// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Created by postproc-shortwords 1.9 on 2011-04-06 13:52:48
// From command line:
//  --quad --standard --minchars=2 --mincount=2
//  --max_items_per_langscript=6000 --flatmap --rr_alloc --freq_alloc
//  --boostcloseweakerpercent=10 --indirectbits=16 --thresh=210 --v25
//  --kentries=256 --34_full
//  --remap=xxx-Latn=>ut-Latn sh-Latn=>hr-Latn sh-Cyrl=>sr-Cyrl
//  nn-Latn=>no-Latn bh-Deva=>ut-Deva mr-Deva=>ut-Deva ne-Deva=>ut-Deva
//  lg-Latn=>ut-Latn rw-Latn=>ut-Latn gd-Latn=>ut-Latn  --include=af-Latn
//  ar-Arab be-Cyrl bg-Cyrl ca-Latn cs-Latn cy-Latn da-Latn de-Latn el-Grek
//  en-Latn es-Latn et-Latn fa-Arab fi-Latn fr-Latn ga-Latn gd-Latn hi-Deva
//  hr-Latn hu-Latn id-Latn is-Latn is-Latn it-Latn iw-Hebr ja-Hani ko-Hani
//  lg-Latn lt-Latn lv-Latn mk-Cyrl ms-Latn nl-Latn no-Latn pl-Latn pt-Latn
//  ro-Latn ru-Cyrl rw-Latn sh-Cyrl sh-Latn sk-Latn sl-Latn sr-Cyrl sv-Latn
//  sw-Latn th-Thai tl-Latn tr-Latn uk-Cyrl vi-Latn yi-Hebr zh-Hani zh-TW
//  sq-Latn az-Latn eu-Latn bn-Beng gl-Latn ht-Latn mt-Latn sr-Latn ur-Arab
//  ut-Latn ut-Deva  --force_to_lang_soft --soft_cram2 --nomsidlevel
//  --shapeflatprob --langpriorpercent=10 --skipnuc --shapeforcetop
//  --shapeeventop --shapesteep2 --langcounts --writebin --list_items=120
//  /export/hda3/cld/all_text_quad_0120_sort.utf8
//
//
// See compact_lang_det.cc for usage
//
#include "encodings/compact_lang_det/cldutil.h"

static const int kQuadChromeBuildDate = 20110406;    // yyyymmdd

COMPILE_ASSERT(MONTENEGRIN == 160, k_montenegrin_changed);
COMPILE_ASSERT(EXT_NUM_LANGUAGES >= 209, k_ext_num_languages_changed);

// Nil-grams: 20 languages
//     GREEK BENGALI MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA
//     PUNJABI GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI
//     CHEROKEE SYRIAC LIMBU ORIYA INUKTITUT

// Uni-grams: 6 languages
//     Japanese Korean Chinese VIETNAMESE ChineseT ZHUANG

// Words/Quads/Gibberish: 52 languages in range ENGLISH..HAITIAN_CREOLE:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     Ignore BULGARIAN CROATIAN SERBIAN IRISH GALICIAN TAGALOG
//     TURKISH UKRAINIAN HINDI MACEDONIAN INDONESIAN MALAY WELSH
//     ALBANIAN BELARUSIAN URDU ARABIC CATALAN BASQUE SWAHILI
//     SLOVENIAN MALTESE VIETNAMESE SLOVAK AZERBAIJANI PERSIAN
//     YIDDISH AFRIKAANS HAITIAN_CREOLE

//  ENGLISH 3456
//  DANISH 3484
//  DUTCH 3417
//  FINNISH 3487
//  FRENCH 3448
//  GERMAN 3397
//  HEBREW 3443
//  ITALIAN 3063
//  NORWEGIAN 3400
//  POLISH 3433
//  PORTUGUESE 3437
//  RUSSIAN 3467
//  SPANISH 3529
//  SWEDISH 3546
//  CZECH 3497
//  ICELANDIC 3422
//  LATVIAN 3497
//  LITHUANIAN 3458
//  ROMANIAN 3465
//  HUNGARIAN 3520
//  ESTONIAN 3430
//  Ignore 6663
//  BULGARIAN 3486
//  CROATIAN 3470
//  SERBIAN 6873
//  IRISH 3469
//  GALICIAN 616
//  TAGALOG 3262
//  TURKISH 3453
//  UKRAINIAN 3465
//  HINDI 3426
//  MACEDONIAN 3437
//  BENGALI 3498
//  INDONESIAN 3328
//  MALAY 3405
//  WELSH 3438
//  ALBANIAN 3500
//  BELARUSIAN 3431
//  URDU 3457
//  ARABIC 3463
//  CATALAN 3422
//  BASQUE 3475
//  SWAHILI 3425
//  SLOVENIAN 3475
//  MALTESE 3432
//  VIETNAMESE 3483
//  SLOVAK 3396
//  AZERBAIJANI 3502
//  PERSIAN 3460
//  YIDDISH 3436
//  AFRIKAANS 3455
//  HAITIAN_CREOLE 3417


static const int kQuadChromeSize = 65536;    // Bucket count
static const int kQuadChromeKeyMask = 0xffff0000;    // Mask hash key

// Of 1187812 offered items (into 262144 table entries):
// 182469 filled (15%), 345 merged (0%), 131090 dropped (11%)
// 873908 items ignored: over --max_items_per_langscript
static const cld::IndirectProbBucket4 kQuadChrome[kQuadChromeSize] = {
  // key[4], words[4] in UTF-8
  // value[4]
  { {0xe9da0001, 0x7c2e0002, 0x394a0003, 0x00000000}},  // [000] вка_, ssbr, _pcbs_,
  { {0x20070004, 0xbddb0005, 0x7bc40006, 0x00000000}},  //   _kuni_, stèr, sniu,
  { {0x65630007, 0xddc40008, 0x7c2e0009, 0x00000000}},  //   denh, _križ, qsbr,
  { {0x27ed000a, 0x63bb000b, 0x2007000c, 0x00000000}},  //   _chen_, jiun, _muni_,
  { {0x2007000d, 0x63a9000e, 0x27ed000f, 0x00000000}},  //   _luni_, dhen, _dhen_,
  { {0xef1f0010, 0x24510011, 0x64430012, 0x00000000}},  //   tjük_, _bơm_, funi,
  { {0x64430013, 0x24510011, 0x28160014, 0x00000000}},  //   guni, _cơm_, _خوزس,
  { {0x63bb0015, 0x63a90016, 0xef1f0010, 0x00000000}},  //   giun, ghen, rjük_,
  { {0x36670017, 0x65630018, 0x443c0019, 0x00000000}},  //   _като_, benh, srv_,
  { {0x6443001a, 0x2007001a, 0x6f04001b, 0x00000000}},  //   buni, _buni_, _agic,
  { {0x6f0f001c, 0x2b9c001d, 0x7528001e, 0x00000000}},  //   tccc, _tích_, _iedz,
  { {0x63a9001f, 0x63bb001a, 0x20070020, 0x00000000}},  //   chen, ciun, _duni_,
  { {0x69dc0021, 0x20000022, 0x6d470023, 0x00000000}},  //   _okre, _diii_, tgja,
  { {0x75280024, 0x71730025, 0x20070026, 0x00000000}},  //   _jedz, _وهنا, _funi_,
  { {0x75280027, 0x6d470028, 0x212c0029, 0x00000000}},  //   _medz, rgja, madh_,
  { {0x212c002a, 0x69c5002b, 0x6d41000c, 0x00000000}},  //   ladh_, wnhe, ólab,
  { {0xafb8002c, 0x6443002d, 0x6b8d002e, 0x00000000}},  // [010] _خطوط_, zuni, rjag,
  { {0x212c002a, 0x63bb001a, 0x63a9002f, 0x00000000}},  //   nadh_, ziun, zhen,
  { {0x65630030, 0x27ed0031, 0x69d70032, 0x00000000}},  //   venh, _phen_, roxe,
  { {0x212c0033, 0x64430034, 0x63bb0035, 0x00000000}},  //   hadh_, vuni, xiun,
  { {0x75280036, 0xd6ab0025, 0x672b0037, 0x00000000}},  //   _bedz, خدام_, ragj,
  { {0x27ed0038, 0x26df0020, 0x672b0023, 0x00000000}},  //   _when_, _vyuo_, sagj,
  { {0x27ed0038, 0x65630039, 0x63bb000d, 0x00000000}},  //   _then_, renh, tiun,
  { {0x6563003a, 0xb385003b, 0x7e6d003c, 0x00000000}},  //   senh, слил, _osap,
  { {0x6563003d, 0x6443003e, 0x63a9003f, 0x00000000}},  //   penh, suni, rhen,
  { {0x212c002a, 0x63bb0040, 0x63a90041, 0x00000000}},  //   gadh_, siun, shen,
  { {0xddc40042, 0x7e6d0032, 0x2a690043, 0x00000000}},  //   _priž, _asap, hwab_,
  { {0x6601002d, 0x06ae0044, 0x44250045, 0x00000000}},  //   _hilk, _ছুটি, _iwl_,
  { {0x66010046, 0x7e6d0047, 0x212c0048, 0x00000000}},  //   _kilk, _csap, badh_,
  { {0x212c002a, 0xb2760049, 0x2000004a, 0x00000000}},  //   cadh_, _לענג_, _wiii_,
  { {0x1015004b, 0xfce6004c, 0xdca3004d, 0x00000000}},  //   _ابتد, сово, пари,
  { {0x69dc004e, 0xee3f004f, 0x6e240050, 0x00000000}},  //   _skre, brý_, _twib,
  { {0x6d410051, 0xddc4002b, 0x00000000, 0x00000000}},  // [020] ólac, _kriż,   ,
  { {0x66010052, 0x44250053, 0x00000000, 0x00000000}},  //   _nilk, _owl_,   ,
  { {0x7528001e, 0x4d7b0049, 0x00000000, 0x00000000}},  //   _redz, _ערטע,   ,
  { {0xbb860054, 0x06d10055, 0x66090056, 0x00000000}},  //   _الحي, ়েছি, _buek,
  { {0x65940057, 0x212c0058, 0x6601002d, 0x00000000}},  //   жалу, yadh_, _bilk,
  { {0xdb16000c, 0x69dc0059, 0xdb0d000c, 0x00000000}},  //   ábær, _ukre, lnað,
  { {0xe644005a, 0xb8960025, 0x4425005b, 0x00000000}},  //   ğlığ, _الزع, _cwl_,
  { {0x5214005c, 0xe644005d, 0x5398005e, 0x00000000}},  //   одит, şlığ, рвия_,
  { {0x6fc8005f, 0x212c0060, 0x00000000, 0x00000000}},  //   rıcl, tadh_,   ,
  { {0x26f60061, 0x44250048, 0xddcd0062, 0x00000000}},  //   ेशीर_, _fwl_, _krať,
  { {0x212c002a, 0xdb0d000c, 0x74130063, 0x00000000}},  //   radh_, knað, _فولا,
  { {0x212c0051, 0x66010064, 0x7f9f0065, 0x00000000}},  //   sadh_, _zilk, _këqi,
  { {0x212c0051, 0xddc40066, 0x00000000, 0x00000000}},  //   padh_, _friż,   ,
  { {0xa2c50067, 0xddc40066, 0x9f490068, 0x00000000}},  //   ापर्, _griż, _thaï_,
  { {0x79950046, 0x5ba70069, 0x63b90016, 0x00000000}},  //   _rozw, браз, _ymwn,
  { {0x2d8c0002, 0xdb0d000c, 0x00000000, 0x00000000}},  //   öder_, gnað,   ,
  { {0x79950046, 0x7e6d006a, 0x6815006b, 0x00000000}},  // [030] _pozw, _usap, _işdə,
  { {0x5a34004c, 0x6729006c, 0x00000000, 0x00000000}},  //   янут, _seej,   ,
  { {0xe719006d, 0x00000000, 0x00000000, 0x00000000}},  //   ليات_,   ,   ,
  { {0x66010030, 0xe00b006e, 0x00000000, 0x00000000}},  //   _silk, _संसद_,   ,
  { {0x6601006f, 0xd2460070, 0x44250071, 0x00000000}},  //   _pilk, _تن_, _swl_,
  { {0xcfcf0044, 0x44150072, 0x00000000, 0x00000000}},  //   রতিন, офит,   ,
  { {0x66010073, 0xddc40066, 0x67290074, 0x00000000}},  //   _vilk, _rriż, _teej,
  { {0x66010075, 0xe3b10076, 0x13090077, 0x00000000}},  //   _wilk, برت_, шний_,
  { {0x66010078, 0xb5fd0079, 0x6609006c, 0x00000000}},  //   _tilk, _apše, _uuek,
  { {0x11d60025, 0x00000000, 0x00000000, 0x00000000}},  //   يوية_,   ,   ,
  { {0xe2a8007a, 0x98b8005d, 0x00000000, 0x00000000}},  //   لاین_, _yarı_,   ,
  { {0x14d6007b, 0x2259007c, 0x31650045, 0x00000000}},  //   _וועל_, _виды_, selz_,
  { {0xc8e6007d, 0x00000000, 0x00000000, 0x00000000}},  //   _कर्म_,   ,   ,
  { {0xa0a5007e, 0x853c007f, 0x00000000, 0x00000000}},  //   _малд, _alėj,   ,
  { {0x09c40055, 0x3b960080, 0x8b960081, 0x00000000}},  //   ্তমা, ојат, орач,
  { {0xe8e00082, 0x00000000, 0x00000000, 0x00000000}},  //   liệu_,   ,   ,
  { {0xdb0d000c, 0x891a0025, 0x00000000, 0x00000000}},  // [040] rnað, لغاز_,   ,
  { {0x2b580014, 0x98b8005a, 0xbc660083, 0x00000000}},  //   _گیرد_, _sarı_, _двок,
  { {0xc8ca0084, 0xd90d0014, 0x00000000, 0x00000000}},  //   جوان_, ایف_,   ,
  { {0x81c10044, 0x00000000, 0x00000000, 0x00000000}},  //   ূতি_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2a620085, 0x00000000, 0x00000000, 0x00000000}},  //   _ipkb_,   ,   ,
  { {0x07a60086, 0x6d5e0087, 0x00000000, 0x00000000}},  //   _давн, _mbpa,   ,
  { {0x81e70044, 0xd3260088, 0x00000000, 0x00000000}},  //   _মূল_, цьки,   ,
  { {0xdcfe0089, 0x6722008a, 0x9f400048, 0x00000000}},  //   _kopē, mboj, _fhiú_,
  { {0xd257008b, 0x27e6008c, 0xdb230051, 0x00000000}},  //   іцы_, llon_, árúc,
  { {0x2018008d, 0xdb060010, 0x26100011, 0x00000000}},  //   ëri_, _elké, _hào_,
  { {0x75ed008e, 0x45220044, 0x00000000, 0x00000000}},  //   púzc, _নাটক_,   ,
  { {0xd2500025, 0xa2d60014, 0x2018008f, 0x00000000}},  //   _أنت_, _بيشت, ūri_,
  { {0x27e60090, 0x99890087, 0x26100082, 0x00000000}},  //   hlon_, ksaš_, _mào_,
  { {0x26100011, 0x27e60091, 0x2ca50092, 0x00000000}},  //   _lào_, klon_, áld_,
  { {0x2a620093, 0xdb1f0023, 0x76420094, 0x00000000}},  //   _bpkb_, miqë, kroy,
  { {0x2610001d, 0x291c006b, 0x27e60016, 0x00000000}},  // [050] _nào_, ıvan_, dlon_,
  { {0xceb20049, 0x76420095, 0x00000000, 0x00000000}},  //   _ניי_, droy,   ,
  { {0x27e60096, 0x00000000, 0x00000000, 0x00000000}},  //   flon_,   ,   ,
  { {0x26100011, 0x27e60016, 0xf0930097, 0x00000000}},  //   _bào_, glon_, ונע_,
  { {0xff7c0049, 0x79a70098, 0x26100082, 0x00000000}},  //   יטאמ, _дрве, _cào_,
  { {0x5a340099, 0x9964009a, 0xbafa009b, 0x00000000}},  //   _інст, _отсл, _להרש,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd90e009c, 0x00000000, 0x00000000, 0x00000000}},  //   _لیے_,   ,   ,
  { {0x7642009d, 0x26100082, 0xe1f2009e, 0x00000000}},  //   croy, _gào_, کسٹ_,
  { {0xd6c60014, 0x14190025, 0x661b008a, 0x00000000}},  //   _عملی, _هيئة_, _ituk,
  { {0x3cdb006e, 0x00000000, 0x00000000, 0x00000000}},  //   _खुले_,   ,   ,
  { {0x6d41009f, 0xc4d200a0, 0xe3b30084, 0x00000000}},  //   ólan, _אגב_, _غرض_,
  { {0x26100011, 0x64df0061, 0xb2c700a1, 0x00000000}},  //   _xào_, _पुतळ, _بغاو,
  { {0xdd9200a2, 0x427a00a3, 0x661b0020, 0x00000000}},  //   روز_, _לאנג, _mtuk,
  { {0x27e600a4, 0xa0a5005e, 0x0c7900a5, 0x00000000}},  //   ylon_, _хайд, осты_,
  { {0xbebb0023, 0x5f7600a6, 0x673b0026, 0x00000000}},  //   mbën, _رابر, _nduj,
  { {0x661b00a7, 0xeb9700a8, 0x4a46007e, 0x00000000}},  // [060] _ntuk, чит_, янав,
  { {0x26100011, 0xfa490025, 0x7e640058, 0x00000000}},  //   _rào_, تشفى_, _ipip,
  { {0x661b00a9, 0x26100082, 0xfce600aa, 0x00000000}},  //   _atuk, _sào_, _хоно,
  { {0x2d9a00ab, 0x6d5c00ac, 0xe737004d, 0x00000000}},  //   _hope_, lfra, зец_,
  { {0x67220089, 0xd90d00a1, 0xf99100a1, 0x00000000}},  //   rboj, ایہ_, ربے_,
  { {0x261000ad, 0x6d4e00ae, 0x6d5c005f, 0x00000000}},  //   _vào_, ngba, nfra,
  { {0x27e600af, 0x7e640009, 0x661b00b0, 0x00000000}},  //   plon_, _lpip, _etuk,
  { {0x69de00b1, 0x764200b2, 0xa85700b3, 0x00000000}},  //   lope, proy, _מילה_,
  { {0x41e6007e, 0x644300b4, 0x04fe0044, 0x00000000}},  //   зіна, arni, ুরের_,
  { {0x69de00b0, 0x6d4e00b5, 0x56370049, 0x00000000}},  //   nope, jgba, _מאמע_,
  { {0xf99300b6, 0x6d5c00b7, 0xe8df0011, 0x00000000}},  //   תרת_, dfra, _trục_,
  { {0xd36f00b8, 0x69de00b9, 0x6d4e00ba, 0x00000000}},  //   _مهم_, hope, egba,
  { {0xe3b3007b, 0x69de00bb, 0x6d5c00bc, 0x00000000}},  //   _אױף_, kope, ffra,
  { {0x72eb00bd, 0x6d5c00be, 0x00000000, 0x00000000}},  //   _פֿאַ, gfra,   ,
  { {0xd5c800ad, 0x645800bf, 0x5ba700c0, 0x00000000}},  //   yền_, ntvi, праз,
  { {0x6d4e00c1, 0xc1780006, 0x6d5c0048, 0x00000000}},  //   agba, ldė_, afra,
  { {0xb99900c2, 0xdcfd00c3, 0xdb0d00c4, 0x00000000}},  // [070] овах_, ızıs, nhaé,
  { {0x5c0700c5, 0x69de007f, 0x644300c6, 0x00000000}},  //   _няма, gope, yrni,
  { {0x3ea6001e, 0x661b00c7, 0xa3be0061, 0x00000000}},  //   _ļoti_, _stuk, ुचा_,
  { {0x64430059, 0x2d9a0032, 0xdc360049, 0x00000000}},  //   vrni, _zope_, _קארט_,
  { {0x69de0035, 0x7bdf004a, 0xb5fd00c8, 0x00000000}},  //   bope, moqu, _apša,
  { {0x7bdf00c9, 0x644300ca, 0x645800cb, 0x00000000}},  //   loqu, trni, ftvi,
  { {0x64580039, 0xbddb0068, 0x644300cc, 0x00000000}},  //   gtvi, yrèn, urni,
  { {0x7bcd00cd, 0x644300ce, 0x22150069, 0x00000000}},  //   nnau, rrni, мфор,
  { {0x6d5c0016, 0x661b0020, 0xd11e0061, 0x00000000}},  //   yfra, _utuk, _म्हण_,
  { {0x7bcd00cf, 0x644300d0, 0x10a500d1, 0x00000000}},  //   hnau, prni, дион,
  { {0x54550001, 0x7e640026, 0x645800d2, 0x00000000}},  //   _цвет, _spip, ctvi,
  { {0xd24e00d3, 0x201800d4, 0xe29100a2, 0x00000000}},  //   دنی_, íria_, _لذت_,
  { {0x6d5c00d5, 0x69de0020, 0x7bdf00d6, 0x00000000}},  //   tfra, yope, doqu,
  { {0x90c500d7, 0x7ae600d8, 0x69de00d9, 0x00000000}},  //   _обле, _rykt, xope,
  { {0xfce300da, 0x6d5c00db, 0x7bdf00dc, 0x00000000}},  //   воро, rfra, foqu,
  { {0x6d5c00dd, 0x8ffa0014, 0x69de00de, 0x00000000}},  //   sfra, _برتر_, wope,
  { {0x69de0056, 0x2d9a008e, 0x6d5c00df, 0x00000000}},  // [080] tope, _tope_, pfra,
  { {0x7bcd00d9, 0x764b00e0, 0x200e0022, 0x00000000}},  //   anau, dugy, _yufi_,
  { {0x8b2600e1, 0xeb9a00e2, 0x7bdf00c4, 0x00000000}},  //   _одне, _дин_, boqu,
  { {0x46ea00e3, 0x69de00b0, 0x7bdf009d, 0x00000000}},  //   оден_, sope, coqu,
  { {0x69de00e4, 0xe67700e5, 0x00000000, 0x00000000}},  //   pope, _aţâţ,   ,
  { {0x645800e6, 0x644a00e7, 0x28d900e8, 0x00000000}},  //   ttvi, tufi, _बुकि,
  { {0xd90d00e9, 0x799c005b, 0x645800ea, 0x00000000}},  //   _ایم_, _iorw, utvi,
  { {0x645800eb, 0xc27400ec, 0x02a600ed, 0x00000000}},  //   rtvi, елиј, дром,
  { {0x645800ee, 0x200e00ef, 0x6aa400f0, 0x00000000}},  //   stvi, _sufi_, nyif,
  { {0xb5aa0025, 0x2fc000f1, 0xc178007f, 0x00000000}},  //   _بارك_, _amig_, udė_,
  { {0x799c005b, 0x7bcd0068, 0xc1780006, 0x00000000}},  //   _morw, ynau, rdė_,
  { {0x2d9e00f2, 0x733600f3, 0xdce50027, 0x00000000}},  //   öten_, _آرائ, _pohľ,
  { {0x799c0007, 0x7bdf00f4, 0x69cb0010, 0x00000000}},  //   _oorw, voqu, égek,
  { {0x29070006, 0x200e00f5, 0x320700f6, 0x00000000}},  //   žnai_, _tufi_, _giny_,
  { {0x7bdf00f7, 0x00000000, 0x00000000, 0x00000000}},  //   toqu,   ,   ,
  { {0x62820004, 0x26ee007d, 0x660800f8, 0x00000000}},  //   _kroo, _जरूर_, _lidk,
  { {0x7bcd00f4, 0x7bdf009d, 0xdee7006d, 0x00000000}},  // [090] rnau, roqu, _تأثي,
  { {0xf99300f9, 0x6e2d0009, 0xdb0d009d, 0x00000000}},  //   خبر_, _iwab, chaî,
  { {0x20090093, 0x7bdf00fa, 0x00000000, 0x00000000}},  //   _kiai_, poqu,   ,
  { {0x6e2d00fb, 0x6aa40045, 0x764b00e0, 0x00000000}},  //   _kwab, byif, tugy,
  { {0x799c00ab, 0x68e70036, 0x00000000, 0x00000000}},  //   _forw, _wyjd,   ,
  { {0xba430006, 0x442c0022, 0x799c0016, 0x00000000}},  //   žįst, _bwd_, _gorw,
  { {0x76590016, 0x645c006c, 0x69c50052, 0x00000000}},  //   stwy, _äril, mihe,
  { {0x6f0d00fc, 0x7c3a00fd, 0x628200fe, 0x00000000}},  //   _ngac, átri, _broo,
  { {0x020500d7, 0x09c40044, 0x6b9d00ff, 0x00000000}},  //   нзин, ্তরা, _mosg,
  { {0x62820100, 0x6f0d0101, 0xe5c40102, 0x00000000}},  //   _droo, _agac, _исхо,
  { {0x62820103, 0xf9920104, 0x444500a1, 0x00000000}},  //   _eroo, ארי_, _سراہ,
  { {0x6e2d0009, 0x69c50105, 0x62820056, 0x00000000}},  //   _bwab, hihe, _froo,
  { {0xee370106, 0x62820100, 0x614500d7, 0x00000000}},  //   ння_, _groo, _зела,
  { {0x7c220107, 0x4cc10044, 0x6f0d00f6, 0x00000000}},  //   _čorb, _শুধু, _egac,
  { {0x61e10108, 0x6b9d002d, 0x69c500e0, 0x00000000}},  //   moll, _bosg, dihe,
  { {0x63a90109, 0xddcd010a, 0x20090011, 0x00000000}},  //   nken, _graž, _giai_,
  { {0x799c010b, 0x6e2d0045, 0x63a9010c, 0x00000000}},  // [0a0] _porw, _gwab, iken,
  { {0x61e1010d, 0x63a9010e, 0x00000000, 0x00000000}},  //   noll, hken,   ,
  { {0x799c010f, 0x5746004d, 0x6aa40022, 0x00000000}},  //   _vorw, енеб, syif,
  { {0x61e100b0, 0x1bba0076, 0x63a900b5, 0x00000000}},  //   holl, _راجع_, jken,
  { {0x61e10110, 0x63a90030, 0x99800006, 0x00000000}},  //   koll, dken, usių_,
  { {0x442c0111, 0x63a90112, 0x224d0032, 0x00000000}},  //   _pwd_, eken, duek_,
  { {0x18670113, 0x61e100b0, 0x63a900d9, 0x00000000}},  //   _пари_, doll, fken,
  { {0x62820114, 0x645c006c, 0x00000000, 0x00000000}},  //   _proo, _ärim,   ,
  { {0x61e1001c, 0x6d41000c, 0x660800ea, 0x00000000}},  //   foll, ólak, _tidk,
  { {0xbddb0115, 0x62820116, 0x6e2d0117, 0x00000000}},  //   trèm, _vroo, _rwab,
  { {0x6e2d002b, 0xddcd00b9, 0x316c0089, 0x00000000}},  //   _swab, _praž, redz_,
  { {0x645a005f, 0x63a9010f, 0xd4690054, 0x00000000}},  //   _iqti, cken, _تحكم_,
  { {0x71a6008b, 0x657a010f, 0x61e1006c, 0x00000000}},  //   _падз, _kath, boll,
  { {0x61e10118, 0xd12f007a, 0x40940025, 0x00000000}},  //   coll, _همه_, _للتر,
  { {0xddcd0119, 0x6b9d011a, 0x6280011b, 0x00000000}},  //   _traž, _posg, lvmo,
  { {0x657a011c, 0x6e2d011d, 0x69c50045, 0x00000000}},  //   _lath, _twab, wihe,
  { {0x245a008d, 0x3df5011e, 0xef64005e, 0x00000000}},  // [0b0] hëm_, _изис, _също,
  { {0xdb0d002a, 0x3eb3011f, 0x63a9002d, 0x00000000}},  //   mhaí, ıntı_, zken,
  { {0x69c50065, 0x63a90120, 0x00000000, 0x00000000}},  //   rihe, yken,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8b9a009b, 0x657a00ab, 0x8a180121, 0x00000000}},  //   _חברת, _bath, _пояс_,
  { {0x657a0122, 0x65940088, 0x1a680123, 0x00000000}},  //   _cath, лачу, _سیمی_,
  { {0x657a0124, 0x61e10125, 0x63a900b0, 0x00000000}},  //   _dath, voll, tken,
  { {0xc178010a, 0x68e3010f, 0x657a0126, 0x00000000}},  //   klės_, ündu, _eath,
  { {0x63a90127, 0x61e100b0, 0x657a00ab, 0x00000000}},  //   rken, toll, _fath,
  { {0x63a90128, 0x92640025, 0x777b002d, 0x00000000}},  //   sken, اديم, _haux,
  { {0x63a90023, 0x224d0032, 0x00000000, 0x00000000}},  //   pken, suek_,   ,
  { {0x61e100b0, 0x00000000, 0x00000000, 0x00000000}},  //   soll,   ,   ,
  { {0x61e10129, 0xddcd002b, 0x657a012a, 0x00000000}},  //   poll, _fraż, _yath,
  { {0x6145012b, 0x777b0082, 0x00000000, 0x00000000}},  //   _река, _laux,   ,
  { {0xb02400ad, 0xfce6012c, 0x00000000, 0x00000000}},  //   _trườ, тово,   ,
  { {0xf4130055, 0x8e4a0025, 0x69d5012d, 0x00000000}},  //   _সবার_, _قلبك_, _ajze,
  { {0xc332012e, 0x7f77012f, 0x245a0065, 0x00000000}},  // [0c0] יון_, _יעקב_, zëm_,
  { {0xe9d70130, 0x2d950131, 0x9f4000f6, 0x00000000}},  //   вку_, _брюс, _thió_,
  { {0x657a0132, 0x777b0082, 0xdd050035, 0x00000000}},  //   _rath, _baux, ăsăt,
  { {0x657a0051, 0x7bda009d, 0xb09a0049, 0x00000000}},  //   _sath, étud, ויער,
  { {0x657a0133, 0x4991009e, 0x00000000, 0x00000000}},  //   _path, _گیلر,   ,
  { {0x245a008d, 0x645c006c, 0x7c3a0134, 0x00000000}},  //   tëm_, _ärik, štru,
  { {0x629d00f8, 0xd467003b, 0x657a0135, 0x00000000}},  //   äson, вије_, _vath,
  { {0x07a30136, 0x657a00e7, 0x245a0023, 0x00000000}},  //   _касн, _wath, rëm_,
  { {0xa6650137, 0x657a0138, 0x245a0065, 0x00000000}},  //   _مطلو, _tath, sëm_,
  { {0x657a002a, 0x601e001e, 0x909800e2, 0x00000000}},  //   _uath, _līme, евот_,
  { {0x8f350139, 0x9f35013a, 0x00000000, 0x00000000}},  //   ленц, лені,   ,
  { {0xdb0d0051, 0x1fa7013b, 0xddcd0036, 0x00000000}},  //   thaí, трог, _wraż,
  { {0x7c22013c, 0xecdb013d, 0xddcd0066, 0x00000000}},  //   _čora, _मुजफ, _traż,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3d6007d, 0xc1f70049, 0x3ead013e, 0x00000000}},  //   _सदा_, _שמוץ_, šet_,
  { {0x644a0051, 0x7d080010, 0x443e013f, 0x00000000}},  //   irfi, _sérü, _mvt_,
  { {0x62840006, 0x00000000, 0x00000000, 0x00000000}},  // [0d0] _šioj,   ,   ,
  { {0x4c950140, 0x443e0141, 0x23b10142, 0x00000000}},  //   _биос, _ovt_, _mája_,
  { {0x29070039, 0x98140025, 0x4cc10044, 0x00000000}},  //   äna_, لبنا, _শুরু,
  { {0x2cac0056, 0xc8640143, 0x00000000, 0x00000000}},  //   ødde_, ртфи,   ,
  { {0x499300a1, 0x443e0144, 0x7bda009d, 0x00000000}},  //   _پیار, _avt_, étue,
  { {0x6d5500b5, 0x601e0089, 0xf4830014, 0x00000000}},  //   ngza, _zīme, لاعی,
  { {0x69d80061, 0xe894007c, 0x00000000, 0x00000000}},  //   _मदती, _карь,   ,
  { {0x29070006, 0x58d40131, 0x2a790145, 0x00000000}},  //   žnas_, _тост, _kssb_,
  { {0x443e0030, 0x644a0066, 0xdb060146, 0x00000000}},  //   _evt_, arfi, _elkæ,
  { {0xdb040051, 0x443e0056, 0x00000000, 0x00000000}},  //   thiú, _fvt_,   ,
  { {0xcea9007b, 0x8fa6005e, 0x443e00c4, 0x00000000}},  //   _צי_, гане, _gvt_,
  { {0x26190082, 0x01c800a1, 0xdb0f0068, 0x00000000}},  //   _kèo_, _یونٹ_, _ulcè,
  { {0xe1ee0147, 0x2bc6006e, 0x00000000, 0x00000000}},  //   _гг_, रोफा,   ,
  { {0x26190011, 0x00000000, 0x00000000, 0x00000000}},  //   _mèo_,   ,   ,
  { {0x225f0148, 0xbb460140, 0x26190082, 0x00000000}},  //   ltuk_, левк, _lèo_,
  { {0xc05200b6, 0x39430009, 0x3a220022, 0x00000000}},  //   _הזה_, _adjs_, _ptkp_,
  { {0x225f0149, 0x26190082, 0x00000000, 0x00000000}},  // [0e0] ntuk_, _nèo_,   ,
  { {0x6e24014a, 0x8d56003b, 0x44270022, 0x00000000}},  //   _itib, _стич, kpn_,
  { {0xdca600d7, 0x395800fa, 0x31360049, 0x00000000}},  //   _сани, _vcrs_, רנעם_,
  { {0x26190082, 0x225f014b, 0xfaff0023, 0x00000000}},  //   _bèo_, ktuk_, _ibën_,
  { {0x443e0039, 0xe5c6014c, 0xe5a6014d, 0x00000000}},  //   _svt_, лско, лиди,
  { {0x443e014e, 0x2816007a, 0x6e2400e7, 0x00000000}},  //   _pvt_, _موسس, _mtib,
  { {0xdd32006b, 0x644a014f, 0x00000000, 0x00000000}},  //   zəşt, urfi,   ,
  { {0x7f440065, 0x644a0150, 0x722a007c, 0x00000000}},  //   _ndiq, rrfi, нцов_,
  { {0x27e60007, 0x6e240061, 0x8556004b, 0x00000000}},  //   moon_, _ntib, _مخاط,
  { {0x27e600b0, 0xd6cf0151, 0x104a0152, 0x00000000}},  //   loon_, _عقل_, нями_,
  { {0xe7b80061, 0x94260153, 0x6e240154, 0x00000000}},  //   _आताप, _смее, _atib,
  { {0x27e60155, 0x2a600156, 0x00000000, 0x00000000}},  //   noon_, ktib_,   ,
  { {0x44ce006b, 0x00000000, 0x00000000, 0x00000000}},  //   _hə_,   ,   ,
  { {0x63a2006c, 0x27e60157, 0x3cb5007e, 0x00000000}},  //   _hoon, hoon_, айгр,
  { {0x63a2006c, 0x27e60158, 0x6e24006b, 0x00000000}},  //   _koon, koon_, _etib,
  { {0x764b0159, 0x63a2015a, 0x44ce006b, 0x00000000}},  //   yrgy, _joon, _mə_,
  { {0x38c900a1, 0x27e60058, 0x44ce006b, 0x00000000}},  // [0f0] ھائی_, doon_, _lə_,
  { {0x63a2015b, 0x2bc6013d, 0x60d30089, 0x00000000}},  //   _loon, रोबा, ņemš,
  { {0x44ce005f, 0x27e6015c, 0x6d45015d, 0x00000000}},  //   _nə_, foon_, _idha,
  { {0x63a2006a, 0xbddb00f4, 0x205700a0, 0x00000000}},  //   _noon, ssèd, ריאל_,
  { {0x69cb0010, 0x6e2400fa, 0xbb3a00a0, 0x00000000}},  //   éges, _xtib, _בערי,
  { {0xce38009b, 0x7e6d015e, 0x9f42015f, 0x00000000}},  //   נאות_, _mpap, roké_,
  { {0x63a20160, 0x9f420161, 0x6d450162, 0x00000000}},  //   _boon, soké_, _mdha,
  { {0x44ce0163, 0xc245003b, 0x225f0010, 0x00000000}},  //   _də_, аник, ttuk_,
  { {0xa3d60164, 0x6d450165, 0x63a2010e, 0x00000000}},  //   _सदर_, _odha, _doon,
  { {0xb5fd0166, 0xf4850167, 0x7dc9012d, 0x00000000}},  //   _opši, _پائی, džso,
  { {0x225f0168, 0x7e6d0169, 0xf07600a1, 0x00000000}},  //   stuk_, _apap, لیوں_,
  { {0x6d45016a, 0x63a2016b, 0x9989016c, 0x00000000}},  //   _adha, _goon, jsaž_,
  { {0x7c25016d, 0x69c7016e, 0x7f440023, 0x00000000}},  //   _athr, _omje, _vdiq,
  { {0x63a200bb, 0x44ce006b, 0x27e6016f, 0x00000000}},  //   _zoon, _yə_, zoon_,
  { {0x7e6d0170, 0x417400a2, 0x30790049, 0x00000000}},  //   _epap, _دانس, _יאַנ,
  { {0x44250171, 0x4b26007e, 0x63a20082, 0x00000000}},  //   _mtl_, рмав, _xoon,
  { {0x44250172, 0x3f920058, 0x98b10173, 0x00000000}},  // [100] _ltl_, _inyu_, _dezč_,
  { {0x27e6015c, 0x644100b9, 0xd946005c, 0x00000000}},  //   woon_, _ovli, режи,
  { {0x27e600b0, 0xe73a0174, 0xb6070089, 0x00000000}},  //   toon_, вее_, _mašī,
  { {0xb6cb00a1, 0xd62a0175, 0xbebb0065, 0x00000000}},  //   ھانے_, воде_, rbëv,
  { {0x27e6006a, 0x64410039, 0x63a20082, 0x00000000}},  //   roon_, _avli, _roon,
  { {0xbebb008d, 0x27e60176, 0x44250177, 0x00000000}},  //   mbët, soon_, _btl_,
  { {0x44250061, 0x27e600b0, 0x63a20178, 0x00000000}},  //   _ctl_, poon_, _poon,
  { {0x44ce0163, 0x44250179, 0x3266017a, 0x00000000}},  //   _və_, _dtl_, атов,
  { {0x6441014a, 0xe57a003b, 0x4425017b, 0x00000000}},  //   _evli, _иза_, _etl_,
  { {0x63a2017c, 0x44ce006b, 0xdce700b4, 0x00000000}},  //   _woon, _tə_, leją,
  { {0x63a2017d, 0x00000000, 0x00000000, 0x00000000}},  //   _toon,   ,   ,
  { {0x224d017e, 0xc477009b, 0x232a017f, 0x00000000}},  //   brek_, _כתבו_, _роди_,
  { {0x539b0104, 0x44250026, 0xef1f0180, 0x00000000}},  //   _שידו, _ztl_, rcü_,
  { {0xdb0d0181, 0x4425014a, 0x00000000, 0x00000000}},  //   lhaç, _ytl_,   ,
  { {0xab95003b, 0xd1380036, 0x00000000, 0x00000000}},  //   бављ, ając_,   ,
  { {0x69c70182, 0x5b15003b, 0xdb0d00c4, 0x00000000}},  //   _smje, смат, nhaç,
  { {0x2bc60183, 0x2fc90096, 0x6d41000c, 0x00000000}},  // [110] रोधा, _imag_, ólas,
  { {0x6d450020, 0x2887003b, 0x61e800f8, 0x00000000}},  //   _udha, ићев, nodl,
  { {0x2fc90087, 0xcd76009b, 0x4dda009b, 0x00000000}},  //   _kmag_, _העתק_, _תחתו,
  { {0x61e80161, 0x9a870184, 0x2d830185, 0x00000000}},  //   hodl, _кугл, ldje_,
  { {0x7bcd010a, 0x44250186, 0x2d81006c, 0x00000000}},  //   miau, _stl_, _kahe_,
  { {0x69c70182, 0x2d830187, 0x7bcd010a, 0x00000000}},  //   _umje, ndje_, liau,
  { {0xf7730188, 0x58d4013b, 0x77690066, 0x00000000}},  //   _وار_, _дорт, _tbex,
  { {0x224d0007, 0x7bcd0006, 0x2d81006c, 0x00000000}},  //   trek_, niau, _lahe_,
  { {0x6aad00d4, 0x27ed0189, 0x3f800022, 0x00000000}},  //   nyaf, _iken_, _raiu_,
  { {0x224d018a, 0xddc4018b, 0x4425018c, 0x00000000}},  //   rrek_, _opiš, _ttl_,
  { {0x600a0175, 0x7bcd0006, 0x27ed018d, 0x00000000}},  //   лном_, kiau, _kken_,
  { {0x25a5018e, 0xdb0d00c4, 0x224d018f, 0x00000000}},  //   _holl_, chaç, prek_,
  { {0x2169005e, 0x25a50039, 0x4ac7013d, 0x00000000}},  //   _били_, _koll_, _रेलव,
  { {0x2d830182, 0x412600e3, 0x63bb0190, 0x00000000}},  //   gdje_, _лошо_, lhun,
  { {0x25a50191, 0x27ed0192, 0x705500a1, 0x00000000}},  //   _moll_, _oken_, _انعا,
  { {0x7bcd0006, 0x25a5006c, 0x6d41000c, 0x00000000}},  //   giau, _loll_, ólar,
  { {0x3946007e, 0xdb1d0030, 0xdb0f00c4, 0x00000000}},  // [120] йнаг, _omsæ, _alcâ,
  { {0x645c0193, 0x0d830194, 0x25a500f8, 0x00000000}},  //   _årig, _ельн, _noll_,
  { {0x6c860054, 0x7bcd0006, 0x27ff0051, 0x00000000}},  //   _الجم, biau, _bhun_,
  { {0x27ff0195, 0x7bcd0196, 0x628b0197, 0x00000000}},  //   _chun_, ciau, _orgo,
  { {0x25a50150, 0x95ca00ed, 0x6b8400f6, 0x00000000}},  //   _boll_, лука_, mdig,
  { {0x6b840073, 0x25a50129, 0x27ff002d, 0x00000000}},  //   ldig, _coll_, _ehun_,
  { {0x628b0198, 0x31cd0055, 0x61e80142, 0x00000000}},  //   _argo, রকাশ, vodl,
  { {0x63bb0199, 0x2915019a, 0x78a100d4, 0x00000000}},  //   ghun, ğdaş_, _àlva,
  { {0x1a9a007b, 0xd1300025, 0x6b84010f, 0x00000000}},  //   ריִע, ومة_, idig,
  { {0x361b019b, 0x154300c0, 0x2fc9019c, 0x00000000}},  //   _עובד, _неум, _smag_,
  { {0x9f99019d, 0x63bb0048, 0x00000000, 0x00000000}},  //   авну_, bhun,   ,
  { {0x63bb019e, 0xf8b300b6, 0x753a00b5, 0x00000000}},  //   chun, פשר_, _hetz,
  { {0x6b84019f, 0x7bcd0006, 0xddc40142, 0x00000000}},  //   ddig, viau, _spiš,
  { {0x753a001f, 0x6b8401a0, 0x0dc800d7, 0x00000000}},  //   _jetz, edig, буси_,
  { {0x2d8301a1, 0x753a01a2, 0x7bcd01a3, 0x00000000}},  //   rdje_, _metz, tiau,
  { {0x753a001f, 0xddc40059, 0x5c0701a4, 0x00000000}},  //   _letz, _vpiš, сяга,
  { {0x7bcd010a, 0x6e36018e, 0x00000000, 0x00000000}},  // [130] riau, _gwyb,   ,
  { {0x753a001f, 0x6b8401a5, 0x7bcd0006, 0x00000000}},  //   _netz, adig, siau,
  { {0x27ff0011, 0x8af0006b, 0x25a501a6, 0x00000000}},  //   _phun_, lgəl, _roll_,
  { {0x25a5001f, 0x64c3001c, 0x63bb01a7, 0x00000000}},  //   _soll_, _वेगळ, xhun,
  { {0x95990088, 0xb5fd01a8, 0xe738007e, 0x00000000}},  //   итку_, _opšt, сеі_,
  { {0x7afd01a9, 0x3c1801aa, 0x00000000, 0x00000000}},  //   _izst, _sčvi_,   ,
  { {0x25a5010f, 0x7995010f, 0x27ff0011, 0x00000000}},  //   _voll_, _inzw, _thun_,
  { {0x42250131, 0x27ed00ea, 0xb22501ab, 0x00000000}},  //   одив, _uken_, омил,
  { {0x25a501ac, 0x248c004a, 0x00000000, 0x00000000}},  //   _toll_, _erdm_,   ,
  { {0x63bb01ad, 0x628b016e, 0xdb1d000c, 0x00000000}},  //   shun, _vrgo, _umsæ,
  { {0xc952019b, 0x00e2008b, 0x6b840007, 0x00000000}},  //   ומי_, джэн, ydig,
  { {0x628b01ae, 0xe3b301af, 0x661b01b0, 0x00000000}},  //   _trgo, _عرض_, _kuuk,
  { {0x61450057, 0x333f00f4, 0x64430039, 0x00000000}},  //   _дела, maux_, lsni,
  { {0x661b01b1, 0x116701b2, 0x00000000, 0x00000000}},  //   _muuk, _طلبی_,   ,
  { {0x8fa601b3, 0x64430056, 0x661b01b4, 0x00000000}},  //   _маке, nsni, _luuk,
  { {0x333f00f4, 0x6b8401b5, 0xbebb0065, 0x00000000}},  //   naux_, udig, rbër,
  { {0x6b8401b6, 0x37cf0044, 0xba2901b7, 0x00000000}},  // [140] rdig, িকার, مسلم_,
  { {0x64430006, 0x6b8401b8, 0x00000000, 0x00000000}},  //   ksni, sdig,   ,
  { {0x2d95008b, 0xdb060065, 0x64430190, 0x00000000}},  //   _хрыс, _kokë, jsni,
  { {0x6d5c01b9, 0x753a010f, 0xbddb01aa, 0x00000000}},  //   lgra, _setz, nsèn,
  { {0x3e6401ba, 0x7c2e01bb, 0x64430089, 0x00000000}},  //   nöt_, lpbr, esni,
  { {0x6d5c01bc, 0x2738001d, 0xc7b90010, 0x00000000}},  //   ngra, ẩn_, _elő_,
  { {0xe73a01bd, 0x26360046, 0x29180059, 0x00000000}},  //   _веб_, sło_, _igra_,
  { {0x66e601be, 0x938a0072, 0x2b400051, 0x00000000}},  //   _доба, рска_, naic_,
  { {0x6d5c00ea, 0xbddb00f6, 0x00000000, 0x00000000}},  //   kgra, krèp,   ,
  { {0x23b800f4, 0x00000000, 0x00000000, 0x00000000}},  //   _déja_,   ,   ,
  { {0x6d5c00ee, 0x213e00cf, 0xdfd10025, 0x00000000}},  //   dgra, rath_, فيد_,
  { {0xa2cb001c, 0x333f00f4, 0x442e010f, 0x00000000}},  //   _तेव्, caux_, mpf_,
  { {0x645800b0, 0x2294005e, 0x213e0133, 0x00000000}},  //   luvi, _хиля, path_,
  { {0x6d5c01bf, 0xe2a900a6, 0xb5fd012d, 0x00000000}},  //   ggra, _دامن_, _upšt,
  { {0x5ba701c0, 0xe0d40049, 0x60210089, 0x00000000}},  //   ораз, _מײַ_, _tēma,
  { {0x6d5c002a, 0x291801c1, 0xc05300b3, 0x00000000}},  //   agra, _agra_, _חזק_,
  { {0x201c006c, 0x645801c2, 0x7c2e01c3, 0x00000000}},  // [150] _huvi_, huvi, apbr,
  { {0x644301c4, 0x645800b0, 0x673b0022, 0x00000000}},  //   ysni, kuvi, _seuj,
  { {0xe7190025, 0x333f009d, 0xf8b100a6, 0x00000000}},  //   ميات_, yaux_, رکس_,
  { {0x7e7d0061, 0x6c7a0049, 0x5c7a0049, 0x00000000}},  //   owsp, _פארפ, _פארה,
  { {0x333f00f4, 0x7afd001e, 0xcb9a009b, 0x00000000}},  //   vaux_, _uzst, _הסרט,
  { {0x64430039, 0x201c00c4, 0xf783002b, 0x00000000}},  //   tsni, _ouvi_, _seħħ_,
  { {0x333f00f4, 0x2246000a, 0x645801c5, 0x00000000}},  //   taux_, _avok_, guvi,
  { {0x64430089, 0x394101c6, 0x6d5c0091, 0x00000000}},  //   rsni, lahs_, zgra,
  { {0x64430039, 0x333f00f4, 0xe43000a1, 0x00000000}},  //   ssni, raux_, _یہود,
  { {0x6443010a, 0x6578014a, 0x2b4001c7, 0x00000000}},  //   psni, cevh, zaic_,
  { {0x645c006c, 0x333f00f4, 0xc9520049, 0x00000000}},  //   _ärip, paux_, עמט_,
  { {0xbebb0065, 0xb4fa009b, 0x6d5c005b, 0x00000000}},  //   rcën, _הפעי, wgra,
  { {0x3fc90014, 0x00000000, 0x00000000, 0x00000000}},  //   تگوی_,   ,   ,
  { {0x6d5c0129, 0xda1f013d, 0x00000000, 0x00000000}},  //   ugra, _बढ़त_,   ,
  { {0x9f9201c8, 0x6d5c0056, 0xdb060065, 0x00000000}},  //   lší_, rgra, _tokë,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6e460054, 0x6d5c01c9, 0x9f9201ca, 0x00000000}},  // [160] _عندم, pgra, nší_,
  { {0x2b4001cb, 0x00000000, 0x00000000, 0x00000000}},  //   saic_,   ,   ,
  { {0x9d1b00a3, 0x2b400048, 0x00000000, 0x00000000}},  //   _לויט, paic_,   ,
  { {0xdc9b0097, 0x00000000, 0x00000000, 0x00000000}},  //   _היטל,   ,   ,
  { {0x9f92004f, 0x9b17009b, 0x7f8d0049, 0x00000000}},  //   jší_, _מחכה_, ינאַ,
  { {0x6458010a, 0x8afb009b, 0x9f9201ca, 0x00000000}},  //   tuvi, _להכי, dší_,
  { {0x69ce011c, 0x80d00055, 0xdd570049, 0x00000000}},  //   _imbe, _সুন্, לבסט_,
  { {0x645800f8, 0xdb060026, 0x7d0701cc, 0x00000000}},  //   ruvi, _pokè, léré,
  { {0x201c01c2, 0xd046006b, 0x00000000, 0x00000000}},  //   _suvi_, əmək,   ,
  { {0x7d0700f4, 0x00000000, 0x00000000, 0x00000000}},  //   néré,   ,   ,
  { {0xf993009b, 0x69ce0145, 0x00000000, 0x00000000}},  //   גרת_, _mmbe,   ,
  { {0x442c01cd, 0x602800b9, 0x78fb01ce, 0x00000000}},  //   _itd_, _něme, מפיו,
  { {0x442c01cf, 0x9f4b004a, 0x9f590048, 0x00000000}},  //   _htd_, nocé_, omsú_,
  { {0x2b4b01d0, 0x442c01d1, 0x127b01ce, 0x00000000}},  //   _sdcc_, _ktd_, _לאדע,
  { {0x6b8601d2, 0x7d0700f4, 0x9f420161, 0x00000000}},  //   _bakg, déré, soká_,
  { {0x442c01d3, 0x69ce01d4, 0x3a2b0026, 0x00000000}},  //   _mtd_, _ambe, _ptcp_,
  { {0x442c01d5, 0xdcf20089, 0x394101d6, 0x00000000}},  // [170] _ltd_, īgāk, tahs_,
  { {0xceb2007b, 0x6e2d01d7, 0x291c016c, 0x00000000}},  //   _סיי_, _itab, žvan_,
  { {0x39410146, 0xf1b30049, 0xa3be013d, 0x00000000}},  //   rahs_, עסע_, ीफा_,
  { {0x69ce0047, 0x256f005a, 0x00000000, 0x00000000}},  //   _embe, zılı_,   ,
  { {0xd24601d8, 0x442c01ca, 0x644801d9, 0x00000000}},  //   _جن_, _atd_, _avdi,
  { {0xcb1200b6, 0x79e700a1, 0x93b50082, 0x00000000}},  //   _שלך_, _روزہ_, _cũn,
  { {0x62820007, 0x442c01da, 0x2409007c, 0x00000000}},  //   _asoo, _ctd_, онки_,
  { {0x442c01db, 0x9f9201dc, 0xc2e60044, 0x00000000}},  //   _dtd_, tší_, খেছি_,
  { {0x6e2d01dd, 0x442c0022, 0x2a690058, 0x00000000}},  //   _ntab, _etd_, ntab_,
  { {0x9f9201ca, 0xab5b010f, 0x442c01de, 0x00000000}},  //   rší_, _flüg, _ftd_,
  { {0xd3710054, 0x6e2d0095, 0x256f01df, 0x00000000}},  //   _لها_, _atab, rılı_,
  { {0x9f92004f, 0x2a6901a3, 0x79870173, 0x00000000}},  //   pší_, ktab_, _lajw,
  { {0xee3701e0, 0xa29401e1, 0xc61f0044, 0x00000000}},  //   мня_, _паці, নীরা_,
  { {0x79870046, 0x6e2d0051, 0x63ab01e2, 0x00000000}},  //   _najw, _dtab, _hogn,
  { {0x6e2d01e3, 0x2c8700b9, 0x6b8601c3, 0x00000000}},  //   _etab, vídá_, _pakg,
  { {0xeb9701e4, 0x6e2d0022, 0x00000000, 0x00000000}},  //   мис_, _ftab,   ,
  { {0x63a60039, 0x63ab00f8, 0xeafa0061, 0x00000000}},  // [180] ökni, _mogn, ्धेत_,
  { {0x63ab01e5, 0x00000000, 0x00000000, 0x00000000}},  //   _logn,   ,   ,
  { {0x7649009d, 0x1d0a00ed, 0x2d9a00fa, 0x00000000}},  //   _avey, _фени_, _inpe_,
  { {0xb7be0044, 0x442c00e7, 0x7d0701e6, 0x00000000}},  //   েক্ট, _rtd_, séré,
  { {0x4cd30055, 0x442c01e7, 0x47330088, 0x00000000}},  //   _দুপু, _std_, тніс,
  { {0x69ce006c, 0x442c0145, 0x00000000, 0x00000000}},  //   _umbe, _ptd_,   ,
  { {0x63ab0190, 0xb8f30044, 0x644d0089, 0x00000000}},  //   _bogn, _হু_, ņain,
  { {0x63ab01e8, 0x00000000, 0x00000000, 0x00000000}},  //   _cogn,   ,   ,
  { {0x9f55000c, 0x056601e9, 0x63ab01ea, 0x00000000}},  //   ófíl_, _ован, _dogn,
  { {0x442c0093, 0x602800b9, 0x26c6004a, 0x00000000}},  //   _ttd_, _němc, mzoo_,
  { {0x6e2d01eb, 0x395700b6, 0x63ab01ec, 0x00000000}},  //   _stab, ושים_, _fogn,
  { {0xe29a008b, 0x69de0026, 0x63ab0026, 0x00000000}},  //   _мае_, hnpe, _gogn,
  { {0x26c60146, 0xdde201ed, 0x31c601ee, 0x00000000}},  //   nzoo_, _šušk, _оскв,
  { {0xe0cf01ef, 0x25ac012d, 0x63ab0026, 0x00000000}},  //   ازی_, _jodl_, _zogn,
  { {0xdb060047, 0x7987000a, 0x00000000, 0x00000000}},  //   _elkü, _rajw,   ,
  { {0x6e2d0022, 0x2d9a01aa, 0x3eae0065, 0x00000000}},  //   _ttab, _enpe_, ëjtë_,
  { {0x6e2d0020, 0x27ef0030, 0xdb1601aa, 0x00000000}},  // [190] _utab, vogn_, nkyè,
  { {0x2a6901f0, 0x00000000, 0x00000000, 0x00000000}},  //   rtab_,   ,   ,
  { {0x2a690004, 0x22510036, 0x917b0082, 0x00000000}},  //   stab_, ązki_, _hệ_,
  { {0x2a6900de, 0x25ac00f6, 0x00000000, 0x00000000}},  //   ptab_, _aodl_,   ,
  { {0xcb36019b, 0x7987002b, 0x1fc10044, 0x00000000}},  //   _ראשי_, _tajw, _উদাস,
  { {0x63ab01f1, 0x659401f2, 0x00000000, 0x00000000}},  //   _sogn, качу,   ,
  { {0x63ab01ed, 0xd914007e, 0x672901f3, 0x00000000}},  //   _pogn, _адры, _tfej,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x645c0039, 0x63ab0030, 0xd24e006d, 0x00000000}},  //   _årin, _vogn, مني_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63ab01f4, 0x67240161, 0x00000000, 0x00000000}},  //   _togn, žije,   ,
  { {0xd9cc01f5, 0x8fa600e2, 0x00000000, 0x00000000}},  //   _ाष्ट, хаме,   ,
  { {0xf1a80014, 0x00000000, 0x00000000, 0x00000000}},  //   سایه_,   ,   ,
  { {0x92c101f6, 0xdd9201f7, 0x7bdf00f6, 0x00000000}},  //   ığın, دوس_, enqu,
  { {0xfce30088, 0xddcd001a, 0x61e60010, 0x00000000}},  //   горо, _spaţ, ékle,
  { {0x24850026, 0x7a160173, 0x00000000, 0x00000000}},  //   _mslm_, _pņto,   ,
  { {0xc33201f8, 0xf412007b, 0x395600ed, 0x00000000}},  // [1a0] טון_, רפן_, ењет,
  { {0xac8601f9, 0x4c860088, 0xdcfe0035, 0x00000000}},  //   _згол, _злов, _capă,
  { {0xa81a01fa, 0xc172009b, 0xbb4600d7, 0x00000000}},  //   ستار_, רחב_, _пенк,
  { {0xfaa601fb, 0xe66601fc, 0x26c601fd, 0x00000000}},  //   _замо, етко, tzoo_,
  { {0x98ac005f, 0x24850022, 0xcb15007e, 0x00000000}},  //   ğlıq_, _aslm_, _афры,
  { {0xe5a301fe, 0x98ac005f, 0xa4d401ff, 0x00000000}},  //   личи, şlıq_, колі,
  { {0x6c7a0049, 0x00000000, 0x00000000, 0x00000000}},  //   לאַפ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66e301ab, 0x00000000, 0x00000000, 0x00000000}},  //   _бота,   ,   ,
  { {0xb5ca00a1, 0x64a60200, 0xbbad0201, 0x00000000}},  //   _عوام_, _паза, _टक्क,
  { {0xdb12000c, 0x6f040202, 0x3f8900f6, 0x00000000}},  //   _ágæt, _azic, _paau_,
  { {0x644a0203, 0x09dd0204, 0x00000000, 0x00000000}},  //   msfi, _मद्य,   ,
  { {0x661a0205, 0x644a00f8, 0x443e0146, 0x00000000}},  //   _kitk, lsfi, _hwt_,
  { {0x9f4b01dc, 0x661a0206, 0x2fc00146, 0x00000000}},  //   mocí_, _jitk, _elig_,
  { {0x661a00b0, 0x2fc00146, 0x00000000, 0x00000000}},  //   _mitk, _flig_,   ,
  { {0x7bdf0207, 0xd1380006, 0x317e0208, 0x00000000}},  //   unqu, lbą_, letz_,
  { {0x66d30047, 0x9f4b008e, 0x443e0022, 0x00000000}},  // [1b0] _műkö, nocí_, _lwt_,
  { {0x661a0209, 0xd8e70088, 0x317e010f, 0x00000000}},  //   _nitk, нцеп, netz_,
  { {0x2009020a, 0x6d470004, 0x443e020b, 0x00000000}},  //   _khai_, maja, _nwt_,
  { {0x6d47020c, 0x7bc4001a, 0x644a00eb, 0x00000000}},  //   laja, chiu, dsfi,
  { {0x661a020d, 0x6b9d010f, 0x46a40088, 0x00000000}},  //   _bitk, _insg, лаїв,
  { {0xb9070055, 0x443e020e, 0xab5b01a2, 0x00000000}},  //   _পর_, _bwt_, _flüc,
  { {0x69d7020f, 0xab5b010f, 0x644a0210, 0x00000000}},  //   mixe, _glüc, gsfi,
  { {0x6d470059, 0x443e01d6, 0xe65d014a, 0x00000000}},  //   haja, _dwt_, ştığ,
  { {0xdb0f00d4, 0x64580052, 0x74120014, 0x00000000}},  //   _alcú, arvi, جويا,
  { {0x6d470211, 0x27fd0016, 0x443e0022, 0x00000000}},  //   jaja, llwn_, _fwt_,
  { {0x6d4701d9, 0xf99200b3, 0x76590016, 0x00000000}},  //   daja, ברי_, lrwy,
  { {0x20090212, 0x69c500e0, 0x6b8d00bb, 0x00000000}},  //   _chai_, hhhe, jdag,
  { {0x63a90182, 0x93b600b6, 0x6b8d01bf, 0x00000000}},  //   mjen, _שלנו_, ddag,
  { {0x63a90213, 0x6d470214, 0x63bb0215, 0x00000000}},  //   ljen, gaja, lkun,
  { {0x22510036, 0x6da30216, 0x63a90217, 0x00000000}},  //   ązku_, шира, ojen,
  { {0x63a90213, 0x63bb0218, 0x6b8d006a, 0x00000000}},  //   njen, nkun, gdag,
  { {0x6d470219, 0x4b2301fb, 0x6f040107, 0x00000000}},  // [1c0] baja, рмув, _uzic,
  { {0x63a901c2, 0x6d470091, 0x76590016, 0x00000000}},  //   hjen, caja, drwy,
  { {0x661a0010, 0x63a9021a, 0x6e24021b, 0x00000000}},  //   _ritk, kjen, _huib,
  { {0x63bb021c, 0x6e240020, 0x2a790022, 0x00000000}},  //   jkun, _kuib, _fpsb_,
  { {0x63a9021d, 0x661a021e, 0x7659018e, 0x00000000}},  //   djen, _pitk, grwy,
  { {0x986600a1, 0xd49a0088, 0x69c5010f, 0x00000000}},  //   _لیئے_, дри_, chhe,
  { {0x63bb021f, 0x18a3005c, 0x6e240051, 0x00000000}},  //   fkun, _карм, _luib,
  { {0x63a90220, 0x61e10221, 0x63bb0222, 0x00000000}},  //   gjen, enll, gkun,
  { {0xfbd300b6, 0x2009018e, 0x661a0223, 0x00000000}},  //   יתה_, _rhai_, _titk,
  { {0xa3f50224, 0x661a00c7, 0x20090225, 0x00000000}},  //   ější_, _uitk, _shai_,
  { {0x6d4701d9, 0x63a90226, 0xd138010a, 0x00000000}},  //   vaja, bjen, rbą_,
  { {0x63bb010f, 0x317e010f, 0x6d4700f0, 0x00000000}},  //   ckun, setz_, waja,
  { {0x6d470004, 0x6e240227, 0xa1580228, 0x00000000}},  //   taja, _cuib, _залу_,
  { {0x6e240048, 0xbf9b01c3, 0x00000000, 0x00000000}},  //   _duib, dlêe,   ,
  { {0x6d470127, 0x80a300d3, 0x6b8d00c7, 0x00000000}},  //   raja, _نمون, tdag,
  { {0x5f770084, 0x6d47003c, 0x20090020, 0x00000000}},  //   _شاعر, saja, _uhai_,
  { {0x6d470229, 0xf96b022a, 0xfaff0023, 0x00000000}},  // [1d0] paja, дрей_, _ecën_,
  { {0x63bb022b, 0x6b8d0039, 0x68fc022c, 0x00000000}},  //   zkun, sdag, _byrd,
  { {0x3eb9022d, 0x6b8d0056, 0xf795007e, 0x00000000}},  //   lyst_, pdag, лажэ,
  { {0x7659018e, 0x69c50023, 0x00000000, 0x00000000}},  //   trwy, shhe,   ,
  { {0x63a9022e, 0x6d45022f, 0x69d70011, 0x00000000}},  //   vjen, _keha, pixe,
  { {0xa9340230, 0xa509017f, 0xe6180088, 0x00000000}},  //   _верш, нела_, вді_,
  { {0x7afd0016, 0x63a90231, 0x63bb000c, 0x00000000}},  //   _hyst, tjen, tkun,
  { {0x7afd01e3, 0x93bc001a, 0x6d450232, 0x00000000}},  //   _kyst, _stăr, _leha,
  { {0x63a90233, 0x63bb001f, 0x59b70067, 0x00000000}},  //   rjen, rkun, _आकार,
  { {0x63bb0234, 0x6d450235, 0x004700a1, 0x00000000}},  //   skun, _neha, نیتي_,
  { {0x0467012b, 0x63a90236, 0x7afd0030, 0x00000000}},  //   _штам, pjen, _lyst,
  { {0xdb0f0181, 0x4425001a, 0xc43a00b3, 0x00000000}},  //   _você, _iul_, _נתני,
  { {0x44250237, 0x6d450238, 0x7afd0239, 0x00000000}},  //   _hul_, _beha, _nyst,
  { {0x44250039, 0x614500ed, 0x4ed50088, 0x00000000}},  //   _kul_, _сека, рюют,
  { {0x44250018, 0x224d023a, 0x30790049, 0x00000000}},  //   _jul_, lsek_, _טאַנ,
  { {0x44250004, 0x7afd0027, 0x7dd4005f, 0x00000000}},  //   _mul_, _byst, _müsə,
  { {0x7afd0016, 0x4425023b, 0xa95a023c, 0x00000000}},  // [1e0] _cyst, _lul_, فجار_,
  { {0x6d45023d, 0x7afd010b, 0x3f82023e, 0x00000000}},  //   _geha, _dyst, leku_,
  { {0x31ba0049, 0x4425023f, 0xdb060161, 0x00000000}},  //   עזענ, _nul_, _doká,
  { {0x6d45022b, 0x224d011f, 0x3f82006c, 0x00000000}},  //   _zeha, ksek_, neku_,
  { {0x7f3b007b, 0x7afd0016, 0x68fc0016, 0x00000000}},  //   גענו, _gyst, _wyrd,
  { {0x4425011f, 0xd5b10011, 0x38610240, 0x00000000}},  //   _bul_, _có_, buhr_,
  { {0x442500f4, 0xd467003b, 0x88840241, 0x00000000}},  //   _cul_, гије_, _خیان,
  { {0x4425002a, 0x53980242, 0x3f820243, 0x00000000}},  //   _dul_, твия_, jeku_,
  { {0x6441002b, 0xbebb0065, 0x798e0244, 0x00000000}},  //   _ewli, ncët, _kabw,
  { {0x44250087, 0x6021001e, 0xc05a0245, 0x00000000}},  //   _ful_, _lēmu, нім_,
  { {0x44250193, 0x798e0246, 0x09f7009b, 0x00000000}},  //   _gul_, _mabw, רמים_,
  { {0x6d450149, 0x7c2501a2, 0x98b80006, 0x00000000}},  //   _seha, _ruhr, _gerą_,
  { {0x442500b5, 0x6d450247, 0x00000000, 0x00000000}},  //   _zul_, _peha,   ,
  { {0xbb1b00f4, 0x7afd0030, 0x798e0248, 0x00000000}},  //   _maît, _ryst, _nabw,
  { {0x48bf0044, 0x3f820032, 0x44250249, 0x00000000}},  //   _আশ্র, beku_, _xul_,
  { {0xc4c4024a, 0x7afd021e, 0x246e006b, 0x00000000}},  //   _ہے_, _pyst, _cəmi_,
  { {0x6d45006c, 0x2d85009d, 0x79d50088, 0x00000000}},  // [1f0] _teha, ôles_, ажає,
  { {0x7afd024b, 0xdcf50089, 0x00000000, 0x00000000}},  //   _vyst, udzē,   ,
  { {0x7afd0046, 0x2d830061, 0xd7c80014, 0x00000000}},  //   _wyst, meje_, گونه_,
  { {0x2d830030, 0x31e1024c, 0x7afd024d, 0x00000000}},  //   leje_, _पद्ध, _tyst,
  { {0x4425024e, 0x98aa0089, 0x64410009, 0x00000000}},  //   _sul_, ējām_, _swli,
  { {0x4425006b, 0x2d83024f, 0xf4830167, 0x00000000}},  //   _pul_, neje_, ماعی,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44250250, 0xdb1d000c, 0xddc40251, 0x00000000}},  //   _vul_, _umsó, _spiż,
  { {0x290c0051, 0x798e0009, 0xa235007e, 0x00000000}},  //   _údar_, _yabw, шэйш,
  { {0x2d830252, 0x4425002b, 0x41b5005e, 0x00000000}},  //   jeje_, _tul_, рсит,
  { {0x2d8301ca, 0x66ca0010, 0x224d0232, 0x00000000}},  //   deje_, _töké, ssek_,
  { {0xe0d6005e, 0x52d9007c, 0x224d0022, 0x00000000}},  //   рвю_, _имею_, psek_,
  { {0x2d830253, 0x00000000, 0x00000000, 0x00000000}},  //   feje_,   ,   ,
  { {0x2d830254, 0x62990066, 0x3f820255, 0x00000000}},  //   geje_, _irwo, seku_,
  { {0xdd0e014a, 0x8c4600e2, 0x798e000a, 0x00000000}},  //   _dışa, ребе, _rabw,
  { {0xc05200b6, 0xb7b00044, 0x798e00e0, 0x00000000}},  //   _וזה_, _কষ্ট, _sabw,
  { {0x09c10044, 0xeab70256, 0x00000000, 0x00000000}},  // [200] োচনা, айт_,   ,
  { {0xfb8200a1, 0xc8960184, 0x00000000, 0x00000000}},  //   _ڈگری, ирењ,   ,
  { {0xc8ca0257, 0x00000000, 0x00000000, 0x00000000}},  //   خوان_,   ,   ,
  { {0x628b0016, 0x6e9301b2, 0x798e0258, 0x00000000}},  //   _osgo, _الیا, _wabw,
  { {0xb8fd0183, 0x6b84000c, 0xe5340259, 0x00000000}},  //   _ते_, meig, бель,
  { {0x6b84000c, 0xb866025a, 0x00000000, 0x00000000}},  //   leig, _پاسو,   ,
  { {0x92e20055, 0x26c0025b, 0x628b00f6, 0x00000000}},  //   _ধরে_, šio_, _asgo,
  { {0x6b84025c, 0x0fc10044, 0x290a025d, 0x00000000}},  //   neig, _উদ্ধ, _izba_,
  { {0x27e6025e, 0xc1a6025f, 0xe61a017f, 0x00000000}},  //   mnon_, ајни, _ада_,
  { {0x6b840260, 0xda16006e, 0x00000000, 0x00000000}},  //   heig, थगित_,   ,
  { {0x628b0261, 0x2d830262, 0xc95300b3, 0x00000000}},  //   _esgo, veje_, חמת_,
  { {0x27e6021e, 0x78a1000c, 0x248c0022, 0x00000000}},  //   nnon_, _álve, _isdm_,
  { {0x2d830263, 0x91e60264, 0x5f940265, 0x00000000}},  //   teje_, _коде, цият,
  { {0x7bc6021e, 0xa3d2006e, 0x20020266, 0x00000000}},  //   _alku, होर_, alki_,
  { {0xf2e80044, 0x70540070, 0x2d910267, 0x00000000}},  //   _পরিণ, _انبا, rdze_,
  { {0x628b018e, 0xe457007b, 0x2ba400ed, 0x00000000}},  //   _ysgo, יילט_, ојув,
  { {0x29050268, 0xac180269, 0x290a000a, 0x00000000}},  // [210] _šla_, роту_, _azba_,
  { {0x2d830023, 0x780f006e, 0x00000000, 0x00000000}},  //   qeje_, िष्क_,   ,
  { {0x63a20116, 0x6b840089, 0x6d57006b, 0x00000000}},  //   _onon, beig, _idxa,
  { {0x27e600f4, 0x20140129, 0xdc9a0049, 0x00000000}},  //   gnon_, _èxit_, _עירל,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63a2026a, 0x7c940123, 0xdcfe00b9, 0x00000000}},  //   _anon, _اشیا, _napě,
  { {0x97a7026b, 0x05740014, 0x798500e0, 0x00000000}},  //   _крал, تاند, mehw,
  { {0xab5b006c, 0xc2450088, 0xdcfc0089, 0x00000000}},  //   _olüm, бник, nerā,
  { {0xe730026c, 0xdd2c0006, 0xe1f900d7, 0x00000000}},  //   _آصف_, vėži, лги_,
  { {0x6b84001f, 0x63a20052, 0xbec4007f, 0x00000000}},  //   zeig, _enon, šūki,
  { {0xf07600a1, 0x69c7016e, 0xab5b026d, 0x00000000}},  //   میوں_, _mlje, _alüm,
  { {0x7dc20027, 0x6299026e, 0x00000000, 0x00000000}},  //   _pôso, _trwo,   ,
  { {0x69c7026f, 0x6fc60051, 0x6b8401e5, 0x00000000}},  //   _olje, _cóca, veig,
  { {0x6b840270, 0xb6da0049, 0xa069003b, 0x00000000}},  //   weig, אַלט, _бака_,
  { {0x6b84010f, 0x27e60271, 0x7d0900b9, 0x00000000}},  //   teig, ynon_, řesn,
  { {0x69c70272, 0x6fc60048, 0x00000000, 0x00000000}},  //   _alje, _fóca,   ,
  { {0x6b840273, 0x7f3b0049, 0x69c70166, 0x00000000}},  // [220] reig, _געפו, _blje,
  { {0x6b8400f4, 0x5d860025, 0xdb0f0051, 0x00000000}},  //   seig, _الدل, _alcó,
  { {0x6d4e006a, 0x3f920169, 0x291c0274, 0x00000000}},  //   maba, _kayu_, äva_,
  { {0x6d4e006a, 0x7ae90087, 0xd62a0140, 0x00000000}},  //   laba, _žete, годе_,
  { {0x27e60275, 0xdd070276, 0x7e6600e0, 0x00000000}},  //   rnon_, _köşk, nukp,
  { {0x6d4e006a, 0x225f0277, 0x27e60278, 0x00000000}},  //   naba, druk_, snon_,
  { {0xef1f0279, 0x69de027a, 0x00000000, 0x00000000}},  //   ndür_, mipe,   ,
  { {0x69de027b, 0x6d4e027c, 0xa857009b, 0x00000000}},  //   lipe, haba, _לילה_,
  { {0x6d4e006a, 0x7dcb027d, 0xaade0061, 0x00000000}},  //   kaba, _hüse, _नेमक,
  { {0x8c000055, 0x6d4e027e, 0x69de0020, 0x00000000}},  //   ্দিন_, jaba, nipe,
  { {0x3f92008a, 0x6fc600c4, 0x63a20058, 0x00000000}},  //   _bayu_, _sóca, _tnon,
  { {0x69de001a, 0x225f01c9, 0x63a2027f, 0x00000000}},  //   hipe, bruk_, _unon,
  { {0x06bc0044, 0x394a0280, 0x3f920281, 0x00000000}},  //   _আইডি, _oebs_, _dayu_,
  { {0x30a60088, 0x3fc900a2, 0xea010011, 0x00000000}},  //   _грив, ادگی_, _đắp_,
  { {0x69de0282, 0x2a60006c, 0x61fa00f6, 0x00000000}},  //   dipe, erib_, motl,
  { {0x69c70182, 0x22460283, 0x61fa0284, 0x00000000}},  //   _slje, _kwok_, lotl,
  { {0x6d4e006a, 0x59d9007e, 0x69c70091, 0x00000000}},  // [230] baba, адаў_, _plje,
  { {0x6d4e0285, 0x7f4f0197, 0x24890036, 0x00000000}},  //   caba, lacq, łami_,
  { {0x2fc90286, 0x6d410276, 0x61e80287, 0x00000000}},  //   _klag_, ılad, indl,
  { {0x61fa0270, 0x7f4f0026, 0x2d930288, 0x00000000}},  //   hotl, nacq, _haxe_,
  { {0x7bdf0289, 0x00000000, 0x00000000, 0x00000000}},  //   miqu,   ,   ,
  { {0x7bdf00f4, 0x69de028a, 0x69c7028b, 0x00000000}},  //   liqu, cipe, _ulje,
  { {0xddcc010a, 0x9965013e, 0x22460085, 0x00000000}},  //   _žiūr, _kůži_, _awok_,
  { {0x7bdf028c, 0x6d4e028d, 0x7bcd010f, 0x00000000}},  //   niqu, zaba, nhau,
  { {0x6d4e028e, 0x27ff01d5, 0x7dcb006b, 0x00000000}},  //   yaba, _ikun_, _müsb,
  { {0x7bdf00f4, 0x6d4e028f, 0x225f01c3, 0x00000000}},  //   hiqu, xaba, rruk_,
  { {0x2fc9002a, 0x6d4e0290, 0x3a3900f6, 0x00000000}},  //   _blag_, vaba, _ltsp_,
  { {0x27ff01d5, 0x6d4e0291, 0x69de002d, 0x00000000}},  //   _jkun_, waba, zipe,
  { {0x6d4e0292, 0x7bdf028c, 0xf8a60061, 0x00000000}},  //   taba, diqu, _गप्प,
  { {0x2b4b00f6, 0x112b0088, 0x00000000, 0x00000000}},  //   _aecc_, _сюди_,   ,
  { {0x7bdf0068, 0xcfaa025a, 0x2fc900ab, 0x00000000}},  //   fiqu, _ناظم_, _flag_,
  { {0x7bdf0293, 0x6d4e0294, 0x27ed0295, 0x00000000}},  //   giqu, saba, _njen_,
  { {0xe9da012b, 0x6d4e011c, 0x2d930296, 0x00000000}},  // [240] ака_, paba, _faxe_,
  { {0x27ff0297, 0x2a600066, 0xdcf501df, 0x00000000}},  //   _akun_, rrib_, _çağr,
  { {0x32050298, 0x7bdf0299, 0x881a007e, 0x00000000}},  //   illy_, biqu, аўду_,
  { {0x394a029a, 0xeb9a029b, 0x7bcd029c, 0x00000000}},  //   _webs_, _тим_, chau,
  { {0xacf60014, 0x00000000, 0x00000000, 0x00000000}},  //   _دسکت,   ,   ,
  { {0x69de008d, 0xfc4b00b9, 0xfe9b00a3, 0x00000000}},  //   qipe, říž_, יינמ,
  { {0x69dc0051, 0x602800b9, 0xa7860025, 0x00000000}},  //   _imre, _těmi, _وشرو,
  { {0x78a1029d, 0xa3ba0025, 0x27ed0065, 0x00000000}},  //   _álva, شاعر_, _gjen_,
  { {0x69dc0022, 0x6f040022, 0x61fa029e, 0x00000000}},  //   _kmre, _nyic, totl,
  { {0x61e8010f, 0x7bcd029f, 0x2000004a, 0x00000000}},  //   undl, zhau, _akii_,
  { {0xdb0f02a0, 0x6f0d0036, 0x399b0049, 0x00000000}},  //   _rocí, _szac, בייד,
  { {0x9325007a, 0x32050038, 0x7bdf00f4, 0x00000000}},  //   _فرهن, ally_, xiqu,
  { {0x6b96018e, 0x69dc02a1, 0x2fc90116, 0x00000000}},  //   ddyg, _omre, _vlag_,
  { {0x72e90049, 0x442c00ca, 0x7f4f0026, 0x00000000}},  //   _פֿײַ, _kud_, sacq,
  { {0x7bdf02a2, 0x442c001a, 0x7bcd010f, 0x00000000}},  //   tiqu, _jud_, thau,
  { {0x5a350072, 0x69dc0016, 0x7bcd02a3, 0x00000000}},  //   знат, _amre, uhau,
  { {0x7bdf028c, 0x7bcd010f, 0x2d9302a4, 0x00000000}},  // [250] riqu, rhau, _taxe_,
  { {0x7bdf0293, 0x7bcd02a5, 0x442c01b5, 0x00000000}},  //   siqu, shau, _oud_,
  { {0x7bdf00f4, 0x442c02a6, 0x48ab02a7, 0x00000000}},  //   piqu, _nud_, штам_,
  { {0x201901aa, 0x6e2d00e7, 0x69dc0095, 0x00000000}},  //   nmsi_, _kuab, _emre,
  { {0xd6db02a8, 0x27ed008d, 0xf77000f9, 0x00000000}},  //   јте_, _vjen_, ضان_,
  { {0x442c02a9, 0x6e2d0011, 0xdcf50089, 0x00000000}},  //   _bud_, _muab, jdzī,
  { {0x27ff01d5, 0xddcd02aa, 0xc44700a1, 0x00000000}},  //   _tkun_, _opaž, زیشن_,
  { {0x442c0066, 0x69c502ab, 0x00000000, 0x00000000}},  //   _dud_, lkhe,   ,
  { {0x644802ac, 0x442c0146, 0xa2ab0061, 0x00000000}},  //   _ewdi, _eud_, जमध्,
  { {0x442c002a, 0x69c5010f, 0x00000000, 0x00000000}},  //   _fud_, nkhe,   ,
  { {0x442c0239, 0x7bc40006, 0x00000000, 0x00000000}},  //   _gud_, ykiu,   ,
  { {0x60330035, 0x76490258, 0x00000000, 0x00000000}},  //   _căma, _kwey,   ,
  { {0x6e2d02ad, 0x00000000, 0x00000000, 0x00000000}},  //   _cuab,   ,   ,
  { {0x79950046, 0x69c502ae, 0x6e2d0022, 0x00000000}},  //   _nazw, jkhe, _duab,
  { {0x61e102af, 0xdca302b0, 0xc18300a1, 0x00000000}},  //   mill, нари, _فیکٹ,
  { {0x61e102b1, 0x67290093, 0x69dc02b2, 0x00000000}},  //   lill, _ngej, _smre,
  { {0x3c19008b, 0x27fd00ab, 0x6e2d00fa, 0x00000000}},  // [260] іўся_, down_, _guab,
  { {0x6d410279, 0x63b901f3, 0x3ea00093, 0x00000000}},  //   ılac, _lown, _irit_,
  { {0x799501a2, 0x778602b3, 0x00000000, 0x00000000}},  //   _dazw, злез,   ,
  { {0x442c002a, 0x2d980030, 0x5faf0061, 0x00000000}},  //   _rud_, ldre_, टायल,
  { {0x61e102b4, 0xc6150055, 0x3f8002b5, 0x00000000}},  //   kill, াদনা_, _mbiu_,
  { {0x2d9802b6, 0x61e102b7, 0x8e570097, 0x00000000}},  //   ndre_, jill, לינג_,
  { {0x62820168, 0x61e10211, 0xf74602b8, 0x00000000}},  //   _spoo, dill, _нево,
  { {0x7dcb02b9, 0x9f5900f4, 0x3ea0000a, 0x00000000}},  //   _müsa, posé_, _orit_,
  { {0x63b90038, 0x61e102ba, 0x6033001a, 0x00000000}},  //   _down, fill, _răma,
  { {0x442c02bb, 0x61e10197, 0xdcf50089, 0x00000000}},  //   _tud_, gill, udzī,
  { {0xdcf5001e, 0x442c023a, 0x03260131, 0x00000000}},  //   rdzī, _uud_, _еден,
  { {0x3ea00010, 0x61e102bc, 0x00000000, 0x00000000}},  //   _brit_, aill,   ,
  { {0x61e102bd, 0x71a602be, 0x3ea000d4, 0x00000000}},  //   bill, _надз, _crit_,
  { {0x61e1027b, 0x57b90204, 0x442602bf, 0x00000000}},  //   cill, _आव्ह, _hio_,
  { {0x48dc0061, 0x7c2602c0, 0x442602c1, 0x00000000}},  //   _गेलो_, _bikr, _kio_,
  { {0xcf270054, 0x2d980207, 0x3ea00030, 0x00000000}},  //   _عربي, adre_, _frit_,
  { {0x44260198, 0x2d8a01aa, 0x3ea002c2, 0x00000000}},  // [270] _mio_, bebe_, _grit_,
  { {0x2d8a0181, 0x3f8b02c3, 0x442602c4, 0x00000000}},  //   cebe_, lecu_, _lio_,
  { {0x7c2602c5, 0x69c50145, 0x27fd00ab, 0x00000000}},  //   _fikr, rkhe, town_,
  { {0x61e10051, 0x442602c6, 0xc794007e, 0x00000000}},  //   zill, _nio_, ершы,
  { {0x63b9010b, 0x61e102c7, 0xcb9a009b, 0x00000000}},  //   _rown, yill, _וסרט,
  { {0xd1260025, 0x61e10275, 0x442602c8, 0x00000000}},  //   _لم_, xill, _aio_,
  { {0x61e1008d, 0xdb0601aa, 0x6fc60051, 0x00000000}},  //   vill, _ankè, _sócm,
  { {0x442602c9, 0x291100ca, 0x61e102ca, 0x00000000}},  //   _cio_, _izza_, will,
  { {0x442602cb, 0x61e102cc, 0x3f8b0107, 0x00000000}},  //   _dio_, till, decu_,
  { {0x61e100f4, 0x3ea00065, 0x629b0006, 0x00000000}},  //   uill, _rrit_, rvuo,
  { {0x61e1021e, 0x7dd0021e, 0x44260181, 0x00000000}},  //   rill, _jäse, _fio_,
  { {0x61e1021e, 0x442602cd, 0xdee601fb, 0x00000000}},  //   sill, _gio_, доми,
  { {0x61e10030, 0x7dd00039, 0x2d8a02ce, 0x00000000}},  //   pill, _läse, tebe_,
  { {0x7c2602cc, 0x442602cf, 0x3e760030, 0x00000000}},  //   _sikr, _zio_, ræt_,
  { {0x2d9802d0, 0x3b9601f9, 0x2d8a02d1, 0x00000000}},  //   rdre_, мјат, rebe_,
  { {0x6ff60054, 0xea010011, 0x2d8a014a, 0x00000000}},  //   _تستط, _đạp_, sebe_,
  { {0x7c2601aa, 0x3b070265, 0x2bdf01f5, 0x00000000}},  // [280] _vikr, дето_, _नगरा,
  { {0xc9860025, 0x6028013e, 0x00000000, 0x00000000}},  //   بشري, _těmt,   ,
  { {0x8cb502d2, 0x7c26010a, 0x19b902d3, 0x00000000}},  //   _उपयो, _tikr, чуть_,
  { {0xb0b60049, 0xf0b60049, 0x7c3e02d4, 0x00000000}},  //   ופעס_, ולער_, _itpr,
  { {0x442602d5, 0xdb0f004a, 0x12e80044, 0x00000000}},  //   _rio_, _tocá, _পর্দ,
  { {0x4426000b, 0x3f8b016c, 0x645e00fa, 0x00000000}},  //   _sio_, zecu_, ápio,
  { {0xd4970147, 0x69ce02d6, 0x442602d7, 0x00000000}},  //   дры_, _ilbe, _pio_,
  { {0x29180036, 0xc178007f, 0x00000000, 0x00000000}},  //   ągać_, ynės_,   ,
  { {0x8cb5013d, 0x44260211, 0xd166005e, 0x00000000}},  //   _उपभो, _vio_, мъни,
  { {0xe29f000c, 0x7c3e0091, 0x00000000, 0x00000000}},  //   æða_, _otpr,   ,
  { {0x44260039, 0xf993009b, 0xd36f00e2, 0x00000000}},  //   _tio_, דרת_, _ич_,
  { {0x443e0047, 0x72c60072, 0xdb0d000c, 0x00000000}},  //   _itt_, _обез, kkað,
  { {0x441b007b, 0x645802d8, 0xff0402d9, 0x00000000}},  //   _וואס, lsvi, вярн,
  { {0x7ae90209, 0x443e02da, 0x3f8b02db, 0x00000000}},  //   _žeto, _ktt_, secu_,
  { {0x6458004e, 0xc1780006, 0xac190088, 0x00000000}},  //   nsvi, snės_, зову_,
  { {0x5bc90204, 0x443e0052, 0x5f9502dc, 0x00000000}},  //   रसेव, _mtt_, _чиит,
  { {0x6feb0046, 0x9f420065, 0xda7802dd, 0x00000000}},  // [290] jęci, zikë_, дях_,
  { {0x443e0047, 0x627700b3, 0xc5f30044, 0x00000000}},  //   _ott_, וגמא_, _চীনা_,
  { {0x6d5502de, 0x443e02da, 0x6d4702df, 0x00000000}},  //   maza, _ntt_, mbja,
  { {0x6d5502e0, 0x64580056, 0x69ce014a, 0x00000000}},  //   laza, dsvi, _elbe,
  { {0x443e02e1, 0x6fc60051, 0xbb3a0104, 0x00000000}},  //   _att_, _dóch, _מערי,
  { {0x443e0129, 0x9f420065, 0x6d5502e2, 0x00000000}},  //   _btt_, tikë_, naza,
  { {0x26c90119, 0x645802e3, 0x443e00c4, 0x00000000}},  //   šao_, gsvi, _ctt_,
  { {0x6d55002b, 0x443e02e4, 0x9f420065, 0x00000000}},  //   haza, _dtt_, rikë_,
  { {0x443e02e1, 0x644e01d5, 0x601601ca, 0x00000000}},  //   _ett_, _ħbie, náme,
  { {0xf1b10054, 0x443e02e5, 0x6b8d0048, 0x00000000}},  //   اءة_, _ftt_, heag,
  { {0x443e0022, 0x672400b9, 0x6b8d02e6, 0x00000000}},  //   _gtt_, žijt, keag,
  { {0x649a00b6, 0x644302e7, 0x14d80061, 0x00000000}},  //   _מסעד, mpni, _भेटण,
  { {0xe1ee0265, 0x712400a1, 0x6d41005d, 0x00000000}},  //   _бг_, ٹریل, ılan,
  { {0x7bcf0198, 0x683301f3, 0x443e02e8, 0x00000000}},  //   _alcu, _aħdm, _ytt_,
  { {0xafe602e9, 0xb042001d, 0xbddb0173, 0x00000000}},  //   _покл, _trưở, nsèy,
  { {0x6b8d0146, 0x8b2602ea, 0x00000000, 0x00000000}},  //   geag, едбе,   ,
  { {0xada60265, 0x6d550161, 0x200202eb, 0x00000000}},  // [2a0] _запл, baza, moki_,
  { {0xdb0d009f, 0x6d5502ec, 0x20020032, 0x00000000}},  //   rkað, caza, loki_,
  { {0x7dcb014a, 0x6b8d002d, 0x7c3e02e1, 0x00000000}},  //   _müsl, beag, _utpr,
  { {0x48c30055, 0x2ca50030, 0x6016008e, 0x00000000}},  //   ্পূর, ælde_, lámb,
  { {0x2d9a011c, 0x69d10089, 0x645802ed, 0x00000000}},  //   _kape_, _ūdeņ, wsvi,
  { {0xab5b010f, 0x245a0089, 0x443e0095, 0x00000000}},  //   _flüs, tīm_, _ptt_,
  { {0xc7b000a1, 0x2002002d, 0x2d9a0027, 0x00000000}},  //   _پڑا_, koki_, _mape_,
  { {0x64580239, 0x443e00f4, 0x9f59008e, 0x00000000}},  //   rsvi, _vtt_, tosí_,
  { {0x6458000c, 0x443e02ee, 0x245a01c5, 0x00000000}},  //   ssvi, _wtt_, sīm_,
  { {0x27e602ef, 0x443e01c5, 0x2d9a01a3, 0x00000000}},  //   lion_, _ttt_, _nape_,
  { {0xc05702f0, 0x6d550010, 0x443e0089, 0x00000000}},  //   нія_, vaza, _utt_,
  { {0x27e602f1, 0x6b8d0032, 0x6d5502f2, 0x00000000}},  //   nion_, xeag, waza,
  { {0x6d550020, 0xf8ad0061, 0x2d9a02f3, 0x00000000}},  //   taza, _टप्प, _bape_,
  { {0xbbc902f4, 0x7d0302cc, 0x27e60016, 0x00000000}},  //   रस्क, _ønsk, hion_,
  { {0x6d5502f5, 0x5ff50265, 0x27e602f6, 0x00000000}},  //   raza, _изку, kion_,
  { {0x6d5a02f7, 0xfc300025, 0x6d5502f8, 0x00000000}},  //   ótar, صحف_, saza,
  { {0x27e6018e, 0x6b8d002a, 0x49750264, 0x00000000}},  // [2b0] dion_, reag, клас,
  { {0x601602f9, 0xab5b02fa, 0x6b8d010e, 0x00000000}},  //   ráme, _plüs, seag,
  { {0x4ddc009b, 0x6fc60181, 0x27e60016, 0x00000000}},  //   _מחזו, _sóci, fion_,
  { {0x27e602f1, 0x76590016, 0x2d9a016c, 0x00000000}},  //   gion_, tswy, _zape_,
  { {0xa3b402fb, 0x7e7d001e, 0x9f4b008e, 0x00000000}},  //   ञान_, ntsp, locó_,
  { {0x7e7d01a2, 0xeabf0082, 0x200202fc, 0x00000000}},  //   itsp, _ngùi_, zoki_,
  { {0x27e6018e, 0xd90f02fd, 0xa8020276, 0x00000000}},  //   bion_, _ایا_, ğıra,
  { {0x27e602fe, 0x644302ff, 0x25ac0300, 0x00000000}},  //   cion_, rpni, _endl_,
  { {0x7dd00039, 0x765b0045, 0x00000000, 0x00000000}},  //   _läsa, _uvuy,   ,
  { {0x64430301, 0x7e7d0302, 0x00000000, 0x00000000}},  //   ppni, dtsp,   ,
  { {0x66030051, 0x20020303, 0xf07600a1, 0x00000000}},  //   monk, toki_, نیوں_,
  { {0x6441000a, 0x7e7d0304, 0xb4bf01f5, 0x00000000}},  //   _itli, ftsp, ुनी_,
  { {0x20020305, 0x7e7d0306, 0x00000000, 0x00000000}},  //   roki_, gtsp,   ,
  { {0x27e60307, 0x212e00d9, 0xd656009b, 0x00000000}},  //   zion_, _ggfh_, כישת_,
  { {0x2d9a0066, 0x7e7d021f, 0x1d07005e, 0x00000000}},  //   _vape_, atsp, вери_,
  { {0x27e6028c, 0x66030308, 0x2d9a00e7, 0x00000000}},  //   xion_, honk, _wape_,
  { {0x27e60052, 0xf1b50309, 0x3ae80014, 0x00000000}},  // [2c0] vion_, _अचान, ربری_,
  { {0xdcfc0089, 0x249200b4, 0x64410087, 0x00000000}},  //   ndrī, łymi_, _otli,
  { {0x27e6030a, 0x66030052, 0xdb060036, 0x00000000}},  //   tion_, donk, _pokó,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27e6018e, 0x6441030b, 0xa3ab013d, 0x00000000}},  //   rion_, _atli, खाई_,
  { {0x27e6030a, 0xd943013b, 0xd64500a1, 0x00000000}},  //   sion_, _вери, ائنٹ,
  { {0x27e600b0, 0xe7f40061, 0x65610026, 0x00000000}},  //   pion_, ेकदा_, _ddlh,
  { {0x799c030c, 0xc27400ed, 0x329800e2, 0x00000000}},  //   _harw, глиј, евиќ_,
  { {0x877b0049, 0x762600e2, 0x3134030d, 0x00000000}},  //   _קאמי, _амаз, лепр,
  { {0xf1a6005e, 0x65610022, 0x799c0022, 0x00000000}},  //   трин, _gdlh, _jarw,
  { {0x799c0016, 0x2fc000d4, 0x32070253, 0x00000000}},  //   _marw, _boig_, _dkny_,
  { {0x7e7d030e, 0x9f4b008e, 0x6d41005a, 0x00000000}},  //   ttsp, vocó_, ılam,
  { {0xdbdc000c, 0x00000000, 0x00000000, 0x00000000}},  //   _ráðn,   ,   ,
  { {0x7e7d0089, 0xdd110161, 0x00000000, 0x00000000}},  //   rtsp, _výži,   ,
  { {0xf4140049, 0x61e8030f, 0x2fd20039, 0x00000000}},  //   ָפּ_, midl, _flyg_,
  { {0x3ec7008b, 0xef67005e, 0x2a6900c4, 0x00000000}},  //   _асоб, _ръко, trab_,
  { {0x5b1501e0, 0x799c0036, 0x00000000, 0x00000000}},  // [2d0] умат, _barw,   ,
  { {0x2a690310, 0x799c005b, 0x98c7005c, 0x00000000}},  //   rrab_, _carw, ксел,
  { {0x2d910311, 0x48c30044, 0xd24600a6, 0x00000000}},  //   meze_, ্প্র, _گن_,
  { {0x2d9101d1, 0x4cdc0044, 0x61e80312, 0x00000000}},  //   leze_, _মুকু, hidl,
  { {0xd24600a1, 0x66030313, 0x799c0016, 0x00000000}},  //   _دن_, tonk, _farw,
  { {0x2d910314, 0x09ad0044, 0x6f0d0019, 0x00000000}},  //   neze_, _গতকা, _myac,
  { {0x66030315, 0xb4bf0316, 0x6b9d00d9, 0x00000000}},  //   ronk, ुने_, _kasg,
  { {0x7bcd010f, 0x2d910317, 0x7d08010e, 0x00000000}},  //   nkau, heze_, üdsi,
  { {0x2fc00129, 0x66030059, 0x2d9100e7, 0x00000000}},  //   _roig_, ponk, keze_,
  { {0xe5730318, 0x2d9100e5, 0x61e80319, 0x00000000}},  //   _خطر_, jeze_, gidl,
  { {0x7bcd021e, 0x43750076, 0x2d91031a, 0x00000000}},  //   kkau, _مهار, deze_,
  { {0x5275031b, 0x6f0d0009, 0xeb9f0030, 0x00000000}},  //   _буку, _byac, _skøn_,
  { {0x6f0d0009, 0x61e8031c, 0xee37005e, 0x00000000}},  //   _cyac, bidl, лня_,
  { {0x409501f9, 0x63bb0313, 0x2d910061, 0x00000000}},  //   _брит, ljun, geze_,
  { {0x6c36031d, 0x32050010, 0x6f0d008e, 0x00000000}},  //   افرا, moly_, _eyac,
  { {0x63bb0149, 0x6b9d018e, 0xdb0f0181, 0x00000000}},  //   njun, _casg, _incê,
  { {0xc332019b, 0x6016008e, 0x6b9d005b, 0x00000000}},  // [2e0] מון_, cáma, _dasg,
  { {0x7bd60061, 0xfd4a0088, 0x6299000a, 0x00000000}},  //   shyu, _язок_, _mswo,
  { {0x63bb000c, 0x6b9d005b, 0x00000000, 0x00000000}},  //   kjun, _fasg,   ,
  { {0x6b9d0016, 0x3205031e, 0x61e8031f, 0x00000000}},  //   _gasg, holy_, zidl,
  { {0x63bb0320, 0x799c00bb, 0x00000000, 0x00000000}},  //   djun, _tarw,   ,
  { {0x6b840321, 0x6e36004a, 0x00000000, 0x00000000}},  //   lfig, _muyb,   ,
  { {0x61e8004f, 0x395a0056, 0x6aa40026, 0x00000000}},  //   vidl, maps_, lvif,
  { {0x6b840322, 0x2d910323, 0x395a006c, 0x00000000}},  //   nfig, zeze_, laps_,
  { {0xd1300054, 0x46a30147, 0xdb1d00f4, 0x00000000}},  //   يمة_, _латв, _posé,
  { {0x7a7b0049, 0xda7b0049, 0x00000000, 0x00000000}},  //   עריס, עניר,   ,
  { {0x63bb0066, 0xe475007e, 0x2d910091, 0x00000000}},  //   bjun, _вучэ, veze_,
  { {0x09c10204, 0x2d910020, 0x8f47007e, 0x00000000}},  //   _शक्य, weze_, ыход,
  { {0x61e80324, 0x2d91001a, 0x6b9d0325, 0x00000000}},  //   pidl, teze_, _rasg,
  { {0x7dcb0004, 0x23270326, 0x60160327, 0x00000000}},  //   _küsi, _сочи_, ráma,
  { {0x2d91001a, 0x62800190, 0x6b840197, 0x00000000}},  //   reze_, ltmo, ffig,
  { {0x2d91001a, 0x6b840010, 0x62800328, 0x00000000}},  //   seze_, gfig, otmo,
  { {0x99550001, 0x7bcd001f, 0x6b9d0007, 0x00000000}},  // [2f0] икац, rkau, _vasg,
  { {0x7bcd0329, 0x6b9d032a, 0x62800270, 0x00000000}},  //   skau, _wasg, itmo,
  { {0x6b9d032b, 0x63bb01e5, 0x00000000, 0x00000000}},  //   _tasg, yjun,   ,
  { {0x3ea90235, 0x6b9d0051, 0x6d57032c, 0x00000000}},  //   _krat_, _uasg, _hexa,
  { {0x6d570032, 0x395a00f6, 0x00000000, 0x00000000}},  //   _kexa, baps_,   ,
  { {0xb5fd00b9, 0x5e580049, 0x4ade007d, 0x00000000}},  //   _ovše, ריגע_, _नेटव,
  { {0x23d5003b, 0xdb060047, 0x6d57006b, 0x00000000}},  //   ицир, _inká, _mexa,
  { {0xea01001d, 0x6265032d, 0x6280032e, 0x00000000}},  //   _đẹp_, авиа, ftmo,
  { {0x63bb00b0, 0xd7f8007e, 0x3205032f, 0x00000000}},  //   rjun, _сур_, toly_,
  { {0xbbd201f5, 0x98a10180, 0x7c2f0249, 0x00000000}},  //   _सत्क, lahı_, _licr,
  { {0x7dd00039, 0xf992009b, 0x6ff20089, 0x00000000}},  //   _säso, חרי_, lāci,
  { {0x3ea90142, 0xf1d901f5, 0x543a0049, 0x00000000}},  //   _brat_, योजन, _סענא,
  { {0x32050142, 0x6ff20089, 0x62800330, 0x00000000}},  //   poly_, nāci, ctmo,
  { {0xc5f20049, 0x10a50331, 0x00000000, 0x00000000}},  //   ַדן_, _викн,   ,
  { {0x442f0030, 0xed57007c, 0x6b840232, 0x00000000}},  //   _kig_, рос_, tfig,
  { {0x6016027b, 0x6ff2001e, 0x2d9e01ca, 0x00000000}},  //   mámo, kāci, žte_,
  { {0x442f0332, 0x3ea90313, 0x6b840333, 0x00000000}},  // [300] _mig_, _grat_, rfig,
  { {0x442f0334, 0xe9d7025f, 0x6b840232, 0x00000000}},  //   _lig_, аку_, sfig,
  { {0xd9100167, 0x6fcd009d, 0x395a0335, 0x00000000}},  //   سیر_, _bûch, raps_,
  { {0x7afd01f3, 0x442f0336, 0x657a0009, 0x00000000}},  //   _fxst, _nig_, _scth,
  { {0x7c240337, 0xeb97005e, 0x2b400338, 0x00000000}},  //   mmir, _тия_, mcic_,
  { {0x6d5c0127, 0x7c24005f, 0x442f0061, 0x00000000}},  //   nara, lmir, _aig_,
  { {0x442f0339, 0x601d00f4, 0x6d5c033a, 0x00000000}},  //   _big_, léme, iara,
  { {0x6d5c033b, 0x938a033c, 0x442f0016, 0x00000000}},  //   hara, тска_, _cig_,
  { {0x442f033d, 0x6d5c033e, 0x05160044, 0x00000000}},  //   _dig_, kara, াশের_,
  { {0x6d5c0149, 0x442f0109, 0x91b800e2, 0x00000000}},  //   jara, _eig_, угот_,
  { {0x442f00ab, 0x3958001a, 0x6d57033f, 0x00000000}},  //   _fig_, _mers_, _rexa,
  { {0x442f0016, 0x3ea90129, 0x6d570190, 0x00000000}},  //   _gig_, _prat_, _sexa,
  { {0x6d5c0073, 0x7c2f0197, 0xdb1d0026, 0x00000000}},  //   fara, _ricr, _così,
  { {0x6d5c0149, 0x7c2f018e, 0x3ea90340, 0x00000000}},  //   gara, _sicr, _vrat_,
  { {0x6ff2001e, 0x61ef009d, 0x6d5700fa, 0x00000000}},  //   zāci, ècle, _vexa,
  { {0x44240341, 0x3ea90342, 0x6d5c012d, 0x00000000}},  //   nmm_, _trat_, aara,
  { {0x6d5c0127, 0x69d50224, 0x6d5700ab, 0x00000000}},  // [310] bara, _plze, _texa,
  { {0xe29f009f, 0xc178010a, 0x442400e0, 0x00000000}},  //   æði_, ngė_, hmm_,
  { {0x3958014a, 0x7c2f00f6, 0x00000000, 0x00000000}},  //   _ders_, _ticr,   ,
  { {0x39580343, 0x6ff20089, 0x224602db, 0x00000000}},  //   _eers_, tāci, _otok_,
  { {0x60160344, 0x442f0345, 0x4424012d, 0x00000000}},  //   zámo, _rig_, dmm_,
  { {0x442f0346, 0x6ff2001e, 0x3958009d, 0x00000000}},  //   _sig_, rāci, _gers_,
  { {0xe3b10054, 0x442f0133, 0x98aa0066, 0x00000000}},  //   كرة_, _pig_, _rebħ_,
  { {0x6d5c0347, 0xb7bd0035, 0x317c00d9, 0x00000000}},  //   zara, _piţu, _acvz_,
  { {0x442f0348, 0x36d40088, 0xdcfe0089, 0x00000000}},  //   _vig_, _дотр, _papī,
  { {0x7c24001e, 0x6d5c0349, 0x442f00b4, 0x00000000}},  //   zmir, xara, _wig_,
  { {0x6d5c0119, 0x442f034a, 0x8fa6034b, 0x00000000}},  //   vara, _tig_, бане,
  { {0xcdc900b6, 0x6d5c034c, 0xdb0f02d0, 0x00000000}},  //   _אך_, wara, _encé,
  { {0x6d5c034d, 0x539a034e, 0xdb24005d, 0x00000000}},  //   tara, _תינו, üsün,
  { {0x32b80025, 0x7dd000b0, 0x61390049, 0x00000000}},  //   _خدمة_, _täsm, _גײַס,
  { {0x6d5c034f, 0xc885006b, 0x7c240350, 0x00000000}},  //   rara, naşı_, tmir,
  { {0x6d5c020c, 0x2b5900d4, 0x9f82000c, 0x00000000}},  //   sara, _cesc_, _góð_,
  { {0x39580351, 0x2b590061, 0x2b40016c, 0x00000000}},  // [320] _pers_, _desc_, rcic_,
  { {0x2a600352, 0x601d0353, 0x7c240232, 0x00000000}},  //   rsib_, réme, smir,
  { {0x39580354, 0xfbd20355, 0x2a60002b, 0x00000000}},  //   _vers_, _فتح_, ssib_,
  { {0xc8850279, 0x9f4b0023, 0x3958005b, 0x00000000}},  //   daşı_, vicë_, _wers_,
  { {0xe5c60356, 0xe775006b, 0x3958014a, 0x00000000}},  //   йско, zıçı, _ters_,
  { {0x7e6400ca, 0x00000000, 0x00000000, 0x00000000}},  //   _mvip,   ,   ,
  { {0x2246033b, 0x7bc60357, 0xe9d70088, 0x00000000}},  //   _stok_, _koku, _укр_,
  { {0x7e6400ea, 0x644a0026, 0x7bc60358, 0x00000000}},  //   _ovip, rpfi, _joku,
  { {0x7ae90359, 0x60290036, 0x7dcb035a, 0x00000000}},  //   _þett, _uśmi, _küst,
  { {0x7bc6000c, 0x104a0077, 0x6d5a000c, 0x00000000}},  //   _loku, лями_, ðtal,
  { {0xe452035b, 0x7dcb035c, 0x7e640022, 0x00000000}},  //   _رضا_, _xüsu, _avip,
  { {0x7bc60145, 0x9426007c, 0x00000000, 0x00000000}},  //   _noku, _умее,   ,
  { {0xdb1d035d, 0x00000000, 0x00000000, 0x00000000}},  //   _posí,   ,   ,
  { {0x270700ad, 0x63a2035e, 0x2b5900c4, 0x00000000}},  //   ống_, _haon, _sesc_,
  { {0x7bc6035f, 0x7a290006, 0x7f5d0026, 0x00000000}},  //   _boku, _užti, pasq,
  { {0x1b020044, 0xdb1d00fa, 0x4a55007e, 0x00000000}},  //   লেছে_, _rosâ, жкас,
  { {0x7bc60292, 0x63a2000b, 0x200b01ca, 0x00000000}},  // [330] _doku, _maon, moci_,
  { {0x200b0207, 0x63a2017b, 0x00000000, 0x00000000}},  //   loci_, _laon,   ,
  { {0x394101a2, 0x7dcb0360, 0x00000000, 0x00000000}},  //   rchs_, _düst,   ,
  { {0x61c502f4, 0x63a20020, 0x7bc60288, 0x00000000}},  //   _लक्ष, _naon, _goku,
  { {0x25ed001c, 0x4ae4008b, 0x249e0035, 0x00000000}},  //   _अगदी_, _еўра, _astm_,
  { {0xdcfc0089, 0x3e5c0049, 0x96280025, 0x00000000}},  //   cerē, נדוס, مكنك_,
  { {0xdb0600f8, 0x63a20361, 0x7bc60362, 0x00000000}},  //   _enkä, _baon, _yoku,
  { {0xc2450081, 0x7dcb01a2, 0x00000000, 0x00000000}},  //   оник, _küss,   ,
  { {0x69c70363, 0x6448005f, 0x85b90364, 0x00000000}},  //   _koje, _etdi, _клас_,
  { {0x27ef0365, 0x7dcb001f, 0x7dd00039, 0x00000000}},  //   lign_, _müss, _väsk,
  { {0x69c70366, 0x7e64000c, 0xcea900b3, 0x00000000}},  //   _moje, _svip, _שי_,
  { {0x6d450367, 0x200b0129, 0xd00a003b, 0x00000000}},  //   _afha, goci_, реме_,
  { {0xa2940106, 0xd9fb0061, 0x24650089, 0x00000000}},  //   _наці, ्वात_, lēm_,
  { {0x7dd00368, 0x41290369, 0x224d008a, 0x00000000}},  //   _käsi, _коло_, mpek_,
  { {0x7bc6036a, 0x63a2036b, 0x7dcb036c, 0x00000000}},  //   _poku, _yaon, _rüst,
  { {0xb068036d, 0x7dcb006c, 0x200b036e, 0x00000000}},  //   _اصول_, _süst, coci_,
  { {0x69c700ee, 0x7dcb006c, 0x19c60088, 0x00000000}},  // [340] _boje, _püst, обам,
  { {0x3ea001aa, 0x7dcb010f, 0x69c702f9, 0x00000000}},  //   _isit_, _düss, _coje,
  { {0x2d980198, 0x69c701d9, 0x5faf0061, 0x00000000}},  //   mere_, _doje, _जोडल,
  { {0x2d98011f, 0x510c007b, 0x7dcb01a2, 0x00000000}},  //   lere_, נהאַ, _wüst,
  { {0xd5ba0057, 0x63a20129, 0x601d00f4, 0x00000000}},  //   иск_, _raon, néma,
  { {0x69c7036f, 0xe4520025, 0x63a20370, 0x00000000}},  //   _goje, وضع_, _saon,
  { {0x601d0371, 0x2caa0009, 0x63a20026, 0x00000000}},  //   héma, nvbd_, _paon,
  { {0x2d980372, 0x32660373, 0x9faf00b9, 0x00000000}},  //   here_, отов, tří_,
  { {0x2d980374, 0xdb1d0010, 0x200b0375, 0x00000000}},  //   kere_, _kosá, voci_,
  { {0x2d980030, 0x63a20020, 0x3f800006, 0x00000000}},  //   jere_, _waon, _aciu_,
  { {0x2d980376, 0x63a2006a, 0x24650089, 0x00000000}},  //   dere_, _taon, cēm_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x200b0059, 0x2d980377, 0x00000000, 0x00000000}},  //   roci_, fere_,   ,
  { {0x2d980378, 0xddcf001a, 0x61ea001a, 0x00000000}},  //   gere_, ducţ, _umfl,
  { {0xa17700b6, 0xfbd30379, 0x69c7037a, 0x00000000}},  //   _ועוד_, وتر_, _roje,
  { {0x69c700ca, 0xdb1d00f6, 0x6446012d, 0x00000000}},  //   _soje, _posà, _čkil,
  { {0x69c7037b, 0x24650089, 0x00000000, 0x00000000}},  // [350] _poje, zēm_,   ,
  { {0x2d98037c, 0x3f990059, 0xdb1d0048, 0x00000000}},  //   cere_, lesu_, _cosá,
  { {0x7649037d, 0xdb1d00b9, 0x69c70161, 0x00000000}},  //   _stey, _dosá, _voje,
  { {0x3f99037e, 0x69c70046, 0x4c9a00b3, 0x00000000}},  //   nesu_, _woje, _פברו,
  { {0x320c00b4, 0x00000000, 0x00000000, 0x00000000}},  //   kody_,   ,   ,
  { {0x2465001e, 0x69de037f, 0x85e80088, 0x00000000}},  //   tēm_, chpe, одів_,
  { {0xd5ae0380, 0x00000000, 0x00000000, 0x00000000}},  //   طفي_,   ,   ,
  { {0x3cfc00a3, 0x61fa0186, 0x7dd0006c, 0x00000000}},  //   ילונ, entl, _väsi,
  { {0x27ed0381, 0x37da0049, 0x2d980056, 0x00000000}},  //   _imen_, _פֿלע, yere_,
  { {0x320c0036, 0x2d980382, 0x6d480276, 0x00000000}},  //   gody_, xere_, ıdak,
  { {0x2d980383, 0x224d0384, 0x60160385, 0x00000000}},  //   vere_, spek_, lámi,
  { {0x2d980007, 0x2d810386, 0xd8d6009b, 0x00000000}},  //   were_, _ache_, פורט_,
  { {0x2d98001f, 0x60160387, 0x320c0388, 0x00000000}},  //   tere_, námi, body_,
  { {0x7bcb000c, 0x7dd000f8, 0xd1bb0389, 0x00000000}},  //   ögun, _läsv, _خاصا_,
  { {0x27ed002d, 0xdb1d00c4, 0x3f99038a, 0x00000000}},  //   _omen_, _rosá, besu_,
  { {0x2d98038b, 0x9e66025f, 0x7bdf0066, 0x00000000}},  //   sere_, _евид, ghqu,
  { {0x6d41038c, 0x2d98038d, 0xe9da0264, 0x00000000}},  // [360] ılar, pere_, бка_,
  { {0xdb04038e, 0x8af0006b, 0x27ff0022, 0x00000000}},  //   ndié, vbəd, _ajun_,
  { {0x6d5e001e, 0x6d3b009b, 0x6376019a, 0x00000000}},  //   _iepa, _לתינ, nünü,
  { {0xf1ba0011, 0x69de0023, 0x25a5005b, 0x00000000}},  //   _nhơn_, shpe, _aall_,
  { {0x6d5e020c, 0x25a5038f, 0x27ff0066, 0x00000000}},  //   _kepa, _ball_, _djun_,
  { {0x6d5e0390, 0x25a50038, 0x7c3e0391, 0x00000000}},  //   _jepa, _call_, _kupr,
  { {0x25a50198, 0x320c01ca, 0x7ae40035, 0x00000000}},  //   _dall_, vody_, lzit,
  { {0x6d5e0127, 0x320c0036, 0x25a5006c, 0x00000000}},  //   _lepa, wody_, _eall_,
  { {0x320c0392, 0x25a50393, 0xdb04009d, 0x00000000}},  //   tody_, _fall_, udiè,
  { {0x6d5e0394, 0x64a60057, 0x20030091, 0x00000000}},  //   _nepa, _наза, čkim_,
  { {0x931600a1, 0x320c0395, 0xef1f0396, 0x00000000}},  //   _کوشش, rody_, rfüm_,
  { {0x443e009d, 0x2ca10022, 0x27ed02d4, 0x00000000}},  //   _iut_, _rshd_, _xmen_,
  { {0x6d5e015c, 0x3f990161, 0x7c3e00f4, 0x00000000}},  //   _bepa, resu_, _aupr,
  { {0x6d5e020c, 0x443e0397, 0x3f990016, 0x00000000}},  //   _cepa, _kut_, sesu_,
  { {0x7c3e001a, 0x443e0010, 0x9f4b00b9, 0x00000000}},  //   _cupr, _jut_, licí_,
  { {0x443e00b0, 0x69dc0398, 0xd11701ce, 0x00000000}},  //   _mut_, _alre, _מקוה_,
  { {0x5a350113, 0x443e0036, 0x9f4b0399, 0x00000000}},  // [370] днат, _lut_, nicí_,
  { {0x443e0038, 0x6d5e0168, 0x2019039a, 0x00000000}},  //   _out_, _gepa, llsi_,
  { {0x443e02c2, 0x25a501c3, 0x7c670257, 0x00000000}},  //   _nut_, _rall_, _عادل,
  { {0x69dc0010, 0x80bd0061, 0x00000000, 0x00000000}},  //   _elre, षमते,   ,
  { {0xf7700137, 0x443e039b, 0x81bc0089, 0x00000000}},  //   طان_, _aut_, rmēj,
  { {0x443e0038, 0x6016039c, 0xf650039d, 0x00000000}},  //   _but_, rámi, ائن_,
  { {0x25a50129, 0x443e00ab, 0x64a2005e, 0x00000000}},  //   _vall_, _cut_, ваща,
  { {0x443e022b, 0x7dd0039e, 0x25a500ab, 0x00000000}},  //   _dut_, _häst, _wall_,
  { {0x443e009d, 0x25a5039f, 0x644902db, 0x00000000}},  //   _eut_, _tall_, _žlič,
  { {0x443e00f4, 0xdb0401a2, 0x8af0006b, 0x00000000}},  //   _fut_, heiß, lbəc,
  { {0x656303a0, 0x7bdd01f6, 0x443e03a1, 0x00000000}},  //   manh, _olsu, _gut_,
  { {0x6d5e020c, 0x5ec60055, 0x7dd003a2, 0x00000000}},  //   _sepa, _লেগে, _läst,
  { {0x6d5e008a, 0x8af0006b, 0x443e0068, 0x00000000}},  //   _pepa, naət, _zut_,
  { {0x7dd00073, 0x63a902cc, 0x656303a3, 0x00000000}},  //   _näst, lden, nanh,
  { {0x62890048, 0x6b8d03a4, 0x443e00d4, 0x00000000}},  //   lteo, ffag, _xut_,
  { {0x7ae4002d, 0x656303a5, 0x673b0023, 0x00000000}},  //   tzit, hanh, _nguj,
  { {0x7dd00073, 0x6d5e0169, 0x6289002a, 0x00000000}},  // [380] _bäst, _tepa, nteo,
  { {0x673b0211, 0x7ae40161, 0x62890051, 0x00000000}},  //   _aguj, rzit, iteo,
  { {0xdb0f00d4, 0xab670089, 0x65630082, 0x00000000}},  //   _encà, _beļģ, danh,
  { {0x63a903a6, 0x443e01e5, 0x628903a7, 0x00000000}},  //   jden, _rut_, kteo,
  { {0x443e018e, 0x7dd00039, 0xd76500a2, 0x00000000}},  //   _sut_, _fäst, رنوی,
  { {0x63a903a8, 0x7dd003a9, 0x443e00ab, 0x00000000}},  //   eden, _gäst, _put_,
  { {0x7dd003aa, 0x78450006, 0xf77203ab, 0x00000000}},  //   _häss, _tėva, _لاء_,
  { {0x63a900ea, 0x6008005d, 0x7a29007f, 0x00000000}},  //   gden, nımd, _užtr,
  { {0xa802005d, 0x291803ac, 0x656303ad, 0x00000000}},  //   ğıda, _hyra_, banh,
  { {0x443e03ae, 0x7dd003af, 0x63a90142, 0x00000000}},  //   _tut_, _mäss, aden,
  { {0x7dd0010f, 0x443e006c, 0xc05701e1, 0x00000000}},  //   _läss, _uut_, мія_,
  { {0x291803b0, 0x601d009d, 0x3eb203b1, 0x00000000}},  //   _myra_, rémo, _bryt_,
  { {0x03d700a0, 0xa30800a1, 0x7dd000f8, 0x00000000}},  //   _קודם_, _عرصے_, _näss,
  { {0xdb0401a2, 0x00000000, 0x00000000, 0x00000000}},  //   weiß,   ,   ,
  { {0x4426001d, 0x2ba700ed, 0x6d4703b2, 0x00000000}},  //   _kho_, мјав, rcja,
  { {0x44260145, 0x3eb20023, 0x00000000, 0x00000000}},  //   _jho_, _fryt_,   ,
  { {0x160e007d, 0x442603b3, 0x6b8d03b4, 0x00000000}},  // [390] ाकार_, _mho_, rfag,
  { {0x4426023a, 0x63a903b5, 0x7e7d03b6, 0x00000000}},  //   _lho_, zden, musp,
  { {0x7dd00073, 0x63a903b7, 0x44260089, 0x00000000}},  //   _väst, yden, _oho_,
  { {0x44260011, 0x291803b8, 0x764000e0, 0x00000000}},  //   _nho_, _dyra_, _bumy,
  { {0x7c2d02e1, 0x20030091, 0x7dd0021e, 0x00000000}},  //   mmar, čkih_, _täst,
  { {0x442603b9, 0x29180039, 0x00000000, 0x00000000}},  //   _aho_, _fyra_,   ,
  { {0x65630181, 0x44260061, 0x63a903ba, 0x00000000}},  //   ranh, _bho_, tden,
  { {0x442600ad, 0x7c2d0018, 0x7e7d002d, 0x00000000}},  //   _cho_, nmar, kusp,
  { {0x63a9004e, 0x66f30164, 0x2a6903bb, 0x00000000}},  //   rden, _अधिक_, nsab_,
  { {0x600802b9, 0x7c2d010f, 0x628903bc, 0x00000000}},  //   zımd, hmar, rteo,
  { {0x62890051, 0x7c2d00ab, 0xdb060065, 0x00000000}},  //   steo, kmar, _pakë,
  { {0x6441000d, 0x656103bd, 0x2a69006c, 0x00000000}},  //   _iuli, _helh, ksab_,
  { {0x442d03be, 0x6441006a, 0x81d50242, 0x00000000}},  //   mme_, _huli, _подх,
  { {0x644103bf, 0x7c26008d, 0x270e0011, 0x00000000}},  //   _kuli, _shkr, ộng_,
  { {0x656102d5, 0xfce603c0, 0x644103c1, 0x00000000}},  //   _melh, хово, _juli,
  { {0x442d011f, 0x644102cc, 0x7c2d03c2, 0x00000000}},  //   nme_, _muli, gmar,
  { {0x291e01cd, 0x160f02fb, 0xe9da00d7, 0x00000000}},  // [3a0] _šta_, िवार_, пка_,
  { {0x442d03c3, 0x7c2d0207, 0xdb0600b9, 0x00000000}},  //   hme_, amar, _jaké,
  { {0x7c2d0181, 0x2b4b0061, 0x64410006, 0x00000000}},  //   bmar, _ffcc_, _nuli,
  { {0x442d03c4, 0x7dd0021e, 0xe853007a, 0x00000000}},  //   jme_, _täss, انند,
  { {0x442603c5, 0x00000000, 0x00000000, 0x00000000}},  //   _rho_,   ,   ,
  { {0x64410010, 0x442601c5, 0x442d03c6, 0x00000000}},  //   _buli, _sho_, eme_,
  { {0x644103c7, 0xd49703c8, 0xdcfc0089, 0x00000000}},  //   _culi, еры_, derī,
  { {0x69ce022b, 0xdb0601aa, 0x442d0213, 0x00000000}},  //   _hobe, _pakè, gme_,
  { {0x65610047, 0x69ce01ca, 0x64410032, 0x00000000}},  //   _felh, _kobe, _euli,
  { {0x44260038, 0x442d03c9, 0xf1ba0011, 0x00000000}},  //   _who_, ame_, _thơm_,
  { {0x33d601fb, 0xdfd10076, 0x442603ca, 0x00000000}},  //   _підт, ليد_, _tho_,
  { {0xa2e600da, 0x7e7d03b6, 0x04db009b, 0x00000000}},  //   _поед, tusp, _מקבל,
  { {0x644103cb, 0x9f4b0129, 0x7c2d03cc, 0x00000000}},  //   _zuli, ricà_, vmar,
  { {0x69ce01d9, 0x64410093, 0x7c2d03cd, 0x00000000}},  //   _nobe, _yuli, wmar,
  { {0xac1901e1, 0x7c2d03ce, 0x7e7d03cf, 0x00000000}},  //   дову_, tmar, susp,
  { {0x7c2d03d0, 0x00000000, 0x00000000, 0x00000000}},  //   umar,   ,   ,
  { {0x7f49004a, 0x9f4b010e, 0x00000000, 0x00000000}},  // [3b0] ñequ, öjõu_,   ,
  { {0x69ce03d1, 0x9f590048, 0x7e6d0032, 0x00000000}},  //   _cobe, insí_, _ivap,
  { {0x69ce0059, 0x7c2d0061, 0x442d0023, 0x00000000}},  //   _dobe, pmar, yme_,
  { {0x6561013e, 0x442d0288, 0x64410133, 0x00000000}},  //   _selh, xme_, _ruli,
  { {0x6441023a, 0x656100b9, 0xe7e200e8, 0x00000000}},  //   _suli, _pelh, _खतरा_,
  { {0x644103d2, 0x69ce03d3, 0x888200a1, 0x00000000}},  //   _puli, _gobe, _چیلن,
  { {0x442d03d4, 0x65610181, 0x6441006b, 0x00000000}},  //   tme_, _velh, _quli,
  { {0x7bcf000d, 0x6b9f001c, 0x442d00f4, 0x00000000}},  //   _jocu, neqg, ume_,
  { {0x130901fb, 0x9f420065, 0x69d80010, 0x00000000}},  //   ьний_, shkë_, öveg,
  { {0x442d03d5, 0x7bcf000d, 0xb63503d6, 0x00000000}},  //   sme_, _locu, _شفاع,
  { {0xf8e103d7, 0xdb1d002a, 0x644103d8, 0x00000000}},  //   पनिय, _cosú, _uuli,
  { {0x13a70063, 0x00000000, 0x00000000, 0x00000000}},  //   _سنتی_,   ,   ,
  { {0x69c4007d, 0x3f8c0036, 0xdb060142, 0x00000000}},  //   रामी, ędu_, _také,
  { {0x82760049, 0x63ab000c, 0xd24e03d9, 0x00000000}},  //   _יענע_, _hagn, _بنو_,
  { {0xa0a50088, 0x4094007e, 0xa3d5013d, 0x00000000}},  //   _райд, _брыт, _सका_,
  { {0x69ce0325, 0x63ab0107, 0xd00f0379, 0x00000000}},  //   _sobe, _jagn, _ولو_,
  { {0x63ab03da, 0x7bcf03db, 0x69ce012b, 0x00000000}},  // [3c0] _magn, _docu, _pobe,
  { {0xdb0d000c, 0x00000000, 0x00000000, 0x00000000}},  //   rjað,   ,   ,
  { {0x1d0a03dc, 0x7bcf00ab, 0xddc400e5, 0x00000000}},  //   _цени_, _focu, _eviţ,
  { {0x63ab03dd, 0x69ce03de, 0x27e003df, 0x00000000}},  //   _nagn, _wobe, óin_,
  { {0xe73703e0, 0x69ce03e1, 0xe7f3013d, 0x00000000}},  //   вец_, _tobe, _आगरा_,
  { {0xa613007e, 0x6aa40045, 0x00000000, 0x00000000}},  //   аміч, mwif,   ,
  { {0x63ab0207, 0x629901aa, 0x44a30025, 0x00000000}},  //   _bagn, _apwo, لموق,
  { {0x63ab03e2, 0x7dd90026, 0x00000000, 0x00000000}},  //   _cagn, _pìsk,   ,
  { {0x41e6007e, 0x63ab03e3, 0x8c1b0104, 0x00000000}},  //   віна, _dagn, ווקי,
  { {0xf1ba0011, 0x63ab0048, 0x27e60052, 0x00000000}},  //   _khơi_, _eagn, lhon_,
  { {0x25be0061, 0x601d038e, 0xb97b009b, 0x00000000}},  //   _intl_, lémi, וניי,
  { {0x63ab03e4, 0x7ec9008d, 0x27e603e5, 0x00000000}},  //   _gagn, _nëpë, nhon_,
  { {0xd2500054, 0xd336008b, 0x6b840146, 0x00000000}},  //   _انت_, _рэжы, dgig,
  { {0x63ab00ca, 0x628001c5, 0x7bcf0035, 0x00000000}},  //   _zagn, mumo, _socu,
  { {0x27e60066, 0xa3d60309, 0x62800006, 0x00000000}},  //   khon_, _हवा_, lumo,
  { {0x313700a0, 0x6008014a, 0x3ed503e6, 0x00000000}},  //   _ברוך_, rımc, _مقبر,
  { {0x27e603e7, 0x00000000, 0x00000000, 0x00000000}},  // [3d0] dhon_,   ,   ,
  { {0x3ea90058, 0x9f4000d4, 0x6008014a, 0x00000000}},  //   _isat_, _aliè_, pımc,
  { {0xf1ba001d, 0xf77503e8, 0x7bcf0035, 0x00000000}},  //   _chơi_, гулю, _tocu,
  { {0xf093007b, 0x1a65026c, 0x63a003e9, 0x00000000}},  //   ינע_, _میری_, jemn,
  { {0x63ab000c, 0x62800089, 0x6008005d, 0x00000000}},  //   _ragn, jumo, nıma,
  { {0x63ab000c, 0x2e24000c, 0x27e600e0, 0x00000000}},  //   _sagn, höfn_, ahon_,
  { {0x63ab03ea, 0x20020036, 0xcd980104, 0x00000000}},  //   _pagn, ynki_, דדות_,
  { {0x27e603eb, 0x249603ec, 0x3d3c00a0, 0x00000000}},  //   chon_, انيد_, וגוס,
  { {0x63ab03ed, 0x628003ee, 0x7c3d03ef, 0x00000000}},  //   _vagn, gumo, _misr,
  { {0x10a50081, 0x63ab02a3, 0xdb0403f0, 0x00000000}},  //   гион, _wagn, ndiá,
  { {0x54550216, 0x69c4001c, 0x63ab03f1, 0x00000000}},  //   _свет, राती, _tagn,
  { {0x628003b5, 0x92b50355, 0x7c3d0066, 0x00000000}},  //   bumo, _محتا, _nisr,
  { {0x94100061, 0x3ea90035, 0x62c70025, 0x00000000}},  //   ावरच_, _csat_, _جزاك,
  { {0xc332009b, 0xdb1e0068, 0x3ea90146, 0x00000000}},  //   _הוד_, _éxéc, _dsat_,
  { {0xfce30264, 0xd1b800a1, 0x3ea90089, 0x00000000}},  //   боро, _جانا_, _esat_,
  { {0xfaa602ea, 0x81bc0089, 0xd0120025, 0x00000000}},  //   лабо, smēt, _دلع_,
  { {0xfe72035b, 0x6b8403f2, 0x7c3d0133, 0x00000000}},  // [3e0] _ادب_, rgig, _disr,
  { {0xf1ba0011, 0x443d0016, 0xd6c40014, 0x00000000}},  //   _phơi_, _liw_, یمای,
  { {0x27e60010, 0x6d5c00d6, 0x81bc001e, 0x00000000}},  //   thon_, mbra, slēg,
  { {0x6d5c0240, 0x4b55005e, 0xdb1d000a, 0x00000000}},  //   lbra, _върт, _onsè,
  { {0xcc3b0049, 0x6d5c0340, 0xddc400ca, 0x00000000}},  //   _רעכט, obra, _zviš,
  { {0xe9df0051, 0x27e60065, 0x8675007e, 0x00000000}},  //   _dtús_, shon_, рыцц,
  { {0xe0c70014, 0x63a00190, 0xdb1d01aa, 0x00000000}},  //   _از_, temn, _ansè,
  { {0xc27403f3, 0xb27403f4, 0x752400b9, 0x00000000}},  //   алиј, алиш, řizo,
  { {0x443d01aa, 0x7d1e03f5, 0x370603f6, 0x00000000}},  //   _diw_, _lyps, _спаг,
  { {0x628003f7, 0x63a003f8, 0xe617007e, 0x00000000}},  //   rumo, semn, _бду_,
  { {0x43860123, 0x6280002d, 0xb97b0049, 0x00000000}},  //   _ملاق, sumo, ענטי,
  { {0x273a038c, 0x9f590065, 0x75280089, 0x00000000}},  //   _günü_, misë_, _izdz,
  { {0x9f590065, 0x98b8002b, 0x244a0082, 0x00000000}},  //   lisë_, _ferħ_, _hùm_,
  { {0x2fc003f9, 0x2e24000c, 0x6d5c03fa, 0x00000000}},  //   _enig_, söfn_, gbra,
  { {0x9f59008d, 0xfaff0065, 0xdb1d00f4, 0x00000000}},  //   nisë_, _ndër_, _insé,
  { {0x81bc0089, 0x3b5500ed, 0x61fa03fb, 0x00000000}},  //   slēd, ркар, litl,
  { {0x6d5c0198, 0x3ea900d4, 0x9f49014a, 0x00000000}},  // [3f0] bbra, _usat_, _amaç_,
  { {0xdcfc0089, 0x9f590065, 0x61fa03fc, 0x00000000}},  //   sgrā, kisë_, nitl,
  { {0x9f590065, 0xf9880025, 0xdb0403fd, 0x00000000}},  //   jisë_, انمي_, rdiá,
  { {0x7e7d01d6, 0x9f590065, 0x61fa014a, 0x00000000}},  //   orsp, disë_, hitl,
  { {0xd90f026c, 0x61fa03fe, 0x22460173, 0x00000000}},  //   _کیا_, kitl, _nuok_,
  { {0x443d01aa, 0xaaa8005e, 0x9f590065, 0x00000000}},  //   _siw_, _съюз_, fisë_,
  { {0x7aed0207, 0x61fa006b, 0x7e7d01a2, 0x00000000}},  //   lzat, ditl, hrsp,
  { {0x7bcd03ff, 0x244a0011, 0x6d5c0089, 0x00000000}},  //   njau, _dùm_, zbra,
  { {0x7aed0400, 0x11e501e0, 0x64580061, 0x00000000}},  //   nzat, ижим, apvi,
  { {0x4375007a, 0x84670265, 0x20b5007e, 0x00000000}},  //   _چهار, _бъде, аёмс,
  { {0x9f590065, 0x55ba00a0, 0x23c5013d, 0x00000000}},  //   cisë_, _שמעו, वादद,
  { {0x22950401, 0x9f590173, 0xdb1d004a, 0x00000000}},  //   _видя, nisè_, _ensé,
  { {0x6d5c0007, 0x61fa0402, 0xceb4006b, 0x00000000}},  //   tbra, bitl, _azər_,
  { {0x91640054, 0x61fa0403, 0xdb0400c4, 0x00000000}},  //   _هههه, citl, ldiç,
  { {0x6d5c010f, 0x8f760245, 0x7f7601ee, 0x00000000}},  //   rbra, _купі, _купц,
  { {0xdb0402d5, 0x2fc0018e, 0x35c7013d, 0x00000000}},  //   ndiç, _unig_, लाड़,

  { {0x896602a8, 0x31670173, 0x9f590065, 0x00000000}},  // [400] икаж, _kenz_, zisë_,
  { {0x48b6005e, 0x7d1e00f8, 0x00000000, 0x00000000}},  //   ищет, _typs,   ,
  { {0x320500ab, 0xac0a0404, 0xeb9f00ea, 0x00000000}},  //   inly_, _анна_, _kjøl_,
  { {0x7bdf0061, 0x9f590065, 0x244a0405, 0x00000000}},  //   ckqu, visë_, _rùm_,
  { {0x61fa01df, 0x7aed0036, 0x00000000, 0x00000000}},  //   yitl, czat,   ,
  { {0xd49a0200, 0x5d7a007b, 0x67290089, 0x00000000}},  //   ври_, דאַק, _dzej,
  { {0x53e601e0, 0x83f80364, 0x399b0097, 0x00000000}},  //   ициа, лекс_, _שילד,
  { {0x9f59008d, 0x32050022, 0x69c40204, 0x00000000}},  //   risë_, enly_, रावी,
  { {0x9f59008d, 0x61fa0406, 0x66e30407, 0x00000000}},  //   sisë_, titl, _дота,
  { {0x9f590408, 0x645802e1, 0x244a0082, 0x00000000}},  //   pisë_, ppvi, _tùm_,
  { {0x7aed0409, 0x9f59040a, 0x66180142, 0x00000000}},  //   zzat, lisé_, movk,
  { {0x61fa040b, 0x6568040c, 0x6618040d, 0x00000000}},  //   sitl, _hedh, lovk,
  { {0x6448040e, 0x9f5900f4, 0x7e7d040f, 0x00000000}},  //   _hudi, nisé_, ursp,
  { {0x64480006, 0x752d00b9, 0x66180410, 0x00000000}},  //   _kudi, řaze, novk,
  { {0x65680065, 0x3157009b, 0x7b67007c, 0x00000000}},  //   _medh, _דיון_, итае,
  { {0x81e80055, 0x7aed0411, 0x80ab0061, 0x00000000}},  //   _যদি_, tzat, _जनते,
  { {0x6e950054, 0x5e950054, 0x7bcd021e, 0x00000000}},  // [410] _الخا, _الخط, rjau,
  { {0x20190412, 0x7bcd0413, 0x64480007, 0x00000000}},  //   losi_, sjau, _oudi,
  { {0x6008014a, 0x66180161, 0xa3d60061, 0x00000000}},  //   kıml, dovk, _हवं_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xef1f0279, 0x60080414, 0x656800d9, 0x00000000}},  //   zgün_, dıml, _bedh,
  { {0x64480415, 0xa509003b, 0xbb3a009b, 0x00000000}},  //   _budi, лела_, _תעשי,
  { {0x20190416, 0x64480417, 0x6d450418, 0x00000000}},  //   kosi_, _cudi, _mgha,
  { {0xd774035b, 0x31670197, 0x69d5012d, 0x00000000}},  //   _واقع, _senz_, _hoze,
  { {0x6568000b, 0x20190419, 0xdb0400c4, 0x00000000}},  //   _fedh, dosi_, rdiç,
  { {0x6d45018e, 0xbbd40164, 0x27fd0016, 0x00000000}},  //   _ngha, _धक्क, liwn_,
  { {0x273300ad, 0x69d5041a, 0xa8790049, 0x00000000}},  //   _ảnh_, _moze, װאָר,
  { {0x6d45041b, 0xdb06041c, 0xfaff0007, 0x00000000}},  //   _agha, _laká, _reën_,
  { {0x69d5041d, 0xfaff0007, 0x6d4501f3, 0x00000000}},  //   _ooze, _seën_, _bgha,
  { {0xc5f2007b, 0x9f59021e, 0x69d5041e, 0x00000000}},  //   ִדן_, ensä_, _noze,
  { {0xdcf7005f, 0xe0550025, 0xfce3041f, 0x00000000}},  //   _baxı, _اختب, поро,
  { {0x20190420, 0x66180421, 0x77690422, 0x00000000}},  //   cosi_, zovk, _neex,
  { {0x69d5002d, 0x4a430423, 0xef1f0424, 0x00000000}},  // [420] _boze, знув, ngül_,
  { {0xe9d70425, 0x9f59009d, 0xa96a0426, 0x00000000}},  //   бку_, visé_, امام_,
  { {0xdb1d027b, 0x65680427, 0xb86501b7, 0x00000000}},  //   _bosó, _redh, قانو,
  { {0x64480020, 0x6d45002b, 0x9f59009d, 0x00000000}},  //   _rudi, _zgha, tisé_,
  { {0x6448037e, 0x7641011c, 0xa6fa0025, 0x00000000}},  //   _sudi, _bily, دعاء_,
  { {0x7c240129, 0x9f5900f4, 0x64480211, 0x00000000}},  //   llir, risé_, _pudi,
  { {0xd467012b, 0xdcf7005f, 0x7641018e, 0x00000000}},  //   бије_, _yaxı, _dily,
  { {0x325400ed, 0xdb060428, 0x938a004d, 0x00000000}},  //   овир, _zaká, уска_,
  { {0x20190429, 0x600801df, 0x7641042a, 0x00000000}},  //   vosi_, rıml, _fily,
  { {0x64480093, 0x7641018e, 0x909800ed, 0x00000000}},  //   _tudi, _gily, авот_,
  { {0x6448042b, 0x7c24016c, 0x2019042c, 0x00000000}},  //   _uudi, klir, tosi_,
  { {0x7c29002b, 0x2019007f, 0x00000000, 0x00000000}},  //   ċerk, uosi_,   ,
  { {0x2019042d, 0x2d9800f4, 0x8af0006b, 0x00000000}},  //   rosi_, ffre_, ncəd,
  { {0xddcd0036, 0x44240093, 0x10f900a1, 0x00000000}},  //   _stał, llm_, ابیں_,
  { {0x69d5042e, 0x7c240066, 0xd12f0245, 0x00000000}},  //   _roze, flir, _хх_,
  { {0x68e1006c, 0xdb0f008e, 0x7c240026, 0x00000000}},  //   _üldi, _hacé, glir,
  { {0x69d50062, 0xdd910054, 0x4424006c, 0x00000000}},  // [430] _poze, _قوة_, ilm_,
  { {0x44240039, 0x6d4500e7, 0xceb40049, 0x00000000}},  //   hlm_, _ugha, _זיץ_,
  { {0x7c2400d4, 0xdb1d042f, 0xdcf7006b, 0x00000000}},  //   blir, _insí, _taxı,
  { {0x76410430, 0x7649004a, 0xe76b0431, 0x00000000}},  //   _sily, _puey, احان_,
  { {0xdb2300a2, 0x76410432, 0xdce500ca, 0x00000000}},  //   _روسی, _pily, _mehč,
  { {0x27fd018e, 0x442f0433, 0x4efc00b3, 0x00000000}},  //   siwn_, _shg_, נהגו,
  { {0x362300a1, 0x62800434, 0x64420133, 0x00000000}},  //   _ہورہ, ermo, _bioi,
  { {0x76410435, 0xd79402dc, 0x84360025, 0x00000000}},  //   _wily, _нисъ, يكور_,
  { {0x644202d0, 0x00000000, 0x00000000, 0x00000000}},  //   _dioi,   ,   ,
  { {0xfaff0007, 0xe1f9030d, 0xef1f026d, 0x00000000}},  //   _reël_, рго_, rgül_,
  { {0x3ea00436, 0x600a0437, 0xa069003b, 0x00000000}},  //   _spit_, ином_, јама_,
  { {0x64420438, 0xd9a6007d, 0xdb1d004a, 0x00000000}},  //   _gioi, _ऑस्ट, _ansí,
  { {0x11d501e1, 0x8db60088, 0x51f50439, 0x00000000}},  //   _мікр, осві, _وستر,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7a30043a, 0x00000000, 0x00000000, 0x00000000}},  //   näte,   ,   ,
  { {0xdb0d0051, 0xf09200a0, 0xec160014, 0x00000000}},  //   adaí, _חנה_, آورد,
  { {0x5336007b, 0x44ef0044, 0x2d98004a, 0x00000000}},  // [440] ַנען_, টপিক_, pfre_,
  { {0x7a30043b, 0x998a007f, 0x00000000, 0x00000000}},  //   käte, _ribų_,   ,
  { {0x7c24043c, 0xa17a0049, 0xb17a0049, 0x00000000}},  //   plir, שטעט, שטער,
  { {0xb09a0049, 0xdb040051, 0x6abd0009, 0x00000000}},  //   ייער, idiú, _frsf,
  { {0x7bc6043d, 0xdce70089, 0x00000000, 0x00000000}},  //   _inku, majā,   ,
  { {0x78af00b0, 0xdce70089, 0x00000000, 0x00000000}},  //   äivä, lajā,   ,
  { {0x37e60088, 0xa6d80044, 0x00000000, 0x00000000}},  //   _довг, _দেশট,   ,
  { {0x68e3043e, 0x7dd000b0, 0xdce70089, 0x00000000}},  //   ønde, _väsy, najā,
  { {0xc1a601fc, 0xdceb00d0, 0x7762043f, 0x00000000}},  //   ојни, _čiče, mbox,
  { {0x776200f8, 0x68e900b9, 0x2be1013d, 0x00000000}},  //   lbox, _ředi, _नवभा,
  { {0xc95300b6, 0x3d1a0061, 0xa0540088, 0x00000000}},  //   ומת_, _मुले_, явні,
  { {0x645a005f, 0x6831032e, 0x00000000, 0x00000000}},  //   _itti, rådg,   ,
  { {0xf77300b6, 0x2ef4007e, 0xf1a90014, 0x00000000}},  //   וקר_, дзяр, _گانه_,
  { {0x77620009, 0x7bc60440, 0x00000000, 0x00000000}},  //   hbox, _anku,   ,
  { {0xdb6b0441, 0xf1a9023c, 0x9b6b00ed, 0x00000000}},  //   ирал_, _دانه_, ишаа_,
  { {0x3d1a0061, 0x3eb000b0, 0x80b80061, 0x00000000}},  //   _मुळे_, ältä_, ेमीं,
  { {0x161a03d7, 0x2aab0098, 0x7762004a, 0x00000000}},  // [450] धवार_, штво_, dbox,
  { {0x645a0282, 0x657a0082, 0x99980087, 0x00000000}},  //   _otti, _ndth, _pirš_,
  { {0x6d550036, 0x00000000, 0x00000000, 0x00000000}},  //   mcza,   ,   ,
  { {0x27e90010, 0x99980006, 0x80380049, 0x00000000}},  //   óan_, _virš_, ַנגע_,
  { {0x645a0442, 0x68e30030, 0xf1bc0164, 0x00000000}},  //   _atti, øndb, ्ञान,
  { {0x7a30010f, 0x6b8d0443, 0x00000000, 0x00000000}},  //   täte, lgag,   ,
  { {0x69cd0061, 0x7d180056, 0x00000000, 0x00000000}},  //   साठी, _øvst,   ,
  { {0x7a300444, 0xf7730445, 0x6aad00e7, 0x00000000}},  //   räte, _زار_, owaf,
  { {0x645a011f, 0x35f5025f, 0xdb0f0446, 0x00000000}},  //   _etti, _епар, _incó,
  { {0x200b0036, 0x95c8004d, 0x00000000, 0x00000000}},  //   enci_, _муха_,   ,
  { {0x6d550046, 0xc6170309, 0x69c701ee, 0x00000000}},  //   dcza, दकीय_, _mnje,
  { {0xdb040051, 0x6d5500b4, 0x00000000, 0x00000000}},  //   rdiú, ecza,   ,
  { {0x63a90100, 0x33f40447, 0x24770035, 0x00000000}},  //   meen, _تسلس, lăm_,
  { {0x63a90343, 0xed570242, 0x225f008a, 0x00000000}},  //   leen, зор_, mpuk_,
  { {0x8af0006b, 0xdce70089, 0x800b00a1, 0x00000000}},  //   hbət, tajā, _گروہ_,
  { {0x60dc0039, 0x24510428, 0x63a90448, 0x00000000}},  //   ärme, _mám_, neen,
  { {0xfaa300ed, 0x20020036, 0x765b00e7, 0x00000000}},  // [460] нато, miki_, _ntuy,
  { {0x20020149, 0x63a900b0, 0xe9d7007c, 0x00000000}},  //   liki_, heen, пку_,
  { {0x24510428, 0x63a90449, 0x02a80316, 0x00000000}},  //   _nám_, keen, _कन्न,
  { {0x6b8d001c, 0x200203e9, 0x63a900b5, 0x00000000}},  //   cgag, niki_, jeen,
  { {0x63a9044a, 0xdb060039, 0x5694044b, 0x00000000}},  //   deen, _bakå, фалт,
  { {0xf1d00011, 0x24510011, 0x200200e7, 0x00000000}},  //   _mạch_, _bám_, hiki_,
  { {0x3958044c, 0x2451001d, 0x2477001a, 0x00000000}},  //   _ifrs_, _cám_, găm_,
  { {0x2451044d, 0x63a9044e, 0xa6d30044, 0x00000000}},  //   _dám_, geen, _দেওয়,
  { {0x366701f9, 0x2002006b, 0x6d550036, 0x00000000}},  //   _нато_, diki_, ycza,
  { {0x6831044f, 0x00000000, 0x00000000, 0x00000000}},  //   råde,   ,   ,
  { {0x80df0055, 0x2002000b, 0x92cc0044, 0x00000000}},  //   _ফেব্, fiki_, রনে_,
  { {0xf1d00011, 0x20020450, 0x27e60010, 0x00000000}},  //   _bạch_, giki_, nkon_,
  { {0xf194007c, 0x41e60451, 0x00000000, 0x00000000}},  //   _жиль, _ніка,   ,
  { {0xc27b0452, 0x7a2b014a, 0xdb0f00f6, 0x00000000}},  //   _פרוי, gütl, _oncò,
  { {0x20020453, 0x24510011, 0x6d550036, 0x00000000}},  //   biki_, _xám_, rcza,
  { {0x1bd40454, 0x69c70166, 0x394a01a2, 0x00000000}},  //   нося, _snje, _agbs_,
  { {0xf1d00011, 0x24770035, 0x59d9007e, 0x00000000}},  // [470] _gạch_, zăm_, одаў_,
  { {0x8af0005f, 0xceb400b3, 0x63a90032, 0x00000000}},  //   vbət, _טיפ_, zeen,
  { {0x63a90455, 0x765b0456, 0x67d50457, 0x00000000}},  //   yeen, _stuy, можу,
  { {0xdb0f0211, 0x24510458, 0xeabf0082, 0x00000000}},  //   _hací, _rám_, _trù_,
  { {0x24510161, 0x9f4b008e, 0x63a9010e, 0x00000000}},  //   _sám_, licó_, veen,
  { {0x20020459, 0x2477001a, 0x8af0013f, 0x00000000}},  //   ziki_, tăm_, rbət,
  { {0x5884045a, 0x63a90368, 0xdb0f027b, 0x00000000}},  //   _пыта, teen, _mací,
  { {0x245101ca, 0xf8b2009b, 0x2477001a, 0x00000000}},  //   _vám_, _בשל_, răm_,
  { {0x765b0009, 0x27ff0145, 0x24770035, 0x00000000}},  //   _utuy, _imun_, săm_,
  { {0x13060057, 0x81bc001e, 0x63a901e2, 0x00000000}},  //   ьный_, blēm, seen,
  { {0x660300b9, 0x20020059, 0xf1d00011, 0x00000000}},  //   mink, tiki_, _sạch_,
  { {0x6603010a, 0x9f4b0211, 0x351a0049, 0x00000000}},  //   link, dicó_, _ווענ,
  { {0x2002000b, 0x8af0005f, 0x6289045b, 0x00000000}},  //   riki_, hbər, queo,
  { {0x6603010a, 0xc33200b6, 0x9f4b008e, 0x00000000}},  //   nink, _סוג_, ficó_,
  { {0x27ed0368, 0x81bc001e, 0x20020020, 0x00000000}},  //   _olen_, klēj, piki_,
  { {0x660300b0, 0x2d84014a, 0xbf9b00fa, 0x00000000}},  //   hink, şme_, liên,
  { {0x66030169, 0x2247010e, 0x78a90166, 0x00000000}},  // [480] kink, _kink_, _ćeva,
  { {0xceb4005f, 0x6603045c, 0xbf9b00c4, 0x00000000}},  //   _isə_, jink, niên,
  { {0x2247045d, 0x66030161, 0x2fc90022, 0x00000000}},  //   _mink_, dink, _ynag_,
  { {0x2247045e, 0xbf9b0011, 0xfbdf0082, 0x00000000}},  //   _link_, hiên, _hiên_,
  { {0x27e6045f, 0xfbdf0011, 0x8af0006b, 0x00000000}},  //   rkon_, _kiên_, rbəs,
  { {0x27e60460, 0x66030461, 0x27ed0462, 0x00000000}},  //   skon_, gink, _elen_,
  { {0xbf9b0181, 0xdcfe014a, 0x64a3003b, 0x00000000}},  //   diên, _kapı, ваја,
  { {0xfbdf00ad, 0x69dc0463, 0x24800213, 0x00000000}},  //   _liên_, _hore, čim_,
  { {0x51860088, 0x12be0044, 0x2327003b, 0x00000000}},  //   муна, েন্দ, моћи_,
  { {0xfbdf001d, 0x66030036, 0xdce70036, 0x00000000}},  //   _niên_, cink, lają,
  { {0x69dc01d9, 0x22470343, 0x9f4b0026, 0x00000000}},  //   _more, _dink_, dicò_,
  { {0xe36302a8, 0xd0110464, 0xdce70036, 0x00000000}},  //   _акци, الح_, nają,
  { {0x3f8501f6, 0xfbdf001d, 0x63a20058, 0x00000000}},  //   ğlu_, _biên_, _ibon,
  { {0x69dc0292, 0xbf9b0181, 0x9f4b008e, 0x00000000}},  //   _nore, ciên, ticó_,
  { {0xdb0f0211, 0x62860465, 0xdce70036, 0x00000000}},  //   _vací, škod, kają,
  { {0xdb0d0181, 0x22470240, 0x66030466, 0x00000000}},  //   ndaç, _zink_, zink,
  { {0x5a350467, 0xdce70046, 0xa3cf001c, 0x00000000}},  // [490] енат, dają, शात_,
  { {0x69dc0468, 0x7e6d0020, 0x27ff0093, 0x00000000}},  //   _core, _iwap, _smun_,
  { {0x69dc000d, 0x66030469, 0x27ed01aa, 0x00000000}},  //   _dore, vink, _plen_,
  { {0x6603046a, 0xdd0d0036, 0x7e6d046b, 0x00000000}},  //   wink, półp, _kwap,
  { {0x69dc02cc, 0xf77001fa, 0x3669046c, 0x00000000}},  //   _fore, شان_, чало_,
  { {0x69dc0059, 0x7e6d00e7, 0xfbdf0082, 0x00000000}},  //   _gore, _mwap, _xiên_,
  { {0xdcfe011f, 0x7648046d, 0x6603046e, 0x00000000}},  //   _yapı, _didy, rink,
  { {0x6603046f, 0x69dc0470, 0x7bdd0032, 0x00000000}},  //   sink, _zore, _josu,
  { {0xc245004c, 0x69dc008e, 0x66030471, 0x00000000}},  //   нник, _yore, pink,
  { {0xdb1d0039, 0x63a20472, 0x7bdd0473, 0x00000000}},  //   _insä, _ebon, _losu,
  { {0xbf9b0181, 0x059600a6, 0x91d00044, 0x00000000}},  //   riên, _سالگ, িসংখ,
  { {0x34bd013d, 0x6e250127, 0x7e6d0173, 0x00000000}},  //   ्मीद, _akhb, _bwap,
  { {0x224700f6, 0x62640088, 0x63b90016, 0x00000000}},  //   _tink_, _авіа, _iawn,
  { {0x63bb0474, 0xf1d0001d, 0x63b9002b, 0x00000000}},  //   ldun, _hạnh_, _hawn,
  { {0xfbdf00ad, 0x32050038, 0xa3e30061, 0x00000000}},  //   _viên_, mily_, _नका_,
  { {0x63bb0475, 0xc4d20476, 0x69dc0207, 0x00000000}},  //   ndun, נגן_, _sore,
  { {0x69dc01cd, 0xfbdf001d, 0xf1d0001d, 0x00000000}},  // [4a0] _pore, _tiên_, _mạnh_,
  { {0xf1d0001d, 0x81e10055, 0x7ae40009, 0x00000000}},  //   _lạnh_, নোর_, ryit,
  { {0x69dc0018, 0xdcfe0477, 0x229901aa, 0x00000000}},  //   _vore, _tapı, hèk_,
  { {0xf7720379, 0x629b0006, 0xe73a0478, 0x00000000}},  //   ااا_, ktuo, пее_,
  { {0x69dc01d9, 0xdce70036, 0x7c260066, 0x00000000}},  //   _tore, rają, _ikkr,
  { {0xb9060055, 0x629b00e0, 0x68310479, 0x00000000}},  //   _বই_, dtuo, råda,
  { {0x06d80044, 0xf7720025, 0x76480095, 0x00000000}},  //   _দেখি, _ماء_, _vidy,
  { {0xf1d0001d, 0x32660088, 0xd3700025, 0x00000000}},  //   _cạnh_, нтов, جهة_,
  { {0x63b9047a, 0x7648000a, 0x75280036, 0x00000000}},  //   _dawn, _tidy, _wydz,
  { {0x75280036, 0x26c40032, 0x51f701ab, 0x00000000}},  //   _tydz, _irmo_, енью_,
  { {0x7e6d001c, 0x68150036, 0x63b90066, 0x00000000}},  //   _swap, ląda, _fawn,
  { {0x63a2047b, 0x20d50006, 0x26c40087, 0x00000000}},  //   _ubon, džią_, _krmo_,
  { {0x91e60216, 0x629b00f6, 0x2d85029d, 0x00000000}},  //   _поде, ctuo, óleo_,
  { {0x92f2005d, 0x7bdd0035, 0x00000000, 0x00000000}},  //   ığım, _sosu,   ,
  { {0x7bdd047c, 0xe5710049, 0x442601c5, 0x00000000}},  //   _posu, יַן_, _kko_,
  { {0x7e6d0418, 0x44260087, 0x00000000, 0x00000000}},  //   _twap, _jko_,   ,
  { {0x442600e7, 0xe987003b, 0xafdb0190, 0x00000000}},  // [4b0] _mko_, ећен, rmød,
  { {0xafdb0030, 0x99990006, 0x3ea90022, 0x00000000}},  //   smød, _rusų_, _ipat_,
  { {0xa775047d, 0x78ba0027, 0x26c40023, 0x00000000}},  //   влеч, _štvr, _armo_,
  { {0x4426047e, 0xfbdf0011, 0x6b67009d, 0x00000000}},  //   _nko_, _kiêm_, _dégâ,
  { {0x7c2d047f, 0x63b9002b, 0x212b0011, 0x00000000}},  //   mlar, _rawn, ́ch_,
  { {0x44260480, 0x7c2d0481, 0x66e2007c, 0x00000000}},  //   _ako_, llar, роша,
  { {0x32050482, 0xfbdf0011, 0x66e70089, 0x00000000}},  //   vily_, _liêm_, _sīkā,
  { {0x7c2d01f6, 0xd6d80055, 0xe795026c, 0x00000000}},  //   nlar, _দেওয, _جاسک,
  { {0x63bb022b, 0x7c2d002d, 0xfbdf0011, 0x00000000}},  //   rdun, ilar, _niêm_,
  { {0x3d1a03d7, 0x629b0006, 0x4426022b, 0x00000000}},  //   _मुझे_, rtuo, _eko_,
  { {0x7c2d0483, 0x629b0484, 0x23e701fb, 0x00000000}},  //   klar, stuo, _підв,
  { {0x7c2d011f, 0x320500ab, 0x629b007f, 0x00000000}},  //   jlar, sily_, ptuo,
  { {0x443f0485, 0x442d0486, 0x7c2d01f6, 0x00000000}},  //   mmu_, mle_, dlar,
  { {0x644b006a, 0x7c2d006c, 0x3ea90487, 0x00000000}},  //   _higi, elar, _dpat_,
  { {0x442d0488, 0x68380489, 0xed57003b, 0x00000000}},  //   ole_, líde, тос_,
  { {0x2d81048a, 0xb7bc0055, 0x442d048b, 0x00000000}},  //   _edhe_, _অক্ট, nle_,
  { {0x442d048c, 0xdb0f0051, 0x2019048d, 0x00000000}},  // [4c0] ile_, _pacá, érie_,
  { {0x442d048e, 0x644b048f, 0x7c2d0032, 0x00000000}},  //   hle_, _ligi, alar,
  { {0x7c2d006b, 0x7db5008b, 0x442d0490, 0x00000000}},  //   blar, _ёсьц, kle_,
  { {0x443f01ca, 0x442d0030, 0x7c2d0491, 0x00000000}},  //   jmu_, jle_, clar,
  { {0x442d0224, 0x443f0066, 0x9696005e, 0x00000000}},  //   dle_, dmu_, треш,
  { {0x442d001f, 0x44260492, 0x628900f8, 0x00000000}},  //   ele_, _sko_, dreo,
  { {0x69ce0493, 0x644b0494, 0x442d02f1, 0x00000000}},  //   _inbe, _bigi, fle_,
  { {0x442d0018, 0x68e30495, 0xe4e301fb, 0x00000000}},  //   gle_, ände, рішн,
  { {0x62890496, 0x26c4010e, 0x00000000, 0x00000000}},  //   greo, _urmo_,   ,
  { {0x442d0198, 0x644b009f, 0x7c2d0497, 0x00000000}},  //   ale_, _eigi, zlar,
  { {0x442d0498, 0x44260209, 0xf99300b6, 0x00000000}},  //   ble_, _tko_, ברת_,
  { {0x442d028a, 0x44260499, 0x62890051, 0x00000000}},  //   cle_, _uko_, breo,
  { {0x7c24049a, 0x69ce049b, 0x4424049c, 0x00000000}},  //   doir, _onbe, mom_,
  { {0x8277007b, 0x24580011, 0xfbdf0011, 0x00000000}},  //   _יעדע_, _kém_, _viêm_,
  { {0x7c2d038c, 0x2d5802d3, 0x7c240051, 0x00000000}},  //   tlar, тись_, foir,
  { {0x69ce02cc, 0x0a6b01fc, 0x6c6a00a1, 0x00000000}},  //   _anbe, држи_, علقہ_,
  { {0x7c2d049d, 0x6d5c0026, 0x644000b0, 0x00000000}},  // [4d0] rlar, bcra, immi,
  { {0x4424049e, 0x7c2d049f, 0x442d04a0, 0x00000000}},  //   hom_, slar, zle_,
  { {0x442d04a1, 0x7c2d047f, 0x443f04a2, 0x00000000}},  //   yle_, plar, ymu_,
  { {0x442404a3, 0x7c2d005f, 0xb8db0204, 0x00000000}},  //   jom_, qlar, _अन_,
  { {0x442d04a4, 0x7e7d01d6, 0xc1780006, 0x00000000}},  //   vle_, nssp, nkės_,
  { {0x69d80010, 0xdb0600b9, 0x1a680014, 0x00000000}},  //   övet, _jaký, _شیمی_,
  { {0x442d0365, 0x18b80057, 0x644b04a5, 0x00000000}},  //   tle_, _игры_, _pigi,
  { {0x44240119, 0x442d00f4, 0x7e7d0109, 0x00000000}},  //   gom_, ule_, kssp,
  { {0x442d04a6, 0x11d90025, 0x6d5c0093, 0x00000000}},  //   rle_, فوظة_, ycra,
  { {0x442d04a7, 0xe0d900ed, 0x628904a8, 0x00000000}},  //   sle_, ево_, rreo,
  { {0x442d0038, 0x4424049c, 0x339500f3, 0x00000000}},  //   ple_, bom_, _ملاز,
  { {0x442404a9, 0x7f5d0009, 0x644b00e7, 0x00000000}},  //   com_, gcsq, _uigi,
  { {0x7c2400f4, 0x3f9e0036, 0x00000000, 0x00000000}},  //   voir, ętu_,   ,
  { {0x7bcf04aa, 0xdb0404ab, 0x645c00c4, 0x00000000}},  //   _ancu, leiç, _éric,
  { {0x7c24028c, 0x6d5c00ab, 0x2019009d, 0x00000000}},  //   toir, rcra, éric_,
  { {0xf092009b, 0x6d5c0051, 0xabf504ac, 0x00000000}},  //   _הנה_, scra, ачущ,
  { {0xed5a00c0, 0x7c2404ad, 0x00000000, 0x00000000}},  // [4e0] _поп_, roir,   ,
  { {0x7bcf0219, 0x7c24009d, 0x7a2b006c, 0x00000000}},  //   _encu, soir, kütu,
  { {0xdb0404ae, 0x2fd7007a, 0x6fd80204, 0x00000000}},  //   rdiñ, _شوید_, यापू,
  { {0x61e00201, 0x27e0009f, 0x78800428, 0x00000000}},  //   _पक्ष, ðin_, _návš,
  { {0x442404a3, 0x4a7504af, 0x2bd10061, 0x00000000}},  //   vom_, _выст, हारा,
  { {0x69ce010f, 0x00000000, 0x00000000, 0x00000000}},  //   _unbe,   ,   ,
  { {0x44240027, 0xdb040181, 0x657800ea, 0x00000000}},  //   tom_, feiç, ravh,
  { {0xd90d007a, 0x7e6404b0, 0x3a2a0093, 0x00000000}},  //   _تیم_, _otip, _hkbp_,
  { {0x81bc001e, 0x659604b1, 0x00000000, 0x00000000}},  //   klēt, _مجار,   ,
  { {0x683800b9, 0x00000000, 0x00000000, 0x00000000}},  //   bídc,   ,   ,
  { {0xf99300b6, 0x7e640058, 0xf48700a6, 0x00000000}},  //   זרת_, _atip, _مانی,
  { {0xde59008b, 0x7e7d04b2, 0x1e1d013d, 0x00000000}},  //   камі_, tssp, पक्ष_,
  { {0x81e30044, 0xbb1b0035, 0x00000000, 0x00000000}},  //   _নগর_, _adîn,   ,
  { {0xdb070047, 0x7e7d04b3, 0xdb060010, 0x00000000}},  //   ámít, rssp, _lakó,
  { {0x7e6400d9, 0x9f52000a, 0x00000000, 0x00000000}},  //   _etip, _olyè_,   ,
  { {0xdb06005a, 0x3a2a0093, 0x7a2b010f, 0x00000000}},  //   _fakü, _akbp_, hütt,
  { {0x200b04b4, 0x497504b5, 0x7b6404b6, 0x00000000}},  // [4f0] mici_, илас, стсе,
  { {0xdd910014, 0x200b0207, 0xd91b007c, 0x00000000}},  //   _بود_, lici_, нье_,
  { {0xd7e701ff, 0x00000000, 0x00000000, 0x00000000}},  //   лідо,   ,   ,
  { {0x200b0119, 0x69d80039, 0xf3f10082, 0x00000000}},  //   nici_, över, _mục_,
  { {0x3a2a04b7, 0x7c3a00f4, 0xdae600a1, 0x00000000}},  //   _fkbp_, ître, _پہلو_,
  { {0x48770137, 0x7bd70006, 0xdb0e000c, 0x00000000}},  //   _مدرس, šbuč, _þjál,
  { {0xdb1d0030, 0x200b014a, 0x25b60025, 0x00000000}},  //   _ansø, kici_, شهيد_,
  { {0x69c901f5, 0x73e50242, 0x200b036a, 0x00000000}},  //   _होती, роиз, jici_,
  { {0x200b04b8, 0x2215025f, 0x00000000, 0x00000000}},  //   dici_, ифор,   ,
  { {0xe12500ed, 0x7a3000b0, 0x9f590026, 0x00000000}},  //   импи, vätk, misù_,
  { {0x200b04b9, 0xdb0601aa, 0x7e6404ba, 0x00000000}},  //   fici_, _jakò, _stip,
  { {0x200b0207, 0x76430093, 0xdb060173, 0x00000000}},  //   gici_, lmny, _makò,
  { {0x3263026c, 0xdb0601aa, 0x32670098, 0x00000000}},  //   _انتہ, _lakò, _стев,
  { {0x3f8c006b, 0x7e6404bb, 0x00000000, 0x00000000}},  //   şdu_, _vtip,   ,
  { {0x76430022, 0x61e304bc, 0x00000000, 0x00000000}},  //   imny, _ionl,   ,
  { {0x61e30047, 0x78450006, 0x6ab601d6, 0x00000000}},  //   _honl, _tėvy, twyf,
  { {0x395601f9, 0x7a2b0010, 0xda650025, 0x00000000}},  // [500] ањет, yütt, مالي,
  { {0x2fc000d4, 0xdb06000a, 0xdb1d000a, 0x00000000}},  //   _haig_, _bakò, _masè,
  { {0x61e300fa, 0xd826005e, 0xdb1d000a, 0x00000000}},  //   _monl, аджи, _lasè,
  { {0x443d018e, 0xe666008b, 0xb8ce03d7, 0x00000000}},  //   _nhw_, атко, _कह_,
  { {0x2fc004bd, 0x660a04be, 0xb86600a1, 0x00000000}},  //   _maig_, tifk, _چارو,
  { {0x200b013e, 0x2d9802e1, 0x645e0181, 0x00000000}},  //   zici_, ngre_, ípio,
  { {0x200b014a, 0x443d0145, 0x7a3000b0, 0x00000000}},  //   yici_, _bhw_, jäti,
  { {0x443d04bf, 0xe8d7009b, 0x25a000b9, 0x00000000}},  //   _chw_, _דולר_, řil_,
  { {0x9f49014a, 0x443d04c0, 0x61e304c1, 0x00000000}},  //   _ilaç_, _dhw_, _bonl,
  { {0xc05a008b, 0x61e3008e, 0x443d0022, 0x00000000}},  //   кім_, _conl, _ehw_,
  { {0x200b04c2, 0x61e304c3, 0x3a3700b3, 0x00000000}},  //   tici_, _donl, שרים_,
  { {0x61e304c4, 0x00000000, 0x00000000, 0x00000000}},  //   _eonl,   ,   ,
  { {0x200b005f, 0x2fc00058, 0x00000000, 0x00000000}},  //   rici_, _daig_,   ,
  { {0x200b001a, 0x628204c5, 0x628000f8, 0x00000000}},  //   sici_, _ivoo, msmo,
  { {0x52b602d2, 0x200b04c6, 0x2fc00129, 0x00000000}},  //   _अनुस, pici_, _faig_,
  { {0xd0f7009b, 0x3b55007e, 0x2fc000f6, 0x00000000}},  //   _כמות_, скар, _gaig_,
  { {0xa3a80201, 0x62800056, 0x69de00ea, 0x00000000}},  // [510] ख्य_, nsmo, fjpe,
  { {0xf9930464, 0x683801dc, 0x9967005c, 0x00000000}},  //   تبر_, vída, ртал,
  { {0xb9c40025, 0x00000000, 0x00000000, 0x00000000}},  //   تقلي,   ,   ,
  { {0x3f9904c7, 0x2a69010e, 0x27ed0066, 0x00000000}},  //   ngsu_, ppab_, _ċens_,
  { {0x6fd8001c, 0xf9930025, 0x27e40035, 0x00000000}},  //   यातू, _وبس_, _domn_,
  { {0x6280005b, 0x7aed0093, 0x443d013e, 0x00000000}},  //   dsmo, myat, _shw_,
  { {0xfc3f001d, 0x628604c8, 0x7aed04c9, 0x00000000}},  //   _khí_, škol, lyat,
  { {0x81c30055, 0x1d18009b, 0x61e3005d, 0x00000000}},  //   _একই_, יקור_, _sonl,
  { {0xfc3f002a, 0x7aed020c, 0xf1d20061, 0x00000000}},  //   _mhí_, nyat, तांन,
  { {0x61fa00ab, 0x673b016c, 0x7a3004ca, 0x00000000}},  //   ghtl, _izuj, täti,
  { {0x628001d6, 0x20090022, 0x7aed0022, 0x00000000}},  //   asmo, _bmai_, hyat,
  { {0xfc3f0011, 0xfbdf0082, 0x7aed04cb, 0x00000000}},  //   _nhí_, _kiêu_, kyat,
  { {0x2fc004bd, 0x62800066, 0x7a3000b0, 0x00000000}},  //   _vaig_, csmo, säti,
  { {0x61fa04cc, 0xfc3f0211, 0x7aed04cd, 0x00000000}},  //   chtl, _ahí_, dyat,
  { {0x40950025, 0xfc3f0195, 0xfbdf0011, 0x00000000}},  //   _العر, _bhí_, _liêu_,
  { {0xfc3f001d, 0x3ce50039, 0x7ff60167, 0x00000000}},  //   _chí_, älva_, _دستا,
  { {0x68e304ce, 0x44c70082, 0x7aed0010, 0x00000000}},  // [520] ändn, _lđ_, gyat,
  { {0xc33200b6, 0x27e4001a, 0xdb04009d, 0x00000000}},  //   לון_, _somn_, nfié,
  { {0xe93a00ed, 0x44c70011, 0xb17a0049, 0x00000000}},  //   учај_, _nđ_, רטער,
  { {0x62800016, 0x8b960088, 0x7aed0045, 0x00000000}},  //   ysmo, _уроч, byat,
  { {0x673b0036, 0x683800b9, 0x661a0093, 0x00000000}},  //   _czuj, bídn, _pjtk,
  { {0x99d60151, 0x44c70082, 0x8af0006b, 0x00000000}},  //   _اتحا, _bđ_, dbəx,
  { {0x6aa40161, 0x44c70011, 0x75890088, 0x00000000}},  //   ltif, _cđ_, рсів_,
  { {0xc7a304cf, 0x7bc404d0, 0x628000f8, 0x00000000}},  //   _ниск, ndiu, tsmo,
  { {0x320c013e, 0x20090145, 0x00000000, 0x00000000}},  //   tidy_, _rmai_,   ,
  { {0x628004d1, 0x776204d2, 0x00000000, 0x00000000}},  //   rsmo, lcox,   ,
  { {0x201902d5, 0x628004d3, 0x546a00ed, 0x00000000}},  //   ério_, ssmo, _саем_,
  { {0x7aed005f, 0x6aa404d4, 0xf537009b, 0x00000000}},  //   yyat, ktif, _פנאי_,
  { {0x7336007a, 0x833603d6, 0x657a0023, 0x00000000}},  //   _ارائ, _اراض, _keth,
  { {0x329b019b, 0x645a04d5, 0x9f4000f6, 0x00000000}},  //   _עבוד, _kuti, _alió_,
  { {0xfc3f001d, 0x657a0038, 0xf1a9007a, 0x00000000}},  //   _phí_, _meth, _خانه_,
  { {0x645a002d, 0x317e010f, 0xddcd0161, 0x00000000}},  //   _muti, latz_, _uvaž,
  { {0x1a5b0025, 0xed4e00a1, 0x3f890145, 0x00000000}},  // [530] اشرة_, ٹھی_, _idau_,
  { {0x645a028c, 0x7aed04be, 0x657a00ab, 0x00000000}},  //   _outi, ryat, _neth,
  { {0xe8e000ad, 0x2bc4024c, 0xfbdf0011, 0x00000000}},  //   ười_, _लोका, _siêu_,
  { {0x317e04d6, 0x473500ed, 0x657a0016, 0x00000000}},  //   hatz_, онес, _aeth,
  { {0x657a0016, 0x6aa400f4, 0x3f890020, 0x00000000}},  //   _beth, ctif, _mdau_,
  { {0x645a04d7, 0x25a90166, 0x1958007e, 0x00000000}},  //   _buti, đalo_, _гары_,
  { {0x69d50428, 0x645a001a, 0x6d570061, 0x00000000}},  //   _inze, _cuti, _mgxa,
  { {0xfbdf001d, 0x69c504d8, 0x645a04d9, 0x00000000}},  //   _tiêu_, ldhe, _duti,
  { {0x6fdd04da, 0xdb1d00dc, 0x657a04db, 0x00000000}},  //   यानं, _insó, _feth,
  { {0x645a0052, 0x657a04dc, 0x80a904dd, 0x00000000}},  //   _futi, _geth, авов_,
  { {0xf99201f8, 0x645a04de, 0x69c504df, 0x00000000}},  //   ורי_, _guti, idhe,
  { {0x7a3004e0, 0x777b00f4, 0x81bc0089, 0x00000000}},  //   lätt, _jeux, slēp,
  { {0xeef5008b, 0x3f89018e, 0x645a0032, 0x00000000}},  //   пярэ, _ddau_, _zuti,
  { {0x317e0061, 0x20190093, 0x63a901a2, 0x00000000}},  //   catz_, ansi_, lfen,
  { {0xb1470014, 0x68e301a2, 0x442f0022, 0x00000000}},  //   _دیدم_, ändl, _kkg_,
  { {0x69d5001f, 0x26cd00e0, 0x6aa40197, 0x00000000}},  //   _anze, _oreo_, ttif,
  { {0x6aa400ab, 0x7bc4006c, 0xb4b6007d, 0x00000000}},  // [540] utif, rdiu, _छन्_,
  { {0x8eb3026c, 0xe9d701e1, 0x69c50250, 0x00000000}},  //   _کمیش, оку_, gdhe,
  { {0xd91004e1, 0x02b60309, 0x9dd701ce, 0x00000000}},  //   ریر_, _अन्न, _וויק_,
  { {0x645a001a, 0x5fdd0061, 0x657a04e2, 0x00000000}},  //   _ruti, यायल, _seth,
  { {0x26cd0219, 0x645a010a, 0x777b00f4, 0x00000000}},  //   _creo_, _suti, _deux,
  { {0x645a04e3, 0x7c36000c, 0x63a904e4, 0x00000000}},  //   _puti, llyr, efen,
  { {0x63a904e5, 0x6fca0164, 0x442f04e6, 0x00000000}},  //   ffen, ियां, _bkg_,
  { {0x657a00bb, 0x63a90016, 0x044300ed, 0x00000000}},  //   _weth, gfen, мејн,
  { {0x442f04e7, 0x657a0322, 0x00000000, 0x00000000}},  //   _dkg_, _teth,   ,
  { {0x645a0232, 0x238c0006, 0x51f803e8, 0x00000000}},  //   _tuti, dėjų_, сною_,
  { {0x645a021e, 0x4254007a, 0x69db0061, 0x00000000}},  //   _uuti, _کنتر, नाती,
  { {0x317e010f, 0x442f01e5, 0x00000000, 0x00000000}},  //   satz_, _gkg_,   ,
  { {0x41e6007e, 0x53160014, 0x00000000, 0x00000000}},  //   _міка, _بذار,   ,
  { {0x81f804e8, 0x386a00fa, 0x3f8401e5, 0x00000000}},  //   _دفتر_, _otbr_, ómur_,
  { {0x271c001d, 0x644204e9, 0x71260025, 0x00000000}},  //   ỉnh_, _khoi, _برشل,
  { {0x3eb20045, 0xdfd10025, 0x929d00b4, 0x00000000}},  //   _fpyt_, _أية_, szłe,
  { {0x8af0006b, 0x64420051, 0x69c50023, 0x00000000}},  // [550] dcəs, _mhoi, tdhe,
  { {0x78a5009f, 0x00000000, 0x00000000, 0x00000000}},  //   tthv,   ,   ,
  { {0x69c504ea, 0x9f40000c, 0x26cd04eb, 0x00000000}},  //   rdhe, _hlið_, _sreo_,
  { {0x78a500ea, 0x76410023, 0x69c50023, 0x00000000}},  //   rthv, _shly, sdhe,
  { {0x7c2d002d, 0x7bda009b, 0x7a3004ec, 0x00000000}},  //   moar, _הקרו, tätt,
  { {0x7c2d000d, 0x26cd001a, 0x290704ed, 0x00000000}},  //   loar, _vreo_, únas_,
  { {0x7a3004ee, 0x6ab9006b, 0x442f01a3, 0x00000000}},  //   rätt, şafı, _pkg_,
  { {0x7a3004ee, 0x57b404ef, 0x644204f0, 0x00000000}},  //   sätt, _обст, _choi,
  { {0xd5bb04f1, 0x63a904f2, 0x64420051, 0x00000000}},  //   _все_, rfen, _dhoi,
  { {0xdb0d04f3, 0x7c2d04f4, 0x00000000, 0x00000000}},  //   ndañ, hoar,   ,
  { {0xf99200bd, 0x6442002a, 0x7c2d022b, 0x00000000}},  //   ערט_, _fhoi, koar,
  { {0xa3bb0070, 0xb4d7007d, 0x7f8500a1, 0x00000000}},  //   _خاطر_, ामी_, ولپن,
  { {0x7c2d04f5, 0x644900f4, 0xdb1d04f6, 0x00000000}},  //   doar, mmei, _basí,
  { {0x64490181, 0x238c007f, 0x8b0800b4, 0x00000000}},  //   lmei, rėjų_, nięż,
  { {0x7c2d04f7, 0xe6b8013d, 0x7c3a009d, 0x00000000}},  //   foar, _इन्ज, îtro,
  { {0x442d0253, 0x7c2d04f8, 0x1e8604f9, 0x00000000}},  //   noe_, goar, _елим,
  { {0x3f8201a3, 0x00000000, 0x00000000, 0x00000000}},  // [560] maku_,   ,   ,
  { {0x3f8204fa, 0x644904fb, 0xdcfc04fc, 0x00000000}},  //   laku_, hmei, larč,
  { {0x53bd0164, 0x442d04fd, 0x23bd0309, 0x00000000}},  //   ्याश, koe_, ्याद,
  { {0x442d0066, 0x7a30010f, 0xdb1d00b9, 0x00000000}},  //   joe_, täts, _zasí,
  { {0x5fdd001c, 0x442d0112, 0x644904fe, 0x00000000}},  //   यातल, doe_, dmei,
  { {0x7bc604ff, 0xe5340500, 0x3f8200b0, 0x00000000}},  //   _haku, мель, haku_,
  { {0x6442002a, 0x7bc6011c, 0x64490501, 0x00000000}},  //   _phoi, _kaku, fmei,
  { {0x2937007b, 0x7bc60502, 0x442d0035, 0x00000000}},  //   _זאלן_, _jaku, goe_,
  { {0x7bc60503, 0x31650061, 0x3f8201a3, 0x00000000}},  //   _maku, fclz_, daku_,
  { {0x7bc604cb, 0x7c2d04f8, 0x6e2e00f8, 0x00000000}},  //   _laku, zoar, jobb,
  { {0x6442002a, 0x442d046a, 0x6e2e0197, 0x00000000}},  //   _thoi, boe_, dobb,
  { {0x7bc601d9, 0x7c2d002d, 0xdcfc0107, 0x00000000}},  //   _naku, xoar, garč,
  { {0x63a20472, 0x7c2d001a, 0xdb0d00c4, 0x00000000}},  //   _icon, voar, meaç,
  { {0x91e30216, 0x611402a8, 0x7bc60058, 0x00000000}},  //   _поче, _одлу, _aaku,
  { {0x7c2d000d, 0x7bc60504, 0xdcfc0505, 0x00000000}},  //   toar, _baku, barč,
  { {0x7bc60093, 0x2c0d0061, 0x61ea0506, 0x00000000}},  //   _caku, _सगळं_, _hofl,
  { {0x7c2d002d, 0x4a55007e, 0x7bc60142, 0x00000000}},  // [570] roar, дкас, _daku,
  { {0x68380224, 0x7c2d0507, 0x7e6d0508, 0x00000000}},  //   bídk, soar, _itap,
  { {0x2d830509, 0x7c2d001a, 0x41ae0309, 0x00000000}},  //   maje_, poar, ज्यस,
  { {0x27e9009f, 0x2d9c0073, 0x2d83050a, 0x00000000}},  //   ðan_, _över_, laje_,
  { {0x6fa503d7, 0x442d016c, 0x7e69001a, 0x00000000}},  //   _कानू, voe_, _împă,
  { {0x63a2050b, 0x7bc60046, 0x2d830211, 0x00000000}},  //   _acon, _zaku, naje_,
  { {0x442d050c, 0x7bc60453, 0x6449050d, 0x00000000}},  //   toe_, _yaku, tmei,
  { {0x69c70190, 0x2d83000a, 0x63a20009, 0x00000000}},  //   _haje, haje_, _ccon,
  { {0x69c7050e, 0x6449010f, 0xdcfc050f, 0x00000000}},  //   _kaje, rmei, varč,
  { {0xa8790049, 0x3f8201a3, 0x78a10510, 0x00000000}},  //   ֿאָר, waku_, _älvs,
  { {0x69c70161, 0x9327025a, 0x3f8201a3, 0x00000000}},  //   _maje, _کران, taku_,
  { {0x63a20051, 0x69c70511, 0x683801dc, 0x00000000}},  //   _gcon, _laje, vídk,
  { {0x7bc60512, 0x3f820513, 0x63bb00e7, 0x00000000}},  //   _raku, raku_, meun,
  { {0x7bc60209, 0x69c70514, 0x2d8301aa, 0x00000000}},  //   _saku, _naje, gaje_,
  { {0x7bc60515, 0x6e2e0516, 0xed570517, 0x00000000}},  //   _paku, robb, дор_,
  { {0x8c4300e2, 0x6e2e0026, 0xf3f80089, 0x00000000}},  //   весе, sobb, _kuģa_,
  { {0x7bc600b0, 0x69c70518, 0xc22200a1, 0x00000000}},  // [580] _vaku, _baje, _سکیو,
  { {0x7bc6000b, 0x68380181, 0x7c290091, 0x00000000}},  //   _waku, mídi, čera,
  { {0x7bc60127, 0x69c70213, 0x1c46003b, 0x00000000}},  //   _taku, _daje, _оном,
  { {0x63bb00f4, 0x00000000, 0x00000000, 0x00000000}},  //   jeun,   ,   ,
  { {0xa3e10164, 0x69c70519, 0x6b840048, 0x00000000}},  //   दान_, _faje, maig,
  { {0x6b84002a, 0x69c7051a, 0x63a2051b, 0x00000000}},  //   laig, _gaje, _scon,
  { {0x63a20009, 0x628f00fa, 0x61ea0095, 0x00000000}},  //   _pcon, ácon, _rofl,
  { {0x69c70119, 0x6b84002a, 0x2d830211, 0x00000000}},  //   _zaje, naig, zaje_,
  { {0x2d8301aa, 0x752d005a, 0xdb0d00fa, 0x00000000}},  //   yaje_, ğaza, reaç,
  { {0x27e6021e, 0x6b84051c, 0x24f6007c, 0x00000000}},  //   ljon_, haig, _очер,
  { {0x2d830470, 0xd4c60439, 0x6b8400e0, 0x00000000}},  //   vaje_, _تغذي, kaig,
  { {0x68e3051d, 0x2d83051e, 0x6e95051f, 0x00000000}},  //   ändi, waje_, ниму,
  { {0x6b840051, 0x2d830213, 0xfe6e025a, 0x00000000}},  //   daig, taje_, یگی_,
  { {0x61ac0044, 0x00000000, 0x00000000, 0x00000000}},  //   _কোরআ,   ,   ,
  { {0x2d830520, 0x6b840051, 0x69c70253, 0x00000000}},  //   raje_, faig, _raje,
  { {0x2d83000d, 0xa0080054, 0x20020521, 0x00000000}},  //   saje_, _يقول_, chki_,
  { {0x2d830522, 0x7e6d0523, 0x68380181, 0x00000000}},  // [590] paje_, _utap, cídi,
  { {0x2fc900b5, 0xdb1d0524, 0x00000000, 0x00000000}},  //   _haag_, _casá,   ,
  { {0x6b84010a, 0x61e70039, 0x26c4002d, 0x00000000}},  //   baig, öjli, _asmo_,
  { {0x2d810525, 0x69c70526, 0x2fc90007, 0x00000000}},  //   _hehe_, _waje, _jaag_,
  { {0xdb1d0527, 0x2fc90168, 0x69c70528, 0x00000000}},  //   _ansö, _maag_, _taje,
  { {0x7a2b010f, 0x2fc901b5, 0xa594005e, 0x00000000}},  //   hütz, _laag_, връщ,
  { {0x63bb015c, 0x6fa50061, 0x2d81006c, 0x00000000}},  //   teun, _काढू, _mehe_,
  { {0x321e013e, 0x2d81006c, 0x75fd0173, 0x00000000}},  //   enty_, _lehe_, _dèza,
  { {0xc6a40081, 0x63bb010f, 0xb06500b0, 0x00000000}},  //   _архи, reun, kyää,
  { {0xddc40091, 0x63bb0529, 0xdb0400c4, 0x00000000}},  //   _otiš, seun, nfiá,
  { {0x27ed00bb, 0x83fc0091, 0x932400a2, 0x00000000}},  //   _koen_, _suđe, فرین,
  { {0x6838052a, 0x321e0022, 0x00000000, 0x00000000}},  //   tídi, anty_,   ,
  { {0x2d81002d, 0x2fc9052b, 0x6b84052c, 0x00000000}},  //   _behe_, _daag_, vaig,
  { {0x6838052d, 0x27ff018e, 0x11d90025, 0x00000000}},  //   rídi, _llun_, _روعة_,
  { {0x6b84052e, 0xc5f2052f, 0x62860530, 0x00000000}},  //   taig, נדל_, škot,
  { {0x27ed0292, 0x64590009, 0x683800fa, 0x00000000}},  //   _noen_, _jiwi, pídi,
  { {0x64590020, 0x6b840531, 0x62890056, 0x00000000}},  // [5a0] _miwi, raig, nseo,
  { {0x6b84002a, 0x2d81010f, 0x27ff0532, 0x00000000}},  //   saig, _gehe_, _alun_,
  { {0xdb1d0010, 0x7d7b009b, 0x6b840533, 0x00000000}},  //   _vasá, _מניו, paig,
  { {0x27ed00bb, 0xc6a60534, 0x25a5005b, 0x00000000}},  //   _coen_, ерки, _acll_,
  { {0x27ed0100, 0x79850009, 0x27e60232, 0x00000000}},  //   _doen_, bahw, rjon_,
  { {0x27e60535, 0x25a500f6, 0x3e660082, 0x00000000}},  //   sjon_, _ccll_, _môt_,
  { {0x69dc0536, 0x20000026, 0x8cd3013d, 0x00000000}},  //   _inre, _olii_, डियो,
  { {0xb5fd049c, 0x3447007e, 0xafdb00ea, 0x00000000}},  //   _ruše, нчын_, nmøt,
  { {0xb5fd040d, 0xf1db0061, 0x64590537, 0x00000000}},  //   _suše, बांन, _diwi,
  { {0x44ce0036, 0x171b0049, 0x22580538, 0x00000000}},  //   _tę_, _זומע, örk_,
  { {0x7a2b010f, 0x5a17009b, 0x00000000, 0x00000000}},  //   tütz, תקין_,   ,
  { {0x2d81010f, 0x00000000, 0x00000000, 0x00000000}},  //   _sehe_,   ,   ,
  { {0x69dc00c7, 0xee3f0062, 0x2fc90539, 0x00000000}},  //   _onre, stým_, _vaag_,
  { {0xb5fd00ca, 0x6286053a, 0x2fc90007, 0x00000000}},  //   _tuše, škos, _waag_,
  { {0x9c470147, 0x765a0006, 0x11e90025, 0x00000000}},  //   ехал, _mity, _تعني_,
  { {0x69dc053b, 0x765a0173, 0xc1780006, 0x00000000}},  //   _anre, _lity, lbė_,
  { {0x5a35053c, 0xa3e101f5, 0x2d8100e7, 0x00000000}},  // [5b0] внат, दात_, _tehe_,
  { {0x27ed0007, 0x61fa053d, 0x00000000, 0x00000000}},  //   _soen_, nktl,   ,
  { {0xe611025a, 0x27ed0016, 0xdcfc0089, 0x00000000}},  //   یشت_, _poen_, parā,
  { {0x69dc053e, 0x87e4053f, 0xe7190025, 0x00000000}},  //   _enre, люче, ويات_,
  { {0xf7700188, 0x7bdd00ab, 0x765a0540, 0x00000000}},  //   صان_, _insu, _bity,
  { {0x765a0541, 0x0c74007a, 0xceb400a0, 0x00000000}},  //   _city, _جدید, ריס_,
  { {0x27ed02ae, 0xdb04009f, 0x6aad01e5, 0x00000000}},  //   _toen_, leið, ltaf,
  { {0xc447026c, 0x7bcd0542, 0x19580147, 0x00000000}},  //   ریشن_, ndau, _часы_,
  { {0x62890061, 0x24800091, 0x7c3a00f4, 0x00000000}},  //   useo, ćima_, îtri,
  { {0x929d0036, 0x64590093, 0x6289008a, 0x00000000}},  //   szło, _wiwi, rseo,
  { {0x7bdd0543, 0x628900ea, 0xdb04000c, 0x00000000}},  //   _onsu, sseo, heið,
  { {0xdb04000c, 0x6289010e, 0x00000000, 0x00000000}},  //   keið, pseo,   ,
  { {0x764800b0, 0x6d450145, 0x7bcd0544, 0x00000000}},  //   _yhdy, _azha, ddau,
  { {0x51870545, 0x7bdd01a3, 0x7af600b0, 0x00000000}},  //   _чуда, _ansu, vyyt,
  { {0x15f4013d, 0x6aad0546, 0xc223009e, 0x00000000}},  //   _अवसर_, etaf, _لکھو,
  { {0x7ae4002d, 0x3e660547, 0x7bcd0548, 0x00000000}},  //   txit, _tôt_, gdau,
  { {0xdfd2026c, 0x00000000, 0x00000000, 0x00000000}},  // [5c0] _ميں_,   ,   ,
  { {0xfe9b00b3, 0x7bdd0549, 0xafdb00ea, 0x00000000}},  //   _קיימ, _ensu, smøt,
  { {0x7e6400b0, 0x7af600b0, 0xeb9f0030, 0x00000000}},  //   _huip, syyt, _blød_,
  { {0x7e640020, 0x6601006c, 0x765a01aa, 0x00000000}},  //   _kuip, _allk, _sity,
  { {0x765a054a, 0x77910167, 0xc7a3017f, 0x00000000}},  //   _pity, صیلا, ричк,
  { {0x6838054b, 0x69dc01ac, 0x9633007e, 0x00000000}},  //   vídu, _unre, аніц,
  { {0x7e64054c, 0x32050022, 0xeb9f0190, 0x00000000}},  //   _luip, dhly_, _flød_,
  { {0x59e00061, 0x2cba0085, 0xeb9f0146, 0x00000000}},  //   नावर, _mppd_, _glød_,
  { {0x2a660048, 0x2cba0093, 0xd403054d, 0x00000000}},  //   íobh_, _lppd_, рящи,
  { {0x320500ab, 0x7bcd007f, 0x00000000, 0x00000000}},  //   ghly_, zdau,   ,
  { {0xa99b0049, 0x68380181, 0x61fa054e, 0x00000000}},  //   וביר, sídu, rktl,
  { {0xc058008b, 0x66180062, 0x2d87012d, 0x00000000}},  //   кія_, livk, _žne_,
  { {0xa294007e, 0x44260093, 0x672901f3, 0x00000000}},  //   _салі, _ijo_, _xxej,
  { {0x2731001d, 0xdb04000c, 0x32050142, 0x00000000}},  //   ỡng_, veið, chly_,
  { {0x4426008d, 0xab950088, 0xd042006b, 0x00000000}},  //   _kjo_, ливі, hvlə,
  { {0x6aad054f, 0xb5fd0550, 0xa4b7009b, 0x00000000}},  //   ttaf, _muša, כללה_,
  { {0xab840551, 0x20190552, 0x7e640553, 0x00000000}},  // [5d0] руск, misi_, _guip,
  { {0x20190554, 0x6aad0555, 0xdb04000c, 0x00000000}},  //   lisi_, rtaf, reið,
  { {0x6aad014a, 0x44260556, 0x67d500ed, 0x00000000}},  //   staf, _ojo_, ложу,
  { {0x7bdd033b, 0xc794008b, 0x20190557, 0x00000000}},  //   _unsu, аршы, nisi_,
  { {0x4b7a019b, 0x3a8400a5, 0xa3e10309, 0x00000000}},  //   _ראשו, _высв, दास_,
  { {0xd1260558, 0x4426008d, 0x2019000b, 0x00000000}},  //   _هم_, _ajo_, hisi_,
  { {0x2019014a, 0x44260559, 0x64b50426, 0x00000000}},  //   kisi_, _bjo_, احتر,
  { {0xb5fd055a, 0x2019055b, 0x6e35055c, 0x00000000}},  //   _duša, jisi_, hozb,
  { {0xe3b60147, 0x55a500a1, 0x4426055d, 0x00000000}},  //   убы_, _مجاہ, _djo_,
  { {0x4426055e, 0x00000000, 0x00000000, 0x00000000}},  //   _ejo_,   ,   ,
  { {0x201904cd, 0x7c2901ae, 0x7e64055f, 0x00000000}},  //   fisi_, čerj, _suip,
  { {0xc50c0049, 0xbb1b0035, 0x20190560, 0x00000000}},  //   _קלאָ, _reîn, gisi_,
  { {0x443f0561, 0xd24e0063, 0x7e64009d, 0x00000000}},  //   mlu_, تنی_, _quip,
  { {0x443f0562, 0x831a007b, 0x22920025, 0x00000000}},  //   llu_, _אונז, _الوس,
  { {0x20190563, 0x443f006c, 0x00000000, 0x00000000}},  //   bisi_, olu_,   ,
  { {0x66180107, 0x443f0564, 0x20190565, 0x00000000}},  //   zivk, nlu_, cisi_,
  { {0x443f021e, 0x9e5a005e, 0x8c4300e3, 0x00000000}},  // [5e0] ilu_, _проф_, сете,
  { {0x443f0566, 0x7a3001a2, 0xd839000a, 0x00000000}},  //   hlu_, lätz, _akō_,
  { {0x443f0567, 0x3ea20568, 0x00000000, 0x00000000}},  //   klu_, lukt_,   ,
  { {0x2bab01f5, 0x2d8a0569, 0xdc9b00b3, 0x00000000}},  //   _छाया, labe_, _איטל,
  { {0x443f056a, 0x6006056b, 0x68e30039, 0x00000000}},  //   dlu_, _góme, ändr,
  { {0x7c24001a, 0x7a30010f, 0x443f056c, 0x00000000}},  //   lnir, hätz, elu_,
  { {0x5faa0061, 0x443f056d, 0x2955005e, 0x00000000}},  //   _काढल, flu_, _вътр,
  { {0x69ce056e, 0x443f000c, 0x7c24056f, 0x00000000}},  //   _habe, glu_, nnir,
  { {0x2d8a0570, 0x6b86012d, 0x629b0006, 0x00000000}},  //   kabe_, _mekg, gruo,
  { {0x69ce002d, 0x32b70025, 0x201900e7, 0x00000000}},  //   _jabe, ادية_, wisi_,
  { {0x443f0571, 0x69ce0572, 0x2019023a, 0x00000000}},  //   blu_, _mabe, tisi_,
  { {0x443f02a4, 0x69ce0573, 0x9f49000c, 0x00000000}},  //   clu_, _labe, _blað_,
  { {0xa3e102f4, 0x2019011f, 0x80ca0044, 0x00000000}},  //   दार_, risi_, িমধ্,
  { {0x20190574, 0xd25001b7, 0x2d8a010f, 0x00000000}},  //   sisi_, _بنت_, gabe_,
  { {0x201902db, 0x0217009b, 0xafdb0030, 0x00000000}},  //   pisi_, _תחום_, rløb,
  { {0xfbdf001d, 0x69ce0030, 0x44240173, 0x00000000}},  //   _thêm_, _aabe, nnm_,
  { {0x7c3f001c, 0x3f8b008a, 0x69ce0575, 0x00000000}},  // [5f0] rlqr, macu_, _babe,
  { {0x69ce0576, 0x3b54005e, 0x443f0279, 0x00000000}},  //   _cabe, скур, zlu_,
  { {0x69ce0577, 0x443f0578, 0xb5fd016c, 0x00000000}},  //   _dabe, ylu_, _bušn,
  { {0x8d74007a, 0x443f006b, 0x7c240579, 0x00000000}},  //   _پایا, xlu_, cnir,
  { {0xb5fd057a, 0x66e50478, 0x443f0095, 0x00000000}},  //   _dušn, рола, vlu_,
  { {0x69ce002d, 0x00000000, 0x00000000, 0x00000000}},  //   _gabe,   ,   ,
  { {0x2aaf006b, 0x3dd70044, 0x3f8b0107, 0x00000000}},  //   lüb_, _সকাল, kacu_,
  { {0x69ce0027, 0x7bcf057b, 0x3f8b057c, 0x00000000}},  //   _zabe, _jacu, jacu_,
  { {0x443f020c, 0x49190061, 0x020501fc, 0x00000000}},  //   rlu_, _येतो_, изин,
  { {0x443f009f, 0xd24e057d, 0x7bcf001a, 0x00000000}},  //   slu_, وني_, _lacu,
  { {0x443f057e, 0x6faa0061, 0x7bcf057f, 0x00000000}},  //   plu_, _कादं, _oacu,
  { {0xdcfe0089, 0xc059007e, 0x3f8b0064, 0x00000000}},  //   _nepā, ліў_, gacu_,
  { {0x91e5003b, 0xf38c0049, 0x2d8a0032, 0x00000000}},  //   _воле, _טראָ, tabe_,
  { {0x44d50580, 0x7a30001f, 0xee370581, 0x00000000}},  //   _kā_, sätz, иня_,
  { {0x2d8a01d9, 0x44d5001e, 0x3f8b0582, 0x00000000}},  //   rabe_, _jā_, bacu_,
  { {0x7bcf00fa, 0x3f8b00fa, 0x00000000, 0x00000000}},  //   _cacu, cacu_,   ,
  { {0x7c240583, 0xfaa60057, 0xcb0003d7, 0x00000000}},  // [600] rnir, разо, लैंड_,
  { {0x69ce01d5, 0x7bcf0584, 0x2d96005e, 0x00000000}},  //   _qabe, _eacu, _трис,
  { {0x7bcf0585, 0x44c70010, 0x08c601ee, 0x00000000}},  //   _facu, _nő_, рбен,
  { {0x7bcf0020, 0xf0b60049, 0x69ce0586, 0x00000000}},  //   _gacu, ילער_, _wabe,
  { {0x69ce049a, 0x7bc40035, 0x00000000, 0x00000000}},  //   _tabe, meiu,   ,
  { {0xa61301fb, 0x3f8b0587, 0x96f700ed, 0x00000000}},  //   оміч, zacu_, решт_,
  { {0x291e0039, 0x64aa006b, 0xb5fd016c, 0x00000000}},  //   _äta_, _rəis, _tušn,
  { {0x07a30545, 0xf3f801c5, 0x00000000, 0x00000000}},  //   _масн, _kuģi_,   ,
  { {0x3f8b0107, 0x41e6007e, 0x5214007c, 0x00000000}},  //   vacu_, аіна, йдит,
  { {0x44c70010, 0x3f8b0045, 0x00000000, 0x00000000}},  //   _fő_, wacu_,   ,
  { {0x7e760387, 0x3f8b01ee, 0xf993009b, 0x00000000}},  //   _atyp, tacu_, חרת_,
  { {0xb5fc0066, 0x6aa4050c, 0x7e760045, 0x00000000}},  //   _diġe, kuif, _btyp,
  { {0x7bcf0588, 0xc7b3009b, 0x3f8b012d, 0x00000000}},  //   _racu, חבר_, racu_,
  { {0x7bcf0107, 0x27230011, 0x3f8b0521, 0x00000000}},  //   _sacu, ằng_, sacu_,
  { {0x40940025, 0x7bcf04aa, 0x4c94007c, 0x00000000}},  //   _البر, _pacu, жисс,
  { {0x95fe0044, 0x7e760009, 0x3ced0091, 0x00000000}},  //   ্চিম_, _ftyp, ćev_,
  { {0x99670589, 0x7bcf058a, 0xddcd002b, 0x00000000}},  // [610] ател, _vacu, _kważ,
  { {0x2aaf006b, 0x69a70061, 0x2b850082, 0x00000000}},  //   rüb_, _चाळी, ặc_,
  { {0x7bcf058b, 0xc7c7058c, 0x00000000, 0x00000000}},  //   _tacu, исди,   ,
  { {0xf7f40014, 0x7bc4001a, 0x5f0a0044, 0x00000000}},  //   يسند, ceiu, রপরও_,
  { {0xa3ea0164, 0xd6d90046, 0x09cf0044, 0x00000000}},  //   मान_, _była_, রাবা,
  { {0x6b8d006c, 0xb8cd0044, 0x00000000, 0x00000000}},  //   laag, _কন_,   ,
  { {0x69c5006c, 0xcd98009b, 0x18a4007e, 0x00000000}},  //   mehe, בדות_, _маём,
  { {0x69c50004, 0x6b8d011c, 0x53c9058d, 0x00000000}},  //   lehe, naag, угим_,
  { {0x6006004a, 0xe5c7058e, 0x00000000, 0x00000000}},  //   _nóma, _всео,   ,
  { {0xa205058f, 0x44d5001e, 0x69c50056, 0x00000000}},  //   спод, _tā_, nehe,
  { {0x3f8900f4, 0x7e760590, 0x6b8d0058, 0x00000000}},  //   _beau_, _styp, kaag,
  { {0x69c50591, 0xdb040592, 0x6b8d0112, 0x00000000}},  //   hehe, rfiú, jaag,
  { {0x6b8d00c7, 0x69c5003f, 0x237f0065, 0x00000000}},  //   daag, kehe, mbuj_,
  { {0x63a90376, 0x3f9e014a, 0x69c50065, 0x00000000}},  //   lgen, ştu_, jehe,
  { {0x61e30593, 0xeb9a0594, 0x1d070595, 0x00000000}},  //   _innl, лив_, бери_,
  { {0x63a90596, 0x78a50107, 0x60dc0030, 0x00000000}},  //   ngen, duhv, ærme,
  { {0x63a9010f, 0xfe720025, 0xb5fd0087, 0x00000000}},  // [620] igen, _عدة_, _pušl,
  { {0x69c50597, 0x443d0598, 0x20020052, 0x00000000}},  //   gehe, _lkw_, lkki_,
  { {0xa3d703d7, 0x395c0039, 0xdcfe001a, 0x00000000}},  //   ाया_, ävs_, _depă,
  { {0x6b8d001c, 0x2002021e, 0x07a6003b, 0x00000000}},  //   caag, nkki_, садн,
  { {0xadec03d7, 0x69c50599, 0x6aa4059a, 0x00000000}},  //   ञापन_, behe, quif,
  { {0x63a9059b, 0xb8660439, 0x69c5059c, 0x00000000}},  //   egen, _هارو, cehe,
  { {0x18a3007e, 0x63a9010f, 0x7d7b0049, 0x00000000}},  //   _нарм, fgen, אנצו,
  { {0x63a9059d, 0x68150036, 0x3a3a0039, 0x00000000}},  //   ggen, ządz, lopp_,
  { {0x443d01d6, 0x78bb012d, 0xfbd3009b, 0x00000000}},  //   _dkw_, _ćuvi, לתה_,
  { {0x63a9059e, 0xd9cf0044, 0x60060092, 0x00000000}},  //   agen, রাথম, _róma,
  { {0x3f8900f4, 0x63a902c2, 0xb5fc0066, 0x00000000}},  //   _peau_, bgen, _tiġb,
  { {0x82a601e0, 0x61e300ea, 0x3a3a00f8, 0x00000000}},  //   _гадж, _ennl, hopp_,
  { {0x3f89009d, 0x3a3a059f, 0xddcd05a0, 0x00000000}},  //   _veau_, kopp_, _ataš,
  { {0xddcd0036, 0x6b8d00e7, 0x00000000, 0x00000000}},  //   _uważ, waag,   ,
  { {0x69c50010, 0x6b8d05a1, 0x00000000, 0x00000000}},  //   vehe, taag,   ,
  { {0x321e05a2, 0x600605a3, 0x27e400e0, 0x00000000}},  //   lity_, _tóma, _nnmn_,
  { {0x69c5010f, 0x6b8d01b5, 0xfaff0065, 0x00000000}},  // [630] tehe, raag, _afër_,
  { {0x996705a4, 0x321e0038, 0xddab05a5, 0x00000000}},  //   стал, nity_, _стил_,
  { {0x63a905a6, 0x094b05a7, 0x69c505a8, 0x00000000}},  //   ygen, учаи_, rehe,
  { {0x69c5001f, 0xb8f10316, 0xad1a00b6, 0x00000000}},  //   sehe, _वन_, _כותר,
  { {0x63a9013f, 0x8f9c0104, 0x00000000, 0x00000000}},  //   vgen, רידי,   ,
  { {0x2009018e, 0x00000000, 0x00000000, 0x00000000}},  //   _llai_,   ,   ,
  { {0x63a90270, 0x2002000c, 0x321e05a9, 0x00000000}},  //   tgen, ykki_, dity_,
  { {0x6683026c, 0xdb0d0211, 0x5fd90061, 0x00000000}},  //   _فیصل, leañ, _बोलल,
  { {0x2329019d, 0x4209003b, 0xb5fd05a0, 0x00000000}},  //   ропи_, инио_, _jušk,
  { {0xb5fd0119, 0x63a90168, 0x3125007c, 0x00000000}},  //   _mušk, sgen, ждог,
  { {0xd12e00a1, 0x443d0093, 0x200905aa, 0x00000000}},  //   ہمی_, _tkw_, _blai_,
  { {0xa3ea02f4, 0xb4d5006e, 0x2009005b, 0x00000000}},  //   माण_, िटी_, _clai_,
  { {0xe2da026c, 0x200200b0, 0xb5fd05ab, 0x00000000}},  //   _پانچ_, rkki_, _nušk,
  { {0x2738001d, 0x321e05ac, 0x27e00089, 0x00000000}},  //   ứng_, city_, ķini_,
  { {0xed5a0057, 0xdbc7009f, 0x20090026, 0x00000000}},  //   ров_, töðu, _flai_,
  { {0xc4d200b3, 0x1c4601ff, 0x20040089, 0x00000000}},  //   וגל_, інам, ījis_,
  { {0xa3ea0061, 0x3a3a05ad, 0x00000000, 0x00000000}},  // [640] मात_, topp_,   ,
  { {0xb5fd04eb, 0x497a007e, 0xc18c0049, 0x00000000}},  //   _dušk, рсаў_, ָטאָ,
  { {0xd6d90046, 0x6e3c001b, 0x3a3a00f8, 0x00000000}},  //   _było_, morb, ropp_,
  { {0x2d9a05ae, 0x3a3a0145, 0x6e3c05af, 0x00000000}},  //   _hdpe_, sopp_, lorb,
  { {0x628600b9, 0x00000000, 0x00000000, 0x00000000}},  //   škoz,   ,   ,
  { {0xd49a00d7, 0x2ba803d7, 0x321e0133, 0x00000000}},  //   ари_, गलवा, xity_,
  { {0x25a0011f, 0xd5ad026c, 0x321e05b0, 0x00000000}},  //   ğil_, اہم_, vity_,
  { {0x25a0014a, 0xaa7b01dc, 0x186700e2, 0x00000000}},  //   şil_, _frýd, _фати_,
  { {0x24890091, 0x6e3c0010, 0x6ab60036, 0x00000000}},  //   ćama_, korb, ntyf,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x321e0038, 0xb3ca026b, 0x104b007c, 0x00000000}},  //   rity_, _влез_, иями_,
  { {0x321e00ab, 0x7d03006b, 0x320c00e7, 0x00000000}},  //   sity_, _ünsi, shdy_,
  { {0x6e3c05b1, 0x7aed05b2, 0x185b0049, 0x00000000}},  //   forb, xxat, יכטע,
  { {0xf287026c, 0x6e3c0032, 0x00000000, 0x00000000}},  //   _بھٹو_, gorb,   ,
  { {0x48c50055, 0x3f820022, 0x00000000, 0x00000000}},  //   _এপ্র, bbku_,   ,
  { {0x7aed05b3, 0x61f800ea, 0x7e7d05b4, 0x00000000}},  //   txat, _hovl, ppsp,
  { {0x7f4d006b, 0x6e3c0232, 0x00000000, 0x00000000}},  // [650] _uzaq, borb,   ,
  { {0x527b007b, 0x386400e5, 0xc98405b5, 0x00000000}},  //   ינמא, _aimr_, дуци,
  { {0x2d9105b6, 0x2d830065, 0x81bc0089, 0x00000000}},  //   maze_, mbje_, tnēj,
  { {0x2d910119, 0x61f805b7, 0x80c40044, 0x00000000}},  //   laze_, _lovl, ষিপ্,
  { {0xeb760049, 0xb5fc0066, 0x00000000, 0x00000000}},  //   _מערץ_, _siġa,   ,
  { {0xe6180088, 0x2d910095, 0xb5fc01f3, 0x00000000}},  //   оді_, naze_, _piġa,
  { {0xf50505b8, 0x7e6d0093, 0x92aa0044, 0x00000000}},  //   язко, _luap, খবো_,
  { {0xfbdf0082, 0x6d4501a2, 0x00000000, 0x00000000}},  //   _thêu_, _myha,   ,
  { {0x69d5012b, 0x2d91041a, 0x29ff0036, 0x00000000}},  //   _kaze, kaze_, ałań_,
  { {0x11d50025, 0xddc40091, 0x69d50142, 0x00000000}},  //   ستخد, _stiž, _jaze,
  { {0x69d50006, 0x61f80035, 0xb5fd05b9, 0x00000000}},  //   _maze, _dovl, _nuši,
  { {0x69d50181, 0x6e3c01a2, 0x4429004a, 0x00000000}},  //   _laze, worb, _ña_,
  { {0x63bb05ba, 0x932704e8, 0x216905bb, 0x00000000}},  //   mfun, _بران, _лили_,
  { {0x2d8c05bc, 0x63bb00db, 0x2d9105bd, 0x00000000}},  //   úde_, lfun, gaze_,
  { {0xe166007a, 0x614205be, 0x6e3c040f, 0x00000000}},  //   _عضوی, _пеша, rorb,
  { {0x6e3c0010, 0xc4d2007b, 0xbc630072, 0x00000000}},  //   sorb, עגן_, евск,
  { {0x2fc0006a, 0x7e6d0211, 0x2d9105bf, 0x00000000}},  // [660] _ibig_, _guap, baze_,
  { {0x4a4305c0, 0xa3e202fb, 0x25db00e8, 0x00000000}},  //   енув, _फोन_, _गोली_,
  { {0x38b505c1, 0x63bb05c2, 0x9d460478, 0x00000000}},  //   går_, kfun, _хенд,
  { {0xde6d001d, 0xdb1d05c3, 0x83fc0166, 0x00000000}},  //   _hươn, _obsè, _tuđi,
  { {0x69d502d5, 0x6d40005a, 0x63bb00ea, 0x00000000}},  //   _faze, şmad, dfun,
  { {0x63bb01a2, 0x00000000, 0x00000000, 0x00000000}},  //   efun,   ,   ,
  { {0xdb0f028c, 0x63bb05c4, 0xdb1d00d4, 0x00000000}},  //   _accè, ffun, _absè,
  { {0xde6d001d, 0x6b840066, 0x02a60088, 0x00000000}},  //   _lươn, nbig, пром,
  { {0x81d50044, 0x93c800a1, 0x61f805c5, 0x00000000}},  //   হান_, ماکہ_, _povl,
  { {0xdb0d0181, 0xde6d0011, 0x909800ed, 0x00000000}},  //   sfaç, _nươn, овот_,
  { {0x6aa405c6, 0x733600a1, 0xd25000a1, 0x00000000}},  //   hrif, _کرائ, ٹنگ_,
  { {0xe45a05c7, 0x6aa405c8, 0x2ee00016, 0x00000000}},  //   _уже_, krif, _brif_,
  { {0xf2060265, 0xe2da00a1, 0x2ee003e2, 0x00000000}},  //   _няко, _دباؤ_, _crif_,
  { {0xde6d0011, 0x6aa40056, 0xd29b0104, 0x00000000}},  //   _cươn, drif, _פשוט,
  { {0xde6d001d, 0x69d505c9, 0xc1bb009b, 0x00000000}},  //   _dươn, _raze, _המוש,
  { {0x6aa4018e, 0x6b84006a, 0x69d5013e, 0x00000000}},  //   frif, gbig, _saze,
  { {0x6aa405ca, 0x69d50089, 0x8f9c009b, 0x00000000}},  // [670] grif, _paze, _היחי,
  { {0xde6d0011, 0x38b505cb, 0xb5fd016e, 0x00000000}},  //   _gươn, tår_, _tuši,
  { {0x6b840039, 0xe3c70006, 0x69d50471, 0x00000000}},  //   bbig, ščių_, _vaze,
  { {0x290701d5, 0x69d50020, 0x76410006, 0x00000000}},  //   ġna_, _waze, _skly,
  { {0x38b505cc, 0x29070340, 0x7c2d001a, 0x00000000}},  //   sår_, šna_, mnar,
  { {0xde6d0011, 0xb9c50257, 0x7c2d013f, 0x00000000}},  //   _xươn, _تقسي, lnar,
  { {0x7c2d049a, 0x24890091, 0x442f05cd, 0x00000000}},  //   onar, ćamo_, _pjg_,
  { {0xdb0f03d5, 0x7c2d05ce, 0x130902d3, 0x00000000}},  //   _accé, nnar, жний_,
  { {0x63bb008d, 0x7c2d05cf, 0x00000000, 0x00000000}},  //   rfun, inar,   ,
  { {0x3eab05d0, 0x6442002d, 0x7c2d010f, 0x00000000}},  //   duct_, _ekoi, hnar,
  { {0x7c2d000c, 0x63bb010f, 0x8fa602dc, 0x00000000}},  //   knar, pfun, мане,
  { {0x2ee0018e, 0x81b50044, 0xe3b00025, 0x00000000}},  //   _prif_, _চোখ_, _مره_,
  { {0xa3ea02fb, 0x7c2d0059, 0x644905d1, 0x00000000}},  //   मार_, dnar, mlei,
  { {0x443f05d2, 0x7c2d0032, 0x4df5007e, 0x00000000}},  //   lou_, enar, няст,
  { {0x442d05d3, 0xe1f005d4, 0x3eb902ae, 0x00000000}},  //   one_, _حسن_, atst_,
  { {0x442d05d5, 0x7c2d05d6, 0x644900db, 0x00000000}},  //   nne_, gnar, nlei,
  { {0x442d05d7, 0xde6d001d, 0xc05300b3, 0x00000000}},  // [680] ine_, _tươn, _בזה_,
  { {0x6aa405d8, 0x443f05d9, 0x2b8c001d, 0x00000000}},  //   rrif, hou_, ếc_,
  { {0x443f004f, 0x644905da, 0xc8ca0014, 0x00000000}},  //   kou_, klei, توان_,
  { {0x442d05db, 0x798e05dc, 0x443f05dd, 0x00000000}},  //   jne_, _webw, jou_,
  { {0x442d04a3, 0x443f004f, 0xb86502fd, 0x00000000}},  //   dne_, dou_, رامو,
  { {0x64490270, 0x44ce00b9, 0x443f01c3, 0x00000000}},  //   elei, _př_, eou_,
  { {0x443f01aa, 0x3e740039, 0x644905de, 0x00000000}},  //   fou_, _lät_, flei,
  { {0x442d02b6, 0x443f0181, 0x68e305df, 0x00000000}},  //   gne_, gou_, ænde,
  { {0x395100ca, 0x3e7400f8, 0x00000000, 0x00000000}},  //   _zzzs_, _nät_,   ,
  { {0x442d000d, 0x64490052, 0x7c2405e0, 0x00000000}},  //   ane_, alei, hiir,
  { {0x850600d3, 0x442d05e1, 0x64490129, 0x00000000}},  //   _توان, bne_, blei,
  { {0x443f05e2, 0x442d0027, 0x64490472, 0x00000000}},  //   cou_, cne_, clei,
  { {0x4424016c, 0x64400006, 0x25f50061, 0x00000000}},  //   mim_, momi, ्सची_,
  { {0x44240213, 0x60320089, 0x7c2d0050, 0x00000000}},  //   lim_, rāma, wnar,
  { {0x7c2d05e3, 0x7c2405e4, 0xb5fc0066, 0x00000000}},  //   tnar, fiir, _riġl,
  { {0x80c40044, 0x7c2d05e5, 0x2bdf00e8, 0x00000000}},  //   ষিদ্, unar, _पोशा,
  { {0x7c2d009f, 0xa3b6006e, 0xcd0400b9, 0x00000000}},  // [690] rnar, _जान_, vněž_,
  { {0x443f049a, 0x7c2d002d, 0x644004eb, 0x00000000}},  //   zou_, snar, homi,
  { {0x443f05e6, 0x442d0142, 0xb5fd016c, 0x00000000}},  //   you_, yne_, _mušt,
  { {0x44240119, 0x27e905e7, 0x64400006, 0x00000000}},  //   jim_, ñan_, jomi,
  { {0x442d05e8, 0x443f0428, 0x7bcd009d, 0x00000000}},  //   vne_, vou_, meau,
  { {0x442d0046, 0x443f01aa, 0x7bcd009d, 0x00000000}},  //   wne_, wou_, leau,
  { {0x6006002a, 0x644905e9, 0xe3b10025, 0x00000000}},  //   _fómh, tlei, هرة_,
  { {0x442d000d, 0x644005ea, 0x61ea05eb, 0x00000000}},  //   une_, gomi, _anfl,
  { {0x442d05ec, 0x644905ed, 0x63a605ee, 0x00000000}},  //   rne_, rlei, ókna,
  { {0x443f05ef, 0xe1f10054, 0x645b0051, 0x00000000}},  //   sou_, اسة_, smui,
  { {0x602600d7, 0x442d0027, 0x65940106, 0x00000000}},  //   една, pne_, _раху,
  { {0x644005f0, 0x4424055a, 0x61ea05f1, 0x00000000}},  //   comi, cim_, _enfl,
  { {0x7bcd05f2, 0x2ac30089, 0x7c2405e0, 0x00000000}},  //   deau, nībā_, viir,
  { {0xdd9205f3, 0x2c750030, 0xa3d7007d, 0x00000000}},  //   طور_, _båd_, ायक_,
  { {0x1b1d0055, 0xa3b6006e, 0x81d50044, 0x00000000}},  //   _ভুলে_, _जाम_, হাদ_,
  { {0x3e7404ce, 0x2c750146, 0x00000000, 0x00000000}},  //   _tät_, _dåd_,   ,
  { {0xf412007b, 0x600605f4, 0x1f660088, 0x00000000}},  // [6a0] אפן_, _nómi, _яким,
  { {0xe9d70099, 0x7c3b016c, 0x2ac30089, 0x00000000}},  //   нку_, čura, dībā_,
  { {0x442405f5, 0x7c24003c, 0x1bea05f6, 0x00000000}},  //   yim_, piir, _едни_,
  { {0x442405f7, 0x6440027b, 0x7bcd0068, 0x00000000}},  //   xim_, xomi, ceau,
  { {0x44240119, 0x6006008e, 0x644005f8, 0x00000000}},  //   vim_, _cómi, vomi,
  { {0x6b9600e0, 0x44240145, 0x644000b4, 0x00000000}},  //   layg, wim_, womi,
  { {0x442405f9, 0x64400036, 0x7c2f002a, 0x00000000}},  //   tim_, tomi, _áirí,
  { {0xb5fd05fa, 0xccf301f8, 0xd467012b, 0x00000000}},  //   _sušt, רכה_, није_,
  { {0x442405fb, 0x2ac3001e, 0xb5fd0091, 0x00000000}},  //   rim_, cībā_, _pušt,
  { {0x644005fc, 0x00000000, 0x00000000, 0x00000000}},  //   somi,   ,   ,
  { {0x644005fd, 0x2a6a0026, 0x64a301ee, 0x00000000}},  //   pomi, _mibb_, _баха,
  { {0x2c7505fe, 0x929d0036, 0x442405ff, 0x00000000}},  //   _råd_, syła, qim_,
  { {0x7bcd028c, 0xb5fd007f, 0x00000000, 0x00000000}},  //   veau, _tušt,   ,
  { {0x61ea0600, 0xaa7b000c, 0x00000000, 0x00000000}},  //   _unfl, _brýn,   ,
  { {0x7bcd0601, 0x71f700a1, 0x2ac301c5, 0x00000000}},  //   teau, _سروس_, zībā_,
  { {0x7c8400ed, 0x6b960009, 0x00000000, 0x00000000}},  //   ѓусе, gayg,   ,
  { {0x7bcd0602, 0x7b740025, 0x39a70603, 0x00000000}},  // [6b0] reau, اطفا, ешев,
  { {0x7bcd00f4, 0x13d90044, 0x49d80604, 0x00000000}},  //   seau, থায়, ндую_,
  { {0x48ab0605, 0x7bcd009d, 0x5d5502ea, 0x00000000}},  //   ятам_, peau, _шкот,
  { {0xfbab0057, 0x629d0010, 0x200b00b9, 0x00000000}},  //   _этой_, ások, nkci_,
  { {0x79a700ec, 0x6aad0197, 0xc66b007c, 0x00000000}},  //   _прве, quaf, чшее_,
  { {0x2a6a0606, 0x2ac30089, 0x600600dc, 0x00000000}},  //   _gibb_, rībā_, _vómi,
  { {0xda340147, 0x2ac30089, 0x2d9300c4, 0x00000000}},  //   _серы, sībā_, _mexe_,
  { {0x2a6a00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _zibb_,   ,   ,
  { {0x961d0089, 0x00000000, 0x00000000, 0x00000000}},  //   _atņe,   ,   ,
  { {0x85b800ed, 0x2d9300f6, 0x27ff000a, 0x00000000}},  //   _плус_, _nexe_, _houn_,
  { {0x7643011c, 0x27ff000a, 0x00000000, 0x00000000}},  //   mony, _koun_,   ,
  { {0x69c101f5, 0x27ff000a, 0x00000000, 0x00000000}},  //   र्ती, _joun_,   ,
  { {0x27ff0607, 0xa3b60183, 0x441a00a0, 0x00000000}},  //   _moun_, _जात_, _קונס,
  { {0x6b960190, 0x76430608, 0x00000000, 0x00000000}},  //   wayg, nony,   ,
  { {0xdcfc0089, 0x629b0006, 0x27ed0609, 0x00000000}},  //   varē, lsuo, _onen_,
  { {0x7ae90091, 0x7643060a, 0x27ff060b, 0x00000000}},  //   _šeta, hony, _noun_,
  { {0xee3a0057, 0xe9da01a4, 0xab27005e, 0x00000000}},  // [6c0] _они_, мка_, вота_,
  { {0x27ed0065, 0x00000000, 0x00000000, 0x00000000}},  //   _anen_,   ,   ,
  { {0x2d98001a, 0x27ff000a, 0x940c006b, 0x00000000}},  //   mare_, _boun_, _evdə_,
  { {0x2d98060c, 0x629b0006, 0x661d0006, 0x00000000}},  //   lare_, ksuo, _įska,
  { {0x76430093, 0x2a6a006b, 0x27ff0288, 0x00000000}},  //   fony, _tibb_, _doun_,
  { {0x7643060d, 0xe534060e, 0x27ed060f, 0x00000000}},  //   gony, лель, _enen_,
  { {0xb5fc002b, 0x2d9800ea, 0x69dc0288, 0x00000000}},  //   _jiġi, iare_, _iare,
  { {0x64590610, 0x2d980611, 0x69dc0612, 0x00000000}},  //   _chwi, hare_, _hare,
  { {0x69dc0390, 0x2d980073, 0xf5b4026c, 0x00000000}},  //   _kare, kare_, _مشاھ,
  { {0x69dc02ae, 0x2d980613, 0x69de0614, 0x00000000}},  //   _jare, jare_, ndpe,
  { {0x69dc000b, 0x2d980615, 0x27ff0263, 0x00000000}},  //   _mare, dare_, _youn_,
  { {0x69dc027b, 0x0326025f, 0x2d930616, 0x00000000}},  //   _lare, _иден, _sexe_,
  { {0xdcf5001e, 0x2d980617, 0x63a20207, 0x00000000}},  //   pazī, fare_, _idon,
  { {0x69dc0618, 0xc0aa00a6, 0x2d9801e2, 0x00000000}},  //   _nare, _قابل_, gare_,
  { {0x6d40005a, 0x7ae600ea, 0x20d30464, 0x00000000}},  //   şman, _arkt, _نتيج,
  { {0x76430619, 0xec340088, 0x69dc006c, 0x00000000}},  //   zony, ансь, _aare,
  { {0x81d50055, 0x69dc0209, 0x5a3500e3, 0x00000000}},  // [6d0] হার_, _bare, гнат,
  { {0x2d98061a, 0x69dc0038, 0x3f99061b, 0x00000000}},  //   care_, _care, lasu_,
  { {0x69dc0007, 0x63a2061c, 0x27ff01aa, 0x00000000}},  //   _dare, _odon, _poun_,
  { {0x63a2008d, 0xac190088, 0x69dc0032, 0x00000000}},  //   _ndon, _чому_, _eare,
  { {0xf770023c, 0x7643061d, 0x501c061e, 0x00000000}},  //   زان_, tony, וואו,
  { {0x63a20129, 0x69dc002d, 0x62720046, 0x00000000}},  //   _adon, _gare, _młod,
  { {0x7bdd061f, 0x7643031e, 0x5e580049, 0x00000000}},  //   _kasu, rony, דיגע_,
  { {0x69dc0620, 0x2d98000d, 0x27ed0621, 0x00000000}},  //   _zare, zare_, _unen_,
  { {0x7bdd0149, 0x76430622, 0x6113006b, 0x00000000}},  //   _masu, pony, mələ,
  { {0x386d0623, 0x6113005f, 0x63a2002d, 0x00000000}},  //   _hier_, lələ, _edon,
  { {0x2d980624, 0x629b0625, 0x7f4d006b, 0x00000000}},  //   vare_, ssuo, _ayaq,
  { {0x7bdd011c, 0x660100b9, 0x6113006b, 0x00000000}},  //   _nasu, _holk, nələ,
  { {0x66010626, 0x7ae90091, 0x765a00b0, 0x00000000}},  //   _kolk, _šetn, _yhty,
  { {0x6113005f, 0xddcd0627, 0x386d0628, 0x00000000}},  //   hələ, _etaž, _lier_,
  { {0x2d980629, 0x6113005f, 0x69dc062a, 0x00000000}},  //   rare_, kələ, _rare,
  { {0x69dc062b, 0x2d98062c, 0x44e3011f, 0x00000000}},  //   _sare, sare_, _mı_,
  { {0x79950263, 0x2d98062d, 0x6113006b, 0x00000000}},  // [6e0] _bezw, pare_, dələ,
  { {0x2d980023, 0xb5fc002b, 0x00000000, 0x00000000}},  //   qare_, _tiġi,   ,
  { {0x69dc0018, 0x6113005f, 0x69de00f8, 0x00000000}},  //   _vare, fələ, rdpe,
  { {0xe73a0057, 0x765a008d, 0xb8dc062e, 0x00000000}},  //   нее_, _shty, _आम_,
  { {0x69dc062f, 0x386d0630, 0xc7a3004d, 0x00000000}},  //   _tare, _dier_, сичк,
  { {0xceb300a0, 0x386d0631, 0x7ae40190, 0x00000000}},  //   מיד_, _eier_, mvit,
  { {0x44e3005f, 0x386d0632, 0x6113005f, 0x00000000}},  //   _cı_, _fier_, bələ,
  { {0x6113005f, 0x386d0036, 0x8d5b0049, 0x00000000}},  //   cələ, _gier_, עכקי,
  { {0x66010374, 0x69c10061, 0x7ae40181, 0x00000000}},  //   _folk, र्वी, nvit,
  { {0xddcd0224, 0x66010633, 0x408600ed, 0x00000000}},  //   _staž, _golk, лумб,
  { {0x7c260634, 0x3f99006c, 0x5ff500c0, 0x00000000}},  //   _omkr, tasu_, азну,
  { {0x63a20020, 0x7e7601d6, 0x6d400276, 0x00000000}},  //   _udon, _buyp, ğmal,
  { {0x44260058, 0x6d40047f, 0x7bdd027e, 0x00000000}},  //   _imo_, şmal, _rasu,
  { {0x2731001d, 0x7ae40635, 0x44e3014a, 0x00000000}},  //   ạng_, dvit, _yı_,
  { {0x7bdd0636, 0xdb0d0051, 0x317b00a3, 0x00000000}},  //   _pasu, rgaí, _ארומ,
  { {0x6006000c, 0xafdb0030, 0x442600e7, 0x00000000}},  //   _dóms, rløs, _jmo_,
  { {0xafdb0637, 0x6113006b, 0x7ac7007e, 0x00000000}},  // [6f0] sløs, vələ, ысве,
  { {0xe29f000c, 0x386d0056, 0x7bdd00e7, 0x00000000}},  //   áði_, _sier_, _wasu,
  { {0x7bdd0004, 0x386d0638, 0x6113006b, 0x00000000}},  //   _tasu, _pier_, tələ,
  { {0x20da0107, 0xe84b0379, 0x660100f8, 0x00000000}},  //   mšić_, رجان_, _solk,
  { {0x386d037f, 0x6b8d0149, 0x66010639, 0x00000000}},  //   _vier_, mbag, _polk,
  { {0x6113005f, 0x6b8d063a, 0x68e3063b, 0x00000000}},  //   sələ, lbag, ånds,
  { {0x66010343, 0x22450007, 0x386d03a1, 0x00000000}},  //   _volk, volk_, _tier_,
  { {0x6601063c, 0x6113005f, 0x22450250, 0x00000000}},  //   _wolk, qələ, wolk_,
  { {0x2bc7001c, 0x6601063d, 0x21f50088, 0x00000000}},  //   ऱ्या, _tolk, аїнс,
  { {0x0322008b, 0x20c50088, 0x69c50051, 0x00000000}},  //   ідэн, айом, nfhe,
  { {0x2ee90016, 0x442600e5, 0x7ae40340, 0x00000000}},  //   _araf_, _fmo_, zvit,
  { {0x6aad05ad, 0xa4fa007b, 0x2ee90016, 0x00000000}},  //   kraf, _בלעט, _braf_,
  { {0x636b047f, 0x1f5600a5, 0xc7d6009b, 0x00000000}},  //   _dönü, ртнё, בורי_,
  { {0x91fc001e, 0x6289029d, 0x6aad063e, 0x00000000}},  //   rmāc, mpeo, draf,
  { {0x3b9600e1, 0x8b9600e3, 0x2ee9063f, 0x00000000}},  //   ијат, ирач, _eraf_,
  { {0xe8e0001d, 0x636b014a, 0xafdb0637, 0x00000000}},  //   _hiệp_, _gönü, slør,
  { {0x2ee90640, 0x6da600ed, 0xada60641, 0x00000000}},  // [700] _graf_, _кипа, _капл,
  { {0x7ae4021e, 0x6006000c, 0xac760014, 0x00000000}},  //   rvit, _tóms, _پادش,
  { {0x7ae40635, 0x636b005a, 0x81c80044, 0x00000000}},  //   svit, _yönü, _লোড_,
  { {0xbc7b00b6, 0x6aad0190, 0xdb200010, 0x00000000}},  //   _שנכת, braf, ítóg,
  { {0x2bdf0204, 0x6aad0133, 0xdcfc0006, 0x00000000}},  //   _पोटा, craf, tarė,
  { {0x442601d9, 0x7aeb0030, 0xe4a600ed, 0x00000000}},  //   _smo_, ægte, арио,
  { {0xd4970642, 0x44260643, 0x18a302dc, 0x00000000}},  //   ары_, _pmo_, _марм,
  { {0xa6860072, 0x7c360016, 0xddcd0036, 0x00000000}},  //   _влад, nnyr, _staż,
  { {0x20190023, 0x00000000, 0x00000000, 0x00000000}},  //   ërim_,   ,   ,
  { {0x1db201f5, 0x38780065, 0x442600bb, 0x00000000}},  //   _जागत, _kurr_, _wmo_,
  { {0xe3ba00e3, 0x80270644, 0xe8e00011, 0x00000000}},  //   _абе_, لرحم, _diệp_,
  { {0x6f1d010f, 0x7c3b0107, 0x20da0645, 0x00000000}},  //   tzsc, čurk, všić_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6aad0026, 0x6f1d01a2, 0x9f4900fa, 0x00000000}},  //   vraf, rzsc, _unaí_,
  { {0x6b8d0646, 0xac19003b, 0x61fc00f8, 0x00000000}},  //   tbag, гову_, örlu,
  { {0x6aad0036, 0x2ee901a2, 0xb068007e, 0x00000000}},  //   traf, _traf_, _крыж_,
  { {0x6b8d04fa, 0xda78007c, 0xf9930379, 0x00000000}},  // [710] rbag, аях_, قبض_,
  { {0xd9990647, 0x6aad00d6, 0x3da701fc, 0x00000000}},  //   انات_, rraf, _триб,
  { {0xa3b601f5, 0x2907001a, 0x69c50051, 0x00000000}},  //   जला_, âna_, rfhe,
  { {0x6aad001a, 0x24850648, 0x00000000, 0x00000000}},  //   praf, _rtlm_,   ,
  { {0x7c2d0649, 0x6aad006b, 0xfaff0023, 0x00000000}},  //   miar, qraf, _egër_,
  { {0x929d0036, 0x387801f3, 0x00000000, 0x00000000}},  //   syłk, _furr_,   ,
  { {0x610a006b, 0x00000000, 0x00000000, 0x00000000}},  //   nəld,   ,   ,
  { {0xf77f005d, 0xa9540088, 0x2a71064a, 0x00000000}},  //   _üç_, _єкті, _hizb_,
  { {0xa3d6013d, 0x26cd0020, 0xa715003b, 0x00000000}},  //   ाज़_, _upeo_, _удаљ,
  { {0xe1f9064b, 0xe61301fa, 0x7c2d064c, 0x00000000}},  //   уго_, _بشر_, hiar,
  { {0x614500ed, 0x7c2d002d, 0xd24e0014, 0x00000000}},  //   сена, kiar, رچه_,
  { {0x6006064d, 0x9f060025, 0xc50c0049, 0x00000000}},  //   _cómp, موجو, _שלאָ,
  { {0x91e50113, 0x7c2d064e, 0x61e1001c, 0x00000000}},  //   _голе, diar, pdll,
  { {0x442d064f, 0x6449046a, 0x62720036, 0x00000000}},  //   lie_, loei, _włoc,
  { {0x7c2d0032, 0x0c79007c, 0x442d0650, 0x00000000}},  //   fiar, исты_, oie_,
  { {0x442d0620, 0x7c2d002d, 0xb5fc002b, 0x00000000}},  //   nie_, giar, _jiġr,
  { {0x63a60651, 0x7c360006, 0x2a710009, 0x00000000}},  // [720] ókni, rnyr, _bizb_,
  { {0x442d0207, 0x644900d9, 0xc3010044, 0x00000000}},  //   hie_, hoei, এনপি_,
  { {0x442d0652, 0x7c2d0653, 0x3ea200f8, 0x00000000}},  //   kie_, biar, lskt_,
  { {0x442d0654, 0x2d9a0058, 0x00000000, 0x00000000}},  //   jie_, _hepe_,   ,
  { {0x442d0428, 0x3ea203ed, 0xdcfc0089, 0x00000000}},  //   die_, nskt_, karī,
  { {0x27e00655, 0x6e2e01d5, 0x9e7b0049, 0x00000000}},  //   žin_, nibb, אנספ,
  { {0xdcfc001e, 0x00000000, 0x00000000, 0x00000000}},  //   darī,   ,   ,
  { {0x2d9a0059, 0x644900c4, 0x6e2e0145, 0x00000000}},  //   _lepe_, goei, hibb,
  { {0x38660039, 0x610a006b, 0xe73a00ed, 0x00000000}},  //   mmor_, zəld, _сеа_,
  { {0x7c2d0656, 0x442d0657, 0x2d9a01aa, 0x00000000}},  //   ziar, aie_, _nepe_,
  { {0x442d0046, 0xa1580175, 0xa3b60061, 0x00000000}},  //   bie_, рану_, _जाऊ_,
  { {0x442d0620, 0x38660658, 0x3957009b, 0x00000000}},  //   cie_, nmor_, משים_,
  { {0x7c2d0207, 0x2d9a0022, 0x6e2e001b, 0x00000000}},  //   viar, _bepe_, fibb,
  { {0xdb0d0181, 0x2d9a00e5, 0x7c2d0036, 0x00000000}},  //   lgaç, _cepe_, wiar,
  { {0x7c2d0659, 0x0ba7007e, 0x6a69007f, 0x00000000}},  //   tiar, йшам, _užfi,
  { {0x3881010a, 0xdb0d065a, 0x00000000, 0x00000000}},  //   _nėra_, ngaç,   ,
  { {0x7c2d022b, 0x9999003b, 0xa3b60061, 0x00000000}},  // [730] riar, икат_, _जाई_,
  { {0x442d065b, 0x6fb501ef, 0x7c2d065c, 0x00000000}},  //   zie_, _امکا, siar,
  { {0x7c2d065d, 0x442d065e, 0x9f520173, 0x00000000}},  //   piar, yie_, _anyè_,
  { {0x38660190, 0x442d065f, 0x81be0044, 0x00000000}},  //   gmor_, xie_, ঁজি_,
  { {0x442d0660, 0xc987003b, 0xb6c7007c, 0x00000000}},  //   vie_, _губи, ссей,
  { {0x442d0661, 0x2d830036, 0x853c0006, 0x00000000}},  //   wie_, ncje_, _idėj,
  { {0x442d0662, 0x1a68009e, 0x64490663, 0x00000000}},  //   tie_, _ایلی_, toei,
  { {0x52a900c0, 0x00000000, 0x00000000, 0x00000000}},  //   авим_,   ,   ,
  { {0x2d830046, 0x64490664, 0x1306007c, 0x00000000}},  //   kcje_, roei, жный_,
  { {0x442d0665, 0x69d70666, 0x7d0800ea, 0x00000000}},  //   sie_, nexe, ødsk,
  { {0x442d0667, 0x644900c4, 0x2d9a0052, 0x00000000}},  //   pie_, poei, _repe_,
  { {0xa2b2001c, 0xa3b602d2, 0x2d9a00ca, 0x00000000}},  //   _आमच्, _जाए_, _sepe_,
  { {0x2d9a0020, 0x6e2e002b, 0x823400a1, 0x00000000}},  //   _pepe_, tibb, _کرنا,
  { {0x63bb0668, 0x3ea20669, 0x00000000, 0x00000000}},  //   lgun, rskt_,   ,
  { {0xc5f2009b, 0xfce3004c, 0x69d7066a, 0x00000000}},  //   ודם_, моро, dexe,
  { {0x63bb020c, 0x799e00e7, 0x6b9f0045, 0x00000000}},  //   ngun, wapw, gaqg,
  { {0x81dc0044, 0x61e3066b, 0x8d760076, 0x00000000}},  // [740] ডার_, _kanl, _وادا,
  { {0x63bb04cb, 0x3866005b, 0x2002066c, 0x00000000}},  //   hgun, wmor_, ljki_,
  { {0x61e3066d, 0x00000000, 0x00000000, 0x00000000}},  //   _manl,   ,   ,
  { {0xb8f203d7, 0x6d5e066e, 0x46ea005e, 0x00000000}},  //   _वह_, _izpa, иден_,
  { {0x386601bf, 0x4e0e006e, 0x25be0009, 0x00000000}},  //   rmor_, _हवाई_, _pctl_,
  { {0x63bb066f, 0xb0a9007d, 0x61e3011c, 0x00000000}},  //   egun, _किंग, _nanl,
  { {0x6aa40023, 0xf8b000a1, 0x9f4500b9, 0x00000000}},  //   lsif, _سکا_, ělé_,
  { {0x61e30100, 0x799c0016, 0x6b840197, 0x00000000}},  //   _aanl, _herw, ncig,
  { {0x61e30670, 0x2d830036, 0x75d6023c, 0x00000000}},  //   _banl, ycje_, _ويرا,
  { {0x61e30671, 0x32180046, 0xd25a025f, 0x00000000}},  //   _canl, óry_, јци_,
  { {0x63bb022b, 0x799c0007, 0xb97b00b3, 0x00000000}},  //   bgun, _merw, יניי,
  { {0x68e30030, 0x27e60672, 0x69ca0164, 0x00000000}},  //   ændi, ndon_, स्ती,
  { {0x733600a1, 0x69ce0197, 0x63a00673, 0x00000000}},  //   _برائ, _obbe, mamn,
  { {0xd344007a, 0x61e3018e, 0x63a0033b, 0x00000000}},  //   _ویژه_, _ganl, lamn,
  { {0x6b84016c, 0x2cb800ea, 0x66080190, 0x00000000}},  //   fcig, gurd_, _modk,
  { {0x27e40674, 0xe3ac0044, 0x228001aa, 0x00000000}},  //   _namn_, ক্রব, _kòk_,
  { {0x27e60675, 0x61e30676, 0xa3cc007d, 0x00000000}},  // [750] ddon_, _yanl, श्य_,
  { {0x3eb90677, 0x63a000f8, 0x20090082, 0x00000000}},  //   must_, hamn, _hoai_,
  { {0x3eb9006c, 0x799c0678, 0x68e20036, 0x00000000}},  //   lust_, _derw, łodn,
  { {0x69ce0047, 0x6b840197, 0x661a010e, 0x00000000}},  //   _ebbe, ccig, _altk,
  { {0x3eb9006c, 0xd6db0679, 0xf770067a, 0x00000000}},  //   nust_, рте_, ناه_,
  { {0x62720036, 0x20090082, 0x799c005b, 0x00000000}},  //   _słon, _loai_, _gerw,
  { {0x1c0f02d2, 0x91fc0089, 0x61e300ca, 0x00000000}},  //   _सवाल_, rmāl, _ranl,
  { {0x3207067b, 0xd7c90558, 0x61e3067c, 0x00000000}},  //   _sony_, _دوره_, _sanl,
  { {0x63bb067d, 0x61e3011c, 0x660802a9, 0x00000000}},  //   rgun, _panl, _fodk,
  { {0x3eb90677, 0x6608063b, 0x6b9d00bb, 0x00000000}},  //   dust_, _godk, _lesg,
  { {0x61e3067e, 0xd87400a1, 0x610a006b, 0x00000000}},  //   _vanl, _راہب, vəlc,
  { {0x22800263, 0x63a00093, 0x54370167, 0x00000000}},  //   _fòk_, camn, _برطر,
  { {0xe803007d, 0x2f5602d3, 0xdbd9000c, 0x00000000}},  //   _रचना_, ятос, væðu,
  { {0x91e50594, 0x321e067f, 0x27380082, 0x00000000}},  //   _хоке, chty_, ẩng_,
  { {0xed5a0680, 0xdbd9000c, 0x8d63003b, 0x00000000}},  //   сов_, tæðu, евре,
  { {0x799c0046, 0x6b9d0681, 0x6c360025, 0x00000000}},  //   _serw, _cesg, أفرا,
  { {0x6b9d0682, 0xdbd9009f, 0x799c0169, 0x00000000}},  // [760] _desg, ræðu, _perw,
  { {0x6aa40169, 0xa3ab007d, 0x19b9007e, 0x00000000}},  //   rsif, कृत_, жуць_,
  { {0x799c0683, 0x6aa40684, 0x1b040044, 0x00000000}},  //   _verw, ssif, _রেখে_,
  { {0xdcf50036, 0x799c021f, 0x27e60685, 0x00000000}},  //   jczę, _werw, udon_,
  { {0x799c0686, 0x66080395, 0xe3c30044, 0x00000000}},  //   _terw, _podk, ্যাব,
  { {0xd49a00e3, 0x26c600b0, 0xd90d00a1, 0x00000000}},  //   бри_, rtoo_, دیہ_,
  { {0x628b0016, 0x3eb90687, 0x25fe007d, 0x00000000}},  //   _atgo, zust_, लाबी_,
  { {0xb6030089, 0xa3b6013d, 0x493b009b, 0x00000000}},  //   īšan, _जाओ_, _הגלו,
  { {0x2bce001c, 0x27f701c8, 0x85760688, 0x00000000}},  //   ह्या, šení_, _فدائ,
  { {0xe8e00011, 0x3eb9006c, 0x63a0000c, 0x00000000}},  //   _nhịp_, vust_, samn,
  { {0x3eb900b5, 0x69c10164, 0x00000000, 0x00000000}},  //   wust_, र्टी,   ,
  { {0x3eb90004, 0x8fa400ec, 0x5ed60044, 0x00000000}},  //   tust_, наџе, দিনে,
  { {0x6b9d0181, 0x79850016, 0x00000000, 0x00000000}},  //   _resg, ychw,   ,
  { {0x99ce0055, 0x3ead016c, 0x6b9d004a, 0x00000000}},  //   রযুক, šeto_, _sesg,
  { {0x61f801b5, 0x3eb9006c, 0x9d180264, 0x00000000}},  //   _invl, sust_, порт_,
  { {0x5c7403dc, 0x3eb90059, 0x99d400a1, 0x00000000}},  //   елст, pust_, ہتما,
  { {0x3eb90689, 0x00000000, 0x00000000, 0x00000000}},  // [770] qust_,   ,   ,
  { {0xdce7011f, 0xdcf50036, 0x601f0023, 0x00000000}},  //   sajı, zczę, _dëme,
  { {0x7985068a, 0x20190006, 0x02d9007d, 0x00000000}},  //   rchw, ūriu_, _भन्न,
  { {0x7985001f, 0x69c8014a, 0x00000000, 0x00000000}},  //   schw, _öden,   ,
  { {0x601f0065, 0x7c2f0022, 0x61f800d9, 0x00000000}},  //   _këmb, _imcr, _onvl,
  { {0x2bcb0061, 0x8afa009b, 0x00000000, 0x00000000}},  //   ाभवा, _והשי,   ,
  { {0x20f00521, 0x7aed051b, 0xa50602dc, 0x00000000}},  //   nđić_, lvat, деща_,
  { {0xfcaa007b, 0x3ea9021e, 0x61f80173, 0x00000000}},  //   קיפּ, _ovat_, _anvl,
  { {0x7aed00bb, 0x00000000, 0x00000000, 0x00000000}},  //   nvat,   ,   ,
  { {0xf0a90264, 0xbebb0023, 0x69c10061, 0x00000000}},  //   окол_, tzën, र्ची,
  { {0x7aed068b, 0xa06a0216, 0x3494005e, 0x00000000}},  //   hvat, жана_, _захр,
  { {0x7aed037e, 0xe4d400a1, 0x00000000, 0x00000000}},  //   kvat, _ستمب,   ,
  { {0x442f0365, 0x6d490035, 0x628b00ea, 0x00000000}},  //   _img_, şeal, _utgo,
  { {0x7a200047, 0x7aed068c, 0x00000000, 0x00000000}},  //   _köte, dvat,   ,
  { {0x425200a1, 0xc0a803ec, 0x7bcd068d, 0x00000000}},  //   _جنور, _فايل_, ffau,
  { {0x7a200039, 0xc172009b, 0x20190065, 0x00000000}},  //   _möte, _בחו_, ërit_,
  { {0xfaa3008b, 0x442f0127, 0x6d4500ab, 0x00000000}},  // [780] като, _mmg_, _exha,
  { {0xe9d70245, 0x601f0065, 0x00000000, 0x00000000}},  //   мку_, _vëme,   ,
  { {0x6d400477, 0x49990088, 0xd7e60088, 0x00000000}},  //   ğmas, яття_, діло,
  { {0x6d4001f6, 0x9f40068e, 0xafdb068f, 0x00000000}},  //   şmas, _unió_, fløy,
  { {0xc7a300e1, 0xa3c8013d, 0xd6d0035b, 0x00000000}},  //   тичк, _लॉग_, اقت_,
  { {0x3eaf0030, 0xe8df0082, 0x7a2000f8, 0x00000000}},  //   _ægte_, _luộc_, _böte,
  { {0x442f0690, 0x68e30190, 0xa5c4013d, 0x00000000}},  //   _bmg_, ændt, _राठौ,
  { {0x6b960056, 0x442f0691, 0xd467003b, 0x00000000}},  //   nbyg, _cmg_, мије_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf8d202d2, 0x442f0093, 0xdb15009d, 0x00000000}},  //   _सहाय, _emg_, ébéc,
  { {0xd1300054, 0x7a200073, 0xe8df0011, 0x00000000}},  //   امج_, _göte, _buộc_,
  { {0xe8df001d, 0x7aed0161, 0x442f0692, 0x00000000}},  //   _cuộc_, yvat, _gmg_,
  { {0xd6d90036, 0x6b960693, 0x2ef20016, 0x00000000}},  //   _były_, dbyg, _cryf_,
  { {0x6ab60007, 0x2ef20007, 0x00000000, 0x00000000}},  //   dryf, _dryf_,   ,
  { {0x1bd50694, 0xfe24007c, 0x645c0089, 0x00000000}},  //   новя, тьян, _īrij,
  { {0x21b700a1, 0xec6803e8, 0x7aed0695, 0x00000000}},  //   _ٹھیک_, друк_, tvat,
  { {0x2ef20696, 0x2019008f, 0x7e770066, 0x00000000}},  // [790] _gryf_, ūris_, _tixp,
  { {0xe9d30025, 0xc95b007e, 0x9e6701b2, 0x00000000}},  //   ضغط_, оўе_, _تابن,
  { {0x7aed03b6, 0x58840147, 0x5c75007c, 0x00000000}},  //   svat, выча, _плот,
  { {0x2019023a, 0xafdb00ea, 0x39580146, 0x00000000}},  //   nksi_, tløy, _dyrs_,
  { {0x201900b0, 0x2a780026, 0x442f00d2, 0x00000000}},  //   iksi_, _firb_, _rmg_,
  { {0x442f0697, 0x68e30698, 0x644200b0, 0x00000000}},  //   _smg_, ænds, _ajoi,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe7390016, 0x58d401e1, 0xc2fa0044, 0x00000000}},  //   _ddŵr_, _шост, েননি_,
  { {0x7c3a0699, 0x9f9d000c, 0xf6b500a1, 0x00000000}},  //   étri, væði_, _سماج,
  { {0x201900b0, 0x7a2001a2, 0x00000000, 0x00000000}},  //   eksi_, _töte,   ,
  { {0x6e3504eb, 0x9f9d01e5, 0x442f069a, 0x00000000}},  //   dizb, tæði_, _tmg_,
  { {0xcdc900b6, 0x80a003d7, 0x59cf0309, 0x00000000}},  //   _לך_, _खबरे, स्तर,
  { {0xef170057, 0x9f9d009f, 0x443f069b, 0x00000000}},  //   емя_, ræði_, mnu_,
  { {0xfce60216, 0x6145025f, 0xc69201ce, 0x00000000}},  //   ного, _пела, ראם_,
  { {0xa3cc02d2, 0x81c80055, 0xe8df0082, 0x00000000}},  //   श्व_, _লোক_, _tuộc_,
  { {0x443f069c, 0x645b069d, 0xfbdf01c3, 0x00000000}},  //   nnu_, nlui, _skêr_,
  { {0x6b96037d, 0x443f069e, 0xbdfa069f, 0x00000000}},  // [7a0] rbyg, inu_, _فردا_,
  { {0x443f06a0, 0x6b9606a1, 0x8e97009b, 0x00000000}},  //   hnu_, sbyg, _רדיו_,
  { {0xf1c201f5, 0x69c8011f, 0x6b96000c, 0x00000000}},  //   _शासन, _ödem, pbyg,
  { {0x443f06a2, 0x41cf0061, 0x96ea01e1, 0x00000000}},  //   jnu_, त्तस, зька_,
  { {0xc87901df, 0x68e30030, 0x645b0168, 0x00000000}},  //   _diş_, ændr, dlui,
  { {0x443f06a3, 0x2d980173, 0x857400a1, 0x00000000}},  //   enu_, nbre_, نگائ,
  { {0x443f069c, 0x5fc6001c, 0x69de06a4, 0x00000000}},  //   fnu_, _वाढल, mepe,
  { {0x443f037e, 0x66e601bd, 0x69de0010, 0x00000000}},  //   gnu_, _поба, lepe,
  { {0xe7d5005d, 0x00000000, 0x00000000, 0x00000000}},  //   lığı,   ,   ,
  { {0x443f001a, 0x9fd00044, 0x69de06a5, 0x00000000}},  //   anu_, িযোগ, nepe,
  { {0x443f06a6, 0x7c2406a7, 0x3a37009b, 0x00000000}},  //   bnu_, khir, תרים_,
  { {0x443f037e, 0x645b0489, 0x69de06a8, 0x00000000}},  //   cnu_, clui, hepe,
  { {0x7c2406a9, 0x4ea7007e, 0x201906aa, 0x00000000}},  //   dhir, эрна, rksi_,
  { {0x932500a1, 0x127b0049, 0xa3cc007d, 0x00000000}},  //   _جرمن, _זאגע, श्र_,
  { {0x69de01cb, 0xc0e301fc, 0x63a2008a, 0x00000000}},  //   depe, _бојк, _keon,
  { {0xe7d5047f, 0x61ea06ab, 0x63a20082, 0x00000000}},  //   dığı, _hafl, _jeon,
  { {0x61ea0651, 0x63a20022, 0x610a006b, 0x00000000}},  // [7b0] _kafl, _meon, zəll,
  { {0x443f06ac, 0x69de06ad, 0x7c240020, 0x00000000}},  //   znu_, gepe, ahir,
  { {0x443f018e, 0x7ae600ea, 0xdb160010, 0x00000000}},  //   ynu_, _eskt, rgyá,
  { {0x7c24001a, 0x63a206ae, 0x61ea06af, 0x00000000}},  //   chir, _neon, _lafl,
  { {0x4424002a, 0x443f0466, 0x69de01b5, 0x00000000}},  //   dhm_, vnu_, bepe,
  { {0x27e90091, 0xcfea0044, 0x69de001a, 0x00000000}},  //   žan_, গায়_, cepe,
  { {0x443f0091, 0x645b0007, 0x6e200023, 0x00000000}},  //   tnu_, tlui, ëmbi,
  { {0x7bdf00c4, 0x3eb9016c, 0x443f0205, 0x00000000}},  //   nequ, krst_, unu_,
  { {0x443f06b0, 0x63a20051, 0x645b06b1, 0x00000000}},  //   rnu_, _deon, rlui,
  { {0x645b06b2, 0xd24e006d, 0x443f0091, 0x00000000}},  //   slui, يني_, snu_,
  { {0x61ea0016, 0x443f036a, 0x645b009d, 0x00000000}},  //   _dafl, pnu_, plui,
  { {0x63a2007f, 0x69de0010, 0x9f4000f6, 0x00000000}},  //   _geon, zepe, _paià_,
  { {0x7bdf06b3, 0x69c7016e, 0x0ef9007e, 0x00000000}},  //   dequ, _ocje, нэры_,
  { {0xc3320452, 0xdd9206b4, 0x61ea06b5, 0x00000000}},  //   _דוד_, شور_, _gafl,
  { {0xed5700d7, 0x7c240020, 0xada306b6, 0x00000000}},  //   вор_, thir, расл,
  { {0x60d60104, 0x8c4300ed, 0x44f10066, 0x00000000}},  //   _יוצא_, аесе, _mġ_,
  { {0xeab1026c, 0x69de008e, 0xc1e50309, 0x00000000}},  // [7c0] یعے_, tepe, _कसाब_,
  { {0x7c2406b7, 0xceb90224, 0xba23007e, 0x00000000}},  //   shir, áře_, адук,
  { {0x69de0010, 0x291c06b8, 0x7bdf06b9, 0x00000000}},  //   repe, áva_, bequ,
  { {0x3ea001aa, 0x69de06ba, 0x7ae60058, 0x00000000}},  //   _kwit_, sepe, _tskt,
  { {0x62720036, 0xa6fa0025, 0x69de00e7, 0x00000000}},  //   _głow, بعاء_, pepe,
  { {0x4a750057, 0xaa4606bb, 0x7ae40020, 0x00000000}},  //   _быст, _регл, mwit,
  { {0x7a200039, 0x7ae40007, 0x63a206bc, 0x00000000}},  //   _göta, lwit, _peon,
  { {0x61ea018e, 0xa7850054, 0x7bc406bd, 0x00000000}},  //   _safl, _مشكو, ngiu,
  { {0x7ae406be, 0x7c23001a, 0x3ea001aa, 0x00000000}},  //   nwit, _înre, _nwit_,
  { {0x610a006b, 0x63a2004a, 0x7aeb0190, 0x00000000}},  //   səlm, _weon, ægti,
  { {0x859b0104, 0x85060070, 0x3ea0011c, 0x00000000}},  //   _חשבו, _جوان, _awit_,
  { {0xc95300b6, 0x7bdf00d4, 0x7d0300d4, 0x00000000}},  //   ימת_, xequ, _ànsi,
  { {0x61ea06bf, 0x7bdf0068, 0x00000000, 0x00000000}},  //   _tafl, vequ,   ,
  { {0xf77301f8, 0x6e94007c, 0x00000000, 0x00000000}},  //   יקר_, риру,   ,
  { {0x62720046, 0x7bdf06c0, 0x7ae406c1, 0x00000000}},  //   _słow, tequ, ewit,
  { {0x7bc40207, 0xa177009b, 0xd10f007d, 0x00000000}},  //   ggiu, _בעוד_, ाहरण_,
  { {0x7ae4002b, 0xdb1d0173, 0x00000000, 0x00000000}},  // [7d0] gwit, _absò,   ,
  { {0x7bdf06c2, 0xf7f4007a, 0x2ee90016, 0x00000000}},  //   sequ, یسند, _isaf_,
  { {0x7bdf004a, 0x00000000, 0x00000000, 0x00000000}},  //   pequ,   ,   ,
  { {0x787a00b9, 0x7ae40066, 0x00000000, 0x00000000}},  //   _důvo, bwit,   ,
  { {0x81d20082, 0x601f0023, 0x00000000, 0x00000000}},  //   _rồng, _lëmo,   ,
  { {0x6aad06c3, 0x6b8d0026, 0xc98700ed, 0x00000000}},  //   msaf, lcag, _шуми,
  { {0x6aad0475, 0xd5ae0439, 0x00000000, 0x00000000}},  //   lsaf, سفي_,   ,
  { {0xd46606c4, 0x6b8d008e, 0x69c506c5, 0x00000000}},  //   лище_, ncag, lghe,
  { {0x2bd5001c, 0x6aad03ba, 0x65950088, 0x00000000}},  //   ड्या, nsaf, _базу,
  { {0x2d81001d, 0x95d8007c, 0xc5fb006d, 0x00000000}},  //   _nghe_, _идут_, _تعرض_,
  { {0xe4cb06c6, 0x2ee906c7, 0x69c50051, 0x00000000}},  //   _زبان_, _asaf_, ighe,
  { {0x25a50019, 0xf3f00025, 0x27ed06c8, 0x00000000}},  //   _hell_, _وأن_, _jaen_,
  { {0x25a506c9, 0x27ed06ca, 0x63a90056, 0x00000000}},  //   _kell_, _maen_, maen,
  { {0x27ed06cb, 0x63a9006c, 0x6aad0190, 0x00000000}},  //   _laen_, laen, dsaf,
  { {0x27ff027d, 0x61e1049a, 0x03e60055, 0x00000000}},  //   _onun_, mell, কারী_,
  { {0x6b8d001c, 0x61e1021e, 0x63a906cc, 0x00000000}},  //   gcag, lell, naen,
  { {0xab6606cd, 0x60c10026, 0x6aad06ce, 0x00000000}},  // [7e0] увал, lulm, gsaf,
  { {0x25a50198, 0x787a0224, 0xdcee0279, 0x00000000}},  //   _nell_, _půvo, sabı,
  { {0x610a005f, 0x60c106cf, 0x63a906d0, 0x00000000}},  //   vəlk, nulm, kaen,
  { {0x61e100b0, 0x6b8d06d1, 0x27ed06d2, 0x00000000}},  //   hell, ccag, _caen_,
  { {0x61e10018, 0x60c106d3, 0x6d5e06d4, 0x00000000}},  //   kell, hulm, _hypa,
  { {0x7e7e01d5, 0x25a50038, 0x61e10065, 0x00000000}},  //   _jipp, _cell_, jell,
  { {0x61e106d5, 0x25a5051b, 0x83fd0010, 0x00000000}},  //   dell, _dell_, klőd,
  { {0x7e7e00b0, 0x3a3a0002, 0x44220047, 0x00000000}},  //   _lipp, lipp_, ók_,
  { {0x61e106d6, 0x610a006b, 0x25a506d7, 0x00000000}},  //   fell, məli, _fell_,
  { {0x61e1014a, 0xf1c600b9, 0x645906d8, 0x00000000}},  //   gell, _část_, _ekwi,
  { {0x63a9011c, 0x00000000, 0x00000000, 0x00000000}},  //   baen,   ,   ,
  { {0x0eeb007c, 0x7e7e00ea, 0x25a50440, 0x00000000}},  //   ньги_, _aipp, _zell_,
  { {0xe29600ed, 0x7e7e01ee, 0x69c506d9, 0x00000000}},  //   _среќ, _bipp, yghe,
  { {0x61e106da, 0x7e7e0197, 0x2fc900c4, 0x00000000}},  //   cell, _cipp, _wcag_,
  { {0x6b8d001c, 0x7e7e0436, 0x00000000, 0x00000000}},  //   tcag, _dipp,   ,
  { {0x60df0047, 0x6aad00eb, 0x6d5e0023, 0x00000000}},  //   őzmé, tsaf, _dypa,
  { {0x5a35026b, 0x765a06db, 0x2ee90085, 0x00000000}},  // [7f0] анат, _okty, _usaf_,
  { {0x6b8d0197, 0x321e0036, 0x6aad03d0, 0x00000000}},  //   scag, nkty_, rsaf,
  { {0x69c50207, 0x6aad0197, 0x9967003b, 0x00000000}},  //   rghe, ssaf, утал,
  { {0x765a06dc, 0x61e10284, 0x62720036, 0x00000000}},  //   _akty, zell, _złot,
  { {0x25a50221, 0x61e102fa, 0x60c10279, 0x00000000}},  //   _pell_, yell, zulm,
  { {0xf77006dd, 0x61e100f4, 0x60c10180, 0x00000000}},  //   سان_, xell, yulm,
  { {0x63a906de, 0x61e1032c, 0x25a50129, 0x00000000}},  //   taen, vell, _vell_,
  { {0x25a50038, 0x61e105af, 0xb6c900a1, 0x00000000}},  //   _well_, well, _لائے_,
  { {0x61e103a1, 0x25a500ab, 0xcb120049, 0x00000000}},  //   tell, _tell_, ַלט_,
  { {0x60c106df, 0x22150140, 0xdb0d004a, 0x00000000}},  //   tulm, рфир, ngañ,
  { {0xc5fa007b, 0xb5fa0049, 0x386d000a, 0x00000000}},  //   _שפעט, _שלעכ, _kher_,
  { {0x61e106e0, 0x437506e1, 0x60c1005d, 0x00000000}},  //   sell, _култ, rulm,
  { {0x2055008b, 0x61e106e2, 0xeac00044, 0x00000000}},  //   стэр, pell, _উন্ম,
  { {0x6da3026b, 0x533206e3, 0x610a006b, 0x00000000}},  //   жира, _фељт, zəli,
  { {0xed5a0057, 0x7e7e0190, 0x62860161, 0x00000000}},  //   тов_, _vipp, íkov,
  { {0x1e86005e, 0x200006e4, 0x6d5e01ca, 0x00000000}},  //   _клим, _unii_, _vypa,

  { {0x7e7e06e5, 0x62720046, 0x6d5e0046, 0x00000000}},  // [800] _tipp, _głos, _wypa,
  { {0x6d410051, 0x3ead002b, 0x3c3f00b0, 0x00000000}},  //   úlac, ġett_, tävä_,
  { {0x6e3c06e6, 0x610a006b, 0x386d0146, 0x00000000}},  //   mirb, təli, _bher_,
  { {0x386d00f4, 0xd90d00a6, 0xe8df0082, 0x00000000}},  //   _cher_, ریق_, _cuốc_,
  { {0x66f406e7, 0xc6a302d3, 0x610a006b, 0x00000000}},  //   сплу, орщи, rəli,
  { {0x386d010f, 0xdb060023, 0xfaa302dc, 0x00000000}},  //   _eher_, _lekë, _фаро,
  { {0x290700f8, 0x00000000, 0x00000000, 0x00000000}},  //   änat_,   ,   ,
  { {0x6a6b010f, 0x387f0026, 0xe8df0082, 0x00000000}},  //   rüfe, _giur_, _guốc_,
  { {0xf5ea026b, 0xdb0d000c, 0x00000000, 0x00000000}},  //   _имал_, ngað,   ,
  { {0xd4d6008b, 0x387f002d, 0xe8040061, 0x00000000}},  //   _відэ, _ziur_, ळावा_,
  { {0x6e3c06e8, 0x741600a2, 0x321e06e9, 0x00000000}},  //   dirb, _پوشا, rkty_,
  { {0x91fc01c5, 0x00000000, 0x00000000, 0x00000000}},  //   flāc,   ,   ,
  { {0x229406ea, 0x32940025, 0xd042006b, 0x00000000}},  //   _التس, _التأ, ntlə,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2ba702a8, 0x442606eb, 0x62720036, 0x00000000}},  //   ијав, _klo_, _włos,
  { {0x5bb80057, 0x717b009b, 0xd042006b, 0x00000000}},  //   ился_, _בנוס, ktlə,
  { {0xaed5003b, 0xb066006c, 0x442600e7, 0x00000000}},  // [810] _уопш, svää, _mlo_,
  { {0x4426049a, 0x7d1c06ec, 0x7c2600f8, 0x00000000}},  //   _llo_, byrs, _elkr,
  { {0xda780242, 0x4f5800a6, 0x442600b0, 0x00000000}},  //   рят_, _مجید_, _olo_,
  { {0xd126009c, 0xe8df00ad, 0x442606ed, 0x00000000}},  //   _ہم_, _quốc_, _nlo_,
  { {0x610a006b, 0x3a3800fa, 0x00000000, 0x00000000}},  //   məlu, _fmrp_,   ,
  { {0x442606ee, 0x386d00e0, 0xe5a2007c, 0x00000000}},  //   _alo_, _wher_, пиши,
  { {0x442606ef, 0x29070479, 0x81ac0044, 0x00000000}},  //   _blo_, ånad_, গলা_,
  { {0x436901be, 0x44260462, 0xd4e40088, 0x00000000}},  //   лайн_, _clo_, юючи,
  { {0x44260263, 0x00000000, 0x00000000, 0x00000000}},  //   _dlo_,   ,   ,
  { {0x442600b0, 0x00000000, 0x00000000, 0x00000000}},  //   _elo_,   ,   ,
  { {0x442606f0, 0x6d400279, 0x1b1b0044, 0x00000000}},  //   _flo_, şmaz, _নেমে_,
  { {0x44260343, 0x00000000, 0x00000000, 0x00000000}},  //   _glo_,   ,   ,
  { {0x2bcb013d, 0x00000000, 0x00000000, 0x00000000}},  //   िलना,   ,   ,
  { {0xe29c007b, 0x44260091, 0x7d1c0065, 0x00000000}},  //   _ישׂר, _zlo_, tyrs,
  { {0x823406f1, 0x1d1901fb, 0x6fc10061, 0x00000000}},  //   _برنا, ають_, _वाचू,
  { {0x61b7024c, 0x6f1d06f2, 0x3b8606f3, 0x00000000}},  //   _आयुष, bysc, слаг,
  { {0xe9da0001, 0xc053009b, 0x3b0705f6, 0x00000000}},  // [820] лка_, _מזה_, бето_,
  { {0x7dea007c, 0xdb0d01e5, 0x00000000, 0x00000000}},  //   _смог_, rgað,   ,
  { {0xe8040061, 0xd23a0049, 0x00000000, 0x00000000}},  //   ळाला_, נגעל,   ,
  { {0xa967005e, 0x00000000, 0x00000000, 0x00000000}},  //   щиха_,   ,   ,
  { {0x29070039, 0x628f06f4, 0x00000000, 0x00000000}},  //   änar_, ícol,   ,
  { {0x442606f5, 0xd042005f, 0xe4a60081, 0x00000000}},  //   _slo_, rtlə, брио,
  { {0x442606f6, 0xd042005f, 0xd4970642, 0x00000000}},  //   _plo_, stlə, бры_,
  { {0x29050107, 0x786a01ca, 0x9418007c, 0x00000000}},  //   _šlag_, býva, ржит_,
  { {0x59cf00e8, 0x6a700039, 0x69c800f8, 0x00000000}},  //   स्कर, räff, _ödes,
  { {0x27e60061, 0x6d40005a, 0xf23800ed, 0x00000000}},  //   leon_, şmay, рпош_,
  { {0x69dc06f7, 0x69ce000a, 0x4426016e, 0x00000000}},  //   _mbre, _mcbe, _tlo_,
  { {0x6f1d001c, 0x43860054, 0x4426006a, 0x00000000}},  //   tysc, _الإق, _ulo_,
  { {0x69dc04bd, 0x00000000, 0x00000000, 0x00000000}},  //   _obre,   ,   ,
  { {0x44f80011, 0x13ad0044, 0x7d0100ea, 0x00000000}},  //   _kĩ_, _গায়, ålso,
  { {0x2d910036, 0xb4250036, 0xceb4006b, 0x00000000}},  //   rcze_, łżeń, _evə_,
  { {0x69dc06f8, 0x44f80082, 0x649501f3, 0x00000000}},  //   _abre, _mĩ_, _wġig,
  { {0x7b67051f, 0x69dc01f3, 0xd24d00a1, 0x00000000}},  // [830] стве, _bbre, _سچی_,
  { {0x6495002b, 0x00000000, 0x00000000, 0x00000000}},  //   _uġig,   ,   ,
  { {0xdd9200a2, 0xa8cb0439, 0x00000000, 0x00000000}},  //   _توپ_, طباق_,   ,
  { {0x7c67004b, 0x69dc06f9, 0x27e606fa, 0x00000000}},  //   _داخل, _ebre, geon_,
  { {0x7c2d06fb, 0xdcf50279, 0x64950066, 0x00000000}},  //   mhar, mazı, _mġie,
  { {0x601f0023, 0x00000000, 0x00000000, 0x00000000}},  //   _dëmi,   ,   ,
  { {0x2409007c, 0xafdb0030, 0x7afd06fc, 0x00000000}},  //   инки_, rnøj, _hrst,
  { {0x7afd041a, 0x7c2d0181, 0x601f008d, 0x00000000}},  //   _krst, nhar, _fëmi,
  { {0xc7b90010, 0x20f7001a, 0x7afb01ed, 0x00000000}},  //   _idő_, _săi_, _šutj,
  { {0x80cd0044, 0x20f70035, 0xdcf501df, 0x00000000}},  //   ়বস্, _păi_, hazı,
  { {0x7bcf06fd, 0x7c2d008a, 0x629b00b0, 0x00000000}},  //   _occu, khar, spuo,
  { {0xe8e00082, 0x00000000, 0x00000000, 0x00000000}},  //   _chộp_,   ,   ,
  { {0x7c2d06fe, 0x442d002a, 0xc7d6009b, 0x00000000}},  //   dhar, mhe_, חורי_,
  { {0x443f010a, 0x7bcf06ff, 0x442d0181, 0x00000000}},  //   liu_, _accu, lhe_,
  { {0x628b0058, 0x7afd006c, 0xa06a0517, 0x00000000}},  //   _hugo, _arst, _кака_,
  { {0x443f0700, 0x7c2d0020, 0x442d0701, 0x00000000}},  //   niu_, ghar, nhe_,
  { {0x628b0702, 0x63ab0047, 0x64490103, 0x00000000}},  // [840] _jugo, _megn, inei,
  { {0x63ab0703, 0x6449010f, 0x628b0202, 0x00000000}},  //   _legn, hnei, _mugo,
  { {0x7afd0109, 0x7c2d002a, 0x443f010a, 0x00000000}},  //   _erst, bhar, kiu_,
  { {0x7c2d032c, 0x60da0049, 0x62990036, 0x00000000}},  //   char, יקענ, _otwo,
  { {0x442d008d, 0x443f0704, 0x44f8001d, 0x00000000}},  //   dhe_, diu_, _sĩ_,
  { {0x6283011c, 0x7c240004, 0x27e60705, 0x00000000}},  //   _nino, lkir, seon_,
  { {0x7a20010f, 0x628b0089, 0x291c006c, 0x00000000}},  //   _nöti, _augo, ävad_,
  { {0x442d0375, 0x7c240706, 0x628300b0, 0x00000000}},  //   ghe_, nkir, _aino,
  { {0x62830058, 0x63ab0197, 0x64950066, 0x00000000}},  //   _bino, _degn, _rġie,
  { {0x386604bd, 0x628b0091, 0x644900c4, 0x00000000}},  //   llor_, _dugo, anei,
  { {0x9354026c, 0xf993019b, 0x2fcb001c, 0x00000000}},  //   _کراچ, ורת_, tgcg_,
  { {0x442d0707, 0x63ab0708, 0x443f0027, 0x00000000}},  //   che_, _gegn, ciu_,
  { {0xe1ef00d3, 0xc7b300b6, 0x6440011c, 0x00000000}},  //   رسی_, ובר_, mimi,
  { {0x62830709, 0x6440070a, 0x63ab0190, 0x00000000}},  //   _gino, limi, _zegn,
  { {0x7c2d070b, 0xfe6e02fd, 0x7c240066, 0x00000000}},  //   thar, دگي_, fkir,
  { {0x6440070c, 0x7afd0091, 0x62830006, 0x00000000}},  //   nimi, _prst, _zino,
  { {0x7c2d04cb, 0xdceb005d, 0xdcf50180, 0x00000000}},  // [850] rhar, ınız, razı,
  { {0x7c2d000b, 0x6440070d, 0x7afd01d9, 0x00000000}},  //   shar, himi, _vrst,
  { {0x6440070e, 0x7c2d0541, 0x3866008e, 0x00000000}},  //   kimi, phar, flor_,
  { {0xdce5001d, 0x6440070f, 0x443f04bd, 0x00000000}},  //   _nghĩ, jimi, xiu_,
  { {0x64400710, 0x63ab068f, 0x66050265, 0x00000000}},  //   dimi, _regn, зпла,
  { {0x63ab0198, 0x628b0065, 0x61e80166, 0x00000000}},  //   _segn, _rugo, jedl,
  { {0x442d0711, 0x443f04bd, 0x7aed01aa, 0x00000000}},  //   the_, tiu_, lwat,
  { {0x64400712, 0x7bcd0006, 0x628b0058, 0x00000000}},  //   gimi, ngau, _pugo,
  { {0x443f0713, 0x6283006a, 0x63ab009f, 0x00000000}},  //   riu_, _pino, _vegn,
  { {0x442d0714, 0x443f04a5, 0x63ab0168, 0x00000000}},  //   she_, siu_, _wegn,
  { {0x442d00f4, 0x64400715, 0x443f0716, 0x00000000}},  //   phe_, bimi, piu_,
  { {0x64400219, 0x628b0717, 0x3ea901aa, 0x00000000}},  //   cimi, _tugo, _bwat_,
  { {0x62990036, 0x62830718, 0x628b00e0, 0x00000000}},  //   _utwo, _tino, _uugo,
  { {0x7aed0719, 0x3ea90263, 0xe8e00082, 0x00000000}},  //   dwat, _dwat_, _chớp_,
  { {0x7aed00e0, 0x32070036, 0x386600ab, 0x00000000}},  //   ewat, _inny_, ylor_,
  { {0x5fc6001c, 0x7aed00e7, 0xdddc0161, 0x00000000}},  //   _वाटल, fwat, zorň,
  { {0x7c24071a, 0x7aed071b, 0xd5b80089, 0x00000000}},  // [860] rkir, gwat, _klāt_,
  { {0x64400714, 0x7c2404a5, 0x4efb071c, 0x00000000}},  //   zimi, skir, _פליג,
  { {0x6440006b, 0xae1b01ce, 0x7aed0022, 0x00000000}},  //   yimi, _הויכ, awat,
  { {0x644000f4, 0x00000000, 0x00000000, 0x00000000}},  //   ximi,   ,   ,
  { {0x6440071d, 0x38660210, 0xb86600a1, 0x00000000}},  //   vimi, rlor_, _ہارو,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6440071e, 0xb86603ab, 0x61e805d2, 0x00000000}},  //   timi, _فارو, vedl,
  { {0x329800ed, 0x443d01c3, 0x7afb0166, 0x00000000}},  //   овиќ_, _cmw_, _šuti,
  { {0x5fc60061, 0x61e80133, 0x00000000, 0x00000000}},  //   _वाजल, tedl,   ,
  { {0x64400710, 0x80c002fb, 0x4b3700a0, 0x00000000}},  //   simi, _विदे, פריל_,
  { {0x64a3008b, 0x3ea90066, 0x61e8003b, 0x00000000}},  //   _заха, _swat_, redl,
  { {0x7aed0046, 0xdcb10082, 0x6440071f, 0x00000000}},  //   ywat, ẩm_, qimi,
  { {0x661a044e, 0x82fa00a6, 0x00000000, 0x00000000}},  //   _kotk, _دراز_,   ,
  { {0x661a021e, 0x6e3e0009, 0xe3b00167, 0x00000000}},  //   _jotk, _cmpb, _سرچ_,
  { {0x61db01f8, 0x601f0065, 0x5fc60061, 0x00000000}},  //   _הקוד, _sëmu, _वाचल,
  { {0x7bcd0006, 0x00000000, 0x00000000, 0x00000000}},  //   ugau,   ,   ,
  { {0xa3de02d2, 0x7bcd04cb, 0x601f0065, 0x00000000}},  // [870] द्य_, rgau, _dëmt,
  { {0x2486002a, 0x91fc001e, 0x661a0720, 0x00000000}},  //   _liom_, klām, _notk,
  { {0x7aed00bb, 0xf9880025, 0x9f52009d, 0x00000000}},  //   swat, أنمي_, _rayé_,
  { {0xa2bd0309, 0x6608010e, 0x6b960145, 0x00000000}},  //   _शिल्, _andk, ccyg,
  { {0xd6db012b, 0x9f52009d, 0x661a00f8, 0x00000000}},  //   сте_, _payé_, _botk,
  { {0x443d0022, 0x95cb007c, 0x661a0087, 0x00000000}},  //   _smw_, суда_, _cotk,
  { {0x661a0721, 0xf8ae0014, 0x443d0722, 0x00000000}},  //   _dotk, _نکن_, _pmw_,
  { {0x3e640010, 0x00000000, 0x00000000, 0x00000000}},  //   lött_,   ,   ,
  { {0x661a0428, 0xe1f200a1, 0x443d00d9, 0x00000000}},  //   _fotk, چسپ_, _vmw_,
  { {0x20090723, 0x80d90088, 0x7a2001e5, 0x00000000}},  //   _anai_, оєму_, _fötu,
  { {0x764301a3, 0x7a20000c, 0x443d0724, 0x00000000}},  //   miny, _götu, _tmw_,
  { {0xa3ae02d2, 0x76430129, 0x3f6a003b, 0x00000000}},  //   करण_, liny, жимо_,
  { {0xd092005f, 0x7a2003ed, 0xdb06008e, 0x00000000}},  //   _müəy, _kött, _pekí,
  { {0xfce60088, 0x1e83007e, 0x7643033b, 0x00000000}},  //   мого, клям, niny,
  { {0x91fc0089, 0x7a200039, 0x3e640010, 0x00000000}},  //   klāj, _mött, dött_,
  { {0x7643027c, 0x601f0065, 0x7a200725, 0x00000000}},  //   hiny, _dëms, _lött,
  { {0xdd8f026c, 0x764304cb, 0xcb670726, 0x00000000}},  // [880] اوہ_, kiny, дате_,
  { {0x76430727, 0x67220020, 0x3e640010, 0x00000000}},  //   jiny, vyoj, gött_,
  { {0x76430728, 0x6ab60203, 0x00000000, 0x00000000}},  //   diny, ssyf,   ,
  { {0x8c460081, 0x2d9802d0, 0x661a00b0, 0x00000000}},  //   _цеме, lcre_, _sotk,
  { {0x76430729, 0x00000000, 0x00000000, 0x00000000}},  //   finy,   ,   ,
  { {0xd49a0200, 0x9d45026c, 0x7643072a, 0x00000000}},  //   ори_, _آئین, giny,
  { {0xf983072b, 0x661a072c, 0x7a2000f8, 0x00000000}},  //   _агро, _votk, _dött,
  { {0xa803005e, 0x69de00d9, 0x00000000, 0x00000000}},  //   _изсл, lfpe,   ,
  { {0x76430056, 0x7a20072d, 0xa01b072e, 0x00000000}},  //   biny, _fött, lmög,
  { {0x7a20072f, 0x20090026, 0x7643008a, 0x00000000}},  //   _gött, _snai_, ciny,
  { {0x644b01e5, 0x00000000, 0x00000000, 0x00000000}},  //   ðmið,   ,   ,
  { {0x3e640047, 0x53460730, 0x03260140, 0x00000000}},  //   zött_, _охла, _оден,
  { {0x80c00309, 0x00000000, 0x00000000, 0x00000000}},  //   _विवे,   ,   ,
  { {0x7412009e, 0x00000000, 0x00000000, 0x00000000}},  //   _سوڈا,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61f80731, 0x76430173, 0x2009002d, 0x00000000}},  //   _havl, ziny, _unai_,
  { {0x76430732, 0x3a750072, 0x61f80460, 0x00000000}},  // [890] yiny, елар, _kavl,
  { {0x61f80091, 0x61fa05b7, 0x9987013e, 0x00000000}},  //   _javl, ndtl, ónů_,
  { {0x7643007f, 0xa3ae0164, 0x7a2004ce, 0x00000000}},  //   viny, करा_, _rött,
  { {0x2c2701fb, 0xfc3f01dc, 0x6d5701f3, 0x00000000}},  //   _цьог, _umí_, _ixxa,
  { {0x76430169, 0x6b9a009b, 0x00000000, 0x00000000}},  //   tiny, _משרד,   ,
  { {0xf77002fd, 0x61f80733, 0x321c04bb, 0x00000000}},  //   جام_, _navl, _novy_,
  { {0x76430734, 0x9f4e00b9, 0x00000000, 0x00000000}},  //   riny, čném_,   ,
  { {0x76430169, 0x00000000, 0x00000000, 0x00000000}},  //   siny,   ,   ,
  { {0xa3de0164, 0x61f80161, 0xe8df0011, 0x00000000}},  //   द्ध_, _bavl, _khỏa_,
  { {0x80c00201, 0x29030022, 0x00000000, 0x00000000}},  //   _विशे, _krja_,   ,
  { {0xa06a005e, 0xe0460735, 0x90460014, 0x00000000}},  //   зана_, енни, فنده,
  { {0x44f10736, 0xdb060027, 0xa3de0164, 0x00000000}},  //   _iš_, _leká, द्द_,
  { {0xd12e00e9, 0xc2c80151, 0x932701fa, 0x00000000}},  //   لمی_, _قبول_, _تران,
  { {0x2d8c0737, 0x32d90173, 0x44f1012d, 0x00000000}},  //   øde_, mèy_, _kš_,
  { {0xdb040219, 0x32d90263, 0x1d070594, 0x00000000}},  //   mbié, lèy_, нери_,
  { {0x61f80738, 0x00000000, 0x00000000, 0x00000000}},  //   _zavl,   ,   ,
  { {0x2903002b, 0x442f0739, 0x44f101ee, 0x00000000}},  // [8a0] _arja_, _mlg_, _lš_,
  { {0x4a4300ed, 0x44f1073a, 0x442f01c3, 0x00000000}},  //   гнув, _oš_, _llg_,
  { {0x4c860265, 0x442f01a2, 0xd826073b, 0x00000000}},  //   _плов, _olg_, нджи,
  { {0x6f04073c, 0x69d50382, 0xa01b073d, 0x00000000}},  //   _kric, _ecze, rmög,
  { {0xdcfc005f, 0x44f1010a, 0x45d4031b, 0x00000000}},  //   marı, _aš_, волс,
  { {0xdcfc01f6, 0xceb3073e, 0x6f040022, 0x00000000}},  //   ları, ניו_, _mric,
  { {0xdb1d000a, 0x6e200023, 0x442f010e, 0x00000000}},  //   _adsè, ëmby, _blg_,
  { {0x6f04000d, 0x61f8037e, 0xdcfc005d, 0x00000000}},  //   _oric, _savl, narı,
  { {0x61f8003b, 0x32d90173, 0x99610089, 0x00000000}},  //   _pavl, gèy_, _cīņa_,
  { {0x442f00ea, 0xdb0f00f6, 0x249e0082, 0x00000000}},  //   _elg_, _decè, _tttm_,
  { {0x403500ed, 0xdcfc011f, 0x3a37009b, 0x00000000}},  //   венс, karı, גרים_,
  { {0x6f04032c, 0x00000000, 0x00000000, 0x00000000}},  //   _bric,   ,   ,
  { {0x61f800eb, 0x6d48073f, 0x9346007c, 0x00000000}},  //   _tavl, údan, _янде,
  { {0x6f040039, 0xbe88007c, 0x00000000, 0x00000000}},  //   _dric, ессе_,   ,
  { {0x6f040740, 0xf1b300b3, 0xcfb00044, 0x00000000}},  //   _eric, _עסק_, _কারন,
  { {0x6f04001a, 0x3ea001d5, 0xac18003b, 0x00000000}},  //   _fric, _ftit_, носу_,
  { {0x06e80055, 0xf9c70741, 0x628a0010, 0x00000000}},  // [8b0] পিডি, ещен, _kifo,
  { {0x8b08013e, 0x9f400288, 0x00000000, 0x00000000}},  //   _spřá, _gaiñ_,   ,
  { {0xdcfc0279, 0xa928007e, 0xbc790088, 0x00000000}},  //   barı, ніце_, _обох_,
  { {0x69d50036, 0xdcfc006b, 0x628a005b, 0x00000000}},  //   _wcze, carı, _lifo,
  { {0xe8df001d, 0x799c0016, 0x80380049, 0x00000000}},  //   _thỏa_, _ffrw, ענדע_,
  { {0x69d50046, 0xb5c202f0, 0x32d901aa, 0x00000000}},  //   _ucze, айшл, vèy_,
  { {0x442f033b, 0x224500ca, 0xaa540545, 0x00000000}},  //   _plg_, vilk_, _сврш,
  { {0xd1380046, 0x130902d3, 0x32d901aa, 0x00000000}},  //   dzą_, дний_, tèy_,
  { {0x628a0039, 0x5695005e, 0x95d900ed, 0x00000000}},  //   _bifo, _разт, _одат_,
  { {0xdcfc0279, 0x32d90263, 0x6442002d, 0x00000000}},  //   zarı, rèy_, _emoi,
  { {0xa2bd02f4, 0xf992009b, 0x628a0056, 0x00000000}},  //   _शिक्, ירי_, _difo,
  { {0xdcfc005f, 0x3ea00742, 0x22450190, 0x00000000}},  //   xarı, _ptit_, silk_,
  { {0x63a90743, 0xe1ee0256, 0x539a0104, 0x00000000}},  //   mben, _кг_, _חינו,
  { {0x63a90089, 0x787800fa, 0x6fa2007d, 0x00000000}},  //   lben, míve, _क्रू,
  { {0x61d6012f, 0xdcfc027d, 0xd1380036, 0x00000000}},  //   _יוסף_, tarı, czą_,
  { {0x6b8f001c, 0x2188007b, 0x51840099, 0x00000000}},  //   _cgcg, _אָפּ, _суча,
  { {0x78780181, 0x27fd018e, 0xea8a06e3, 0x00000000}},  // [8c0] níve, ddwn_, дбал_,
  { {0xdcfc014a, 0x26cf0744, 0x00000000, 0x00000000}},  //   sarı, dugo_,   ,
  { {0xdcfc005d, 0xd7fa0745, 0x7d010374, 0x00000000}},  //   parı, дул_, ålst,
  { {0x26cf0020, 0xb6a600e2, 0x3ead0035, 0x00000000}},  //   fugo_, видл, ţete_,
  { {0x63a90746, 0xfaa60098, 0x00000000, 0x00000000}},  //   dben, _јаго,   ,
  { {0x63a9010f, 0x787800b9, 0x00000000, 0x00000000}},  //   eben, díve,   ,
  { {0x628a01bc, 0xd94601fc, 0x499100a1, 0x00000000}},  //   _rifo, _реви, _ایمر,
  { {0xd70600d7, 0x7c36018e, 0x628a04be, 0x00000000}},  //   _изби, nhyr, _sifo,
  { {0x97ea005f, 0x26dd0046, 0xe0ae0044, 0x00000000}},  //   ışdı, ctwo_, _কমেন,
  { {0x62060088, 0x00000000, 0x00000000, 0x00000000}},  //   тчиз,   ,   ,
  { {0xc4c50464, 0x1be2006e, 0x6457004a, 0x00000000}},  //   _متنو, खभाल_, éxic,
  { {0x23ba004b, 0x14d700b3, 0x787800c4, 0x00000000}},  //   _آداب_, _יובל_, bíve,
  { {0xd1380046, 0x628a0747, 0x787800c4, 0x00000000}},  //   szą_, _tifo, cíve,
  { {0xa3de02fb, 0xdb1601aa, 0x00000000, 0x00000000}},  //   द्र_, mayè,   ,
  { {0x69c8014a, 0x00000000, 0x00000000, 0x00000000}},  //   _ödey,   ,   ,
  { {0xdb0f0035, 0xdfd10025, 0xc61f0309, 0x00000000}},  //   _decî, _اية_, _भव्य_,
  { {0x06d70044, 0x9f5200f6, 0x00000000, 0x00000000}},  // [8d0] _দৈনি, _gayà_,   ,
  { {0x63a90209, 0x26cf0009, 0xbdf5025f, 0x00000000}},  //   zben, vugo_, _спој,
  { {0x27ef01e3, 0x00000000, 0x00000000, 0x00000000}},  //   tegn_,   ,   ,
  { {0xdb060002, 0x00000000, 0x00000000, 0x00000000}},  //   _bekä,   ,   ,
  { {0x7c2d006b, 0x27ef0748, 0x787800c4, 0x00000000}},  //   mkar, regn_, xíve,
  { {0xd7740054, 0x26cf0058, 0xbb3a0049, 0x00000000}},  //   جامع, rugo_, _טערי,
  { {0xd4690175, 0x245a0089, 0x26dd0036, 0x00000000}},  //   нике_, zīme_, stwo_,
  { {0x7c2d002d, 0x78780749, 0x63a9074a, 0x00000000}},  //   nkar, tíve, uben,
  { {0x63a904cb, 0xc7b2034e, 0x7c2d000c, 0x00000000}},  //   rben, _לבן_, ikar,
  { {0x63a90059, 0x96f8002c, 0x7c2d074b, 0x00000000}},  //   sben, _جعفر_, hkar,
  { {0x7c2d00b0, 0x78780181, 0x9f4e00b9, 0x00000000}},  //   kkar, síve, čním_,
  { {0xddd500b9, 0x7c2d00f8, 0x6d48004a, 0x00000000}},  //   mozř, jkar, údam,
  { {0x91e50057, 0x442d074c, 0x7c2d0036, 0x00000000}},  //   _боле, mke_, dkar,
  { {0xdd920426, 0xf7760049, 0x6449074d, 0x00000000}},  //   صور_, טערי_, liei,
  { {0x7c36074e, 0x09b20055, 0xed570269, 0x00000000}},  //   thyr, _চালা, гор_,
  { {0xaca9026c, 0x7c2d006a, 0x09cc0061, 0x00000000}},  //   کھیے_, gkar, ाल्य,
  { {0x9b930054, 0x442d046a, 0xed1700a1, 0x00000000}},  // [8e0] إلكت, ike_, نہیں_,
  { {0xe9d701f9, 0x3b830099, 0x442d006c, 0x00000000}},  //   лку_, слуг, hke_,
  { {0x442d0374, 0x7c2d006b, 0x8c460478, 0x00000000}},  //   kke_, bkar, _бене,
  { {0x442d02ae, 0x7c2d0039, 0xdbd701a2, 0x00000000}},  //   jke_, ckar, mäßi,
  { {0x442d074f, 0xd707007c, 0x64490750, 0x00000000}},  //   dke_, лнце_, diei,
  { {0x442d0100, 0x9f5b0023, 0x7af6005b, 0x00000000}},  //   eke_, _saqë_, mwyt,
  { {0x64490016, 0x7af60016, 0x04660751, 0x00000000}},  //   fiei, lwyt, лтим,
  { {0x25f0013d, 0x4d7b0049, 0xd467003b, 0x00000000}},  //   _इसकी_, ערקע, лије_,
  { {0xa6ca0167, 0xd5d60752, 0x386601d6, 0x00000000}},  //   _سوال_, _متاث, moor_,
  { {0xd6cf0647, 0xe29f009f, 0x7c2d022b, 0x00000000}},  //   _رقم_, íða_, zkar,
  { {0xf5930054, 0x055603f6, 0xa158003b, 0x00000000}},  //   _المج, _стая, тану_,
  { {0x442d001f, 0x764a01aa, 0x5577007b, 0x00000000}},  //   cke_, lify, _געבן_,
  { {0x09cc0055, 0x80c0006e, 0x6d5a009d, 0x00000000}},  //   র্যা, _विके, ûtan,
  { {0x38660007, 0x764a0753, 0xb80b013d, 0x00000000}},  //   hoor_, nify, _सोनम_,
  { {0x16d10754, 0x7c2d0089, 0x38660755, 0x00000000}},  //   _सम्ब, tkar, koor_,
  { {0x09cc0055, 0x386601d6, 0xd175007e, 0x00000000}},  //   র্মা, joor_, _тычы,
  { {0x7c2d0127, 0x386600ab, 0xead50451, 0x00000000}},  // [8f0] rkar, door_, розь,
  { {0x7c2d0756, 0x442d0757, 0xdfd100a1, 0x00000000}},  //   skar, zke_, _ايک_,
  { {0x764a0758, 0x442d0007, 0x09cc0044, 0x00000000}},  //   dify, yke_, র্ভা,
  { {0x386601d6, 0x00000000, 0x00000000, 0x00000000}},  //   goor_,   ,   ,
  { {0x442d0209, 0x644900c4, 0x6f1b01a2, 0x00000000}},  //   vke_, viei, äuch,
  { {0x80aa0055, 0x09cc0055, 0x19940088, 0x00000000}},  //   _কিন্, র্বা, _гаря,
  { {0x442d0759, 0x8459005e, 0x6449032e, 0x00000000}},  //   tke_, крит_, tiei,
  { {0x442d075a, 0x6a6b010f, 0x91fc0089, 0x00000000}},  //   uke_, rüfu, klās,
  { {0xe80b013d, 0x64490145, 0x7cec075b, 0x00000000}},  //   _सोया_, riei, _körö,
  { {0x442d0374, 0xc245004d, 0x27ff0052, 0x00000000}},  //   ske_, рнок, _haun_,
  { {0xc3230055, 0x7878008e, 0x442d016e, 0x00000000}},  //   _বেশি_, líva, pke_,
  { {0xdb0f0181, 0x27ff075c, 0x00000000, 0x00000000}},  //   _mecâ, _jaun_,   ,
  { {0x92b70054, 0x02a7003b, 0x63bb075d, 0x00000000}},  //   _إحصا, _срем, maun,
  { {0x63bb075e, 0xed5a012b, 0x27ff000c, 0x00000000}},  //   laun, вог_, _laun_,
  { {0xdb0f0211, 0x629b06b9, 0x6142075f, 0x00000000}},  //   _decí, lquo, _меша,
  { {0x63bb00e0, 0x229b01c3, 0x27ff0288, 0x00000000}},  //   naun, _kêk_, _naun_,
  { {0x4a46008b, 0x386600b5, 0xa3e70164, 0x00000000}},  // [900] анав, voor_, म्य_,
  { {0x7af60016, 0x787801dc, 0x20000145, 0x00000000}},  //   rwyt, díva, _haii_,
  { {0x41dd007d, 0x63bb0760, 0xf1dd006e, 0x00000000}},  //   _मानस, kaun, _मानन,
  { {0xdb0f001a, 0x63bb001e, 0x20020036, 0x00000000}},  //   _decâ, jaun, ndki_,
  { {0x38660343, 0x764a01aa, 0x27ff04cb, 0x00000000}},  //   roor_, tify, _daun_,
  { {0x7cec0010, 0xb8dc0044, 0x00000000, 0x00000000}},  //   _görö, _আম_,   ,
  { {0x01bb0055, 0x764a0761, 0x38660168, 0x00000000}},  //   ংলাদ, rify, poor_,
  { {0x27ff0762, 0x63bb0006, 0x764a0173, 0x00000000}},  //   _gaun_, gaun, sify,
  { {0x46a30264, 0x07a3030d, 0x00000000, 0x00000000}},  //   _матв, _фаун,   ,
  { {0x27e6000a, 0x201200e7, 0x00000000, 0x00000000}},  //   lfon_, _anyi_,   ,
  { {0x7bc60763, 0xdb0f06f4, 0x20120145, 0x00000000}},  //   _odku, _recí, _bnyi_,
  { {0x78a10010, 0x63bb00ea, 0x27e60016, 0x00000000}},  //   _élve, caun, nfon_,
  { {0x200500b9, 0x629b0068, 0x44f80082, 0x00000000}},  //   ěli_, cquo, _hũ_,
  { {0x20050046, 0x20120020, 0x290a05ae, 0x00000000}},  //   śli_, _enyi_, _orba_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8f470764, 0x7055007a, 0x44f80011, 0x00000000}},  //   _вход, _دنبا, _mũ_,
  { {0x290a010a, 0x207c0049, 0x27ff000c, 0x00000000}},  // [910] _arba_, _באהא, _raun_,
  { {0x39a7007e, 0x24840058, 0x27ff010e, 0x00000000}},  //   ршав, hmmm_, _saun_,
  { {0x69dd0061, 0x7cec0010, 0x69dc0009, 0x00000000}},  //   _पाठी, _vörö, _dcre,
  { {0xdd1c00b9, 0x629b0068, 0x78780765, 0x00000000}},  //   _nářa, yquo, tíva,
  { {0x290a0766, 0x8c1a00b6, 0x7cec0010, 0x00000000}},  //   _erba_, _עושי, _törö,
  { {0x63a20767, 0x7afd0768, 0x63bb00e7, 0x00000000}},  //   _afon, _isst, waun,
  { {0x44f8001d, 0x27ff0085, 0x63bb00e7, 0x00000000}},  //   _cũ_, _taun_, taun,
  { {0xed58012e, 0x80c00309, 0x6d480051, 0x00000000}},  //   יבור_, _विजे, údai,
  { {0x63bb002d, 0x386d002d, 0x86980769, 0x00000000}},  //   raun, _iker_, _вкус_,
  { {0xe4e701fb, 0x629b028c, 0xdb0f0129, 0x00000000}},  //   _відн, rquo, _mecà,
  { {0x92d70055, 0x63a20016, 0x63bb011c, 0x00000000}},  //   াবে_, _ffon, paun,
  { {0x6601014a, 0x44e1076a, 0xc95200b3, 0x00000000}},  //   _halk, mó_, למי_,
  { {0x69c70209, 0x44e10047, 0x539a009b, 0x00000000}},  //   _odje, ló_, _עיסו,
  { {0x69c7008d, 0x6da30200, 0x660100b0, 0x00000000}},  //   _ndje, зира, _jalk,
  { {0x44e1076b, 0x7afd00e0, 0x386d002d, 0x00000000}},  //   nó_, _asst, _oker_,
  { {0x69dc0038, 0x69c7076c, 0xdb0a00b9, 0x00000000}},  //   _scre, _adje, šníh,
  { {0x290a05fa, 0x63b9018e, 0x7afd0009, 0x00000000}},  // [920] _srba_, _mewn, _csst,
  { {0xbf9b0181, 0x69dd0061, 0x386d00ea, 0x00000000}},  //   ndên, _पाणी, _aker_,
  { {0x31ba007b, 0x93f9001c, 0x78a70061, 0x00000000}},  //   רזענ, ्याच_, _ctjv,
  { {0x387f002a, 0x44e1076d, 0xe73a0057, 0x00000000}},  //   _chur_, dó_, лее_,
  { {0x27e6076e, 0x00000000, 0x00000000, 0x00000000}},  //   rfon_,   ,   ,
  { {0x63a20207, 0xceb300a3, 0x660100b4, 0x00000000}},  //   _sfon, ליד_, _calk,
  { {0x44e1076f, 0x96c4013d, 0x7c260023, 0x00000000}},  //   gó_, _रिकॉ, _kokr,
  { {0x44f8001d, 0x69c70770, 0x62990022, 0x00000000}},  //   _vũ_, _zdje, _buwo,
  { {0x8c1b00b6, 0x66010039, 0x3266005e, 0x00000000}},  //   רופי, _falk, йтов,
  { {0x41dd001c, 0x44e10771, 0x11d80025, 0x00000000}},  //   _माणस, bó_, جودة_,
  { {0x04960054, 0x44e10211, 0xdb0f0211, 0x00000000}},  //   _الصح, có_, _mecá,
  { {0x6e25011f, 0x7ae40772, 0x7c260773, 0x00000000}},  //   _sohb, ktit, _nokr,
  { {0x447b007b, 0x00000000, 0x00000000, 0x00000000}},  //   _ענדע,   ,   ,
  { {0x63b90036, 0x4426010e, 0xbc9500ed, 0x00000000}},  //   _zewn, _hoo_, жавј,
  { {0x90a60774, 0x442600e7, 0x7c2606d4, 0x00000000}},  //   _احتم, _koo_, _bokr,
  { {0x442600b0, 0x62990093, 0x7c260022, 0x00000000}},  //   _joo_, _yuwo, _cokr,
  { {0x2fc90775, 0x44e10776, 0x7ae4006a, 0x00000000}},  // [930] _idag_, zó_, gtit,
  { {0x386d0193, 0x98b8005d, 0x4426006c, 0x00000000}},  //   _sker_, _ayrı_, _loo_,
  { {0xda7801e0, 0x7ae40026, 0xdb0f004a, 0x00000000}},  //   сят_, atit, _decá,
  { {0x6f0d00b5, 0x4426011c, 0x44e10211, 0x00000000}},  //   _krac, _noo_, vó_,
  { {0x66010777, 0xe610025a, 0xd3660076, 0x00000000}},  //   _palk, کشن_, _آه_,
  { {0x44e10047, 0xd12605f3, 0x34a9003b, 0x00000000}},  //   tó_, _قم_, авко_,
  { {0x63b90046, 0x66010778, 0xe3b10054, 0x00000000}},  //   _pewn, _valk, ورة_,
  { {0x44e10779, 0x6601077a, 0x42c90140, 0x00000000}},  //   ró_, _walk, агин_,
  { {0xe816001c, 0x44e1076f, 0x660100ab, 0x00000000}},  //   णारा_, só_, _talk,
  { {0x63b90036, 0x44e1077b, 0x60e90437, 0x00000000}},  //   _wewn, pó_, амом_,
  { {0x6f0d077c, 0x3ea9000d, 0x7a3b009d, 0x00000000}},  //   _arac, _atat_, _gîte,
  { {0xa06a0113, 0x4426077d, 0x68e50016, 0x00000000}},  //   рама_, _goo_, ithd,
  { {0x44c5001e, 0x644b077e, 0x7ae40009, 0x00000000}},  //   lē_, _imgi, xtit,
  { {0x6f0d077f, 0x7ae4001c, 0x00000000, 0x00000000}},  //   _drac, vtit,   ,
  { {0x8c010055, 0x27ed001f, 0x3ea900f4, 0x00000000}},  //   _একজন_, _oben_, _etat_,
  { {0x6a70001f, 0xeb97007c, 0x5baa0780, 0x00000000}},  //   häft, жит_, ркам_,
  { {0x3b07026b, 0x6f0d0781, 0x3a26005e, 0x00000000}},  // [940] оето_, _grac, омаг,
  { {0x27ed0146, 0x32050133, 0x2b4000e5, 0x00000000}},  //   _aben_, ndly_, rzic_,
  { {0x7ae40782, 0x6f0d0107, 0xe8160061, 0x00000000}},  //   stit, _zrac, णाला_,
  { {0xdb2400a1, 0xb6c800a1, 0x7ae40048, 0x00000000}},  //   _فوجی, ماتے_, ptit,
  { {0x4426008e, 0xafdb00ea, 0x290702e1, 0x00000000}},  //   _roo_, shøg, ånar_,
  { {0x27ed010f, 0x3af90049, 0xe4a600ed, 0x00000000}},  //   _eben_, _פּרע, орио,
  { {0xd4970783, 0x44260784, 0xd0b1006b, 0x00000000}},  //   оры_, _poo_, _təəs,
  { {0x68e300d4, 0x00000000, 0x00000000, 0x00000000}},  //   ànde,   ,   ,
  { {0x442600c4, 0x69da01df, 0x00000000, 0x00000000}},  //   _voo_, _ötes,   ,
  { {0x81d20055, 0x44260785, 0x6f0d0023, 0x00000000}},  //   হ্ন_, _woo_, _rrac,
  { {0x4a7b007b, 0x44260038, 0xd257007e, 0x00000000}},  //   שריב, _too_, ўцы_,
  { {0x6f0d0395, 0x4034007c, 0x32050133, 0x00000000}},  //   _prac, деюс, adly_,
  { {0x2fc901c3, 0x3d950745, 0x00000000, 0x00000000}},  //   _vdag_, зигр,   ,
  { {0xdef8008b, 0x00000000, 0x00000000, 0x00000000}},  //   цыю_,   ,   ,
  { {0x6ce40088, 0x6f0d0036, 0xbc4b007e, 0x00000000}},  //   міте, _wrac, ачае_,
  { {0x2611006e, 0xafdb0737, 0x69dd0061, 0x00000000}},  //   _धोनी_, riøs, _पाही,
  { {0x6f0d016c, 0x5a350786, 0x97ea005a, 0x00000000}},  // [950] _urac, пнат, ışlı,
  { {0xceb20097, 0x78a30010, 0xd042013f, 0x00000000}},  //   _ריי_, ínvo, drlə,
  { {0x6aad0026, 0x00000000, 0x00000000, 0x00000000}},  //   spaf,   ,   ,
  { {0xdb1f0065, 0x68e50787, 0xa802014a, 0x00000000}},  //   naqë, rthd, _çılg,
  { {0x8c1a009b, 0x00000000, 0x00000000, 0x00000000}},  //   _הורי,   ,   ,
  { {0x3866016c, 0x59e201f5, 0x44c50089, 0x00000000}},  //   čora_, _पायर, tē_,
  { {0x6a700788, 0xafdb00ea, 0x7af9026d, 0x00000000}},  //   räft, snøy, şatı,
  { {0x44390789, 0x57f4025f, 0x44c50089, 0x00000000}},  //   ós_, _опст, rē_,
  { {0xf7490054, 0x051b0044, 0x44c50089, 0x00000000}},  //   _الذي_, তনের_, sē_,
  { {0x3637007a, 0xc2420259, 0xd5b10082, 0x00000000}},  //   _بررس, еньк, _góp_,
  { {0x32050133, 0xdb1d0190, 0x86220167, 0x00000000}},  //   rdly_, _udsæ, _سکول,
  { {0x29360049, 0x3e76000c, 0x00000000, 0x00000000}},  //   פארן_, mæti_,   ,
  { {0x20040027, 0x3e76000c, 0x00000000, 0x00000000}},  //   ľmi_, læti_,   ,
  { {0x443f001c, 0x3d080061, 0x614501ee, 0x00000000}},  //   lhu_, हिले_, _нела,
  { {0xc692009b, 0x91ba009b, 0xed52025a, 0x00000000}},  //   תאם_, _המצי, رپر_,
  { {0x443f078a, 0x645b078b, 0x00000000, 0x00000000}},  //   nhu_, nnui,   ,
  { {0x6b63007e, 0x00000000, 0x00000000, 0x00000000}},  // [960] екта,   ,   ,
  { {0x443f0066, 0xd042006b, 0x499a0783, 0x00000000}},  //   hhu_, vrlə, стая_,
  { {0x290e000c, 0xd88a00a1, 0xa96a0025, 0x00000000}},  //   ífa_, مپئن_, حمام_,
  { {0xfc320054, 0xdb0400b5, 0x7a32000c, 0x00000000}},  //   _أحد_, ncië, _mæti,
  { {0xfbd300b6, 0xf3f9001a, 0x00000000, 0x00000000}},  //   _אתר_, deţ_,   ,
  { {0xe8df001d, 0xdb0f00c4, 0x4b7b009b, 0x00000000}},  //   _giữa_, _secç, _לאכו,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x443f01d5, 0xb3c6013d, 0xe73a00ed, 0x00000000}},  //   ghu_, रृंख, _леб_,
  { {0xdb060010, 0x00000000, 0x00000000, 0x00000000}},  //   _nekü,   ,   ,
  { {0x443f0022, 0x69de0145, 0x7a32000c, 0x00000000}},  //   ahu_, ngpe, _bæti,
  { {0x443f0066, 0x26190309, 0xf1dd013d, 0x00000000}},  //   bhu_, पारी_, _मारन,
  { {0x443f078c, 0xc48603c8, 0x395700b6, 0x00000000}},  //   chu_, _элек, לשים_,
  { {0xee87007c, 0x26c6010e, 0x00000000, 0x00000000}},  //   зыво, nsoo_,   ,
  { {0xd2500084, 0x6ca7078d, 0x9f590023, 0x00000000}},  //   _جنت_, зраж, lesë_,
  { {0xa157078e, 0x61fa0148, 0xe9ff0011, 0x00000000}},  //   _нашу_, metl, _ngạc_,
  { {0x61fa06cf, 0x31c600b9, 0x415b034e, 0x00000000}},  //   letl, bízí_, _לדוג,
  { {0xa3df0204, 0xdb0400f4, 0x8f9c00a0, 0x00000000}},  // [970] _तास_, nciè, _פיזי,
  { {0x61fa078f, 0x443f0790, 0x7c2400e7, 0x00000000}},  //   netl, zhu_, ajir,
  { {0x7c38004a, 0x64400022, 0x00000000, 0x00000000}},  //   ñará, khmi,   ,
  { {0xf7700014, 0x9f590023, 0x61fa0479, 0x00000000}},  //   گام_, jesë_, hetl,
  { {0x61fa011f, 0x64400051, 0x2619007d, 0x00000000}},  //   ketl, dhmi, पाली_,
  { {0xf770031d, 0x61fa0182, 0xf3f90035, 0x00000000}},  //   دام_, jetl, inţe_,
  { {0x443f0791, 0x61fa0792, 0x00000000, 0x00000000}},  //   thu_, detl,   ,
  { {0xc952009b, 0xdb1d0065, 0x52a90793, 0x00000000}},  //   _סמן_, _nesë, овим_,
  { {0x1306007c, 0x443f016e, 0x61fa014a, 0x00000000}},  //   дный_, rhu_, fetl,
  { {0x443f0089, 0x645b001a, 0x10a50794, 0x00000000}},  //   shu_, snui, мион,
  { {0x3de30055, 0x443f0082, 0xdb1d0023, 0x00000000}},  //   য়াল, phu_, _besë,
  { {0xcdc900b6, 0x644003de, 0x78a90059, 0x00000000}},  //   _כך_, chmi, _čevl,
  { {0xdb060263, 0x09d50044, 0x437401fc, 0x00000000}},  //   _lekò, স্যা, _пушт,
  { {0x291100e5, 0x00000000, 0x00000000, 0x00000000}},  //   _orza_,   ,   ,
  { {0x1d07005e, 0x6da302ea, 0x64850051, 0x00000000}},  //   мери_, тиса, róif,
  { {0x6e21000c, 0xdb1d01c3, 0x00000000, 0x00000000}},  //   ölbr, _gesë,   ,
  { {0x29030795, 0xfaff0089, 0x7c360796, 0x00000000}},  // [980] _asja_, šīnu_, rkyr,
  { {0x7c360006, 0x64850051, 0xdb04009d, 0x00000000}},  //   skyr, lóid, ncié,
  { {0x32070038, 0xd00f04e1, 0xeb9a0797, 0x00000000}},  //   _many_, _صلی_, _мин_,
  { {0x9f5901aa, 0x61fa0798, 0x32070799, 0x00000000}},  //   fesè_, zetl, _lany_,
  { {0x61fa079a, 0x46a3007e, 0x96fa0257, 0x00000000}},  //   yetl, вачв, تعار_,
  { {0x6f040020, 0x443d0016, 0x7bc402a6, 0x00000000}},  //   _msic, _alw_, laiu,
  { {0x5e57007b, 0x64400020, 0xe0c70014, 0x00000000}},  //   ויסע_, thmi, _جز_,
  { {0x7bc4079b, 0x672d0023, 0x61fa01d6, 0x00000000}},  //   naiu, ënjë, wetl,
  { {0x3ea000f4, 0x68e10039, 0x61fa079c, 0x00000000}},  //   _nuit_, _äldr, tetl,
  { {0x64400065, 0x2fc000f6, 0x443d079d, 0x00000000}},  //   shmi, _aeig_, _elw_,
  { {0x61fa079e, 0x443d00c4, 0xdb1d0023, 0x00000000}},  //   retl, _flw_, _pesë,
  { {0x68e10039, 0xf993009b, 0x3ea0079f, 0x00000000}},  //   _ålde, כרת_, _buit_,
  { {0x61fa07a0, 0x3ea001a3, 0xdb0d006b, 0x00000000}},  //   petl, _cuit_, çkün,
  { {0x3ea007a1, 0x3207000a, 0x00000000, 0x00000000}},  //   _duit_, _gany_,   ,
  { {0xd30800ad, 0x6e940077, 0x66080190, 0x00000000}},  //   _hệ_, тиру, _madk,
  { {0xdb0601aa, 0xd3080011, 0x3ea0009d, 0x00000000}},  //   _rekò, _kệ_, _fuit_,
  { {0x661a00c7, 0x7a32000c, 0xae0c006e, 0x00000000}},  // [990] _ontk, _lætu, िएशन_,
  { {0x2009054c, 0xdb06000a, 0x00000000, 0x00000000}},  //   _haai_, _pekò,   ,
  { {0xd308001d, 0xdb1d0010, 0x7a32000c, 0x00000000}},  //   _lệ_, _mesé, _nætu,
  { {0xa2cf02fb, 0xec35007b, 0x3157007b, 0x00000000}},  //   _दिल्, _נאָר_, ויבן_,
  { {0x660807a2, 0x200901d6, 0x00000000, 0x00000000}},  //   _badk, _maai_,   ,
  { {0x6298016c, 0x20090007, 0xdb1d01aa, 0x00000000}},  //   _nivo, _laai_, _resè,
  { {0x6d4701d5, 0x9f5901aa, 0x69c501c5, 0x00000000}},  //   nzja, sesè_, mahe,
  { {0xcd98019b, 0x13050098, 0x20090007, 0x00000000}},  //   ודות_, езим, _naai_,
  { {0x320700f6, 0x2fc000d4, 0x443d00c4, 0x00000000}},  //   _pany_, _reig_, _vlw_,
  { {0x660807a3, 0x69c507a4, 0x2486012d, 0x00000000}},  //   _gadk, nahe, _ehom_,
  { {0x09d50055, 0x200907a5, 0x3ea00549, 0x00000000}},  //   স্থা, _baai_, _suit_,
  { {0x7a32009f, 0xf99200a0, 0x78780161, 0x00000000}},  //   _hætt, טרי_, tívi,
  { {0x20090343, 0x63a907a6, 0x648507a7, 0x00000000}},  //   _daai_, mcen, róid,
  { {0x09d50055, 0x63a900bb, 0x3ea00129, 0x00000000}},  //   স্তা, lcen, _vuit_,
  { {0x75f30279, 0x7a3207a8, 0x69c50023, 0x00000000}},  //   mızı, _mætt, dahe,
  { {0x6298016c, 0x98a700b9, 0x3ea007a9, 0x00000000}},  //   _zivo, šně_, _tuit_,
  { {0x1e96013b, 0xfc3f002a, 0xab66003b, 0x00000000}},  // [9a0] _прор, _dlí_, хвал,
  { {0x19b9008b, 0x69c5006c, 0x75f3005a, 0x00000000}},  //   дуць_, gahe, nızı,
  { {0xa3df024c, 0x66080062, 0xba3b07aa, 0x00000000}},  //   तला_, _radk, _suïc,
  { {0xc18c0049, 0xe78607ab, 0x63a907ac, 0x00000000}},  //   קטאָ, нуло, jcen,
  { {0xe7370121, 0x66080007, 0x69c50023, 0x00000000}},  //   нец_, _padk, bahe,
  { {0x63a907ad, 0x69ce0030, 0x69c50082, 0x00000000}},  //   ecen, _udbe, cahe,
  { {0x62980207, 0x00000000, 0x00000000, 0x00000000}},  //   _rivo,   ,   ,
  { {0x63a90190, 0x629801ed, 0x00000000, 0x00000000}},  //   gcen, _sivo,   ,
  { {0xa01b000c, 0x20090007, 0x8857009b, 0x00000000}},  //   llög, _raai_, _נשמע_,
  { {0xd308001d, 0x63a907ae, 0x200900c7, 0x00000000}},  //   _vệ_, acen, _saai_,
  { {0x248607af, 0x63a90030, 0x62980555, 0x00000000}},  //   _thom_, bcen, _vivo,
  { {0xd3080011, 0x44cc00b9, 0x63a90197, 0x00000000}},  //   _tệ_, mě_, ccen,
  { {0x629807b0, 0x69c507b1, 0x00000000, 0x00000000}},  //   _tivo, yahe,   ,
  { {0x614600f4, 0x20090007, 0xfc3f0051, 0x00000000}},  //   _célé, _waai_, _slí_,
  { {0x69c50004, 0x44cc00b9, 0x225901aa, 0x00000000}},  //   vahe, ně_, èske_,
  { {0x9f52008e, 0x657a028a, 0xb7bd0035, 0x00000000}},  //   _cayó_, _myth, _toţi,
  { {0x69c5006c, 0x657a0016, 0x3e76000c, 0x00000000}},  // [9b0] tahe, _lyth, tætt_,
  { {0xbbeb007a, 0xddc701a8, 0xf3f90035, 0x00000000}},  //   _کردم_, bojš, inţa_,
  { {0xe61f001d, 0x63a9013e, 0x69c507b2, 0x00000000}},  //   _đô_, ycen, rahe,
  { {0x7a3207b3, 0x44cc0224, 0x69c507b4, 0x00000000}},  //   _sætt, dě_, sahe,
  { {0xd90f009c, 0xab8402dc, 0x76430022, 0x00000000}},  //   _گیا_, _бурк, thny,
  { {0x7aed0047, 0x657a07b5, 0x649501ca, 0x00000000}},  //   mtat, _byth, _všim,
  { {0xd90f009c, 0x657a005b, 0xf3f90035, 0x00000000}},  //   _دیا_, _cyth, enţa_,
  { {0x6d5807b6, 0x7aed0197, 0x756800a1, 0x00000000}},  //   _žvak, otat, رینہ_,
  { {0x7aed0198, 0x63a907b7, 0x4864005e, 0x00000000}},  //   ntat, rcen, _сърб,
  { {0x7aed00f4, 0x25ac07b8, 0x248d013e, 0x00000000}},  //   itat, _gfdl_, smem_,
  { {0x7aed0065, 0xe8160061, 0x63a900f8, 0x00000000}},  //   htat, णाचा_, pcen,
  { {0x7c2f07b9, 0x6146009d, 0x321c0133, 0x00000000}},  //   _nocr, _sélé, _envy_,
  { {0xe28e008b, 0x09cc0044, 0x00000000, 0x00000000}},  //   _ва_, র্টা,   ,
  { {0xc0a8007a, 0x7aed07ba, 0x82d600a3, 0x00000000}},  //   بایل_, dtat, _יונג_,
  { {0x1fb607bb, 0x442f037e, 0x7aed04f8, 0x00000000}},  //   _испр, _kog_, etat,
  { {0x442f07bc, 0xe8df0011, 0xbc63003b, 0x00000000}},  //   _jog_, _nhựa_, авск,
  { {0x6146028c, 0x7aed07bd, 0x442f0091, 0x00000000}},  // [9c0] _télé, gtat, _mog_,
  { {0x4a43072b, 0xa01b0039, 0x00000000, 0x00000000}},  //   анув, smöt,   ,
  { {0x2dd9007b, 0x442f00c7, 0x4dd90049, 0x00000000}},  //   _אַרב, _oog_, _אַרױ,
  { {0x44cc0224, 0x76410016, 0x657a00f4, 0x00000000}},  //   vě_, _ally, _ryth,
  { {0x7aed000d, 0xa3e80204, 0x6495012d, 0x00000000}},  //   ctat, _बाब_, _iših,
  { {0x657a07be, 0x09cc0055, 0x44cc00b9, 0x00000000}},  //   _pyth, র্জা, tě_,
  { {0x442f0146, 0xe9760014, 0x7f4a006b, 0x00000000}},  //   _bog_, _شهرد, _əfqa,
  { {0x442f0719, 0x6f1600f6, 0x76410145, 0x00000000}},  //   _cog_, _oryc, _elly,
  { {0x657a018e, 0x442f07bf, 0x65c60264, 0x00000000}},  //   _wyth, _dog_, _абза,
  { {0x44cc00b9, 0x442f07c0, 0xb3550014, 0x00000000}},  //   pě_, _eog_, دیها_,
  { {0x7aed07c1, 0x442f0010, 0xd3e40014, 0x00000000}},  //   ztat, _fog_, _مقای,
  { {0x320a004f, 0x7658000b, 0xe537007b, 0x00000000}},  //   žby_, livy, _שטאט_,
  { {0x644200b0, 0xdb0d07c2, 0xdd3b0035, 0x00000000}},  //   _iloi, mbaç, _băşt,
  { {0x7c2f002a, 0x6f1607c3, 0x539b00a0, 0x00000000}},  //   _socr, _dryc, _חידו,
  { {0x442f0022, 0xe29b009b, 0x2d8507c4, 0x00000000}},  //   _yog_, _קשור, åle_,
  { {0x7aed07c5, 0x3d08001c, 0x09cb0061, 0x00000000}},  //   ttat, हिजे_, ाण्य,
  { {0x7aed001a, 0xc4c400a1, 0x4c94007c, 0x00000000}},  // [9d0] utat, _ڈے_, ритс,
  { {0x7aed07c6, 0x201e0089, 0x3eda0049, 0x00000000}},  //   rtat, ētie_, _אַטא,
  { {0x7aed07c7, 0xda7801e0, 0x39a40457, 0x00000000}},  //   stat, тят_, ршув,
  { {0x7aed07c8, 0x00000000, 0x00000000, 0x00000000}},  //   ptat,   ,   ,
  { {0x4421001d, 0x442f001a, 0xdcfe0089, 0x00000000}},  //   _đh_, _rog_, _izpā,
  { {0x69dd001c, 0x6442021e, 0x6d580006, 0x00000000}},  //   _पाटी, _aloi, _žvai,
  { {0x442f0305, 0x644207c9, 0xb7bd001a, 0x00000000}},  //   _pog_, _bloi, _soţu,
  { {0x130907ca, 0x644207cb, 0xe80b013d, 0x00000000}},  //   ений_, _cloi, _सोचा_,
  { {0x628a002a, 0x97ea011f, 0xe5e50014, 0x00000000}},  //   _bhfo, ıştı, _مزای,
  { {0x42250264, 0x00000000, 0x00000000, 0x00000000}},  //   удов,   ,   ,
  { {0x442f07cc, 0xf3f50014, 0xe4e40088, 0x00000000}},  //   _tog_, _متشک, _вічн,
  { {0x644207cd, 0x6f1607ce, 0x00000000, 0x00000000}},  //   _gloi, _pryc,   ,
  { {0xa3e802d2, 0x63bb020c, 0x60da00bb, 0x00000000}},  //   _बात_, mbun, artm,
  { {0xa2d802f4, 0xfce6007c, 0x63bb0039, 0x00000000}},  //   _मित्, лого, lbun,
  { {0xdb1d00b9, 0x00000000, 0x00000000, 0x00000000}},  //   _desí,   ,   ,
  { {0x6e3c07a0, 0x6f1607cf, 0x409507d0, 0x00000000}},  //   skrb, _tryc, _крыт,
  { {0x63bb010f, 0xc053009b, 0x20020145, 0x00000000}},  // [9e0] ibun, _לזה_, meki_,
  { {0x63bb04be, 0x01d50044, 0x00000000, 0x00000000}},  //   hbun, ত্রদ,   ,
  { {0x291e07d1, 0x38cb01b2, 0x9c660014, 0x00000000}},  //   _štab_, فانی_, _مهدو,
  { {0x46a6007e, 0x64950066, 0x200204eb, 0x00000000}},  //   гадв, _eġiz, neki_,
  { {0xa2cf0309, 0x63bb0190, 0x601b00b0, 0x00000000}},  //   _दिग्, dbun, _hämä,
  { {0x7bc60065, 0x64420048, 0x200207d2, 0x00000000}},  //   _heku, _sloi, heki_,
  { {0xa3e802d2, 0x7bc6020c, 0x6442001a, 0x00000000}},  //   _बाद_, _keku, _ploi,
  { {0x765807d3, 0x200207d4, 0x63bb07d5, 0x00000000}},  //   sivy, jeki_, gbun,
  { {0x38550265, 0xc1ea008b, 0x2002014a, 0x00000000}},  //   _търс, ньне_, deki_,
  { {0x7bc6022b, 0x64a60088, 0x27e606d4, 0x00000000}},  //   _leku, _бажа, lgon_,
  { {0xdb1d0181, 0x00000000, 0x00000000, 0x00000000}},  //   _resí,   ,   ,
  { {0x7bc6001e, 0x27e6070d, 0xa3bb0164, 0x00000000}},  //   _neku, ngon_, _अभय_,
  { {0xa857009b, 0x63a207d6, 0x27e60082, 0x00000000}},  //   ריכה_, _igon, igon_,
  { {0x539b00a3, 0xc6940049, 0xdb1d00c4, 0x00000000}},  //   _ניגו, יאָ_, _lesã,
  { {0xf1b300a0, 0x7bc60023, 0x20020032, 0x00000000}},  //   _פסק_, _beku, beki_,
  { {0x2002014a, 0x7bc607d7, 0x00000000, 0x00000000}},  //   ceki_, _ceku,   ,
  { {0x29180047, 0xba5507d8, 0x7bc607d9, 0x00000000}},  // [9f0] _arra_, авај, _deku,
  { {0x63bb0035, 0x2b4b0082, 0x00000000, 0x00000000}},  //   zbun, _đhcđ_,   ,
  { {0x648507da, 0x63bb0036, 0x3eb90089, 0x00000000}},  //   dóin, ybun, lpst_,
  { {0x63a20020, 0x64b10089, 0x7bc601d6, 0x00000000}},  //   _ngon, _jāie, _geku,
  { {0x61f80059, 0x67d407db, 0x291801a3, 0x00000000}},  //   _obvl, сочу, _erra_,
  { {0x7c2d07dc, 0x63a201a3, 0xd00e0044, 0x00000000}},  //   ljar, _agon, ষায়_,
  { {0xce3800b6, 0x7bc6006b, 0x63bb0168, 0x00000000}},  //   ראות_, _yeku, tbun,
  { {0x7c2d07dd, 0xd3f9007e, 0x00000000, 0x00000000}},  //   njar, тэкі_,   ,
  { {0x63bb0109, 0x69c707de, 0xc2450069, 0x00000000}},  //   rbun, _keje, иник,
  { {0xdb040010, 0x63a2022b, 0x69c707df, 0x00000000}},  //   nciá, _egon, _jeje,
  { {0x7c2d07e0, 0x216907e1, 0xafdb0030, 0x00000000}},  //   kjar, тини_, dkøb,
  { {0x660307e2, 0x69c70030, 0x7c2d0066, 0x00000000}},  //   lenk, _leje, jjar,
  { {0x387e028c, 0x7c2d07e3, 0x443f0161, 0x00000000}},  //   _être_, djar, mku_,
  { {0x442d0340, 0x443f07e4, 0x69c70224, 0x00000000}},  //   lje_, lku_, _neje,
  { {0x7afd001e, 0x7c2d07e5, 0x442d0006, 0x00000000}},  //   _apst, fjar, oje_,
  { {0x442d00ee, 0x644907e6, 0x443f07e7, 0x00000000}},  //   nje_, nhei, nku_,
  { {0x69c70047, 0x207b007b, 0x443f07e8, 0x00000000}},  // [a00] _beje, _באקא, iku_,
  { {0xba230364, 0x442d07e9, 0x601b021e, 0x00000000}},  //   одук, hje_, _tämä,
  { {0x7bc6000c, 0x443f0004, 0x64490343, 0x00000000}},  //   _teku, kku_, khei,
  { {0x1ae60057, 0xf0930049, 0x443f0213, 0x00000000}},  //   _комм, ַנג_, jku_,
  { {0x442d07ea, 0x27e60039, 0x443f0395, 0x00000000}},  //   dje_, rgon_, dku_,
  { {0x660307eb, 0x443f001e, 0x442d0036, 0x00000000}},  //   genk, eku_, eje_,
  { {0x44f1001d, 0x7ae400b5, 0x6449002a, 0x00000000}},  //   _cơ_, luit, fhei,
  { {0x64490100, 0x442d008d, 0x62810211, 0x00000000}},  //   ghei, gje_, ello,
  { {0x7ae407ec, 0x2338007c, 0x32660175, 0x00000000}},  //   nuit, уппы_, итов,
  { {0x442d07ed, 0x3866000a, 0x443f0145, 0x00000000}},  //   aje_, lnor_, aku_,
  { {0x850600a2, 0x442d0059, 0x443f0161, 0x00000000}},  //   _خوان, bje_, bku_,
  { {0x442d0046, 0x38660039, 0x6449001f, 0x00000000}},  //   cje_, nnor_, chei,
  { {0x386600e0, 0xfe7f00d4, 0xd3720014, 0x00000000}},  //   inor_, juïc_, _بهش_,
  { {0x7ae4028c, 0x30a602a8, 0x6e95044b, 0x00000000}},  //   duit, _крив, сигу,
  { {0x0ed301f5, 0x7c2d07ee, 0x69c70652, 0x00000000}},  //   _तिकड, tjar, _reje,
  { {0xe51703d7, 0x69c704cb, 0x660307ef, 0x00000000}},  //   थिति_, _seje, zenk,
  { {0x7ae40198, 0xdb0f07f0, 0x66fa0089, 0x00000000}},  // [a10] guit, _recó, nākā,
  { {0x443f07f1, 0x442d07f2, 0x7c2d07f3, 0x00000000}},  //   zku_, zje_, sjar,
  { {0x69c707f4, 0x442d010a, 0x64490007, 0x00000000}},  //   _veje, yje_, yhei,
  { {0x7ae404b4, 0x38660197, 0x3ea904cb, 0x00000000}},  //   buit, gnor_, _kuat_,
  { {0x6603021e, 0x44f1001d, 0x443f0428, 0x00000000}},  //   tenk, _sơ_, vku_,
  { {0xba4500a1, 0x3ea907f5, 0x644900d9, 0x00000000}},  //   _انسٹ, _muat_, whei,
  { {0x442d07f6, 0x64490007, 0x3ea9000d, 0x00000000}},  //   tje_, thei, _luat_,
  { {0x66030036, 0x442d010a, 0x443f07f7, 0x00000000}},  //   senk, uje_, uku_,
  { {0x644907f8, 0x442d07f9, 0xa3e803d7, 0x00000000}},  //   rhei, rje_, _बार_,
  { {0x442d07fa, 0x64490007, 0xa2d8006e, 0x00000000}},  //   sje_, shei, _मिर्,
  { {0x2fc9002a, 0x442d00b5, 0x84670265, 0x00000000}},  //   _beag_, pje_, _къде,
  { {0x3ea9020c, 0x644002a3, 0x442d0065, 0x00000000}},  //   _buat_, ckmi, qje_,
  { {0x14740025, 0x9e660025, 0x6459002b, 0x00000000}},  //   _بالج, ماسن, _imwi,
  { {0x6d4e010f, 0xed5a01ee, 0x7ae40035, 0x00000000}},  //   tzba, гог_, vuit,
  { {0x50b504b6, 0xc212009b, 0x320507fb, 0x00000000}},  //   _услу, _זהו_, mely_,
  { {0xb60301ca, 0x320507fc, 0x2fc901d6, 0x00000000}},  //   _hráč, lely_, _geag_,
  { {0xab270265, 0x9ce80044, 0x7ae400fa, 0x00000000}},  // [a20] бота_, খবেন_, uuit,
  { {0x9d4602e9, 0x27ed0016, 0x78a0006b, 0x00000000}},  //   _геод, _acen_, _simv,
  { {0x7ae400f4, 0xa3e802d2, 0x3979007e, 0x00000000}},  //   suit, _बाल_, асцю_,
  { {0x320507fd, 0x20120173, 0x317a0049, 0x00000000}},  //   hely_, _jayi_, ארעמ,
  { {0x386607fe, 0x7ae400d6, 0x78bb037e, 0x00000000}},  //   rnor_, quit, _čuve,
  { {0xdb1d0030, 0x38660146, 0x27ed0023, 0x00000000}},  //   _besæ, snor_, _ecen_,
  { {0x78a00011, 0x320507ff, 0x64590026, 0x00000000}},  //   _timv, dely_, _bmwi,
  { {0xe8e0001d, 0xa2b400ed, 0x66fa0089, 0x00000000}},  //   _chụp_, обич, tākā,
  { {0x6440000c, 0x661100b0, 0x68fb016c, 0x00000000}},  //   rkmi, ökkä, _ćudi,
  { {0x64400004, 0xc50a031d, 0x66fa0089, 0x00000000}},  //   skmi, _متصل_, rākā,
  { {0x531601ef, 0x20120800, 0x09d50044, 0x00000000}},  //   _گذار, _bayi_, স্কা,
  { {0xa2e6007e, 0x6f0d0801, 0xfe7f00d4, 0x00000000}},  //   _годд, _psac, duïa_,
  { {0x32050802, 0x7e7e0022, 0x3ea902d4, 0x00000000}},  //   bely_, _bkpp, _quat_,
  { {0x6d14007d, 0x32050133, 0x00000000, 0x00000000}},  //   डिंग_, cely_,   ,
  { {0x403501bd, 0x463b0049, 0x00000000, 0x00000000}},  //   _мекс, נעלע,   ,
  { {0x0ca800d7, 0x225e0803, 0x3ea90023, 0x00000000}},  //   стри_, litk_, _tuat_,
  { {0x5a35005e, 0x6a35012b, 0x7e7e0022, 0x00000000}},  // [a30] онат, онађ, _fkpp,
  { {0x27ed0804, 0x6aad0065, 0xfe7f00f6, 0x00000000}},  //   _scen_, rqaf, buïa_,
  { {0xa3e8007d, 0x00000000, 0x00000000, 0x00000000}},  //   बला_,   ,   ,
  { {0xac190805, 0xb90101f5, 0xc0b20082, 0x00000000}},  //   _тому_, _दि_, _sưởi_,
  { {0xd6db0216, 0x1dbf0164, 0xb06600b0, 0x00000000}},  //   уте_, ्रपत, ltää,
  { {0xf7700070, 0x1a94007e, 0x00000000, 0x00000000}},  //   ران_, _наяў,   ,
  { {0x32050038, 0x91fc001e, 0xb06600b0, 0x00000000}},  //   vely_, rnāl, ntää,
  { {0x3205005b, 0x00000000, 0x00000000, 0x00000000}},  //   wely_,   ,   ,
  { {0x32050038, 0x52a60147, 0xe7330318, 0x00000000}},  //   tely_, овым_, _عصر_,
  { {0xe4e70088, 0x2012019a, 0x00000000, 0x00000000}},  //   _гідн, _sayi_,   ,
  { {0x69d802d5, 0x386d01d9, 0xe3b30318, 0x00000000}},  //   óvei, _kjer_, _فرش_,
  { {0xdb1d021e, 0x64590806, 0x60dc0092, 0x00000000}},  //   _kesä, _umwi, árma,
  { {0x6e370807, 0x2d850808, 0x32050161, 0x00000000}},  //   _boxb, ülen_, pely_,
  { {0x76430809, 0xdca600ed, 0xdef8002b, 0x00000000}},  //   nkny, жави, ċċ_,
  { {0xdfd2026c, 0x6da3017a, 0x2d8c080a, 0x00000000}},  //   _ہيں_, дира, åde_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd042005f, 0xe7ff013d, 0xa09b01ce, 0x00000000}},  // [a40] xslə, ोजना_, _דיקט,
  { {0x5e570025, 0x386d080b, 0x25fb006e, 0x00000000}},  //   _وليس_, _ajer_, ल्मी_,
  { {0x7e7c0133, 0xe7aa0745, 0x00000000, 0x00000000}},  //   morp, авел_,   ,
  { {0x7e7c0146, 0xdb1d04ce, 0x7786080c, 0x00000000}},  //   lorp, _besä, олез,
  { {0x7c260066, 0x00000000, 0x00000000, 0x00000000}},  //   _inkr,   ,   ,
  { {0x9633007e, 0x386d0030, 0xc4da003b, 0x00000000}},  //   мніц, _ejer_, ађи_,
  { {0x8675008b, 0x344a080d, 0xdb07000c, 0x00000000}},  //   чыцц, ичин_, élög,
  { {0x386d080e, 0x9cd7009b, 0x7e7c021b, 0x00000000}},  //   _gjer_, קופה_, horp,
  { {0x1666005e, 0x213e0016, 0x7e7c0056, 0x00000000}},  //   _двам, wyth_, korp,
  { {0x7af6010a, 0x76430093, 0xb06600b0, 0x00000000}},  //   ityt, ckny, ytää,
  { {0x7e7c0168, 0x7c26080f, 0x00000000, 0x00000000}},  //   dorp, _onkr,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x09d50055, 0x289b0049, 0x7e7c0810, 0x00000000}},  //   স্টা, ייטא, forp,
  { {0x3f85001e, 0x7c260066, 0xb06600b0, 0x00000000}},  //   ālu_, _ankr, ttää,
  { {0x442602c2, 0x25b9006b, 0x91bb009b, 0x00000000}},  //   _kno_, _əsl_, _דמוי,
  { {0x1bbb0025, 0x00000000, 0x00000000, 0x00000000}},  //   شارع_,   ,   ,
  { {0xe8df0011, 0x44260020, 0xb06600b0, 0x00000000}},  // [a50] _thừa_, _mno_, stää,
  { {0x09e30055, 0x7c2601d9, 0x387f0066, 0x00000000}},  //   ন্না, _enkr, _skur_,
  { {0x3a3800c7, 0x999100b9, 0x00000000, 0x00000000}},  //   _dorp_, _vozů_,   ,
  { {0x442600d2, 0x3835007e, 0xdb1d00b0, 0x00000000}},  //   _nno_, янер, _pesä,
  { {0x2b520036, 0xab8402ea, 0x58bb00a1, 0x00000000}},  //   czyc_, _журк, _چارج_,
  { {0x44260811, 0xd1260025, 0xdb1601aa, 0x00000000}},  //   _ano_, _كم_, payò,
  { {0x04450812, 0x386d0023, 0x44260232, 0x00000000}},  //   зейн, _tjer_, _bno_,
  { {0x387f0169, 0x44f300c4, 0x290300ca, 0x00000000}},  //   _ukur_, rã_, _ipja_,
  { {0x44260466, 0x44f300fa, 0x00000000, 0x00000000}},  //   _dno_, sã_,   ,
  { {0x442601d9, 0x00000000, 0x00000000, 0x00000000}},  //   _eno_,   ,   ,
  { {0x44260009, 0x05190025, 0x00000000, 0x00000000}},  //   _fno_, _دياب_,   ,
  { {0x44d7001a, 0xe8df0011, 0xbbaa006e, 0x00000000}},  //   mă_, _chứa_, _कलेक,
  { {0x7d1e021d, 0x644b0813, 0x44d7000d, 0x00000000}},  //   _srps, _ilgi, lă_,
  { {0x629d0224, 0x00000000, 0x00000000, 0x00000000}},  //   ůsob,   ,   ,
  { {0x44d7000d, 0x4426018e, 0x00000000, 0x00000000}},  //   nă_, _yno_,   ,
  { {0x09e30055, 0x7e7c00ab, 0xc7a500a1, 0x00000000}},  //   ন্মা, sorp, _لڑ_,
  { {0xe9da0256, 0x78bb0091, 0xeb97004c, 0x00000000}},  // [a60] йка_, _čuva, зит_,
  { {0x6f0400f6, 0x9e0a0025, 0x3af400f8, 0x00000000}},  //   _ipic, _ايدك_, räp_,
  { {0xe8fa0057, 0x7af60814, 0x44d7001a, 0x00000000}},  //   сле_, styt, jă_,
  { {0xafdb01e3, 0x44d7001a, 0x7c2601a2, 0x00000000}},  //   lhør, dă_, _unkr,
  { {0xf7430423, 0x3a3804d3, 0x44260068, 0x00000000}},  //   нецо, _torp_, _rno_,
  { {0x644b0006, 0x442600f8, 0xf3f90035, 0x00000000}},  //   _algi, _sno_, viţa_,
  { {0x44d7001a, 0x44260815, 0x69dc00ea, 0x00000000}},  //   gă_, _pno_, _idre,
  { {0xb603001e, 0x68e30211, 0x69ce01a2, 0x00000000}},  //   ēšan, ánde, _hebe,
  { {0x69ce020c, 0x96b90816, 0x7ae401e5, 0x00000000}},  //   _kebe, _духу_, nrit,
  { {0x64aa0224, 0x69ce0166, 0x644b007f, 0x00000000}},  //   _přid, _jebe, _elgi,
  { {0x44d7000d, 0x7ae4010f, 0x69ce023a, 0x00000000}},  //   că_, hrit, _mebe,
  { {0x44260817, 0x69ce001f, 0x00000000, 0x00000000}},  //   _uno_, _lebe,   ,
  { {0x69dc0119, 0xa857009b, 0x00000000, 0x00000000}},  //   _odre, ליטה_,   ,
  { {0x6266023c, 0x8cb10309, 0xbeed007d, 0x00000000}},  //   _عاشق, _आंदो, _जमीन_,
  { {0x7ae40004, 0x6f040142, 0xd7cc001c, 0x00000000}},  //   erit, _epic, ाराच,
  { {0x7ae401c9, 0x69ce002d, 0xdb0d04bc, 0x00000000}},  //   frit, _aebe, scaí,
  { {0x69ce0475, 0x44d7000d, 0x6fc3006e, 0x00000000}},  // [a70] _bebe, ză_, _व्यं,
  { {0x19ab0818, 0x69ce0095, 0x00000000, 0x00000000}},  //   стап_, _cebe,   ,
  { {0x69ce0819, 0xdb1d081a, 0x7ae40197, 0x00000000}},  //   _debe, _jesú, arit,
  { {0x7ae4081b, 0x44d7001a, 0x9cd6009b, 0x00000000}},  //   brit, vă_, _קורה_,
  { {0x7ae40555, 0x69ce02e7, 0x7bdd00f6, 0x00000000}},  //   crit, _febe, _idsu,
  { {0x69ce037f, 0x44d7000d, 0xcb1200b3, 0x00000000}},  //   _gebe, tă_, _שלם_,
  { {0x7bcf04cb, 0x78a20161, 0x7d02016c, 0x00000000}},  //   _kecu, ňova, _ćosk,
  { {0x44d7000d, 0x200b0166, 0xa01b0039, 0x00000000}},  //   ră_, jeci_, slöj,
  { {0x200b037e, 0x44d7000d, 0x1dbf0061, 0x00000000}},  //   deci_, să_, ्रात,
  { {0xe0d9081c, 0x44d7001a, 0x7bcf00e5, 0x00000000}},  //   ово_, pă_, _lecu,
  { {0x7bdd037e, 0x7bcf00d9, 0x69c50048, 0x00000000}},  //   _odsu, _oecu, ibhe,
  { {0x7bcf001a, 0xe3b30025, 0xdb1d00f6, 0x00000000}},  //   _necu, _أرض_, _desú,
  { {0xdb040048, 0x9983007f, 0x6d4100ea, 0x00000000}},  //   sciú, _kojų_, ølan,
  { {0x09e30044, 0x7ae4010e, 0xf2d2009b, 0x00000000}},  //   ন্তা, vrit, _יעד_,
  { {0x7bcf0035, 0xbea3007e, 0x7ae400ab, 0x00000000}},  //   _becu, тарк, writ,
  { {0x69ce020c, 0xdd8f0426, 0x7bcf0035, 0x00000000}},  //   _sebe, شوق_, _cecu,
  { {0x78ae081d, 0x7bcf001a, 0xd91000a6, 0x00000000}},  // [a80] _subv, _decu, گیز_,
  { {0x7ae4022b, 0xe8df001d, 0x6aa700b5, 0x00000000}},  //   rrit, _chữa_, _cijf,
  { {0xfbc6007c, 0x2d96081e, 0x27fd0016, 0x00000000}},  //   _обно, _юрис, ffwn_,
  { {0xab2a01f9, 0x3136007b, 0x7ae40065, 0x00000000}},  //   _дома_, ונעם_, prit,
  { {0x09e30055, 0x69ce081f, 0xe737004d, 0x00000000}},  //   ন্ধা, _tebe, мец_,
  { {0x69dc0820, 0x200b0821, 0x69ce010f, 0x00000000}},  //   _udre, zeci_, _uebe,
  { {0x6935013e, 0xdb060190, 0x00000000, 0x00000000}},  //   _přeš, _afkø,   ,
  { {0x64aa00b9, 0x09e30044, 0xd706003b, 0x00000000}},  //   _přib, ন্দা, _озби,
  { {0x41e60822, 0x64aa013e, 0x69a20061, 0x00000000}},  //   міна, _břic, _कृती,
  { {0xd25003ec, 0xd626006d, 0x63ab00e0, 0x00000000}},  //   اند_, _تعري, _eggn,
  { {0xa01b00b0, 0x629a0203, 0x6935013e, 0x00000000}},  //   llöi, rmto, _třeš,
  { {0xc32a0054, 0x6283000a, 0xd5b10082, 0x00000000}},  //   _وكان_, _ekno, _tác_,
  { {0x200b0823, 0xa2d8006e, 0x00000000, 0x00000000}},  //   reci_, _मिट्,   ,
  { {0x7bcf0824, 0x200b0825, 0x00000000, 0x00000000}},  //   _secu, seci_,   ,
  { {0x38b701d5, 0x320c00ab, 0x6d550026, 0x00000000}},  //   _oħra_, medy_, uzza,
  { {0x28d8006e, 0x320c0826, 0x00000000, 0x00000000}},  //   _डिजि, ledy_,   ,
  { {0x7bcf001e, 0x7b6700ec, 0xfe6e025a, 0x00000000}},  // [a90] _vecu, фтве, شگی_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3c30164, 0x1bd50827, 0x7bcf0035, 0x00000000}},  //   ्रम_, _поня, _tecu,
  { {0x883500a1, 0x2aad0087, 0x00000000, 0x00000000}},  //   رکزئ, _ažbe_,   ,
  { {0x7d0205fa, 0x7c3d0051, 0x320c0027, 0x00000000}},  //   _ćosi, _iosr, kedy_,
  { {0x245101ca, 0x7aed01a3, 0x00000000, 0x00000000}},  //   _máme_, muat,   ,
  { {0x7aed0549, 0x7c3d0828, 0x04b800a1, 0x00000000}},  //   luat, _kosr, وپوں_,
  { {0xdb1d02cc, 0xe8cb0061, 0x00000000, 0x00000000}},  //   _besø, ाठीच,   ,
  { {0x64aa00b9, 0x25a90014, 0x7c3d0829, 0x00000000}},  //   _přic, _فضای_, _mosr,
  { {0x291e0006, 0x320c0133, 0x00000000, 0x00000000}},  //   _štai_, gedy_,   ,
  { {0x75210061, 0x7aed082a, 0x7c3d01c3, 0x00000000}},  //   _urlz, huat, _oosr,
  { {0x7aed04cb, 0x1b060044, 0x00000000, 0x00000000}},  //   kuat, রিতে_,   ,
  { {0xe801001c, 0x7aed008e, 0x6449010f, 0x00000000}},  //   ळ्या_, juat, mkei,
  { {0x443d0038, 0x78a900d9, 0x644900b0, 0x00000000}},  //   _how_, _liev, lkei,
  { {0x6281082b, 0x7c960264, 0x443d0173, 0x00000000}},  //   molo, ерац, _kow_,
  { {0x7aed000b, 0x6281082c, 0x78a90211, 0x00000000}},  //   fuat, lolo, _niev,
  { {0x3b07005e, 0xfe7200a1, 0x7aed0207, 0x00000000}},  // [aa0] нето_, _مدد_, guat,
  { {0x443d0038, 0x9b930025, 0x6449082d, 0x00000000}},  //   _low_, الكت, hkei,
  { {0x6449021e, 0x64850048, 0xef180089, 0x00000000}},  //   kkei, nóis, āļu_,
  { {0x443d0038, 0x7aed003f, 0x38600009, 0x00000000}},  //   _now_, buat, òir_,
  { {0x78a9082e, 0x91fc0089, 0x0c23005e, 0x00000000}},  //   _diev, onāt, _смян,
  { {0x25fb02d2, 0x62810066, 0x7bd60487, 0x00000000}},  //   ल्ली_, jolo, layu,
  { {0x628104f4, 0x3eb201d6, 0x443d0133, 0x00000000}},  //   dolo, _luyt_, _bow_,
  { {0x6449001f, 0x98a3003b, 0x7bd60058, 0x00000000}},  //   gkei, _бисе, nayu,
  { {0x6281082f, 0x443d0082, 0xa3b70025, 0x00000000}},  //   folo, _dow_, راير_,
  { {0x62810830, 0xa68301ee, 0x7bd60831, 0x00000000}},  //   golo, _блуд, hayu,
  { {0x7bd60058, 0x75d30025, 0x00000000, 0x00000000}},  //   kayu, _إيما,   ,
  { {0x44fa048a, 0xd25000a6, 0x00000000, 0x00000000}},  //   më_, انگ_,   ,
  { {0x6281012b, 0x44fa008d, 0xc43b00b6, 0x00000000}},  //   bolo, lë_, _מתאי,
  { {0x62810365, 0x661a021e, 0x386600fa, 0x00000000}},  //   colo, _jatk, hior_,
  { {0x44fa008d, 0x661a021e, 0x7c3d0087, 0x00000000}},  //   në_, _matk, _posr,
  { {0x661a0832, 0x7bd60487, 0x60da00ea, 0x00000000}},  //   _latk, gayu, mstm,
  { {0x44fa0065, 0xeab30025, 0x78a90197, 0x00000000}},  // [ab0] hë_, اعر_, _riev,
  { {0x78a9001e, 0x44fa008d, 0xda780425, 0x00000000}},  //   _siev, kë_, нях_,
  { {0xdd9101ef, 0x78a9001e, 0x44fa008d, 0x00000000}},  //   _خود_, _piev, jë_,
  { {0x64850051, 0x44fa0065, 0x7aed008e, 0x00000000}},  //   hóir, dë_, puat,
  { {0x44fa0007, 0x6281014a, 0xdb0700b0, 0x00000000}},  //   eë_, yolo, ämäs,
  { {0xa50901f9, 0x6281006b, 0x99d4023c, 0x00000000}},  //   дека_, xolo, _متفا,
  { {0x6485002a, 0x44fa0065, 0x443d0036, 0x00000000}},  //   dóir, gë_, _pow_,
  { {0x38660833, 0x62810834, 0x69d70835, 0x00000000}},  //   cior_, wolo, laxe,
  { {0x64490706, 0x661a0065, 0xf7730025, 0x00000000}},  //   rkei, _fatk, _صار_,
  { {0x6485002a, 0x64490836, 0x443d0837, 0x00000000}},  //   góir, skei, _wow_,
  { {0x44fa0023, 0x443d0838, 0x00000000, 0x00000000}},  //   cë_, _tow_,   ,
  { {0x3f6a0404, 0xd5640839, 0x62810232, 0x00000000}},  //   димо_, _ступ, solo,
  { {0x62810207, 0x6e3e01fd, 0x249f01e5, 0x00000000}},  //   polo, _popb, mmum_,
  { {0x248d05a6, 0x63bb0207, 0xfce6004c, 0x00000000}},  //   llem_, lcun, кого,
  { {0x7bd6011c, 0x8d6300ed, 0xfc3f00d4, 0x00000000}},  //   tayu, авре, _boí_,
  { {0x63bb083a, 0x3ce50010, 0x2cab00d9, 0x00000000}},  //   ncun, álva_, _cicd_,
  { {0xcb6704cf, 0x6e3e01a3, 0x44fa0065, 0x00000000}},  // [ac0] вате_, _topb, zë_,
  { {0x7bd6083b, 0xbea601e0, 0x6fa7013d, 0x00000000}},  //   sayu, _шапк, _गणतं,
  { {0x661a083c, 0xa3c30164, 0x7bd6083d, 0x00000000}},  //   _ratk, ्रा_, payu,
  { {0xb90a0164, 0x44fa0065, 0x076a083e, 0x00000000}},  //   _मि_, vë_, وماً_,
  { {0x248d083f, 0x69ca000c, 0x2ca0006c, 0x00000000}},  //   dlem_, ðfes, mmid_,
  { {0x44fa048a, 0x2ca0006c, 0xe737003b, 0x00000000}},  //   të_, lmid_, тељ_,
  { {0x81d70044, 0x386600f8, 0xda0201f5, 0x00000000}},  //   িলা_, pior_, र्णत_,
  { {0x44fa048a, 0x291804d4, 0x661a0075, 0x00000000}},  //   rë_, _isra_, _watk,
  { {0x44fa008d, 0x6d470046, 0x64850051, 0x00000000}},  //   së_, zyja, tóir,
  { {0x91fc001e, 0xd05d006b, 0x44fa0065, 0x00000000}},  //   ciāl, əyəc, pë_,
  { {0x67220840, 0x64850051, 0x44fa0023, 0x00000000}},  //   lvoj, róir, që_,
  { {0xdb040841, 0x64850051, 0x60da054e, 0x00000000}},  //   nció, sóir, rstm,
  { {0x733601f7, 0xf09f0129, 0xdb04008e, 0x00000000}},  //   _جرائ, rmà_, ició,
  { {0x52d700b6, 0x2ca0006c, 0xc6940049, 0x00000000}},  //   _יודע_, emid_, טאָ_,
  { {0x4fc700c0, 0xdb040010, 0x7e6700bb, 0x00000000}},  //   _испа, kció, rijp,
  { {0x30a4007e, 0x3f85006b, 0x5c740478, 0x00000000}},  //   _крыв, ğlub_, алст,
  { {0x2c77002b, 0x6e450379, 0x00000000, 0x00000000}},  // [ad0] għda_, _منظم,   ,
  { {0x68e30842, 0x67220247, 0x99d501d8, 0x00000000}},  //   ándo, dvoj, اقات,
  { {0x248d0667, 0x8af0006b, 0x69d70843, 0x00000000}},  //   ylem_, lzəl, raxe,
  { {0x69ca009f, 0xa01b0210, 0x00000000, 0x00000000}},  //   ðfer, mlös,   ,
  { {0x7c2f0038, 0x64aa00b9, 0xa01b0844, 0x00000000}},  //   _incr, _přin, llös,
  { {0xe29a00ad, 0xdb040819, 0x4519004d, 0x00000000}},  //   _như_, ació, еция_,
  { {0x91fc001e, 0x58d4007c, 0xa01b0210, 0x00000000}},  //   riāl, _вост, nlös,
  { {0xdb040845, 0x69d50032, 0x33260846, 0x00000000}},  //   cció, _heze, _brox_,
  { {0x63bb049a, 0x248d0847, 0x69d50047, 0x00000000}},  //   rcun, rlem_, _keze,
  { {0xa3c30164, 0x63bb0848, 0x248d0062, 0x00000000}},  //   ्रह_, scun, slem_,
  { {0x10a60849, 0x69d500b5, 0x321c0471, 0x00000000}},  //   лион, _meze, _davy_,
  { {0xcea9007b, 0x69d502ae, 0xf99200b3, 0x00000000}},  //   _זי_, _leze, מרי_,
  { {0xe28e012b, 0x442f0161, 0xa2e5041f, 0x00000000}},  //   _га_, _ing_, _солд,
  { {0xa01b084a, 0x764101c3, 0x7c2f009d, 0x00000000}},  //   flös, _joly, _ancr,
  { {0xed5a0175, 0x672207ac, 0x2d8c0030, 0x00000000}},  //   хов_, zvoj, æde_,
  { {0x09cd0044, 0xfe7f00d4, 0x442f0022, 0x00000000}},  //   _লাগা, duïu_, _jng_,
  { {0x69d5084b, 0x2ca0084c, 0x7053023c, 0x00000000}},  // [ae0] _beze, rmid_, _دنيا,
  { {0x442f011c, 0x7c2f084d, 0x2ca00114, 0x00000000}},  //   _lng_, _encr, smid_,
  { {0x69d50691, 0x4996007c, 0x20d1050f, 0x00000000}},  //   _deze, ушат, nši_,
  { {0x442f00e0, 0xa967003b, 0xf3f90035, 0x00000000}},  //   _nng_, ћица_, biţi_,
  { {0xdb040211, 0x69d500c4, 0x76410010, 0x00000000}},  //   rció, _feze, _boly,
  { {0x442f084e, 0x69d5084f, 0x67220850, 0x00000000}},  //   _ang_, _geze, rvoj,
  { {0xdb040219, 0x67220059, 0x20d101d9, 0x00000000}},  //   pció, svoj, jši_,
  { {0x44de01d5, 0x69d5002d, 0x33260851, 0x00000000}},  //   rċ_, _zeze, _prox_,
  { {0x76410047, 0x442f04be, 0x926a0594, 0x00000000}},  //   _foly, _dng_, ерна_,
  { {0x76410852, 0xda14013d, 0x00000000, 0x00000000}},  //   _goly, ड़ित_,   ,
  { {0xd48f0265, 0x74130014, 0x2d8c0036, 0x00000000}},  //   _гр_, _گونا, żdej_,
  { {0x78a2008e, 0x442f0058, 0xd0e5007d, 0x00000000}},  //   nmov, _gng_, _किरण_,
  { {0xe29a001d, 0xdd250089, 0x78a200fa, 0x00000000}},  //   _thư_, dīša, imov,
  { {0x98bc0224, 0xa01b0210, 0x644200bb, 0x00000000}},  //   ávě_, tlös, _hooi,
  { {0x442f018e, 0x78a20059, 0xfe7f0129, 0x00000000}},  //   _yng_, kmov, duït_,
  { {0x78a2016e, 0xf3f9001a, 0x69d50853, 0x00000000}},  //   jmov, tiţi_, _seze,
  { {0x90980070, 0x6442015c, 0x69d5002d, 0x00000000}},  // [af0] _حضور_, _mooi, _peze,
  { {0xf3f9001a, 0xdb1d0129, 0xa01b0039, 0x00000000}},  //   riţi_, _besò, plös,
  { {0x69d50854, 0x98510036, 0x57b500ed, 0x00000000}},  //   _veze, nąć_, абет,
  { {0x64420100, 0x69d500b5, 0xdddc0035, 0x00000000}},  //   _nooi, _weze, porţ,
  { {0x7bcd0855, 0x7bda00b3, 0x17070123, 0x00000000}},  //   mbau, _בקרו, افتی_,
  { {0x7aed0039, 0x7bcd010f, 0x6d480856, 0x00000000}},  //   mrat, lbau, ädag,
  { {0xe3b10054, 0x442f0857, 0x7a4100b9, 0x00000000}},  //   يرة_, _png_, _vítě,
  { {0x20d10119, 0x130901fb, 0x7bcd010f, 0x00000000}},  //   vši_, вний_, nbau,
  { {0x644207a5, 0x442f0858, 0x7aed0859, 0x00000000}},  //   _dooi, _vng_, nrat,
  { {0x24800091, 0xdd250089, 0x7aed085a, 0x00000000}},  //   čima_, zīša, irat,
  { {0x29010010, 0x442f085b, 0x27e0000c, 0x00000000}},  //   ntha_, _tng_, ðing_,
  { {0x442f006a, 0x67290065, 0x20d10059, 0x00000000}},  //   _ung_, _krej, rši_,
  { {0x6f0d0045, 0x999800ca, 0x00000000, 0x00000000}},  //   _cpac, _morš_,   ,
  { {0x20d1085c, 0x8cb1013d, 0x00000000, 0x00000000}},  //   pši_, _आंखो,   ,
  { {0xada604ef, 0xdb12009f, 0xdd25001e, 0x00000000}},  //   равл, _ágús, tīša,
  { {0x67290553, 0x32050190, 0x7bcd0548, 0x00000000}},  //   _orej, lfly_, gbau,
  { {0x7aed085d, 0x2d85085e, 0xfe7f0129, 0x00000000}},  // [b00] grat, üler_, tuït_,
  { {0x09e6085f, 0x8d7600a1, 0xdd250089, 0x00000000}},  //   рожн, _ناجا, sīša,
  { {0x2901002a, 0x7aed0207, 0xaa7b00b9, 0x00000000}},  //   gtha_, arat, _svýc,
  { {0x67290860, 0x64aa00b9, 0x78a20861, 0x00000000}},  //   _brej, _přim, umov,
  { {0x7aed049a, 0x64420007, 0x2bd30309, 0x00000000}},  //   crat, _rooi, तररा,
  { {0x67290862, 0x29010051, 0x78a20387, 0x00000000}},  //   _drej, btha_, smov,
  { {0x250804e1, 0x29010051, 0xafdb01e3, 0x00000000}},  //   ارتی_, ctha_, ljøe,
  { {0x67290863, 0x32050133, 0x941801ab, 0x00000000}},  //   _frej, efly_, ужит_,
  { {0x67290864, 0xd1ca007c, 0xa2b3007c, 0x00000000}},  //   _grej, кунд_, обыч,
  { {0x16630865, 0x228b00ea, 0x3254013b, 0x00000000}},  //   _двум, døks_, свор,
  { {0x7aed0061, 0x6f0d0866, 0x91a90082, 0x00000000}},  //   zrat, _spac, _đã_,
  { {0x7aed007f, 0x50670867, 0x00000000, 0x00000000}},  //   yrat, ртоа,   ,
  { {0xfe7f00d4, 0x00000000, 0x00000000, 0x00000000}},  //   duïr_,   ,   ,
  { {0x7aed0868, 0x9f40001f, 0x69d8000c, 0x00000000}},  //   vrat, _weiß_, ðvel,
  { {0x7aed0869, 0xdd95007e, 0x929b009b, 0x00000000}},  //   wrat, савы, _שיות,
  { {0x7aed086a, 0x228b00ea, 0x628801ed, 0x00000000}},  //   trat, søkt_, lodo,
  { {0x7bcd086b, 0x64aa0224, 0xdb99072b, 0x00000000}},  // [b10] rbau, _přij, увач_,
  { {0x6288018e, 0xe9ab06c6, 0xab84086c, 0x00000000}},  //   nodo, ندان_, цуск,
  { {0x7aed086d, 0x6729012d, 0x39470035, 0x00000000}},  //   srat, _srej, âns_,
  { {0x6729086e, 0x7aed086f, 0x628806b8, 0x00000000}},  //   _prej, prat, hodo,
  { {0x29010870, 0x62880871, 0xdd280089, 0x00000000}},  //   stha_, kodo, mēša,
  { {0xb6070373, 0xdd28001e, 0x29010051, 0x00000000}},  //   рядк, lēša, ptha_,
  { {0xd4690872, 0x628801c5, 0x00000000, 0x00000000}},  //   лике_, dodo,   ,
  { {0x67290873, 0xdd280089, 0xb733009e, 0x00000000}},  //   _trej, nēša, _وہاب,
  { {0x672901d9, 0x6288018e, 0x9f440279, 0x00000000}},  //   _urej, fodo, ümü_,
  { {0x62880874, 0x8b58009b, 0x00000000, 0x00000000}},  //   godo, ייחס_,   ,
  { {0x32050875, 0xf5950054, 0x00000000, 0x00000000}},  //   rfly_, _الاج,   ,
  { {0x2056008b, 0x7ae20876, 0xb7bd00e5, 0x00000000}},  //   стор, šoti, _faţe,
  { {0x62880016, 0x443f0089, 0xdd280089, 0x00000000}},  //   bodo, mju_, dēša,
  { {0x62880082, 0xb6cc0279, 0x645b0877, 0x00000000}},  //   codo, _şükü, lhui,
  { {0xdd9201fa, 0x443f0006, 0xc69200a3, 0x00000000}},  //   سور_, oju_, פאל_,
  { {0x443f0213, 0x645b00b5, 0x78a30112, 0x00000000}},  //   nju_, nhui, ïnvl,
  { {0xbbb80061, 0x8c43005e, 0x00000000, 0x00000000}},  // [b20] _अलीक, чете,   ,
  { {0x443f006c, 0xe9d70878, 0x64aa00b9, 0x00000000}},  //   hju_, йку_, _přik,
  { {0x08fa0879, 0x645b0112, 0x443f000c, 0x00000000}},  //   طراب_, khui, kju_,
  { {0x443f01d5, 0xb8eb00a1, 0xdd280089, 0x00000000}},  //   jju_, ابلے_, cēša,
  { {0x443f087a, 0xf3ff0055, 0xeb75007e, 0x00000000}},  //   dju_, ্যার_, _дырэ,
  { {0x7c24038c, 0x89f5008b, 0x443f087b, 0x00000000}},  //   ldir, _мясц, eju_,
  { {0x62880027, 0x69de087c, 0x645b0048, 0x00000000}},  //   vodo, mape, fhui,
  { {0x7c240475, 0x62880046, 0x443f0028, 0x00000000}},  //   ndir, wodo, gju_,
  { {0x35fa01f7, 0x00000000, 0x00000000, 0x00000000}},  //   _مراد_,   ,   ,
  { {0x69de0020, 0xdd280089, 0x443f087d, 0x00000000}},  //   nape, zēša, aju_,
  { {0x628806dc, 0x7c24087e, 0x443f087f, 0x00000000}},  //   rodo, kdir, bju_,
  { {0x62880880, 0x69de0881, 0x645b0882, 0x00000000}},  //   sodo, hape, chui,
  { {0x69de04d3, 0x628805fd, 0x7c24018e, 0x00000000}},  //   kape, podo, ddir,
  { {0x3dd90055, 0x5eb80044, 0x69de0883, 0x00000000}},  //   _তাহল, _অবশে, jape,
  { {0x69de0047, 0x64aa0224, 0xdd280089, 0x00000000}},  //   dape, _přih, tēša,
  { {0x7c24011c, 0x60c70884, 0xa177009b, 0x00000000}},  //   gdir, íjme, _לעוד_,
  { {0xdd28001e, 0xeabf0011, 0xf3fa0044, 0x00000000}},  // [b30] rēša, _trùm_, _আসার_,
  { {0x443f01d5, 0x7b740025, 0x69de0885, 0x00000000}},  //   zju_, أطفا, gape,
  { {0x7c240886, 0x984b0887, 0xdd2801c5, 0x00000000}},  //   bdir, ляда_, pēša,
  { {0x19a80888, 0x987c00b9, 0x00000000, 0x00000000}},  //   ступ_, bíč_,   ,
  { {0x443f0889, 0x7bdf088a, 0xe73900a8, 0x00000000}},  //   vju_, maqu, рел_,
  { {0xdb1d0073, 0x7bdf00d6, 0x1b060044, 0x00000000}},  //   _besö, laqu, রিখে_,
  { {0xf53201f9, 0x443f088b, 0x3eb3088c, 0x00000000}},  //   дејќ, tju_, _mixt_,
  { {0x7bdf088d, 0x9479003b, 0x443f088e, 0x00000000}},  //   naqu, јску_, uju_,
  { {0x443f088f, 0x645b01b5, 0xa5f9003b, 0x00000000}},  //   rju_, rhui, _везу_,
  { {0x645b0168, 0x7c240890, 0xdd1c01ca, 0x00000000}},  //   shui, zdir, váže,
  { {0x443f0891, 0x932700a6, 0x61450269, 0x00000000}},  //   pju_, _گران, цена,
  { {0x69de0892, 0x1faa0893, 0x00000000, 0x00000000}},  //   zape, икни_,   ,
  { {0x7bdf00d4, 0x93270123, 0x645901f3, 0x00000000}},  //   daqu, _دران, _ilwi,
  { {0x6d4e007f, 0xdd1c0062, 0x69de0288, 0x00000000}},  //   tyba, ráže, xape,
  { {0xa3bd0183, 0x69de0894, 0x7bdf0895, 0x00000000}},  //   _आला_, vape, faqu,
  { {0x69de0896, 0x224700d9, 0xdb1d00c4, 0x00000000}},  //   wape, _honk_, _lesõ,
  { {0x7c240897, 0x2005005f, 0xf412019b, 0x00000000}},  // [b40] rdir, əli_, ופן_,
  { {0x22470007, 0x49960545, 0x00000000, 0x00000000}},  //   _jonk_, ошет,   ,
  { {0x8c460898, 0x69de022b, 0xdd0f011f, 0x00000000}},  //   _дене, rape, mışt,
  { {0xdd0f014a, 0x9f480011, 0x7af600d9, 0x00000000}},  //   lışt, _điêu_, puyt,
  { {0xcfbc0044, 0x64aa00b9, 0xfaa602b8, 0x00000000}},  //   _অজান, _křiv, _мамо,
  { {0x7bc40899, 0x64590066, 0x7ae40051, 0x00000000}},  //   lciu, _alwi, msit,
  { {0xd90d00e9, 0x7ae40051, 0x81cf0044, 0x00000000}},  //   _میل_, lsit, ষণা_,
  { {0x7bc4001a, 0x7ae405e0, 0x00000000, 0x00000000}},  //   nciu, osit,   ,
  { {0x69dc089a, 0x224700e0, 0x7bc40006, 0x00000000}},  //   _kere, _bonk_, iciu,
  { {0x69dc0030, 0x7ae4089b, 0x24510051, 0x00000000}},  //   _jere, isit, _lámh_,
  { {0xd257008b, 0x69dc020c, 0x2247089c, 0x00000000}},  //   іць_, _mere, _donk_,
  { {0xe0cf089d, 0x69dc00b5, 0x7bdf00d6, 0x00000000}},  //   کزی_, _lere, xaqu,
  { {0x7bdf06d2, 0x76480022, 0x78bc0203, 0x00000000}},  //   vaqu, _kody, _lurv,
  { {0x69dc012b, 0x764801aa, 0x7ae4017d, 0x00000000}},  //   _nere, _jody, dsit,
  { {0x7bdf00f4, 0x7ae4089e, 0x76480036, 0x00000000}},  //   taqu, esit, _mody,
  { {0x69dc0207, 0x3ced089f, 0xa06807d8, 0x00000000}},  //   _aere, čev_, _маја_,
  { {0x69dc08a0, 0x201908a1, 0x7ae40058, 0x00000000}},  // [b50] _bere, mesi_, gsit,
  { {0x2019014a, 0x69dc0585, 0x76480016, 0x00000000}},  //   lesi_, _cere, _nody,
  { {0x69dc08a2, 0x7bdf008e, 0xfe700076, 0x00000000}},  //   _dere, paqu, _جدي_,
  { {0x765a08a3, 0x2019011f, 0xb17b007b, 0x00000000}},  //   _alty, nesi_, סטאר,
  { {0x69dc08a4, 0x2ca904cb, 0x27e0000c, 0x00000000}},  //   _fere, mmad_, ðina_,
  { {0x69dc08a5, 0x201908a6, 0x2ca9006c, 0x00000000}},  //   _gere, hesi_, lmad_,
  { {0x7bdd04cb, 0x201908a7, 0x6e250066, 0x00000000}},  //   _kesu, kesi_, _mahb,
  { {0x7bdd0343, 0x69c505ca, 0x201906e6, 0x00000000}},  //   _jesu, lche, jesi_,
  { {0x76d5006d, 0x69dc005a, 0x2019014a, 0x00000000}},  //   _رياض, _yere, desi_,
  { {0x69c503a1, 0x7bdd0170, 0x2ca908a8, 0x00000000}},  //   nche, _lesu, hmad_,
  { {0x69c5001f, 0x201908a9, 0x69d8000c, 0x00000000}},  //   iche, fesi_, ðvei,
  { {0x7bdd010a, 0x245808aa, 0x7ae4007f, 0x00000000}},  //   _nesu, _téma_, ysit,
  { {0x245108ab, 0x64aa00b9, 0x62350437, 0x00000000}},  //   _námi_, _přiv, _неду,
  { {0x248d0116, 0x69c508ac, 0xe29801e1, 0x00000000}},  //   loem_, jche, _даі_,
  { {0x61e1021e, 0x7bdd001f, 0xdca60517, 0x00000000}},  //   mall, _besu, зави,
  { {0x2019014a, 0x61e100b0, 0x248d0007, 0x00000000}},  //   cesi_, lall, noem_,
  { {0x69dc04d4, 0x7bdd0030, 0x78bc0549, 0x00000000}},  // [b60] _pere, _desu, _surv,
  { {0x61e10038, 0x7bc40207, 0x78bc08ad, 0x00000000}},  //   nall, sciu, _purv,
  { {0x7ae404bd, 0x7648010a, 0x7bdd0016, 0x00000000}},  //   ssit, _rody, _fesu,
  { {0x69c508ae, 0x61e108af, 0x69dc08b0, 0x00000000}},  //   ache, hall, _were,
  { {0x61e106d5, 0x387f0039, 0x69c501a2, 0x00000000}},  //   kall, _djur_, bche,
  { {0x61e108b1, 0x78bc08b2, 0x69c50207, 0x00000000}},  //   jall, _turv, cche,
  { {0x20c1001d, 0x2019014a, 0xfaa30816, 0x00000000}},  //   _nói_, yesi_, _чаро,
  { {0x7c2608b3, 0x6d4100b0, 0x06660123, 0x00000000}},  //   _jakr, älai, _کارپ,
  { {0x66180027, 0x61e1010f, 0x67200243, 0x00000000}},  //   pevk, fall, _usmj,
  { {0x61e10625, 0x2019023a, 0x20c10011, 0x00000000}},  //   gall, wesi_, _bói_,
  { {0x2019011f, 0xcfe10044, 0x69c30059, 0x00000000}},  //   tesi_, _ভাবন, žneg,
  { {0xe3a7026c, 0x7c260142, 0x3dd90044, 0x00000000}},  //   _کشمی, _nakr, _তাইল,
  { {0x61e108b4, 0x2019011f, 0x69c50462, 0x00000000}},  //   ball, resi_, yche,
  { {0x4426000b, 0x61e10038, 0x7bdd020c, 0x00000000}},  //   _hao_, call, _sesu,
  { {0x442601cd, 0x20c10011, 0x7bdd003c, 0x00000000}},  //   _kao_, _gói_, _pesu,
  { {0x442608b5, 0x201908b6, 0x7c26008a, 0x00000000}},  //   _jao_, qesi_, _cakr,
  { {0xd6d708b7, 0x4426011c, 0x69c50038, 0x00000000}},  // [b70] _সম্প, _mao_, tche,
  { {0x4426001d, 0x27e0009f, 0x69c5010f, 0x00000000}},  //   _lao_, ðinn_, uche,
  { {0x69c508b8, 0x291901fa, 0x7bdd08b9, 0x00000000}},  //   rche, تقاد_, _tesu,
  { {0x69c508ba, 0x442608bb, 0x61e1027b, 0x00000000}},  //   sche, _nao_, zall,
  { {0x69c508bc, 0x61e1005d, 0x79950036, 0x00000000}},  //   pche, yall, _wyzw,
  { {0x7c260046, 0x61e100d4, 0xf1ba0082, 0x00000000}},  //   _zakr, xall, _ngơ_,
  { {0x61e108bd, 0x4426001d, 0x7c3a0051, 0x00000000}},  //   vall, _bao_, _úcrá,
  { {0x4426001d, 0xdb0d027b, 0x61e10016, 0x00000000}},  //   _cao_, lcañ, wall,
  { {0x442608be, 0x20c10011, 0x3b09006b, 0x00000000}},  //   _dao_, _sói_, ntaq_,
  { {0x81bc0089, 0x25a000b9, 0x44260288, 0x00000000}},  //   ldēj, řila_, _eao_,
  { {0x26cd01a8, 0x61e108bf, 0x355503ab, 0x00000000}},  //   _hteo_, rall, _تناز,
  { {0xd36e007a, 0x44260082, 0x81bc0089, 0x00000000}},  //   اهی_, _gao_, ndēj,
  { {0x61e108c0, 0x00000000, 0x00000000, 0x00000000}},  //   pall,   ,   ,
  { {0x7c26037e, 0x4426000b, 0x13e20044, 0x00000000}},  //   _sakr, _zao_, _যায়,
  { {0x4426000b, 0x7c260006, 0x27ed00f8, 0x00000000}},  //   _yao_, _pakr, _oden_,
  { {0x44260011, 0x8af0006b, 0x27ed014a, 0x00000000}},  //   _xao_, yyəd, _nden_,
  { {0xeb97007c, 0x7c2600ea, 0xc6240044, 0x00000000}},  // [b80] дит_, _vakr, পাতা_,
  { {0x7c2608c1, 0x63bc00b9, 0x24800059, 0x00000000}},  //   _wakr, ěrni, čimi_,
  { {0x7c2608c2, 0xa806008b, 0xa3bd0061, 0x00000000}},  //   _takr, дзел, _आलं_,
  { {0xd7ef0025, 0x27ed0146, 0x00000000, 0x00000000}},  //   لكم_, _cden_,   ,
  { {0x4426001d, 0xdb1d0190, 0x47360025, 0x00000000}},  //   _rao_, _afsæ, براز,
  { {0x442608c3, 0x27ed08c4, 0xdd1d01ca, 0x00000000}},  //   _sao_, _eden_, lášt,
  { {0x44260091, 0x644b08c5, 0x00000000, 0x00000000}},  //   _pao_, _bogi,   ,
  { {0x644b04bf, 0xfc3f0082, 0x7af60036, 0x00000000}},  //   _cogi, _khía_, oryt,
  { {0x84ea013d, 0x442608c6, 0xb286007e, 0x00000000}},  //   _टिकट_, _vao_, дынк,
  { {0x4426000b, 0x64aa00b9, 0x65790051, 0x00000000}},  //   _wao_, _přis, ábhá,
  { {0x09f700b6, 0x4426006a, 0xd48f030d, 0x00000000}},  //   ומים_, _tao_, _ар_,
  { {0xdbd603b6, 0x644b0016, 0x442600f6, 0x00000000}},  //   _jääd, _gogi, _uao_,
  { {0xfe730076, 0x00000000, 0x00000000, 0x00000000}},  //   ندس_,   ,   ,
  { {0x63a20032, 0x7af608c7, 0x00000000, 0x00000000}},  //   _izon, dryt,   ,
  { {0xdd94008b, 0xafdb08c8, 0x425500a1, 0x00000000}},  //   вары, ljøm, _سنٹر,
  { {0x7af60065, 0x3b09002b, 0xaa7b04bb, 0x00000000}},  //   fryt, ttaq_, _zvýh,
  { {0x5a35005e, 0xf094009b, 0x7af608c9, 0x00000000}},  // [b90] ннат, _בנק_, gryt,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x80e00044, 0x57f5013b, 0x629a057b, 0x00000000}},  //   পূর্, епет, ilto,
  { {0x63a20007, 0x7af601c9, 0xc19b009b, 0x00000000}},  //   _ozon, bryt, חשבי,
  { {0x6d550010, 0x81bc0089, 0x387d0016, 0x00000000}},  //   lyza, rdēj, rnwr_,
  { {0x644b08ca, 0xe5a5058e, 0x00000000, 0x00000000}},  //   _sogi, нили,   ,
  { {0x63a20047, 0x644b0213, 0x00000000, 0x00000000}},  //   _azon, _pogi,   ,
  { {0x03250072, 0x27ed0018, 0x63a2002b, 0x00000000}},  //   един, _uden_, _bzon,
  { {0xe61000d3, 0x64aa00b9, 0x200c0010, 0x00000000}},  //   _چشم_, _přir, ődik_,
  { {0x63a201ee, 0x64b10089, 0x24510062, 0x00000000}},  //   _dzon, _jāiz, _rámu_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe730026c, 0x629a08cb, 0xb602002b, 0x00000000}},  //   _حصہ_, alto, _ħġie,
  { {0xafdb0056, 0x00000000, 0x00000000, 0x00000000}},  //   nkøy,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x40960072, 0xdd9206dd, 0x00000000, 0x00000000}},  //   _прит, اوز_,   ,
  { {0xfc3f001d, 0x7af604a5, 0x00000000, 0x00000000}},  //   _phía_, tryt,   ,
  { {0x7bd60058, 0xc2cc0049, 0x00000000, 0x00000000}},  // [ba0] rbyu, ַמאָ,   ,
  { {0xcfb7009b, 0xdbd600b0, 0x7af60052, 0x00000000}},  //   _אלפי_, _sääd, rryt,
  { {0xdbd60103, 0x00000000, 0x00000000, 0x00000000}},  //   _pääd,   ,   ,
  { {0x27e008cc, 0xe3a701f7, 0x2002003f, 0x00000000}},  //   úin_, _مر_, ngki_,
  { {0x81d60044, 0x00000000, 0x00000000, 0x00000000}},  //   িণত_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x245101e5, 0xfc3f0048, 0x00000000, 0x00000000}},  //   _náms_, _mhín_,   ,
  { {0x25a000b9, 0xccf308cd, 0x629a08ce, 0x00000000}},  //   řilo_, אכה_, wlto,
  { {0x0877007b, 0x27e60058, 0xb5fc002b, 0x00000000}},  //   _נעמט_, maon_, _alġe,
  { {0x27e608cf, 0xaa16007e, 0x3eba00d9, 0x00000000}},  //   laon_, дзiц, _nipt_,
  { {0x64a6013b, 0x629a08d0, 0x00000000, 0x00000000}},  //   _зажа, rlto,   ,
  { {0x20b4007e, 0x25a101a2, 0x27e60058, 0x00000000}},  //   лёўс, ühle_, naon_,
  { {0x3ce30061, 0x3eba00d9, 0x00000000, 0x00000000}},  //   टीने_, _bipt_,   ,
  { {0xfc3f0011, 0x6114007e, 0x6d550036, 0x00000000}},  //   _chín_, _адку, tyza,
  { {0x27e608d1, 0xdd95007e, 0x2d9a004a, 0x00000000}},  //   kaon_, тавы, _cype_,
  { {0x6d550036, 0x321e08d2, 0xc5e60044, 0x00000000}},  //   ryza, lety_, নলিপ,
  { {0x200c005f, 0x291808d3, 0x00000000, 0x00000000}},  // [bb0] ədi_, _apra_,   ,
  { {0x321e0036, 0x06cf0044, 0x9e670025, 0x00000000}},  //   nety_, _রিলি, _ساخن,
  { {0xa3c2007d, 0xfe7f00f6, 0xf8b108d4, 0x00000000}},  //   ्डा_, duïx_, لکر_,
  { {0xab5b00c4, 0x9cd600a0, 0x69d8000c, 0x00000000}},  //   _agüe, _שורה_, ðver,
  { {0x58b80025, 0x7c2d08d5, 0x38a7006c, 0x00000000}},  //   رامج_, mdar, võrd_,
  { {0x7c2d009f, 0xafdb00ea, 0xf6d40014, 0x00000000}},  //   ldar, rkøy, ازند,
  { {0x64aa0224, 0xc984005e, 0x60cd016c, 0x00000000}},  //   _přip, _бути, _čamo,
  { {0x248901ae, 0x00000000, 0x00000000, 0x00000000}},  //   čamo_,   ,   ,
  { {0x321e00ab, 0x1306007c, 0x7c2d00ea, 0x00000000}},  //   fety_, вный_, idar,
  { {0xa77408d6, 0x68e10030, 0x7c2d005b, 0x00000000}},  //   _случ, _ælds, hdar,
  { {0x320b0036, 0x332608d7, 0x3eba0009, 0x00000000}},  //   ęcy_, _esox_, _ript_,
  { {0x7c2d0089, 0x2bd30061, 0x3f8c013f, 0x00000000}},  //   jdar, धुमा, şdum_,
  { {0xf8b2007b, 0x7c2d018e, 0x442d0483, 0x00000000}},  //   ישט_, ddar, mde_,
  { {0x7c2d08d8, 0x2d9a01d6, 0x443d08d9, 0x00000000}},  //   edar, _pype_, _hnw_,
  { {0x442d03fd, 0x67220036, 0x2d9a01a2, 0x00000000}},  //   ode_, zwoj, _qype_,
  { {0x61e300b7, 0x644908da, 0x7c2d011c, 0x00000000}},  //   _henl, njei, gdar,
  { {0x442d001e, 0xc05300b6, 0x7c3d0009, 0x00000000}},  // [bc0] ide_, _כזה_, _dnsr,
  { {0x2d9a0365, 0x442d021e, 0x628108db, 0x00000000}},  //   _type_, hde_, nnlo,
  { {0x442d08dc, 0x61e30093, 0x27e6006a, 0x00000000}},  //   kde_, _menl, taon_,
  { {0x442d08dd, 0x3860002a, 0x78a9028a, 0x00000000}},  //   jde_, óir_, _chev,
  { {0xe1e700d3, 0x442d0292, 0x2ee001aa, 0x00000000}},  //   _پس_, dde_, _jwif_,
  { {0x442d0168, 0x27e60058, 0x443d00d9, 0x00000000}},  //   ede_, saon_, _anw_,
  { {0x442d06b2, 0x291808de, 0x60c301a2, 0x00000000}},  //   fde_, _upra_, _nunm,
  { {0x442d08df, 0x98a60478, 0x443d0068, 0x00000000}},  //   gde_, _рибе, _cnw_,
  { {0x68e10030, 0x799c0016, 0xd707007c, 0x00000000}},  //   _ældr, _hyrw, _инте_,
  { {0x7c2d066e, 0x386602d5, 0x443d018e, 0x00000000}},  //   zdar, lhor_, _enw_,
  { {0x26c40020, 0x442d08e0, 0x321e0395, 0x00000000}},  //   _humo_, bde_, rety_,
  { {0xf993019b, 0x38660181, 0x68e308e1, 0x00000000}},  //   ירת_, nhor_, ândi,
  { {0x321e08e2, 0x61e30173, 0x69ce000c, 0x00000000}},  //   pety_, _fenl, _ofbe,
  { {0x4256025f, 0xdce50027, 0x61e304cd, 0x00000000}},  //   _штет, _vyhľ, _genl,
  { {0xac19012b, 0x26c40032, 0x61e808e3, 0x00000000}},  //   нову_, _lumo_, madl,
  { {0xfbd300d3, 0x69ce02ae, 0x7c2d008a, 0x00000000}},  //   شتر_, _afbe, udar,
  { {0x38660065, 0x00000000, 0x00000000, 0x00000000}},  // [bd0] dhor_,   ,   ,
  { {0x442d08e4, 0xf09f04bd, 0x78a90023, 0x00000000}},  //   zde_, llà_, _shev,
  { {0x442d08e5, 0x9f4e0010, 0x6abc08e6, 0x00000000}},  //   yde_, önöm_, _dirf,
  { {0x24860091, 0x7c3d0170, 0x7c2d006b, 0x00000000}},  //   _njom_, _unsr, qdar,
  { {0x442d0018, 0xdbd1006c, 0x443d00d9, 0x00000000}},  //   vde_, _müüd, _rnw_,
  { {0x442d08e7, 0x6a6001e5, 0x7aed08e8, 0x00000000}},  //   wde_, _höfn, msat,
  { {0x2609001c, 0x78a908e9, 0x26c400f6, 0x00000000}},  //   _साठी_, _thev, _eumo_,
  { {0x442d08ea, 0x2901011c, 0x26c408eb, 0x00000000}},  //   ude_, muha_, _fumo_,
  { {0x387c009d, 0x645b0288, 0x2901011c, 0x00000000}},  //   èvre_, rkui, luha_,
  { {0x442d08ec, 0xb7bd000d, 0x645b0007, 0x00000000}},  //   sde_, _naţi, skui,
  { {0x61e30030, 0x442d0129, 0x2901011c, 0x00000000}},  //   _venl, pde_, nuha_,
  { {0x44e1010a, 0xbf9b0181, 0x833501fa, 0x00000000}},  //   mų_, rgên, _مرتض,
  { {0x44e10006, 0xa3c20316, 0x09ca0044, 0x00000000}},  //   lų_, ्डर_, ষরতা,
  { {0x249f000c, 0x7aed0030, 0x2901006a, 0x00000000}},  //   llum_, dsat, kuha_,
  { {0x44e1010a, 0x10f5007e, 0x7aed08ed, 0x00000000}},  //   nų_, _сяля, esat,
  { {0x6b9d0016, 0xc00602b0, 0x7aed08ee, 0x00000000}},  //   _bysg, _спик, fsat,
  { {0x6f0f001c, 0xfc3f0428, 0x6b9d0016, 0x00000000}},  // [be0] ctcc, _dní_, _cysg,
  { {0xfeba035b, 0x6b9d018e, 0x44e1010a, 0x00000000}},  //   _ثابت_, _dysg, kų_,
  { {0x44e1010a, 0x386608ef, 0x3e6600f4, 0x00000000}},  //   jų_, thor_, _côte_,
  { {0x8c4600d7, 0x6abc068a, 0x44e10006, 0x00000000}},  //   _семе, _wirf, dų_,
  { {0x09e80055, 0xe73703e0, 0x81bc0089, 0x00000000}},  //   _পাঠা, лец_, ldēt,
  { {0x290108f0, 0x2ca008f1, 0xfc3f013e, 0x00000000}},  //   buha_, llid_, _zní_,
  { {0x67290089, 0x44e10006, 0x61e808f2, 0x00000000}},  //   _esej, gų_, vadl,
  { {0x545408f3, 0x249f000c, 0x2609006e, 0x00000000}},  //   рвит, glum_, _साथी_,
  { {0x1867003b, 0x61e80161, 0x41e60245, 0x00000000}},  //   _сати_, tadl, ліна,
  { {0x471b00a3, 0xdbd10004, 0x44e10006, 0x00000000}},  //   _אומג, _süüd, bų_,
  { {0x3de208b7, 0x2ca0006c, 0xdbd1006c, 0x00000000}},  //   _বাংল, klid_, _püüd,
  { {0xfc3f0011, 0x61e808f4, 0x442008f5, 0x00000000}},  //   _phím_, sadl, _úi_,
  { {0x543b007b, 0x08770049, 0x61e80387, 0x00000000}},  //   _רעדא, רעכט_, padl,
  { {0x6a60000c, 0x00000000, 0x00000000, 0x00000000}},  //   _söfn,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7aed08f6, 0x2ca0006c, 0x6b9d0016, 0x00000000}},  //   tsat, glid_, _pysg,
  { {0x0ca8007c, 0x998c01ee, 0x7bcd08f7, 0x00000000}},  // [bf0] утри_, _ćoše_, rcau,
  { {0x7aed08f8, 0x7ed40025, 0x29010066, 0x00000000}},  //   rsat, _ازيا, tuha_,
  { {0x7aed08f9, 0x6675007a, 0xc9840478, 0x00000000}},  //   ssat, یدتر, буци,
  { {0x2c2701fb, 0x7aed0039, 0x44e10006, 0x00000000}},  //   _сьог, psat, vų_,
  { {0xd6db005e, 0x66b500ed, 0xf745007c, 0x00000000}},  //   хте_, абду, рело,
  { {0x44e1010a, 0x09df0055, 0xa2c3007d, 0x00000000}},  //   tų_, _ঢাকা, रदस्,
  { {0x249f08fa, 0xdb1d0190, 0x00000000, 0x00000000}},  //   tlum_, _afsø,   ,
  { {0x99840054, 0x44e1010a, 0x60c408fb, 0x00000000}},  //   _الفو, rų_, _čimp,
  { {0x09e80055, 0xc864072b, 0x44e10006, 0x00000000}},  //   _পাতা, _утри, sų_,
  { {0x7c2f0375, 0x425508fc, 0x249f000c, 0x00000000}},  //   _lacr, ртит, slum_,
  { {0xa06a08fd, 0xc4f8006d, 0x249f014a, 0x00000000}},  //   вана_, _معنا_, plum_,
  { {0xb4c102fb, 0x54a700f3, 0xe3b000a6, 0x00000000}},  //   ंदी_, _صحاف, _کرم_,
  { {0x442f031c, 0x324500e2, 0x00000000, 0x00000000}},  //   _iag_, _велг,   ,
  { {0x3ebe08fe, 0x442f000c, 0x2ca008ff, 0x00000000}},  //   ött_, _hag_, wlid_,
  { {0x442f0058, 0xfce60900, 0x94ee013f, 0x00000000}},  //   _kag_, робо, _bəə_,
  { {0x442f0901, 0xbc630081, 0xa3ac0309, 0x00000000}},  //   _jag_, овск, _गरम_,

  { {0x442f0222, 0x6b850025, 0x91fc0089, 0x00000000}},  // [c00] _mag_, مشكل, bkād,
  { {0xe9d70902, 0x442f0292, 0x7ea00039, 0x00000000}},  //   ику_, _lag_, köpi,
  { {0xdca6007c, 0xa9260081, 0x00000000, 0x00000000}},  //   _вани, рдел,   ,
  { {0x442f0903, 0x6d5c0904, 0x00000000, 0x00000000}},  //   _nag_, myra,   ,
  { {0x7c2402d5, 0x7e770009, 0x28130426, 0x00000000}},  //   meir, _ymxp, تونس,
  { {0x7c2402d5, 0xb4c10164, 0x442f01d6, 0x00000000}},  //   leir, ंदू_, _aag_,
  { {0x39470039, 0x442f0905, 0x6d5c0906, 0x00000000}},  //   änst_, _bag_, nyra,
  { {0x7c240907, 0x8af0006b, 0x442f0908, 0x00000000}},  //   neir, yyəl, _cag_,
  { {0x27e0009f, 0xd5b10011, 0x6d5c0909, 0x00000000}},  //   ðinu_, _máy_, hyra,
  { {0x80ca0164, 0x78a2090a, 0x7c24090b, 0x00000000}},  //   _संदे, llov, heir,
  { {0x3a3700b6, 0x442f05b7, 0xd5750088, 0x00000000}},  //   ברים_, _fag_, _луць,
  { {0x442f0093, 0x6d5c00ea, 0x7c2400c4, 0x00000000}},  //   _gag_, dyra, jeir,
  { {0x7c24090c, 0x236d0046, 0x6442002d, 0x00000000}},  //   deir, czej_, _inoi,
  { {0xa2c302d2, 0x442f00b5, 0x78a20161, 0x00000000}},  //   रदर्, _zag_, hlov,
  { {0x7c24018e, 0x442f033b, 0xd087007c, 0x00000000}},  //   feir, _yag_, _выпи,
  { {0x4424090d, 0x78a2037e, 0x7c24090e, 0x00000000}},  //   nem_, jlov, geir,
  { {0x44240191, 0xf9c70827, 0x78a20161, 0x00000000}},  // [c10] iem_, ащен, dlov,
  { {0x4424090f, 0x6d5c00eb, 0x24890910, 0x00000000}},  //   hem_, byra, čami_,
  { {0x44240911, 0x7c2405bc, 0x00000000, 0x00000000}},  //   kem_, beir,   ,
  { {0x7c2400c4, 0x78a20213, 0x00000000, 0x00000000}},  //   ceir, glov,   ,
  { {0x4424059c, 0x442f0912, 0x753a002d, 0x00000000}},  //   dem_, _rag_, _artz,
  { {0x64420913, 0x442f05a6, 0x442401ee, 0x00000000}},  //   _anoi, _sag_, eem_,
  { {0x442f0811, 0xb4c101f5, 0x78a20142, 0x00000000}},  //   _pag_, ंदे_, blov,
  { {0x442402d5, 0x78a20914, 0xe894007e, 0x00000000}},  //   gem_, clov, _дась,
  { {0x442f01aa, 0xdbf40055, 0xd8b600a1, 0x00000000}},  //   _vag_, ঙ্কস_, _اگلا_,
  { {0x442f0915, 0x7c240181, 0x9f4201ca, 0x00000000}},  //   _wag_, zeir, jaká_,
  { {0x44240916, 0x236d0046, 0x2913002d, 0x00000000}},  //   bem_, szej_, ntxa_,
  { {0x7c240181, 0x673b0065, 0x442f004a, 0x00000000}},  //   xeir, _kruj, _uag_,
  { {0x7c240917, 0x7e7c007f, 0x6d5c0696, 0x00000000}},  //   veir, tirp, wyra,
  { {0x6d5c0065, 0x1d0a0918, 0xda030309, 0x00000000}},  //   tyra, леги_, _लागत_,
  { {0x7c240181, 0x78a20062, 0x98a7013e, 0x00000000}},  //   teir, ylov, íně_,
  { {0x3fe6025f, 0x6d5c0544, 0x673b0919, 0x00000000}},  //   _ужив, ryra, _oruj,
  { {0x7c2402d5, 0x78a2037e, 0x387d018e, 0x00000000}},  // [c20] reir, vlov, diwr_,
  { {0x7c2408da, 0x09e80044, 0x00000000, 0x00000000}},  //   seir, _পাহা,   ,
  { {0x7d1e091a, 0xed5a091b, 0x1e57009b, 0x00000000}},  //   _upps, _сон_, _השיר_,
  { {0x44240129, 0x673b0211, 0x16050061, 0x00000000}},  //   xem_, _bruj, _राउर_,
  { {0x4424091c, 0x78a2091d, 0x673b008e, 0x00000000}},  //   vem_, rlov, _cruj,
  { {0x78a2091e, 0x44240036, 0xd946025f, 0x00000000}},  //   slov, wem_, _леги,
  { {0x78a20738, 0x9ac3002b, 0x2609006e, 0x00000000}},  //   plov, ċċes, _सारी_,
  { {0x4424091f, 0xafdb0190, 0x00000000, 0x00000000}},  //   uem_, hjør,   ,
  { {0xe7370057, 0x533401e0, 0x66e30920, 0x00000000}},  //   _лет_, цепт, _нота,
  { {0x44240921, 0x3d1903d7, 0x6f060667, 0x00000000}},  //   sem_, _पहले_, dukc,
  { {0x442400b9, 0x1a9b0049, 0x3a37009b, 0x00000000}},  //   pem_, רייע, זרים_,
  { {0x5edd0044, 0x9f4b009d, 0xc953009b, 0x00000000}},  //   _বিবে, lacé_, למת_,
  { {0xa3bc0365, 0x80ca007d, 0x987b0049, 0x00000000}},  //   _आणि_, _संवे, ראכט,
  { {0x63a20811, 0x9f4000f6, 0x92a40036, 0x00000000}},  //   _iyon, _deià_, ółdz,
  { {0x865b01ce, 0xdd3a001a, 0x00000000, 0x00000000}},  //   נדלי, văţa,   ,
  { {0x629a0142, 0x63a20922, 0xd7ba0061, 0x00000000}},  //   loto, _kyon, ेशाच,
  { {0x260901f5, 0x62880020, 0x61ea000c, 0x00000000}},  // [c30] _साली_, ondo, _kefl,
  { {0x80db0044, 0xe9ab0014, 0x00000000, 0x00000000}},  //   _ভিত্, هدان_,   ,
  { {0x628801d6, 0x63a20923, 0x09e80044, 0x00000000}},  //   indo, _lyon, _পাশা,
  { {0xf77000e9, 0x629a0142, 0xbd880014, 0x00000000}},  //   کام_, hoto, _چنین_,
  { {0x63a2036b, 0x629a0924, 0x387d0016, 0x00000000}},  //   _nyon, koto, riwr_,
  { {0x673b0925, 0xddc500b9, 0x34b3006e, 0x00000000}},  //   _vruj, _pohř, ुद्द,
  { {0x629a0006, 0x69c70292, 0x63a2009d, 0x00000000}},  //   doto, _igje, _ayon,
  { {0xe459026b, 0x673b0926, 0x63a20927, 0x00000000}},  //   ржи_, _truj, _byon,
  { {0x60ca010f, 0x63a20009, 0x673b0045, 0x00000000}},  //   _aufm, _cyon, _uruj,
  { {0x63a20173, 0x60d800f6, 0x7d070023, 0x00000000}},  //   _dyon, _btvm, kujs,
  { {0x6026008b, 0xdddc0006, 0x404a0069, 0x00000000}},  //   одна, sirū, апно_,
  { {0x62880197, 0x5046012b, 0xe45f006c, 0x00000000}},  //   ando, цемб, ööd_,
  { {0x629a0928, 0x63a20232, 0x00000000, 0x00000000}},  //   boto, _gyon,   ,
  { {0x6f060036, 0x61ea03a9, 0x629a0299, 0x00000000}},  //   rukc, _gefl, coto,
  { {0x8c7a005e, 0x2c67006c, 0xdd9203d6, 0x00000000}},  //   ащат_, _sõda_, ذور_,
  { {0x69c70065, 0x69d500b5, 0xc5f30044, 0x00000000}},  //   _agje, _afze, চ্চা_,
  { {0x2ea700a1, 0x20e70010, 0x00000000, 0x00000000}},  // [c40] _ڈپٹی_, lői_,   ,
  { {0x89f5007e, 0xafdb08c8, 0xa01b0010, 0x00000000}},  //   зяцц, ljøp, ynök,
  { {0x38cb0167, 0x60c40929, 0xc92a005e, 0x00000000}},  //   لانی_, _kiim, роеж_,
  { {0x629a0020, 0x186a00ed, 0x09aa0061, 0x00000000}},  //   zoto, јади_, _करीय,
  { {0x41c9007d, 0x629a000b, 0xc5f30044, 0x00000000}},  //   रशास, yoto, চ্ছা_,
  { {0x473301fb, 0x63a20022, 0x60c4092a, 0x00000000}},  //   ьніс, _ryon, _liim,
  { {0x629a0142, 0x00000000, 0x00000000, 0x00000000}},  //   voto,   ,   ,
  { {0x69c7008d, 0x60c4006c, 0x6d4e00f6, 0x00000000}},  //   _zgje, _niim, ixba,
  { {0x629a006a, 0x00000000, 0x00000000, 0x00000000}},  //   toto,   ,   ,
  { {0xd25a092b, 0x628800c4, 0x60c40068, 0x00000000}},  //   рци_, undo, _aiim,
  { {0x629a092c, 0x5bb70061, 0x7c360635, 0x00000000}},  //   roto, _अण्व, kdyr,
  { {0x629a0052, 0x7ea00039, 0x6a60000c, 0x00000000}},  //   soto, köps, _döfi,
  { {0x61ea092d, 0x629a0020, 0x60c404cb, 0x00000000}},  //   _tefl, poto, _diim,
  { {0x5edd0055, 0x00000000, 0x00000000, 0x00000000}},  //   _বিদে,   ,   ,
  { {0xa6e90082, 0x00000000, 0x00000000, 0x00000000}},  //   _giươ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3f8c005f, 0x27ef092e, 0x00000000, 0x00000000}},  // [c50] şdur_, vagn_,   ,
  { {0x3cfe092f, 0x0b880088, 0xea000082, 0x00000000}},  //   štva_, істи_, _đản_,
  { {0xeeb80930, 0xfeb8006d, 0x00000000, 0x00000000}},  //   _флэш_, _بايت_,   ,
  { {0xfc3f0011, 0x6faf0061, 0x88c80088, 0x00000000}},  //   _chít_, _घरां, ілів_,
  { {0xe739005e, 0x87270025, 0x4907013d, 0x00000000}},  //   сел_, تعام, _हमको_,
  { {0xb9010044, 0x69c700ea, 0xd6290931, 0x00000000}},  //   _দি_, _ugje, соке_,
  { {0x22490932, 0xb06600b0, 0x2fc900e0, 0x00000000}},  //   _đak_, nsää, _ogag_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66f4003b, 0xc6a70098, 0x60c40933, 0x00000000}},  //   _опту, _држи, _riim,
  { {0x27ed01b5, 0xcb1200b3, 0x20e70010, 0x00000000}},  //   _heen_, עלי_, tői_,
  { {0x60c40934, 0x61450745, 0x2d84014a, 0x00000000}},  //   _piim, чена, şmez_,
  { {0x26c5000b, 0xc4d200b6, 0x27ed00d9, 0x00000000}},  //   _hilo_, _נגד_, _jeen_,
  { {0x60c408b2, 0x26c5014a, 0x27ed0935, 0x00000000}},  //   _viim, _kilo_, _meen_,
  { {0x27ed0168, 0xd35600b3, 0x6459005b, 0x00000000}},  //   _leen_, _מיני_, _howi,
  { {0x60c40103, 0x2fcd0936, 0x00000000, 0x00000000}},  //   _tiim, žega_,   ,
  { {0x62810937, 0x26c50082, 0xd0fa0049, 0x00000000}},  //   lilo, _lilo_, _פּור,
  { {0x64590036, 0x2d85009d, 0x00000000, 0x00000000}},  // [c60] _mowi, ûler_,   ,
  { {0x6281000d, 0x26c500c4, 0x00000000, 0x00000000}},  //   nilo, _nilo_,   ,
  { {0x27ed0038, 0x2f160030, 0x00000000, 0x00000000}},  //   _been_, læg_,   ,
  { {0x62810938, 0xc18c0049, 0x64590036, 0x00000000}},  //   hilo, סטאָ, _nowi,
  { {0x26c501d9, 0x6281009f, 0x16340242, 0x00000000}},  //   _bilo_, kilo, деля,
  { {0x6b890359, 0x98ac0279, 0x62810939, 0x00000000}},  //   _þega, ılır_, jilo,
  { {0x3494008b, 0x628100ca, 0x6459093a, 0x00000000}},  //   макр, dilo, _bowi,
  { {0x27ed015c, 0xc955007e, 0x00000000, 0x00000000}},  //   _geen_, _ўтры,   ,
  { {0x64590036, 0x26c50207, 0x62810321, 0x00000000}},  //   _dowi, _filo_, filo,
  { {0x6281001a, 0x25a5093b, 0xa3dc007d, 0x00000000}},  //   gilo, _fyll_, _त्र_,
  { {0x76480036, 0xfc3f0051, 0x2ee90173, 0x00000000}},  //   _indy, _mhír_, _swaf_,
  { {0x38660010, 0xa3e6013d, 0x7af600b0, 0x00000000}},  //   nkor_, _बजट_, ksyt,
  { {0x6a60009f, 0x62810142, 0x533400e3, 0x00000000}},  //   _höfu, bilo, _целт,
  { {0x6281001a, 0x64470089, 0x645900bb, 0x00000000}},  //   cilo, ējie, _zowi,
  { {0x38660010, 0x765a093c, 0x1bd5004d, 0x00000000}},  //   kkor_, _moty, добя,
  { {0xea000011, 0x9f4b0802, 0x00000000, 0x00000000}},  //   _đạn_, lací_,   ,
  { {0x5a35041f, 0xb06600b0, 0x27ed01d6, 0x00000000}},  // [c70] мнат, ssää, _reen_,
  { {0x27ed00ab, 0x32d20011, 0x765a04c4, 0x00000000}},  //   _seen_, _mây_, _noty,
  { {0x80a400d3, 0x32d20011, 0x6dc301f3, 0x00000000}},  //   _زمین, _lây_, _qċaċ,
  { {0x76480178, 0x26c5093d, 0x6281093e, 0x00000000}},  //   _andy, _silo_, zilo,
  { {0x9f4b093f, 0x2ca90940, 0xcc5600b3, 0x00000000}},  //   kací_, mlad_, _חברי_,
  { {0x6459001f, 0x2ca9074e, 0x6281002d, 0x00000000}},  //   _sowi, llad_, xilo,
  { {0x64590046, 0x765a0941, 0x62810942, 0x00000000}},  //   _powi, _doty, vilo,
  { {0x38660073, 0x32d2001d, 0x764801aa, 0x00000000}},  //   ckor_, _bây_, _endy,
  { {0x6281000d, 0x32d2001d, 0x2ca90016, 0x00000000}},  //   tilo, _cây_, ilad_,
  { {0x32d2001d, 0x64590943, 0x00000000, 0x00000000}},  //   _dây_, _wowi,   ,
  { {0x6281000d, 0x2ca90161, 0xd5670783, 0x00000000}},  //   rilo, klad_, _этап,
  { {0x628105d2, 0x23720036, 0xd59a009b, 0x00000000}},  //   silo, _żyje_, _ובעל,
  { {0x32d2001d, 0xd3d80025, 0x248d00ca, 0x00000000}},  //   _gây_, _ربنا_, mnem_,
  { {0x5edd0055, 0x7cd5010a, 0x248d0059, 0x00000000}},  //   _বিশে, _sąra, lnem_,
  { {0x6da300aa, 0x248d00d4, 0xdca60140, 0x00000000}},  //   вира, onem_, дави,
  { {0x3cfe01ae, 0x248d0018, 0x2ca90190, 0x00000000}},  //   štvo_, nnem_, glad_,
  { {0x32d2001d, 0xdca301bd, 0xa5a4013d, 0x00000000}},  // [c80] _xây_, тати, _चुनौ,
  { {0x2bde006e, 0x7af60036, 0x386d00d4, 0x00000000}},  //   _फ्रा, rsyt, _aler_,
  { {0x2ca90944, 0x248d0091, 0x249f0068, 0x00000000}},  //   blad_, knem_, koum_,
  { {0x20d3001d, 0x31560049, 0x9f4b01dc, 0x00000000}},  //   _mãi_, ויען_, zací_,
  { {0x248d0059, 0x20d30011, 0x386600f8, 0x00000000}},  //   dnem_, _lãi_, rkor_,
  { {0x38660073, 0xa3c1013d, 0xd042006b, 0x00000000}},  //   skor_, ंधन_, rqlə,
  { {0x386d0073, 0xceb3007b, 0x9f4b01c8, 0x00000000}},  //   _fler_, דיג_, vací_,
  { {0x38b50945, 0x3a38020d, 0x248d0091, 0x00000000}},  //   gård_, _harp_, gnem_,
  { {0x27e60946, 0xd6260054, 0x41c9006e, 0x00000000}},  //   mbon_, _يعطي, रशंस,
  { {0x51860454, 0x20d30011, 0x27e6002d, 0x00000000}},  //   дума, _bãi_, lbon_,
  { {0x248d0947, 0x20d30011, 0x9f4b0802, 0x00000000}},  //   bnem_, _cãi_, rací_,
  { {0x32d2001d, 0x248d0107, 0x27e601ed, 0x00000000}},  //   _tây_, cnem_, nbon_,
  { {0x80ca02f4, 0x44fa0089, 0x62790062, 0x00000000}},  //   _संके, lī_, vňov,
  { {0x8d6b00ed, 0x2005005d, 0x2ca90016, 0x00000000}},  //   ојба_, şli_, wlad_,
  { {0x2ca00022, 0x44fa0089, 0x20d30082, 0x00000000}},  //   foid_, nī_, _gãi_,
  { {0x8af00163, 0xfc3f0082, 0x2ca008ce, 0x00000000}},  //   yyət, _chíp_, goid_,
  { {0x7b18007c, 0x291801d5, 0x2d9e036c, 0x00000000}},  // [c90] мотр_, _aqra_, üter_,
  { {0xd5a4009c, 0x248d0059, 0x00000000, 0x00000000}},  //   _نہ_, znem_,   ,
  { {0x249f042a, 0x386d00f6, 0x00000000, 0x00000000}},  //   youm_, _pler_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x248d01d9, 0x7c2d002d, 0x38b50039, 0x00000000}},  //   vnem_, mear, vård_,
  { {0x7c2d0948, 0x8cb9006e, 0xe610006b, 0x00000000}},  //   lear, ्दको, rüşə,
  { {0x248d0059, 0xe5a20088, 0x387f002b, 0x00000000}},  //   tnem_, лиши, _tmur_,
  { {0x7c2d0949, 0x387f0149, 0x20d30011, 0x00000000}},  //   near, _umur_, _rãi_,
  { {0x248d0059, 0x6d43016c, 0x00000000, 0x00000000}},  //   rnem_, _šnal,   ,
  { {0x7c2d002a, 0x248d0087, 0x00000000, 0x00000000}},  //   hear, snem_,   ,
  { {0x0086014c, 0x7c2d002d, 0x332600e5, 0x00000000}},  //   елно, kear, _epox_,
  { {0xcea900a0, 0x20d30082, 0x7c2d0032, 0x00000000}},  //   _הי_, _vãi_, jear,
  { {0x644b033b, 0x7c2d094a, 0x270d0061, 0x00000000}},  //   _ingi, dear, _समोर_,
  { {0x442d021e, 0x877a0104, 0x00000000, 0x00000000}},  //   lee_, לארי,   ,
  { {0x8af0005f, 0x7c2d0048, 0x6fa0007d, 0x00000000}},  //   yyəs, fear, _गुरू,
  { {0x442d021e, 0x7c2d0949, 0xdca60216, 0x00000000}},  //   nee_, gear, хаби,
  { {0xac07008b, 0xdb1c0477, 0xab27094b, 0x00000000}},  // [ca0] энта_, _özüm, нота_,
  { {0x27ff094c, 0x00000000, 0x00000000, 0x00000000}},  //   _adun_,   ,   ,
  { {0x442d094d, 0x7c2d084b, 0x644b02f6, 0x00000000}},  //   kee_, bear, _ongi,
  { {0x7c2d094e, 0x442d094f, 0x27e600bb, 0x00000000}},  //   cear, jee_, ubon_,
  { {0x3a38010a, 0x00000000, 0x00000000, 0x00000000}},  //   _tarp_,   ,   ,
  { {0x644b0292, 0x7ae40207, 0x442d0950, 0x00000000}},  //   _angi, mpit, eee_,
  { {0x442d01d6, 0x2b400951, 0x7ae40207, 0x00000000}},  //   fee_, lvic_, lpit,
  { {0x442d0343, 0x7ae40020, 0x6e2e0952, 0x00000000}},  //   gee_, opit, hebb,
  { {0x7ae400b0, 0x96ba03ab, 0x00000000, 0x00000000}},  //   npit, _فائز_,   ,
  { {0x644b0953, 0x7c2d002d, 0x75d60025, 0x00000000}},  //   _engi, zear, _أيضا,
  { {0xd48f0954, 0x7c2d0955, 0x2ee0012d, 0x00000000}},  //   _бр_, year, _atif_,
  { {0x442d0956, 0x7f440957, 0x7c2d002d, 0x00000000}},  //   cee_, _briq, xear,
  { {0x69dc0958, 0x7c2d0190, 0x7f440068, 0x00000000}},  //   _ofre, vear, _criq,
  { {0x7ae4012d, 0x6e2e0010, 0x78a2010e, 0x00000000}},  //   dpit, gebb, hoov,
  { {0x7c2d022b, 0x3ced0107, 0xac190451, 0x00000000}},  //   tear, ćevo_, мову_,
  { {0x69dc000c, 0xa01b0039, 0x2ee00022, 0x00000000}},  //   _afre, rnös, _ftif_,
  { {0x7c2d002d, 0x9f530036, 0x5f950959, 0x00000000}},  // [cb0] rear, ędów_, _шиит,
  { {0x7c2d0038, 0x442d0020, 0x6f0f0197, 0x00000000}},  //   sear, zee_, mucc,
  { {0x7c2d00ab, 0x6f0f0197, 0x6f1d010f, 0x00000000}},  //   pear, lucc, ltsc,
  { {0xdddc010a, 0x69ce00bb, 0x6f1d00bb, 0x00000000}},  //   mirš, _egbe, otsc,
  { {0x442d095a, 0x6f1d05c6, 0x6f0f0197, 0x00000000}},  //   vee_, ntsc, nucc,
  { {0x442d095b, 0x6d4a0051, 0x6f1d01a2, 0x00000000}},  //   wee_, _áfac, itsc,
  { {0x442d095c, 0xc44700a1, 0x6f1d095d, 0x00000000}},  //   tee_, ٹیشن_, htsc,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x36d501fb, 0x2ba702d2, 0x442d0038, 0x00000000}},  //   _розр, _कुमा, ree_,
  { {0x442d00b0, 0x6f0f095e, 0xcb1401ce, 0x00000000}},  //   see_, ducc, אלץ_,
  { {0x442d095f, 0xd00a003b, 0x6e2e0010, 0x00000000}},  //   pee_, мене_, vebb,
  { {0x6e2e0009, 0x644b01e5, 0x6f1d01a2, 0x00000000}},  //   webb, _ungi, ftsc,
  { {0xa3a80061, 0x547a009b, 0x6f0f0026, 0x00000000}},  //   _खुप_, _קטנו, gucc,
  { {0xdee301fc, 0x78a2012d, 0x00000000, 0x00000000}},  //   рори, zoov,   ,
  { {0x6e2e0198, 0x6da602e9, 0xada605c7, 0x00000000}},  //   rebb, тива, тавл,
  { {0x7f440066, 0x6e2e0010, 0x69dc0197, 0x00000000}},  //   _triq, sebb, _sfre,
  { {0x6d45001f, 0x7d1c01d9, 0x6b63007e, 0x00000000}},  // [cc0] _erha, strs, акта,
  { {0x2b4001f3, 0x7ae40960, 0xeef70097, 0x00000000}},  //   rvic_, rpit, _שמיר_,
  { {0x1bea007c, 0xb05b0961, 0x00000000, 0x00000000}},  //   _одни_, smäe,   ,
  { {0x7ae40052, 0xe7860478, 0xe3a70241, 0x00000000}},  //   ppit, куло, _نر_,
  { {0x78a2017b, 0x3eba0082, 0x00000000, 0x00000000}},  //   roov, _khpt_,   ,
  { {0xb7d20044, 0x20ee00b9, 0x78a2006c, 0x00000000}},  //   ারেট, yři_, soov,
  { {0x6f0f0026, 0x91fc0089, 0xafdb00ea, 0x00000000}},  //   zucc, skāk, ldøe,
  { {0x63ab0637, 0x62830962, 0x39470030, 0x00000000}},  //   _bygn, _amno, ænse_,
  { {0x872505f3, 0x63ab0068, 0xa7a70264, 0x00000000}},  //   _معلم, _cygn, _акта_,
  { {0x63ab0039, 0x6fec0044, 0x00000000, 0x00000000}},  //   _dygn, _কাগজ_,   ,
  { {0x60f8008b, 0x7c260268, 0x26170963, 0x00000000}},  //   эння_, _obkr, _नाती_,
  { {0x64a3007e, 0x6f0f0197, 0xdddc0964, 0x00000000}},  //   _каха, tucc, virš,
  { {0x26cc0093, 0xd36f0379, 0x6f1d010f, 0x00000000}},  //   _kido_, _وهم_, utsc,
  { {0x6f0f029a, 0x6f1d001f, 0x2c750018, 0x00000000}},  //   rucc, rtsc, _måde_,
  { {0x6288029d, 0x6f1d010f, 0xeca700ed, 0x00000000}},  //   mido, stsc, вјан,
  { {0x26cc0089, 0x6f1d01a2, 0x2005007f, 0x00000000}},  //   _lido_, ptsc, ėlis_,
  { {0x201e005f, 0x44260965, 0x26cc008e, 0x00000000}},  // [cd0] əti_, _mbo_, _oido_,
  { {0x62880966, 0x2ba70183, 0xadbd008b, 0x00000000}},  //   nido, _कुणा, _напi,
  { {0x67290030, 0x49a406e3, 0x60cd033b, 0x00000000}},  //   _spej, ајца, _kiam,
  { {0x2c75044f, 0x24580027, 0x442600bb, 0x00000000}},  //   _både_, _témy_, _nbo_,
  { {0x60cd0967, 0x62880968, 0x160e0061, 0x00000000}},  //   _miam, kido, _साखर_,
  { {0x98b301f6, 0xa3ac0183, 0x442600ac, 0x00000000}},  //   ıdır_, _गरज_, _abo_,
  { {0x6288029d, 0x63ab0036, 0x7c3d0969, 0x00000000}},  //   dido, _sygn, _kasr,
  { {0x60cd096a, 0x9f52000a, 0x67290066, 0x00000000}},  //   _niam, _feyè_, _tpej,
  { {0x26cc0197, 0x7c3d014a, 0x5884007e, 0x00000000}},  //   _fido_, _masr, _тыра,
  { {0x6288096b, 0x4426096c, 0x7c3d096d, 0x00000000}},  //   gido, _ebo_, _lasr,
  { {0x60cd096e, 0x659400e2, 0x64150025, 0x00000000}},  //   _biam, _кафу, _مواط,
  { {0x7c3d096f, 0x60cd0970, 0xdee60088, 0x00000000}},  //   _nasr, _ciam, ломи,
  { {0x6288029d, 0x60cd0971, 0x443f0972, 0x00000000}},  //   bido, _diam, mdu_,
  { {0x443f0756, 0x62880489, 0x62830973, 0x00000000}},  //   ldu_, cido, _umno,
  { {0x443f010a, 0x60cd0207, 0x443d0760, 0x00000000}},  //   odu_, _fiam, _kaw_,
  { {0x443f0974, 0x60cd0197, 0x443d0652, 0x00000000}},  //   ndu_, _giam, _jaw_,
  { {0x4bd90373, 0x443d0016, 0x3b07026b, 0x00000000}},  // [ce0] ться_, _maw_, лето_,
  { {0x443d0975, 0xfaaa0014, 0x443f0976, 0x00000000}},  //   _law_, رهاي_, hdu_,
  { {0x9f520263, 0x090601a4, 0x26cc01aa, 0x00000000}},  //   _seyè_, упен, _rido_,
  { {0x3860009f, 0x26cc0977, 0x62880978, 0x00000000}},  //   ðir_, _sido_, zido,
  { {0x443f0979, 0x26cc097a, 0x7c240035, 0x00000000}},  //   ddu_, _pido_, mfir,
  { {0x0f3700b6, 0x6288049a, 0x443f097b, 0x00000000}},  //   טרנט_, xido, edu_,
  { {0x62880181, 0x26cc097c, 0x443d00be, 0x00000000}},  //   vido, _vido_, _baw_,
  { {0xdd04010a, 0x7c240335, 0x26cc0022, 0x00000000}},  //   ūrėt, nfir, _wido_,
  { {0x443d097d, 0x62880576, 0x60cd002a, 0x00000000}},  //   _daw_, tido, _riam,
  { {0x60cd0198, 0x443f0016, 0x78bb097e, 0x00000000}},  //   _siam, adu_, _zhuv,
  { {0x6288029d, 0x443f097f, 0x443d0980, 0x00000000}},  //   rido, bdu_, _faw_,
  { {0xf53700b6, 0x62880981, 0x443d00e0, 0x00000000}},  //   _תנאי_, sido, _gaw_,
  { {0x628800b0, 0x64400045, 0x9f590023, 0x00000000}},  //   pido, mdmi, masë_,
  { {0x6440000c, 0x6e3e0982, 0x7c3d016c, 0x00000000}},  //   ldmi, _capb, _sasr,
  { {0x7c240983, 0x61fa005f, 0x60cd00d4, 0x00000000}},  //   ffir, matl, _tiam,
  { {0x61fa0984, 0x6440006c, 0xaed500ed, 0x00000000}},  //   latl, ndmi, _коиш,
  { {0x50b80318, 0x6e950985, 0x6d4a000c, 0x00000000}},  // [cf0] _حدود_, _випу, _áfan,
  { {0x61fa0890, 0xda780986, 0xdb240010, 0x00000000}},  //   natl, лях_, ásán,
  { {0x628f009d, 0x443f005d, 0x7c3d0022, 0x00000000}},  //   écoi, ydu_, _tasr,
  { {0x2617001c, 0x61fa0279, 0x443f006b, 0x00000000}},  //   _नाही_, hatl, xdu_,
  { {0xe73905b5, 0x443f0987, 0x07a502a8, 0x00000000}},  //   тел_, vdu_, јалн,
  { {0xa5090121, 0x443f0988, 0x61fa00ca, 0x00000000}},  //   века_, wdu_, jatl,
  { {0x61fa0989, 0x443d0173, 0x3e74006c, 0x00000000}},  //   datl, _paw_, _jäta_,
  { {0x443f098a, 0xc6060044, 0x3e74098b, 0x00000000}},  //   udu_, ল্লা_, _mäta_,
  { {0xfc3f0359, 0x443f011f, 0xa3a803d7, 0x00000000}},  //   _maí_, rdu_, _खुद_,
  { {0xc6a7098c, 0x61fa0047, 0x64400056, 0x00000000}},  //   _срби, gatl, admi,
  { {0x443d098d, 0x7c24000c, 0x6e3e0093, 0x00000000}},  //   _taw_, yfir, _rapb,
  { {0x44f3001a, 0x3f6a003b, 0x00000000, 0x00000000}},  //   mţ_, вимо_,   ,
  { {0x61fa006b, 0xa3c10061, 0x00000000, 0x00000000}},  //   batl, ंधळ_,   ,
  { {0x200c005f, 0x61fa01ee, 0x00000000, 0x00000000}},  //   şdi_, catl,   ,
  { {0x7c24098e, 0x8d63013b, 0xa3dc0061, 0x00000000}},  //   tfir, овре, तुक_,
  { {0xb05b0073, 0x9ce5007e, 0xfc3f098f, 0x00000000}},  //   lmän, сцёл, _caí_,
  { {0x7c240990, 0xfc3f0181, 0x63880089, 0x00000000}},  // [d00] rfir, _daí_, cīnī,
  { {0x7c24006c, 0xab27005e, 0x7bdf0197, 0x00000000}},  //   sfir, рофа_, acqu,
  { {0xd00f089d, 0x19b9008b, 0x7c240991, 0x00000000}},  //   _علی_, гуць_, pfir,
  { {0x8c46025f, 0x61fa0010, 0xa01b00b0, 0x00000000}},  //   _теме, zatl, tiöi,
  { {0x27e90211, 0x61fa047f, 0xbb430088, 0x00000000}},  //   ñana_, yatl, _деяк,
  { {0x3cfe0295, 0xbb4300ed, 0x248601d6, 0x00000000}},  //   štvu_, _ќерк, _smom_,
  { {0xd49a00aa, 0x2617006e, 0x5e570049, 0x00000000}},  //   кри_, _नारी_, ייסע_,
  { {0x98a30088, 0x00000000, 0x00000000, 0x00000000}},  //   _дисе,   ,   ,
  { {0xc178010a, 0x61fa0992, 0x9f590023, 0x00000000}},  //   ybės_, tatl, rasë_,
  { {0x09ca0044, 0x67220993, 0x00000000, 0x00000000}},  //   _ল্যা, mtoj,   ,
  { {0x272001aa, 0x61fa0994, 0x6722042c, 0x00000000}},  //   lòn_, ratl, ltoj,
  { {0x6722010a, 0x44320082, 0x61fa0994, 0x00000000}},  //   otoj, _úy_, satl,
  { {0x67220995, 0x61fa0996, 0x3ce6016c, 0x00000000}},  //   ntoj, patl, _čova_,
  { {0xea0000ad, 0x67220997, 0x7ae9014a, 0x00000000}},  //   _đến_, itoj, _çeti,
  { {0xb2bb00b6, 0x67220998, 0x307b0025, 0x00000000}},  //   _שמור, htoj, _لحظة_,
  { {0x2c750039, 0x67220065, 0x5c740999, 0x00000000}},  //   _båda_, ktoj, олст,
  { {0x67220065, 0x27200173, 0xa9e70025, 0x00000000}},  // [d10] jtoj, jòn_, لثان,
  { {0x4a540131, 0x00000000, 0x00000000, 0x00000000}},  //   окус,   ,   ,
  { {0xdd910137, 0x06e60044, 0x61f8014a, 0x00000000}},  //   _روح_, _নিষি, _mevl,
  { {0x3157007b, 0x2019099a, 0x673b099b, 0x00000000}},  //   ייבן_, ngsi_, _psuj,
  { {0x25b2006b, 0x2720099c, 0x00000000, 0x00000000}},  //   əyli_, gòn_,   ,
  { {0xbb3a007b, 0x61f8099d, 0x78a20428, 0x00000000}},  //   _געשי, _nevl, čova,
  { {0x28f8041f, 0x1994004d, 0x00000000, 0x00000000}},  //   _весь_, _даря,   ,
  { {0xcd9800a0, 0x29010020, 0x272001aa, 0x00000000}},  //   ידות_, msha_, bòn_,
  { {0x61f80116, 0x00000000, 0x00000000, 0x00000000}},  //   _bevl,   ,   ,
  { {0x38bc0051, 0x27fd005b, 0x290100e7, 0x00000000}},  //   ríre_, lawn_, osha_,
  { {0x61f8099e, 0xa06a003b, 0x290104e7, 0x00000000}},  //   _devl, гана_, nsha_,
  { {0xf992009b, 0x290100e7, 0xb05b099f, 0x00000000}},  //   לרי_, isha_, smän,
  { {0x248d001e, 0x7641011c, 0x72050014, 0x00000000}},  //   miem_, _kaly, _هوشم,
  { {0x248d0089, 0x61f800c7, 0x27fd0016, 0x00000000}},  //   liem_, _gevl, hawn_,
  { {0x01c50044, 0x764105e1, 0x91680082, 0x00000000}},  //   _শ্রদ, _maly, _tức_,
  { {0x248d09a0, 0x6722010a, 0xb05b0039, 0x00000000}},  //   niem_, ytoj, nmäl,
  { {0xf1bf00b9, 0x290100e0, 0xd5b10082, 0x00000000}},  // [d20] řád_, esha_, _lý_,
  { {0x6f040166, 0x248d09a1, 0x764100ea, 0x00000000}},  //   _ivic, hiem_, _naly,
  { {0xfe3700b6, 0x248d09a2, 0xdca601ee, 0x00000000}},  //   _פרטי_, kiem_, _гани,
  { {0x248d001e, 0x91fc001e, 0x17fa0025, 0x00000000}},  //   jiem_, nkār, اراة_,
  { {0x501b01f8, 0x248d001e, 0x67220997, 0x00000000}},  //   רונו, diem_, utoj,
  { {0x67220006, 0x1ae305f6, 0x7c3609a3, 0x00000000}},  //   rtoj, _хорм, leyr,
  { {0x672206a6, 0x7641010a, 0x9f59009d, 0x00000000}},  //   stoj, _daly, rasé_,
  { {0x248d09a4, 0x67220065, 0xb1760011, 0x00000000}},  //   giem_, ptoj, _ngượ,
  { {0xa3a8006e, 0x61f8012d, 0x76410288, 0x00000000}},  //   _खुश_, _pevl, _faly,
  { {0x06650014, 0x7641007f, 0xda7b0049, 0x00000000}},  //   _والپ, _galy, ָנטר,
  { {0xd0110076, 0x909900ed, 0x248d0089, 0x00000000}},  //   ولد_, ивот_, biem_,
  { {0x248d02ff, 0x00000000, 0x00000000, 0x00000000}},  //   ciem_,   ,   ,
  { {0x3e970025, 0x5f94005e, 0x6e350032, 0x00000000}},  //   مؤسس, зият, tezb,
  { {0x64420051, 0x29010058, 0x539b009b, 0x00000000}},  //   _haoi, ysha_, _גידו,
  { {0x90e6031d, 0x7c36000c, 0x628a004a, 0x00000000}},  //   _استن, feyr, _imfo,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x5eb80055, 0x64420051, 0x20090697, 0x00000000}},  // [d30] _ইংরে, _maoi, _idai_,
  { {0x7f4d006b, 0x290109a5, 0x248d09a6, 0x00000000}},  //   _iraq, tsha_, ziem_,
  { {0x6f040065, 0xa01b09a7, 0xb05b00b0, 0x00000000}},  //   _zvic, rhöf, ymäl,
  { {0x6d40001e, 0xdb0f00f4, 0x764109a8, 0x00000000}},  //   āmat, _lycé, _saly,
  { {0x76410006, 0x248d09a9, 0x29010066, 0x00000000}},  //   _paly, viem_, ssha_,
  { {0x7aed020c, 0xf1c802d2, 0x248d09aa, 0x00000000}},  //   mpat, रधान, wiem_,
  { {0x248d001e, 0x9f40009f, 0x764109ab, 0x00000000}},  //   tiem_, _leið_, _valy,
  { {0x130907ca, 0x7b08009f, 0x64420051, 0x00000000}},  //   аний_, _ástæ, _caoi,
  { {0x6442002a, 0x7aed09ac, 0x248d09a9, 0x00000000}},  //   _daoi, npat, riem_,
  { {0x248d001e, 0x7aed09ad, 0x20090020, 0x00000000}},  //   siem_, ipat, _adai_,
  { {0x6442002a, 0x645d010f, 0x248d0089, 0x00000000}},  //   _faoi, ösis, piem_,
  { {0xf48500a1, 0x437509ae, 0x9fca026b, 0x00000000}},  //   _بائی, _мулт, игна_,
  { {0xe28e008b, 0x7f4d09af, 0x083a0049, 0x00000000}},  //   _жа_, _craq, בערל,
  { {0x7aed00d2, 0x7f4d0026, 0xc5f90049, 0x00000000}},  //   dpat, _draq, יפֿט,
  { {0xa01b09b0, 0x6442004a, 0x00000000, 0x00000000}},  //   giös, _yaoi,   ,
  { {0x7d05001c, 0x7f4d09b1, 0x7aed00d9, 0x00000000}},  //   _dvhs, _fraq, fpat,
  { {0x7c36000c, 0x7aed011c, 0x68e900ca, 0x00000000}},  // [d40] reyr, gpat, _čeda,
  { {0x25a00095, 0x00000000, 0x00000000, 0x00000000}},  //   şili_,   ,   ,
  { {0xed5a09b2, 0x64970089, 0x6ee500a2, 0x00000000}},  //   _тон_, rģij, _وسیل,
  { {0x7aed09b3, 0xd7ef0025, 0xcfad0044, 0x00000000}},  //   bpat, نكم_, _গণতন,
  { {0x8af0006b, 0x7aed06ed, 0xa01b09b4, 0x00000000}},  //   yyəy, cpat, shög,
  { {0x6442002a, 0x6b63007e, 0x00000000, 0x00000000}},  //   _saoi, _ўкра,   ,
  { {0x385a09b5, 0x69230478, 0xd839000a, 0x00000000}},  //   _краю_, _омра, _djōb_,
  { {0x387d005b, 0x00000000, 0x00000000, 0x00000000}},  //   chwr_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x026a0088, 0x3f8209b6, 0x862b009e, 0x00000000}},  //   рший_, dzku_, _نغمہ_,
  { {0x3a37034e, 0x2ee904cb, 0x64420051, 0x00000000}},  //   חרים_, _staf_, _taoi,
  { {0x232a0517, 0x7aed04a5, 0xb05b00b0, 0x00000000}},  //   _води_, ypat, mmäk,
  { {0xe29a012b, 0xb05b00b0, 0x00000000, 0x00000000}},  //   _кад_, lmäk,   ,
  { {0x29070047, 0x9f5b0023, 0x63a20288, 0x00000000}},  //   ának_, _heqë_, _ixon,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa01b09b7, 0xe5710049, 0x69d80006, 0x00000000}},  //   riös, ײַל_, žvel,
  { {0x629a0009, 0x9f5b0065, 0x6d480039, 0x00000000}},  // [d50] onto, _meqë_, ådar,
  { {0x7aed09b8, 0x629a00ea, 0x00000000, 0x00000000}},  //   rpat, nnto,   ,
  { {0xa3ca0061, 0x629a00b0, 0x387d005b, 0x00000000}},  //   ळेत_, into, thwr_,
  { {0x7aed01bc, 0x7c590025, 0x00000000, 0x00000000}},  //   ppat, _الحر_,   ,
  { {0xfc5a009b, 0x00000000, 0x00000000, 0x00000000}},  //   _הכרמ,   ,   ,
  { {0x26c70618, 0x00000000, 0x00000000, 0x00000000}},  //   umno_,   ,   ,
  { {0x2d830036, 0x63a20133, 0x00000000, 0x00000000}},  //   nzje_, _axon,   ,
  { {0x629a0142, 0x00000000, 0x00000000, 0x00000000}},  //   ento,   ,   ,
  { {0x383401ff, 0xf77309b9, 0xafdb00ea, 0x00000000}},  //   _інфр, _غار_, gdøm,
  { {0x629a0146, 0xb05b04ec, 0x00000000, 0x00000000}},  //   gnto, lmäh,   ,
  { {0x27e00087, 0x85050167, 0x91fc0089, 0x00000000}},  //   žine_, _روشن, rkāp,
  { {0x8fa60783, 0x55ba009b, 0x61ee006b, 0x00000000}},  //   заме, _המעו, ıbla,
  { {0xc3190055, 0xe80c0061, 0x442f09ba, 0x00000000}},  //   _তৈরি_, हणता_, _ibg_,
  { {0x442f0203, 0x13a9009e, 0x00000000, 0x00000000}},  //   _hbg_, _پنڈی_,   ,
  { {0xdd920137, 0x00000000, 0x00000000, 0x00000000}},  //   رور_,   ,   ,
  { {0xda1e0061, 0x442f0091, 0xaf0609bb, 0x00000000}},  //   _पाहत_, _jbg_, _епил,
  { {0x3aeb09bc, 0x200209bd, 0x207b01ce, 0x00000000}},  // [d60] مبلی_, maki_, _לאקא,
  { {0x20020127, 0xdb060036, 0xa6e90082, 0x00000000}},  //   laki_, _szkó, _khươ,
  { {0xceb300bd, 0x4ddb009b, 0xe8530014, 0x00000000}},  //   _איז_, _לחיו, کنند,
  { {0x38cb01ef, 0x20020052, 0xdca600ed, 0x00000000}},  //   مانی_, naki_, _хами,
  { {0x629a09be, 0x60c400e7, 0x00000000, 0x00000000}},  //   ynto, _mhim,   ,
  { {0x442f003f, 0xd6d90088, 0x200209bf, 0x00000000}},  //   _abg_, іті_, haki_,
  { {0xe9a309c0, 0x442f0173, 0x20020145, 0x00000000}},  //   _зарп, _bbg_, kaki_,
  { {0x399b00b6, 0x20020059, 0x442f09c1, 0x00000000}},  //   _הילד, jaki_, _cbg_,
  { {0x2002011f, 0x6b84010f, 0x291a0161, 0x00000000}},  //   daki_, nzig, lupa_,
  { {0x2a6a09c2, 0xb05b021e, 0x877b00b3, 0x00000000}},  //   _jobb_, mmäi, _האמי,
  { {0x2497007a, 0xa6e9001d, 0x2bb90309, 0x00000000}},  //   _کنند_, _chươ, _आर्थ,
  { {0x27e6008e, 0x60c409c3, 0x2a6a0066, 0x00000000}},  //   ncon_, _chim, _lobb_,
  { {0x6b8402ae, 0x60c40065, 0x291a0058, 0x00000000}},  //   jzig, _dhim, hupa_,
  { {0x291a09c4, 0x60c4000a, 0x539b0097, 0x00000000}},  //   kupa_, _ehim, _פיגו,
  { {0x200209c5, 0x68e909c6, 0x60c40066, 0x00000000}},  //   baki_, _čedo, _fhim,
  { {0x30a4008b, 0x60c40035, 0x291a0022, 0x00000000}},  //   _прыв, _ghim, dupa_,
  { {0x3f9e014a, 0x2a6a01ee, 0x7c2f0082, 0x00000000}},  // [d70] ştur_, _bobb_, _vbcr,
  { {0x6d4107a8, 0x291a09c7, 0x2a6a0133, 0x00000000}},  //   ælas, fupa_, _cobb_,
  { {0x29070884, 0x27e60087, 0x291a0058, 0x00000000}},  //   éna_, fcon_, gupa_,
  { {0x3869009f, 0x6a7301df, 0x00000000, 0x00000000}},  //   ðar_, _sıfı,   ,
  { {0x7c2d000c, 0x6497001a, 0xf72b007e, 0x00000000}},  //   mfar, nţie, сцей_,
  { {0x200209c8, 0x442f01a3, 0x7c2d09c9, 0x00000000}},  //   zaki_, _sbg_, lfar,
  { {0xa9340822, 0x20020058, 0x291a0207, 0x00000000}},  //   _перш, yaki_, cupa_,
  { {0x7c2d000c, 0x200200c4, 0x00000000, 0x00000000}},  //   nfar, xaki_,   ,
  { {0x200209ca, 0x7c2d09cb, 0x00000000, 0x00000000}},  //   vaki_, ifar,   ,
  { {0xa6e9001d, 0x60c401a3, 0x200209cc, 0x00000000}},  //   _phươ, _shim, waki_,
  { {0x660300b0, 0x20020020, 0x60c40082, 0x00000000}},  //   mank, taki_, _phim,
  { {0x60d6005f, 0x660309cd, 0xf4b60014, 0x00000000}},  //   _qiym, lank, _قشنگ,
  { {0x6449018e, 0x64590270, 0x7c2d0190, 0x00000000}},  //   mdei, _inwi, dfar,
  { {0x20020089, 0x442d001f, 0xa6e9001d, 0x00000000}},  //   saki_, lfe_, _thươ,
  { {0x2002011c, 0x7c2d02e5, 0x60c40048, 0x00000000}},  //   paki_, ffar, _thim,
  { {0x64490004, 0x442d0129, 0x6b8409ce, 0x00000000}},  //   ndei, nfe_, tzig,
  { {0x660309cf, 0x06e30044, 0x3e74006c, 0x00000000}},  // [d80] kank, নীতি, _läti_,
  { {0x291a0020, 0x224701f3, 0x20000087, 0x00000000}},  //   tupa_, _jank_, _heii_,
  { {0x660309d0, 0x2ee009d1, 0x224701aa, 0x00000000}},  //   dank, _ভবিষ, _mank_,
  { {0x291a09d2, 0x224709d3, 0x7d1c050f, 0x00000000}},  //   rupa_, _lank_, murs,
  { {0x442d0009, 0x073a0355, 0xc6f70245, 0x00000000}},  //   dfe_, تساب_, дніх_,
  { {0x660300b5, 0x6e3c09d4, 0x442d01a2, 0x00000000}},  //   gank, nerb, efe_,
  { {0x442d0109, 0x69dc0181, 0x27e60283, 0x00000000}},  //   ffe_, _igre, pcon_,
  { {0x3ae40073, 0x6e3c05de, 0x22470022, 0x00000000}},  //   _köp_, herb, _aank_,
  { {0x6603000c, 0x6e3c01d6, 0x224709d5, 0x00000000}},  //   bank, kerb, _bank_,
  { {0x7d1c0110, 0x6e3c01ee, 0x6459005b, 0x00000000}},  //   kurs, jerb, _enwi,
  { {0x6e3c0039, 0x224709d6, 0x7c2d0016, 0x00000000}},  //   derb, _dank_, yfar,
  { {0x7d1c000c, 0x38660203, 0x1c1d007d, 0x00000000}},  //   durs, njor_, _फाइल_,
  { {0x69dc066e, 0x6e3c010f, 0x764809d7, 0x00000000}},  //   _ogre, ferb, _kady,
  { {0x62810161, 0x6e3c0030, 0x69dc0065, 0x00000000}},  //   chlo, gerb, _ngre,
  { {0xf1aa007a, 0xc3480011, 0xec6b003b, 0x00000000}},  //   _باشه_, _hổ_, орак_,
  { {0x660309d8, 0x69dc09d9, 0x6e3c0026, 0x00000000}},  //   zank, _agre, aerb,
  { {0x3ec70373, 0x6e3c02fa, 0x6d4e0009, 0x00000000}},  // [d90] _особ, berb, avba,
  { {0x27ff0343, 0x68fc018e, 0x7c2d0197, 0x00000000}},  //   _seun_, _bwrd, sfar,
  { {0x7d1c00d6, 0x6603003b, 0x481509da, 0x00000000}},  //   curs, vank, емес,
  { {0x765a09db, 0x6d450020, 0x69dc008e, 0x00000000}},  //   _anty, _isha, _egre,
  { {0x660309dc, 0xc3480011, 0x76480058, 0x00000000}},  //   tank, _nổ_, _bady,
  { {0x68fc0016, 0x00000000, 0x00000000, 0x00000000}},  //   _fwrd,   ,   ,
  { {0x442d00f6, 0x27e002db, 0x224709dd, 0x00000000}},  //   tfe_, žina_, _rank_,
  { {0x934509de, 0xc3480011, 0x6d450020, 0x00000000}},  //   ение, _bổ_, _msha,
  { {0xc348001d, 0x64490016, 0x660300b0, 0x00000000}},  //   _cổ_, rdei, pank,
  { {0x27290211, 0xe1f10025, 0x6f1d0210, 0x00000000}},  //   mún_, دسة_, dusc,
  { {0x27290051, 0x6d4509df, 0x386d006c, 0x00000000}},  //   lún_, _nsha, _koer_,
  { {0x6e3c001f, 0x7f4400d6, 0x6f1d0026, 0x00000000}},  //   werb, _psiq, fusc,
  { {0x660109e0, 0x6d4500f0, 0xda0f0061, 0x00000000}},  //   _kelk, _asha, ाणात_,
  { {0x249f000c, 0x660109e1, 0x386d0007, 0x00000000}},  //   lnum_, _jelk, _loer_,
  { {0x387f01f6, 0x7afd09e2, 0x6601021e, 0x00000000}},  //   _olur_, _awst, _melk,
  { {0x249f009f, 0x6e3c002d, 0x66010010, 0x00000000}},  //   nnum_, serb, _lelk,
  { {0x7d1c09e3, 0x6e3c033b, 0xc3480011, 0x00000000}},  // [da0] surs, perb, _xổ_,
  { {0x6d45008d, 0x32050062, 0x387f09e4, 0x00000000}},  //   _fsha, naly_, _alur_,
  { {0x386d0007, 0x387f04e2, 0x764809e5, 0x00000000}},  //   _boer_, _blur_, _rady,
  { {0x7648011c, 0x7afd0544, 0x07a609e6, 0x00000000}},  //   _sady, _fwst, наен,
  { {0x27290958, 0x61360047, 0x6601014a, 0x00000000}},  //   gún_, _külö, _belk,
  { {0x66010428, 0x69dc0107, 0xc3480011, 0x00000000}},  //   _celk, _ugre, _rổ_,
  { {0x2ca009e7, 0xc348001d, 0x249f009f, 0x00000000}},  //   onid_, _sổ_, fnum_,
  { {0x249f009f, 0x545409e8, 0x95530076, 0x00000000}},  //   gnum_, твит, اخوا,
  { {0xc7a30331, 0x660109e9, 0xb05b0039, 0x00000000}},  //   _битк, _felk, lläg,
  { {0x2c7c008e, 0x320505f0, 0x2ca00048, 0x00000000}},  //   _oído_, galy_, hnid_,
  { {0xb05b0039, 0x5a170049, 0xd6cf006d, 0x00000000}},  //   nläg, עקטן_, _اقل_,
  { {0xc348001d, 0xbebb0065, 0x6f1d0210, 0x00000000}},  //   _tổ_, ntëv, tusc,
  { {0x44260061, 0xb05b010f, 0x32050062, 0x00000000}},  //   _ico_, hläg, baly_,
  { {0x6f1d09ea, 0xa01b010f, 0x7c2609eb, 0x00000000}},  //   rusc, chön, _ackr,
  { {0xac95058d, 0x2ca0012d, 0xfe6e0014, 0x00000000}},  //   вавш, fnid_, تگي_,
  { {0xdcb80265, 0x6f1d001a, 0x9404006b, 0x00000000}},  //   ещу_, pusc, timə_,
  { {0x6497001a, 0x00d800f3, 0x92de0044, 0x00000000}},  // [db0] nţia, _ثبوت_, _তবু_,
  { {0xdb260014, 0x2ca0006c, 0x9404006b, 0x00000000}},  //   ئولی, anid_, rimə_,
  { {0x6d45000b, 0x387f0870, 0x94200061, 0x00000000}},  //   _usha, _plur_, _यांच_,
  { {0x660100b0, 0xb06600b0, 0x272909ec, 0x00000000}},  //   _selk, mpää, tún_,
  { {0xf7450898, 0x386d00c7, 0x6601021e, 0x00000000}},  //   тело, _voer_, _pelk,
  { {0x272909ed, 0xe9d300a2, 0xbebb0023, 0x00000000}},  //   rún_, _مغز_, atëv,
  { {0x66010224, 0x320509ee, 0x386d0007, 0x00000000}},  //   _velk, valy_, _toer_,
  { {0x6601015c, 0x442600f6, 0x387f09ef, 0x00000000}},  //   _welk, _cco_, _ulur_,
  { {0x249f000c, 0x320504b8, 0xd84200b9, 0x00000000}},  //   rnum_, taly_, áčů_,
  { {0x4426027b, 0x249f000c, 0x425500e2, 0x00000000}},  //   _eco_, snum_, ттит,
  { {0xb05b09f0, 0x442600d6, 0x249f000c, 0x00000000}},  //   kläd, _fco_, pnum_,
  { {0x3e740039, 0xdee6007c, 0xcea90104, 0x00000000}},  //   _lätt_, коми, _וי_,
  { {0x443f0129, 0xab5b0010, 0x10a309f1, 0x00000000}},  //   meu_, _szün, риян,
  { {0x443f096b, 0x644b0129, 0x6da6051f, 0x00000000}},  //   leu_, _hagi, вига,
  { {0x6f0d0035, 0x644b011c, 0x27ed01a2, 0x00000000}},  //   _evac, _kagi, _ofen_,
  { {0x443f0129, 0x7f860025, 0x6f960025, 0x00000000}},  //   neu_, _للبن, _للعض,
  { {0x644b006a, 0x7c2b09f2, 0x443f00d4, 0x00000000}},  // [dc0] _magi, ògra, ieu_,
  { {0x644b09f3, 0x443f0065, 0xaa7b000c, 0x00000000}},  //   _lagi, heu_, _stýr,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x644b006a, 0x63a4009f, 0x7f560065, 0x00000000}},  //   _nagi, _þing, _kryq,
  { {0x443f04bd, 0x27e009f4, 0xb05b0039, 0x00000000}},  //   deu_, žino_, släg,
  { {0x7c240006, 0x7bc601d9, 0xbebb0065, 0x00000000}},  //   lgir, _izku, stëv,
  { {0x92de0055, 0xc5d50055, 0x644b0149, 0x00000000}},  //   _তবে_, _স্বপ, _bagi,
  { {0x7c2409f5, 0x38c801ef, 0x443f0129, 0x00000000}},  //   ngir, _سازی_, geu_,
  { {0x644b09f6, 0x44260093, 0xb05b00f8, 0x00000000}},  //   _dagi, _vco_, kmär,
  { {0x78a20062, 0x7c24000a, 0x64970035, 0x00000000}},  //   lnov, hgir, rţia,
  { {0x443f09f7, 0x6f0d09f8, 0x644b09f9, 0x00000000}},  //   beu_, _svac, _fagi,
  { {0x0446045e, 0x443f02d5, 0x78a209fa, 0x00000000}},  //   _једн, ceu_, nnov,
  { {0x6440014a, 0x7c24017b, 0x442406e9, 0x00000000}},  //   memi, dgir, mgm_,
  { {0x6497001a, 0x442409fb, 0x7c240032, 0x00000000}},  //   nţin, lgm_, egir,
  { {0x3e740073, 0x644b0061, 0xac2700ed, 0x00000000}},  //   _rätt_, _yagi, кфак,
  { {0x78a209fc, 0x644009fd, 0x3e740073, 0x00000000}},  //   jnov, nemi, _sätt_,
  { {0x5a350200, 0xbebb0065, 0xb05b09fe, 0x00000000}},  // [dd0] лнат, ftët, smäs,
  { {0x644009ff, 0x443f000d, 0xdce70036, 0x00000000}},  //   hemi, zeu_, zyję,
  { {0x7bc6002d, 0x443f0011, 0x64400a00, 0x00000000}},  //   _ezku, yeu_, kemi,
  { {0x443f0a01, 0x78a20062, 0x64870a02, 0x00000000}},  //   xeu_, gnov, _iñig,
  { {0x644b0a03, 0x443f09f7, 0x8c1a0104, 0x00000000}},  //   _ragi, veu_, _אורי,
  { {0x644b0a04, 0x332d0066, 0x00000000, 0x00000000}},  //   _sagi, vtex_,   ,
  { {0x644b0a05, 0x443f0a06, 0x6440009d, 0x00000000}},  //   _pagi, teu_, femi,
  { {0x69c70059, 0x64400004, 0x332d01d5, 0x00000000}},  //   _izje, gemi, ttex_,
  { {0x443f0a07, 0x91e500d7, 0x2cb90022, 0x00000000}},  //   reu_, лопе, _mksd_,
  { {0x443f0a08, 0x644b0a09, 0x332d0133, 0x00000000}},  //   seu_, _wagi, rtex_,
  { {0xe4e701fb, 0x644b0039, 0x443f0a0a, 0x00000000}},  //   _різн, _tagi, peu_,
  { {0xa3550151, 0xbebb0065, 0x644b00e7, 0x00000000}},  //   _مختص, ktës, _uagi,
  { {0xbebb008d, 0x6d57006b, 0x6d4101df, 0x00000000}},  //   jtës, _arxa, çlan,
  { {0x78a20059, 0x539a00a3, 0xdee302dc, 0x00000000}},  //   znov, _אינו, сори,
  { {0x6497001a, 0x7c240a0b, 0x78a20a0c, 0x00000000}},  //   nţio, tgir, ynov,
  { {0xb05b0004, 0xdd8f0025, 0xbebb0023, 0x00000000}},  //   smär, سوق_, ftës,
  { {0xb05b0039, 0x69c70066, 0x5f460014, 0x00000000}},  // [de0] pmär, _azje, _صندل,
  { {0x7c2400f8, 0x64400036, 0x8af0006b, 0x00000000}},  //   sgir, zemi, vvəd,
  { {0x64400a0d, 0x7c2400d4, 0xdce80089, 0x00000000}},  //   yemi, pgir, ēlēt,
  { {0xe3a7007a, 0x64400288, 0x66e60816, 0x00000000}},  //   _هر_, xemi, года,
  { {0x78a20142, 0x64400a0e, 0x2bba0025, 0x00000000}},  //   rnov, vemi, _ساحة_,
  { {0x78a20a0f, 0x09e30256, 0x00000000, 0x00000000}},  //   snov, _горн,   ,
  { {0x6440011f, 0xafdb05b7, 0x6497001a, 0x00000000}},  //   temi, ndør, rţin,
  { {0x6497001a, 0x62830a10, 0xe31400e2, 0x00000000}},  //   sţin, _alno, амињ,
  { {0x6d580a11, 0xf20607e1, 0x00000000, 0x00000000}},  //   _šval, ляно,   ,
  { {0x7ae6008a, 0x67220006, 0x86c60025, 0x00000000}},  //   _mukt, muoj, _صيان,
  { {0x27e90059, 0x6440023a, 0x7ae60039, 0x00000000}},  //   žane_, pemi, _lukt,
  { {0xf993019b, 0x6497001a, 0x26de004a, 0x00000000}},  //   מרת_, nţil, _hito_,
  { {0x6722010a, 0xf4870167, 0x26de0006, 0x00000000}},  //   nuoj, _حالی, _kito_,
  { {0xc7b30104, 0xb05b0788, 0x0cbf0309, 0x00000000}},  //   מבר_, fläc, ्ष्म,
  { {0x7ae600eb, 0x26de0207, 0x6ca70a12, 0x00000000}},  //   _aukt, _mito_, граж,
  { {0x629a0a13, 0x26de025e, 0x1f750242, 0x00000000}},  //   lito, _lito_, _влия,
  { {0x200b09c6, 0x26de0181, 0x60cd0058, 0x00000000}},  // [df0] maci_, _oito_, _iham,
  { {0x44ea028c, 0x200b00b9, 0x26de006a, 0x00000000}},  //   _où_, laci_, _nito_,
  { {0x81b60044, 0x60cd01a3, 0xbebb0065, 0x00000000}},  //   চের_, _kham, stës,
  { {0x200b0a14, 0x89340054, 0xa5650014, 0x00000000}},  //   naci_, إعلا, یگان,
  { {0x629a0020, 0x67220006, 0x26de0146, 0x00000000}},  //   kito, guoj, _bito_,
  { {0x629a000b, 0x8704007c, 0x44ea0011, 0x00000000}},  //   jito, сяце, _bù_,
  { {0x26de006a, 0x6f1d010f, 0x200b00b9, 0x00000000}},  //   _dito_, hrsc, kaci_,
  { {0x200b0868, 0x44ea001d, 0x628800b0, 0x00000000}},  //   jaci_, _dù_, ehdo,
  { {0x6b8d0a15, 0xc4820088, 0x200b05c5, 0x00000000}},  //   nzag, ільк, daci_,
  { {0x68e70065, 0x6595007e, 0x629a01b1, 0x00000000}},  //   _kujd, _казу, gito,
  { {0x7643010a, 0x4254007e, 0x200b0a16, 0x00000000}},  //   meny, стыт, faci_,
  { {0x60cd0a17, 0x200b00b9, 0x76430a18, 0x00000000}},  //   _cham, gaci_, leny,
  { {0x60cd000b, 0xe1ee0920, 0xdee6007c, 0x00000000}},  //   _dham, _мг_, роги,
  { {0x629a0142, 0x6288059c, 0x78a90243, 0x00000000}},  //   cito, chdo, _ljev,
  { {0x75230a19, 0x78bb0009, 0x67220006, 0x00000000}},  //   nunz, _okuv, zuoj,
  { {0x60cd002b, 0x200b0197, 0x76430010, 0x00000000}},  //   _gham, caci_, heny,
  { {0x76430a1a, 0x4e1a007c, 0xbebb0065, 0x00000000}},  // [e00] keny, _июня_, rtër,
  { {0x75230a1b, 0xda790088, 0xef1f0010, 0x00000000}},  //   kunz, ляє_, zzük_,
  { {0xfe37007b, 0x26de011c, 0x960b0044, 0x00000000}},  //   _דריי_, _rito_, রলাম_,
  { {0x26de0198, 0x6288008d, 0x3136007b, 0x00000000}},  //   _sito_, zhdo, ינעם_,
  { {0x78a90a1c, 0x26de0a1d, 0x87030a1e, 0x00000000}},  //   _djev, _pito_, ояще,
  { {0x7523000b, 0x200b00b9, 0x67220006, 0x00000000}},  //   funz, zaci_, ruoj,
  { {0x629a00b9, 0x32180036, 0x26de0197, 0x00000000}},  //   vito, órym_, _vito_,
  { {0x26de0020, 0x6b9b003b, 0x78a90056, 0x00000000}},  //   _wito_, _žugi, _gjev,
  { {0x629a001a, 0x26de0a1f, 0x32070a20, 0x00000000}},  //   tito, _tito_, _beny_,
  { {0x60cd002a, 0x320708e2, 0xab5b0047, 0x00000000}},  //   _sham, _ceny_, _szük,
  { {0x68e0005d, 0x6b8d0197, 0x60cd0082, 0x00000000}},  //   _kimd, zzag, _pham,
  { {0x859b009b, 0x6f040009, 0x757b0049, 0x00000000}},  //   _בשבו, _bwic, _שטאפ,
  { {0x200b00b9, 0x3eb803a1, 0x2486012d, 0x00000000}},  //   raci_, fort_, _ilom_,
  { {0x200b041a, 0x6f1d0a21, 0x66080087, 0x00000000}},  //   saci_, rrsc, _jedk,
  { {0xa3ea001c, 0x60cd0020, 0xbc0709f1, 0x00000000}},  //   _मला_, _tham, ичай,
  { {0x60cd0020, 0x320c0161, 0x6b8d002d, 0x00000000}},  //   _uham, lady_, tzag,
  { {0xa3ca0061, 0x764300e7, 0x00000000, 0x00000000}},  // [e10] ळेच_, yeny,   ,
  { {0x78a90243, 0x78bb02c3, 0x62860065, 0x00000000}},  //   _sjev, _skuv, ëkoh,
  { {0x78a90243, 0xbebb0065, 0x7ed40025, 0x00000000}},  //   _pjev, rrëd, _بزيا,
  { {0x7643005b, 0x25470010, 0x66080288, 0x00000000}},  //   weny, _ről_, _aedk,
  { {0xa01b01a2, 0x78a9016e, 0x62980116, 0x00000000}},  //   rhöh, _vjev, _omvo,
  { {0x7bda009b, 0x75230020, 0x24860a22, 0x00000000}},  //   _תקשו, tunz, _alom_,
  { {0x24860a23, 0x2bdb0061, 0x32070a24, 0x00000000}},  //   _blom_, _मृता, _reny_,
  { {0x76430a25, 0x68e00006, 0x78bb0009, 0x00000000}},  //   seny, _gimd, _ukuv,
  { {0x75230207, 0x764306fe, 0x6487004a, 0x00000000}},  //   sunz, peny, _añic,
  { {0xf6740054, 0x75230a26, 0x25470010, 0x00000000}},  //   _والخ, punz, _től_,
  { {0x6f040145, 0xd00a0a27, 0x3eb80a28, 0x00000000}},  //   _swic, лене_, vort_,
  { {0x3eb8001f, 0xb7bd001a, 0x2009001a, 0x00000000}},  //   wort_, _acţi, _ceai_,
  { {0xd12e00d3, 0x3eb80010, 0x42d50088, 0x00000000}},  //   ومی_, tort_, _ліку,
  { {0x201e0a29, 0x24860253, 0xddde00e5, 0x00000000}},  //   şti_, _zlom_, _copş,
  { {0x22450a2a, 0x80f50025, 0x3eb805b4, 0x00000000}},  //   melk_, _استض, rort_,
  { {0x27e0089f, 0xb05b0a2b, 0x6f0400ab, 0x00000000}},  //   žini_, llän, _twic,
  { {0x3eb80a2c, 0x7c360a2d, 0x00000000, 0x00000000}},  // [e20] port_, rfyr,   ,
  { {0xb05b0210, 0x62810a2e, 0xa96a005e, 0x00000000}},  //   nlän, nklo, лиза_,
  { {0x66080059, 0xb05b0210, 0xfeba00a1, 0x00000000}},  //   _redk, ilän, _لاگت_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68fb073a, 0xb05b0a2f, 0x00000000, 0x00000000}},  //   _čude, klän,   ,
  { {0xfd65001d, 0x00000000, 0x00000000, 0x00000000}},  //   _nguồ,   ,   ,
  { {0x99860054, 0x660805b7, 0x5d7a0049, 0x00000000}},  //   _الأو, _vedk, טאַק,
  { {0x62810168, 0x00000000, 0x00000000, 0x00000000}},  //   eklo,   ,   ,
  { {0xc4450014, 0x7786003b, 0xf3ef0025, 0x00000000}},  //   زیون_, _улаз, رأي_,
  { {0x32660a30, 0x2732001a, 0xe5a600d7, 0x00000000}},  //   стив, mân_, _лизи,
  { {0x320c0a31, 0xd257008b, 0xaabb0049, 0x00000000}},  //   rady_, сцы_, רזיכ,
  { {0x320c0a32, 0x629d009d, 0x62810168, 0x00000000}},  //   sady_, ésor, aklo,
  { {0x320c067f, 0x937a0445, 0xdb0f00fa, 0x00000000}},  //   pady_, _حصار_, _excê,
  { {0xacf90a33, 0xddde0173, 0x00000000, 0x00000000}},  //   ингу_, _enpō,   ,
  { {0x403501be, 0x27320016, 0x00000000, 0x00000000}},  //   _дейс, hân_,   ,
  { {0xa0a40080, 0xce33007a, 0xd011025a, 0x00000000}},  //   _најд, _کودک, _کلک_,
  { {0xf09f0129, 0x3a750545, 0x00000000, 0x00000000}},  // [e30] mià_, олар,   ,
  { {0x9e070200, 0xf09f0129, 0x00000000, 0x00000000}},  //   _учил, lià_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x50c9007d, 0x00000000, 0x00000000, 0x00000000}},  //   रतिष,   ,   ,
  { {0xf10502fb, 0x2ca90a34, 0x628104a5, 0x00000000}},  //   _शब्द_, mnad_, yklo,
  { {0x45190001, 0x2ca902e1, 0xf09f0026, 0x00000000}},  //   ация_, lnad_, hià_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2ca90004, 0x833900ed, 0xf1c3013e, 0x00000000}},  //   nnad_, ачот_, _liší_,
  { {0x6497001a, 0x2d8c004a, 0xb05b04ce, 0x00000000}},  //   nţii, údez_, tlän,
  { {0xe299012b, 0x2ca90016, 0x7c2f01c3, 0x00000000}},  //   рао_, hnad_, _lccr,
  { {0xc66801f9, 0xb05b0002, 0xe04604ef, 0x00000000}},  //   _уште_, rlän, онни,
  { {0x628101d6, 0x61fc0279, 0xb05b0a35, 0x00000000}},  //   sklo, ırla, slän,
  { {0xb05b01a2, 0x2d910026, 0x7e770203, 0x00000000}},  //   plän, ezze_, _boxp,
  { {0x7c2f062a, 0x0eba0147, 0x2eb403d7, 0x00000000}},  //   _accr, румы_, ंकेत,
  { {0x1d0a0545, 0x00000000, 0x00000000, 0x00000000}},  //   реби_,   ,   ,
  { {0x90c301be, 0x9f5201aa, 0x248d00b5, 0x00000000}},  //   _обще, _deyò_, nhem_,
  { {0x8af7005f, 0x443d01c3, 0x2d910026, 0x00000000}},  // [e40] _şəra, _mbw_, azze_,
  { {0xa01b0a36, 0x443d01d6, 0x4a4300ed, 0x00000000}},  //   nkön, _lbw_, мнув,
  { {0x443d0a37, 0x02b60049, 0xdb0600f8, 0x00000000}},  //   _obw_, קלעך_, _nykö,
  { {0xd7f00025, 0xa01b0052, 0x00000000, 0x00000000}},  //   ركت_, hkön,   ,
  { {0x05260055, 0x6497001a, 0x248d0829, 0x00000000}},  //   _মনের_, cţii, dhem_,
  { {0x057601d8, 0x63a4010a, 0x6d5e00d0, 0x00000000}},  //   قاعد, _žino, _krpa,
  { {0x248d002b, 0x443d0133, 0x00000000, 0x00000000}},  //   fhem_, _bbw_,   ,
  { {0x69ce0a38, 0x248d00f8, 0x7d7b0049, 0x00000000}},  //   _izbe, ghem_, ינצו,
  { {0x6843008b, 0xe3af00a1, 0xd7ef0025, 0x00000000}},  //   _інфа, ہری_, _شكل_,
  { {0xa5f7012b, 0x442f0253, 0x443d01c3, 0x00000000}},  //   _међу_, _ecg_, _ebw_,
  { {0xe3af00a6, 0xdb0f0a39, 0x21660088, 0x00000000}},  //   فری_, _excè, ітог,
  { {0x248d0a3a, 0x442f0093, 0x27e00213, 0x00000000}},  //   chem_, _gcg_, žinu_,
  { {0x14d70049, 0xf09f0129, 0x6722004a, 0x00000000}},  //   _וואל_, rià_, nroj,
  { {0x6263005e, 0x69ce0a3b, 0x9f520173, 0x00000000}},  //   _овча, _ozbe, _peyò_,
  { {0x2d85004f, 0x628a001a, 0xb05b0a3c, 0x00000000}},  //   ále_, _ilfo, lläm,
  { {0xbca50025, 0x67220a3d, 0x6fd30309, 0x00000000}},  //   أمري, kroj, _सरपं,
  { {0x2d850091, 0x2ca900ea, 0x6d5e0058, 0x00000000}},  // [e50] šle_, rnad_, _erpa,
  { {0x67220a3e, 0x248d0645, 0xc5e400a1, 0x00000000}},  //   droj, zhem_, _لۓ_,
  { {0xdcef0089, 0x5f740014, 0x6aae0146, 0x00000000}},  //   ēdēt, _فایر, _djbf,
  { {0x63ad000c, 0x249f062a, 0x00000000, 0x00000000}},  //   _þang, xium_,   ,
  { {0x69ce0a3f, 0xae1f013d, 0x442f012d, 0x00000000}},  //   _ezbe, _बयान_, _rcg_,
  { {0x7bda009b, 0x442f0a40, 0x249f0a41, 0x00000000}},  //   _לקרו, _scg_, wium_,
  { {0xa8a7007c, 0x20020036, 0x248d02f1, 0x00000000}},  //   _драк, ybki_, them_,
  { {0x7c2d0a42, 0x628a0779, 0x67220091, 0x00000000}},  //   ngar, _alfo, broj,
  { {0x248d0a43, 0x7c2d0032, 0xec790082, 0x00000000}},  //   rhem_, igar, _độc_,
  { {0x248d008d, 0x7c2d018e, 0xc879014a, 0x00000000}},  //   shem_, hgar, _hoş_,
  { {0x63ad0107, 0x6b890036, 0x78ab0082, 0x00000000}},  //   _žand, _żegl, ongv,
  { {0x628a0047, 0x2eb60164, 0x443d0a44, 0x00000000}},  //   _elfo, ृत्त, _ubw_,
  { {0xe28e00aa, 0x44f102d5, 0x6d5e0209, 0x00000000}},  //   _за_, _há_, _srpa,
  { {0x7c2d0207, 0x644906c0, 0x00000000, 0x00000000}},  //   egar, leei,   ,
  { {0x44f10a45, 0x68fe0009, 0x6722012d, 0x00000000}},  //   _já_, xppd, zroj,
  { {0x7c2d0a46, 0xb5fc0066, 0x644900ea, 0x00000000}},  //   ggar, _anġl, neei,
  { {0x44f10a47, 0x442d0a48, 0xfbd1026c, 0x00000000}},  // [e60] _lá_, ige_, ہتے_,
  { {0x20d20051, 0x7c2d0a49, 0x68fe0009, 0x00000000}},  //   sáid_, agar, tppd,
  { {0x44f10a4a, 0xc879005d, 0xd7fa01bd, 0x00000000}},  //   _ná_, _boş_, бул_,
  { {0x67220161, 0xc8790a4b, 0x26c701ee, 0x00000000}},  //   troj, _coş_, elno_,
  { {0x442d0038, 0x27e0021e, 0x6d5c0007, 0x00000000}},  //   dge_, äin_, lvra,
  { {0xa96a017a, 0x67220065, 0x44f10011, 0x00000000}},  //   _лига_, rroj, _bá_,
  { {0x44f10a4c, 0x69ce0a4d, 0x6d5c02ae, 0x00000000}},  //   _cá_, _uzbe, nvra,
  { {0x67220089, 0x44f1002a, 0x442d0374, 0x00000000}},  //   proj, _dá_, gge_,
  { {0x68ee0022, 0xa01b04ce, 0x00000000, 0x00000000}},  //   _hubd, khör,   ,
  { {0x44f10a4e, 0x442d0866, 0x8af0005f, 0x00000000}},  //   _fá_, age_, vvəl,
  { {0x44f1002a, 0x7c2d0006, 0x044602b8, 0x00000000}},  //   _gá_, ygar, _нежн,
  { {0xc879006b, 0x84960a4f, 0x232a0216, 0x00000000}},  //   _xoş_, _عجائ, _годи_,
  { {0x4abe007d, 0xb05b00b0, 0x7c2d02a9, 0x00000000}},  //   ्ताव, lläk, vgar,
  { {0x68fc0089, 0x2ee501a2, 0x7c2d00d9, 0x00000000}},  //   _otrd, ölf_, wgar,
  { {0x291c0a50, 0xd23b009b, 0xdb1d00b9, 0x00000000}},  //   ával_, _הגול, _vysí,
  { {0x7c2d0a51, 0xd1380a52, 0xb4fb00a3, 0x00000000}},  //   ugar, mtą_, מפלי,
  { {0x7c2d009f, 0x78a20a53, 0x64970a54, 0x00000000}},  // [e70] rgar, diov, cţiu,
  { {0x7c2d022b, 0x6ce70088, 0xd1380a55, 0x00000000}},  //   sgar, _німе, otą_,
  { {0xd1380006, 0x442d08c8, 0x9f590919, 0x00000000}},  //   ntą_, yge_, pasó_,
  { {0x44f10a56, 0x78a20a57, 0xd1380006, 0x00000000}},  //   _rá_, giov, itą_,
  { {0xb8f402d2, 0x2918003b, 0x44f1009f, 0x00000000}},  //   _सी_, _evra_, _sá_,
  { {0x44f100b9, 0xd1380006, 0x764a00eb, 0x00000000}},  //   _pá_, ktą_, gefy,
  { {0x442d04bd, 0x2d83010a, 0xe6100076, 0x00000000}},  //   tge_, nyje_, اشه_,
  { {0x44f10a58, 0x442d0a59, 0x6d450146, 0x00000000}},  //   _vá_, uge_, _mpha,
  { {0x44f10011, 0x6d450919, 0x6d5c0466, 0x00000000}},  //   _wá_, _lpha, zvra,
  { {0x44f10195, 0x6d450a5a, 0xe2990088, 0x00000000}},  //   _tá_, _opha, іан_,
  { {0xbebb0023, 0x442d00f8, 0x00000000, 0x00000000}},  //   trën, pge_,   ,
  { {0xbe250055, 0xa06a003b, 0x7afd006c, 0x00000000}},  //   ম্মদ_, цама_, _otst,
  { {0x3ea30a5b, 0x7afd01d6, 0xa01b06d3, 0x00000000}},  //   fijt_, _ntst, thör,
  { {0x68fb0091, 0xdd9200a6, 0x6d5c0023, 0x00000000}},  //   _čudn, پور_, tvra,
  { {0x7afd0a5c, 0xed5701bd, 0xa01b0a5d, 0x00000000}},  //   _atst, мор_, rhör,
  { {0x69da0181, 0x6d5c0a5e, 0xa01b06d3, 0x00000000}},  //   _útei, rvra, shör,
  { {0x7ae70a5b, 0x68fc00ca, 0x6d5c0112, 0x00000000}},  // [e80] _bijt, _strd, svra,
  { {0x68ee0a5f, 0xab5b0010, 0x7aef0a60, 0x00000000}},  //   _pubd, _gyüm, _duct,
  { {0xceb3007b, 0xbebb0065, 0x994a0380, 0x00000000}},  //   _ביז_, ytëz, تلال_,
  { {0x672b0a61, 0x7aef00e5, 0xcb6a0545, 0x00000000}},  //   fugj, _fuct, _даме_,
  { {0x78a20161, 0x7bc6014a, 0x60c400e7, 0x00000000}},  //   riov, _uyku, _mkim,
  { {0xd1380a62, 0xa92601fc, 0x6eeb0066, 0x00000000}},  //   ytą_, _одгл, _użbe,
  { {0x98a6017a, 0x250700a1, 0x764a0016, 0x00000000}},  //   _живе, ورٹی_, refy,
  { {0x7afd00ea, 0x764a0016, 0x00000000, 0x00000000}},  //   _ytst, sefy,   ,
  { {0x98a3004d, 0x6b840a63, 0xb05b00f8, 0x00000000}},  //   _рите, nyig, släk,
  { {0x60c40a64, 0x325401ff, 0xa01b01a2, 0x00000000}},  //   _akim, хвор, rköm,
  { {0x60f803e8, 0x403502dc, 0x6b840a65, 0x00000000}},  //   яння_, ненс, hyig,
  { {0xd1380a66, 0x60d6018e, 0x42ce0044, 0x00000000}},  //   rtą_, _chym, রদেশ,
  { {0xd1380a67, 0x32050a68, 0x00000000, 0x00000000}},  //   stą_, bbly_,   ,
  { {0x60c40a69, 0x2d830006, 0x2bd5007d, 0x00000000}},  //   _ekim, tyje_, _दरबा,
  { {0x68fb0627, 0x6d580006, 0x7ae700bb, 0x00000000}},  //   _čudo, _švar, _rijt,
  { {0x96140044, 0x2d830006, 0xbf350088, 0x00000000}},  //   সলিম_, ryje_, _знищ,
  { {0x3f4f01d5, 0x7ebf00b9, 0x92c20044, 0x00000000}},  // [e90] _użu_, tápě, ্দী_,
  { {0x6f0d0117, 0x2d830006, 0x2a6a00c4, 0x00000000}},  //   _iwac, pyje_, _cnbb_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x38690841, 0xc879047f, 0x80d10044, 0x00000000}},  //   ñar_, _kişi_, _সূত্,
  { {0x7afd01c9, 0x3669003b, 0xfc3f0010, 0x00000000}},  //   _utst, зало_, _amíg_,
  { {0x29010061, 0xaa4500b0, 0x6f0d00e7, 0x00000000}},  //   ppha_, ävää_, _mwac,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3ba007d, 0xf99200b3, 0x6aa50022, 0x00000000}},  //   _आँख_, _ערן_, lihf,
  { {0x27ed0a6a, 0x60d60a6b, 0x00000000, 0x00000000}},  //   _igen_, _rhym,   ,
  { {0x68e90a6c, 0x60d604a5, 0x00000000, 0x00000000}},  //   _hied, _shym,   ,
  { {0x68e90046, 0x32050007, 0x00000000, 0x00000000}},  //   _kied, rbly_,   ,
  { {0x6f0d0a5f, 0x2280000a, 0x62880133, 0x00000000}},  //   _bwac, _bòks_, akdo,
  { {0x68e90a6d, 0x443f0a6e, 0x00000000, 0x00000000}},  //   _mied, mfu_,   ,
  { {0x443f088f, 0x5239007b, 0x68e901c3, 0x00000000}},  //   lfu_, _זײַנ, _lied,
  { {0xfaff008d, 0x64590a6f, 0x7bcb010f, 0x00000000}},  //   _atë_, _kawi, ügun,
  { {0x68e90a70, 0x60c4000b, 0x63a4010a, 0x00000000}},  //   _nied, _ukim, _žini,
  { {0x6d41011f, 0x64590020, 0x443f0020, 0x00000000}},  // [ea0] çlar, _mawi, ifu_,
  { {0x27ed0169, 0x64590a71, 0x00000000, 0x00000000}},  //   _agen_, _lawi,   ,
  { {0x68e90a72, 0x20120a73, 0x9c8300ca, 0x00000000}},  //   _bied, _keyi_, ščav,
  { {0x7e7e0073, 0x64590036, 0xb5fc002b, 0x00000000}},  //   _hopp, _nawi, _inġi,
  { {0x7e7e0a5e, 0x1754007c, 0xe7c00044, 0x00000000}},  //   _kopp, твля, েশ্য,
  { {0x27ed05cb, 0x443f0020, 0x7e7e0a74, 0x00000000}},  //   _egen_, efu_, _jopp,
  { {0x80d10055, 0x443f0016, 0x7e7e0a75, 0x00000000}},  //   _সংস্, ffu_, _mopp,
  { {0x7e7e021e, 0xd497007c, 0x68e90a76, 0x00000000}},  //   _lopp, ерь_, _gied,
  { {0x64590a77, 0x82a60a78, 0x7e7e0052, 0x00000000}},  //   _dawi, ешне, _oopp,
  { {0x68e9001e, 0x443f0a79, 0x07a30242, 0x00000000}},  //   _zied, afu_, _саун,
  { {0xc5690025, 0x3ce10061, 0x00000000, 0x00000000}},  //   _يحمل_, _कळले_,   ,
  { {0x6459006a, 0x92c20044, 0x765a0a7a, 0x00000000}},  //   _gawi, ্দে_, _haty,
  { {0x765a000a, 0x7e7e01ee, 0x00000000, 0x00000000}},  //   _katy, _bopp,   ,
  { {0x64590046, 0x7e7e051b, 0xa6e70082, 0x00000000}},  //   _zawi, _copp, _nhữ,
  { {0x7e7e09fa, 0x765a0a7b, 0x20d20051, 0x00000000}},  //   _dopp, _maty, máin_,
  { {0x6ca40a7c, 0x765a01d6, 0x20d20051, 0x00000000}},  //   груж, _laty, láin_,
  { {0x68e9002b, 0xfaf30084, 0x5a350893, 0x00000000}},  // [eb0] _ried, اثر_, кнат,
  { {0x765a0a7d, 0x68e90036, 0x20d20051, 0x00000000}},  //   _naty, _sied, náin_,
  { {0x68e9001e, 0x39470129, 0x48150242, 0x00000000}},  //   _pied, ïns_, вмес,
  { {0x20d2002a, 0xe0df0263, 0x7e7e0a7e, 0x00000000}},  //   háin_, nmò_, _zopp,
  { {0x68e90a7f, 0x20d90051, 0xed590089, 0x00000000}},  //   _vied, méid_, āžu_,
  { {0x68e90a80, 0x945d0036, 0x645904cb, 0x00000000}},  //   _wied, końc, _sawi,
  { {0x68e9021e, 0x64590a81, 0x20d20051, 0x00000000}},  //   _tied, _pawi, dáin_,
  { {0x27ed0030, 0x20d90051, 0x69d601f5, 0x00000000}},  //   _ugen_, néid_, _भरती,
  { {0x645b0007, 0x443f0a82, 0x00000000, 0x00000000}},  //   rdui, rfu_,   ,
  { {0x09e50055, 0x6459000b, 0x2362000c, 0x00000000}},  //   _প্যা, _wawi, ækja_,
  { {0x20120607, 0x81c90055, 0x443f0009, 0x00000000}},  //   _peyi_, লেন_, pfu_,
  { {0x387f028c, 0x7e7e0a83, 0x7e0a007d, 0x00000000}},  //   _jour_, _sopp, वर्ग_,
  { {0xa4d401fb, 0x08760049, 0x0478025a, 0x00000000}},  //   _соці, דערט_, _سلوک_,
  { {0x9f9e0181, 0xe0df0026, 0x387f000a, 0x00000000}},  //   _ação_, amò_, _lour_,
  { {0x71640025, 0x386d0085, 0x00000000, 0x00000000}},  //   _مايك, _oner_,   ,
  { {0x09b00055, 0x387f0a84, 0x00000000, 0x00000000}},  //   _করলা, _nour_,   ,
  { {0xf412007b, 0x69d50197, 0xebe60a85, 0x00000000}},  // [ec0] יפן_, _azze, тоап,
  { {0x386d0190, 0xdee60745, 0x0d860478, 0x00000000}},  //   _aner_, _шопи, _алон,
  { {0x386d0093, 0x387f0a86, 0xceb900b9, 0x00000000}},  //   _bner_, _bour_, éře_,
  { {0x387f00f4, 0x765a0036, 0x20d90a87, 0x00000000}},  //   _cour_, _saty, céid_,
  { {0x765a010a, 0x69d50047, 0x387f0685, 0x00000000}},  //   _paty, _ezze, _dour_,
  { {0x6f02011f, 0x64950051, 0xa6340088, 0x00000000}},  //   _çocu, _láid, ункі,
  { {0x387f0a88, 0xc60b0044, 0x64b3001a, 0x00000000}},  //   _four_, _রাখা_, răin,
  { {0xb4cc0061, 0x2cb20544, 0x00000000, 0x00000000}},  //   ळते_, nnyd_,   ,
  { {0x20d20051, 0xd2500025, 0x765a0a89, 0x00000000}},  //   táin_, منة_, _taty,
  { {0x7c290089, 0x00000000, 0x00000000, 0x00000000}},  //   _ķerm,   ,   ,
  { {0x387f0a8a, 0x63ad009f, 0x20d203df, 0x00000000}},  //   _your_, _þann, ráin_,
  { {0x20d2002a, 0x63a4010a, 0x661800ca, 0x00000000}},  //   sáin_, _žinu, lavk,
  { {0x44f80a8b, 0xe0df0197, 0x20d20051, 0x00000000}},  //   _hé_, rmò_, máil_,
  { {0x6fe90089, 0x768f00ea, 0x44f80082, 0x00000000}},  //   _rīcī, _løyn, _ké_,
  { {0x3958012d, 0xac950140, 0x00000000, 0x00000000}},  //   _nsrs_, гавш,   ,
  { {0x44f80195, 0x273b00ad, 0x80d10044, 0x00000000}},  //   _mé_, yên_, _সূর্,
  { {0x44f80048, 0x3084006d, 0xdad9003b, 0x00000000}},  // [ed0] _lé_, _خليف, емац_,
  { {0x20d2002a, 0x20190a8c, 0x7e5501fb, 0x00000000}},  //   háil_, lasi_, _своє,
  { {0x387f0a8d, 0x44f80a8e, 0x20d90051, 0x00000000}},  //   _pour_, _né_, péid_,
  { {0x20190a8f, 0xdb1d00b0, 0xb4cc0061, 0x00000000}},  //   nasi_, _pysä, ळतो_,
  { {0xfeb80a90, 0x9cd6061e, 0x20d2002a, 0x00000000}},  //   _سایت_, _תורה_, dáil_,
  { {0x2ca9018e, 0x44f80a91, 0x2557005f, 0x00000000}},  //   liad_, _bé_, _hələ_,
  { {0x20190149, 0x44f8002a, 0x8883007a, 0x00000000}},  //   kasi_, _cé_, _پیشن,
  { {0x236601cd, 0x20d2002a, 0x2ca9018e, 0x00000000}},  //   _broj_, gáil_, niad_,
  { {0x2019023a, 0x69da00b9, 0x661804eb, 0x00000000}},  //   dasi_, _úter, bavk,
  { {0x44f80a92, 0x2019001a, 0x2ca90016, 0x00000000}},  //   _fé_, easi_, hiad_,
  { {0x2019000b, 0xe43500f3, 0x2366002b, 0x00000000}},  //   fasi_, _مفاد, _eroj_,
  { {0x20190a93, 0x20d20051, 0x672b0023, 0x00000000}},  //   gasi_, cáil_, orgj,
  { {0x2ca9018e, 0x324500ed, 0x44f80181, 0x00000000}},  //   diad_, _белг, _zé_,
  { {0xed5a012b, 0x248d0224, 0xf2070077, 0x00000000}},  //   ног_, lkem_, _рядо,
  { {0x2ca9018e, 0xf8b301f5, 0x20190020, 0x00000000}},  //   fiad_, ंचाय, basi_,
  { {0x2ca9018e, 0x6abe0309, 0x1bea0a94, 0x00000000}},  //   giad_, ्त्र, едби_,
  { {0xab66045a, 0x7c2b0a58, 0xb05b0039, 0x00000000}},  // [ee0] ывал, ógra, rlät,
  { {0x248d0004, 0x68f5014a, 0xb86500a6, 0x00000000}},  //   hkem_, _buzd, یانو,
  { {0xb05b010f, 0xdca601c0, 0x2ca90016, 0x00000000}},  //   plät, _бани, biad_,
  { {0x44f80a95, 0x63b6000c, 0x2ca90016, 0x00000000}},  //   _ré_, _þyng, ciad_,
  { {0x44f80a96, 0x248d00b9, 0xc60b0044, 0x00000000}},  //   _sé_, dkem_, _রাজা_,
  { {0x44f80a97, 0x4ab80309, 0x248d00bb, 0x00000000}},  //   _pé_, _आदिव, ekem_,
  { {0x20d2002a, 0x2019027d, 0x2b400a98, 0x00000000}},  //   táil_, yasi_, ltic_,
  { {0x44f80011, 0x768f00ea, 0x6f0404eb, 0x00000000}},  //   _vé_, _høyl, _otic,
  { {0x20d2002a, 0xe80a001c, 0x36360151, 0x00000000}},  //   ráil_, _ह्या_, _مراس,
  { {0x44f80a99, 0x20d20051, 0x20190a9a, 0x00000000}},  //   _té_, sáil_, wasi_,
  { {0x20190149, 0x326307d0, 0x6f04008e, 0x00000000}},  //   tasi_, стыв, _atic,
  { {0x68e20302, 0x6f1d0a9b, 0x248d013e, 0x00000000}},  //   nmod, tssc, ckem_,
  { {0x20190149, 0xb4c20061, 0xb4c0006e, 0x00000000}},  //   rasi_, ृती_, ंकी_,
  { {0x20190149, 0x2563011f, 0x2ca9010b, 0x00000000}},  //   sasi_, _yıl_, wiad_,
  { {0x6f040a9c, 0x20190169, 0x2ca90016, 0x00000000}},  //   _etic, pasi_, tiad_,
  { {0xb05b0788, 0x2b4b00d4, 0x68e20471, 0x00000000}},  //   rläs, _ppcc_, jmod,
  { {0x2ca9018e, 0x68e20a9d, 0x68f50166, 0x00000000}},  // [ef0] riad_, dmod, _suzd,
  { {0x69ce0343, 0x2ca9018e, 0x8f9c0049, 0x00000000}},  //   _bybe, siad_, _ריזי,
  { {0xb9b50a4f, 0x81e60044, 0x2ca9010e, 0x00000000}},  //   جماع, যুর_, piad_,
  { {0x69ce0190, 0x21370049, 0x68e202fa, 0x00000000}},  //   _dybe, רטאל_, gmod,
  { {0x65680a9e, 0x2b400899, 0xdc36007b, 0x00000000}},  //   _ardh, ctic_, _דארט_,
  { {0x7aee010f, 0x83fd0010, 0x8af0006b, 0x00000000}},  //   _gibt, zdőd, rvət,
  { {0xd6180379, 0x248d0a9f, 0x291c093f, 0x00000000}},  //   اتها_, tkem_, ávat_,
  { {0x032509bb, 0x7f4d0aa0, 0x68e206ed, 0x00000000}},  //   адин, _opaq, cmod,
  { {0x65680065, 0xc6140055, 0x248d0aa1, 0x00000000}},  //   _erdh, _সারা_, rkem_,
  { {0x248d018b, 0x78ab0030, 0x6487008e, 0x00000000}},  //   skem_, ligv, _añit,
  { {0xe0da0aa2, 0x39410038, 0x26c70aa3, 0x00000000}},  //   кво_, nths_, mono_,
  { {0x6f040825, 0x6e2504df, 0x78ab0112, 0x00000000}},  //   _ptic, _adhb, nigv,
  { {0xe28e017f, 0x7d050051, 0xa856009b, 0x00000000}},  //   _да_, _aths, בירה_,
  { {0x91e50364, 0x539a009b, 0x1167025a, 0x00000000}},  //   _коле, _בינו, _ملتی_,
  { {0x6283031e, 0x26c70197, 0x5fd80061, 0x00000000}},  //   _iono, iono_, _ठरवल,
  { {0x62830aa4, 0x26c70658, 0x77690032, 0x00000000}},  //   _hono, hono_, _orex,
  { {0x62830aa5, 0x6f0405fa, 0x26c70020, 0x00000000}},  // [f00] _kono, _utic, kono_,
  { {0x26c70006, 0x68e200d9, 0x628300b0, 0x00000000}},  //   jono_, wmod, _jono,
  { {0x26c70207, 0x20d90181, 0x394100e0, 0x00000000}},  //   dono_, léia_, gths_,
  { {0x69ce0428, 0x2b400133, 0xa01b0aa6, 0x00000000}},  //   _vybe, ptic_, lkör,
  { {0x26c70682, 0x68e20039, 0xbebb0065, 0x00000000}},  //   fono_, rmod, rrëv,
  { {0x26c7027b, 0x62830207, 0x69ce026e, 0x00000000}},  //   gono_, _nono, _tybe,
  { {0x68e200ea, 0xa01b0039, 0x768f00ea, 0x00000000}},  //   pmod, ljöe, _gøym,
  { {0xd7060242, 0x69d80089, 0x77690288, 0x00000000}},  //   _взаи, ļved, _frex,
  { {0xa2c2024c, 0x26c70066, 0x6283008e, 0x00000000}},  //   रकल्, bono_, _bono,
  { {0x62830aa7, 0xc2c30054, 0x26c70207, 0x00000000}},  //   _cono, يييي, cono_,
  { {0x62830aa8, 0xd48f017f, 0x7c260aa9, 0x00000000}},  //   _dono, _др_, _odkr,
  { {0xdcee010a, 0x75d30014, 0xb97b009b, 0x00000000}},  //   mybė, _بيما, דנטי,
  { {0x44260211, 0x6283002d, 0xe3b20151, 0x00000000}},  //   _ido_, _fono, _برا_,
  { {0x62830010, 0xef1f0095, 0x442600d2, 0x00000000}},  //   _gono, rsü_, _hdo_,
  { {0x44260aaa, 0xdcee0006, 0x6ca7007e, 0x00000000}},  //   _kdo_, nybė, араж,
  { {0x80d10055, 0x1bf5007e, 0x62830006, 0x00000000}},  //   _সংক্, спаў, _zono,
  { {0x26c7023a, 0x39410319, 0x60cd0284, 0x00000000}},  // [f10] yono_, wths_, _ikam,
  { {0x99670001, 0x3b09006b, 0xdcee0006, 0x00000000}},  //   ител, rpaq_, kybė,
  { {0xd366007a, 0x26c70207, 0x44260aab, 0x00000000}},  //   _که_, vono_, _odo_,
  { {0x7769027b, 0x44260020, 0x649c0051, 0x00000000}},  //   _prex, _ndo_, _héif,
  { {0x26c70006, 0xcc7600b3, 0x60cd00e7, 0x00000000}},  //   tono_, _הערה_, _mkam,
  { {0x1af600a0, 0x4426009d, 0x39410133, 0x00000000}},  //   _למשל_, _ado_, pths_,
  { {0x09e50055, 0x99850054, 0x4518008b, 0x00000000}},  //   _প্রা, _الزو, ацыя_,
  { {0x4426008d, 0xa8a40aac, 0xe459003b, 0x00000000}},  //   _cdo_, _друк, ужи_,
  { {0x62830119, 0x6b8d0010, 0x26c70aad, 0x00000000}},  //   _pono, nyag, pono_,
  { {0x44260756, 0x60cd0aae, 0x80d10044, 0x00000000}},  //   _edo_, _akam, _সংগ্,
  { {0xb5a70605, 0x62830023, 0x4426004a, 0x00000000}},  //   _трай, _vono, _fdo_,
  { {0x656e002a, 0x160b03d7, 0x62830093, 0x00000000}},  //   _ábha, _स्तर_, _wono,
  { {0x80d10055, 0xafdb0030, 0x443d0093, 0x00000000}},  //   _সংখ্, lføj, _icw_,
  { {0x629a0aaf, 0x20d900c4, 0xde030ab0, 0x00000000}},  //   chto, réia_, зпри,
  { {0x753c010f, 0x7c96007e, 0x69a7013d, 0x00000000}},  //   _ärzt, брац, _टेली,
  { {0x20d900c4, 0xa01b0010, 0xa5c30036, 0x00000000}},  //   péia_, skör, ciół,
  { {0xc9f60025, 0x09e50044, 0x5f4600a1, 0x00000000}},  // [f20] مساع, _প্লা, _انخل,
  { {0xe810007d, 0x2bac0061, 0x7810006e, 0x00000000}},  //   ार्थ_, _घेणा, ार्क_,
  { {0x81c90055, 0x443d05aa, 0x186a01ee, 0x00000000}},  //   লের_, _ocw_, лажи_,
  { {0x6d5e0209, 0xa01b0039, 0xe81a05f3, 0x00000000}},  //   _ispa, nköp, ازات_,
  { {0x6d5e001c, 0x20020521, 0x649c0048, 0x00000000}},  //   _hspa, icki_, _héig,
  { {0xdcee010a, 0xa01b021e, 0x44260065, 0x00000000}},  //   tybė, hköp, _sdo_,
  { {0x2bac0061, 0x443d0009, 0xdcfc0006, 0x00000000}},  //   _घेता, _bcw_, tyrę,
  { {0x69dc0059, 0x44260ab1, 0x629d0023, 0x00000000}},  //   _izre, _qdo_, ëson,
  { {0x649c002a, 0xd6d20318, 0x57fb0097, 0x00000000}},  //   _léig, _فقر_, _תלמו,
  { {0x60cd06e8, 0x6d5e002d, 0xd25a014c, 0x00000000}},  //   _skam, _ospa, уци_,
  { {0x67220089, 0x38cb00a1, 0x44260ab2, 0x00000000}},  //   lsoj, _شاہی_, _tdo_,
  { {0x5577007b, 0x629a008d, 0x661a08b2, 0x00000000}},  //   _לעבן_, shto, _hetk,
  { {0x6d5e0ab3, 0x7e2b008b, 0x32cb00ea, 0x00000000}},  //   _aspa, ліва_, røyr_,
  { {0x0dcb0a94, 0x20020190, 0x768f00ea, 0x00000000}},  //   губи_, acki_, _røyk,
  { {0x321e0036, 0x64950051, 0x661a016e, 0x00000000}},  //   maty_, _máin, _metk,
  { {0x6d5e0ab4, 0x661a0052, 0x60cd0020, 0x00000000}},  //   _dspa, _letk, _ukam,
  { {0xfbd30076, 0x6f160016, 0x3cfa00f6, 0x00000000}},  // [f30] ستر_, _gwyc, _eupv_,
  { {0x661a0209, 0xbebb0065, 0x24860ab5, 0x00000000}},  //   _netk, rrës, _loom_,
  { {0x6f160036, 0x29070065, 0x79590ab6, 0x00000000}},  //   _zwyc, ëna_, риер_,
  { {0x29070089, 0xd7d50ab7, 0x00000000, 0x00000000}},  //   īna_, ожењ,   ,
  { {0x321e0036, 0x649c0048, 0x69dc0010, 0x00000000}},  //   katy_, _méid, _ezre,
  { {0x661a0ab8, 0xda7b007e, 0x57a90061, 0x00000000}},  //   _cetk, _сям_, _कधीह,
  { {0x24860007, 0x78bb00d8, 0xe8100061, 0x00000000}},  //   _boom_, _tjuv, ारखा_,
  { {0x629805b7, 0x661a0116, 0x78a90ab9, 0x00000000}},  //   _alvo, _eetk, _umev,
  { {0x254e006b, 0x64950051, 0x24860aba, 0x00000000}},  //   _cəlb_, _fáin, _doom_,
  { {0x52a9007c, 0x81bd0044, 0x321e00b4, 0x00000000}},  //   рвом_, _আরব_, gaty_,
  { {0xdb06000c, 0x6f1600b4, 0x00000000, 0x00000000}},  //   _ómög, _swyc,   ,
  { {0x649c0051, 0x6d5e0022, 0x090e0044, 0x00000000}},  //   _réig, _rspa, _হিমু_,
  { {0x661a0676, 0x6d5e0061, 0x2d8504ce, 0x00000000}},  //   _yetk, _sspa, älen_,
  { {0x64490abb, 0xfc3f0129, 0xa01b0abc, 0x00000000}},  //   lfei, _ací_, sköp,
  { {0x649c0195, 0xed5a0088, 0x6724002b, 0x00000000}},  //   _féid, шов_, ġiji,
  { {0x6d5e001c, 0x644902a3, 0x20d90051, 0x00000000}},  //   _vspa, nfei, néil_,
  { {0x6d5e0036, 0xbb4308d6, 0x8b2601ab, 0x00000000}},  // [f40] _wspa, метк, юдае,
  { {0x649c002a, 0x1ae3013b, 0xddde00e5, 0x00000000}},  //   _téig, доум, _copţ,
  { {0x661a0abd, 0x6d5e0091, 0xa01b00f8, 0x00000000}},  //   _retk, _uspa, ljöa,
  { {0x50ca03d7, 0x661a00b9, 0x672200b0, 0x00000000}},  //   रविष, _setk, tsoj,
  { {0x661a00ee, 0x248600ab, 0x20d90051, 0x00000000}},  //   _petk, _room_, déil_,
  { {0x6d5c0061, 0x6b8b0039, 0x248601c3, 0x00000000}},  //   owra, ägge, _soom_,
  { {0x64490abe, 0x69dc0089, 0xd49a017a, 0x00000000}},  //   ffei, _uzre, ири_,
  { {0xb1980011, 0x672d08ad, 0xe9d70088, 0x00000000}},  //   _ngưỡ, šaja, _єкт_,
  { {0x661a016c, 0x61ef005f, 0x649c0051, 0x00000000}},  //   _tetk, əklə, _réid,
  { {0x7f46001c, 0x68fc014a, 0x38660007, 0x00000000}},  //   dtkq, _kurd, ldor_,
  { {0xe45a01fb, 0x321e05fd, 0x24860abf, 0x00000000}},  //   _вже_, raty_, _toom_,
  { {0x38660010, 0x68fc08ce, 0x76580ac0, 0x00000000}},  //   ndor_, _murd, levy,
  { {0x6101001e, 0x38660285, 0xdfdb02dc, 0x00000000}},  //   _vēla, idor_, рън_,
  { {0x81c90055, 0x76580020, 0xbbb40061, 0x00000000}},  //   লেই_, nevy, ंपैक,
  { {0x68fc0563, 0x6d5c005b, 0x20d90048, 0x00000000}},  //   _nurd, gwra, léim_,
  { {0x90c401fc, 0x90e703ec, 0x00000000, 0x00000000}},  //   _обје, _بستن,   ,
  { {0x1eab0025, 0x7bc10036, 0x3866024d, 0x00000000}},  // [f50] _نادي_, _ślub, ddor_,
  { {0x1b040044, 0x768f00ea, 0x00000000, 0x00000000}},  //   _লিখে_, _høyv,   ,
  { {0xad27007a, 0xe9f80088, 0x64490016, 0x00000000}},  //   _برخو, інці_, yfei,
  { {0xe8f802f0, 0x321c0ac1, 0x64950051, 0x00000000}},  //   ілі_, _levy_, _cáil,
  { {0xcb4401f9, 0x0c24007e, 0x64950051, 0x00000000}},  //   _охри, _імён, _dáil,
  { {0x38660446, 0x8afa009b, 0x24670082, 0x00000000}},  //   ador_, _להשי, _ốm_,
  { {0xceb4007b, 0x8557089d, 0x6495002a, 0x00000000}},  //   ויס_, تیار_, _fáil,
  { {0x7afd0ac2, 0x7af5022b, 0x81c20044, 0x00000000}},  //   _kust, _hizt, ্ধা_,
  { {0xe3b10054, 0x64490181, 0x68fc008e, 0x00000000}},  //   عرب_, rfei, _zurd,
  { {0xe299012b, 0x6449003a, 0x68fc005d, 0x00000000}},  //   сао_, sfei, _yurd,
  { {0x76b20036, 0xe8100061, 0x7af50288, 0x00000000}},  //   słyc, ारचा_, _mizt,
  { {0x69d50023, 0x7af50288, 0x00000000, 0x00000000}},  //   _myze, _lizt,   ,
  { {0x7afd010a, 0x3f8f01d5, 0xbf9b00c4, 0x00000000}},  //   _nust, _żgur_, scên,
  { {0x91fc0089, 0x00000000, 0x00000000, 0x00000000}},  //   ndāl,   ,   ,
  { {0x7c9602f0, 0x64950051, 0xfce6004c, 0x00000000}},  //   прац, _láim, зово,
  { {0x7afd001c, 0x249f0181, 0x6d5c005b, 0x00000000}},  //   _bust, nhum_, rwra,
  { {0x7af50ac3, 0x7afd0ac4, 0x68fc00c4, 0x00000000}},  // [f60] _bizt, _cust, _surd,
  { {0x7afd0406, 0x290a0022, 0x64950048, 0x00000000}},  //   _dust, _ptba_, _sáil,
  { {0x7afd002d, 0x68fc006b, 0x0d94025a, 0x00000000}},  //   _eust, _qurd, _غیرح,
  { {0x7afd0129, 0x68fc02cc, 0x69d50ac5, 0x00000000}},  //   _fust, _vurd, _dyze,
  { {0x7afd0ac6, 0x68fc001f, 0x38660ac7, 0x00000000}},  //   _gust, _wurd, rdor_,
  { {0x68fc0ac8, 0xba55005e, 0x2d8700d4, 0x00000000}},  //   _turd, _отсъ, _ànec_,
  { {0x7afd010f, 0x64950051, 0x321c07c4, 0x00000000}},  //   _zust, _táil, _revy_,
  { {0x2ca00ac9, 0xf746007c, 0x7de70010, 0x00000000}},  //   nhid_, _небо, lésé,
  { {0x7afd049a, 0x00000000, 0x00000000, 0x00000000}},  //   _xust,   ,   ,
  { {0xcb13009b, 0x6d47000c, 0x7de70010, 0x00000000}},  //   עלת_, ytja, nésé,
  { {0x20d2004a, 0xc5160014, 0x00000000, 0x00000000}},  //   jáis_, _ربات,   ,
  { {0x249f01a2, 0x64a307d0, 0x7bc3001a, 0x00000000}},  //   chum_, _паха, şnui,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afd00c7, 0x6d470aca, 0xfd13006d, 0x00000000}},  //   _rust, ttja, فجر_,
  { {0x71f70076, 0x7afd0acb, 0x7de70010, 0x00000000}},  //   _عروس_, _sust, désé,
  { {0x7afd0119, 0x6d47002b, 0x768f00ea, 0x00000000}},  //   _pust, rtja, _høyt,
  { {0x6d470acc, 0xc6220044, 0x7af5002d, 0x00000000}},  // [f70] stja, _নানা_, _pizt,
  { {0x6f0d0acd, 0xbd02004a, 0x00000000, 0x00000000}},  //   _itac, ñéca,   ,
  { {0xb5fc01d5, 0x628a0ace, 0x96220044, 0x00000000}},  //   _paġn, _mofo, নলাম_,
  { {0xddde01a8, 0x2ca0001a, 0x20d20051, 0x00000000}},  //   _uopš, chid_, láir_,
  { {0x26ce00fa, 0x00000000, 0x00000000, 0x00000000}},  //   fofo_,   ,   ,
  { {0x628a0acf, 0xfbd200a0, 0x20d2002a, 0x00000000}},  //   _nofo, _סתם_, náir_,
  { {0x249f005b, 0x00000000, 0x00000000, 0x00000000}},  //   thum_,   ,   ,
  { {0x64950051, 0x6f0d0ad0, 0x9f650142, 0x00000000}},  //   _táim, _otac, _štýl_,
  { {0x6f0d0009, 0x249f00ef, 0x628a02e7, 0x00000000}},  //   _ntac, rhum_, _bofo,
  { {0xd048006b, 0x64420a40, 0x628a0666, 0x00000000}},  //   əməy, _ecoi, _cofo,
  { {0x628a0022, 0x61010089, 0x648e0009, 0x00000000}},  //   _dofo, _vēlo, _cùis,
  { {0x6442002a, 0x7de70047, 0xf4850167, 0x00000000}},  //   _gcoi, zésé, _تائی,
  { {0x628a00c4, 0x10a307e1, 0xe3ae007e, 0x00000000}},  //   _fofo, тиян, _рб_,
  { {0x12fa00b6, 0x83fd0010, 0x443f0ad1, 0x00000000}},  //   _והסב, zdől, lgu_,
  { {0x2ca00ad2, 0x443f0ad3, 0x768f00ea, 0x00000000}},  //   thid_, ogu_, _høys,
  { {0x443f0ad4, 0x20d205f4, 0x645b0115, 0x00000000}},  //   ngu_, ráis_, neui,
  { {0x7de70047, 0xaec6003b, 0x9f4400b0, 0x00000000}},  // [f80] tésé, _обил, ämä_,
  { {0x2ca00518, 0x629d0023, 0x6b8b00f8, 0x00000000}},  //   shid_, ësoh, ägga,
  { {0x610800b9, 0x443f01a3, 0x768f0056, 0x00000000}},  //   _těle, kgu_, _løys,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7c2400f4, 0x00000000, 0x00000000, 0x00000000}},  //   mair,   ,   ,
  { {0x7c240ad5, 0x6442002a, 0x443f0004, 0x00000000}},  //   lair, _scoi, egu_,
  { {0xa01b000c, 0xd82601fc, 0x645b0ad6, 0x00000000}},  //   fjöl, _одви, feui,
  { {0x7c24028c, 0x628a010f, 0x443f0ad7, 0x00000000}},  //   nair, _sofo, ggu_,
  { {0x64420011, 0x628a0232, 0x00000000, 0x00000000}},  //   _vcoi, _pofo,   ,
  { {0x7c24002a, 0x78a200ea, 0x443f007f, 0x00000000}},  //   hair, lhov, agu_,
  { {0x3a3701f8, 0x60cf001a, 0x6f0d0652, 0x00000000}},  //   ורים_, tocm, _stac,
  { {0x78a200bb, 0x645b009d, 0xa19301e1, 0x00000000}},  //   nhov, ceui, таюч,
  { {0x44240ad8, 0x7c2400f4, 0x78a2012d, 0x00000000}},  //   mam_, dair, ihov,
  { {0x4424020c, 0x60cf0061, 0x768f0292, 0x00000000}},  //   lam_, socm, _høyr,
  { {0x20c70ad9, 0x7c240549, 0x78a200bb, 0x00000000}},  //   _осиг, fair, khov,
  { {0x44240ada, 0x6f0d001c, 0x7c24002a, 0x00000000}},  //   nam_, _ttac, gair,
  { {0x44240adb, 0x6f0d00e7, 0xfbd00025, 0x00000000}},  // [f90] iam_, _utac, لتك_,
  { {0x4424005f, 0x81c90055, 0x5a34013b, 0x00000000}},  //   ham_, লেও_, кнут,
  { {0x443f0adc, 0x67290091, 0x7c240add, 0x00000000}},  //   ygu_, _svej, bair,
  { {0x44240ade, 0xe8c90061, 0x7c240adf, 0x00000000}},  //   jam_, िकेच, cair,
  { {0xfe7000a1, 0xe7080439, 0x00000000, 0x00000000}},  //   _صدی_, وتون_,   ,
  { {0x81c90044, 0xa01b0010, 0x45190ae0, 0x00000000}},  //   লেট_, gköz, пция_,
  { {0xddde0036, 0x645b00f4, 0x44240142, 0x00000000}},  //   _zapł, teui, fam_,
  { {0x44240149, 0x78a2004f, 0xfdf800b6, 0x00000000}},  //   gam_, chov, וצות_,
  { {0x254e006b, 0x61010089, 0x645b009d, 0x00000000}},  //   _həll_, _vēlm, reui,
  { {0x443f018e, 0x236d0030, 0xf3f90035, 0x00000000}},  //   sgu_, rvej_, deţe_,
  { {0x236d0030, 0xa06a06f3, 0x00000000, 0x00000000}},  //   svej_, пана_,   ,
  { {0x4424020c, 0x20050036, 0x236d0190, 0x00000000}},  //   cam_, ślin_, pvej_,
  { {0x442f0ae1, 0x7c240089, 0x9f4c005d, 0x00000000}},  //   _idg_, vair, _ölüm_,
  { {0x78a20161, 0xa3b80025, 0xdbd9000c, 0x00000000}},  //   zhov, _تامر_, _ræði,
  { {0x7c240ae2, 0x69c70065, 0xc6920097, 0x00000000}},  //   tair, _nxje, נאל_,
  { {0x649c0051, 0xa01b0047, 0x7c2f00f6, 0x00000000}},  //   _léin, zköz, _cdcr,
  { {0x7c24028c, 0x442f0ae3, 0x69cb014a, 0x00000000}},  // [fa0] rair, _mdg_, şgel,
  { {0x442401cd, 0x7c240ae4, 0x4a430893, 0x00000000}},  //   zam_, sair, лнув,
  { {0x44240ae5, 0x442f0059, 0x78a20142, 0x00000000}},  //   yam_, _odg_, thov,
  { {0x44240ae6, 0xafdb01e3, 0xaca800a1, 0x00000000}},  //   xam_, mfør, _کھڑے_,
  { {0x78a20146, 0xa01b0010, 0xafdb043e, 0x00000000}},  //   rhov, tköz, lfør,
  { {0x44240ae7, 0xfaff0023, 0x00000000, 0x00000000}},  //   wam_, _erës_,   ,
  { {0x442f0093, 0xb7bd001a, 0x78a20039, 0x00000000}},  //   _bdg_, _reţe, phov,
  { {0x60c40825, 0x442f00d4, 0x2a6a01f3, 0x00000000}},  //   _njim, _cdg_, _habb_,
  { {0x4424090b, 0x64400004, 0xe73700e3, 0x00000000}},  //   ram_, rgmi, _пет_,
  { {0x44240673, 0x442f0ae8, 0xafdb00ea, 0x00000000}},  //   sam_, _edg_, kfør,
  { {0xf3f90035, 0xa2a6007d, 0x00000000, 0x00000000}},  //   veţe_, टोग्,   ,
  { {0xafdb01e3, 0x39580093, 0x44240312, 0x00000000}},  //   dfør, _mprs_, qam_,
  { {0x610800b9, 0x60c40022, 0x2d8c09b0, 0x00000000}},  //   _děla, _djim, äden_,
  { {0xd36f0014, 0x00000000, 0x00000000, 0x00000000}},  //   _دهه_,   ,   ,
  { {0xafdb08e0, 0x6ee000f8, 0x62880861, 0x00000000}},  //   gfør, möbl, mjdo,
  { {0x11db00b6, 0x60c40ae9, 0x2a6a00fa, 0x00000000}},  //   _מחוב, _gjim, _aabb_,
  { {0x6fb90088, 0x6ad90044, 0x00000000, 0x00000000}},  // [fb0] _ігор_, _ভূগো,   ,
  { {0x60dd0239, 0x39580022, 0x200b00fa, 0x00000000}},  //   llsm, _bprs_, lcci_,
  { {0x649c0aea, 0xb8120044, 0x200b0026, 0x00000000}},  //   _réin, _হয়ত_, occi_,
  { {0x893401b7, 0xb4ca007d, 0x00000000, 0x00000000}},  //   اعلا, लको_,   ,
  { {0x3669003b, 0x649c0051, 0x00000000, 0x00000000}},  //   дало_, _péin,   ,
  { {0x38690aeb, 0xd1380aec, 0x442f0145, 0x00000000}},  //   žar_, krą_, _sdg_,
  { {0x39580011, 0x6abf013d, 0x64a50aed, 0x00000000}},  //   _gprs_, ्वीर, кака,
  { {0x29110032, 0xd1380a67, 0xfaff0023, 0x00000000}},  //   _itza_, drą_, _urës_,
  { {0x2a6a0052, 0x290300e7, 0x3a230085, 0x00000000}},  //   _yabb_, _huja_, _kejp_,
  { {0x29030aee, 0x60d600f8, 0x2366003b, 0x00000000}},  //   _kuja_, _skym, _dsoj_,
  { {0x10a60aef, 0x442f00d4, 0xbbde0164, 0x00000000}},  //   винн, _tdg_, _मर्क,
  { {0x92c30055, 0x442f0af0, 0x629a0af1, 0x00000000}},  //   ্ষে_, _udg_, akto,
  { {0x6f63008b, 0x68e90af2, 0x68fb00fa, 0x00000000}},  //   авяз, _mhed, _miud,
  { {0x7643020c, 0xed5a019d, 0x68fb0006, 0x00000000}},  //   ngny, мог_, _liud,
  { {0x63a901a2, 0x29030af3, 0x00000000, 0x00000000}},  //   lzen, _nuja_,   ,
  { {0xafdb043e, 0x6fb60025, 0x27ff00e0, 0x00000000}},  //   rfør, _لمعا, _ngun_,
  { {0x63a9010f, 0xab2702dc, 0x00000000, 0x00000000}},  // [fc0] nzen, кота_,   ,
  { {0x63a900bb, 0xafdb0292, 0x27ff0022, 0x00000000}},  //   izen, pfør, _agun_,
  { {0x29030181, 0x68fb0006, 0x3eb80af4, 0x00000000}},  //   _cuja_, _biud, mirt_,
  { {0x68fb0af5, 0x68e9027b, 0x649c0af6, 0x00000000}},  //   _ciud, _ched, _céil,
  { {0x649c0051, 0x2d980010, 0x6f040af7, 0x00000000}},  //   _déil, lyre_, _juic,
  { {0x63a90af8, 0x27ff0756, 0x248f00ea, 0x00000000}},  //   dzen, _egun_, _aogm_,
  { {0x649c002a, 0x6846003b, 0x2d980af9, 0x00000000}},  //   _féil, _инва, nyre_,
  { {0x68fb0198, 0x3eb80afa, 0x68e90afb, 0x00000000}},  //   _giud, hirt_, _ghed,
  { {0x69dc0afc, 0x7afc007f, 0x3eb80145, 0x00000000}},  //   _hyre, _kirt, kirt_,
  { {0x6d4e05d5, 0xd1380a67, 0x6108013e, 0x00000000}},  //   ktba, trą_, _děln,
  { {0x629a00bb, 0x6f040022, 0x2d980023, 0x00000000}},  //   rkto, _auic, jyre_,
  { {0x6f040051, 0x69dc0190, 0x4035008b, 0x00000000}},  //   _buic, _myre, ыемс,
  { {0x63a90046, 0x6d4e00bb, 0x6f0401f3, 0x00000000}},  //   czen, etba, _cuic,
  { {0x6f04000a, 0x2d980afd, 0xf773009b, 0x00000000}},  //   _duic, fyre_, בקש_,
  { {0x5c0700a5, 0x69dc032e, 0xb5fc002b, 0x00000000}},  //   вяза, _nyre, _baġi,
  { {0x7afc002a, 0x672d0afe, 0x3eb80051, 0x00000000}},  //   _airt, šaji, airt_,
  { {0x649c002a, 0x7afc0953, 0x68e90aff, 0x00000000}},  // [fd0] _réil, _birt, _rhed,
  { {0x29030129, 0x69dc004e, 0x64950051, 0x00000000}},  //   _puja_, _byre, _háit,
  { {0x69dc01d6, 0x7afc039f, 0x2d8c0030, 0x00000000}},  //   _cyre, _dirt, ødet_,
  { {0x69dc0b00, 0xf8d10055, 0x08d40088, 0x00000000}},  //   _dyre, িষ্ঠ, ація,
  { {0x649c0051, 0x68fb008e, 0x7afc0792, 0x00000000}},  //   _céim, _viud, _firt,
  { {0x6495002a, 0xf7700084, 0x0dba00a1, 0x00000000}},  //   _láit, غان_, _آئیں_,
  { {0x68e9002b, 0x20d90b01, 0xb8120044, 0x00000000}},  //   _thed, néis_, _হযরত_,
  { {0x20050046, 0x63a9010f, 0xe89405b8, 0x00000000}},  //   ślij_, tzen, _кась,
  { {0xe894007c, 0x69dc0023, 0x6108013e, 0x00000000}},  //   _тать, _zyre, _bělo,
  { {0x63a90b02, 0x45450774, 0x69080010, 0x00000000}},  //   rzen, _منطق, _ördö,
  { {0x63a90046, 0x6d4e0203, 0x6108013e, 0x00000000}},  //   szen, xtba, _dělo,
  { {0x20d9008e, 0x23750b03, 0x71a2007e, 0x00000000}},  //   déis_, _ماتح, саюз,
  { {0x6f040038, 0x386d0b04, 0x6e25013f, 0x00000000}},  //   _quic, _maer_, _behb,
  { {0x2d98008d, 0x6d4e02e1, 0x66e30061, 0x00000000}},  //   tyre_, ttba, गतिक_,
  { {0x09be0055, 0x6da30057, 0x332d0b05, 0x00000000}},  //   _অর্থ, бира, lsex_,
  { {0x09e20044, 0x7afc08c0, 0x6f040b06, 0x00000000}},  //   _বললা, _sirt, _tuic,
  { {0x7afc0b07, 0x0aea005e, 0x3eb80065, 0x00000000}},  // [fe0] _pirt, едай_, pirt_,
  { {0x649c002a, 0x0e66007e, 0x20d9008e, 0x00000000}},  //   _réim, _скон, béis_,
  { {0x20d9008e, 0xddde0089, 0x649c0048, 0x00000000}},  //   céis_, _sapņ, _séim,
  { {0x7afc0a80, 0x386d0966, 0x20d90051, 0x00000000}},  //   _wirt, _caer_, léir_,
  { {0x7afc0b08, 0x3ce00b09, 0x7c2601c5, 0x00000000}},  //   _tirt, mliv_, _iekr,
  { {0x20d90051, 0x7afc0051, 0xe9440063, 0x00000000}},  //   néir_, _uirt, _پرسی,
  { {0x2aa40047, 0x6495002a, 0x7c260b0a, 0x00000000}},  //   _több_, _náis, _kekr,
  { {0xa01b0b0b, 0x386d005b, 0x938a00e2, 0x00000000}},  //   ljöv, _gaer_, есоа_,
  { {0x6495002a, 0x5c370049, 0x00000000, 0x00000000}},  //   _ráit, ארפן_,   ,
  { {0x59b8007d, 0xa5da0025, 0x64950048, 0x00000000}},  //   _आधार, _كبار_, _báis,
  { {0x6e25011f, 0xdd120477, 0xba570049, 0x00000000}},  //   _rehb, _rüşv, נסטו_,
  { {0x7c26016e, 0x629d0065, 0x7d05014a, 0x00000000}},  //   _nekr, ësor, _ruhs,
  { {0xe29a008b, 0xe0df0026, 0x91fc0089, 0x00000000}},  //   _пад_, rlò_, edāt,
  { {0x20d90b0c, 0x44260011, 0x7bdd0024, 0x00000000}},  //   téis_, _heo_, _rysu,
  { {0x7c260292, 0x254e006b, 0x44260011, 0x00000000}},  //   _bekr, _bəli_, _keo_,
  { {0x64950051, 0x20d90b0d, 0x3ce00190, 0x00000000}},  //   _háir, réis_, gliv_,
  { {0x7c26002d, 0x44260082, 0x2d8c0030, 0x00000000}},  // [ff0] _dekr, _meo_, øder_,
  { {0x44260b0e, 0x20d90b0f, 0x386d005b, 0x00000000}},  //   _leo_, péis_, _saer_,
  { {0x64950051, 0x7c260066, 0xca48023c, 0x00000000}},  //   _máir, _fekr, المه_,
  { {0x7c260b10, 0xddde00b9, 0x64950048, 0x00000000}},  //   _gekr, _např, _láir,
  { {0xd366007a, 0xddd7005f, 0x2ca90051, 0x00000000}},  //   _به_, _yaxş, mhad_,
  { {0xca490014, 0xe77800a1, 0x44260058, 0x00000000}},  //   _جلسه_, الوں_, _aeo_,
  { {0x44260051, 0x00000000, 0x00000000, 0x00000000}},  //   _beo_,   ,   ,
  { {0x4426003b, 0x332d0146, 0xa4230044, 0x00000000}},  //   _ceo_, tsex_, ফল্য_,
  { {0xd05d005f, 0x44260051, 0x730506e3, 0x00000000}},  //   _üzər, _deo_, јпоз,
  { {0x64950051, 0xe299012b, 0x00000000, 0x00000000}},  //   _páis, тао_,   ,
  { {0x00860b11, 0x91e502be, 0x4426008e, 0x00000000}},  //   ално, роне, _feo_,
  { {0x2c150309, 0x3ce0032e, 0x672d04eb, 0x00000000}},  //   _फ्लू_, xliv_, šaju,
  { {0x81bd0055, 0x20d90051, 0x2ca90b12, 0x00000000}},  //   _আরও_, téir_, dhad_,
  { {0xe29601fe, 0x64950051, 0x7bc0012d, 0x00000000}},  //   _ваш_, _gáir, _žmuo,
  { {0x20d90051, 0x442600e0, 0x8cb60b13, 0x00000000}},  //   réir_, _yeo_, асач,
  { {0x248d0295, 0x2ca90b14, 0x64ba01d5, 0x00000000}},  //   njem_, ghad_, nċip,

  { {0x3b0703dc, 0x249f0b15, 0x20d90051, 0x00000000}},  // [1000] ието_, ikum_, péir_,
  { {0x3ce00b16, 0x249f0180, 0x248d0190, 0x00000000}},  //   sliv_, hkum_, hjem_,
  { {0x186a005e, 0x7c26011f, 0x249f000c, 0x00000000}},  //   кажи_, _tekr, kkum_,
  { {0x3156007b, 0x2ca90b17, 0x248d01d5, 0x00000000}},  //   ייען_, chad_, jjem_,
  { {0x248d0b18, 0x91fc0089, 0x44260082, 0x00000000}},  //   djem_, ndār, _reo_,
  { {0x44260195, 0xfaa60aa2, 0x64590b19, 0x00000000}},  //   _seo_, _таго, _abwi,
  { {0x44260b1a, 0x8af0006b, 0x00000000, 0x00000000}},  //   _peo_, ttəf,   ,
  { {0xd766026c, 0x2ca00b1b, 0x248d0023, 0x00000000}},  //   _پارٹ, nkid_, gjem_,
  { {0x6495002a, 0x44260211, 0xb5fc002b, 0x00000000}},  //   _páir, _veo_, _raġu,
  { {0x6d5e055f, 0x68e20016, 0xd2570088, 0x00000000}},  //   _oppa, llod, ацю_,
  { {0x672d0209, 0x64a60b1c, 0x69130066, 0x00000000}},  //   šajt, _кажа, _għed,
  { {0x249f06be, 0xd83f01ca, 0xd13000a1, 0x00000000}},  //   ckum_, _účtu_, _ہمت_,
  { {0x6495002a, 0x6d5e06e2, 0x657a0009, 0x00000000}},  //   _táir, _appa, _hrth,
  { {0x68e20061, 0xd065006b, 0x539b009b, 0x00000000}},  //   hlod, _əsər, _בידו,
  { {0x3cf30204, 0x6143025f, 0x61130035, 0x00000000}},  //   ंगले_, _деја, _căld,
  { {0x76b20036, 0xbd440025, 0x00000000, 0x00000000}},  //   pływ, تنفي,   ,
  { {0x90a7025a, 0x2ca90b1d, 0x5a35005e, 0x00000000}},  // [1010] _محکم, rhad_, йнат,
  { {0xda78007c, 0x2ca90b1e, 0x657a0122, 0x00000000}},  //   иях_, shad_, _orth,
  { {0xceb200bd, 0x83fd0010, 0x249f0b1f, 0x00000000}},  //   _זיי_, ndőr, ykum_,
  { {0x2ca00009, 0x68e2005b, 0x00000000, 0x00000000}},  //   ckid_, glod,   ,
  { {0x7c2d010e, 0x291a08a6, 0x96b9003b, 0x00000000}},  //   maar, appa_, луку_,
  { {0x7c2d0b20, 0x5b140088, 0x7b3d00e5, 0x00000000}},  //   laar, _ємст, _căuş,
  { {0x248d0059, 0xd5750b21, 0x6d9e002b, 0x00000000}},  //   tjem_, суль, _għaġ,
  { {0x58d401be, 0x7c2d0343, 0x64950048, 0x00000000}},  //   _дост, naar, _cáip,
  { {0xf77300a2, 0x248d0059, 0x657a018e, 0x00000000}},  //   _باز_, rjem_, _erth,
  { {0x249f0b22, 0x248d089f, 0x777b0288, 0x00000000}},  //   skum_, sjem_, _irux,
  { {0x7c2d017d, 0x6f160b23, 0xfa980049, 0x00000000}},  //   kaar, _styc, ידזש_,
  { {0x64590061, 0x7c2d0a2a, 0x00000000, 0x00000000}},  //   _ubwi, jaar,   ,
  { {0x442d0acd, 0xf4560879, 0x116700a1, 0x00000000}},  //   mae_, _طلوع_, _چلتی_,
  { {0x442d0b24, 0x644903d0, 0xd839000a, 0x00000000}},  //   lae_, lgei, _blōk_,
  { {0x6da3005e, 0x62830b25, 0xf1cf0164, 0x00000000}},  //   пира, _inno, _सुचन,
  { {0x7c2d0030, 0x64490b26, 0xdd8f03ab, 0x00000000}},  //   gaar, ngei, روق_,
  { {0x09b50055, 0xbebb0065, 0x7e9a0084, 0x00000000}},  // [1020] _জুলা, rsër, _منظر_,
  { {0xe3a7026c, 0x442d0abb, 0x2ca00b27, 0x00000000}},  //   _ہر_, hae_, skid_,
  { {0x9e7b007b, 0x7c2d01b5, 0x7bcf01cb, 0x00000000}},  //   _ענטפ, baar, _excu,
  { {0x6c8601b7, 0x777b00f4, 0xe3a7004b, 0x00000000}},  //   _الحم, _brux, _فر_,
  { {0x442d0b28, 0x628300c7, 0x68e20146, 0x00000000}},  //   dae_, _onno, rlod,
  { {0xcd29089d, 0x68e20b29, 0xa01b00f8, 0x00000000}},  //   _حسین_, slod, njör,
  { {0x2b400115, 0x64950051, 0xb99601b7, 0x00000000}},  //   lric_, _páip, _الزب,
  { {0x62830b2a, 0x6e2e0b2b, 0x5fc80164, 0x00000000}},  //   _anno, habb, रपाल,
  { {0xdc9b007b, 0x213e018e, 0x657a018e, 0x00000000}},  //   טיקל, wrth_, _wrth,
  { {0x290a0b2c, 0x78a20428, 0x6e2e0b2d, 0x00000000}},  //   _kuba_, lkov, jabb,
  { {0x290a0004, 0x442d006a, 0x867b00b6, 0x00000000}},  //   _juba_, bae_, _תרבו,
  { {0x290a0022, 0xa49200a2, 0x2fc60b2e, 0x00000000}},  //   _muba_, _ریخت, _žoga_,
  { {0x7c2d0168, 0x6234025f, 0xa01b000c, 0x00000000}},  //   vaar, _делу, fjör,
  { {0x29180b2f, 0x7c2d015c, 0xa01b000c, 0x00000000}},  //   _otra_, waar, gjör,
  { {0x8af0005f, 0x6ca701fb, 0x7c2d006c, 0x00000000}},  //   ktəb, браж, taar,
  { {0x78a20b30, 0xfc3f000c, 0x2b400048, 0x00000000}},  //   jkov, _elín_, fric_,
  { {0x7c2d00b5, 0x60cd0061, 0x6e2e002b, 0x00000000}},  // [1030] raar, _ijam, babb,
  { {0x7c2d0b31, 0xff500025, 0x6f1d00d9, 0x00000000}},  //   saar, _أخي_, mpsc,
  { {0x290a0127, 0x7c2d0168, 0x29180b32, 0x00000000}},  //   _cuba_, paar, _ctra_,
  { {0xec6b01e0, 0xfc3f01dc, 0x2b400133, 0x00000000}},  //   _срок_, _zlín_, bric_,
  { {0x6d55022b, 0x6d470142, 0x2b4000d4, 0x00000000}},  //   ltza, luja, cric_,
  { {0x29070b33, 0x6d550b34, 0xb7c60089, 0x00000000}},  //   ínas_, otza, diģē,
  { {0x6d550756, 0x64490253, 0x6d470059, 0x00000000}},  //   ntza, tgei, nuja,
  { {0x6d55022b, 0x78a20161, 0x60cd0020, 0x00000000}},  //   itza, ckov, _njam,
  { {0x442d0b35, 0x9868026c, 0xc64b0426, 0x00000000}},  //   rae_, _دینے_, _مجال_,
  { {0x442d0b36, 0x27ed002d, 0x6d470b37, 0x00000000}},  //   sae_, _izen_, kuja,
  { {0x29180b38, 0x208a0b39, 0x71b5007c, 0x00000000}},  //   _xtra_, айни_, ющих,
  { {0x25d600bd, 0x6d470027, 0x6abe0b3a, 0x00000000}},  //   _ווען_, duja, zipf,
  { {0x78a90b3b, 0x60cd000c, 0x6e2e002b, 0x00000000}},  //   _mlev, _djam, tabb,
  { {0x78a90b3c, 0x62830b3d, 0x78a201ca, 0x00000000}},  //   _llev, _unno, zkov,
  { {0xde0301fb, 0x6e2e0a19, 0x78a90b3e, 0x00000000}},  //   дпри, rabb, _olev,
  { {0x2b400b3f, 0x6e2e0010, 0x8b26022a, 0x00000000}},  //   tric_, sabb, ждае,
  { {0x78a20161, 0x6d55022b, 0x7eab011f, 0x00000000}},  // [1040] vkov, atza, _süpe,
  { {0x2b400719, 0x6d47008e, 0x78a9014a, 0x00000000}},  //   rric_, buja, _alev,
  { {0x78a20428, 0x78a90018, 0x386601aa, 0x00000000}},  //   tkov, _blev, teor_,
  { {0x290a0009, 0x80370049, 0x78a900ab, 0x00000000}},  //   _vuba_, ַנצע_, _clev,
  { {0x8af0006b, 0x61e30190, 0x38660b40, 0x00000000}},  //   rtəb, _lynl, reor_,
  { {0x78a20b41, 0x649c0051, 0x290a006c, 0x00000000}},  //   skov, _léit, _tuba_,
  { {0x27ed0b42, 0x98a6005e, 0x78a90b43, 0x00000000}},  //   _ezen_, _диве, _flev,
  { {0xd91b00b3, 0x78a900d4, 0x00000000, 0x00000000}},  //   _כולל, _glev,   ,
  { {0xccf301f8, 0xf3660088, 0x00000000, 0x00000000}},  //   וכה_, ітин,   ,
  { {0x29040b44, 0x60cd0b45, 0x78a90b46, 0x00000000}},  //   _hima_, _sjam, _zlev,
  { {0x61e3018e, 0x290400e7, 0x27e40075, 0x00000000}},  //   _cynl, _kima_, _hymn_,
  { {0x290400ca, 0x00000000, 0x00000000, 0x00000000}},  //   _jima_,   ,   ,
  { {0x24860b47, 0x78fb00a3, 0x649c0048, 0x00000000}},  //   _inom_, יפטו, _déit,
  { {0x26dc01cd, 0x2904033b, 0x6d470b48, 0x00000000}},  //   novo_, _lima_, tuja,
  { {0x621b00a0, 0x61e3018e, 0xdcbb0b49, 0x00000000}},  //   _דווק, _gynl, аща_,
  { {0x6d55022b, 0x29040059, 0x26dc0059, 0x00000000}},  //   rtza, _nima_, hovo_,
  { {0x26dc0b4a, 0x24860091, 0x62980b4b, 0x00000000}},  // [1050] kovo_, _mnom_, _kovo,
  { {0x78a90224, 0x78bb0107, 0x6d470b4c, 0x00000000}},  //   _slev, _smuv, puja,
  { {0x26dc0006, 0x89d90025, 0x24860091, 0x00000000}},  //   dovo_, حوار_, _onom_,
  { {0xf7710379, 0x62980b4d, 0x29040b4e, 0x00000000}},  //   فات_, _lovo, _cima_,
  { {0x7c22008e, 0x2904010e, 0x0a6b003b, 0x00000000}},  //   ñore, _dima_, _крви_,
  { {0xd6db098c, 0x26dc0059, 0xaa6409da, 0x00000000}},  //   ште_, govo_, _отск,
  { {0x6f0d0051, 0x170500a1, 0xa9540088, 0x00000000}},  //   _luac, _کہتی_, _окрі,
  { {0x78bb0b4f, 0x27ed002d, 0x20090082, 0x00000000}},  //   _umuv, _tzen_, _ngai_,
  { {0x6f0d002a, 0x649c002a, 0xf77000f3, 0x00000000}},  //   _nuac, _réit, _لال_,
  { {0xd2a9007c, 0x62980b50, 0x649c0b51, 0x00000000}},  //   ское_, _covo, _béis,
  { {0x216909f1, 0x60dd000a, 0x67290066, 0x00000000}},  //   щини_, fosm, _hwej,
  { {0x92cb0044, 0x60dd0107, 0x6f0d0051, 0x00000000}},  //   লতে_, gosm, _buac,
  { {0x7ea200f4, 0x61fe0428, 0x6f0d003f, 0x00000000}},  //   _hôpi, _úpln, _cuac,
  { {0x62980295, 0x5239007b, 0xe3b00167, 0x00000000}},  //   _govo, _הײַנ, _جرم_,
  { {0xf3f9001a, 0xb7bd001a, 0x91e2007c, 0x00000000}},  //   deţi_, _deţi, _поше,
  { {0x649c002a, 0x60dd008e, 0x236d0036, 0x00000000}},  //   _héir, cosm, owej_,
  { {0x6b630b52, 0x6f0d008e, 0x29040b53, 0x00000000}},  // [1060] нкта, _guac, _rima_,
  { {0x6d41002a, 0x29040010, 0xf3f90035, 0x00000000}},  //   álac, _sima_, geţi_,
  { {0xfe9b01ce, 0x5e9b009b, 0x29040258, 0x00000000}},  //   _היימ, _הביק, _pima_,
  { {0x649c002a, 0x7b0900ca, 0x29040066, 0x00000000}},  //   _léir, _džub, _qima_,
  { {0x7c24003f, 0x26dc0340, 0x66e60088, 0x00000000}},  //   mbir, tovo_, пода,
  { {0x24860b54, 0xf3f9001a, 0x7c240288, 0x00000000}},  //   _snom_, ceţi_, lbir,
  { {0x26dc09fc, 0x29040091, 0x00000000, 0x00000000}},  //   rovo_, _tima_,   ,
  { {0x7c240051, 0x7d06002b, 0x27e903b2, 0x00000000}},  //   nbir, _jiks, żana_,
  { {0x7d06021e, 0xf74301fc, 0x7c240a15, 0x00000000}},  //   _miks, _пето, ibir,
  { {0x7d0600d8, 0x0bb7009b, 0x61130035, 0x00000000}},  //   _liks, פלים_, _săla,
  { {0xb7bd001a, 0x7c240b55, 0x649c0048, 0x00000000}},  //   _reţi, kbir, _déir,
  { {0x7d060b56, 0x75d30025, 0x24860b57, 0x00000000}},  //   _niks, _ثيما, _unom_,
  { {0x7c240b58, 0x62980059, 0x6f0d0082, 0x00000000}},  //   dbir, _tovo, _quac,
  { {0xd24f0b59, 0xdb23026c, 0xef1f006b, 0x00000000}},  //   _منه_, ہوری, rpü_,
  { {0x7d060089, 0x00000000, 0x00000000, 0x00000000}},  //   _biks,   ,   ,
  { {0x7c240b5a, 0x6f0d096a, 0x44240022, 0x00000000}},  //   gbir, _tuac, nbm_,
  { {0x2d8c0b5b, 0x7d060b5c, 0xf3f9001a, 0x00000000}},  // [1070] äder_, _diks, teţi_,
  { {0xed4e00a1, 0x0dcb0b5d, 0x7c240288, 0x00000000}},  //   دھی_, _гуми_, abir,
  { {0x7c240b5e, 0xa90701f7, 0xa3de0061, 0x00000000}},  //   bbir, سبان, _दुस_,
  { {0xe9f80088, 0x6ef20190, 0x00000000, 0x00000000}},  //   їнці_, ræbe,   ,
  { {0x3b640265, 0x69130066, 0x00000000, 0x00000000}},  //   _първ, _għen,   ,
  { {0x64470006, 0x45190401, 0x3ce90023, 0x00000000}},  //   ėjim, оция_, llav_,
  { {0x7e7700f8, 0x6724001e, 0x00000000, 0x00000000}},  //   _maxp, ģija,   ,
  { {0xc952009b, 0x8af0006b, 0x2d810087, 0x00000000}},  //   _שמן_, ntən, _mrhe_,
  { {0x2d57011f, 0x649c0051, 0x00000000, 0x00000000}},  //   hçe_, _péir,   ,
  { {0x2d57014a, 0x7c2f0068, 0x957c00b4, 0x00000000}},  //   kçe_, _lecr, _cząs,
  { {0x9046007a, 0x3ce901aa, 0xf4870b5f, 0x00000000}},  //   ونده, klav_, _нудн,
  { {0xcea9007b, 0x7c2f0129, 0x7c24006b, 0x00000000}},  //   _די_, _necr, xbir,
  { {0x7d06093b, 0x00000000, 0x00000000, 0x00000000}},  //   _riks,   ,   ,
  { {0x7d060b60, 0xa1c50088, 0x442f01d6, 0x00000000}},  //   _siks, _облд, _heg_,
  { {0xfce602e9, 0x7c240095, 0x8af0006b, 0x00000000}},  //   дово, tbir, ftən,
  { {0x442f01e3, 0x3ce90059, 0x7c2f0544, 0x00000000}},  //   _jeg_, glav_, _cecr,
  { {0x442f0b61, 0x7c240b62, 0x7c2f0b63, 0x00000000}},  // [1080] _meg_, rbir, _decr,
  { {0x4a4300ed, 0x7d060b64, 0x442f0b65, 0x00000000}},  //   кнув, _wiks, _leg_,
  { {0x7d060b66, 0xa96a01f7, 0xd9100014, 0x00000000}},  //   _tiks, تمام_, ایر_,
  { {0x442f0b67, 0x3ce90802, 0x7c2f00bb, 0x00000000}},  //   _neg_, clav_, _gecr,
  { {0x69d501a2, 0xafdb0190, 0x00000000, 0x00000000}},  //   _exze, lgør,   ,
  { {0x442f0004, 0xd7f90088, 0x00000000, 0x00000000}},  //   _aeg_, чує_,   ,
  { {0x442f0145, 0xafdb0637, 0x443d0846, 0x00000000}},  //   _beg_, ngør, _bdw_,
  { {0x442f005b, 0x9855007e, 0xb05b0052, 0x00000000}},  //   _ceg_, _птуш, nnät,
  { {0x442f0b68, 0x443d0b69, 0xfc3f000c, 0x00000000}},  //   _deg_, _ddw_, _slík_,
  { {0x6722007f, 0x00000000, 0x00000000, 0x00000000}},  //   mpoj,   ,   ,
  { {0x6722001e, 0x443d008e, 0x442f0b6a, 0x00000000}},  //   lpoj, _fdw_, _feg_,
  { {0x3cfa013d, 0x442f0b6b, 0x14170025, 0x00000000}},  //   ्दों_, _geg_, _قيمة_,
  { {0xceeb0b6c, 0x7c2f032c, 0x26ce0197, 0x00000000}},  //   قرآن_, _recr, onfo_,
  { {0x442f00b5, 0x2d57014a, 0x00000000, 0x00000000}},  //   _zeg_, tçe_,   ,
  { {0x26ce006c, 0x9d18017f, 0xafdb0030, 0x00000000}},  //   info_, дост_, ggør,
  { {0x9f550088, 0x2cb20016, 0x6aae0023, 0x00000000}},  //   _звич, ghyd_, _albf,
  { {0x7c220b6d, 0x7c2f0089, 0x7e770133, 0x00000000}},  // [1090] ñora, _vecr, _taxp,
  { {0x3ce904c8, 0x2a7801a3, 0x7d1e00d9, 0x00000000}},  //   slav_, _carb_, _ftps,
  { {0x7c2f011f, 0x2a78002b, 0x6913002b, 0x00000000}},  //   _tecr, _darb_, _għel,
  { {0x2cb2018e, 0x20190010, 0x20d900f6, 0x00000000}},  //   chyd_, ncsi_, géix_,
  { {0x442f0b6e, 0x628a0061, 0xe76b031d, 0x00000000}},  //   _reg_, _onfo, تحان_,
  { {0x442f0292, 0x443d01f3, 0x9967073b, 0x00000000}},  //   _seg_, _sdw_, _отбл,
  { {0x442f0145, 0x26c904eb, 0xb05b0b6f, 0x00000000}},  //   _peg_, đao_, nnäs,
  { {0x628a0b70, 0x2ca900f8, 0x00000000, 0x00000000}},  //   _anfo, nkad_,   ,
  { {0x442f0b71, 0xe3b10025, 0x6e350288, 0x00000000}},  //   _veg_, طرة_, kazb,
  { {0x442f0b72, 0x29110117, 0x00000000, 0x00000000}},  //   _weg_, _kuza_,   ,
  { {0x442f0b73, 0x2ca9006c, 0x2f1400f8, 0x00000000}},  //   _teg_, kkad_, _säg_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc0000055, 0x2ca90717, 0xe3ae0121, 0x00000000}},  //   ূর্ণ_, dkad_, _сб_,
  { {0x539a0097, 0x2f140039, 0xafdb0030, 0x00000000}},  //   _מינו, _väg_, tgør,
  { {0x98a700b9, 0xacf600ec, 0xd24e0025, 0x00000000}},  //   éně_, ечај, _انى_,
  { {0x2ca900e0, 0x00000000, 0x00000000, 0x00000000}},  //   gkad_,   ,   ,
  { {0xcb670140, 0x60d7009b, 0xbb430a85, 0x00000000}},  // [10a0] нате_, _רופא_, летк,
  { {0x2911031a, 0x60c60b74, 0x69130066, 0x00000000}},  //   _buza_, likm, _iħej,
  { {0xc87902b9, 0xc86600e3, 0x29110035, 0x00000000}},  //   _baş_, етли, _cuza_,
  { {0x6d4e0009, 0x2ca90039, 0x60c604cb, 0x00000000}},  //   muba, ckad_, nikm,
  { {0x6d5c0211, 0xb05b0b75, 0x7c3600e0, 0x00000000}},  //   ltra, onär, mayr,
  { {0x26ce0b76, 0x7c36006b, 0x69130066, 0x00000000}},  //   unfo_, layr, _mħej,
  { {0x6d4e0111, 0x672204eb, 0x2366016e, 0x00000000}},  //   nuba, spoj, _spoj_,
  { {0x6d5c0b77, 0x09e30b5f, 0xb05b01a2, 0x00000000}},  //   itra, _сосн, hnär,
  { {0x68e2006c, 0x6d4e011c, 0x60c60022, 0x00000000}},  //   mood, huba, dikm,
  { {0x6d4e000b, 0x6d5c0059, 0x8af0005f, 0x00000000}},  //   kuba, ktra, xtəl,
  { {0xe3af00d3, 0xc879047f, 0x6d5c0626, 0x00000000}},  //   لری_, _yaş_, jtra,
  { {0xe61f001d, 0x68e20168, 0x60c6000a, 0x00000000}},  //   _đôi_, nood, gikm,
  { {0xdefb007c, 0x6d5c010e, 0x00000000, 0x00000000}},  //   зыв_, etra,   ,
  { {0x6d5c010f, 0x628a00ab, 0xb8160044, 0x00000000}},  //   ftra, _unfo, ারিত_,
  { {0x6d5c011c, 0xc27b009b, 0x68e2003c, 0x00000000}},  //   gtra, _מרגי, kood,
  { {0x8af0006b, 0x6143012b, 0xdef801d5, 0x00000000}},  //   stəl, _сећа, ċċa_,
  { {0x29110091, 0x6d5c0b78, 0x2ca90039, 0x00000000}},  // [10b0] _suza_, atra, rkad_,
  { {0x2ca900f8, 0x6d4e0145, 0x8af0006b, 0x00000000}},  //   skad_, buba, qtəl,
  { {0xc984025f, 0x7c360b79, 0x6d4e00ab, 0x00000000}},  //   луци, bayr, cuba,
  { {0x61ea00c4, 0xcd96009b, 0x7afe01d6, 0x00000000}},  //   _myfl, _סדרת_, ampt,
  { {0x4c9a019b, 0x00000000, 0x00000000, 0x00000000}},  //   _חברו,   ,   ,
  { {0x07a20b7a, 0x29110066, 0xc668003b, 0x00000000}},  //   рашн, _tuza_, ешће_,
  { {0x68e20168, 0xc879014a, 0xd5750b7b, 0x00000000}},  //   bood, _taş_, туль,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d4e0b7c, 0x6d5c0b7d, 0x77550a85, 0x00000000}},  //   zuba, ztra, _шкаф,
  { {0x6d5c0056, 0x6d4e0b7e, 0x00000000, 0x00000000}},  //   ytra, yuba,   ,
  { {0x61ea018e, 0x26c70b7f, 0x6d5c00f8, 0x00000000}},  //   _cyfl, mino_, xtra,
  { {0xf485026c, 0x6d5c07f9, 0x3cf901d6, 0x00000000}},  //   _جائی, vtra, _nhsv_,
  { {0x6d5c002b, 0x3f8401dc, 0xb05b0039, 0x00000000}},  //   wtra, ímu_, tnär,
  { {0x6d5c002b, 0x6d4e0b80, 0x60c6023a, 0x00000000}},  //   ttra, tuba, sikm,
  { {0x61ea018e, 0xed5700ed, 0xddc30b81, 0x00000000}},  //   _gyfl, кор_, абри,
  { {0x6d4e020c, 0x26c70207, 0x6d5c03a1, 0x00000000}},  //   ruba, hino_, rtra,
  { {0x26c70006, 0x387d0016, 0x6d4e011c, 0x00000000}},  // [10c0] kino_, ddwr_, suba,
  { {0x68e20061, 0x26c70059, 0x0f370049, 0x00000000}},  //   wood, jino_, _שריט_,
  { {0x26c70119, 0xfbd100a1, 0x68e2006c, 0x00000000}},  //   dino_, لتے_, tood,
  { {0xd3080082, 0xdca60478, 0x2b490b82, 0x00000000}},  //   _hệt_, _рами, brac_,
  { {0xdb0a0048, 0x68e20b83, 0x00000000, 0x00000000}},  //   únói, rood,   ,
  { {0x26c705fc, 0xb05b010f, 0x68e20b84, 0x00000000}},  //   gino_, hnäp, sood,
  { {0xceb300b6, 0xd3080011, 0xd5af0380, 0x00000000}},  //   שיו_, _mệt_, يفه_,
  { {0x98a300d7, 0x60c400e0, 0x982800a1, 0x00000000}},  //   _кисе, _nmim, _سترہ_,
  { {0x26c70059, 0x98a30140, 0xf9f40044, 0x00000000}},  //   bino_, _тите, _জলিল_,
  { {0x26c70207, 0x00000000, 0x00000000, 0x00000000}},  //   cino_,   ,   ,
  { {0x4035007e, 0x3a37009b, 0xaa370049, 0x00000000}},  //   ленс, כרים_, כטיק_,
  { {0x7f5d001c, 0x60c40065, 0xd250025a, 0x00000000}},  //   ttsq, _cmim, جنگ_,
  { {0x2d8c05cc, 0x64420032, 0x2d9e0b85, 0x00000000}},  //   åden_, _idoi, äten_,
  { {0x41dd0309, 0x60c4013e, 0x00000000, 0x00000000}},  //   _नुकस, _emim,   ,
  { {0xd3080011, 0x2d850051, 0x7b0901c5, 0x00000000}},  //   _dệt_, íle_, _džul,
  { {0x2b49023a, 0x60d60023, 0x1fa70b86, 0x00000000}},  //   trac_, _gjym, _арог,
  { {0x0bf50b87, 0x09bd0309, 0x9be70088, 0x00000000}},  // [10d0] упаю, ्प्य, тівк,
  { {0x6d480b88, 0xdd03005d, 0x629a0023, 0x00000000}},  //   ádac, ırıc, njto,
  { {0x26c70059, 0x81e40055, 0x6cd50879, 0x00000000}},  //   vino_, পের_, _مقدا,
  { {0x78a0013e, 0x64420048, 0x00000000, 0x00000000}},  //   _comv, _ndoi,   ,
  { {0x26c70207, 0x3ea10b89, 0x7b090006, 0x00000000}},  //   tino_, _koht_, _užuo,
  { {0x644201a3, 0x00000000, 0x00000000, 0x00000000}},  //   _adoi,   ,   ,
  { {0x26c70198, 0x00000000, 0x00000000, 0x00000000}},  //   rino_,   ,   ,
  { {0x26c70181, 0xf773025a, 0x00000000, 0x00000000}},  //   sino_, _پار_,   ,
  { {0x26c7006a, 0xdce5001e, 0x130902d3, 0x00000000}},  //   pino_, _arhī, нний_,
  { {0xd7f80088, 0x6b670089, 0x3ea100ca, 0x00000000}},  //   _рус_, mīgā, _noht_,
  { {0x24550879, 0x27fa0036, 0x68fb0022, 0x00000000}},  //   _مناس, ępne_, _khud,
  { {0xd3080082, 0x00000000, 0x00000000, 0x00000000}},  //   _sệt_,   ,   ,
  { {0x7ae50368, 0x68fb00e7, 0x27ed000a, 0x00000000}},  //   koht, _mhud, _jyen_,
  { {0x7ae500b0, 0x63a90058, 0x63bb00e7, 0x00000000}},  //   joht, myen, mzun,
  { {0x27ed0263, 0x925606e3, 0x8af0006b, 0x00000000}},  //   _lyen_, _сајт_, stək,
  { {0x60c40058, 0x27ed004a, 0x00000000, 0x00000000}},  //   _umim, _oyen_,   ,
  { {0x8b26008b, 0x63a904cb, 0x63bb0b8a, 0x00000000}},  // [10e0] удзе, nyen, nzun,
  { {0xfeba007a, 0x290d0b8b, 0x7e56003b, 0x00000000}},  //   _ساخت_, _aiea_, _стиц,
  { {0x09f6022a, 0x27ed0173, 0xa84a0025, 0x00000000}},  //   учая, _ayen_, فلام_,
  { {0x27ed0b8c, 0x7e7e0b8d, 0x68fb0142, 0x00000000}},  //   _byen_, _happ, _chud,
  { {0x7e7e00b0, 0x7c95007e, 0x96ea085f, 0x00000000}},  //   _kapp, _трэц, нька_,
  { {0x7e7e01d5, 0xddc70165, 0x66e30147, 0x00000000}},  //   _japp, lejš, боча,
  { {0x7e7e0198, 0x7b090209, 0x6b840277, 0x00000000}},  //   _mapp, _ožuj, lvig,
  { {0x7e7e00b0, 0xddc70b8e, 0x3a3a0b8f, 0x00000000}},  //   _lapp, nejš, lapp_,
  { {0x63a90047, 0x6b8402e1, 0xa3de007d, 0x00000000}},  //   gyen, nvig, _दुख_,
  { {0x7e7e0b90, 0x3a3a00f8, 0xf1260b91, 0x00000000}},  //   _napp, napp_, льмо,
  { {0x6b84010e, 0x63a901c3, 0x00000000, 0x00000000}},  //   hvig, ayen,   ,
  { {0x657a00ea, 0x6f160b92, 0x63a90146, 0x00000000}},  //   _isth, _buyc, byen,
  { {0x7e7e023a, 0x4fc7005e, 0x3a3a0894, 0x00000000}},  //   _bapp, усна, kapp_,
  { {0x7e7e07c5, 0x00000000, 0x00000000, 0x00000000}},  //   _capp,   ,   ,
  { {0x7e7e0b93, 0xccfb012b, 0x7eb0006c, 0x00000000}},  //   _dapp, ећа_, _täpn,
  { {0x657a0009, 0x61f80295, 0x00000000, 0x00000000}},  //   _msth, _izvl,   ,
  { {0x5a35053c, 0x7ae50b94, 0x68fb005b, 0x00000000}},  // [10f0] инат, toht, _rhud,
  { {0x7e7e01f3, 0x68fb0b95, 0x6b670089, 0x00000000}},  //   _gapp, _shud, vīgā,
  { {0x7ae50b96, 0xb81500ed, 0x1ed80379, 0x00000000}},  //   roht, адеј, _حبيب_,
  { {0xf7710137, 0x3f890b97, 0x765a00d9, 0x00000000}},  //   قات_, _krau_, _acty,
  { {0x7c2d0b98, 0x3a3a0b99, 0x7e7e0b9a, 0x00000000}},  //   mbar, bapp_, _yapp,
  { {0x6b670089, 0xe4630180, 0x3a3a0026, 0x00000000}},  //   rīgā, şmüş, capp_,
  { {0x7d0f0047, 0x5e580049, 0x68fb0b9b, 0x00000000}},  //   _kics, טיגע_, _thud,
  { {0x93450797, 0x63bb0577, 0x58d50088, 0x00000000}},  //   ание, tzun, _тобт,
  { {0x657a00f4, 0x7c2d0032, 0x63bb0b9c, 0x00000000}},  //   _esth, ibar, uzun,
  { {0x52a90b9d, 0x387f002d, 0x63a9011c, 0x00000000}},  //   твом_, _haur_, ryen,
  { {0x7c2d00b5, 0x7e7e0b9e, 0x3f89002d, 0x00000000}},  //   kbar, _rapp, _arau_,
  { {0x7e7e01bc, 0x7c2d0036, 0x3f890a16, 0x00000000}},  //   _sapp, jbar, _brau_,
  { {0x442d000b, 0x7e7e0039, 0xddc70b9f, 0x00000000}},  //   mbe_, _papp, vejš,
  { {0x442d010f, 0x321e0009, 0x7b09016c, 0x00000000}},  //   lbe_, ccty_, _džuk,
  { {0x3f89001a, 0x3c420010, 0x7a40000c, 0x00000000}},  //   _erau_, _lévő_, hátí,
  { {0x0c260517, 0x442d0263, 0x3f89010f, 0x00000000}},  //   рман, nbe_, _frau_,
  { {0x3f8906c0, 0xddc701d9, 0x2c010061, 0x00000000}},  // [1100] _grau_, rejš, लेलं_,
  { {0x6b8400cd, 0x62810652, 0x7c2d0288, 0x00000000}},  //   rvig, ndlo, abar,
  { {0x6e3c004e, 0x7c2d0039, 0x81e70055, 0x00000000}},  //   marb, bbar, _মৃত_,
  { {0x6e3c0002, 0x387f0089, 0x442d016e, 0x00000000}},  //   larb, _caur_, jbe_,
  { {0x7d040ba0, 0x442d01d9, 0xdddc0010, 0x00000000}},  //   mmis, dbe_, merő,
  { {0x7d040368, 0x6b8b0030, 0x442d010f, 0x00000000}},  //   lmis, ægge, ebe_,
  { {0xd943003b, 0x3856005e, 0x387f00e5, 0x00000000}},  //   _мери, _възс, _faur_,
  { {0x387f0ba1, 0x48e303e8, 0x6e3c002d, 0x00000000}},  //   _gaur_, _досв, harb,
  { {0x7d040ba2, 0x6e3c002d, 0x2918002d, 0x00000000}},  //   imis, karb, _hura_,
  { {0x29180ba3, 0xc5fd0044, 0x7d040ba4, 0x00000000}},  //   _kura_, ুড়া_, hmis,
  { {0x6e3c0ba5, 0x442d0198, 0x29180ba6, 0x00000000}},  //   darb, bbe_, _jura_,
  { {0x29180ba7, 0xd57700b6, 0x386605ba, 0x00000000}},  //   _mura_, _כתבה_, nfor_,
  { {0x7d040004, 0x291801d5, 0x7c2d0ba8, 0x00000000}},  //   dmis, _lura_, vbar,
  { {0x6e3c0006, 0x2bf0013d, 0x7c2d00bb, 0x00000000}},  //   garb, _आरजू_, wbar,
  { {0x02fb0104, 0x7d0f0232, 0x7d040190, 0x00000000}},  //   _שלומ, _pics, fmis,
  { {0xb035025f, 0xc03501fc, 0x7c2d0ba9, 0x00000000}},  //   _униш, _униј, ubar,
  { {0x7c2d0149, 0x29180baa, 0x5c07005e, 0x00000000}},  // [1110] rbar, _aura_, рява,
  { {0x7c2d0bab, 0x7d040bac, 0x442d016e, 0x00000000}},  //   sbar, amis, zbe_,
  { {0x29180bad, 0x442d0bae, 0x7d0400ab, 0x00000000}},  //   _cura_, ybe_, bmis,
  { {0x7c950025, 0x442d0066, 0x6205006b, 0x00000000}},  //   _الحص, xbe_, ürlə,
  { {0x7bd8011f, 0x6d550baf, 0x442d0142, 0x00000000}},  //   şvur, luza, vbe_,
  { {0x1fd90044, 0x29180bb0, 0x442d000a, 0x00000000}},  //   _সরাস, _fura_, wbe_,
  { {0x6a22026c, 0x291804f8, 0x20d20027, 0x00000000}},  //   _رہنم, _gura_, lšie_,
  { {0x6f1d001c, 0x442d010f, 0x9dd8009b, 0x00000000}},  //   kqsc, ube_, יווק_,
  { {0x7c22008e, 0x6e3c014a, 0x29180bb1, 0x00000000}},  //   ñori, yarb, _zura_,
  { {0x7d04037e, 0x442d0880, 0x6d550bb2, 0x00000000}},  //   zmis, sbe_, kuza,
  { {0x62810007, 0xd298008b, 0x7d04021e, 0x00000000}},  //   rdlo, ртыі_, ymis,
  { {0xcea901f8, 0x2b4000f6, 0x6d550bb3, 0x00000000}},  //   _אי_, ysic_, duza,
  { {0x6e3c010f, 0x20d20027, 0xd34100a1, 0x00000000}},  //   tarb, jšie_, _عہدی,
  { {0x249f07e0, 0x6d55001a, 0x7e230143, 0x00000000}},  //   ljum_, fuza, здрж,
  { {0x7d040004, 0x6e3c010f, 0x6d550032, 0x00000000}},  //   tmis, rarb, guza,
  { {0x6e3c04d3, 0xceb4006b, 0x3a380bb4, 0x00000000}},  //   sarb, _atət_, _serp_,
  { {0x7e7508e2, 0x29180020, 0x6a160a4f, 0x00000000}},  // [1120] bezp, _sura_, مبار,
  { {0x3f8f0181, 0x6d5501f3, 0x2b400bb5, 0x00000000}},  //   _água_, buza, rsic_,
  { {0x5d860025, 0x8fc50014, 0xd23a0049, 0x00000000}},  //   _الجل, _هزین, רגעל,
  { {0x3a3801d6, 0x29180350, 0x00000000, 0x00000000}},  //   _werp_, _vura_,   ,
  { {0x386602cc, 0xdd8f00a2, 0x3a380146, 0x00000000}},  //   rfor_, _قوی_, _terp_,
  { {0xe9440bb6, 0x00000000, 0x00000000, 0x00000000}},  //   _ورزی,   ,   ,
  { {0x249f000c, 0xceb300a0, 0x386600fa, 0x00000000}},  //   fjum_, היג_, pfor_,
  { {0x249f000c, 0x00000000, 0x00000000, 0x00000000}},  //   gjum_,   ,   ,
  { {0x6d550bb7, 0x00000000, 0x00000000, 0x00000000}},  //   zuza,   ,   ,
  { {0x25610047, 0xe643003b, 0x22470288, 0x00000000}},  //   ból_, _неуп, _cdnk_,
  { {0x7648018e, 0xf09f0129, 0x6a9b0049, 0x00000000}},  //   _iddy, tjà_, אשינ,
  { {0x64a30bb8, 0x00000000, 0x00000000, 0x00000000}},  //   _наха,   ,   ,
  { {0x33f6023c, 0x2ca00bb9, 0xc7b40049, 0x00000000}},  //   _اساس, djid_, קבֿ_,
  { {0x20d20027, 0x3d950bba, 0x121a007e, 0x00000000}},  //   všie_, оигр, _сюды_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8cf50106, 0x6d550bbb, 0x853b0049, 0x00000000}},  //   ізац, ruza, טגלי,
  { {0xab87005e, 0x764809b6, 0x5b14004d, 0x00000000}},  // [1130] щувк, _oddy, змут,
  { {0x70550123, 0x249f0036, 0x20d20027, 0x00000000}},  //   _انکا, zjum_, ršie_,
  { {0xceb20104, 0x69c801ed, 0x249f01e5, 0x00000000}},  //   _חיי_, _žder, yjum_,
  { {0x7648018e, 0x515b0097, 0x20d20027, 0x00000000}},  //   _addy, רכאו, pšie_,
  { {0x75280089, 0x46a502dc, 0x00000000, 0x00000000}},  //   _atdz, жалв,   ,
  { {0x25610047, 0x7f3c0049, 0xf7700380, 0x00000000}},  //   tól_, נעוו, عان_,
  { {0x04590025, 0x249f01e5, 0x00000000, 0x00000000}},  //   للغة_, tjum_,   ,
  { {0x25610047, 0xc32501e0, 0x0325003b, 0x00000000}},  //   ról_, омик, один,
  { {0x249f009f, 0xd2990088, 0x7b09012d, 0x00000000}},  //   rjum_, атні_, _džuv,
  { {0x02c501fb, 0x68eb0bbc, 0x8af0006b, 0x00000000}},  //   ійно, logd, ltər,
  { {0xe0da0bbd, 0xd4e701fb, 0x21690364, 0x00000000}},  //   иво_, _люди, шини_,
  { {0x60cf009d, 0x67290066, 0xc1060025, 0x00000000}},  //   gicm, _ktej, توجي,
  { {0x443f0bbe, 0xe9ff0082, 0x6d450479, 0x00000000}},  //   mau_, _trặc_, _avha,
  { {0x443f04be, 0x645b0129, 0x67290bbf, 0x00000000}},  //   lau_, lgui, _mtej,
  { {0x62830bc0, 0xa0a6004d, 0x2d8c0142, 0x00000000}},  //   _iano, _макд, íde_,
  { {0x443f0bc1, 0x62830011, 0x00000000, 0x00000000}},  //   nau_, _hano,   ,
  { {0xeab200a1, 0x5aca0147, 0x443f0bc2, 0x00000000}},  // [1140] وٹر_, алам_, iau_,
  { {0x443f018e, 0x386d001f, 0x62830161, 0x00000000}},  //   hau_, _aber_, _jano,
  { {0xdca601fb, 0x443f09cf, 0x6d410010, 0x00000000}},  //   _дани, kau_, álat,
  { {0x186a0113, 0x443f0bc3, 0x62830161, 0x00000000}},  //   ради_, jau_, _lano,
  { {0x443f0bc4, 0x27e00bc5, 0x47330088, 0x00000000}},  //   dau_, çin_, дніс,
  { {0x2906002d, 0x27e001d5, 0x9f610010, 0x00000000}},  //   smoa_, ħin_, ését_,
  { {0x443f018e, 0xe1e701d8, 0x8af0006b, 0x00000000}},  //   fau_, _آس_, stəs,
  { {0x7c240627, 0x443f018e, 0x2005005f, 0x00000000}},  //   ncir, gau_, əlif_,
  { {0x62830065, 0x8af0006b, 0x6d480062, 0x00000000}},  //   _bano, qtəs, ádaj,
  { {0x62830b69, 0x78a200ea, 0x645b0325, 0x00000000}},  //   _cano, ljov, agui,
  { {0x443f0bc6, 0xe29a001d, 0x645b0bc7, 0x00000000}},  //   bau_, _chưa_, bgui,
  { {0x443f0bc8, 0x00000000, 0x00000000, 0x00000000}},  //   cau_,   ,   ,
  { {0x6283091d, 0x64400258, 0x34d90049, 0x00000000}},  //   _fano, mami, _פֿעב,
  { {0x62830bc9, 0x60cf0bca, 0x7c260bcb, 0x00000000}},  //   _gano, sicm, _afkr,
  { {0xeca701fc, 0x9c8300b9, 0x64400020, 0x00000000}},  //   ојан, íčov, oami,
  { {0x628300ee, 0x6aaa010f, 0x4c94007c, 0x00000000}},  //   _zano, öffn, мисс,
  { {0x60cd0059, 0x628300e0, 0xdfd10464, 0x00000000}},  // [1150] _imam, _yano, _سيد_,
  { {0x6440000b, 0x44240011, 0x443f001a, 0x00000000}},  //   hami, hcm_, zau_,
  { {0xceb2007b, 0xe2a6009f, 0x67290224, 0x00000000}},  //   _ניט_, _áður_, _stej,
  { {0x5d7a0476, 0x2d810bcc, 0x44260403, 0x00000000}},  //   _פארק, _ishe_, _nfo_,
  { {0x64400004, 0x443f010a, 0x7b64007c, 0x00000000}},  //   dami, vau_, _отре,
  { {0x8af0005f, 0xcf58009b, 0x443f0bcd, 0x00000000}},  //   stər, קבות_, wau_,
  { {0x6440027b, 0x443f0bce, 0x60cd006c, 0x00000000}},  //   fami, tau_, _omam,
  { {0x64400bcf, 0x6283021e, 0x78a200f6, 0x00000000}},  //   gami, _sano, cjov,
  { {0x443f0bc4, 0x645b0190, 0x7c3d01a3, 0x00000000}},  //   rau_, rgui, _mesr,
  { {0x443f0bd0, 0x78a9049b, 0x60cd00d6, 0x00000000}},  //   sau_, _hoev, _amam,
  { {0x62830007, 0x443f0016, 0x6440006c, 0x00000000}},  //   _vano, pau_, bami,
  { {0x64400181, 0x7c3d0340, 0x44240020, 0x00000000}},  //   cami, _nesr, ccm_,
  { {0x6283006a, 0xa29501fb, 0x78bb00b9, 0x00000000}},  //   _tano, _наді, _mluv,
  { {0x78bb0211, 0xe29a0011, 0x60cd0288, 0x00000000}},  //   _lluv, _thưa_, _emam,
  { {0x443d0bd1, 0x6da60bd2, 0x6b8f0bd3, 0x00000000}},  //   _kew_, чива, _arcg,
  { {0x61fc011f, 0x8b26007c, 0x78a9012d, 0x00000000}},  //   ürle, здае, _noev,
  { {0xeb970407, 0x7c3d00c4, 0x7c240145, 0x00000000}},  // [1160] пит_, _desr, rcir,
  { {0x64400814, 0x09e60200, 0x7c240bd4, 0x00000000}},  //   zami, позн, scir,
  { {0x78bb0617, 0x78a2008e, 0x78a900d9, 0x00000000}},  //   _bluv, tjov, _boev,
  { {0x443d0038, 0x6440062c, 0x78a900bb, 0x00000000}},  //   _new_, xami, _coev,
  { {0x8af0005f, 0x64400bd5, 0x7d1e04fd, 0x00000000}},  //   stəq, vami, _hups,
  { {0xab270265, 0x44260190, 0xd94601fc, 0x00000000}},  //   _хора_, _sfo_, _неги,
  { {0x78bb0129, 0x64400114, 0x78a2007f, 0x00000000}},  //   _fluv, tami, pjov,
  { {0x78bb0107, 0x89db009b, 0x443d0093, 0x00000000}},  //   _gluv, _החלי, _cew_,
  { {0x6440006a, 0xe7370057, 0x68e3004a, 0x00000000}},  //   rami, _нет_, énde,
  { {0x6440006c, 0xbebb0023, 0x6e3e00d9, 0x00000000}},  //   sami, hpër, _nepb,
  { {0x64400814, 0x443d0038, 0x705504b1, 0x00000000}},  //   pami, _few_, وندا,
  { {0x443d0bd6, 0xdfd507d0, 0x69c1006c, 0x00000000}},  //   _gew_, домы, _ülee,
  { {0x2d8c0030, 0xdcb10082, 0x7c3d0203, 0x00000000}},  //   æden_, ểm_, _resr,
  { {0x7bc40bd7, 0x7c3d00f6, 0x00000000, 0x00000000}},  //   dziu, _sesr,   ,
  { {0x629800ab, 0x443d0085, 0x7eb0006c, 0x00000000}},  //   _invo, _yew_, _näpu,
  { {0x60cd0058, 0x62880bd8, 0x00000000, 0x00000000}},  //   _umam, lddo,   ,
  { {0x9f54008b, 0x2bc7006e, 0xfbd301fa, 0x00000000}},  // [1170] _звыч, _रेखा, رتر_,
  { {0x7b090bd9, 0x628803cd, 0x7c3d01c3, 0x00000000}},  //   _ažur, nddo, _wesr,
  { {0x2d8c0bda, 0x7d1e0606, 0x78bb0bdb, 0x00000000}},  //   ådet_, _gups, _pluv,
  { {0x315701ce, 0x60dd0bdc, 0x00000000, 0x00000000}},  //   ליבן_, nnsm,   ,
  { {0x629801b5, 0x2cf90061, 0x60dd0146, 0x00000000}},  //   _onvo, ंतील_, insm,
  { {0x443d002b, 0x6b8d03cc, 0x00000000, 0x00000000}},  //   _sew_, mvag,   ,
  { {0x78a9017c, 0x443d0bdd, 0x58d50088, 0x00000000}},  //   _toev, _pew_, _жовт,
  { {0xe3b901bd, 0xcd9800a0, 0x62880016, 0x00000000}},  //   жби_, לדות_, eddo,
  { {0x27ff01f6, 0xf770002c, 0x628800bb, 0x00000000}},  //   _uzun_, _مال_, fddo,
  { {0x25e8013d, 0x443d0bde, 0x04fd0044, 0x00000000}},  //   _चुकी_, _wew_, ঁদের_,
  { {0x69c50bdf, 0x7643033b, 0x6d550036, 0x00000000}},  //   nzhe, many, jrza,
  { {0x62980be0, 0x6d55057c, 0x644b0018, 0x00000000}},  //   _envo, drza, _udgi,
  { {0x7d1e0107, 0x6d550036, 0x945d00b4, 0x00000000}},  //   _sups, erza, sińs,
  { {0x76430169, 0x7d1e0be1, 0x8fa3003b, 0x00000000}},  //   nany, _pups, њаре,
  { {0x9fa00112, 0x00000000, 0x00000000, 0x00000000}},  //   _méér_,   ,   ,
  { {0xc1060025, 0x76430be2, 0x69c5012d, 0x00000000}},  //   _توبي, hany, dzhe,
  { {0x09ab0044, 0xcb6700c0, 0x6d47006c, 0x00000000}},  // [1180] _গেলা, мате_, asja,
  { {0x0f57009b, 0x76430145, 0xbebb0023, 0x00000000}},  //   _קיים_, jany, spër,
  { {0x76430127, 0x7e7c0277, 0xa967005e, 0x00000000}},  //   dany, merp, диха_,
  { {0x6d5c09f3, 0x395a00eb, 0x2c7800a1, 0x00000000}},  //   mura, rups_, _ڈیڑھ_,
  { {0x76430be3, 0x6288018e, 0x6d5c0169, 0x00000000}},  //   fany, yddo, lura,
  { {0x395a01db, 0x07a3012b, 0xfbd3009b, 0x00000000}},  //   pups_, таљн, _יתר_,
  { {0x6d5c0be4, 0xf983007c, 0x00000000, 0x00000000}},  //   nura, _игро,   ,
  { {0x2ebb0201, 0x7e7c0be5, 0x00000000, 0x00000000}},  //   _उत्त, herp,   ,
  { {0x7643020c, 0x6d5c01a3, 0x20c20048, 0x00000000}},  //   bany, hura, _móid_,
  { {0xd250007a, 0x6d5c0653, 0xeb910049, 0x00000000}},  //   دند_, kura, אָט_,
  { {0x7e7c0af1, 0x6288018e, 0x6d5c0be6, 0x00000000}},  //   derp, rddo, jura,
  { {0x6d5c022b, 0x67200020, 0x04930025, 0x00000000}},  //   dura, _kumj, _للمح,
  { {0x7c360190, 0x60dd0be7, 0x2d6801a2, 0x00000000}},  //   dbyr, rnsm, eße_,
  { {0x6d5c0020, 0x7e7c0030, 0x826800a1, 0x00000000}},  //   fura, gerp, _رشتہ_,
  { {0x9f9901d6, 0x00000000, 0x00000000, 0x00000000}},  //   _dáár_,   ,   ,
  { {0x6d47002b, 0x76430036, 0x20c20051, 0x00000000}},  //   rsja, zany, _cóid_,
  { {0x2d9e010f, 0x2d8c043e, 0xfc3f0129, 0x00000000}},  // [1190] äter_, åder_, _veí_,
  { {0x6d5c020c, 0x9af50025, 0x7e7c08d0, 0x00000000}},  //   bura, ركات, cerp,
  { {0x6d5c0be8, 0x6b8d0039, 0x76430321, 0x00000000}},  //   cura, svag, vany,
  { {0x76430046, 0x2bd002d2, 0xe0df0197, 0x00000000}},  //   wany, _सेवा, nnò_,
  { {0x7643020c, 0x7d0d003c, 0xf3880011, 0x00000000}},  //   tany, mmas, _nợ_,
  { {0x7d0d038c, 0xddde05fa, 0xbb3a00a0, 0x00000000}},  //   lmas, _hapš, _מעשי,
  { {0x7643020c, 0x00000000, 0x00000000, 0x00000000}},  //   rany,   ,   ,
  { {0x7d0d038c, 0x76430149, 0xb38500c0, 0x00000000}},  //   nmas, sany, елил,
  { {0x76430be9, 0x7e7c0009, 0x7d0d010e, 0x00000000}},  //   pany, yerp, imas,
  { {0x13060057, 0x6d5c033b, 0x7d0d0bea, 0x00000000}},  //   нный_, yura, hmas,
  { {0xd12e00d3, 0xe1f9008b, 0x6d5c002d, 0x00000000}},  //   یمی_, яго_, xura,
  { {0x76410047, 0xf9920476, 0x2ec803d7, 0x00000000}},  //   _hely, ארט_, रफ्त,
  { {0x42cd0044, 0x6d5c0093, 0x76410006, 0x00000000}},  //   রকৌশ, wura, _kely,
  { {0x91e50001, 0x7d0d01a3, 0x3ebe000c, 0x00000000}},  //   _поле, emas, ótt_,
  { {0x76410047, 0xc5f20049, 0x7e7c0146, 0x00000000}},  //   _mely, ָדן_, rerp,
  { {0x7d0d011c, 0x7e7c0056, 0x6d5c0beb, 0x00000000}},  //   gmas, serp, rura,
  { {0x7e7c0bec, 0x245a011f, 0x75210023, 0x00000000}},  // [11a0] perp, lümü_, _lulz,
  { {0x6d5c0016, 0xb05b0a35, 0xea87026b, 0x00000000}},  //   pura, nhän, нбул_,
  { {0xcee90014, 0x245a0279, 0x8c460745, 0x00000000}},  //   _ترين_, nümü_, _пене,
  { {0x7eb00004, 0x22450bed, 0x00000000, 0x00000000}},  //   _täps, halk_,   ,
  { {0x68e3008e, 0x20d20059, 0x224500ea, 0x00000000}},  //   énda, jšim_, kalk_,
  { {0x09bf0044, 0x75210026, 0x0cc30044, 0x00000000}},  //   _আশরা, _bulz, ্কৃত,
  { {0xf3880011, 0xceb3009b, 0x76410016, 0x00000000}},  //   _sợ_, ריו_, _dely,
  { {0x7521008e, 0xd3a6004c, 0x69c1006c, 0x00000000}},  //   _dulz, ероп, _ülea,
  { {0x76410bee, 0x22450239, 0xb05b01a2, 0x00000000}},  //   _fely, falk_, fhän,
  { {0xf388001d, 0x76410bef, 0x6aae0190, 0x00000000}},  //   _vợ_, _gely, _jobf,
  { {0xba570049, 0xf48400a1, 0x752100d9, 0x00000000}},  //   עסטו_, _لاشی, _gulz,
  { {0x7d0d006b, 0x254c00b9, 0x00000000, 0x00000000}},  //   xmas, měl_,   ,
  { {0xb05b010f, 0xe0df0197, 0x224500bb, 0x00000000}},  //   bhän, rnò_, balk_,
  { {0x245a014a, 0xddde012d, 0x539b00a0, 0x00000000}},  //   bümü_, _sapš, _מידו,
  { {0x7d0d0279, 0x20240048, 0x00000000, 0x00000000}},  //   tmas, íriú_,   ,
  { {0xccf8012b, 0x628a005b, 0x00000000, 0x00000000}},  //   ећу_, _hafo,   ,
  { {0x7d0d0bf0, 0x628a01aa, 0x6aae00fa, 0x00000000}},  // [11b0] rmas, _kafo, _bobf,
  { {0x2b490068, 0x64420048, 0x00000000, 0x00000000}},  //   rsac_, _leoi,   ,
  { {0x764101aa, 0xd9990054, 0xddde0bf1, 0x00000000}},  //   _rely, بنات_, _tapš,
  { {0x48cf0044, 0x254c00b9, 0x628a0bf2, 0x00000000}},  //   িক্র, děl_, _lafo,
  { {0x81bc0089, 0x245a005a, 0x7eb00bf3, 0x00000000}},  //   ucēj, zümü_, _käpp,
  { {0x69d5001c, 0xf65300a1, 0x75210096, 0x00000000}},  //   _येथी, ائش_, _pulz,
  { {0x64420051, 0x76410006, 0xb5c20088, 0x00000000}},  //   _beoi, _vely, ийшл,
  { {0x64420051, 0x7eb00bf4, 0x798701c3, 0x00000000}},  //   _ceoi, _läpp, _isjw,
  { {0xe3b10025, 0x69d50061, 0x130902d3, 0x00000000}},  //   شرة_, _येती, мний_,
  { {0x628a018e, 0x7eb00103, 0x00000000, 0x00000000}},  //   _cafo, _näpp,   ,
  { {0x628a005b, 0xb05b09b0, 0x64420048, 0x00000000}},  //   _dafo, rhän, _feoi,
  { {0xe3b002fd, 0xe5080025, 0x64420bf5, 0x00000000}},  //   _گرم_, _كيلو_, _geoi,
  { {0xb05b0bf6, 0x2ca9006c, 0xe3ae013a, 0x00000000}},  //   mhäl, djad_, _тб_,
  { {0x79820046, 0x628a0016, 0x248d00b4, 0x00000000}},  //   łowi, _gafo, ldem_,
  { {0xbea301fc, 0x8af0006b, 0xb05b01a2, 0x00000000}},  //   шарк, frən, chäo,
  { {0x248d0bf7, 0x1fb6030d, 0x3ce000ea, 0x00000000}},  //   ndem_, _асор, univ_,
  { {0x248d042e, 0x00000000, 0x00000000, 0x00000000}},  // [11c0] idem_,   ,   ,
  { {0x3ced0bf8, 0x248d0bf9, 0x63a600f8, 0x00000000}},  //   čeva_, hdem_, äkni,
  { {0x19b9008b, 0xae57009b, 0x7d0a003b, 0x00000000}},  //   нуць_, _בסיס_, _оног_,
  { {0x79950036, 0x38cb00a6, 0x248d0bfa, 0x00000000}},  //   _drzw, وانی_, jdem_,
  { {0xe7d201f5, 0x6d5a0006, 0x248d098d, 0x00000000}},  //   _देशप, štad, ddem_,
  { {0x248d01d5, 0x254c00b9, 0x64420bfb, 0x00000000}},  //   edem_, těl_, _seoi,
  { {0xe9a30594, 0x628a01e5, 0xa01b0010, 0x00000000}},  //   _карп, _rafo, ldöt,
  { {0x628a018e, 0xb86604e8, 0xfb8500a1, 0x00000000}},  //   _safo, _جاسو, _جگہی,
  { {0x2c6d0010, 0xaa82000c, 0xa766007e, 0x00000000}},  //   lódó_, _þýsk, _шкад,
  { {0x68e20bfc, 0x00000000, 0x00000000, 0x00000000}},  //   lnod,   ,   ,
  { {0x64420bfd, 0x9f4f000c, 0xe3af0bb6, 0x00000000}},  //   _teoi, _ágú_, مری_,
  { {0x68e20016, 0x6b840009, 0xd5d90049, 0x00000000}},  //   nnod, kwig, _אַנש,
  { {0x35a8013d, 0x628a0016, 0xe7030082, 0x00000000}},  //   _कपड़, _tafo, _hướ,
  { {0x6b840090, 0x7a480089, 0x68e20544, 0x00000000}},  //   dwig, nūtē, hnod,
  { {0x2ca9006c, 0x1df80147, 0x51f30014, 0x00000000}},  //   tjad_, веры_, _پسور,
  { {0x20d20059, 0x0217009b, 0x00000000, 0x00000000}},  //   jših_, _בחום_,   ,
  { {0x68e20428, 0x2ca90bfe, 0x3a75007c, 0x00000000}},  // [11d0] dnod, rjad_, ллар,
  { {0x5a340bff, 0x2ca9006c, 0x248d0528, 0x00000000}},  //   инут, sjad_, zdem_,
  { {0x68e2018e, 0x68e30211, 0xceb20104, 0x00000000}},  //   fnod, éndo, _היי_,
  { {0x68e20016, 0x3f890022, 0x236d013e, 0x00000000}},  //   gnod, _ksau_, ytej_,
  { {0xe9ff0011, 0x7c2d0145, 0x2fcb0009, 0x00000000}},  //   _trắc_, mcar, nzcg_,
  { {0x7d1d038c, 0x7c2d001a, 0xda34007e, 0x00000000}},  //   _hiss, lcar, _веры,
  { {0x45190401, 0xb05b0c00, 0xc98404cf, 0x00000000}},  //   нция_, thäl, _кути,
  { {0x7c2d020c, 0x7d1d01d5, 0x05760025, 0x00000000}},  //   ncar, _jiss, امية_,
  { {0x7d1d01cb, 0x248d010f, 0xb05b010f, 0x00000000}},  //   _miss, rdem_, rhäl,
  { {0x236d0c01, 0xf77000a1, 0x27e00051, 0x00000000}},  //   rtej_, _گاہ_, úine_,
  { {0x291e00f4, 0xa06a013a, 0x236d05fd, 0x00000000}},  //   _état_, нана_, stej_,
  { {0x7c2d0c02, 0xd5ba0049, 0x6b8401d6, 0x00000000}},  //   jcar, _אזעל, ywig,
  { {0x442d00d2, 0xe28e008b, 0x7c2d05eb, 0x00000000}},  //   mce_, _ла_, dcar,
  { {0x442d0763, 0x66f503d7, 0x64490051, 0x00000000}},  //   lce_, ेतिक_, laei,
  { {0x62810314, 0x7d1d010f, 0x3f8900e0, 0x00000000}},  //   melo, _biss, _esau_,
  { {0x442d0c03, 0x6281001a, 0x7d1d00c4, 0x00000000}},  //   nce_, lelo, _ciss,
  { {0x442f010f, 0x60c40c04, 0x442d00ab, 0x00000000}},  // [11e0] _mfg_, _ilim, ice_,
  { {0x7bc0005f, 0x628100e5, 0xc33200b6, 0x00000000}},  //   _ümum, nelo, צוב_,
  { {0x2d96098c, 0x442d0224, 0x7d1d0207, 0x00000000}},  //   _српс, kce_, _fiss,
  { {0xdca601f9, 0x442d00b9, 0x7c2d0207, 0x00000000}},  //   _сами, jce_, ccar,
  { {0x442d0c05, 0x6281023a, 0x6d4e0039, 0x00000000}},  //   dce_, kelo, lsba,
  { {0x62810209, 0x6d5c046a, 0x60c400d4, 0x00000000}},  //   jelo, orra, _llim,
  { {0x60c4006b, 0x62810c06, 0x6d4e0039, 0x00000000}},  //   _olim, delo, nsba,
  { {0x442f0c07, 0x6f1e0046, 0x64490048, 0x00000000}},  //   _cfg_, _lipc, gaei,
  { {0xb4e40316, 0x62810951, 0x6d5c010f, 0x00000000}},  //   _नदी_, felo, hrra,
  { {0x6281049b, 0x26c700b9, 0x3866018e, 0x00000000}},  //   gelo, chno_, lgor_,
  { {0x60c40c08, 0x442d00b9, 0x7c2d0133, 0x00000000}},  //   _blim, bce_, ycar,
  { {0x38660bbe, 0x442d0207, 0x30a70364, 0x00000000}},  //   ngor_, cce_, уров,
  { {0x8af0006b, 0x6d4e0168, 0x2d9e01c9, 0x00000000}},  //   stəy, esba, åten_,
  { {0x60c4000b, 0x7d1d0004, 0x62810c09, 0x00000000}},  //   _elim, _siss, celo,
  { {0x7d1d03b4, 0x60c401d5, 0x7c2d00b5, 0x00000000}},  //   _piss, _flim, tcar,
  { {0x60c40007, 0x3ced0c0a, 0xd7c40061, 0x00000000}},  //   _glim, čevo_, वनाच,
  { {0x7d1d0c0b, 0x7c2d0412, 0x6d5c0add, 0x00000000}},  // [11f0] _viss, rcar, arra,
  { {0x7d1d0c0c, 0x442d011f, 0x7c2d0781, 0x00000000}},  //   _wiss, zce_, scar,
  { {0x7d1d0c0d, 0x442d0036, 0x60c400b0, 0x00000000}},  //   _tiss, yce_, _ylim,
  { {0x62810c0e, 0x69c1006c, 0x6f1e0019, 0x00000000}},  //   zelo, _ülem, _zipc,
  { {0x442d0428, 0x07a509ae, 0x499300a1, 0x00000000}},  //   vce_, ралн, _گیار,
  { {0x442d0036, 0x0555005e, 0x442f0bf5, 0x00000000}},  //   wce_, атия, _sfg_,
  { {0x6281030a, 0x442d0c0f, 0x442f0c10, 0x00000000}},  //   velo, tce_, _pfg_,
  { {0x26c7012d, 0x473507e1, 0xed640161, 0x00000000}},  //   shno_, _внас, leží_,
  { {0x442d0c11, 0x62810c12, 0xe73001fa, 0x00000000}},  //   rce_, telo, _فصل_,
  { {0x442d0c13, 0x60c40089, 0x27ff0c14, 0x00000000}},  //   sce_, _slim, _iyun_,
  { {0x442d091d, 0x6281001a, 0x60c4001a, 0x00000000}},  //   pce_, relo, _plim,
  { {0x6281001a, 0x65630181, 0x272b0030, 0x00000000}},  //   selo, munh, _køn_,
  { {0x68e90065, 0x62810716, 0x20c20048, 0x00000000}},  //   _mjed, pelo, _fóin_,
  { {0xed5a012b, 0x6d4e00bb, 0x200900fa, 0x00000000}},  //   ког_, tsba, _dzai_,
  { {0x272b0737, 0x68fb014a, 0x63bb0232, 0x00000000}},  //   _løn_, _okud, lyun,
  { {0x27ff0676, 0x60c40020, 0x224700b5, 0x00000000}},  //   _oyun_, _ulim, _henk_,
  { {0x6d4e010f, 0x63bb008a, 0x63a90c15, 0x00000000}},  // [1200] ssba, nyun, nxen,
  { {0xc879005f, 0xed460454, 0x68fb08ff, 0x00000000}},  //   _abş_, _кноп, _akud,
  { {0x27ff011c, 0x63bb0093, 0x212700d4, 0x00000000}},  //   _ayun_, hyun, _junh_,
  { {0x26c50c16, 0x290d0061, 0xe73a0780, 0x00000000}},  //   _allo_, _chea_, вед_,
  { {0x18670b86, 0x1634005e, 0x68e9016e, 0x00000000}},  //   рачи_, беля, _djed,
  { {0x8b190256, 0x68fb00bb, 0x68e90190, 0x00000000}},  //   _бюст_, _ekud, _ejed,
  { {0x68e90190, 0x3866005b, 0x27ed00d9, 0x00000000}},  //   _fjed, pgor_, _exen_,
  { {0x26c50211, 0xd497007c, 0x68e900ea, 0x00000000}},  //   _ello_, арь_, _gjed,
  { {0x2247016c, 0x63bb0010, 0x00000000, 0x00000000}},  //   _benk_, gyun,   ,
  { {0x291f000d, 0x68e90a32, 0xb2730147, 0x00000000}},  //   _ziua_, _zjed, ольш,
  { {0x22470c17, 0x2ef8010f, 0x21630088, 0x00000000}},  //   _denk_, dorf_, отяг,
  { {0x64a3005e, 0xddc500b9, 0x26dc04bb, 0x00000000}},  //   _маха, _schů, livo_,
  { {0xa2940c18, 0xdc2e006b, 0x224701aa, 0x00000000}},  //   _галі, _sığo, _fenk_,
  { {0x76480046, 0x7b10010f, 0x24840066, 0x00000000}},  //   _jedy, läuf, lemm_,
  { {0xe3e80055, 0x00000000, 0x00000000, 0x00000000}},  //   _পরিব,   ,   ,
  { {0xc05b01fb, 0x6ca40c19, 0x26dc0555, 0x00000000}},  //   _рік_, оруж, hivo_,
  { {0x75280c1a, 0x60dd0c1b, 0x290d01eb, 0x00000000}},  // [1210] _ludz, mism, _rhea_,
  { {0x60dd0c1c, 0x68e90c1d, 0x26dc0c1e, 0x00000000}},  //   lism, _sjed, jivo_,
  { {0xc8ab005e, 0x272b0737, 0x248401d5, 0x00000000}},  //   къде_, _søn_, kemm_,
  { {0xf77106ea, 0x60dd0c1f, 0x00000000, 0x00000000}},  //   كات_, nism,   ,
  { {0x2bde02fb, 0x68e90065, 0x75280089, 0x00000000}},  //   _नेपा, _vjed, _audz,
  { {0x75280c20, 0xdc3c0066, 0x00000000, 0x00000000}},  //   _budz, _iġġo,   ,
  { {0x68e90209, 0x785700d3, 0xa8a7005e, 0x00000000}},  //   _tjed, _نیاز_, _крак,
  { {0x224701aa, 0x68e90091, 0x60dd008e, 0x00000000}},  //   _senk_, _ujed, jism,
  { {0x60dd0779, 0x7648005b, 0x00000000, 0x00000000}},  //   dism, _fedy,   ,
  { {0x26dc037e, 0x68f90066, 0x7528012d, 0x00000000}},  //   civo_, lowd, _fudz,
  { {0x60dd030e, 0x63bb011c, 0xdcf001ee, 0x00000000}},  //   fism, syun, _šeči,
  { {0x67210c21, 0x297a061e, 0x397a00b6, 0x00000000}},  //   _hilj, נטרא, נטרנ,
  { {0x443f0b98, 0x22470c22, 0x2005006b, 0x00000000}},  //   mbu_, _tenk_, əlik_,
  { {0x443f002b, 0x6d450c23, 0x7d180010, 0x00000000}},  //   lbu_, _bwha, _évsz,
  { {0x672107dc, 0xdca60057, 0x2d95025f, 0x00000000}},  //   _milj, бави, ортс,
  { {0x672106a1, 0x26dc055a, 0x443f0253, 0x00000000}},  //   _lilj, zivo_, nbu_,
  { {0x1d070c24, 0x443f0c25, 0x00000000, 0x00000000}},  // [1220] сети_, ibu_,   ,
  { {0x386d0c26, 0x9e660c27, 0x8e860025, 0x00000000}},  //   _acer_, _увод, _الده,
  { {0x76480c28, 0x248400e0, 0x499a0641, 0x00000000}},  //   _redy, yemm_, ытая_,
  { {0x443f0c29, 0x75280c2a, 0xa3c70067, 0x00000000}},  //   jbu_, _rudz, ईना_,
  { {0x26dc0a15, 0x443f0142, 0x7d040c2b, 0x00000000}},  //   tivo_, dbu_, mlis,
  { {0x7d040b3e, 0x67210295, 0x386d0c2c, 0x00000000}},  //   llis, _cilj, _ecer_,
  { {0x26dc0207, 0x60dd0c2d, 0x6721016e, 0x00000000}},  //   rivo_, yism, _dilj,
  { {0x7d04009f, 0x26dc0c2e, 0x60dd0c2f, 0x00000000}},  //   nlis, sivo_, xism,
  { {0x60dd049a, 0x47c600ed, 0x26dc0c30, 0x00000000}},  //   vism, _убав, pivo_,
  { {0x7d040052, 0x415402d3, 0x66010c31, 0x00000000}},  //   hlis, овос, _fylk,
  { {0x7d040161, 0x8afb0049, 0x443f0c32, 0x00000000}},  //   klis, רהיי, bbu_,
  { {0x7d040085, 0x67210c33, 0x00000000, 0x00000000}},  //   jlis, _zilj,   ,
  { {0x68e30c34, 0xe6c4009f, 0x44260c35, 0x00000000}},  //   éndi, _þjóð, _igo_,
  { {0x7d040c36, 0x7d160027, 0x4426004a, 0x00000000}},  //   elis, emys, _hgo_,
  { {0x6d5a0091, 0x7d040c37, 0x60dd0036, 0x00000000}},  //   štan, flis, pism,
  { {0xd904089d, 0x4426004a, 0x9c39030d, 0x00000000}},  //   _سی_, _jgo_, рпат_,
  { {0x2d8c0030, 0x752200f6, 0x88bd0036, 0x00000000}},  // [1230] æder_, _mioz, _liśc,
  { {0x443f016e, 0x2d98009d, 0x31790036, 0x00000000}},  //   zbu_, bvre_, ńsze_,
  { {0x7d040038, 0x443f04bb, 0x27e00c38, 0x00000000}},  //   blis, ybu_, úinn_,
  { {0x7d04006b, 0x442604e6, 0x3eb1012d, 0x00000000}},  //   clis, _ngo_, ljzt_,
  { {0x67290211, 0xe81401f5, 0xd366023c, 0x00000000}},  //   _quej, तेला_, _ته_,
  { {0x44260038, 0x3ce90c39, 0x91fc0089, 0x00000000}},  //   _ago_, lnav_, rgāj,
  { {0x67210c3a, 0x443f0062, 0x44260c3b, 0x00000000}},  //   _vilj, tbu_, _bgo_,
  { {0x3ce90009, 0x44260c3c, 0x00000000, 0x00000000}},  //   nnav_, _cgo_,   ,
  { {0x443f0c3d, 0x7b10010f, 0xb05b010f, 0x00000000}},  //   rbu_, bäud, nhäu,
  { {0x66010046, 0x443f0c3e, 0x7d04020d, 0x00000000}},  //   _tylk, sbu_, zlis,
  { {0x7d0403ca, 0x0086013b, 0x44260c3f, 0x00000000}},  //   ylis, олно, _fgo_,
  { {0xcea900a0, 0x2eb4007d, 0xe0df0026, 0x00000000}},  //   _בי_, ुस्त, giò_,
  { {0xbebb0065, 0x7d04014a, 0xfc460142, 0x00000000}},  //   jqës, vlis, šíka_,
  { {0x6145007c, 0x7d040c40, 0x644b0c41, 0x00000000}},  //   _дека, wlis, _hegi,
  { {0x644b04fa, 0x7e2300ed, 0xdddc016c, 0x00000000}},  //   _kegi, ддрж, ferš,
  { {0x0ce80044, 0xe0df0c42, 0xb05b0c43, 0x00000000}},  //   পত্ত, ciò_, lkän,
  { {0x7d040a48, 0x644b0c44, 0xeb970c45, 0x00000000}},  // [1240] rlis, _megi, оит_,
  { {0x7d040c46, 0xda660054, 0x7d1600b9, 0x00000000}},  //   slis, تاري, smys,
  { {0x3ce90061, 0x64590036, 0xe9da003b, 0x00000000}},  //   bnav_, _odwi, јке_,
  { {0x644b0c47, 0xa8a30098, 0xb17a0049, 0x00000000}},  //   _negi, дршк, יטער,
  { {0xb05b00f8, 0x44260068, 0x00000000, 0x00000000}},  //   phäv, _rgo_,   ,
  { {0x8f9b012f, 0xe0df0197, 0xbf9b00a3, 0x00000000}},  //   ייני, ziò_, יינש,
  { {0xb05b0039, 0x2bde006e, 0x44260c48, 0x00000000}},  //   dkän, _नेता, _pgo_,
  { {0x18670364, 0x644b026e, 0x64400009, 0x00000000}},  //   _маси_, _cegi, ubmi,
  { {0x644b014a, 0xe0df0026, 0x00000000, 0x00000000}},  //   _degi, viò_,   ,
  { {0x3ce00004, 0x64590016, 0x8af0005f, 0x00000000}},  //   hiiv_, _edwi, qsəd,
  { {0x2730001d, 0x44260026, 0x644b01e5, 0x00000000}},  //   _hàn_, _tgo_, _fegi,
  { {0x44260197, 0xbebb0065, 0x6ab7007d, 0x00000000}},  //   _ugo_, yqës, _आक्र,
  { {0x6d5a0142, 0x69c1006c, 0x3ce900ca, 0x00000000}},  //   štal, _ülev, vnav_,
  { {0x2730001d, 0x2005001e, 0xdefb0a78, 0x00000000}},  //   _màn_, āli_, рым_,
  { {0x62880211, 0x27300011, 0x3ce90009, 0x00000000}},  //   medo, _làn_, tnav_,
  { {0x628801d9, 0x00000000, 0x00000000, 0x00000000}},  //   ledo,   ,   ,
  { {0x60c00c49, 0x27300082, 0x3ce90c4a, 0x00000000}},  // [1250] ömme, _nàn_, rnav_,
  { {0x62880544, 0x3ce90c4b, 0x77620133, 0x00000000}},  //   nedo, snav_, drox,
  { {0x3ce90061, 0xdc3f0161, 0x00000000, 0x00000000}},  //   pnav_, líčk,   ,
  { {0xd04f005f, 0x2730001d, 0x628800ea, 0x00000000}},  //   ticə, _bàn_, hedo,
  { {0x6d550010, 0x62880091, 0xdc3f01ca, 0x00000000}},  //   lsza, kedo, níčk,
  { {0x644b009f, 0x62880209, 0x27300011, 0x00000000}},  //   _segi, jedo, _dàn_,
  { {0x62880325, 0x6b8d00b5, 0x644b008a, 0x00000000}},  //   dedo, lwag, _pegi,
  { {0x213e0009, 0x28f80088, 0x00000000, 0x00000000}},  //   dpth_, _десь_,   ,
  { {0x644b000c, 0xf41f00b0, 0x6b8d0c4c, 0x00000000}},  //   _vegi, ää_, nwag,
  { {0x628800c4, 0x04fd0044, 0x4255004d, 0x00000000}},  //   gedo, ুদের_, чтит,
  { {0x644b0004, 0xb05b0c43, 0x68eb0082, 0x00000000}},  //   _tegi, rkän, ongd,
  { {0x6b8d0168, 0x69c1010e, 0xb05b00f8, 0x00000000}},  //   kwag, _üleu, skän,
  { {0xa3d30061, 0x62880181, 0x2004000c, 0x00000000}},  //   _हेच_, bedo, æmi_,
  { {0x62880335, 0x6d5a04eb, 0x00000000, 0x00000000}},  //   cedo, štam,   ,
  { {0x2d9e004f, 0x6da30794, 0x6d550010, 0x00000000}},  //   íte_, нира, gsza,
  { {0xd7bd0061, 0xb05b0c4d, 0x8af0013f, 0x00000000}},  //   ्नाच, nkäl, hrət,
  { {0x6b8d0058, 0xab660c4e, 0x00000000, 0x00000000}},  // [1260] gwag, явал,   ,
  { {0x0e660057, 0x3f92011c, 0x387f0c4f, 0x00000000}},  //   _экон, _isyu_, _abur_,
  { {0x2730001d, 0x3ebb009b, 0xdebb009b, 0x00000000}},  //   _sàn_, _הציב, _המיל,
  { {0x77620190, 0x186a0088, 0x779400a1, 0x00000000}},  //   trox, сади_, ویزا,
  { {0x656301a2, 0x47330c50, 0x6b8d0045, 0x00000000}},  //   ernh, еніс, cwag,
  { {0x2b400c51, 0x628800d4, 0x996400b9, 0x00000000}},  //   mpic_, xedo, může_,
  { {0x62880062, 0x9d000044, 0xe1e70025, 0x00000000}},  //   vedo, ্দীন_, _أس_,
  { {0x6288018e, 0x27300011, 0x776200ab, 0x00000000}},  //   wedo, _tàn_, prox,
  { {0x2b400061, 0x76430c52, 0x00000000, 0x00000000}},  //   npic_, bbny,   ,
  { {0xb6c8026c, 0x7afe0c53, 0x68e20c54, 0x00000000}},  //   _بارے_, nopt, liod,
  { {0x62880142, 0x6d5a0091, 0x69c1006c, 0x00000000}},  //   redo, štaj, _ület,
  { {0x62880c55, 0xeafa00e8, 0x68e2010b, 0x00000000}},  //   sedo, ्तुत_, niod,
  { {0x62880c56, 0xa4b7009b, 0x14a90061, 0x00000000}},  //   pedo, _מלאה_, कारण,
  { {0x6288008d, 0x6d550c57, 0x3eba0035, 0x00000000}},  //   qedo, tsza, _copt_,
  { {0x7afe0bbc, 0xf29700b3, 0x200c006b, 0x00000000}},  //   dopt, _זכור_, ədim_,
  { {0x6d550c58, 0xfbde001c, 0xf1ba0011, 0x00000000}},  //   rsza, _नेहम, _ngơi_,
  { {0x6d550047, 0x68e204bf, 0x60cd0996, 0x00000000}},  // [1270] ssza, diod, _ilam,
  { {0x6b8d0007, 0x6d550c59, 0x88bd0036, 0x00000000}},  //   rwag, psza, _ciśn,
  { {0x60cd0142, 0xc1780006, 0x673b099a, 0x00000000}},  //   _klam, ntė_, _stuj,
  { {0xa3be02d2, 0x26cc0197, 0x2ee300b5, 0x00000000}},  //   ीना_, _aldo_, lijf_,
  { {0x2b400061, 0x60cd015e, 0x69d80c5a, 0x00000000}},  //   cpic_, _mlam, úver,
  { {0x60cd0219, 0x7afe001a, 0x2557001a, 0x00000000}},  //   _llam, copt, tăl_,
  { {0xf65000b8, 0x60cd014a, 0xb05b0c4d, 0x00000000}},  //   ائه_, _olam, tkäl,
  { {0xe894008b, 0x68e2001a, 0x2ee300b5, 0x00000000}},  //   _пась, ciod, hijf_,
  { {0xd702007e, 0xc1780006, 0x00000000, 0x00000000}},  //   _кiра, etė_,   ,
  { {0x60cd020c, 0x78bb0c5b, 0x69c1006c, 0x00000000}},  //   _alam, _houv, _üles,
  { {0x78bb0c5c, 0x208a005e, 0x78a900d9, 0x00000000}},  //   _kouv, ойни_, _knev,
  { {0xafe601fb, 0xd00a00ed, 0x5558007e, 0x00000000}},  //   домл, жеме_, _хаця_,
  { {0x78bb03eb, 0x92b50025, 0x3eba0c5d, 0x00000000}},  //   _mouv, _يحتا, _popt_,
  { {0x78bb0c5e, 0x60cd006c, 0x68e20032, 0x00000000}},  //   _louv, _elam, ziod,
  { {0x78a90270, 0x60cd0c5f, 0x2b400009, 0x00000000}},  //   _onev, _flam, wpic_,
  { {0x78bb0c60, 0x2b400c61, 0x7afe0a5f, 0x00000000}},  //   _nouv, tpic_, wopt,
  { {0xb05b010f, 0x7afe00bb, 0xa2b40061, 0x00000000}},  // [1280] phär, topt, ेसच्,
  { {0x273b0035, 0x78a90035, 0x2b400c62, 0x00000000}},  //   _mână_, _anev, rpic_,
  { {0x2d9c0010, 0xfbd100a1, 0x7afe00ea, 0x00000000}},  //   _éve_, نتے_, ropt,
  { {0x78bb00f4, 0x58830147, 0x88bd0036, 0x00000000}},  //   _couv, выша, _wiśn,
  { {0x68e20292, 0x78a90746, 0x78bb01aa, 0x00000000}},  //   riod, _dnev, _douv,
  { {0x68e20016, 0x78a9068f, 0xc1780006, 0x00000000}},  //   siod, _enev, ytė_,
  { {0x68e2005b, 0x00000000, 0x00000000, 0x00000000}},  //   piod,   ,   ,
  { {0x78bb0c63, 0x6abc009f, 0x78a907d1, 0x00000000}},  //   _gouv, _horf, _gnev,
  { {0x66cf0c64, 0x6abc0253, 0x69c1010e, 0x00000000}},  //   _søke, _korf, _üler,
  { {0xf743072b, 0xc17a0088, 0x6abc00f6, 0x00000000}},  //   _рефо, оїм_, _jorf,
  { {0x6abc049a, 0x60cd016e, 0xb05b0210, 0x00000000}},  //   _morf, _plam, skäm,
  { {0x30a70c65, 0x2249016c, 0xc1780006, 0x00000000}},  //   фров, _đake_, rtė_,
  { {0x351b007b, 0xc1780006, 0x60cd0116, 0x00000000}},  //   _וואנ, stė_, _vlam,
  { {0x32070016, 0x213c0011, 0x6abc046e, 0x00000000}},  //   _fyny_, _ttvh_, _norf,
  { {0x27fa0036, 0x67280aca, 0x63a20c66, 0x00000000}},  //   ępny_, _midj, _hron,
  { {0x63a20239, 0x629a0af1, 0x60cd04cb, 0x00000000}},  //   _kron, ldto, _ulam,
  { {0x5b15005e, 0x62980006, 0x78bb0c67, 0x00000000}},  // [1290] емат, _kavo, _rouv,
  { {0x78bb0c68, 0x6abc018e, 0x62980161, 0x00000000}},  //   _souv, _corf, _javo,
  { {0x25de001c, 0x78bb0c69, 0x78a90059, 0x00000000}},  //   _केली_, _pouv, _pnev,
  { {0x62980198, 0x7d0901d5, 0x20090093, 0x00000000}},  //   _lavo, ċess, _kyai_,
  { {0x6abc02cc, 0x672801aa, 0x7f4d0066, 0x00000000}},  //   _forf, _bidj, _jwaq,
  { {0x6abc018e, 0x21290022, 0x66cf0056, 0x00000000}},  //   _gorf, _liah_, _søkb,
  { {0xd5b106dd, 0x629a0009, 0x78bb0068, 0x00000000}},  //   افع_, ddto, _touv,
  { {0x273b000d, 0x629a09d0, 0xb9250025, 0x00000000}},  //   _până_, edto, _أفري,
  { {0x63a20207, 0x6593005f, 0x69c50010, 0x00000000}},  //   _cron, _məhə, lyhe,
  { {0x62980207, 0x7dee0010, 0x3f4d0089, 0x00000000}},  //   _cavo, nősé, džu_,
  { {0x6298010f, 0x69c50039, 0x20090085, 0x00000000}},  //   _davo, nyhe, _ayai_,
  { {0xf9da007b, 0x0ef8013d, 0x6593006b, 0x00000000}},  //   פֿיל, ंक्स_, _nəhə,
  { {0x63a20100, 0x21290093, 0x00000000, 0x00000000}},  //   _gron, _diah_,   ,
  { {0xe3b00123, 0x62980006, 0x248d0145, 0x00000000}},  //   _خرم_, _gavo, leem_,
  { {0xdd920355, 0x2ee10146, 0x00000000, 0x00000000}},  //   دوز_, _dmhf_,   ,
  { {0x248d0343, 0x6593006b, 0x91fc0089, 0x00000000}},  //   neem_, _cəhə, rgāt,
  { {0xc4d20476, 0x6abc0211, 0x63a2013f, 0x00000000}},  // [12a0] אגן_, _porf, _xron,
  { {0x248d0066, 0x09c40044, 0x629800f6, 0x00000000}},  //   heem_, _এইবা, _xavo,
  { {0xa84a0025, 0x6abc010f, 0x91fc0089, 0x00000000}},  //   كلام_, _vorf, lgār,
  { {0x67280107, 0xa2a10316, 0x212902d4, 0x00000000}},  //   _sidj, _कोस्, _xiah_,
  { {0x66e601fb, 0x248d0c6a, 0x6abc06d6, 0x00000000}},  //   нода, deem_, _torf,
  { {0x248d012d, 0x69c50c6b, 0x6593006b, 0x00000000}},  //   eeem_, byhe, _zəhə,
  { {0x67280c6c, 0x69c10c6d, 0x00000000, 0x00000000}},  //   _vidj, _ülep,   ,
  { {0x6298028c, 0x67280093, 0x62830133, 0x00000000}},  //   _savo, _widj, _abno,
  { {0x62980c6e, 0xe3b2006d, 0xa6860c6f, 0x00000000}},  //   _pavo, ارع_, _плад,
  { {0x21290c70, 0x00000000, 0x00000000, 0x00000000}},  //   _siah_,   ,   ,
  { {0x63a200ab, 0x629a00ea, 0x250b00a1, 0x00000000}},  //   _wron, rdto, _کرلی_,
  { {0x63a200ad, 0x3cfa013d, 0x00000000, 0x00000000}},  //   _tron, ंवों_,   ,
  { {0x09dd0201, 0x62980c71, 0xbfa8007c, 0x00000000}},  //   _मध्य, _tavo, нтре_,
  { {0x61eb0010, 0xb3e90025, 0x6593006b, 0x00000000}},  //   állá, _تعمل_, _səhə,
  { {0xe29b007b, 0x7ae500ca, 0xe2970545, 0x00000000}},  //   _זשור, viht, _чај_,
  { {0x7f4d002b, 0xb05b00b0, 0x2f160190, 0x00000000}},  //   _twaq, kkäi, væge_,
  { {0x7dee0047, 0x3a750364, 0x2d9e0c72, 0x00000000}},  // [12b0] tősé, клар, åter_,
  { {0x69110c73, 0x69c50023, 0x63bd0637, 0x00000000}},  //   gåen, tyhe, øsni,
  { {0x1df9007c, 0x7ae5014a, 0x20c200fa, 0x00000000}},  //   _цены_, riht, _góis_,
  { {0xf7710137, 0xa9070084, 0x69c501d6, 0x00000000}},  //   لات_, ربان, ryhe,
  { {0x7d0d006c, 0x257a0007, 0xafdb0056, 0x00000000}},  //   mlas, eël_, dbøk,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d5a0363, 0x1af40c74, 0x257a0065, 0x00000000}},  //   štav, _спря, gël_,
  { {0x7d0d0c75, 0xafdb00ea, 0x00000000, 0x00000000}},  //   nlas, gbøk,   ,
  { {0x0735081e, 0x248d0abf, 0x8af0006b, 0x00000000}},  //   _резю, reem_, ksəl,
  { {0x7d0d06b8, 0xc3c80025, 0x257a0065, 0x00000000}},  //   hlas, عظيم_, bël_,
  { {0x3de10055, 0x8602007a, 0x63ad0c76, 0x00000000}},  //   _মুসল, _پژوه, _šand,
  { {0xa2a102fb, 0x349501fc, 0xf992009b, 0x00000000}},  //   _कोर्, _јадр, ברט_,
  { {0xe28e012b, 0x7d0d0c77, 0x64490181, 0x00000000}},  //   _ка_, dlas, mbei,
  { {0x644901e5, 0x20c20051, 0x7d0d0c78, 0x00000000}},  //   lbei, _cóir_, elas,
  { {0x628101e5, 0x442f00e0, 0x64490c79, 0x00000000}},  //   mflo, _kgg_, obei,
  { {0x7d0d01cd, 0x64490c7a, 0x753c0010, 0x00000000}},  //   glas, nbei, _érze,
  { {0x69110c7b, 0x1d0700ed, 0x60dd0c7c, 0x00000000}},  // [12c0] tåen, тети_, ërme,
  { {0x6281002b, 0x4a43072b, 0x7d0d006c, 0x00000000}},  //   nflo, инув, alas,
  { {0x7d0d0c7d, 0x64490635, 0x00000000, 0x00000000}},  //   blas, kbei,   ,
  { {0x6d5c0240, 0x8af0006b, 0x00000000, 0x00000000}},  //   msra, msəm,   ,
  { {0xd7ef0054, 0x7d04089e, 0xb86500a1, 0x00000000}},  //   يكم_, mois, طانو,
  { {0xa2a101f5, 0x7d0400b0, 0x442f0197, 0x00000000}},  //   _कोल्, lois, _agg_,
  { {0x6d5c0039, 0x1ae3022a, 0x09e6007c, 0x00000000}},  //   nsra, _торм, _ровн,
  { {0x7d040c7e, 0x443d0022, 0x22490107, 0x00000000}},  //   nois, _cfw_, _đaka_,
  { {0x613e0089, 0x628100f8, 0x64a301fc, 0x00000000}},  //   _mīle, fflo, рања,
  { {0x02a601fb, 0x7d0d014a, 0x7d040c7f, 0x00000000}},  //   трим, zlas, hois,
  { {0x7d04021e, 0xf484007a, 0x443d0c80, 0x00000000}},  //   kois, _ماشی, _ffw_,
  { {0x6d5c00ea, 0x044602dc, 0x7d0400b0, 0x00000000}},  //   dsra, _редн, jois,
  { {0x7d0400b0, 0xc0e4007e, 0xfbdf01c3, 0x00000000}},  //   dois, роўк, _leêr_,
  { {0x7658000b, 0x00000000, 0x00000000, 0x00000000}},  //   navy,   ,   ,
  { {0x2fcd0119, 0x7d0d0c75, 0x6d5c00ea, 0x00000000}},  //   šeg_, tlas, gsra,
  { {0x48bd0044, 0x656a0051, 0x7d040c81, 0x00000000}},  //   _আগ্র, irfh, gois,
  { {0x7d0d010f, 0x20c20051, 0xe7bd0044, 0x00000000}},  // [12d0] rlas, _tóir_, _অধ্য,
  { {0x7d0d006c, 0x76580c82, 0xf09f00d4, 0x00000000}},  //   slas, javy, ldà_,
  { {0x7d0d0292, 0x6f020051, 0x7d040c83, 0x00000000}},  //   plas, _íoca, bois,
  { {0x658a006b, 0x6d470066, 0x48e10044, 0x00000000}},  //   _məhd, mpja, যক্র,
  { {0x973500e9, 0x62810016, 0x6d5a0c84, 0x00000000}},  //   اکرا, yflo, štat,
  { {0xfc3f013e, 0x00000000, 0x00000000, 0x00000000}},  //   _sníh_,   ,   ,
  { {0xceb4012f, 0x940d006b, 0x443d00d9, 0x00000000}},  //   ייס_, ənən_, _pfw_,
  { {0x2619013d, 0x8a1801ab, 0x00000000, 0x00000000}},  //   येगी_, _росс_,   ,
  { {0x64490c85, 0x27e0002a, 0xf794008b, 0x00000000}},  //   rbei, úint_, _катэ,
  { {0xf09f0129, 0x64490c86, 0x7d0400e7, 0x00000000}},  //   edà_, sbei, zois,
  { {0x6281000c, 0x7d0400e7, 0x658a006b, 0x00000000}},  //   rflo, yois, _cəhd,
  { {0x6281000c, 0x20c20051, 0xe7b70061, 0x00000000}},  //   sflo, _cóip_, _आपाप,
  { {0x6e29005f, 0x273901aa, 0x7d040c7e, 0x00000000}},  //   əmbə, _jèn_, vois,
  { {0x249f0c87, 0x6d5c04b2, 0xe29600ed, 0x00000000}},  //   ldum_, tsra, _баш_,
  { {0x7d04021e, 0x69110c88, 0xa0a60c89, 0x00000000}},  //   tois, tåel, _байд,
  { {0x249f009f, 0x724200a1, 0x6d5c0089, 0x00000000}},  //   ndum_, _پھیل, rsra,
  { {0x7d0400b0, 0x237f0036, 0x8fa6007e, 0x00000000}},  // [12e0] rois, ntuj_, _сапе,
  { {0xda650054, 0x8f9b00b3, 0x63a40c8a, 0x00000000}},  //   لامي, _טיפי, _šink,
  { {0x7d040c8b, 0xbebb0023, 0x00000000, 0x00000000}},  //   pois, yqëz,   ,
  { {0x237f0c8c, 0x27390082, 0x00000000, 0x00000000}},  //   ktuj_, _bèn_,   ,
  { {0x27e00009, 0x249f0c8d, 0x76580c8e, 0x00000000}},  //   àin_, ddum_, tavy,
  { {0xb8cb0754, 0x3b0a0057, 0x2ca00004, 0x00000000}},  //   _को_, _чего_, ldid_,
  { {0x2ca0006c, 0x00000000, 0x00000000, 0x00000000}},  //   odid_,   ,   ,
  { {0x2ca00004, 0x765807d3, 0x8af0006b, 0x00000000}},  //   ndid_, savy, ksək,
  { {0xc676025a, 0xe646081c, 0x66760318, 0x00000000}},  //   _مطاب, _безп, _مدار,
  { {0x4b7b0049, 0x63ad0161, 0x5b7b0049, 0x00000000}},  //   עטיג, _šanc, עריא,
  { {0xdb060023, 0x5ab70049, 0x00000000, 0x00000000}},  //   _arkë, אליע_,   ,
  { {0x2ca00022, 0x00000000, 0x00000000, 0x00000000}},  //   jdid_,   ,   ,
  { {0xf09f0129, 0x2d9a0c8f, 0x2ca00c90, 0x00000000}},  //   rdà_, _aspe_, ddid_,
  { {0x11d6002c, 0x539b0104, 0x66cf00ea, 0x00000000}},  //   _متعد, _ניוו, _nøkl,
  { {0x7f440919, 0x56370049, 0xfce90025, 0x00000000}},  //   _etiq, ראלע_, نفسي_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4a550072, 0xba550098, 0x6d470c91, 0x00000000}},  // [12f0] икас, ивај, spja,
  { {0xb05b0c92, 0x658a006b, 0x27390c93, 0x00000000}},  //   rkäu, _məhb, _rèn_,
  { {0x6d5a09fc, 0x273901aa, 0x249f005a, 0x00000000}},  //   štar, _sèn_, ydum_,
  { {0x6d45014a, 0x237f0036, 0x5c0702dc, 0x00000000}},  //   _itha, ytuj_, _бяга,
  { {0x0a6b01fc, 0xb05b00b0, 0x00000000, 0x00000000}},  //   _први_, lkäs,   ,
  { {0xe736005e, 0x00000000, 0x00000000, 0x00000000}},  //   шеш_,   ,   ,
  { {0xa5640025, 0xb05b0c94, 0xb9250025, 0x00000000}},  //   مدين, nkäs, _نفسي,
  { {0x38600051, 0x6d4501c3, 0xe79502fd, 0x00000000}},  //   óirt_, _mtha, _پارک,
  { {0x249f014a, 0x00000000, 0x00000000, 0x00000000}},  //   rdum_,   ,   ,
  { {0x6d450051, 0x237f0036, 0x68eb0c95, 0x00000000}},  //   _otha, rtuj_, ligd,
  { {0x25b90076, 0x7f4400f6, 0x237f00b4, 0x00000000}},  //   _جهاد_, _stiq, stuj_,
  { {0x68eb0250, 0x60260c96, 0x00000000, 0x00000000}},  //   nigd, идна,   ,
  { {0x6d450c97, 0x443f0142, 0x60dd0065, 0x00000000}},  //   _atha, mcu_, ërma,
  { {0x443f0c98, 0x00000000, 0x00000000, 0x00000000}},  //   lcu_,   ,   ,
  { {0xa01b0047, 0xddc300ed, 0x1c3a007e, 0x00000000}},  //   lföl, обри, вязь_,
  { {0x645b01a2, 0x00000000, 0x00000000, 0x00000000}},  //   naui,   ,   ,
  { {0x2ca0006c, 0x68eb00c1, 0xef1a007c, 0x00000000}},  // [1300] rdid_, digd, _ими_,
  { {0xc33200b3, 0x6723012d, 0xb05b010e, 0x00000000}},  //   קוב_, jmnj, skät,
  { {0x2d9a00ca, 0x00000000, 0x00000000, 0x00000000}},  //   _uspe_,   ,   ,
  { {0x200c005f, 0xa967017f, 0x270e02d2, 0x00000000}},  //   ədir_, рица_, ित्र_,
  { {0x2b4901f3, 0x443f0142, 0xb05b04ce, 0x00000000}},  //   cpac_, dcu_, sjäg,
  { {0x658a005f, 0x236d0465, 0x316b0036, 0x00000000}},  //   _rəhb, drej_, ńczy_,
  { {0x60d60161, 0x00000000, 0x00000000, 0x00000000}},  //   _olym,   ,   ,
  { {0x399b061e, 0xe3e70044, 0x60c40c99, 0x00000000}},  //   _בילד, _পড়ব, _noim,
  { {0xf74301fb, 0x7581009e, 0x00000000, 0x00000000}},  //   _мето, _ہیوم,   ,
  { {0x78a2000d, 0xdce70036, 0x00000000, 0x00000000}},  //   ldov, mują,   ,
  { {0x3a37019b, 0x6f07037e, 0xaa370049, 0x00000000}},  //   ירים_, vojc, יטיק_,
  { {0x60c40c9a, 0x78a20209, 0x236d0a32, 0x00000000}},  //   _coim, ndov, brej_,
  { {0x60c40c9b, 0x77f40309, 0x6d450066, 0x00000000}},  //   _doim, _अशोक_, _stha,
  { {0x0eeb004c, 0xb05b00b0, 0x00000000, 0x00000000}},  //   тьми_, tkäs,   ,
  { {0xdef8008b, 0xd2f8026c, 0xeda40088, 0x00000000}},  //   рыя_, _لکھا_, ошто,
  { {0xdce70036, 0x60d60c9c, 0x8af0006b, 0x00000000}},  //   kują, _glym, mrəy,
  { {0x78a20197, 0x00000000, 0x00000000, 0x00000000}},  // [1310] ddov,   ,   ,
  { {0x6e950054, 0xdce70036, 0x00000000, 0x00000000}},  //   _الدا, dują,   ,
  { {0x6d450c9d, 0x68eb0328, 0x2b49009d, 0x00000000}},  //   _utha, tigd, spac_,
  { {0x78a002ad, 0x00000000, 0x00000000, 0x00000000}},  //   _camv,   ,   ,
  { {0x2d8300b5, 0x443f0466, 0x36690256, 0x00000000}},  //   ltje_, vcu_, гало_,
  { {0x98bc0089, 0x236d012d, 0x68eb0bed, 0x00000000}},  //   īvā_, vrej_, sigd,
  { {0x2d830c9e, 0x443f00ca, 0x645b00ea, 0x00000000}},  //   ntje_, tcu_, taui,
  { {0xfdf80c9f, 0x66cf0030, 0x443f0ca0, 0x00000000}},  //   ימוש_, _køkk, ucu_,
  { {0x60c4002a, 0x443f0ca1, 0x68e903c7, 0x00000000}},  //   _roim, rcu_, _imed,
  { {0x443f000d, 0x236d0ca2, 0xa01b0ca3, 0x00000000}},  //   scu_, rrej_, rföl,
  { {0x60d60ca4, 0x2d830ca5, 0x66cf0030, 0x00000000}},  //   _plym, jtje_, _løkk,
  { {0x236d01d9, 0xfd1f0011, 0xa01b0039, 0x00000000}},  //   prej_, _nhì_, pföl,
  { {0x60c4021e, 0x26c505d2, 0x2d8300bb, 0x00000000}},  //   _voim, _kolo_, etje_,
  { {0x68fb0213, 0x78a20161, 0xc332009b, 0x00000000}},  //   _ljud, zdov, _זוג_,
  { {0x60c40368, 0x645904be, 0x68e90039, 0x00000000}},  //   _toim, _kewi, _omed,
  { {0x26c5011c, 0xcd2a0ca6, 0xb05b0039, 0x00000000}},  //   _lolo_, ужбе_, skär,
  { {0x63bb049a, 0x2d8300b5, 0xfc3f00f6, 0x00000000}},  // [1320] nxun, atje_, _anís_,
  { {0x64590675, 0x68fb0ca7, 0xd05d005f, 0x00000000}},  //   _lewi, _ajud, disə,
  { {0x2722001d, 0x68fb0039, 0xdb040ca8, 0x00000000}},  //   _hưng_, _bjud, nvié,
  { {0x6459018e, 0x291f0ca9, 0x63ab0caa, 0x00000000}},  //   _newi, _chua_, _orgn,
  { {0x78a20b30, 0x96ea0cab, 0x26c50027, 0x00000000}},  //   rdov, лька_, _bolo_,
  { {0x68e900f8, 0x26c50325, 0xdce70036, 0x00000000}},  //   _emed, _colo_, rują,
  { {0x64590cac, 0x6b840a35, 0x98a60cad, 0x00000000}},  //   _bewi, ltig, _ливе,
  { {0xdce70036, 0xd497007c, 0x26c50026, 0x00000000}},  //   pują, брь_, _eolo_,
  { {0x6b84027b, 0x6459018e, 0xd2500054, 0x00000000}},  //   ntig, _dewi, ونة_,
  { {0x6b84010f, 0x68e900ca, 0x291f00fa, 0x00000000}},  //   itig, _zmed, _zhua_,
  { {0x6b84010f, 0x3abb0097, 0x60dd0023, 0x00000000}},  //   htig, אמינ, ërmo,
  { {0x645909d6, 0x6b84067e, 0x2120004a, 0x00000000}},  //   _gewi, ktig, _chih_,
  { {0xdfd8005e, 0x765a0037, 0x27220011, 0x00000000}},  //   бър_, _kety, _cưng_,
  { {0xd9fa0164, 0x27220011, 0x8c000044, 0x00000000}},  //   ्थात_, _dưng_, ্ধান_,
  { {0x6b840112, 0xfd1f0082, 0x765a0cae, 0x00000000}},  //   etig, _phì_, _mety,
  { {0x2d8300b5, 0x3ea100e0, 0xed4e00a1, 0x00000000}},  //   rtje_, _waht_, کھی_,
  { {0x6b840caf, 0x3ea1002b, 0x2d830cb0, 0x00000000}},  // [1330] gtig, _taht_, stje_,
  { {0x68e90cb1, 0x433b0049, 0xf41a0044, 0x00000000}},  //   _smed, טעמב, _ডলার_,
  { {0xfd1f00ad, 0x753a001f, 0x99990364, 0x00000000}},  //   _thì_, _nutz, ркет_,
  { {0x26c50555, 0x628800ea, 0xdced007f, 0x00000000}},  //   _solo_, hfdo, _įkėl,
  { {0x765a0cb2, 0x6c7a007b, 0x6604005d, 0x00000000}},  //   _bety, _דארפ, şikl,
  { {0x35c90cb3, 0x765a0cb4, 0x64590133, 0x00000000}},  //   игло_, _cety, _sewi,
  { {0x765a008d, 0x291f0cb5, 0xd05d005f, 0x00000000}},  //   _dety, _thua_, sisə,
  { {0xf9920104, 0x68e90cb6, 0x9345009a, 0x00000000}},  //   _קרן_, _umed, оние,
  { {0xdcfc0089, 0x03a50cb7, 0x26c5007f, 0x00000000}},  //   ntrā, ципо, _tolo_,
  { {0xdddc0047, 0x21200cb8, 0x765a0cb9, 0x00000000}},  //   zerű, _shih_, _gety,
  { {0x27220082, 0xb05b0cba, 0x00000000, 0x00000000}},  //   _sưng_, tkäp,   ,
  { {0x297a0049, 0x79850016, 0x7b10010f, 0x00000000}},  //   סטרא, ithw, läut,
  { {0xa3bb04e8, 0xbf050061, 0x94050014, 0x00000000}},  //   _حاضر_, ळवून_, _بوشه,
  { {0x63a90cbb, 0x161d006e, 0x673b00e7, 0x00000000}},  //   mven, _फरार_, _muuj,
  { {0x63a9001e, 0x6da30265, 0x2120012d, 0x00000000}},  //   lven, мира, _thih_,
  { {0x27220082, 0x63a90026, 0x60dd01a2, 0x00000000}},  //   _tưng_, oven, chsm,
  { {0xab660cbc, 0x79850016, 0x6b8401a2, 0x00000000}},  // [1340] ювал, ethw, utig,
  { {0x6b840cbd, 0x6023007e, 0x63a90ad6, 0x00000000}},  //   rtig, _ідэа, iven,
  { {0x765a0133, 0x00000000, 0x00000000, 0x00000000}},  //   _rety,   ,   ,
  { {0x63a90292, 0x765a0cbe, 0x6d4e0146, 0x00000000}},  //   kven, _sety, mpba,
  { {0x765a01aa, 0x63a900b5, 0x7cf301d5, 0x00000000}},  //   _pety, jven, għru,
  { {0x63a90cbf, 0x7d1600b0, 0x645d000c, 0x00000000}},  //   dven, llys, ðsin,
  { {0xd54701f9, 0xa967007c, 0x63a90cc0, 0x00000000}},  //   опје_, _мира_, even,
  { {0x387f0051, 0x7d160190, 0x94aa01a4, 0x00000000}},  //   _gcur_, nlys, ртка_,
  { {0x63a90cc1, 0x60ce0066, 0x00000000, 0x00000000}},  //   gven, _ċamp,   ,
  { {0x7d160016, 0x6f020048, 0x8af0006b, 0x00000000}},  //   hlys, _íoch, msəs,
  { {0x63a90cc2, 0x7d160cc3, 0x8af0013f, 0x00000000}},  //   aven, klys, lsəs,
  { {0x63a9081d, 0x00000000, 0x00000000, 0x00000000}},  //   bven,   ,   ,
  { {0x63a90cc4, 0x7d160cc5, 0x4ea70783, 0x00000000}},  //   cven, dlys, орва,
  { {0xe297005e, 0x7d1601c3, 0x00000000, 0x00000000}},  //   _мач_, elys,   ,
  { {0x7b10010f, 0x752201c3, 0x3ceb00e2, 0x00000000}},  //   häus, _khoz, аќам_,
  { {0xd5a4009c, 0x69c3006c, 0xdcee0089, 0x00000000}},  //   _یہ_, änem, tubā,
  { {0x28ab007d, 0x2d9e06ec, 0x6d4e01c3, 0x00000000}},  // [1350] _घोषि, æter_, apba,
  { {0x7e99025a, 0x6d48013e, 0x00000000, 0x00000000}},  //   _اندر_, ídac,   ,
  { {0xdcfc001e, 0x63a9016c, 0x39580016, 0x00000000}},  //   strā, zven, _cwrs_,
  { {0x79850cc6, 0x23660119, 0x6ee90521, 0x00000000}},  //   rthw, _ovoj_, džbi,
  { {0xba770379, 0x7d0d001a, 0x66dd000a, 0x00000000}},  //   _واست, moas, _lèke,
  { {0x60dd0065, 0x7d0d0cc7, 0x63a90cc8, 0x00000000}},  //   ërmj, loas, vven,
  { {0x39580016, 0x00000000, 0x00000000, 0x00000000}},  //   _gwrs_,   ,   ,
  { {0x63a90a0f, 0x7d0d0cc9, 0x2ec80164, 0x00000000}},  //   tven, noas, _रक्त,
  { {0x3a380061, 0x63a900f4, 0xf3f90035, 0x00000000}},  //   _ygrp_, uven, faţa_,
  { {0x2b4b0082, 0x00000000, 0x00000000, 0x00000000}},  //   _mtcc_,   ,   ,
  { {0x7d0d00b0, 0xa0a600e2, 0x00000000, 0x00000000}},  //   koas, панд,   ,
  { {0x210602f4, 0x63a90190, 0x7d0d0035, 0x00000000}},  //   रवेश_, pven, joas,
  { {0x0876007b, 0xe4560049, 0xdfd2006d, 0x00000000}},  //   הערט_, _זינט_, ريس_,
  { {0x75290cca, 0x00000000, 0x00000000, 0x00000000}},  //   lmez,   ,   ,
  { {0x412a02dc, 0x00000000, 0x00000000, 0x00000000}},  //   _локо_,   ,   ,
  { {0x0b460364, 0x201e005f, 0x2b590066, 0x00000000}},  //   знан, ətin_, _bwsc_,
  { {0x7d160193, 0xfc0300e2, 0x394a0022, 0x00000000}},  // [1360] rlys, епто, _stbs_,
  { {0x7d1601e5, 0x6d4e0ccb, 0x2bf00061, 0x00000000}},  //   slys, ppba, _घेणं_,
  { {0x7d160ccc, 0xbe3b009b, 0xf1cb0061, 0x00000000}},  //   plys, _לעית, ाहिन,
  { {0x7d0d001a, 0xc18c0049, 0x658a006b, 0x00000000}},  //   coas, שטאָ, _dəhl,
  { {0xdc37007b, 0x68e30ccd, 0x00000000, 0x00000000}},  //   _מאכט_, ënda,   ,
  { {0x66e301e1, 0x7b10010f, 0xa01b000c, 0x00000000}},  //   ноча, räus, sgög,
  { {0x8af0005f, 0x23660cce, 0xceb3009b, 0x00000000}},  //   ssəs, _svoj_, תיו_,
  { {0x68130036, 0xd37a0478, 0x225c0095, 0x00000000}},  //   _będą, бчо_, _sevk_,
  { {0x2005014a, 0x09c40044, 0x225c0087, 0x00000000}},  //   ğlik_, _এইটা, _pevk_,
  { {0xe5a602dc, 0x2005026d, 0x7d0d0ccf, 0x00000000}},  //   _низи, şlik_, zoas,
  { {0x74160123, 0x7d0d00e7, 0x00000000, 0x00000000}},  //   _کوشا, yoas,   ,
  { {0x69370166, 0x09f7034e, 0x23660465, 0x00000000}},  //   _kćer, למים_, _tvoj_,
  { {0xa3cd007d, 0xdfd802dc, 0x00000000, 0x00000000}},  //   रहण_, пър_,   ,
  { {0x63a20052, 0x00000000, 0x00000000, 0x00000000}},  //   _ison,   ,   ,
  { {0x7d0d001a, 0x629a0cd0, 0x00000000, 0x00000000}},  //   toas, meto,   ,
  { {0x7aee00b5, 0x629a066d, 0x51fb009b, 0x00000000}},  //   _ambt, leto, _להוצ,
  { {0x7d0d001a, 0xfc3f004a, 0x00000000, 0x00000000}},  // [1370] roas, _caía_,   ,
  { {0x63a20cd1, 0x801805f3, 0x7f4d00c4, 0x00000000}},  //   _mson, _عزيز_, _itaq,
  { {0x7d0d0adb, 0x2b4b00d2, 0x75290023, 0x00000000}},  //   poas, _wtcc_, ymez,
  { {0x3ce00cd2, 0x63a20129, 0x57f507e1, 0x00000000}},  //   chiv_, _oson, мпет,
  { {0x6d4a008d, 0x629a0209, 0xdcfc001a, 0x00000000}},  //   _çfar, keto, stră,
  { {0x629a0cd3, 0x658a005f, 0x2ca90cd4, 0x00000000}},  //   jeto, _təhl, ldad_,
  { {0x63a20058, 0x6592003b, 0x7f4d0066, 0x00000000}},  //   _ason, вају, _ltaq,
  { {0x2ca90c1b, 0x7f4d006b, 0xddde000a, 0x00000000}},  //   ndad_, _otaq, _depň,
  { {0x752901d5, 0x290f04cb, 0xb05b0039, 0x00000000}},  //   rmez, moga_, tjän,
  { {0x290f02db, 0x658a006b, 0xe3ca004a, 0x00000000}},  //   loga_, _zəhm, _soñó_,
  { {0x7f4d0489, 0x93ca00a1, 0x63a20197, 0x00000000}},  //   _ataq, مایہ_, _eson,
  { {0x290f016e, 0x6aa700ca, 0x63a204a5, 0x00000000}},  //   noga_, _lajf, _fson,
  { {0x2ca900f8, 0x629a0cd5, 0x00000000, 0x00000000}},  //   ddad_, beto,   ,
  { {0x290f00e7, 0x2ca9004a, 0x853c0006, 0x00000000}},  //   hoga_, edad_, _grės,
  { {0x386d08ba, 0x290f0825, 0x6f0e0428, 0x00000000}},  //   _oder_, koga_, robc,
  { {0x386d0065, 0xb5fc0066, 0x00000000, 0x00000000}},  //   _nder_, _weġg,   ,
  { {0x658a006b, 0x63a20026, 0x394d0059, 0x00000000}},  // [1380] _rəhm, _xson, _česa_,
  { {0x658a006b, 0xb05b0510, 0x7d090cd6, 0x00000000}},  //   _səhm, hjäl, česa,
  { {0x888601fc, 0x6283004a, 0x290f00f8, 0x00000000}},  //   длеж, _mcno, foga_,
  { {0x290f016e, 0x386d0190, 0xddde000a, 0x00000000}},  //   goga_, _cder_, _repň,
  { {0x629a0cd7, 0x872a007e, 0x60dd0023, 0x00000000}},  //   yeto, оўка_, ërmi,
  { {0x473301fb, 0x386d0cd8, 0x00000000, 0x00000000}},  //   вніс, _eder_,   ,
  { {0x69d80030, 0x248d005b, 0x290f0213, 0x00000000}},  //   øved, ffem_, boga_,
  { {0x63a2004a, 0x66cf0056, 0x3eba0085, 0x00000000}},  //   _pson, _søkt, _lnpt_,
  { {0xd90d0cd9, 0x629a0cda, 0xb6cb00a1, 0x00000000}},  //   _این_, teto, _ڈالے_,
  { {0xb6cb026c, 0x628300f6, 0x00000000, 0x00000000}},  //   _والے_, _ccno,   ,
  { {0x658a005f, 0x629a02d5, 0x02a3008b, 0x00000000}},  //   _məhk, reto, трым,
  { {0x63a20058, 0x75490010, 0x629a0213, 0x00000000}},  //   _tson, őszö, seto,
  { {0x044300e3, 0x26cc024f, 0x937703ab, 0x00000000}},  //   _речн, _kodo_, _قصور_,
  { {0xe1ef06c6, 0x7ce30004, 0x2cb90cdb, 0x00000000}},  //   اسی_, _kõrg, _snsd_,
  { {0x26cc0cdc, 0x9f3401fb, 0xdc3a011f, 0x00000000}},  //   _modo_, тері, _açık,
  { {0x26cc0cdd, 0x2ca9004a, 0x00000000, 0x00000000}},  //   _lodo_, udad_,   ,
  { {0x2ca90219, 0x68e20059, 0x290f016e, 0x00000000}},  // [1390] rdad_, dhod, voga_,
  { {0x26cc0555, 0xcf270464, 0x60cd0082, 0x00000000}},  //   _nodo_, _تربي, _hoam,
  { {0x290f0cde, 0x7ce3006c, 0x68e30ccd, 0x00000000}},  //   toga_, _nõrg, ëndo,
  { {0x26de0cdf, 0x2fe4014a, 0xf8690025, 0x00000000}},  //   _alto_, _örgü_, سمتي_,
  { {0x26cc01d9, 0x6aa70c8a, 0x60cd0ce0, 0x00000000}},  //   _bodo_, _tajf, _moam,
  { {0x26cc008e, 0x6f020051, 0xdb060190, 0x00000000}},  //   _codo_, _íoct, _arkæ,
  { {0x04450ce1, 0x6283000a, 0x00000000, 0x00000000}},  //   нейн, _rcno,   ,
  { {0x68e20ce2, 0x27e6014a, 0x2f16000c, 0x00000000}},  //   chod, bzon_, lægt_,
  { {0xe3b10426, 0x248d0466, 0x92f50451, 0x00000000}},  //   ارب_, rfem_, ечні,
  { {0x26cc0ce3, 0x888100a1, 0x00000000, 0x00000000}},  //   _godo_, _شیڈن,   ,
  { {0x78a9006c, 0xcb12009b, 0x78bb01c3, 0x00000000}},  //   _kaev, רלי_, _knuv,
  { {0x26c70ce4, 0xe454008b, 0x98b8001e, 0x00000000}},  //   ljno_, _акцы, _kurā_,
  { {0x952204e1, 0x60cd0ce5, 0xb05b00b0, 0x00000000}},  //   _حکوم, _doam, nkäy,
  { {0x68e20428, 0x78a9006c, 0x25a50022, 0x00000000}},  //   zhod, _laev, _ksll_,
  { {0x60cd0ce6, 0x7d090ab8, 0x3eba0011, 0x00000000}},  //   _foam, česn, _vnpt_,
  { {0xdca3013b, 0x7693005d, 0x64490335, 0x00000000}},  //   ласи, lıyı, ncei,
  { {0xac070264, 0x6836011f, 0x68e206b8, 0x00000000}},  // [13a0] ента_, _müdü, vhod,
  { {0x09e6005c, 0x76930180, 0x00000000, 0x00000000}},  //   нозн, nıyı,   ,
  { {0xd910026c, 0xae5b00b6, 0xe93a0076, 0x00000000}},  //   لیس_, _מכיר, سسات_,
  { {0x38600ce7, 0xa01b0073, 0x68e200b9, 0x00000000}},  //   úir_, mför, uhod,
  { {0xa01b03a2, 0xcc3b0049, 0x68e20b4a, 0x00000000}},  //   lför, _מעכט, rhod,
  { {0x68e20107, 0x644b0030, 0x27e60032, 0x00000000}},  //   shod, _afgi, rzon_,
  { {0x68e2037e, 0xa01b0ce8, 0x26cc0059, 0x00000000}},  //   phod, nför, _vodo_,
  { {0x7ce3006c, 0xd37a00ed, 0x693401b2, 0x00000000}},  //   _võrg, пчо_, _شکار,
  { {0x26cc0219, 0x60cd0253, 0x29040093, 0x00000000}},  //   _todo_, _roam, _ijma_,
  { {0x026a007c, 0xa01b0039, 0x60cd012d, 0x00000000}},  //   чший_, kför, _soam,
  { {0xb5fc0066, 0x00000000, 0x00000000, 0x00000000}},  //   _weġb,   ,   ,
  { {0xa01b0039, 0x73e6007c, 0x644900d4, 0x00000000}},  //   dför, _поез, ccei,
  { {0xddcc00b9, 0x658a013f, 0x673a00d9, 0x00000000}},  //   _čišt, _səhh, _kitj,
  { {0x661a0ce9, 0x673a0066, 0x00000000, 0x00000000}},  //   _kytk, _jitj,   ,
  { {0x673a04bd, 0xfcd900a1, 0x60cd001a, 0x00000000}},  //   _mitj, وارڈ_, _toam,
  { {0x673a0ba0, 0x658a013f, 0x00000000, 0x00000000}},  //   _litj, _vəhh,   ,
  { {0x317e00e5, 0x2f160190, 0x5b15004d, 0x00000000}},  // [13b0] lutz_, tægt_, вмат,
  { {0xff500025, 0x00000000, 0x00000000, 0x00000000}},  //   _اخي_,   ,   ,
  { {0x317e0cea, 0x00000000, 0x00000000, 0x00000000}},  //   nutz_,   ,   ,
  { {0x6ee20142, 0x00000000, 0x00000000, 0x00000000}},  //   _vôbe,   ,   ,
  { {0x9814008b, 0x07a504f9, 0x317e010f, 0x00000000}},  //   льшч, талн, hutz_,
  { {0xcf94007b, 0x443d0270, 0xbdf800a2, 0x00000000}},  //   רטס_, _sgw_, _آریا_,
  { {0x6b8d04d7, 0xceb40104, 0x673a023a, 0x00000000}},  //   ltag, טיס_, _ditj,
  { {0xdb060a5d, 0xe3b90ceb, 0x673a00bb, 0x00000000}},  //   _erkä, дби_, _eitj,
  { {0x47940070, 0x64490335, 0x62810462, 0x00000000}},  //   _مجلس, rcei, tglo,
  { {0x24860009, 0xd90d00a1, 0x21290cec, 0x00000000}},  //   _ecom_, _ایچ_, _ahah_,
  { {0x057400a2, 0x69c50023, 0x00000000, 0x00000000}},  //   _ماند, nxhe,   ,
  { {0x62810ced, 0x3f6a0cee, 0xa01b0039, 0x00000000}},  //   sglo, мимо_, vför,
  { {0x6f1c001c, 0xa85600b6, 0x660401df, 0x00000000}},  //   tlrc, כירה_, şikt,
  { {0x658a005f, 0xe1f1007a, 0x6b8d0018, 0x00000000}},  //   _səhi, _پست_, dtag,
  { {0x8d63098c, 0x92580025, 0x6b8d01c3, 0x00000000}},  //   ивре, _أشهر_, etag,
  { {0xa01b03ed, 0x00000000, 0x00000000, 0x00000000}},  //   rför,   ,   ,
  { {0xa01b03a2, 0xcb67026b, 0x6b8d011c, 0x00000000}},  // [13c0] sför, кате_, gtag,
  { {0xa01b00f8, 0x249f0022, 0x00000000, 0x00000000}},  //   pför, heum_,   ,
  { {0xa01b000c, 0x673a00bb, 0xef1f0010, 0x00000000}},  //   ngön, _ritj, ztük_,
  { {0x673a0cef, 0x080a0014, 0x6b8d0c4c, 0x00000000}},  //   _sitj, وزشي_, btag,
  { {0x2ca0006c, 0x673a0129, 0x98b800e5, 0x00000000}},  //   meid_, _pitj, _aură_,
  { {0x2ca00cf0, 0x7c260089, 0xda65006d, 0x00000000}},  //   leid_, _izkr, _مافي,
  { {0x44200006, 0x888402fd, 0x673a0cf1, 0x00000000}},  //   _ši_, _میان, _vitj,
  { {0x4420001d, 0x2ca0006c, 0xef1f0010, 0x00000000}},  //   _ơi_, neid_, ttük_,
  { {0xccf300b6, 0x2b46002a, 0x673a002b, 0x00000000}},  //   יכה_, íoch_, _titj,
  { {0x2ca0049b, 0x21290127, 0x2d9a05b7, 0x00000000}},  //   heid_, _shah_, _oppe_,
  { {0x60f90cf2, 0xc4860057, 0x2ca0095a, 0x00000000}},  //   ення_, _алек, keid_,
  { {0x6b8d0cf3, 0x249f0036, 0x64a602ea, 0x00000000}},  //   ytag, ceum_, _јада,
  { {0x2ca0006c, 0x44200011, 0x996200b9, 0x00000000}},  //   deid_, _ái_, _níže_,
  { {0x44260061, 0x2d470cf4, 0x6b8d0cf5, 0x00000000}},  //   _izo_, _põe_, vtag,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6b8d0cf6, 0x2ca00cf7, 0x00000000, 0x00000000}},  //   ttag, geid_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [13d0]   ,   ,   ,
  { {0x6b8d028c, 0xbb190054, 0x60dd021f, 0x00000000}},  //   rtag, رياض_, lksm,
  { {0x6b8d0cf8, 0x2ca00cf9, 0x249f0022, 0x00000000}},  //   stag, beid_, yeum_,
  { {0xf7710355, 0x60dd0006, 0x98ad0036, 0x00000000}},  //   مات_, nksm, _mieć_,
  { {0xb05b0cfa, 0x6d4500e7, 0x36d501ab, 0x00000000}},  //   rjäh, _huha, лодр,
  { {0x6d450cfb, 0x6f150211, 0xd6db0077, 0x00000000}},  //   _kuha, nozc, ьте_,
  { {0x298801f9, 0x6d450cfc, 0xf3f9001a, 0x00000000}},  //   _исто_, _juha, maţi_,
  { {0xf3f9001a, 0x60dd00bb, 0x63890023, 0x00000000}},  //   laţi_, jksm, _nënç,
  { {0xf49500a2, 0x42d5007e, 0xe7960167, 0x00000000}},  //   نشکد, гіну, _مالک,
  { {0xdb0402d5, 0x2fd9018e, 0x63ad0091, 0x00000000}},  //   rviç, dysg_, _šans,
  { {0x658a006b, 0x6d450110, 0x442604e7, 0x00000000}},  //   _səhv, _nuha, _ezo_,
  { {0xcea900b6, 0xf48701fc, 0x758200a1, 0x00000000}},  //   _מי_, _јужн, _ایٹم,
  { {0x645b0007, 0x2ca00cfd, 0xe2a80014, 0x00000000}},  //   mbui, veid_, راین_,
  { {0x6d45006a, 0x201e001e, 0x645b0cfe, 0x00000000}},  //   _buha, āti_, lbui,
  { {0x2ca0084c, 0xe296005e, 0x44260cff, 0x00000000}},  //   teid_, _сащ_, _zzo_,
  { {0x6d450d00, 0x645b00bb, 0x658a006b, 0x00000000}},  //   _duha, nbui, _təhv,
  { {0x2ca0095c, 0x0c260b7a, 0x6d4501ed, 0x00000000}},  // [13e0] reid_, уман, _euha,
  { {0x2ca00004, 0xf3f9001a, 0x3f8204a5, 0x00000000}},  //   seid_, gaţi_, muku_,
  { {0x3f820d01, 0x6d450061, 0x2d9a0039, 0x00000000}},  //   luku_, _guha, _uppe_,
  { {0x7d7b00a3, 0xa3e3013d, 0x00000000, 0x00000000}},  //   _אנטו, नना_,   ,
  { {0x6d450668, 0x3f820d02, 0x7c260089, 0x00000000}},  //   _zuha, nuku_, _uzkr,
  { {0xf3f9001a, 0x7d0401a2, 0x6d450085, 0x00000000}},  //   caţi_, lnis, _yuha,
  { {0x7d040207, 0x3f820085, 0x00000000, 0x00000000}},  //   onis, huku_,   ,
  { {0x33740d03, 0x7d040d04, 0x3f82014a, 0x00000000}},  //   агир, nnis, kuku_,
  { {0xd70a026b, 0x7d040051, 0x3f820093, 0x00000000}},  //   _знае_, inis, juku_,
  { {0x7d040d05, 0x92b60379, 0x00000000, 0x00000000}},  //   hnis, احظا,   ,
  { {0x645b0026, 0xe3b20bb6, 0x00000000, 0x00000000}},  //   bbui, _گرا_,   ,
  { {0x33860081, 0x2ba502fb, 0x6d450d06, 0x00000000}},  //   _букв, _ऑनला, _ruha,
  { {0x7d040107, 0x6d4504cb, 0x3f820022, 0x00000000}},  //   dnis, _suha, guku_,
  { {0x6d450d07, 0x7d04095c, 0xf1a6003b, 0x00000000}},  //   _puha, enis, _брин,
  { {0x59a4013d, 0x7d040d08, 0xf3f90035, 0x00000000}},  //   _गैलर, fnis, vaţi_,
  { {0x7d0405af, 0xd90400a6, 0x7d1600e0, 0x00000000}},  //   gnis, _ری_, goys,
  { {0x78a20179, 0x6d450066, 0xf3f9001a, 0x00000000}},  // [13f0] deov, _wuha, taţi_,
  { {0x7d0400d4, 0x6d450127, 0x00000000, 0x00000000}},  //   anis, _tuha,   ,
  { {0x7d04001f, 0x658a005f, 0xad2700a6, 0x00000000}},  //   bnis, _məhs, _مرحو,
  { {0x64420d09, 0x2d8305fd, 0xf3f9001a, 0x00000000}},  //   _ngoi, muje_, saţi_,
  { {0x2d91022b, 0x47350256, 0x62980165, 0x00000000}},  //   ltze_, андс, _obvo,
  { {0x4b7a0049, 0x64420032, 0x645b00d9, 0x00000000}},  //   _באשו, _agoi, wbui,
  { {0x2d830395, 0x645b01d6, 0x2d91002d, 0x00000000}},  //   nuje_, tbui, ntze_,
  { {0x09e103d7, 0x78a20d0a, 0x2d910032, 0x00000000}},  //   पनीय, ceov, itze_,
  { {0xe78700e1, 0x2d830428, 0xe7980d0b, 0x00000000}},  //   _љубо, huje_, _مخلص_,
  { {0x3ae40073, 0x6442002d, 0x3f820107, 0x00000000}},  //   _köpa_, _egoi, vuku_,
  { {0x2d8306a6, 0x3ea30d0c, 0x7d04000c, 0x00000000}},  //   juje_, dejt_, ynis,
  { {0xf5300025, 0x3f82007f, 0x00000000, 0x00000000}},  //   _فإن_, tuku_,   ,
  { {0x7d040107, 0x8c3b01a2, 0x00000000, 0x00000000}},  //   vnis, _maßs,   ,
  { {0x3f820119, 0xc8e2013d, 0x7d040052, 0x00000000}},  //   ruku_, _खत्म_, wnis,
  { {0x7d040d0d, 0xacf6025f, 0x6da6058d, 0x00000000}},  //   tnis, ачај, шива,
  { {0x7ce3006c, 0xdb0f00f6, 0x3f820d0e, 0x00000000}},  //   _põra, _arcà, puku_,

  { {0x7d04032c, 0x8fa600c0, 0xac050025, 0x00000000}},  // [1400] rnis, _тапе, مذكو,
  { {0x7d040d0f, 0x2d830b41, 0xba26007e, 0x00000000}},  //   snis, buje_, адзк,
  { {0x78a20d10, 0x7e7b009b, 0xc8660d11, 0x00000000}},  //   teov, _באיז, атли,
  { {0xd7fa008b, 0x00000000, 0x00000000, 0x00000000}},  //   кул_,   ,   ,
  { {0x27e00195, 0x78a20133, 0x00000000, 0x00000000}},  //   áin_, reov,   ,
  { {0x78a2001c, 0x64420d12, 0x6b840d13, 0x00000000}},  //   seov, _sgoi, muig,
  { {0xafdb0030, 0x27e00340, 0x00000000, 0x00000000}},  //   ncør, šin_,   ,
  { {0xd9430140, 0x658a006b, 0x00000000, 0x00000000}},  //   _фети, _bəhr,   ,
  { {0x6676007a, 0xb4d60061, 0x1afb0044, 0x00000000}},  //   _ندار, _हवी_, ্তরে_,
  { {0x4ac901f5, 0x63ab0146, 0x00000000, 0x00000000}},  //   रायव, _dsgn,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d830428, 0x00000000, 0x00000000, 0x00000000}},  //   vuje_,   ,   ,
  { {0x658a005f, 0x89370049, 0x61ff006b, 0x00000000}},  //   _təhs, ירטע_, _əylə,
  { {0xdefb0642, 0x272001aa, 0x539b00b3, 0x00000000}},  //   тым_, fòni_, _סיוו,
  { {0x27290051, 0x3ea30065, 0x8e380025, 0x00000000}},  //   núna_, rejt_, لسفر_,
  { {0x2d91002d, 0x3ea30d14, 0x2c780088, 0x00000000}},  //   rtze_, sejt_, ийсь_,
  { {0x2d830036, 0x3ea30065, 0x6f950025, 0x00000000}},  // [1410] suje_, pejt_, _الخض,
  { {0x2d830161, 0x628800ab, 0xed4e00a1, 0x00000000}},  //   puje_, ngdo, بھی_,
  { {0xf9f901b7, 0xdb2600a1, 0x3ce90056, 0x00000000}},  //   دفاع_, حولی, phav_,
  { {0x6d57002d, 0xb4d5006e, 0x6b8401c3, 0x00000000}},  //   _itxa, _सके_, buig,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9a840098, 0x00000000, 0x00000000, 0x00000000}},  //   _мусл,   ,   ,
  { {0x25ac0082, 0x00000000, 0x00000000, 0x00000000}},  //   _csdl_,   ,   ,
  { {0xe9190088, 0x00000000, 0x00000000, 0x00000000}},  //   _собі_,   ,   ,
  { {0x658a006b, 0x368b005e, 0xa82501b2, 0x00000000}},  //   _qəhr, _асен_, _اکان,
  { {0x2d730107, 0x6d570032, 0xa2e500e2, 0x00000000}},  //   kće_, _otxa, соод,
  { {0x6b8400bb, 0x00000000, 0x00000000, 0x00000000}},  //   zuig,   ,   ,
  { {0x658a006b, 0x00000000, 0x00000000, 0x00000000}},  //   _təhr,   ,   ,
  { {0xe2990d15, 0x6d57002d, 0x7e770009, 0x00000000}},  //   _бал_, _atxa, _bdxp,
  { {0x63a90d16, 0x2d73012d, 0xd9f9007d, 0x00000000}},  //   mwen, fće_, ्पात_,
  { {0xdef9007e, 0x63a90036, 0x8db50088, 0x00000000}},  //   рыў_, lwen, ості,
  { {0x6b8400b5, 0xa5da0049, 0x00000000, 0x00000000}},  //   tuig, אַמי,   ,
  { {0x60c40004, 0x3ce005d5, 0x6d57002d, 0x00000000}},  // [1420] _inim, rkiv_, _etxa,
  { {0x60d6008e, 0x4bd9007c, 0x00000000, 0x00000000}},  //   _hoym, шься_,   ,
  { {0xbed70049, 0x60d6014a, 0x63a901a2, 0x00000000}},  //   _הויז_, _koym, hwen,
  { {0x6d5c0977, 0x63a9000b, 0xe89401fb, 0x00000000}},  //   mpra, kwen, іаль,
  { {0x6b8400c4, 0xb796003b, 0x29060d17, 0x00000000}},  //   quig, срећ, rnoa_,
  { {0xef1f011f, 0x6ffc0089, 0x63a90007, 0x00000000}},  //   ltür_, mācī, dwen,
  { {0x6d5c0263, 0x60c40091, 0xc7af00a1, 0x00000000}},  //   npra, _onim, وڑے_,
  { {0x98bc0089, 0xdbdd0027, 0x63a90d18, 0x00000000}},  //   īvē_, zšír, fwen,
  { {0x394a0b8b, 0x9696017f, 0x63a9002b, 0x00000000}},  //   _hubs_, _греш, gwen,
  { {0x68e20010, 0x6eeb050d, 0x6d5c01c3, 0x00000000}},  //   lkod, _kübe, kpra,
  { {0xba9b01ce, 0x658a006b, 0x5a9b0049, 0x00000000}},  //   נסטי, _təhq, נשטא,
  { {0x68e20006, 0x692c001a, 0x7afe014a, 0x00000000}},  //   nkod, _aşez, hipt,
  { {0x7afe009f, 0x6eeb01a2, 0x53a30228, 0x00000000}},  //   kipt, _lübe, _нацб,
  { {0x39580d19, 0x7afe0065, 0x60c403b6, 0x00000000}},  //   _otrs_, jipt, _enim,
  { {0x6d5c0336, 0x68e20d1a, 0x8af0013f, 0x00000000}},  //   gpra, kkod, rpəl,
  { {0x99860046, 0x657c068f, 0x2d730107, 0x00000000}},  //   łoś_, _århu, rće_,
  { {0x09e10061, 0x8b580025, 0x8af902dc, 0x00000000}},  // [1430] पन्य, مجلس_, анас_,
  { {0x2d730d1b, 0x6e99007e, 0x7afe0048, 0x00000000}},  //   pće_, _твор_, gipt,
  { {0x69de001c, 0x7f3c007b, 0x39580009, 0x00000000}},  //   gype, _געזו, _ctrs_,
  { {0xad2706c6, 0x3869009f, 0x0cab0441, 0x00000000}},  //   _درخو, úar_, _стои_,
  { {0x395800f6, 0x2a6a0026, 0x00000000, 0x00000000}},  //   _etrs_, _febb_,   ,
  { {0xab5b010f, 0xe739007c, 0x7afe04cb, 0x00000000}},  //   _prüf, шел_, cipt,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63a9010f, 0x280401dc, 0x00000000, 0x00000000}},  //   twen, ásná_,   ,
  { {0x6d5c0235, 0x63a900b5, 0x25a00035, 0x00000000}},  //   zpra, uwen, ăila_,
  { {0x81d40055, 0x68e90224, 0x63a9001f, 0x00000000}},  //   _সেই_, _hled, rwen,
  { {0x5455026b, 0x68e90d1c, 0x63a9037f, 0x00000000}},  //   _двет, _kled, swen,
  { {0x60d6006b, 0x6d5c0059, 0x63a90173, 0x00000000}},  //   _qoym, vpra, pwen,
  { {0xb05b0510, 0x00000000, 0x00000000, 0x00000000}},  //   tjär,   ,   ,
  { {0x6d5c06ed, 0x68e20d1d, 0x539a00b3, 0x00000000}},  //   tpra, zkod, _כינו,
  { {0x8237035b, 0x68e90d1e, 0xe3b90010, 0x00000000}},  //   _ارشا, _oled, lvű_,
  { {0x60c40d1f, 0xb05b0d20, 0x6eeb01a2, 0x00000000}},  //   _unim, sjär, _rübe,
  { {0x6d5c0d21, 0x2a780093, 0x611201c5, 0x00000000}},  // [1440] spra, _pdrb_, rāld,
  { {0x6d5c0c08, 0x68e9008e, 0x25550089, 0x00000000}},  //   ppra, _aled, _zāle_,
  { {0x7afe062a, 0x8c460259, 0x68e200ea, 0x00000000}},  //   ript, _мене, tkod,
  { {0x319a0049, 0x69de01d6, 0x6f1c0197, 0x00000000}},  //   יבענ, rype, lorc,
  { {0x7d0902db, 0x68e20232, 0x7afe00e0, 0x00000000}},  //   čest, rkod, pipt,
  { {0x7afe048a, 0x68e20d22, 0x6f1c0129, 0x00000000}},  //   qipt, skod, norc,
  { {0xc44804e1, 0xbb430373, 0xab5b0d23, 0x00000000}},  //   میان_, _церк, _prüg,
  { {0x68e90340, 0x15170025, 0xd2500014, 0x00000000}},  //   _gled, يزية_, کند_,
  { {0x39440093, 0x6b960af1, 0x00000000, 0x00000000}},  //   _iims_, ntyg,   ,
  { {0xb5fc002b, 0x7f5d0045, 0xe5a60c96, 0x00000000}},  //   _leġi, vpsq, _мизи,
  { {0x7ce3006c, 0xab5b0d24, 0xdcfc01c5, 0x00000000}},  //   _sõrm, _trüg, ntrē,
  { {0x39440203, 0x00000000, 0x00000000, 0x00000000}},  //   _jims_,   ,   ,
  { {0x6f1c00ab, 0x00000000, 0x00000000, 0x00000000}},  //   forc,   ,   ,
  { {0x63a20d25, 0x6b960675, 0x6f1c0091, 0x00000000}},  //   _ipon, dtyg, gorc,
  { {0x3eb3005f, 0x2b4b0197, 0xdb0d00c4, 0x00000000}},  //   _vaxt_, _succ_, lvaç,
  { {0x9f6b012b, 0x1fa700ed, 0x8b670025, 0x00000000}},  //   _кроз_, _дрог, قائم,
  { {0x200c005f, 0x6f1c0871, 0x00000000, 0x00000000}},  // [1450] şdir_, borc,   ,
  { {0x6f1c0555, 0x2732001a, 0x61120089, 0x00000000}},  //   corc, nând_, rāle,
  { {0xfc3f0d26, 0xdcf50036, 0x68e9060b, 0x00000000}},  //   _país_, erzą, _pled,
  { {0x63a20036, 0x394400d4, 0xaac9007d, 0x00000000}},  //   _opon, _cims_, राहक,
  { {0x995400b9, 0x39440190, 0x37ab0ab6, 0x00000000}},  //   _výše_, _dims_, ртен_,
  { {0xb34500c4, 0x7bda009b, 0x68e90016, 0x00000000}},  //   _liçã, _הקשו, _wled,
  { {0x63a20181, 0x3944000a, 0xfc3f00fa, 0x00000000}},  //   _apon, _fims_, _taís_,
  { {0x68fb0d27, 0x6fcb01f5, 0x2ca90d28, 0x00000000}},  //   _umud, ामां, nead_,
  { {0x291d0036, 0x46150123, 0x399502e7, 0x00000000}},  //   mowa_, _کوار, lås_,
  { {0x386d0b10, 0x291d0036, 0x2ca90d29, 0x00000000}},  //   _heer_, lowa_, head_,
  { {0x386d049b, 0x63a20d2a, 0x6f1c08d0, 0x00000000}},  //   _keer_, _epon, vorc,
  { {0x291d0036, 0x7cf10d2b, 0x8fa60072, 0x00000000}},  //   nowa_, _hårf, паме,
  { {0x386d049b, 0x6f1c0606, 0xb5fc01d5, 0x00000000}},  //   _meer_, torc, _reġi,
  { {0x386d0d2c, 0x2732001a, 0x248d0d2d, 0x00000000}},  //   _leer_, când_, lgem_,
  { {0x63bb000c, 0x291d0036, 0x2ca90051, 0x00000000}},  //   lvun, kowa_, fead_,
  { {0x2ca90061, 0x248d0d2e, 0x386d00c7, 0x00000000}},  //   gead_, ngem_, _neer_,
  { {0x291d0036, 0x39440d2f, 0x61e10d30, 0x00000000}},  // [1460] dowa_, _rims_, lyll,
  { {0xe81f02d2, 0x8b23007c, 0x6b960039, 0x00000000}},  //   _बड़ा_, едуе, rtyg,
  { {0x6edb009b, 0x6b960d31, 0x39950d32, 0x00000000}},  //   _החיפ, styg, gås_,
  { {0x2fc00c88, 0x3eaa010f, 0x2732001a, 0x00000000}},  //   _krig_, lebt_, zând_,
  { {0xdcfc001e, 0x4cbb00b6, 0x2d9804b9, 0x00000000}},  //   strē, _הזכו, ltre_,
  { {0x6d46011f, 0x8f9b00a0, 0x6b840d33, 0x00000000}},  //   _hika, מיני, mrig,
  { {0x6d460d34, 0x61e10030, 0x6b840190, 0x00000000}},  //   _kika, jyll, lrig,
  { {0x6eeb02b9, 0x94aa007e, 0x2d980d35, 0x00000000}},  //   _müba, стка_, itre_,
  { {0x6d460d36, 0x6b840030, 0x2732001a, 0x00000000}},  //   _mika, nrig, tând_,
  { {0x6d460d37, 0x386d02ae, 0xdb0d0181, 0x00000000}},  //   _lika, _zeer_, rvaç,
  { {0x64a60175, 0x6b84010f, 0x2732001a, 0x00000000}},  //   _нажа, hrig, rând_,
  { {0x6d460119, 0x2fc0018e, 0x6b840cb2, 0x00000000}},  //   _nika, _brig_, krig,
  { {0x613f001e, 0x3869000c, 0x2732001a, 0x00000000}},  //   _jūli, ðari_, pând_,
  { {0x44260d38, 0x6b8406f8, 0x6d46021e, 0x00000000}},  //   _iyo_, drig, _aika,
  { {0x6d46002d, 0x6b84010f, 0x06fd00b9, 0x00000000}},  //   _bika, erig, _říká_,
  { {0x2d830065, 0x6d460563, 0x44260d39, 0x00000000}},  //   rrje_, _cika, _kyo_,
  { {0x2d9c0073, 0x6d46020c, 0x66dd01aa, 0x00000000}},  // [1470] _även_, _dika, _mèkr,
  { {0x386d0007, 0x13df0055, 0x7cea0428, 0x00000000}},  //   _seer_, _বেড়, _výra,
  { {0x291d0036, 0x2d8a008e, 0x75220010, 0x00000000}},  //   towa_, cube_, _okoz,
  { {0xf7710d3a, 0xddde0224, 0x39950039, 0x00000000}},  //   نات_, _nepř, rås_,
  { {0x7d0d01bf, 0x4426006a, 0x386d0c95, 0x00000000}},  //   mnas, _nyo_, _veer_,
  { {0x386d049b, 0xea63026c, 0xd2460025, 0x00000000}},  //   _weer_, _سپری, _لن_,
  { {0x44260d3b, 0x67210059, 0x386d0007, 0x00000000}},  //   _ayo_, _vklj, _teer_,
  { {0x7d0d0d3c, 0x0445005e, 0x44260061, 0x00000000}},  //   nnas, мейн, _byo_,
  { {0x44260061, 0x61e1018e, 0x248d0d3d, 0x00000000}},  //   _cyo_, wyll, rgem_,
  { {0x7cf101bf, 0x7d0d018e, 0x67210091, 0x00000000}},  //   _hård, hnas, _uklj,
  { {0x7d0d0d3e, 0x44260d3f, 0x00000000, 0x00000000}},  //   knas, _eyo_,   ,
  { {0x61e10016, 0x63a40035, 0x00000000, 0x00000000}},  //   ryll, _ţine,   ,
  { {0x61e1018e, 0x3f8b016c, 0xdb0f008e, 0x00000000}},  //   syll, gucu_, _escé,
  { {0x2d980d40, 0x75290555, 0x6b840193, 0x00000000}},  //   ttre_, llez, vrig,
  { {0x6d4603b6, 0x311601e0, 0x6b840d41, 0x00000000}},  //   _pika, _офис, wrig,
  { {0xd132004b, 0x7d0d000c, 0x2d9806f0, 0x00000000}},  //   _جمع_, gnas, rtre_,
  { {0x2d980d42, 0x6d460d43, 0x0b460088, 0x00000000}},  // [1480] stre_, _vika, днан,
  { {0x6b840d44, 0xa01b03ed, 0x6d46011c, 0x00000000}},  //   rrig, rgöt, _wika,
  { {0x6d46001e, 0x644b0d45, 0x7c260036, 0x00000000}},  //   _tika, _oggi, _wykr,
  { {0x6b840d46, 0xfd45007e, 0x395c0089, 0x00000000}},  //   prig, _пэўн, īvs_,
  { {0x75290521, 0xa01b00f8, 0x7d0401b1, 0x00000000}},  //   dlez, lgör, miis,
  { {0x644b0198, 0x7529000b, 0x7d0400b0, 0x00000000}},  //   _aggi, elez, liis,
  { {0x7ae300b0, 0xa01b0d47, 0xdcf50036, 0x00000000}},  //   önte, ngör, erzę,
  { {0x7529001a, 0x7cf105cb, 0x29020039, 0x00000000}},  //   glez, _gård, _öka_,
  { {0x386601a3, 0xddde013e, 0x00000000, 0x00000000}},  //   mbor_, _vepř,   ,
  { {0x65c60401, 0x6d5e0091, 0x644b01e5, 0x00000000}},  //   _обза, _otpa, _eggi,
  { {0xe8df0011, 0x75290d48, 0x7cf103bd, 0x00000000}},  //   _hiền_, blez, _håre,
  { {0x44260058, 0xf503005e, 0x7cf107c4, 0x00000000}},  //   _tyo_, _изхо, _kåre,
  { {0x6d5e001e, 0x7ce30004, 0xc0e4007e, 0x00000000}},  //   _atpa, _kõrv, тоўк,
  { {0xe8df001d, 0x3f990d49, 0x3f8b014a, 0x00000000}},  //   _miền_, rtsu_, rucu_,
  { {0xdd94008b, 0xc348001d, 0xe8df0011, 0x00000000}},  //   кары, _nổi_, _liền_,
  { {0x30a702a8, 0x7d040d4a, 0x201e001a, 0x00000000}},  //   _цркв, giis, ştia_,
  { {0x7d0d0d4b, 0xfd44008b, 0x3866012d, 0x00000000}},  // [1490] rnas, тэрн, dbor_,
  { {0x0dcb005e, 0x19eb0025, 0x4ac9006e, 0x00000000}},  //   _думи_, يراً_, राइव,
  { {0xceb201ce, 0x212b0016, 0x00000000, 0x00000000}},  //   _גיי_, olch_,   ,
  { {0x25a50022, 0x7cf10190, 0xe8df0082, 0x00000000}},  //   _rpll_, _båre, _biền_,
  { {0x7cf10039, 0x78ab0d4c, 0xc7ab0d0b, 0x00000000}},  //   _vård, regv, تدال_,
  { {0x6b8d0020, 0x6d58009d, 0x7aee00fa, 0x00000000}},  //   muag, _évac, _glbt,
  { {0x27e90466, 0x75290d4d, 0x657a0068, 0x00000000}},  //   šan_, tlez, _cvth,
  { {0x672a040f, 0x7cf1032e, 0x00000000, 0x00000000}},  //   alfj, _fåre,   ,
  { {0x752900bb, 0x387f0066, 0x68e400b0, 0x00000000}},  //   rlez, _idur_, öide,
  { {0x752900b9, 0x290f00e0, 0x00000000, 0x00000000}},  //   slez, lnga_,   ,
  { {0x75290cc1, 0x00000000, 0x00000000, 0x00000000}},  //   plez,   ,   ,
  { {0x644b0026, 0x6b8d0bb2, 0x387f0066, 0x00000000}},  //   _uggi, kuag, _jdur_,
  { {0x7d0403b6, 0x13a70014, 0x290f0056, 0x00000000}},  //   viis, _آنتی_, inga_,
  { {0x613601ca, 0x7e75002d, 0x2d5500ea, 0x00000000}},  //   dále, gazp, _båe_,
  { {0x6da30751, 0x387f0477, 0x7d040052, 0x00000000}},  //   лира, _odur_, tiis,
  { {0x7cea0428, 0xe05800a2, 0x387f01f3, 0x00000000}},  //   _výro, _زیست_, _ndur_,
  { {0x7d0401c2, 0x6b8d0197, 0x61360d4e, 0x00000000}},  // [14a0] riis, guag, ráld,
  { {0x7d04010e, 0x2cb900f6, 0x387f0d4f, 0x00000000}},  //   siis, _easd_, _adur_,
  { {0x88860098, 0x7cf101c4, 0xf9690088, 0x00000000}},  //   ележ, _såre, дрій_,
  { {0xdd2f00b9, 0x00000000, 0x00000000, 0x00000000}},  //   pěšn,   ,   ,
  { {0x3c77009b, 0x387f0af2, 0x38660133, 0x00000000}},  //   _אתכם_, _ddur_, rbor_,
  { {0x290f0051, 0x7cf1093b, 0xa8240014, 0x00000000}},  //   anga_, _våre, _یکشن,
  { {0x212b018e, 0x6b490d50, 0x940a006b, 0x00000000}},  //   ylch_, _užga, əbə_,
  { {0xe8df001d, 0xd9430d51, 0xf3660b81, 0x00000000}},  //   _tiền_, _беси, нтон,
  { {0x7ce3010e, 0x29060032, 0x2ca00048, 0x00000000}},  //   _tõrv, mioa_, ifid_,
  { {0x877b00b3, 0xdb970049, 0x2906002d, 0x00000000}},  //   _מאמי, עדיט_, lioa_,
  { {0x27e60890, 0x26cc0d52, 0xe6d9000c, 0x00000000}},  //   lyon_, _indo_, _þráð,
  { {0x29060d53, 0x00000000, 0x00000000, 0x00000000}},  //   nioa_,   ,   ,
  { {0xa30b009c, 0xa2e60d54, 0xe8df0011, 0x00000000}},  //   _کرنے_, _подд, _hiển_,
  { {0x26de0020, 0x9f350088, 0x3eba0133, 0x00000000}},  //   _joto_, тегі, _capt_,
  { {0x7e750d55, 0x3eba0d56, 0x00000000, 0x00000000}},  //   razp, _dapt_,   ,
  { {0x0ccf0055, 0x26de0035, 0x6b8d0d57, 0x00000000}},  //   রস্ত, _loto_, tuag,
  { {0x60cd0b1f, 0x26cc022b, 0x27e60263, 0x00000000}},  // [14b0] _inam, _ondo_, jyon_,
  { {0x26de0207, 0x6b8d002d, 0x2cb9000a, 0x00000000}},  //   _noto_, ruag, _wasd_,
  { {0xab5b001f, 0x7b0b0089, 0x6b8d0032, 0x00000000}},  //   _grün, kļuv, suag,
  { {0xa95401fb, 0x6c790049, 0xdb04000c, 0x00000000}},  //   укці, _קאָפ, svið,
  { {0x27e60047, 0x60cd0020, 0x26de0d58, 0x00000000}},  //   gyon_, _mnam, _boto_,
  { {0xe8df001d, 0x04ed0044, 0x8698005e, 0x00000000}},  //   _biển_, _ওদের_, етът_,
  { {0x5b14025f, 0x27e60058, 0x26de01c5, 0x00000000}},  //   _смрт, ayon_, _doto_,
  { {0x81c80044, 0x60cd0045, 0xe8df0082, 0x00000000}},  //   োনা_, _nnam, _diển_,
  { {0x249f000c, 0xf699012b, 0x1fcb0061, 0x00000000}},  //   rfum_, _овај_, ामोड,
  { {0x60cd0020, 0x26de0d59, 0x00000000, 0x00000000}},  //   _anam, _goto_,   ,
  { {0x67230d5a, 0xe4e70088, 0x60cd00ea, 0x00000000}},  //   monj, _підн, _bnam,
  { {0x6723002b, 0x60cd0019, 0xd00a00ed, 0x00000000}},  //   lonj, _cnam, деме_,
  { {0x78bb00f4, 0x3ae40039, 0xe29900ed, 0x00000000}},  //   _mauv, _köpt_, _жал_,
  { {0x2906022b, 0x60cd0004, 0x672307d7, 0x00000000}},  //   zioa_, _enam, nonj,
  { {0x27e60d5b, 0xeab200a1, 0x60cd0009, 0x00000000}},  //   zyon_, یٹر_, _fnam,
  { {0xfbe70011, 0x645b0d5c, 0x29060032, 0x00000000}},  //   _thể_, ncui, xioa_,
  { {0x3eba0056, 0x672304eb, 0x00000000, 0x00000000}},  // [14c0] _tapt_, konj,   ,
  { {0x67230066, 0x00000000, 0x00000000, 0x00000000}},  //   jonj,   ,   ,
  { {0x67230d5d, 0x26de004a, 0x29060032, 0x00000000}},  //   donj, _roto_, tioa_,
  { {0xe786008b, 0x27e601aa, 0xa9670d5e, 0x00000000}},  //   вуко, tyon_, тица_,
  { {0xa2b2001c, 0x26de01aa, 0x2906022b, 0x00000000}},  //   _असल्, _poto_, rioa_,
  { {0x27e6049a, 0x67230020, 0x7bc6002b, 0x00000000}},  //   ryon_, gonj, _irku,
  { {0x27e60d5f, 0x26de0d60, 0x66e306e3, 0x00000000}},  //   syon_, _voto_, роја,
  { {0x399c0129, 0x6abc014a, 0x27e60173, 0x00000000}},  //   mís_, _harf, pyon_,
  { {0x290401d5, 0x26de0428, 0x67230d61, 0x00000000}},  //   _imma_, _toto_, bonj,
  { {0x6723001a, 0x78bb0091, 0x60cd00ca, 0x00000000}},  //   conj, _zauv, _snam,
  { {0x6abc001a, 0x68e007e0, 0x399c0d62, 0x00000000}},  //   _marf, _komd, nís_,
  { {0x7bc60d63, 0x645b0026, 0xb97b00a0, 0x00000000}},  //   _orku, ccui, ונטי,
  { {0x399c0051, 0x68e300c4, 0x6f0700d0, 0x00000000}},  //   hís_, êndi, tijc,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdef8008b, 0x5e5801fb, 0x6f0700ca, 0x00000000}},  //   тыя_, тися_, rijc,
  { {0x399c0d64, 0x60cd0020, 0x853c0006, 0x00000000}},  //   dís_, _unam, _spėj,
  { {0x6d58009d, 0x7bc60087, 0x67230045, 0x00000000}},  // [14d0] _évan, _crku, yonj,
  { {0x2904005f, 0x78bb028c, 0x6136009f, 0x00000000}},  //   _amma_, _sauv, mála,
  { {0xce330167, 0x61360047, 0x6abc0d65, 0x00000000}},  //   _خودک, lála, _darf,
  { {0xfc640265, 0xfc3f008e, 0x68e00048, 0x00000000}},  //   _върн, _maíz_, _comd,
  { {0xd3660076, 0x6723002b, 0x9cd600b6, 0x00000000}},  //   _ده_, tonj, _עושה_,
  { {0x29040039, 0x6abc005b, 0x399c0d66, 0x00000000}},  //   _emma_, _garf, bís_,
  { {0x399c0d67, 0x61360051, 0x67230c33, 0x00000000}},  //   cís_, hála, ronj,
  { {0x2602001c, 0xe3b90d68, 0x69c70093, 0x00000000}},  //   _वेळी_, еби_, _irje,
  { {0x67230d69, 0xecc50044, 0x6136000c, 0x00000000}},  //   ponj, _একাড, jála,
  { {0xe8df00ad, 0x645b001a, 0x61e8018e, 0x00000000}},  //   _diễn_, scui, fydl,
  { {0x394d01b5, 0x04950355, 0xb1460595, 0x00000000}},  //   _kies_, _ملاح, лнол,
  { {0xa6e2009f, 0x201e014a, 0x00000000, 0x00000000}},  //   _öðru, ştim_,   ,
  { {0x61360d6a, 0x394d00b0, 0xdcfc0089, 0x00000000}},  //   gála, _mies_, strī,
  { {0x69c70d6b, 0xe299012b, 0x2d910d6c, 0x00000000}},  //   _orje, _чак_, fuze_,
  { {0x5239007b, 0x62830982, 0xd336009b, 0x00000000}},  //   _אײַנ, _idno, _גרסה_,
  { {0x394d01d5, 0x399c0d6d, 0x6abc0095, 0x00000000}},  //   _nies_, vís_, _sarf,
  { {0x6abc0d6e, 0x69c70d6f, 0xdc75007e, 0x00000000}},  // [14e0] _parf, _arje, рысь,
  { {0x89f6008b, 0x80a002d2, 0x2d910c39, 0x00000000}},  //   ляец, ग्रे, buze_,
  { {0x6abc0d70, 0x7ce30004, 0x80d80061, 0x00000000}},  //   _varf, _võrr, यापे,
  { {0x399c0d71, 0x394d00d4, 0x7bc60521, 0x00000000}},  //   rís_, _cies_, _trku,
  { {0x394d0d72, 0x62830119, 0x66e60878, 0x00000000}},  //   _dies_, _odno, лода,
  { {0xd5ba0594, 0x00000000, 0x00000000, 0x00000000}},  //   еси_,   ,   ,
  { {0x394d06f8, 0xdb230010, 0xc7b90010, 0x00000000}},  //   _fies_, _óráj, _eső_,
  { {0x2904000b, 0x6283018e, 0xc448007a, 0x00000000}},  //   _umma_, _adno, نیان_,
  { {0xd2500054, 0x2729027b, 0x9cd7009b, 0x00000000}},  //   ينة_, gúns_, רופה_,
  { {0xe8df0011, 0x61e80039, 0x61360010, 0x00000000}},  //   _viễn_, tydl, vála,
  { {0x62340ab7, 0xe61600ed, 0x546a0d73, 0x00000000}},  //   рену, _сфаќ, _заем_,
  { {0x2d910061, 0x62830d74, 0xe8df0011, 0x00000000}},  //   vuze_, _edno, _tiễn_,
  { {0x8cbf03d7, 0xe47b0049, 0x72d40467, 0x00000000}},  //   _लोगो, _טראכ, _волф,
  { {0x43830d75, 0x61360d76, 0xef1f0180, 0x00000000}},  //   _الوق, rála, mrük_,
  { {0x6d5800f4, 0x61360d77, 0xeca700ed, 0x00000000}},  //   _éval, máln, лјан,
  { {0x69c7008d, 0x55770049, 0xf19300a1, 0x00000000}},  //   _rrje, טעלן_, _اُٹھ,
  { {0xe8df00ad, 0x1bd4005e, 0x394d0d78, 0x00000000}},  // [14f0] _hiện_, ботя, _ries_,
  { {0xe8df001d, 0x613608aa, 0x394d0944, 0x00000000}},  //   _kiện_, náln, _sies_,
  { {0xc33300b6, 0x394d0a6d, 0x00000000, 0x00000000}},  //   צוע_, _pies_,   ,
  { {0x2fc90343, 0xe8df0082, 0xd7f10025, 0x00000000}},  //   _krag_, _miện_, يكا_,
  { {0x394d0d79, 0x61360d7a, 0xdb0f008e, 0x00000000}},  //   _vies_, káln, _escá,
  { {0x6d4f0180, 0x6b8d0190, 0x394d01a2, 0x00000000}},  //   _hica, mrag, _wies_,
  { {0x394d0006, 0x45190001, 0x8aa40088, 0x00000000}},  //   _ties_, кция_, _уряд,
  { {0x7cf80d7b, 0x6d4f000a, 0x7e770d7c, 0x00000000}},  //   _vírg, _jica, _lexp,
  { {0x28f80077, 0x6d4f0d7d, 0x00000000, 0x00000000}},  //   _сеть_, _mica,   ,
  { {0x425502a8, 0xe8df0011, 0x6d4f0197, 0x00000000}},  //   штит, _biện_, _lica,
  { {0x7cf80047, 0x6b8d0d7e, 0xa06a00ed, 0x00000000}},  //   _híre, hrag, кана_,
  { {0xe8df001d, 0x2fc90190, 0x6b8d01d6, 0x00000000}},  //   _diện_, _brag_, krag,
  { {0xf3670242, 0x61120089, 0x61360d7f, 0x00000000}},  //   _стен, nāli, báln,
  { {0x7cf80051, 0x6d57006b, 0xdcee00b9, 0x00000000}},  //   _míre, _buxa, ědče,
  { {0x6d4f04cb, 0x2d9e00f4, 0x442f01d6, 0x00000000}},  //   _bica, îte_, _hyg_,
  { {0x6b8d001f, 0xb4e30061, 0xa2cd0204, 0x00000000}},  //   frag, _नको_, ताक्,
  { {0x6d4f0d80, 0x61360010, 0x7cf10748, 0x00000000}},  // [1500] _dica, lálo, _tårn,
  { {0xff7b007b, 0x7bc40cc7, 0x442f0190, 0x00000000}},  //   _שטימ, rviu, _myg_,
  { {0x6d4f02d5, 0x442f0006, 0x61360d81, 0x00000000}},  //   _fica, _lyg_, nálo,
  { {0xdbdc01ca, 0x2c5c0036, 0x3ead0091, 0x00000000}},  //   lšíc, _bądź_, đete_,
  { {0x3869004a, 0x69c500ea, 0x6b8d009d, 0x00000000}},  //   ñara_, avhe, crag,
  { {0x7cf8002a, 0x6d57006b, 0x613d0010, 0x00000000}},  //   _díre, _yuxa, méle,
  { {0x6d5c0d82, 0x7cf80051, 0x6d4f0009, 0x00000000}},  //   nqra, _tírd, _yica,
  { {0x7d1600b0, 0x442f0030, 0x7e7c009d, 0x00000000}},  //   nnys, _byg_, harp,
  { {0x2bc9007d, 0x61360d83, 0x7e7c0d84, 0x00000000}},  //   रिया, táln, karp,
  { {0x39580036, 0xdbdc0161, 0x6eeb0d85, 0x00000000}},  //   _kurs_, jšíc, _tübi,
  { {0x61360d86, 0x7e7c00ea, 0x8af0006b, 0x00000000}},  //   ráln, darp, vqəl,
  { {0xb356089d, 0xe8df001d, 0xab5b001f, 0x00000000}},  //   _پیدا_, _viện_, _früh,
  { {0x6d4f0d87, 0x7cf101e3, 0x7e7c0016, 0x00000000}},  //   _rica, _dårl, farp,
  { {0xe8df001d, 0x6b8d05f2, 0x395806fa, 0x00000000}},  //   _tiện_, vrag, _ours_,
  { {0x13b602f4, 0xab5b0d88, 0x6136004a, 0x00000000}},  //   _अनुभ, _trük, cálo,
  { {0x6b8d001f, 0x2fc90035, 0x61360010, 0x00000000}},  //   trag, _trag_, náll,
  { {0x2a780093, 0xa0680098, 0xa2cb0061, 0x00000000}},  // [1510] _berb_, _тања_, _थोड्,
  { {0x6b8d0d89, 0xf9c702d3, 0x6d4f0093, 0x00000000}},  //   rrag, ищен, _wica,
  { {0x39580d8a, 0x6d4f005d, 0x6b8d01a2, 0x00000000}},  //   _curs_, _tica, srag,
  { {0x39580d8b, 0x69c10089, 0x61120089, 0x00000000}},  //   _durs_, _šles, tāli,
  { {0x7d0d0046, 0x00000000, 0x00000000, 0x00000000}},  //   mias,   ,   ,
  { {0x395800f6, 0x7cf80051, 0x442f08c8, 0x00000000}},  //   _furs_, _víre, _ryg_,
  { {0xa50900ed, 0x442f0d8c, 0x39580087, 0x00000000}},  //   лека_, _syg_, _gurs_,
  { {0x7d0d0006, 0x61360d8d, 0x201e001a, 0x00000000}},  //   nias, gáll, ştii_,
  { {0x57f500ed, 0xe3b10025, 0x387d005b, 0x00000000}},  //   _упат, سرة_, mawr_,
  { {0x81e20055, 0x61360d8e, 0x6d440036, 0x00000000}},  //   _নেই_, tálo, zmia,
  { {0x7e7c009f, 0x6d440016, 0x7d0d0d8f, 0x00000000}},  //   varp, ymia, kias,
  { {0x387d0016, 0x3f6a003b, 0x2d5c008e, 0x00000000}},  //   nawr_, лимо_, _ríe_,
  { {0x7e7c0d90, 0x320b0036, 0xdbdc0861, 0x00000000}},  //   tarp, ńcy_, tšíc,
  { {0x2cab00c4, 0x613d0d91, 0x3f5d0082, 0x00000000}},  //   _abcd_, véle, _dìu_,
  { {0x61460265, 0x7e7c00ea, 0x51950025, 0x00000000}},  //   _лека, rarp, _العذ,
  { {0x3d080061, 0x2a780065, 0x4bda007c, 0x00000000}},  //   _सगळे_, _serb_, льзя_,
  { {0x4aaa01f9, 0x6d440904, 0x7e7c0052, 0x00000000}},  // [1520] лкан_, rmia, parp,
  { {0x6d4401a3, 0x7d160a67, 0x61360010, 0x00000000}},  //   smia, snys, záll,
  { {0x7d0d0d92, 0xc8790279, 0x7cf80d93, 0x00000000}},  //   bias, _beş_, _círc,
  { {0x7d0d0d94, 0x2732001a, 0x7c96005e, 0x00000000}},  //   cias, mâni_, _уроц,
  { {0x3f820027, 0x09e00055, 0x02b70061, 0x00000000}},  //   nsku_, _যেখা, _असून,
  { {0xb8ef03d7, 0xe3e8026c, 0x3ce00c1e, 0x00000000}},  //   _वो_, یکشن_, ljiv_,
  { {0xceb300b6, 0x61360010, 0x395800bb, 0x00000000}},  //   פיה_, táll, _uurs_,
  { {0x18a30216, 0xdb1d0039, 0x4d7b0049, 0x00000000}},  //   _насм, _ersä, ארקע,
  { {0xe73a01f9, 0x24180147, 0x3f820091, 0x00000000}},  //   _беа_, ропы_, jsku_,
  { {0x27f9006c, 0x39460d95, 0x3f5d0082, 0x00000000}},  //   _üsna_, lmos_, _rìu_,
  { {0xd2500070, 0x613d0010, 0x00000000, 0x00000000}},  //   بند_, vélb,   ,
  { {0x3a37019b, 0x463b0049, 0xca37009b, 0x00000000}},  //   מרים_, _געבע, מניה_,
  { {0x7d0d023a, 0x394600dc, 0x00000000, 0x00000000}},  //   vias, imos_,   ,
  { {0x61360010, 0xdb1d00c4, 0x28cf007d, 0x00000000}},  //   nálj, _essê, _सोनि,
  { {0xc27b007b, 0x7d0d044e, 0x25be00fa, 0x00000000}},  //   _גרוי, tias, _jstl_,
  { {0xdb060010, 0x00000000, 0x00000000, 0x00000000}},  //   _eskü,   ,   ,
  { {0x6eeb006b, 0xa2cd0061, 0xfc330025, 0x00000000}},  // [1530] _sübu, ताच्, سحر_,
  { {0x7d0d000b, 0xda670054, 0x629a00ab, 0x00000000}},  //   sias, صائي, ngto,
  { {0xb9b5031d, 0x7d0d0d96, 0x99620161, 0x00000000}},  //   تماع, pias, _píše_,
  { {0x38350594, 0x212b0d97, 0x00000000, 0x00000000}},  //   онер, noch_,   ,
  { {0x65680065, 0x7d1d00bb, 0x00000000, 0x00000000}},  //   _atdh, _ijss,   ,
  { {0x39460d98, 0x3cef0061, 0x212b0142, 0x00000000}},  //   amos_, _इकडे_, hoch_,
  { {0x286b025f, 0x19940d99, 0x05790025, 0x00000000}},  //   _брзо_, _наря, جمعة_,
  { {0x2d8300bb, 0x394600e5, 0xe9190088, 0x00000000}},  //   isje_, cmos_, _тобі_,
  { {0x212b0d9a, 0x290f006c, 0x9f4e013e, 0x00000000}},  //   doch_, miga_, žném_,
  { {0x290f0073, 0xf6f500d3, 0x1309007c, 0x00000000}},  //   liga_, _بزرگ, рной_,
  { {0xf7480054, 0x75290d9b, 0x2d8300bb, 0x00000000}},  //   _اللي_, poez, jsje_,
  { {0xa4f7007a, 0xa2a90316, 0x3f82016e, 0x00000000}},  //   _دکتر_, _जॉर्, tsku_,
  { {0x3f84004f, 0x61360010, 0x6ef0010e, 0x00000000}},  //   ému_, lálk, _häbi,
  { {0x290f0d9c, 0x7cea000c, 0x68f80089, 0x00000000}},  //   higa_, _nýrr, īvdi,
  { {0xdd9204e8, 0x290f0d9d, 0x25550089, 0x00000000}},  //   ظور_, kiga_, _tālu_,
  { {0x3f82037e, 0x290f0059, 0x61120089, 0x00000000}},  //   psku_, jiga_, tālu,
  { {0x290f03af, 0x6ef00004, 0xeb9a00ed, 0x00000000}},  // [1540] diga_, _läbi, риз_,
  { {0x2d910046, 0x80d80061, 0xdcfc001e, 0x00000000}},  //   brze_, यावे, turē,
  { {0x60c40d9e, 0xfce6003b, 0x3eb80d9f, 0x00000000}},  //   _kaim, _доно, mert_,
  { {0x60c40211, 0x3eb80056, 0x290f006c, 0x00000000}},  //   _jaim, lert_, giga_,
  { {0x39460da0, 0x39400089, 0x2d980549, 0x00000000}},  //   rmos_, ķis_, lure_,
  { {0x39460325, 0x60c40a5c, 0x6b84002a, 0x00000000}},  //   smos_, _laim, msig,
  { {0x20dd0061, 0x290f0da1, 0x2d980133, 0x00000000}},  //   यामध, biga_, nure_,
  { {0x443d001f, 0x60c40247, 0x3eb8010f, 0x00000000}},  //   _bzw_, _naim, hert_,
  { {0xa686017f, 0x6b840198, 0x3eb8009f, 0x00000000}},  //   _млад, nsig, kert_,
  { {0x2d9801c5, 0x61360047, 0x6b840da2, 0x00000000}},  //   kure_, lálh, isig,
  { {0xd62a0057, 0x3eb80c7a, 0x60c40da3, 0x00000000}},  //   _тоже_, dert_, _baim,
  { {0x613d009f, 0x61360010, 0xdb1d00d4, 0x00000000}},  //   féla, nálh, _essè,
  { {0x60c40da4, 0x3eb80da5, 0x212b0142, 0x00000000}},  //   _daim, fert_, roch_,
  { {0x6b840030, 0x3eb80da6, 0x69ce0032, 0x00000000}},  //   dsig, gert_, _orbe,
  { {0x2d9800ab, 0x60c40035, 0x2d850010, 0x00000000}},  //   gure_, _faim, éle_,
  { {0x290f0da7, 0x60c4005b, 0x2d830da8, 0x00000000}},  //   xiga_, _gaim, rsje_,
  { {0x20020046, 0x69de0da9, 0x290f0daa, 0x00000000}},  // [1550] czki_, expe, viga_,
  { {0x3eb800d4, 0xdb0400f4, 0xad670025, 0x00000000}},  //   cert_, ntiè, _واجه,
  { {0xfd10026c, 0x6d3500ed, 0x7ae705d2, 0x00000000}},  //   رجہ_, _неоф, _vojt,
  { {0x52b70164, 0x7ae70036, 0x6b84004a, 0x00000000}},  //   _अस्स, _wojt, bsig,
  { {0x290f07dc, 0x3f99014a, 0x69ce0dab, 0x00000000}},  //   riga_, nusu_, _erbe,
  { {0x290f0dac, 0x69ce0087, 0x00000000, 0x00000000}},  //   siga_, _frbe,   ,
  { {0x3f99000b, 0x290f000b, 0x7cf800b9, 0x00000000}},  //   husu_, piga_, _mírn,
  { {0xd5ae0379, 0x3f990dad, 0x7bcf01ee, 0x00000000}},  //   افي_, kusu_, _krcu,
  { {0x48fa0049, 0x13090088, 0x3ea10051, 0x00000000}},  //   _פּלא, йний_, _ocht_,
  { {0x60c4001e, 0x613d0dae, 0x61360daf, 0x00000000}},  //   _saim, véla, máli,
  { {0x60c40997, 0x68e90db0, 0xe8df0082, 0x00000000}},  //   _paim, _koed, _nhịn_,
  { {0x3ea10db1, 0x3eb8010f, 0x2d98009d, 0x00000000}},  //   _acht_, wert_, vure_,
  { {0xe28e0db2, 0x68e90db3, 0x26c50db4, 0x00000000}},  //   _па_, _moed, _kalo_,
  { {0x2d98030a, 0x60c400a9, 0x3eb801a2, 0x00000000}},  //   ture_, _waim, uert_,
  { {0x6281011c, 0x26c50cce, 0x60c401c2, 0x00000000}},  //   malo, _malo_, _taim,
  { {0x3ea10db5, 0x3eb80292, 0x3f990089, 0x00000000}},  //   _echt_, sert_, busu_,
  { {0x2d980db6, 0x3f990279, 0x69ce0db7, 0x00000000}},  // [1560] sure_, cusu_, _srbe,
  { {0x6b840018, 0x2d980198, 0x62810020, 0x00000000}},  //   rsig, pure_, nalo,
  { {0x68e90db8, 0x68fb0db9, 0x14bd0309, 0x00000000}},  //   _boed, _blud, ्याण,
  { {0x7e7e000c, 0x68fb0016, 0x68e90016, 0x00000000}},  //   _hepp, _clud, _coed,
  { {0x62810010, 0x7e7e009f, 0x68e2002b, 0x00000000}},  //   kalo, _kepp, rjod,
  { {0x6d5e000b, 0x26c50026, 0x7e7e0dba, 0x00000000}},  //   _kupa, _calo_, _jepp,
  { {0x62810dbb, 0x69da0142, 0xbb430088, 0x00000000}},  //   dalo, _štef, _черк,
  { {0x68e90dbc, 0x21200dbd, 0x7e7e03b6, 0x00000000}},  //   _goed, _njih_, _lepp,
  { {0x6d5e0dbe, 0x62810dbf, 0x26c500c4, 0x00000000}},  //   _lupa, falo, _falo_,
  { {0xe3af05f3, 0x6281006a, 0x26c50dc0, 0x00000000}},  //   اري_, galo, _galo_,
  { {0xb5ca03e6, 0x6d5e00c8, 0x68e90022, 0x00000000}},  //   _دوام_, _nupa, _yoed,
  { {0x3f99049d, 0x38660dc1, 0x63a4001a, 0x00000000}},  //   tusu_, ncor_, _ţinu,
  { {0x6281002d, 0x6d5e0dc2, 0xe50503ec, 0x00000000}},  //   balo, _aupa, _تبلي,
  { {0x6d5e023a, 0x628a0030, 0x26c50011, 0x00000000}},  //   _bupa, _udfo, _xalo_,
  { {0xa2a101f5, 0x7e7e0740, 0x63ac0dc3, 0x00000000}},  //   _खात्, _depp, žinč,
  { {0x291c0dc4, 0x5d54012c, 0xa3c00061, 0x00000000}},  //   éval_, екст, _ंना_,
  { {0x68e9018e, 0x201e011f, 0xd008012b, 0x00000000}},  // [1570] _roed, ştir_, _неће_,
  { {0x765a001c, 0x68fb001e, 0x7cf80047, 0x00000000}},  //   _ngty, _slud, _hírl,
  { {0xed5800ed, 0x68fb0dc5, 0x68e90112, 0x00000000}},  //   _ноќ_, _plud, _poed,
  { {0xf990031d, 0x6281016c, 0x61360010, 0x00000000}},  //   ابل_, zalo, táli,
  { {0x2b93089d, 0x37ab005e, 0x68e901b5, 0x00000000}},  //   _سیاس, стен_, _voed,
  { {0x61360010, 0x8f9c00a0, 0x68e901bb, 0x00000000}},  //   ráli, מידי, _woed,
  { {0x62810dc6, 0x68e90116, 0x26c500b0, 0x00000000}},  //   valo, _toed, _valo_,
  { {0x26c50058, 0x68fb014a, 0x290d0032, 0x00000000}},  //   _walo_, _ulud, _umea_,
  { {0xa2a102d2, 0x26c50dc7, 0x7f5f002b, 0x00000000}},  //   _खाद्, _talo_, _nuqq,
  { {0x7bcd0dc8, 0x21cc013e, 0x00000000, 0x00000000}},  //   ivau, _běh_,   ,
  { {0x7e7e0052, 0x387f0116, 0x63a40035, 0x00000000}},  //   _repp, _keur_, _ţint,
  { {0x6281006c, 0x7e7e0dc9, 0x6d5e01a3, 0x00000000}},  //   salo, _sepp, _rupa,
  { {0x6d5e0127, 0x387f00d4, 0xe8df0082, 0x00000000}},  //   _supa, _meur_, _nhọn_,
  { {0x387f028c, 0x56b50049, 0x6d5e0dca, 0x00000000}},  //   _leur_, ופֿן_, _pupa,
  { {0x6da305a5, 0xd10a0439, 0x00000000, 0x00000000}},  //   кира, _وقته_,   ,
  { {0x249f009f, 0x20560057, 0x63a90bb2, 0x00000000}},  //   ngum_, _отпр, oten,
  { {0x63a90dcb, 0xe8df001d, 0x38c60006, 0x00000000}},  // [1580] nten, _chọn_, _jūrų_,
  { {0x6d5e00b0, 0x63a90dcc, 0xc31f0044, 0x00000000}},  //   _tupa, iten, _নীতি_,
  { {0x63a90dcd, 0xf8da0061, 0x387f0dce, 0x00000000}},  //   hten, णालय, _beur_,
  { {0x63a90056, 0x00000000, 0x00000000, 0x00000000}},  //   kten,   ,   ,
  { {0x387f0343, 0x386606c2, 0x69da0091, 0x00000000}},  //   _deur_, rcor_, _šted,
  { {0x386600d4, 0x6136000c, 0xdcfc0006, 0x00000000}},  //   scor_, málu, turė,
  { {0x9418005f, 0x63a9000d, 0xceb300b6, 0x00000000}},  //   ərə_, eten, דיו_,
  { {0x63a90056, 0x2ca0006c, 0x387f0116, 0x00000000}},  //   ften, ngid_, _geur_,
  { {0x63a90dcf, 0x2ca0006c, 0x69e30035, 0x00000000}},  //   gten, igid_, ăteş,
  { {0x7cf1032e, 0x27320035, 0x00000000, 0x00000000}},  //   _hårt, râns_,   ,
  { {0x63a9095c, 0x6128014a, 0x2b580095, 0x00000000}},  //   aten, kıld, _mirc_,
  { {0x63a90dd0, 0x2b580943, 0x00000000, 0x00000000}},  //   bten, _lirc_,   ,
  { {0xa29401ff, 0x63a90dd1, 0x2bd2013d, 0x00000000}},  //   _залі, cten, सिफा,
  { {0x44260288, 0x24840145, 0x6d460dd2, 0x00000000}},  //   _ixo_, lamm_, _ahka,
  { {0x7bcd0009, 0x929b009b, 0xfcc7003b, 0x00000000}},  //   wvau, _ויות, мљам,
  { {0x2b580dd3, 0x2ca00dd4, 0x00000000, 0x00000000}},  //   _airc_, ggid_,   ,
  { {0x8aa7005e, 0x00000000, 0x00000000, 0x00000000}},  // [1590] дред,   ,   ,
  { {0x2b580dd5, 0x2d85008e, 0x7bcd0103, 0x00000000}},  //   _circ_, áles_, rvau,
  { {0x387f00f4, 0x63a90dd6, 0x13b70044, 0x00000000}},  //   _peur_, zten, জিয়,
  { {0x09b10055, 0x63a9000c, 0x4426098e, 0x00000000}},  //   ছিলা, yten, _oxo_,
  { {0x36690175, 0x6d4d0052, 0x387f00d9, 0x00000000}},  //   пало_, mmaa, _veur_,
  { {0xd246006d, 0x6d4d0128, 0x61360010, 0x00000000}},  //   _من_, lmaa, lált,
  { {0x442600c4, 0x6d4d0dd7, 0x644200e5, 0x00000000}},  //   _axo_, omaa, _azoi,
  { {0x6d4d0dd8, 0x61360010, 0xe3c80082, 0x00000000}},  //   nmaa, nált, _bự_,
  { {0x63a90dd9, 0x249f000c, 0xe3c80011, 0x00000000}},  //   uten, rgum_, _cự_,
  { {0x63a90dda, 0xe3c8001d, 0x8af0006b, 0x00000000}},  //   rten, _dự_, qqət,
  { {0x6d4d00bb, 0x6128019a, 0x2747013e, 0x00000000}},  //   kmaa, yıld, _vůně_,
  { {0xcea900b6, 0x00000000, 0x00000000, 0x00000000}},  //   _לי_,   ,   ,
  { {0xc4cf026c, 0x6d4d00c7, 0xdb1d0ddb, 0x00000000}},  //   _مےں_, dmaa, _assí,
  { {0x6d46008d, 0x6561002b, 0x6d4d0112, 0x00000000}},  //   _shka, _kulh, emaa,
  { {0x656102d5, 0xe816013d, 0x6128005a, 0x00000000}},  //   _julh, _देना_, tıld,
  { {0x656102d5, 0x6d4d0222, 0x6b96000c, 0x00000000}},  //   _mulh, gmaa, tryg,
  { {0xf1c9001d, 0x2ca00ddc, 0x6128005d, 0x00000000}},  // [15a0] _hạ_, rgid_, rıld,
  { {0x6b960190, 0x6d4d0103, 0x61280095, 0x00000000}},  //   rryg, amaa, sıld,
  { {0x6128005a, 0x753b0161, 0x499a0147, 0x00000000}},  //   pıld, kluz, ятая_,
  { {0xf1c90011, 0x57a6017a, 0x6d4600b0, 0x00000000}},  //   _mạ_, ешка, _uhka,
  { {0xf1c9001d, 0xe73a0081, 0x69c30030, 0x00000000}},  //   _lạ_, пед_, æner,
  { {0x7bc60119, 0xe5c6064b, 0x8f9b01ce, 0x00000000}},  //   _isku, есио, פיצי,
  { {0xe3c800ad, 0xf1c90011, 0x24840d24, 0x00000000}},  //   _sự_, _nạ_, tamm_,
  { {0x2d98008e, 0x38c800a1, 0x7d040ddd, 0x00000000}},  //   irre_, _غازی_, nhis,
  { {0xd90d01ef, 0xe8b5005d, 0x00000000, 0x00000000}},  //   _بین_, lışı,   ,
  { {0x7aee0bc7, 0xf1c90011, 0x78a200ca, 0x00000000}},  //   _jobt, _bạ_, lgov,
  { {0xe8b502b9, 0x61360daf, 0x7d0402e1, 0x00000000}},  //   nışı, jáls, khis,
  { {0xe3c8001d, 0x78a201ca, 0x7bc6006c, 0x00000000}},  //   _tự_, ngov, _osku,
  { {0x04570054, 0x7d040020, 0x61360010, 0x00000000}},  //   _كلمة_, dhis, vált,
  { {0x3ea50047, 0x1ee70014, 0xbe0500a1, 0x00000000}},  //   ült_, روزی_, پورٹ,
  { {0x7bc60065, 0x6d4d01b5, 0x00000000, 0x00000000}},  //   _asku, tmaa,   ,
  { {0x23b7007d, 0xd9040014, 0xe8b501df, 0x00000000}},  //   _अहमद, _طی_, dışı,
  { {0x6d4d0dde, 0x61360ddf, 0x78a20de0, 0x00000000}},  // [15b0] rmaa, rált, dgov,
  { {0xadf5008b, 0x6d4d006c, 0xab180088, 0x00000000}},  //   _апош, smaa, нієї_,
  { {0x7bc6022b, 0xf1c90011, 0x6d4d07a5, 0x00000000}},  //   _esku, _xạ_, pmaa,
  { {0x7d04001a, 0x38c904e1, 0x57f500e2, 0x00000000}},  //   chis, بائی_, кпет,
  { {0xa2a10061, 0x8af0013f, 0x00000000, 0x00000000}},  //   _खाल्, rqər,   ,
  { {0x7aee0254, 0x65610de1, 0x00000000, 0x00000000}},  //   _gobt, _pulh,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3ce9021c, 0x69c701ed, 0x00000000, 0x00000000}},  //   njav_, _isje,   ,
  { {0x3f8b0036, 0xd4680025, 0x753b0de2, 0x00000000}},  //   jscu_, رحيم_, rluz,
  { {0x753b037e, 0x7790026c, 0x69d50036, 0x00000000}},  //   sluz, _ایوا, _krze,
  { {0x3f8b0de3, 0x7d040de4, 0x00000000, 0x00000000}},  //   escu_, yhis,   ,
  { {0x69d50de5, 0xdddc0521, 0xf1c90082, 0x00000000}},  //   _mrze, jarš, _vạ_,
  { {0xc9520049, 0x00000000, 0x00000000, 0x00000000}},  //   ימט_,   ,   ,
  { {0x69c70182, 0x78a20119, 0xf1c90011, 0x00000000}},  //   _osje, zgov, _tạ_,
  { {0x386d0de6, 0xe8b5006b, 0x2d980032, 0x00000000}},  //   _ofer_, xışı, urre_,
  { {0x62830de7, 0x7aee00d4, 0xad390088, 0x00000000}},  //   _heno, _sobt, ечує_,
  { {0x7d040056, 0x69c700d9, 0xc0c9003b, 0x00000000}},  // [15c0] rhis, _asje, _чује_,
  { {0x628300b9, 0x7d040de8, 0x386d0065, 0x00000000}},  //   _jeno, shis, _afer_,
  { {0x62830de9, 0x7d0400f4, 0x1d0a0751, 0x00000000}},  //   _meno, phis, _жени_,
  { {0x62830dea, 0xe8b5005d, 0x69d50036, 0x00000000}},  //   _leno, rışı, _drze,
  { {0x98a30242, 0x7bc60deb, 0x69d5010f, 0x00000000}},  //   риче, _usku, _erze,
  { {0x62830dec, 0x799e0061, 0x473301e1, 0x00000000}},  //   _neno, pupw, аніс,
  { {0x69d50036, 0x27e0001a, 0x09e3007c, 0x00000000}},  //   _grze, ţin_, _корн,
  { {0x62830982, 0x00000000, 0x00000000, 0x00000000}},  //   _aeno,   ,   ,
  { {0x62830de7, 0x7d03001a, 0x7cf800fa, 0x00000000}},  //   _beno, _înse, _círi,
  { {0x62830161, 0x7cf80051, 0xe6c50025, 0x00000000}},  //   _ceno, _díri, _متمي,
  { {0x26de0038, 0xe816007d, 0x31c3005e, 0x00000000}},  //   _into_, _देता_, асяв,
  { {0x29060ded, 0x7cf80051, 0x26cc0145, 0x00000000}},  //   nhoa_, _fíri, _hado_,
  { {0x26cc0dee, 0x7cf80def, 0x9443009e, 0x00000000}},  //   _kado_, _gíri, _پھٹن,
  { {0x62830a5e, 0x26cc021c, 0xe57100a1, 0x00000000}},  //   _geno, _jado_, _خطے_,
  { {0x628808cb, 0x63a00149, 0x823300a6, 0x00000000}},  //   mado, lumn, _پروا,
  { {0x26cc029d, 0x6283016c, 0x00000000, 0x00000000}},  //   _lado_, _zeno,   ,
  { {0xac18003b, 0x26de00ab, 0x2b4a0009, 0x00000000}},  // [15d0] воту_, _onto_, _bhbc_,
  { {0x69d50df0, 0x62880977, 0x62830df1, 0x00000000}},  //   _prze, nado, _xeno,
  { {0xb0aa0183, 0x61280279, 0xed4e00a1, 0x00000000}},  //   _कामग, lıla, تھی_,
  { {0xf1b3007b, 0x62880471, 0x63a0008a, 0x00000000}},  //   יסע_, hado, kumn,
  { {0x26cc000b, 0x6128047f, 0x60cd0b48, 0x00000000}},  //   _bado_, nıla, _maam,
  { {0x69d50046, 0x62880211, 0x6d5d0df2, 0x00000000}},  //   _trze, jado, _hisa,
  { {0x6d5d0127, 0x62880df3, 0x26cc0489, 0x00000000}},  //   _kisa, dado, _dado_,
  { {0x62830006, 0x23ab0018, 0x6d5d0020, 0x00000000}},  //   _seno, tøj_, _jisa,
  { {0x6b8d02d5, 0x62830df4, 0x62880df5, 0x00000000}},  //   nsag, _peno, fado,
  { {0x6d5d0004, 0x61280279, 0x26cc0df6, 0x00000000}},  //   _lisa, dıla, _gado_,
  { {0x62830142, 0x60cd0011, 0x0596025a, 0x00000000}},  //   _veno, _baam, _مانگ,
  { {0x6d5d0df7, 0x6b8d016c, 0xd5fa0049, 0x00000000}},  //   _nisa, ksag, _אפער,
  { {0x6128014a, 0xe2990900, 0x26cc0045, 0x00000000}},  //   gıla, _зал_, _yado_,
  { {0x62880df8, 0x33920025, 0x48160049, 0x00000000}},  //   cado, _الوز, אַלן_,
  { {0x6d5d011c, 0x78a90107, 0xb1760011, 0x00000000}},  //   _bisa, _ocev, _trượ,
  { {0x6d5d0690, 0x6b8d000c, 0x6128026d, 0x00000000}},  //   _cisa, fsag, bıla,
  { {0x61280676, 0xeb97007c, 0x6b8d011c, 0x00000000}},  // [15e0] cıla, лит_, gsag,
  { {0x4e3606b4, 0x78a9008e, 0x6d5d0ba5, 0x00000000}},  //   _معجز, _acev, _eisa,
  { {0x6d5d00e7, 0x69c500d9, 0x26cc0a76, 0x00000000}},  //   _fisa, gwhe, _rado_,
  { {0x62880df9, 0x613d0dfa, 0x26cc0065, 0x00000000}},  //   zado, téli, _sado_,
  { {0x01370049, 0x62880dfb, 0x2796030d, 0x00000000}},  //   אָגט_, yado, ушер,
  { {0x62880181, 0x613d09af, 0x6d5d0dfc, 0x00000000}},  //   xado, réli, _zisa,
  { {0xe1e7025a, 0x6288029d, 0x612801f6, 0x00000000}},  //   _اس_, vado, zıla,
  { {0x443d018e, 0x6128005d, 0xd37a00e3, 0x00000000}},  //   _byw_, yıla, нчо_,
  { {0x62880977, 0x60cd0004, 0x29040dfd, 0x00000000}},  //   tado, _raam, _ilma_,
  { {0x60cd0dfe, 0x63a00dff, 0xc8790279, 0x00000000}},  //   _saam, rumn, _inşa_,
  { {0x628800d6, 0x63a00e00, 0xba9b0049, 0x00000000}},  //   rado, sumn, עסטי,
  { {0x62880211, 0x6128005a, 0x443d0016, 0x00000000}},  //   sado, tıla, _fyw_,
  { {0x6d5d0cec, 0x62880142, 0x33f605f3, 0x00000000}},  //   _risa, pado, _حساس,
  { {0x6d5d0515, 0x6128038c, 0x60cd0020, 0x00000000}},  //   _sisa, rıla, _waam,
  { {0x69da0626, 0xbcfb00f4, 0x6b4b010f, 0x00000000}},  //   _šten, _liée, nüge,
  { {0x61280676, 0x6b8d0e01, 0x463b0049, 0x00000000}},  //   pıla, tsag, געלע,
  { {0x6d5d0995, 0x5b150c4e, 0xaae00316, 0x00000000}},  // [15f0] _visa, амат, नांक,
  { {0x6d5d023a, 0x6b8d010f, 0xa3d50309, 0x00000000}},  //   _wisa, rsag, हित_,
  { {0x6b8d0e02, 0x64b40061, 0xba470c18, 0x00000000}},  //   ssag, ंभाळ, ухай,
  { {0xd7d506e3, 0xc9130044, 0x69c502f1, 0x00000000}},  //   ижењ, িক্ত_, rwhe,
  { {0xdb040211, 0x212900d9, 0x00000000, 0x00000000}},  //   stiá, _mjah_,   ,
  { {0x6b4b010f, 0x443d0016, 0x2904014a, 0x00000000}},  //   füge, _ryw_, _elma_,
  { {0x5a44008b, 0xba74026c, 0xf77000a1, 0x00000000}},  //   _гэта, _چاہت, _ہال_,
  { {0x2d9e01ee, 0xe81601f5, 0xd6180025, 0x00000000}},  //   šteg_, _देवा_, دتها_,
  { {0xf77000a2, 0xab5b006c, 0x394d002d, 0x00000000}},  //   _فال_, _psüh, _ihes_,
  { {0x21290093, 0x57f4003b, 0x9814002c, 0x00000000}},  //   _ajah_, _упут, _طبقا,
  { {0xf8c9007d, 0x75dc00e5, 0x00000000, 0x00000000}},  //   _रसाय, _căză,   ,
  { {0x33d501e1, 0x24860197, 0x628e0e03, 0x00000000}},  //   _вікт, _geom_, óbor,
  { {0x9554004b, 0xa936009b, 0x320c0036, 0x00000000}},  //   _اخلا, שטרה_, azdy_,
  { {0x394d0181, 0xa856009b, 0x2cab0045, 0x00000000}},  //   _lhes_, יירה_, _accd_,
  { {0xe2da00a1, 0x63b5007f, 0x00000000, 0x00000000}},  //   _جانچ_, žanč,   ,
  { {0x25ed03d7, 0x395f00d4, 0x6f660098, 0x00000000}},  //   _अपनी_, _nius_, _квиз,
  { {0xed5701f9, 0x6b4b036c, 0x2cb90009, 0x00000000}},  // [1600] рот_, züge, _dbsd_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1c0b62, 0x7e9b009b, 0x395f099a, 0x00000000}},  //   mirc, _בסיו, _bius_,
  { {0x394d0462, 0x613d00d6, 0x00000000, 0x00000000}},  //   _ches_, bélu,   ,
  { {0x67d4025f, 0x395f0129, 0xe8160204, 0x00000000}},  //   солу, _dius_, _देशा_,
  { {0x7cf80e04, 0x9713013a, 0x3ce201c3, 0x00000000}},  //   _víru, оміц, _hnkv_,
  { {0x4420001a, 0x95ca0e05, 0x394d0087, 0x00000000}},  //   _ţi_, тула_, _fhes_,
  { {0x395f0026, 0xc4480014, 0x00000000, 0x00000000}},  //   _gius_, هیان_,   ,
  { {0x6f1c010f, 0x248601ee, 0xdb040374, 0x00000000}},  //   kirc, _veom_, rtiæ,
  { {0x212900d9, 0x00000000, 0x00000000, 0x00000000}},  //   _sjah_,   ,   ,
  { {0x8ad90049, 0x98af0089, 0x0566007c, 0x00000000}},  //   אַרפ, logā_, _твен,
  { {0x23660006, 0x25be00e7, 0xd5fb0049, 0x00000000}},  //   _tuoj_, _iptl_, _שפאר,
  { {0x69da00d0, 0x65680e06, 0x853500a1, 0x00000000}},  //   _štel, _hudh, _اونچ,
  { {0x65680020, 0x31670026, 0x7d060e07, 0x00000000}},  //   _kudh, _funz_, _alks,
  { {0xe297012b, 0x31670e08, 0x3eba00e0, 0x00000000}},  //   _тај_, _gunz_, _dbpt_,
  { {0x6568033b, 0x00000000, 0x00000000, 0x00000000}},  //   _mudh,   ,   ,
  { {0x6738022e, 0x2d580e09, 0x395f0129, 0x00000000}},  // [1610] kovj, рить_, _rius_,
  { {0x394d0e0a, 0x21390065, 0x6f1c0133, 0x00000000}},  //   _shes_, losh_, circ,
  { {0x395f0e0b, 0x9c830087, 0xdb1d01e5, 0x00000000}},  //   _pius_, _ščuk, _orsö,
  { {0x80c50044, 0x21390023, 0x00000000, 0x00000000}},  //   ষাক্, nosh_,   ,
  { {0x395f00d4, 0x2d910036, 0x386400d9, 0x00000000}},  //   _vius_, lsze_, _dgmr_,
  { {0x16a9005e, 0x6128006b, 0x2ca9006c, 0x00000000}},  //   увки_, yılo, lgad_,
  { {0x21390065, 0x394d0b97, 0xa49300a1, 0x00000000}},  //   kosh_, _thes_, قیات,
  { {0x2ca90013, 0x65680022, 0x7af50e0c, 0x00000000}},  //   ngad_, _dudh, _hozt,
  { {0x291d000b, 0x67380e0d, 0x21390023, 0x00000000}},  //   miwa_, bovj, dosh_,
  { {0x291d000b, 0xddde0428, 0xdb040e0e, 0x00000000}},  //   liwa_, _lepš, rtiç,
  { {0xdb0402d5, 0x7af50347, 0x2d910036, 0x00000000}},  //   stiç, _mozt, jsze_,
  { {0x291d0020, 0x21390023, 0x14ca0014, 0x00000000}},  //   niwa_, gosh_, _مهمی_,
  { {0xc50c0049, 0x9fd60044, 0xb05b00b0, 0x00000000}},  //   _בלאָ, সঙ্গ, seän,
  { {0x6568023a, 0x644b0e0f, 0x291d0020, 0x00000000}},  //   _yudh, _izgi, hiwa_,
  { {0x291d000b, 0x6b500073, 0xf2d20049, 0x00000000}},  //   kiwa_, lägg, _מעג_,
  { {0x3c66008b, 0x291d0e10, 0x2ca90039, 0x00000000}},  //   скаг, jiwa_, ggad_,
  { {0x6128047f, 0x291d0020, 0x6f1c0e11, 0x00000000}},  // [1620] nılm, diwa_, pirc,
  { {0xbcfb009d, 0x60c60010, 0x00000000, 0x00000000}},  //   _piéc, lekm,   ,
  { {0x8db60088, 0x291d0020, 0x7c2f0835, 0x00000000}},  //   _успі, fiwa_, _excr,
  { {0x6128014a, 0x291d0020, 0xc9850025, 0x00000000}},  //   kılm, giwa_, تشكي,
  { {0xc7a302a8, 0x31b10010, 0x65680e12, 0x00000000}},  //   зичк, ház_, _sudh,
  { {0x6128005f, 0x6d4402f1, 0x09e60265, 0x00000000}},  //   dılm, llia, _логн,
  { {0x6d44018e, 0x291d0020, 0x690700c4, 0x00000000}},  //   olia, biwa_, órdã,
  { {0x69dc049a, 0x6d440051, 0x53980ae0, 0x00000000}},  //   _irre, nlia, авия_,
  { {0x2d850211, 0x6738016e, 0xe8df0011, 0x00000000}},  //   ález_, povj, _nhộn_,
  { {0x6d440027, 0x91b800e2, 0x65680232, 0x00000000}},  //   hlia, агот_, _tudh,
  { {0xe3af089d, 0x6d440e13, 0x21390065, 0x00000000}},  //   وری_, klia, tosh_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d910046, 0x6d440e14, 0x21390065, 0x00000000}},  //   wsze_, dlia, rosh_,
  { {0x291d0e15, 0x69dc002d, 0x21390065, 0x00000000}},  //   ziwa_, _orre, sosh_,
  { {0x8cda0061, 0x7af5067f, 0x2d850e16, 0x00000000}},  //   _पोहो, _rozt, èle_,
  { {0x6d440198, 0x2d910e17, 0x91e3003b, 0x00000000}},  //   glia, rsze_, _хоће,
  { {0x69ce002b, 0x2ca90dac, 0x7af5002d, 0x00000000}},  // [1630] _asbe, rgad_, _pozt,
  { {0x2d910036, 0x6d440e18, 0xaa67007e, 0x00000000}},  //   psze_, alia, стак,
  { {0x291d000b, 0x6128005d, 0x7d03001a, 0x00000000}},  //   tiwa_, zılm, _înso,
  { {0x61280279, 0x628a0010, 0xdcfc0089, 0x00000000}},  //   yılm, _lefo, rurģ,
  { {0x69dc0756, 0x62980027, 0x291d0e19, 0x00000000}},  //   _erre, _odvo, riwa_,
  { {0x7d0d0047, 0x291d0e1a, 0xdb0d0051, 0x00000000}},  //   lhas, siwa_, otaí,
  { {0x24e90265, 0x65620061, 0xceb4019b, 0x00000000}},  //   имки_, _bioh, פיק_,
  { {0x6128005a, 0x7d0d00b0, 0x62980335, 0x00000000}},  //   tılm, nhas, _advo,
  { {0x628a0038, 0x13090e1b, 0xd6ab0439, 0x00000000}},  //   _befo, иний_, _مدام_,
  { {0x6128038c, 0xe299025f, 0x42250b11, 0x00000000}},  //   rılm, јан_, ждов,
  { {0x26c70e1c, 0x90c60604, 0x6d440016, 0x00000000}},  //   meno_, обне, ylia,
  { {0xf992019b, 0x7bcf0e1d, 0x61280676, 0x00000000}},  //   ורט_, _oscu, pılm,
  { {0x6b500a5d, 0x7529000d, 0x60c6014a, 0x00000000}},  //   läge, mnez, rekm,
  { {0x26c7000b, 0x6d44018e, 0x753b01aa, 0x00000000}},  //   neno_, wlia, louz,
  { {0x62810e1e, 0x7bcf000d, 0x7529031a, 0x00000000}},  //   mblo, _ascu, onez,
  { {0x62810007, 0x6d440e1f, 0x26c70e20, 0x00000000}},  //   lblo, ulia, heno_,
  { {0x8c43004d, 0x26c704a5, 0x6d560048, 0x00000000}},  // [1640] дете, keno_, rmya,
  { {0x26c7089f, 0xb0aa001c, 0x00000000, 0x00000000}},  //   jeno_, _काँग,   ,
  { {0x26c70c76, 0x7bcf0219, 0x7d0d0e21, 0x00000000}},  //   deno_, _escu, bhas,
  { {0x7d0d0e22, 0x31ba007b, 0xdb040051, 0x00000000}},  //   chas, יזענ, ntiú,
  { {0x765f005f, 0x75290173, 0x628100f8, 0x00000000}},  //   əyyə, dnez, kblo,
  { {0x6281037e, 0x26c70555, 0x7d04021e, 0x00000000}},  //   jblo, geno_, lkis,
  { {0xb0aa03d7, 0x69dc0ab3, 0x69ce010e, 0x00000000}},  //   _कांग, _urre, _usbe,
  { {0x7d040e23, 0x75290010, 0x62810e24, 0x00000000}},  //   nkis, gnez, eblo,
  { {0x628a000a, 0x3946010f, 0x26c70e25, 0x00000000}},  //   _pefo, mlos_, beno_,
  { {0x39460845, 0x26c70e26, 0x20d70082, 0x00000000}},  //   llos_, ceno_, _ủi_,
  { {0x753b013e, 0xdb04004a, 0xb5ca0014, 0x00000000}},  //   bouz, guié, _خوام_,
  { {0x3946001f, 0x657a0010, 0x00000000, 0x00000000}},  //   nlos_, _itth,   ,
  { {0x3946008e, 0x628100f8, 0x00000000, 0x00000000}},  //   ilos_, bblo,   ,
  { {0x62810e27, 0xdb040e28, 0xf1a6003b, 0x00000000}},  //   cblo, quiè, _дрин,
  { {0x7d0d0e29, 0xf27b00b6, 0x3946010a, 0x00000000}},  //   thas, _דרוש, klos_,
  { {0xdb04002a, 0x26c700b9, 0x7d040e2a, 0x00000000}},  //   ctiú, zeno_, gkis,
  { {0x7d0d04fa, 0xdb0d0051, 0x00000000, 0x00000000}},  // [1650] rhas, staí,   ,
  { {0x7d0d06d0, 0x657a0047, 0x3946008e, 0x00000000}},  //   shas, _otth, elos_,
  { {0xceb20097, 0x7d0d00ab, 0x753b00e7, 0x00000000}},  //   _איי_, phas, youz,
  { {0x7d040c43, 0x39460211, 0x6b500e2b, 0x00000000}},  //   ckis, glos_, väge,
  { {0x7bdd0de1, 0x60dc007b, 0x26c70059, 0x00000000}},  //   _ursu, יקאנ, teno_,
  { {0x62810030, 0xff7c01ce, 0x3946004a, 0x00000000}},  //   xblo, סטומ, alos_,
  { {0x80ac001c, 0x39460211, 0x26c70091, 0x00000000}},  //   _झाले, blos_, reno_,
  { {0x61360047, 0x39460325, 0x6b50010f, 0x00000000}},  //   bály, clos_, räge,
  { {0x628100eb, 0x6b500210, 0x75290035, 0x00000000}},  //   tblo, säge, rnez,
  { {0x13090783, 0x753b00b9, 0x00000000, 0x00000000}},  //   сной_, souz,   ,
  { {0x62810039, 0x7d040193, 0x753b049c, 0x00000000}},  //   rblo, ykis, pouz,
  { {0x62810af1, 0xbcfb02a0, 0x00000000, 0x00000000}},  //   sblo, _sién,   ,
  { {0x4aac0061, 0xb4d7007d, 0x628106ba, 0x00000000}},  //   _चालव, ायी_, pblo,
  { {0x3f9e0161, 0x63a900e7, 0x3ebe000c, 0x00000000}},  //   čtu_, muen, ýtt_,
  { {0x7d040e2c, 0xdb04009d, 0xbcfb004a, 0x00000000}},  //   tkis, quié, _vién,
  { {0x2571009f, 0x41b20025, 0xa01b000c, 0x00000000}},  //   _mál_, _أمير, mbön,
  { {0x7d040e2d, 0xfbdf00c4, 0x63a90e2e, 0x00000000}},  // [1660] rkis, _crê_, nuen,
  { {0x7d040263, 0xa3dc0309, 0x6ea800a1, 0x00000000}},  //   skis, डित_, _بندہ_,
  { {0x9d4600ed, 0x60d6014a, 0x63a9004a, 0x00000000}},  //   _неод, _kaym, huen,
  { {0x63a90e2f, 0x7ae70065, 0x61360010, 0x00000000}},  //   kuen, _enjt, tály,
  { {0x39460977, 0xe81603d7, 0x2efa010f, 0x00000000}},  //   rlos_, _देखा_, _kopf_,
  { {0x61360010, 0x394601a2, 0x4e7a0049, 0x00000000}},  //   rály, slos_, זאַצ,
  { {0x39460e30, 0x00000000, 0x00000000, 0x00000000}},  //   plos_,   ,   ,
  { {0x399b00b6, 0x257100b9, 0xd3a60088, 0x00000000}},  //   _לילד, _dál_, проп,
  { {0x63a90198, 0x07a300ed, 0x00000000, 0x00000000}},  //   guen, _патн,   ,
  { {0xa3ab013d, 0x877b00a3, 0x957c0036, 0x00000000}},  //   गढ़_, _לאמי, _prąd,
  { {0x29060e31, 0xbcfb009d, 0x00000000, 0x00000000}},  //   okoa_, _biél,   ,
  { {0x63a90e32, 0x29060e33, 0x644e006b, 0x00000000}},  //   buen, nkoa_, əbin,
  { {0x63a90219, 0x5f940265, 0xe8df0082, 0x00000000}},  //   cuen, ният, _nhờn_,
  { {0x7d1d00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _smss,   ,   ,
  { {0xb2bb009b, 0x290600b0, 0x2d9e0091, 0x00000000}},  //   _המור, kkoa_, šten_,
  { {0x614406e3, 0x60d60203, 0x9d1801ee, 0x00000000}},  //   _пеја, _gaym, пост_,
  { {0xa3d503d7, 0xe8df0082, 0x00000000, 0x00000000}},  // [1670] हिए_, _chờn_,   ,
  { {0xc87900e5, 0x00000000, 0x00000000, 0x00000000}},  //   _inşi_,   ,   ,
  { {0x63a9002d, 0x30a600a1, 0x5d550745, 0x00000000}},  //   zuen, _علیہ, _окот,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb1601aa, 0x25710e34, 0x63a90032, 0x00000000}},  //   ktyè, _sál_, xuen,
  { {0x8579007c, 0x25710e35, 0x00000000, 0x00000000}},  //   осит_, _pál_,   ,
  { {0x69da01d9, 0x20020036, 0xd6ce0439, 0x00000000}},  //   _štev, zyki_, شقي_,
  { {0x63a9022b, 0xb4d700e8, 0x6b4b010f, 0x00000000}},  //   tuen, ाये_, zügl,
  { {0x68e90412, 0x2be0006e, 0x29070e36, 0x00000000}},  //   _ined, निया, ūnas_,
  { {0x68fb02ae, 0x63a9002d, 0x60d60279, 0x00000000}},  //   _houd, ruen, _saym,
  { {0xa0a6008b, 0x6723016c, 0x68fb0e37, 0x00000000}},  //   манд, minj, _koud,
  { {0x67230e38, 0x20020036, 0x68fb0b60, 0x00000000}},  //   linj, tyki_, _joud,
  { {0x68fb013e, 0x21220127, 0xe2990069, 0x00000000}},  //   _moud, rikh_, _дал_,
  { {0x2906022b, 0x672304be, 0x7f19007e, 0x00000000}},  //   zkoa_, ninj, пісу_,
  { {0xa3d5007d, 0x6e4301fc, 0xdd1c0161, 0x00000000}},  //   हिक_, верз, _vážn,
  { {0x672300ee, 0xdb0d010f, 0x68fb0158, 0x00000000}},  //   hinj, traß, _noud,
  { {0x67230295, 0xab66007e, 0x6f1e0009, 0x00000000}},  // [1680] kinj, двал, _tmpc,
  { {0x290d04f8, 0x68e9005b, 0x68fb01f3, 0x00000000}},  //   _alea_, _aned, _aoud,
  { {0x672300ee, 0x68fb0e39, 0x6b960190, 0x00000000}},  //   dinj, _boud, ssyg,
  { {0xc7c60072, 0x66030036, 0x68fb009d, 0x00000000}},  //   дски, dynk, _coud,
  { {0x4c36008b, 0x68fb009d, 0x29060d17, 0x00000000}},  //   _цэнт, _doud, rkoa_,
  { {0x29060e3a, 0x67230e3b, 0x68e9005b, 0x00000000}},  //   skoa_, ginj, _ened,
  { {0x68fb009d, 0x290d0133, 0x7afc0288, 0x00000000}},  //   _foud, _flea_, _iort,
  { {0x7afc002d, 0x25a00e3c, 0x68fb00b5, 0x00000000}},  //   _hort, čil_, _goud,
  { {0x644e0036, 0x672304eb, 0x06bd0044, 0x00000000}},  //   ębio, binj, _আফরি,
  { {0x6723037e, 0x68fb00b5, 0x291f012d, 0x00000000}},  //   cinj, _zoud, _zmua_,
  { {0x36060076, 0x2d9e00b9, 0x66e30143, 0x00000000}},  //   _تواف, átel_, _јоха,
  { {0x7afc022b, 0x849600a1, 0xd1310379, 0x00000000}},  //   _lort, _آجائ, امح_,
  { {0x7afc0007, 0x2d9e0e3d, 0x00000000, 0x00000000}},  //   _oort, štel_,   ,
  { {0x7afc0e3e, 0x00000000, 0x00000000, 0x00000000}},  //   _nort,   ,   ,
  { {0xa3d6007d, 0x7bc60e3f, 0x64550036, 0x00000000}},  //   ाटक_, _apku, ęzie,
  { {0x7afc0e40, 0x506700aa, 0x6ca40081, 0x00000000}},  //   _aort, _отпа, круж,
  { {0xdb0d02d5, 0x3b5500e3, 0x68fb013e, 0x00000000}},  // [1690] ntaç, екар, _roud,
  { {0x7afc08d3, 0x68fb00b9, 0x68e9032e, 0x00000000}},  //   _cort, _soud, _sned,
  { {0x67230925, 0x68fb0e41, 0x7afc0e42, 0x00000000}},  //   vinj, _poud, _dort,
  { {0x2d8300bb, 0x3835041f, 0x00000000, 0x00000000}},  //   mpje_, ннер,   ,
  { {0x7afc004e, 0x67230119, 0x68fb00f4, 0x00000000}},  //   _fort, tinj, _voud,
  { {0xe73306dd, 0x7afc0add, 0x68fb0328, 0x00000000}},  //   خصص_, _gort, _woud,
  { {0xe81f03d7, 0x67230059, 0x23670065, 0x00000000}},  //   _मेरा_, rinj, _rinj_,
  { {0x6723002b, 0x67d50088, 0x68e90016, 0x00000000}},  //   sinj, _побу, _uned,
  { {0x3735007e, 0x386d0e43, 0x75d3006b, 0x00000000}},  //   _знаё, _iger_, _məzə,
  { {0xcb12007b, 0xfbd2009b, 0x7afc002b, 0x00000000}},  //   ָלט_, נתי_, _xort,
  { {0x76480e44, 0x0322008b, 0xe1260088, 0x00000000}},  //   _gydy, удэн, емни,
  { {0x75d3005f, 0x70aa0061, 0xab5b01a2, 0x00000000}},  //   _nəzə, कलेल, _spül,
  { {0x3169008e, 0x13f4005e, 0x2d8300bb, 0x00000000}},  //   _diaz_, _изця, epje_,
  { {0x63bb0020, 0x2d9e0e45, 0x61ee0048, 0x00000000}},  //   mtun, štem_, óilí,
  { {0x63bb001f, 0x2f140073, 0x2d8c00f4, 0x00000000}},  //   ltun, _lägg_, ède_,
  { {0x7afc0e46, 0xc5f20049, 0x00000000, 0x00000000}},  //   _sort, נדן_,   ,
  { {0x63bb020c, 0x60c40009, 0xe81f007d, 0x00000000}},  // [16a0] ntun, _ibim, _मेला_,
  { {0x63bb001f, 0x7afc0226, 0x4e1c0044, 0x00000000}},  //   itun, _qort, _দুঃখ_,
  { {0x7afc04b2, 0x63bb0e47, 0xfbdf0011, 0x00000000}},  //   _vort, htun, _uyên_,
  { {0x7648018e, 0x63bb0e48, 0x7afc01ac, 0x00000000}},  //   _rydy, ktun, _wort,
  { {0x6d460ab5, 0x69d50e49, 0x7afc0e4a, 0x00000000}},  //   _ikka, _esze, _tort,
  { {0x6b840e4b, 0x63bb0e4c, 0x98c50089, 0x00000000}},  //   mpig, dtun, ītās_,
  { {0x60c40107, 0xceb30049, 0x63bb0e4d, 0x00000000}},  //   _obim, טיג_, etun,
  { {0x75d3005f, 0x63bb010f, 0x6721012d, 0x00000000}},  //   _xəzə, ftun, _emlj,
  { {0xd4e30057, 0x63bb00e0, 0xdb04009d, 0x00000000}},  //   ующи, gtun, triè,
  { {0x60c40e4e, 0xdb0d0e4f, 0x0bb7009b, 0x00000000}},  //   _abim, rtaç, עלים_,
  { {0x6d46009f, 0xdb0400f4, 0xdb0d0181, 0x00000000}},  //   _okka, rriè, staç,
  { {0xdb0d0181, 0x26ce000a, 0x6d460e50, 0x00000000}},  //   ptaç, lefo_, _nkka,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x545301fb, 0x6d460e51, 0x320501dc, 0x00000000}},  //   _світ, _akka, byly_,
  { {0x720300a1, 0x7c87003b, 0xac950aed, 0x00000000}},  //   _مووم, еузе, кавш,
  { {0x75d3006b, 0x38690e3b, 0xdb0f013f, 0x00000000}},  //   _qəzə, žari_, şdür,
  { {0x69c70e52, 0x8aa7041f, 0xfaa70242, 0x00000000}},  // [16b0] _spje, еред, ешен,
  { {0x60dd08e0, 0x6d46020b, 0x2fc90058, 0x00000000}},  //   ldsm, _ekka, _ipag_,
  { {0xf9930d3a, 0x7dc40752, 0x63bb028d, 0x00000000}},  //   ابط_, _یقین, ztun,
  { {0x60dd000c, 0x2d810051, 0x63bb0016, 0x00000000}},  //   ndsm, _ithe_, ytun,
  { {0xb8c903d7, 0x69d50046, 0x60dd0112, 0x00000000}},  //   _गए_, _wsze, idsm,
  { {0x6d4d021e, 0x2f1400f8, 0x00000000, 0x00000000}},  //   llaa, _vägg_,   ,
  { {0xa3b30061, 0x6d46000c, 0x98c7003b, 0x00000000}},  //   जून_, _ykka, _псал,
  { {0x63bb0e53, 0x386d0030, 0x60dd0030, 0x00000000}},  //   ttun, _uger_, jdsm,
  { {0x63bb00b0, 0x7d03001a, 0x7c290e54, 0x00000000}},  //   utun, _însu, _žerj,
  { {0x63bb03a1, 0x613d0047, 0x75220e55, 0x00000000}},  //   rtun, mély, _emoz,
  { {0x6d4d0004, 0x3f80000d, 0x6b840032, 0x00000000}},  //   klaa, _stiu_, zpig,
  { {0xbcfb00c4, 0xdb040068, 0x00000000, 0x00000000}},  //   _fiéi, rrié,   ,
  { {0x889a009b, 0x2f140039, 0x6b8400ea, 0x00000000}},  //   וברי, _läge_, xpig,
  { {0x656b0038, 0xdb0400f4, 0x4ed50147, 0x00000000}},  //   _high, prié, люст,
  { {0x644b0387, 0x00000000, 0x00000000, 0x00000000}},  //   _hygi,   ,   ,
  { {0x63a90197, 0x6d4d011c, 0x657c0010, 0x00000000}},  //   oren, glaa, _érhe,
  { {0x656b0038, 0x63a90232, 0xeb9702b3, 0x00000000}},  // [16c0] _migh, nren, кит_,
  { {0x656b0038, 0x613d0010, 0x63a90dc0, 0x00000000}},  //   _ligh, dély, iren,
  { {0x63a9001f, 0x644b010a, 0x6d4d00c7, 0x00000000}},  //   hren, _lygi, blaa,
  { {0x656b0038, 0x63a90091, 0xdcfc0089, 0x00000000}},  //   _nigh, kren, bprā,
  { {0x63a90190, 0x68430e56, 0x6d440e57, 0x00000000}},  //   jren, анца, moia,
  { {0x63a90142, 0x656b0051, 0xd09a006b, 0x00000000}},  //   dren, _aigh, rçək,
  { {0xdb040841, 0x656b0058, 0x63a90125, 0x00000000}},  //   stió, _bigh, eren,
  { {0x63a90bf7, 0x6d44065d, 0x00000000, 0x00000000}},  //   fren, noia,   ,
  { {0x63a90e58, 0x656b0026, 0xdce6016c, 0x00000000}},  //   gren, _digh, _nikč,
  { {0x86ea0025, 0x656b00ab, 0x14ae0061, 0x00000000}},  //   _تعرف_, _eigh, _टाकण,
  { {0x63a9002d, 0x656b00ab, 0x2fc90066, 0x00000000}},  //   aren, _figh, _spag_,
  { {0x63a9011c, 0x94260057, 0x6913014a, 0x00000000}},  //   bren, _имее, _içec,
  { {0x60dd01c9, 0x6d440e57, 0x63a90e59, 0x00000000}},  //   rdsm, doia, cren,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7e280822, 0x6d4d0e5a, 0xb0ac006b, 0x00000000}},  //   віта_, tlaa, _şüşə,
  { {0xe7f3001c, 0x6d440032, 0x7d160016, 0x00000000}},  //   _आपला_, goia, ghys,
  { {0xdc5501f9, 0x6d4d00c7, 0xfbd00025, 0x00000000}},  // [16d0] увањ, rlaa, يتك_,
  { {0x6d4d01b5, 0x200401a2, 0x00000000, 0x00000000}},  //   slaa, ämie_,   ,
  { {0x6d4d0e5b, 0x63a90e5c, 0x6d440982, 0x00000000}},  //   plaa, zren, boia,
  { {0x63a9060a, 0xe0df0e5d, 0x6d4400f6, 0x00000000}},  //   yren, ndò_, coia,
  { {0x656b0866, 0x499300a1, 0xfd5601ce, 0x00000000}},  //   _righ, _چیئر, _תשרי_,
  { {0x7d0d0dcd, 0x63a90e5e, 0x656b0e5f, 0x00000000}},  //   lkas, vren, _sigh,
  { {0xdb040285, 0x656b0058, 0x63a9086a, 0x00000000}},  //   quiá, _pigh, wren,
  { {0x7d0d03fb, 0x25780010, 0x00000000, 0x00000000}},  //   nkas, _dél_,   ,
  { {0x63a90685, 0x7d0d00b0, 0x3835007c, 0x00000000}},  //   uren, ikas, _снар,
  { {0xe1f90057, 0x63a90e60, 0x25780010, 0x00000000}},  //   его_, rren, _fél_,
  { {0x7d0d003c, 0x656b00ab, 0x63a90e61, 0x00000000}},  //   kkas, _tigh, sren,
  { {0x6455005f, 0x7fb6007e, 0x7d0d0340, 0x00000000}},  //   əzin, лёгі, jkas,
  { {0x03a5013b, 0x7d0d006b, 0x6d440035, 0x00000000}},  //   _сило, dkas, voia,
  { {0xfd650082, 0x00000000, 0x00000000, 0x00000000}},  //   _truồ,   ,   ,
  { {0xc0e6005e, 0xdd1d00b9, 0xdb0400c4, 0x00000000}},  //   _бойк, lářs, luiç,
  { {0x7d0d0e62, 0xd24e0025, 0x75290035, 0x00000000}},  //   gkas, _عني_, niez,
  { {0x6eac013d, 0xdd1d00b9, 0xdb0400c4, 0x00000000}},  // [16e0] _जयपु, nářs, nuiç,
  { {0x7d0d00b0, 0x945d0036, 0x8a3a007c, 0x00000000}},  //   akas, leńs, няет_,
  { {0x8886005e, 0x7d160e63, 0x6d440e64, 0x00000000}},  //   глеж, phys, poia,
  { {0x7d0d04eb, 0x7aeb0089, 0xdb040e65, 0x00000000}},  //   ckas, ēgta, rtiñ,
  { {0xa3d20754, 0xdb04049a, 0x6ac90055, 0x00000000}},  //   _हैं_, stiñ, রয়ো,
  { {0xdd1d00b9, 0x3ce0010e, 0x00000000, 0x00000000}},  //   dářs, ldiv_,   ,
  { {0x645d009f, 0xceb300b6, 0xe5c602b8, 0x00000000}},  //   ýsin, ציה_, усло,
  { {0x7529002d, 0x3ce00b1b, 0x2578000c, 0x00000000}},  //   giez, ndiv_, _vél_,
  { {0x46b601fa, 0xdb0400c4, 0x28dd006e, 0x00000000}},  //   _محاس, guiç, _नोटि,
  { {0x39460a2a, 0x257800f4, 0x9bbb0049, 0x00000000}},  //   loos_, _tél_, עציפ,
  { {0xaac602f4, 0xd2500014, 0x80de0055, 0x00000000}},  //   र्यक, تند_, যান্,
  { {0xdb040181, 0x75290e66, 0x26de004a, 0x00000000}},  //   buiç, ciez, _hato_,
  { {0x7d0d0030, 0x26de0052, 0xa3b3013d, 0x00000000}},  //   vkas, _kato_, जूद_,
  { {0x26de00c4, 0x1ee70014, 0x3dda01a2, 0x00000000}},  //   _jato_, دوسی_, _bspw_,
  { {0xc27b007b, 0x26de0181, 0x7d0d0e67, 0x00000000}},  //   _ארוי, _mato_, tkas,
  { {0xf1a903d7, 0x26de0e68, 0x629a0e69, 0x00000000}},  //   _कितन, _lato_, lato,
  { {0x7d0d021e, 0x39460112, 0x212b0253, 0x00000000}},  // [16f0] rkas, doos_, mich_,
  { {0x629a000d, 0x212b001f, 0x26de070c, 0x00000000}},  //   nato, lich_, _nato_,
  { {0x987509e6, 0x00000000, 0x00000000, 0x00000000}},  //   алец,   ,   ,
  { {0x629a0e49, 0xaa6401ee, 0x00000000, 0x00000000}},  //   hato, стук,   ,
  { {0x26de0e6a, 0xbcfb0e6b, 0xab5b00f6, 0x00000000}},  //   _bato_, _diét, _aqüe,
  { {0x7ceb0073, 0x945d0036, 0x16a60407, 0x00000000}},  //   _förä, zeńs, авши_,
  { {0x212b0046, 0x629a0e6c, 0x2d9e0059, 0x00000000}},  //   kich_, dato, štev_,
  { {0x212b004f, 0xdb0402d5, 0x81cd0044, 0x00000000}},  //   jich_, tuiç, রিম_,
  { {0x26de0181, 0x80de0044, 0x629a00c4, 0x00000000}},  //   _fato_, যাম্, fato,
  { {0xa1c5008b, 0x26de0325, 0x1309007c, 0x00000000}},  //   абод, _gato_, тной_,
  { {0xcb1400b6, 0x75290211, 0x212b0e6d, 0x00000000}},  //   מלץ_, piez, fich_,
  { {0x75ca005f, 0x95670265, 0x26de01d9, 0x00000000}},  //   _qəze, _създ, _zato_,
  { {0x248d0181, 0x5edf0044, 0x2fdb01f3, 0x00000000}},  //   mbem_, মানে, _csqg_,
  { {0xb05b09b0, 0x629a0e6e, 0x6d5d00e7, 0x00000000}},  //   pfän, cato, _ahsa,
  { {0x212b0173, 0x78bb0107, 0xb05b0788, 0x00000000}},  //   bich_, _ocuv, lfäl,
  { {0x212b0e6f, 0x4fea00e2, 0x00000000, 0x00000000}},  //   cich_, _амин_,   ,
  { {0x998d0091, 0x8b260147, 0x3ce00e70, 0x00000000}},  // [1700] _ćeš_, адае, rdiv_,
  { {0x6d5d0e71, 0xfaa6091b, 0xdb0400b0, 0x00000000}},  //   _ehsa, ражо, htiö,
  { {0x26de0e72, 0xa2bd007d, 0xbcfb009d, 0x00000000}},  //   _rato_, _शान्, _piét,
  { {0x629a0e73, 0x497305b8, 0xbcfb004a, 0x00000000}},  //   zato, іліс, _diés,
  { {0xa81a01fa, 0x26de094f, 0x39460b1a, 0x00000000}},  //   ختار_, _pato_, roos_,
  { {0x212b00bb, 0xc9860014, 0x38af014a, 0x00000000}},  //   zich_, _نشري, törü_,
  { {0x629a0010, 0x80d70061, 0x26de0087, 0x00000000}},  //   vato, _बसले, _vato_,
  { {0x629a0e74, 0xd9430e75, 0x69dc007f, 0x00000000}},  //   wato, _деси, _isre,
  { {0x26de01c8, 0x5397008b, 0x672a0023, 0x00000000}},  //   _tato_, авыя_, pifj,
  { {0x68e00016, 0x29040020, 0x68e20168, 0x00000000}},  //   _hamd, _homa_, ldod,
  { {0xbcfb0e76, 0x2904009f, 0x212b0142, 0x00000000}},  //   _miér, _koma_, tich_,
  { {0x629a001a, 0x68e20065, 0x29040089, 0x00000000}},  //   sato, ndod, _joma_,
  { {0x629a0e77, 0x212b010f, 0x2f140073, 0x00000000}},  //   pato, rich_, _säga_,
  { {0x69dc0059, 0x290402c8, 0x69ce0e78, 0x00000000}},  //   _osre, _loma_, _opbe,
  { {0x2d8501b5, 0x4d2700ed, 0x7095005e, 0x00000000}},  //   ële_, аќаа, _лайф,
  { {0x2f140004, 0x5c750a27, 0x29040e79, 0x00000000}},  //   _väga_, слат, _noma_,
  { {0x68e2018e, 0x645c006b, 0x5ecc0044, 0x00000000}},  // [1710] ddod, əric, ায়ে,
  { {0xf1da03d7, 0x62980e7a, 0xa3d70061, 0x00000000}},  //   _बनान, _jevo, ाबत_,
  { {0xceb20049, 0xf8750025, 0x29040e7b, 0x00000000}},  //   _ציט_, مهاج, _boma_,
  { {0x29040b32, 0xc879027d, 0x68e00016, 0x00000000}},  //   _coma_, _başa_, _camd,
  { {0x27e90e7c, 0x29040b41, 0x68e0011c, 0x00000000}},  //   ían_, _doma_, _damd,
  { {0x62980e7d, 0x7bdd0038, 0x81cd0055, 0x00000000}},  //   _nevo, _issu, রিত_,
  { {0x63a20e7e, 0xe7f303d7, 0x2904012d, 0x00000000}},  //   _avon, _आपका_, _foma_,
  { {0xce38019b, 0x29040e7f, 0x25a90e80, 0x00000000}},  //   יאות_, _goma_, čal_,
  { {0x62980125, 0xa3d2006e, 0x00000000, 0x00000000}},  //   _bevo, हौल_,   ,
  { {0xf7700054, 0xc2e9026c, 0xb05b09b0, 0x00000000}},  //   _قال_, اعظم_, rfäl,
  { {0x7c3b009f, 0x62980e81, 0x41b40152, 0x00000000}},  //   _þurf, _devo, осят,
  { {0x628e000c, 0x80fa00e2, 0xc879019a, 0x00000000}},  //   ðbor, ухот_, _yaşa_,
  { {0xe28e0113, 0x43850054, 0x63850e82, 0x00000000}},  //   _на_, _التق, _угла,
  { {0x6298049b, 0xe7fa0061, 0x00000000, 0x00000000}},  //   _gevo, ्हता_,   ,
  { {0x63a20e83, 0x7bdd0e84, 0xa3b30309, 0x00000000}},  //   _zvon, _assu, जूर_,
  { {0x31a301f6, 0x62810adb, 0x61430e85, 0x00000000}},  //   mız_, lclo, _неща,
  { {0x29040198, 0xed5701f9, 0x68e0011c, 0x00000000}},  // [1720] _roma_, сот_, _ramd,
  { {0x628100d4, 0x29040020, 0x68e00e86, 0x00000000}},  //   nclo, _soma_, _samd,
  { {0x31a30676, 0x290400d4, 0xe0df0129, 0x00000000}},  //   nız_, _poma_, clòs_,
  { {0x75ca005f, 0x61fc03a2, 0x68e201ee, 0x00000000}},  //   _nəza, ärli, udod,
  { {0xe1e7089d, 0x68e20e87, 0x765a00b4, 0x00000000}},  //   _کس_, rdod, _szty,
  { {0x29040061, 0x27e60cba, 0x612f0173, 0x00000000}},  //   _woma_, rvon_, _kòlè,
  { {0x63a2009f, 0x6d41009f, 0x7bc406c2, 0x00000000}},  //   _svon, élag, ltiu,
  { {0x75ca006b, 0x7d060e88, 0x7644014a, 0x00000000}},  //   _cəza, _joks, şiyo,
  { {0x7d06010a, 0x5edf0044, 0x97bd0245, 0x00000000}},  //   _moks, মাতে, _архi,
  { {0x62810e89, 0x7d06000c, 0x00000000, 0x00000000}},  //   gclo, _loks,   ,
  { {0x60f90cf2, 0x14ca0057, 0x8afb0097, 0x00000000}},  //   ання_, _были_, אליז,
  { {0x63a2023a, 0x7d060056, 0x05660e8a, 0x00000000}},  //   _tvon, _noks, _увен,
  { {0x321e0036, 0x62980112, 0x25710091, 0x00000000}},  //   szty_, _tevo, _ušla_,
  { {0x543b007b, 0x657a0020, 0x612f0173, 0x00000000}},  //   _געדא, _kuth, _bòlè,
  { {0x91860318, 0x7d060292, 0x98bd00b4, 0x00000000}},  //   _اجتم, _boks, lową_,
  { {0x657a0e8b, 0x5d5501ff, 0x212901a3, 0x00000000}},  //   _muth, ікат, _umah_,
  { {0x2d58004c, 0x60cd00c4, 0xba990088, 0x00000000}},  // [1730] сить_, _ibam, иває_,
  { {0x2dd50256, 0x657a0203, 0x3f8900fa, 0x00000000}},  //   _джор, _outh, _itau_,
  { {0x5edf0044, 0x7d06006b, 0xc27b0049, 0x00000000}},  //   মাদে, _foks, ארבי,
  { {0xfbd000a1, 0x7d060e8c, 0x7644014a, 0x00000000}},  //   بتہ_, _goks, ğiyl,
  { {0x657a08ef, 0x7bc40d8a, 0x2b9300e9, 0x00000000}},  //   _auth, ctiu, _ریاس,
  { {0x6b8d0e8d, 0x31a3005a, 0x657a01c3, 0x00000000}},  //   mpag, yız_, _buth,
  { {0x6b8d0e8e, 0x451901e0, 0x7d06014a, 0x00000000}},  //   lpag, иция_, _yoks,
  { {0x69c50016, 0x75ca006b, 0xb385012c, 0x00000000}},  //   mthe, _qəza, олил,
  { {0x69c50e8f, 0x6b8d00b5, 0x78a90e90, 0x00000000}},  //   lthe, npag, _idev,
  { {0x69c507eb, 0x6b8d0e91, 0x60cd0e92, 0x00000000}},  //   othe, ipag, _abam,
  { {0x3f890149, 0x657a0e93, 0x69c50aba, 0x00000000}},  //   _atau_, _guth, nthe,
  { {0xe56e01fb, 0x69c5002a, 0x27ed04be, 0x00000000}},  //   _із_, ithe, _kren_,
  { {0x31a3005d, 0xb05b01a2, 0x225c00d9, 0x00000000}},  //   sız_, nfäh, _ezvk_,
  { {0x6b8d0e94, 0x69c50065, 0x7d060010, 0x00000000}},  //   dpag, kthe, _soks,
  { {0xec9a06e3, 0x6b8d00bb, 0x78a90142, 0x00000000}},  //   итај_, epag, _odev,
  { {0xa01b06d3, 0x6b8d0009, 0x78a900e7, 0x00000000}},  //   rbör, fpag, _ndev,
  { {0xdee60a27, 0x7d0601e3, 0x6b8d0e95, 0x00000000}},  // [1740] _допи, _voks, gpag,
  { {0x7bc40e96, 0x78a9000d, 0xab5b010f, 0x00000000}},  //   rtiu, _adev, _spür,
  { {0x27ed0e97, 0xe9da0175, 0x7bc40e98, 0x00000000}},  //   _aren_, рке_, stiu,
  { {0x6b8d00b5, 0x27ed005b, 0x7c3b0bf8, 0x00000000}},  //   bpag, _bren_, _žure,
  { {0x2ca0006c, 0x6b8d0050, 0xc7a302dc, 0x00000000}},  //   maid_, cpag, дичк,
  { {0x657a0065, 0x6d560e99, 0xb86500a1, 0x00000000}},  //   _puth, llya, سانو,
  { {0xd5b00054, 0x27ed00f6, 0x69c503b3, 0x00000000}},  //   رفة_, _eren_, cthe,
  { {0x291d0d16, 0x2ca00ddc, 0x4ac6013d, 0x00000000}},  //   chwa_, naid_, र्रव,
  { {0x27ed0239, 0x2be00061, 0xdddc04eb, 0x00000000}},  //   _gren_, निटा, jbrž,
  { {0xbcfb0051, 0x657a0e9a, 0xb6cb00a1, 0x00000000}},  //   _mhéa, _tuth, _نامے_,
  { {0x3f89001a, 0x2ca0006c, 0x660300ed, 0x00000000}},  //   _stau_, kaid_, _опфа,
  { {0x645c0163, 0x2ca00004, 0x6b8d0e9b, 0x00000000}},  //   ərin, jaid_, ypag,
  { {0xb4b602d2, 0xdb0400c4, 0xb4d60309, 0x00000000}},  //   जली_, criç, ाजी_,
  { {0xf651026c, 0xa3d7006e, 0x764d006b, 0x00000000}},  //   _آئے_, ाबर_, şaye,
  { {0x6b8d0061, 0xf1c300b9, 0xdb0d009d, 0x00000000}},  //   wpag, _vaší_, fraî,
  { {0xbcfb0051, 0x6b8d0e9c, 0x2ca00016, 0x00000000}},  //   _bhéa, tpag, gaid_,
  { {0xbcfb002a, 0x0ca8005e, 0x6b8d0e9d, 0x00000000}},  // [1750] _chéa, ютри_, upag,
  { {0xbcfb0195, 0x6b8d0e8e, 0x81cd0044, 0x00000000}},  //   _dhéa, rpag, রির_,
  { {0x13d30055, 0x693c0142, 0xa2bd0309, 0x00000000}},  //   ়িয়, rčen, _शास्,
  { {0x2ca00e9e, 0xbcfb002a, 0xa2ca024c, 0x00000000}},  //   caid_, _fhéa, त्त्,
  { {0x6cfa009b, 0xbcfb0051, 0x27ed00fa, 0x00000000}},  //   _הפרס, _ghéa, _qren_,
  { {0x291d000b, 0x69c50e9f, 0x3946016c, 0x00000000}},  //   shwa_, pthe, čosa_,
  { {0x6ecd007d, 0xb05b010f, 0xa8a701ee, 0x00000000}},  //   द्यु, sfäh, _мрак,
  { {0xd4d901fb, 0xdb040181, 0x2e3c01ce, 0x00000000}},  //   ські_, triç, יגונ,
  { {0x249f0ea0, 0xe3b10025, 0x27ed00b5, 0x00000000}},  //   raum_, ررة_, _uren_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb0d0ea1, 0x06760049, 0x00000000, 0x00000000}},  //   ntañ, _זײער_,   ,
  { {0xdb0d0116, 0x00000000, 0x00000000, 0x00000000}},  //   kraï,   ,   ,
  { {0x2ca00004, 0x65690190, 0x2458007e, 0x00000000}},  //   vaid_, mmeh, _даць_,
  { {0xd34300a1, 0x656901a2, 0x2ca0005b, 0x00000000}},  //   _تفتی, lmeh, waid_,
  { {0xdb0d00f4, 0xbcfb0051, 0x12fa009b, 0x00000000}},  //   traî, _shéa, _להסב,
  { {0x753b0026, 0x3b86078d, 0x656901a2, 0x00000000}},  //   nnuz, злаг, nmeh,
  { {0x1d070ea2, 0x6d5600e0, 0x25dd013d, 0x00000000}},  // [1760] чети_, rlya, _कैसी_,
  { {0x2ca0006c, 0x7c3b0ea3, 0xdb1c0276, 0x00000000}},  //   said_, _žurc, _üzüm,
  { {0x2ca00ea4, 0x6d5600e0, 0x49ca00c0, 0x00000000}},  //   paid_, plya, слен_,
  { {0xbcfb0ea5, 0x203300a1, 0x00000000, 0x00000000}},  //   _théa, _آفیس,   ,
  { {0xdb040007, 0x24c30044, 0x80ce0061, 0x00000000}},  //   nsië, ্যাহ, ध्ये,
  { {0x65620065, 0xdbc7006c, 0x7d040c31, 0x00000000}},  //   _shoh, tööt, ljis,
  { {0xdb040039, 0x7c24001a, 0x9f4001d6, 0x00000000}},  //   rriä, lzir, _asië_,
  { {0x48e30216, 0xdce4037e, 0x7d040173, 0x00000000}},  //   _посв, kmič, njis,
  { {0xd9430a94, 0x7c240ea6, 0xa2bd01f5, 0x00000000}},  //   _чети, nzir, _शाश्,
  { {0x645c005f, 0x98bd0036, 0xdb0d000c, 0x00000000}},  //   əril, dowę_, ntað,
  { {0x8675008b, 0x65620022, 0x00000000, 0x00000000}},  //   _жыцц, _thoh,   ,
  { {0x2d57014a, 0x7aeb0089, 0x81cd0044, 0x00000000}},  //   rçek_, ēgti, রিং_,
  { {0x5064012b, 0x75ca006b, 0xdb0d0032, 0x00000000}},  //   етра, _məzm, ztañ,
  { {0x70770167, 0xdb0400fa, 0xf1a60140, 0x00000000}},  //   _کاغذ, ssiê, _ерин,
  { {0x97570104, 0x9f44013e, 0x78a20253, 0x00000000}},  //   פילו_, ímá_, kaov,
  { {0x7d04008d, 0x00000000, 0x00000000, 0x00000000}},  //   gjis,   ,   ,
  { {0xdb0d00c4, 0x6f010010, 0x00000000, 0x00000000}},  // [1770] nuaç, ölcs,   ,
  { {0x501c009b, 0x44240ea7, 0x00000000, 0x00000000}},  //   _לוחו, izm_,   ,
  { {0xceb2007b, 0xdb0400f4, 0x99d903d9, 0x00000000}},  //   _ביי_, isiè, تواء_,
  { {0x7c240107, 0x7d160c51, 0xa3ac0061, 0x00000000}},  //   bzir, ckys, गळा_,
  { {0xdb0d0ea8, 0x66e50088, 0xa8780025, 0x00000000}},  //   stañ, дола, أحمر_,
  { {0x8ae401fb, 0xdb0d0181, 0x3ea30ea9, 0x00000000}},  //   _післ, duaç, najt_,
  { {0xdb0d0051, 0xdce40e3d, 0x2d7800ca, 0x00000000}},  //   nraí, zmič, _hčer_,
  { {0xfdf8009b, 0x7ae70010, 0x3ce9006c, 0x00000000}},  //   לצות_, _hajt, ndav_,
  { {0x0477026c, 0x65690eaa, 0x7ae70059, 0x00000000}},  //   _ہلاک_, rmeh, _kajt,
  { {0x394f001e, 0x65690d2d, 0x81d60044, 0x00000000}},  //   logs_, smeh, সিন_,
  { {0x645c005f, 0x7ae70eab, 0xf748023c, 0x00000000}},  //   ərim, _majt, _علمي_,
  { {0xcea900b6, 0x7ae70023, 0x8fa60478, 0x00000000}},  //   _כי_, _lajt, маме,
  { {0xbcfb00f4, 0x00000000, 0x00000000, 0x00000000}},  //   _phén,   ,   ,
  { {0x7ae7016e, 0x69d500b5, 0x63bb0eac, 0x00000000}},  //   _najt, _opze, muun,
  { {0xdb0d002a, 0xc1060025, 0xdce4021c, 0x00000000}},  //   graí, _يوتي, smič,
  { {0x7c24002d, 0x2f14006c, 0x61fc00ea, 0x00000000}},  //   tzir, _mägi_, årle,
  { {0x394f0c0d, 0x3ce60027, 0x7d040279, 0x00000000}},  // [1780] dogs_, ľov_, rjis,
  { {0x7c240107, 0xd91000a6, 0xa2d30164, 0x00000000}},  //   rzir, گیر_, _बॉम्,
  { {0x7ae709fc, 0x6e4602e9, 0xdb0d0051, 0x00000000}},  //   _dajt, _ценз, craí,
  { {0xdb0d009f, 0x63bb0ead, 0xd9100167, 0x00000000}},  //   stað, kuun, دیر_,
  { {0x98a30680, 0x87da0b6c, 0x97da06b4, 0x00000000}},  //   тиче, تباس_, تظار_,
  { {0x66e3003b, 0x758a0152, 0x78a200fa, 0x00000000}},  //   воља, осив_, saov,
  { {0x60c40091, 0x693c0eae, 0x7d1d0045, 0x00000000}},  //   _ocim, nček, _ylss,
  { {0xdb0d0181, 0x38ca00a1, 0x7ae70134, 0x00000000}},  //   tuaç, _گاڑی_, _zajt,
  { {0x693c00b9, 0x33740eaf, 0x63bb0eb0, 0x00000000}},  //   yčej, нгир, guun,
  { {0x764d0279, 0x60c40181, 0x59d2006e, 0x00000000}},  //   şaya, _acim, _सहार,
  { {0xe1350eb1, 0x3ea3022e, 0xdb040ea5, 0x00000000}},  //   енны, vajt_, friú,
  { {0x26dc0207, 0x92be0044, 0xdb0400f4, 0x00000000}},  //   levo_, ঁজে_, ssiè,
  { {0xdb0d00c4, 0xc1780006, 0x78a00093, 0x00000000}},  //   quaç, tvės_, _memv,
  { {0xdb0d0eb2, 0x26dc0724, 0x78a00190, 0x00000000}},  //   traí, nevo_, _lemv,
  { {0x7ae70010, 0xdb040051, 0x628a0066, 0x00000000}},  //   _rajt, briú, _iffo,
  { {0x7ae70320, 0xa2ca0204, 0xdb0d0eb3, 0x00000000}},  //   _sajt, त्र्, rraí,
  { {0x7ae70065, 0x60dd0116, 0x3f67007c, 0x00000000}},  // [1790] _pajt, mesm, _отоб,
  { {0x26dc06a6, 0xbcfb0eb4, 0x60dd0181, 0x00000000}},  //   jevo_, _théo, lesm,
  { {0x26dc0eb5, 0x7ae70065, 0x79e700a1, 0x00000000}},  //   devo_, _vajt, بوضہ_,
  { {0x2561000c, 0x60dd0032, 0x25f4006e, 0x00000000}},  //   kóla_, nesm, ्मनी_,
  { {0x628a0eb6, 0x06e80044, 0x394f01c5, 0x00000000}},  //   _offo, পানি, rogs_,
  { {0x2d7800d0, 0x7c200095, 0x00000000, 0x00000000}},  //   _učer_, _ümra,   ,
  { {0x60dd098e, 0x2d810eb7, 0x63bb0045, 0x00000000}},  //   kesm, _juhe_, wuun,
  { {0xfba3007d, 0x3ea10eb8, 0x63bb0058, 0x00000000}},  //   _ओबाम, _leht_, tuun,
  { {0x2d8106be, 0xf77801f3, 0xa24700a1, 0x00000000}},  //   _luhe_, _fiħ_, ڈیشل_,
  { {0x26dc0eb9, 0x60c40eba, 0xa20502b8, 0x00000000}},  //   cevo_, _scim, епод,
  { {0x68fb0ebb, 0x63bb0103, 0x68e901a3, 0x00000000}},  //   _knud, suun, _kaed,
  { {0xaacf0201, 0x628a0549, 0x4acf0309, 0x00000000}},  //   स्तक, _effo, स्तव,
  { {0x7c3b0ebc, 0x653a0049, 0xdb040068, 0x00000000}},  //   _žurn, _צענד, ssié,
  { {0x63a9014a, 0xfd1f0026, 0x68e90240, 0x00000000}},  //   msen, _alì_, _laed,
  { {0x63a905b7, 0x52390049, 0x60dd0ebd, 0x00000000}},  //   lsen, _מײַנ, besm,
  { {0xfce3005c, 0x60c40ebe, 0x693c0027, 0x00000000}},  //   лосо, _ucim, rček,
  { {0x63a90322, 0x6b4b0010, 0xab6602b8, 0x00000000}},  // [17a0] nsen, lügy, евал,
  { {0x3ea1001f, 0x63a900b0, 0x64590ebf, 0x00000000}},  //   _geht_, isen, _mywi,
  { {0x81cd0055, 0x26dc0197, 0x13d80044, 0x00000000}},  //   রিক_, vevo_, তিয়,
  { {0xc7c60680, 0x63a9021e, 0x80de0044, 0x00000000}},  //   ески, ksen, যাক্,
  { {0x26dc0ec0, 0x63a90030, 0xb05b0039, 0x00000000}},  //   tevo_, jsen, lfär,
  { {0x63a90030, 0x290d000a, 0x81d60044, 0x00000000}},  //   dsen, _eoea_, সিত_,
  { {0xd91006c6, 0x78a00059, 0xb05b04ce, 0x00000000}},  //   _پیش_, _temv, nfär,
  { {0x44f40098, 0x68fb00ea, 0x68e9096d, 0x00000000}},  //   тпис, _gnud, _gaed,
  { {0x6459047a, 0x26dc0197, 0x63a90bce, 0x00000000}},  //   _cywi, pevo_, gsen,
  { {0x212004cb, 0x2f14010e, 0x6723012d, 0x00000000}},  //   _alih_, _kägu_, chnj,
  { {0x22580030, 0x60dd006c, 0x75d3006d, 0x00000000}},  //   ærk_, tesm, _ميلا,
  { {0x2d81010f, 0x3ea101a2, 0x63a904fb, 0x00000000}},  //   _ruhe_, _seht_, bsen,
  { {0x60dd0ec1, 0x64590016, 0x2d810ec2, 0x00000000}},  //   resm, _gywi, _suhe_,
  { {0xb05b03a2, 0x60dd010e, 0x2d810052, 0x00000000}},  //   ffär, sesm, _puhe_,
  { {0xa01b0010, 0x1df80a78, 0x777a002d, 0x00000000}},  //   nböz, неры_, _mitx,
  { {0x81cd0055, 0xbcfb00f4, 0x67230ec3, 0x00000000}},  //   রিখ_, _thém, zhnj,
  { {0x80de0044, 0xfe7000a1, 0x7ff70025, 0x00000000}},  // [17b0] যাখ্, لدہ_, _أسعا,
  { {0x68fb00ea, 0x291f0048, 0x777a0032, 0x00000000}},  //   _snud, _slua_, _nitx,
  { {0xc33300b6, 0x68e90253, 0x290d00e0, 0x00000000}},  //   נוע_, _paed, _poea_,
  { {0xa3e00164, 0x9f520173, 0x63a90095, 0x00000000}},  //   दबा_, _aryè_, ysen,
  { {0x67230065, 0x777a002d, 0x25710ec4, 0x00000000}},  //   thnj, _bitx, _ušli_,
  { {0x45d50893, 0x7bcd0ec5, 0x63a905d5, 0x00000000}},  //   вцит, mtau, vsen,
  { {0x7d0f0010, 0xb8950025, 0x7bcd0ec6, 0x00000000}},  //   _kocs, _للأع, ltau,
  { {0x63a90004, 0x26c50061, 0x67230ec7, 0x00000000}},  //   tsen, _wclo_, shnj,
  { {0x777a0ec8, 0x7bcd01a3, 0x63a901a2, 0x00000000}},  //   _fitx, ntau, usen,
  { {0x63a90ec9, 0x765a0065, 0x7d0f0eca, 0x00000000}},  //   rsen, _fyty, _locs,
  { {0x63a903a1, 0x64590036, 0x7bcd00b0, 0x00000000}},  //   ssen, _wywi, htau,
  { {0x63a90ecb, 0x7bcd01a2, 0x00000000, 0x00000000}},  //   psen, ktau,   ,
  { {0x61e10016, 0xa3e50309, 0x81bc0089, 0x00000000}},  //   swll, _पनि_, nzēj,
  { {0x7bcd08db, 0x81bc0089, 0xb4640088, 0x00000000}},  //   dtau, izēj, _скіл,
  { {0xed5a0057, 0x2d9e0e16, 0xdca60088, 0x00000000}},  //   дов_, ète_, кави,
  { {0xed4301fb, 0xb05b04ce, 0x7bcd01a2, 0x00000000}},  //   ансп, rfär, ftau,
  { {0xed5701f9, 0x75ca005f, 0x7d0f01ee, 0x00000000}},  // [17c0] тот_, _vəzi, _docs,
  { {0x81bc001e, 0x693c0ecc, 0x387f002d, 0x00000000}},  //   dzēj, nčev, _agur_,
  { {0x18a60ecd, 0x7d0f0ece, 0xb05b04ec, 0x00000000}},  //   ваем, _focs, ngän,
  { {0xdcfe0ecf, 0x672103e1, 0xe9950014, 0x00000000}},  //   _kupč, _allj, اهنگ,
  { {0x765a00b0, 0xc0ad0049, 0x2ba9006e, 0x00000000}},  //   _syty, ליאָ, _चौपा,
  { {0xcf93007b, 0x693c02aa, 0x387f0032, 0x00000000}},  //   סטו_, jčev, _egur_,
  { {0x644e006b, 0x19b9007c, 0xe9a3003b, 0x00000000}},  //   əbiy, _путь_, _васп,
  { {0x291c0089, 0xaa43003b, 0x00000000, 0x00000000}},  //   īvas_, _тесл,   ,
  { {0xf36600e2, 0x765a00b4, 0x00000000, 0x00000000}},  //   ктон, _wyty,   ,
  { {0xd7640014, 0x81d60044, 0x764d0010, 0x00000000}},  //   _صنای, সিস_, ényé,
  { {0x6913011f, 0xaad4013d, 0x3abb0104, 0x00000000}},  //   _içer, ठ्यक, ומינ,
  { {0x7bcd0006, 0x00000000, 0x00000000, 0x00000000}},  //   ytau,   ,   ,
  { {0x693c050f, 0xc0580088, 0x7d0f00e5, 0x00000000}},  //   bčev, вір_, _rocs,
  { {0x82330123, 0x81cd0044, 0xdb23014a, 0x00000000}},  //   اریا, রিজ_, örün,
  { {0x75220095, 0xd37b08cd, 0x00000000, 0x00000000}},  //   _kloz, _קרוט,   ,
  { {0x7bcd00b0, 0xdb21014a, 0x629a0ed0, 0x00000000}},  //   ttau, ştür, lbto,
  { {0x2d580057, 0x8aa703f3, 0x21390048, 0x00000000}},  // [17d0] тить_, вред, mish_,
  { {0xd5a4009c, 0xdd11001e, 0x7bcd0ed1, 0x00000000}},  //   _وہ_, _kļūd, rtau,
  { {0x7bcd0ed2, 0x9f49014a, 0x7d0f0ed3, 0x00000000}},  //   stau, _araç_, _tocs,
  { {0x213900ab, 0x7bcd0ed4, 0x9f4900d4, 0x00000000}},  //   nish_, ptau, _braç_,
  { {0x2ca9006c, 0x75ca006b, 0x8c67007e, 0x00000000}},  //   maad_, _məzu, _штод,
  { {0x3669005e, 0xd2460379, 0x21390350, 0x00000000}},  //   нало_, _هن_, hish_,
  { {0x21390ed5, 0xa4930167, 0x44290142, 0x00000000}},  //   kish_, لیات, _ťa_,
  { {0xdb0d00c4, 0x75220ed6, 0xa3e908f3, 0x00000000}},  //   fraç, _cloz, едиа_,
  { {0xbcfb002a, 0xdb0d0181, 0x291d0ed7, 0x00000000}},  //   _chéi, graç, mkwa_,
  { {0x2ca900d9, 0xbcfb0048, 0xb05b06d3, 0x00000000}},  //   haad_, _dhéi, tgän,
  { {0xc6920476, 0x693c0ed8, 0x10a604dd, 0x00000000}},  //   _האב_, rčev, линн,
  { {0xbcfb002a, 0xdb0d0181, 0xb05b0788, 0x00000000}},  //   _fhéi, braç, rgän,
  { {0x693c0ed9, 0x2ca9018f, 0xbcfb0048, 0x00000000}},  //   mčet, daad_, _ghéi,
  { {0x248d0059, 0xf5390027, 0x343a0049, 0x00000000}},  //   lcem_, liť_, _אײנע,
  { {0x63bb0089, 0xa30a00a1, 0x2f140039, 0x00000000}},  //   lrun, _سروے_, _sägs_,
  { {0x693c0a14, 0xf5390027, 0x2139012d, 0x00000000}},  //   nčet, niť_, cish_,
  { {0xb7be0055, 0x2d93002d, 0x61260325, 0x00000000}},  // [17e0] _ইন্ট, _etxe_, _cóle,
  { {0x81d60044, 0x291d01c3, 0x4f9b01ce, 0x00000000}},  //   সির_, ekwa_, _רביצ,
  { {0x63bb001f, 0xeb75007e, 0x248d012d, 0x00000000}},  //   hrun, рытэ, kcem_,
  { {0x248d00ca, 0xb95a0025, 0x63a40180, 0x00000000}},  //   jcem_, رجاء_, _çing,
  { {0x6d440036, 0xf5390027, 0x645d006c, 0x00000000}},  //   mnia, diť_, üsil,
  { {0x6d440eda, 0x7522037e, 0x63bb0edb, 0x00000000}},  //   lnia, _sloz, drun,
  { {0x63bb001f, 0x6d44010e, 0xbcfb0048, 0x00000000}},  //   erun, onia, _shéi,
  { {0x6d4403b6, 0xdb0d0181, 0x69dc00f8, 0x00000000}},  //   nnia, traç, _ipre,
  { {0xd90d026c, 0x21390edc, 0x6d440904, 0x00000000}},  //   _تین_, vish_, inia,
  { {0x7c3b01ee, 0xdb0d00c4, 0x51f80088, 0x00000000}},  //   _žurk, rraç, вною_,
  { {0x2d9805fa, 0x21390edd, 0xf5390027, 0x00000000}},  //   jpre_, tish_, biť_,
  { {0x63bb0039, 0x7aee01c5, 0x69dc0ede, 0x00000000}},  //   brun, _labt, _mpre,
  { {0x6d440871, 0x29370049, 0x2139071e, 0x00000000}},  //   dnia, ראכן_, rish_,
  { {0x69dc0edf, 0xa2940ee0, 0x6d440036, 0x00000000}},  //   _opre, _такі, enia,
  { {0x6d440016, 0x693c01ee, 0x65600051, 0x00000000}},  //   fnia, nčes, olmh,
  { {0x63a20ee1, 0x6d440a6d, 0x5c070ee2, 0x00000000}},  //   _kwon, gnia, ляза,
  { {0x69dc02d5, 0x2ca90ee3, 0x81c60044, 0x00000000}},  // [17f0] _apre, raad_, _উনি_,
  { {0x63a20020, 0x6d44006c, 0xf5390027, 0x00000000}},  //   _mwon, ania, ziť_,
  { {0x0cd50364, 0x6d560ee4, 0x2ca900ea, 0x00000000}},  //   _коню, boya, paad_,
  { {0x6d440024, 0x63a2000a, 0x6d56004a, 0x00000000}},  //   cnia, _owon, coya,
  { {0xf5390027, 0x248d0340, 0x69dc0ee5, 0x00000000}},  //   viť_, vcem_, _epre,
  { {0x7d0d0004, 0xc5f90055, 0x7bdd0ee6, 0x00000000}},  //   ljas, _অথবা_, _ipsu,
  { {0x63a201aa, 0x80ab0044, 0xceb400a0, 0x00000000}},  //   _awon, _কান্, ציק_,
  { {0x63bb001a, 0x7d0d0ee7, 0x63a20a5f, 0x00000000}},  //   trun, njas, _bwon,
  { {0x7c2d000d, 0xf5760054, 0x693c016c, 0x00000000}},  //   nzar, جميع_, rčet,
  { {0xc6a401f9, 0x63bb0668, 0x6d440006, 0x00000000}},  //   _грци, rrun, znia,
  { {0x6d44018e, 0x6d560ee8, 0x7d0d000c, 0x00000000}},  //   ynia, yoya, kjas,
  { {0x63bb0ee9, 0x7bdd0eea, 0x63a201aa, 0x00000000}},  //   prun, _opsu, _fwon,
  { {0xe28e012b, 0x63a20173, 0xa6e80044, 0x00000000}},  //   _ма_, _gwon, পারট,
  { {0x6d440eeb, 0x08760049, 0x82350014, 0x00000000}},  //   wnia, יערט_, _پرتا,
  { {0x442d048e, 0x7bdd0c47, 0xada60eec, 0x00000000}},  //   lze_, _apsu, рабл,
  { {0xef860265, 0x7aee0169, 0x27e60b69, 0x00000000}},  //   _клип, _sabt, ywon_,

  { {0x69dc01d9, 0x2d980eed, 0xafe60726, 0x00000000}},  // [1800] _spre, spre_, _топл,
  { {0x442d0061, 0x69dc0eee, 0x2561000c, 0x00000000}},  //   ize_, _ppre, fólk_,
  { {0x09e60242, 0x2d8501dc, 0x7d0d016c, 0x00000000}},  //   роен, ílet_, bjas,
  { {0xe3a70d3a, 0x27e601aa, 0x753b0020, 0x00000000}},  //   _ور_, twon_, jiuz,
  { {0x442d00b5, 0x06af0044, 0x7aee0030, 0x00000000}},  //   jze_, চ্ছি, _tabt,
  { {0x442d0eef, 0x69960088, 0x501b0104, 0x00000000}},  //   dze_, _врах, כונו,
  { {0xe1e70647, 0x69dc0142, 0xdce4016c, 0x00000000}},  //   _بس_, _upre, gmić,
  { {0x6283027b, 0x63a201aa, 0xa96a005e, 0x00000000}},  //   _agno, _pwon, _риба_,
  { {0x39460211, 0x43060088, 0x00000000, 0x00000000}},  //   mnos_, аїна,   ,
  { {0x7d0d016c, 0xf36600ec, 0x394605a0, 0x00000000}},  //   zjas, јтин, lnos_,
  { {0x79800cd1, 0xd48f003b, 0x7c2d051b, 0x00000000}},  //   _kimw, _мр_, zzar,
  { {0x7529000b, 0x63a201aa, 0x39460052, 0x00000000}},  //   chez, _twon, nnos_,
  { {0x442d0046, 0x394600c4, 0x63a20020, 0x00000000}},  //   cze_, inos_, _uwon,
  { {0xdced0161, 0x39460016, 0x6d48009d, 0x00000000}},  //   rmač, hnos_, édan,
  { {0xeca700e1, 0x7d0d021a, 0x3f84000c, 0x00000000}},  //   ијан, tjas, ímur_,
  { {0x7c2d0ef0, 0xc27b071c, 0x39460010, 0x00000000}},  //   tzar, _ברוי, jnos_,
  { {0x29e8000d, 0x67da0089, 0x60cd0085, 0x00000000}},  // [1810] _aşa_, nājā, _icam,
  { {0x7c2d0197, 0x3946008f, 0x6aa70065, 0x00000000}},  //   rzar, enos_, _qejf,
  { {0x442d0ef1, 0x79800009, 0x7c2d0ef2, 0x00000000}},  //   zze_, _bimw, szar,
  { {0x39460ef3, 0x645d006c, 0x59c90061, 0x00000000}},  //   gnos_, üsik, ांबर,
  { {0x6126009f, 0x79800173, 0x6d5d020e, 0x00000000}},  //   _jóla, _dimw, _iksa,
  { {0x39460489, 0x66e5007e, 0x8698005e, 0x00000000}},  //   anos_, сока, атът_,
  { {0x60cd03fd, 0x3f890ef4, 0x7afa000c, 0x00000000}},  //   _ocam, _luau_, _ótta,
  { {0x442d0474, 0x7ae50368, 0x39460ef5, 0x00000000}},  //   tze_, leht, cnos_,
  { {0xc952019b, 0x442d00b5, 0xf794008b, 0x00000000}},  //   _זמן_, uze_, _матэ,
  { {0x442d0667, 0x60cd0919, 0x79800dfc, 0x00000000}},  //   rze_, _acam, _zimw,
  { {0x442d0ef6, 0x6d5d0ef7, 0x69c50009, 0x00000000}},  //   sze_, _oksa, nuhe,
  { {0x2d68010f, 0x7ae50065, 0x2561000c, 0x00000000}},  //   eßen_, heht, kóli_,
  { {0x249f0ab2, 0x78a900bb, 0x69c501a2, 0x00000000}},  //   mbum_, _meev, huhe,
  { {0x539a00b6, 0x61260489, 0x6d5d014a, 0x00000000}},  //   _עיצו, _dóla, _aksa,
  { {0xe1640014, 0x6d5d0022, 0x853c0006, 0x00000000}},  //   _وضعی, _bksa, _kvėp,
  { {0x4c8606b6, 0x61360d90, 0x61fc0c31, 0x00000000}},  //   слав, kšli, ærle,
  { {0x79800009, 0xf3880011, 0xdb0400c4, 0x00000000}},  // [1820] _rimw, _lợn_, nsiç,
  { {0x6ac60025, 0xdb040181, 0xf1db013d, 0x00000000}},  //   إقام, isiç, _बहान,
  { {0x1efb007b, 0x27ed0173, 0x69c50ef8, 0x00000000}},  //   _עלטע, _asen_, guhe,
  { {0x984a0888, 0x1d0a0131, 0xdb040e65, 0x00000000}},  //   ляла_, _семи_, rriñ,
  { {0x39460977, 0xaab80167, 0x27ed0026, 0x00000000}},  //   rnos_, _نگار_, _csen_,
  { {0x254c00b9, 0xe9aa0014, 0x3946007f, 0x00000000}},  //   děla_, _مدرن_, snos_,
  { {0x2d820020, 0x79800ef9, 0xa91d0089, 0x00000000}},  //   _kike_, _timw, _siže,
  { {0x7786007c, 0x2ca00007, 0x81bf0044, 0x00000000}},  //   _глаз, nbid_, ুবা_,
  { {0x2d8200ab, 0xccf300b3, 0xd37a0478, 0x00000000}},  //   _mike_, לכה_, лчо_,
  { {0x2d820038, 0xaaa80309, 0x60cd0efa, 0x00000000}},  //   _like_, गरिक, _scam,
  { {0xd5b901fb, 0x6126000c, 0x71270025, 0x00000000}},  //   _всі_, _sóla, مرحل,
  { {0x81bc001e, 0x59c90164, 0xa15901e1, 0x00000000}},  //   dzēt, ांतर, раму_,
  { {0xa2d3006e, 0xd8d70049, 0x2ca00146, 0x00000000}},  //   _बॉक्, זוכט_, dbid_,
  { {0x4374007a, 0x2d6801a2, 0x2cad016c, 0x00000000}},  //   _بهتر, ußen_, _žed_,
  { {0xd047005f, 0xe1890011, 0x9cf505b8, 0x00000000}},  //   _əməl, _hẳn_, озві,
  { {0x61440545, 0x2d820023, 0x00000000, 0x00000000}},  //   _неја, _cike_,   ,
  { {0x78a90951, 0x2d820065, 0xdb04000c, 0x00000000}},  // [1830] _reev, _dike_, trið,
  { {0x333e002b, 0x2d820efb, 0xbcfb0bf2, 0x00000000}},  //   nitx_, _eike_, _chér,
  { {0x7ae50efc, 0x78a90943, 0x13e10044, 0x00000000}},  //   reht, _peev, বিয়,
  { {0x2ca00061, 0x69c50efd, 0xf3880082, 0x00000000}},  //   cbid_, ruhe, _rợn_,
  { {0xf7710379, 0x78a9010e, 0x272b00ea, 0x00000000}},  //   وات_, _veev, _løne_,
  { {0x69c500b0, 0x2d82016c, 0x25a50016, 0x00000000}},  //   puhe, _zike_, _pwll_,
  { {0x78a9006c, 0x212904cb, 0xf59201b7, 0x00000000}},  //   _teev, _olah_, ولوج,
  { {0x58d4007c, 0x321e0036, 0x254c00b9, 0x00000000}},  //   _ност, dyty_, těla_,
  { {0x9817007a, 0x395f002d, 0x27ed0efe, 0x00000000}},  //   _ابزا, _ikus_, _usen_,
  { {0xdb16021e, 0x21290145, 0x15ab02dc, 0x00000000}},  //   styö, _alah_, _бъди_,
  { {0x21290eff, 0x9f49010f, 0x2cab0253, 0x00000000}},  //   _blah_, _spaß_, _oecd_,
  { {0x2ca00009, 0x6f050082, 0x00000000, 0x00000000}},  //   xbid_, _anhc,   ,
  { {0x2d820056, 0x6f170f00, 0xd24e0014, 0x00000000}},  //   _rike_, _boxc, فنی_,
  { {0xe2990b21, 0x2d820173, 0x321e0f01, 0x00000000}},  //   _так_, _sike_, byty_,
  { {0xad3a0088, 0x2ca00d12, 0x395f02db, 0x00000000}},  //   ачає_, tbid_, _okus_,
  { {0x8d66007e, 0xc5f200b3, 0x4d660451, 0x00000000}},  //   івае, ודל_, ікав,
  { {0x6f170f02, 0xcb05013d, 0x4aaa0517, 0x00000000}},  // [1840] _foxc, रांड_, икан_,
  { {0x5ec10044, 0x2cb90009, 0x00000000, 0x00000000}},  //   শ্বে, _edsd_,   ,
  { {0xa3a902fb, 0x2d82000a, 0x7f5c009d, 0x00000000}},  //   गीत_, _tike_, morq,
  { {0x6d41009d, 0x7f5c0026, 0xdd0f0095, 0x00000000}},  //   élat, lorq, mışs,
  { {0x7d060006, 0xbcfb00f4, 0x321e0036, 0x00000000}},  //   _inks, _thér, zyty_,
  { {0xab2a012b, 0xd5ba0517, 0x394d0f03, 0x00000000}},  //   _тога_, аси_, _ejes_,
  { {0x386d028d, 0x76a90088, 0xe1890082, 0x00000000}},  //   _ezer_, стів_, _sẳn_,
  { {0x89d700a1, 0x00000000, 0x00000000, 0x00000000}},  //   _گوہر_,   ,   ,
  { {0x73fa0055, 0x78a20f04, 0x25a90091, 0x00000000}},  //   েন্ট_, mbov, ćala_,
  { {0x5edf0044, 0x1fd00044, 0xd370006d, 0x00000000}},  //   _ফোনে, িবাস, عهد_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c30059, 0x7bd60058, 0x254c013e, 0x00000000}},  //   šneg, ktyu, mělo_,
  { {0xb97b00a3, 0xf8b3034e, 0x357300a1, 0x00000000}},  //   ינטי, ושר_, _تھوڑ,
  { {0x7d06010a, 0xa91d0087, 0x25450089, 0x00000000}},  //   _anks, _miža, vēli_,
  { {0xdef8008b, 0x00000000, 0x00000000, 0x00000000}},  //   цыя_,   ,   ,
  { {0x21290093, 0x25450089, 0x69c100ea, 0x00000000}},  //   _ulah_, tēli_, _ålei,
  { {0xb7c50044, 0xa91d00ca, 0x00000000, 0x00000000}},  // [1850] _এন্ট, _niža,   ,
  { {0xdea100a1, 0x6f0500e7, 0x99d70426, 0x00000000}},  //   _سیری, _unhc, قتصا,
  { {0x386d0c59, 0x394d0023, 0x00000000, 0x00000000}},  //   _szer_, _pjes_,   ,
  { {0xdb0d0051, 0x00000000, 0x00000000, 0x00000000}},  //   msaí,   ,   ,
  { {0x07a505f6, 0x3d08013d, 0x00000000, 0x00000000}},  //   чалн, हारे_,   ,
  { {0x3707007c, 0x00000000, 0x00000000, 0x00000000}},  //   ючев,   ,   ,
  { {0x394d0f05, 0xf6250152, 0x7af50288, 0x00000000}},  //   _tjes_, ядко, _iazt,
  { {0x395f037e, 0x7af50f06, 0x00000000, 0x00000000}},  //   _ukus_, _hazt,   ,
  { {0x59c90061, 0x7f5c004a, 0x3a2100e0, 0x00000000}},  //   ांवर, yorq, lyhp_,
  { {0xfbd2019b, 0x395d00ab, 0x27ff002d, 0x00000000}},  //   עתי_, lows_, _irun_,
  { {0x644d010a, 0x69d7002d, 0x4add0204, 0x00000000}},  //   _žaid, ntxe, न्यव,
  { {0x70c60061, 0x395d00e0, 0x7af50032, 0x00000000}},  //   वलेल, nows_, _lazt,
  { {0x4f96007e, 0x3eba0022, 0x7f5c0f07, 0x00000000}},  //   ярну, _pdpt_, torq,
  { {0x2d960d54, 0x539a009b, 0x4ac70204, 0x00000000}},  //   зрас, _היסו, _लागव,
  { {0x80ab0055, 0x78bb0091, 0x6126000c, 0x00000000}},  //   _কার্, _oduv, _hólm,
  { {0x80da0055, 0x6d4f00f6, 0x7af50288, 0x00000000}},  //   _বোর্, _cjca, _aazt,
  { {0x7af5002d, 0x3b180f08, 0xe8df0011, 0x00000000}},  // [1860] _bazt, _porq_, _ngựa_,
  { {0x7bd600e0, 0xa91d0087, 0x00000000, 0x00000000}},  //   rtyu, _riža,   ,
  { {0x273000ad, 0xe9da0f09, 0xdb0d0048, 0x00000000}},  //   _hàng_, ске_, csaí,
  { {0x27ff0056, 0xd9100167, 0xdb040051, 0x00000000}},  //   _brun_, خیر_, nsiú,
  { {0x78a20bca, 0xdb040051, 0x4c83005e, 0x00000000}},  //   rbov, isiú, _плюв,
  { {0x7af5022b, 0x27300011, 0x7bc40129, 0x00000000}},  //   _gazt, _màng_, mriu,
  { {0x09e30057, 0x2730001d, 0xa5d70025, 0x00000000}},  //   _порн, _làng_, كبير_,
  { {0x5398005e, 0x00000000, 0x00000000, 0x00000000}},  //   овия_,   ,   ,
  { {0x2730001d, 0xf4930439, 0x27ff01e5, 0x00000000}},  //   _nàng_, رشيد, _grun_,
  { {0x59d003d7, 0x798e000b, 0xaacc0201, 0x00000000}},  //   _हमार, _kubw, ालिक,
  { {0xc4860920, 0x20000089, 0x27e0002b, 0x00000000}},  //   _елек, _arii_, ħinu_,
  { {0x27300011, 0x798e0009, 0x92ac0044, 0x00000000}},  //   _bàng_, _mubw, গলে_,
  { {0x2730001d, 0x64a3003b, 0x63ae013e, 0x00000000}},  //   _càng_, _чача, áhně,
  { {0x27300011, 0x7bc40006, 0x3f8501e5, 0x00000000}},  //   _dàng_, driu, ölu_,
  { {0x7bc40004, 0x798e0009, 0x7af50059, 0x00000000}},  //   eriu, _nubw, _razt,
  { {0x20000022, 0x8d7401fa, 0x7bc40026, 0x00000000}},  //   _frii_, فاقا, friu,
  { {0xc15800b6, 0x31ae0044, 0x70550014, 0x00000000}},  // [1870] _משהו_, _কমিশ, _زندا,
  { {0x60dd01a2, 0x00000000, 0x00000000, 0x00000000}},  //   lfsm,   ,   ,
  { {0x79a4007c, 0xa2cf013d, 0x69c40316, 0x00000000}},  //   ерче, _दास्, ांगी,
  { {0x69d70032, 0x7bc40133, 0x29d500ea, 0x00000000}},  //   rtxe, briu, råa_,
  { {0x7bc404bd, 0x6d4d006c, 0x395d0133, 0x00000000}},  //   criu, mnaa, rows_,
  { {0x656200e0, 0x6d4d00bb, 0x0f1b0061, 0x00000000}},  //   _akoh, lnaa, _नकोस_,
  { {0x6d4d006c, 0x00000000, 0x00000000, 0x00000000}},  //   onaa,   ,   ,
  { {0x6d4d00b5, 0x92ac0044, 0x62980f0a, 0x00000000}},  //   nnaa, গলো_, _afvo,
  { {0x47d50054, 0x6ece001c, 0x23d4007e, 0x00000000}},  //   _زيار, _तालु, нцэр,
  { {0x27300011, 0x68eb00bb, 0x20fa0082, 0x00000000}},  //   _ràng_, legd, _ỏi_,
  { {0x69c50016, 0x27300011, 0x6d4d0f0b, 0x00000000}},  //   nrhe, _sàng_, knaa,
  { {0xd7d103d7, 0xe7d1006e, 0x7bc40006, 0x00000000}},  //   _समाच, _समाप, yriu,
  { {0x69c5010f, 0x316c0089, 0x00000000, 0x00000000}},  //   hrhe, ēdz_,   ,
  { {0x2730001d, 0x6569068f, 0x6d4d0128, 0x00000000}},  //   _vàng_, lleh, enaa,
  { {0xa3a9006e, 0xa91d0087, 0x00000000, 0x00000000}},  //   गीर_, _rižn,   ,
  { {0x6d4d0f0c, 0x27300011, 0x65690cba, 0x00000000}},  //   gnaa, _tàng_, nleh,
  { {0x6b8700b5, 0x799c0016, 0x8c430478, 0x00000000}},  // [1880] _bijg, _strw, вете,
  { {0xdcfd0089, 0x2d57002b, 0x7bc40f0d, 0x00000000}},  //   _visā, eħed_, rriu,
  { {0xfe720025, 0x0ed30061, 0x20050089, 0x00000000}},  //   _جدة_, _तातड, ālie_,
  { {0x2d57002b, 0xeb9f0637, 0x7bc4001a, 0x00000000}},  //   għed_, _brød_, priu,
  { {0x69c50250, 0xeb9a004d, 0x9f4900f6, 0x00000000}},  //   arhe, _фиг_, _graó_,
  { {0x81e40044, 0x1de20061, 0xa91d00ca, 0x00000000}},  //   নিত_, _पहात, _fižo,
  { {0xa3b0013d, 0xb05b0210, 0xdce40062, 0x00000000}},  //   टीन_, ngär, hlič,
  { {0xdce40059, 0x6ba50039, 0x65690010, 0x00000000}},  //   klič, _åtgä, gleh,
  { {0x7c240f0e, 0xd8d7007b, 0xa3a9001c, 0x00000000}},  //   nyir, _קומט_, गील_,
  { {0x6126009f, 0xdce40062, 0x52140242, 0x00000000}},  //   _fólk, dlič, едот,
  { {0x7c240009, 0x65690009, 0x75ca013f, 0x00000000}},  //   hyir, bleh, _ləzz,
  { {0xf388001d, 0x65690f0f, 0x00000000, 0x00000000}},  //   _lợi_, cleh,   ,
  { {0x60dd009f, 0x28d1013d, 0x61ed0107, 0x00000000}},  //   rfsm, _हासि, _ćale,
  { {0x44240036, 0x636f05b7, 0x272b00ea, 0x00000000}},  //   mym_, lønn, _lønn_,
  { {0x1df80147, 0x44240462, 0x200d001a, 0x00000000}},  //   меры_, lym_, ţei_,
  { {0xdce4037e, 0xc4450014, 0x5cc402ea, 0x00000000}},  //   blič, _آیین_, ксуз,
  { {0x44240046, 0x6d4d02ae, 0x4ea7012c, 0x00000000}},  // [1890] nym_, rnaa, _орна,
  { {0x65600051, 0xdb1601aa, 0x6d4d0250, 0x00000000}},  //   homh, nsyè, snaa,
  { {0x65690943, 0x637400f6, 0x69c50052, 0x00000000}},  //   yleh, càne, urhe,
  { {0x7c240009, 0x69c50f10, 0x636f0056, 0x00000000}},  //   byir, rrhe, jønn,
  { {0xdb1601aa, 0x7c240009, 0x6b8700bb, 0x00000000}},  //   ksyè, cyir, _tijg,
  { {0x7d1d0047, 0x4424018e, 0x68eb01d6, 0x00000000}},  //   _hoss, dym_, segd,
  { {0xdce400ee, 0xf3880011, 0x7d1d0f11, 0x00000000}},  //   zlič, _gợi_, _koss,
  { {0x7d1d021e, 0x00000000, 0x00000000, 0x00000000}},  //   _joss,   ,   ,
  { {0x7d1d0129, 0x65690eaa, 0x13e6007c, 0x00000000}},  //   _moss, rleh, емый_,
  { {0x6569003c, 0xdce4050f, 0x7d1d0f12, 0x00000000}},  //   sleh, vlič, _loss,
  { {0xcb12019b, 0x216a005e, 0x6569041d, 0x00000000}},  //   אלי_, зини_, pleh,
  { {0x7d1d02d5, 0xdce40059, 0x44240036, 0x00000000}},  //   _noss, tlič, bym_,
  { {0xb4270151, 0x44240036, 0x44270076, 0x00000000}},  //   _تعاو, cym_, _تراف,
  { {0x79890343, 0x75290047, 0x7bcd006c, 0x00000000}},  //   _liew, lkez, duau,
  { {0xc6920452, 0xdd920151, 0xfce60f13, 0x00000000}},  //   ראל_, اور_, ново,
  { {0x7d1d00d4, 0x79890046, 0x5ec10044, 0x00000000}},  //   _coss, _niew, শ্লে,
  { {0x7d1d028c, 0xf3880011, 0x7ff60025, 0x00000000}},  // [18a0] _doss, _sợi_, _أسبا,
  { {0x80d60061, 0x00000000, 0x00000000, 0x00000000}},  //   _भाडे,   ,   ,
  { {0x7d1d0d87, 0x3f92000b, 0x44240036, 0x00000000}},  //   _foss, _huyu_, zym_,
  { {0x69c3008e, 0x59d20309, 0x6f1e0544, 0x00000000}},  //   ánea, दंबर, _hopc,
  { {0x6f1e07e4, 0x798901d6, 0xa7fd0010, 0x00000000}},  //   _kopc, _diew, _szűr,
  { {0x57f3012b, 0xa84701b7, 0x254c00b9, 0x00000000}},  //   упшт, علوم_, měli_,
  { {0x44240046, 0x7d1d0697, 0x61260b33, 0x00000000}},  //   wym_, _yoss, _eóli,
  { {0x89db0104, 0x44240832, 0x61260f14, 0x00000000}},  //   _מחלי, tym_, _fóli,
  { {0x39460f15, 0x84970025, 0x00000000, 0x00000000}},  //   mios_, رئيس_,   ,
  { {0x39460006, 0x65600378, 0x81e40044, 0x00000000}},  //   lios_, somh, নিস_,
  { {0x041e0055, 0xa1590088, 0x53c20316, 0x00000000}},  //   _বেশী_, дану_, _शिवश,
  { {0x39460f16, 0x63740129, 0x2a6a0095, 0x00000000}},  //   nios_, fànc, _mybb_,
  { {0x7d1d0703, 0xe803007d, 0xc54200a1, 0x00000000}},  //   _ross, लिया_, _لڑکی,
  { {0x7d1d003d, 0x6f1e0a16, 0xdefb007e, 0x00000000}},  //   _soss, _copc, чым_,
  { {0x7d1d0f17, 0x3946010a, 0xdb0d000c, 0x00000000}},  //   _poss, kios_, drað,
  { {0x9d1804f9, 0xe7f10061, 0x00000000, 0x00000000}},  //   ност_, _आईला_,   ,
  { {0x39460977, 0xdb0d0e4f, 0x7d1d0181, 0x00000000}},  // [18b0] dios_, nsaç, _voss,
  { {0xdb0d0211, 0x798903b2, 0x00000000, 0x00000000}},  //   trañ, _siew,   ,
  { {0x7d1d0ba0, 0xa2d80201, 0x61260f18, 0x00000000}},  //   _toss, _मान्, _sóli,
  { {0x39460181, 0x612605a3, 0x3f9200f6, 0x00000000}},  //   gios_, _póli, _yuyu_,
  { {0x79890038, 0x2ca90277, 0x7c6709b9, 0x00000000}},  //   _view, mbad_, _ساحل,
  { {0x3669003b, 0x2d8b0211, 0xdcef0089, 0x00000000}},  //   мало_, _hice_, _ticē,
  { {0x75290047, 0x39460325, 0x56920ab7, 0x00000000}},  //   tkez, bios_, шајт,
  { {0x39460f19, 0x2ca90e42, 0x73e50216, 0x00000000}},  //   cios_, nbad_, воиз,
  { {0x80a202fb, 0x75290f1a, 0x2d9305f2, 0x00000000}},  //   _क्षे, rkez, _luxe_,
  { {0x3eb30038, 0x2d8b0091, 0x69ca0181, 0x00000000}},  //   _next_, _lice_, áfeg,
  { {0x2d8b0f1b, 0x68fb0f1c, 0x3f92005a, 0x00000000}},  //   _oice_, _kaud, _suyu_,
  { {0x61460264, 0x2d8b0549, 0x6f1e0f1d, 0x00000000}},  //   тема, _nice_, _sopc,
  { {0x20040f1e, 0x68fb0a64, 0x2ca90f1f, 0x00000000}},  //   ími_, _maud, dbad_,
  { {0x2d8b0051, 0x39460914, 0x80a2006e, 0x00000000}},  //   _aice_, zios_, _क्रे,
  { {0x63bb01e5, 0x2d8b01ee, 0x63a401d5, 0x00000000}},  //   lsun, _bice_, _ħini,
  { {0x68fb0394, 0x291f000d, 0xf2880049, 0x00000000}},  //   _naud, _noua_, _אָפֿ,
  { {0x6f1e003b, 0x39460211, 0x63bb0f20, 0x00000000}},  // [18c0] _topc, vios_, nsun,
  { {0x5fb700b6, 0x81e40044, 0x63bb010f, 0x00000000}},  //   _שהיא_, নির_, isun,
  { {0x39460211, 0x68fb0d90, 0x3eb80082, 0x00000000}},  //   tios_, _baud, mart_,
  { {0x3eb80039, 0xc7c600a8, 0x68fb008e, 0x00000000}},  //   lart_, вски, _caud,
  { {0x39460977, 0x68fb0f21, 0x2d800007, 0x00000000}},  //   rios_, _daud, mmie_,
  { {0x3946010a, 0x3eb80f22, 0x2d8b001a, 0x00000000}},  //   sios_, nart_, _zice_,
  { {0x3946029d, 0x68fb00f4, 0x7afc0f23, 0x00000000}},  //   pios_, _faud, _iart,
  { {0x7afc022b, 0x29dc0845, 0x68fb0f24, 0x00000000}},  //   _hart, mía_, _gaud,
  { {0x7afc010a, 0x3eb80f25, 0x29dc0f26, 0x00000000}},  //   _kart, kart_, lía_,
  { {0x68fb0f27, 0x7afc022b, 0xa6c70a94, 0x00000000}},  //   _zaud, _jart, _алфа_,
  { {0x29dc0f28, 0x7c3a005f, 0x69de00f4, 0x00000000}},  //   nía_, _ətra, ntpe,
  { {0x7afc008d, 0x64a6007e, 0x68e20016, 0x00000000}},  //   _lart, _рада, nfod,
  { {0xdb040211, 0xb4ae0309, 0x29dc0f29, 0x00000000}},  //   nsió, करी_, hía_,
  { {0x3eb8010f, 0x63a2006a, 0x2d8b01ca, 0x00000000}},  //   gart_, _iton, _sice_,
  { {0x29dc02a0, 0x63a2016c, 0x2ca900ea, 0x00000000}},  //   jía_, _hton, tbad_,
  { {0x29dc0f2a, 0x7afc0f2b, 0xa3e60061, 0x00000000}},  //   día_, _aart, _पहा_,
  { {0x3eb30472, 0x2d8b0181, 0x3eb8093b, 0x00000000}},  // [18d0] _text_, _vice_, bart_,
  { {0x68fb0f2c, 0x29dc0211, 0xe4e2013d, 0x00000000}},  //   _saud, fía_, क्ति_,
  { {0x29dc0219, 0x68e20016, 0x2d8b037a, 0x00000000}},  //   gía_, ffod, _tice_,
  { {0x63a20f2d, 0x7afc00ab, 0x23c20204, 0x00000000}},  //   _oton, _eart, _शिंद,
  { {0xb8db02f4, 0x69dc0f2e, 0x68fb009d, 0x00000000}},  //   _आज_, _eqre, _vaud,
  { {0x29dc0219, 0x7afc05ca, 0xe70700a1, 0x00000000}},  //   bía_, _gart, کسچی,
  { {0x29dc0219, 0x63a20f2f, 0x3a84007e, 0x00000000}},  //   cía_, _aton, _вытв,
  { {0x63bb002d, 0x7afc0f30, 0x290d0032, 0x00000000}},  //   tsun, _zart, _unea_,
  { {0xa8550057, 0x25be010f, 0x3eb802d0, 0x00000000}},  //   _скач, _evtl_, yart_,
  { {0x63bb0f31, 0x3eb80f32, 0x31690173, 0x00000000}},  //   rsun, xart_, _akaz_,
  { {0x63bb0f33, 0x3eb80d3e, 0x63a2000a, 0x00000000}},  //   ssun, vart_, _eton,
  { {0x7fd60245, 0x34950f34, 0x6d4b01aa, 0x00000000}},  //   лігі, _садр, _ňgan,
  { {0x67210f35, 0xf487003b, 0x00000000, 0x00000000}},  //   _kolj, _ружн,   ,
  { {0x61260010, 0x08760049, 0x083a0049, 0x00000000}},  //   _rólu, טערט_, געשל,
  { {0xa2d80201, 0x29dc049a, 0xf3880011, 0x00000000}},  //   _मात्, xía_, _vợt_,
  { {0x7afc022b, 0x29dc0f2a, 0x5c160057, 0x00000000}},  //   _sart, vía_, льзу,
  { {0x3eb80f36, 0x2d800036, 0x386d0f37, 0x00000000}},  // [18e0] part_, rmie_, _nyer_,
  { {0x7afc0065, 0x0eaa008b, 0x29dc008e, 0x00000000}},  //   _qart, _якой_, tía_,
  { {0x7afc0f38, 0x386d0211, 0xbf9b0181, 0x00000000}},  //   _vart, _ayer_, nvên,
  { {0x29dc0845, 0x7afc0046, 0x386d05b7, 0x00000000}},  //   ría_, _wart, _byer_,
  { {0x7afc0f39, 0x6d46038c, 0x67210f3a, 0x00000000}},  //   _tart, _imka, _bolj,
  { {0xdb040819, 0xa2d802f4, 0x29dc0f3b, 0x00000000}},  //   rsió, _माध्, pía_,
  { {0xf41f0f3c, 0xe9a3008b, 0x63a20f3d, 0x00000000}},  //   ään_, _гасп, _ston,
  { {0xb4ae0201, 0x80d60061, 0x60c40f3e, 0x00000000}},  //   करे_, _भाषे, _ndim,
  { {0x6721043d, 0x68e4006c, 0x00000000, 0x00000000}},  //   _folj, õidu,   ,
  { {0x60c4002d, 0x672100ca, 0x79820036, 0x00000000}},  //   _adim, _golj, lmow,
  { {0xe6930054, 0x41550594, 0x6d460066, 0x00000000}},  //   _المد, ивос, _omka,
  { {0x6ed70316, 0x00000000, 0x00000000, 0x00000000}},  //   _बाहु,   ,   ,
  { {0x63a203dd, 0x5ede0044, 0x81e40044, 0x00000000}},  //   _uton, য়নে, নিই_,
  { {0x88bd0036, 0x2fc000ca, 0x636f00ea, 0x00000000}},  //   _kośc, _dvig_, jønh,
  { {0x2bc70309, 0xd2b701ce, 0x2fc0032e, 0x00000000}},  //   _लिहा, _גלות_, _evig_,
  { {0x79820036, 0x316900ca, 0xeb9f0190, 0x00000000}},  //   jmow, _ukaz_, _drøn_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [18f0]   ,   ,   ,
  { {0x9b440025, 0x69c300ca, 0x2009009d, 0x00000000}},  //   منقو, šnem, _irai_,
  { {0xdb58007c, 0xeb9f0737, 0x672100d9, 0x00000000}},  //   уют_, _grøn_, _rolj,
  { {0x20090085, 0x00000000, 0x00000000, 0x00000000}},  //   _krai_,   ,   ,
  { {0x67210c1e, 0xdcef00b4, 0x00000000, 0x00000000}},  //   _polj, _chcą,   ,
  { {0x386d0f3f, 0x00000000, 0x00000000, 0x00000000}},  //   _vyer_,   ,   ,
  { {0x67210295, 0x7bcd000c, 0x23650059, 0x00000000}},  //   _volj, lrau, volj_,
  { {0x20090006, 0x00000000, 0x00000000, 0x00000000}},  //   _orai_,   ,   ,
  { {0xa3b00201, 0x36d50f40, 0x752201f3, 0x00000000}},  //   टील_, _возр, _dooz,
  { {0x6ac70044, 0x7bcd0f41, 0x27ed00fa, 0x00000000}},  //   র্রো, irau, _ipen_,
  { {0x88bd0036, 0x7bcd010f, 0x20090f42, 0x00000000}},  //   _gośc, hrau, _arai_,
  { {0x291d000b, 0x7bcd0006, 0x008604f9, 0x00000000}},  //   njwa_, krau, илно,
  { {0x2365012d, 0x20090f43, 0x00000000, 0x00000000}},  //   polj_, _crai_,   ,
  { {0x7bcd03ee, 0x82a50057, 0x56b5007b, 0x00000000}},  //   drau, _такж, יפֿן_,
  { {0x63a9022b, 0x99d70044, 0x20090035, 0x00000000}},  //   lpen, সবুক, _erai_,
  { {0xf388001d, 0x27ed0f44, 0x7bcd01a2, 0x00000000}},  //   _hợp_, _open_, frau,
  { {0x63a90f45, 0x4d630088, 0x26c50f46, 0x00000000}},  // [1900] npen, ікув, _odlo_,
  { {0x68e901d6, 0x63a9002d, 0x09e6017a, 0x00000000}},  //   _abed, ipen, иозн,
  { {0xe9da0f47, 0xa2d80309, 0xfce6012c, 0x00000000}},  //   тке_, _मास्, _коно,
  { {0x7bcd0f48, 0x88e6007c, 0x76000010, 0x00000000}},  //   brau, ржде, házá,
  { {0x79820046, 0x76000f49, 0x6b8e002b, 0x00000000}},  //   rmow, kázá, _tibg,
  { {0x63a90f4a, 0x88bd0036, 0x6d560022, 0x00000000}},  //   dpen, _pośc, lnya,
  { {0xd5b70147, 0xdced006b, 0x27ed00d9, 0x00000000}},  //   асы_, nmağ, _epen_,
  { {0x6d560010, 0xa91d0471, 0x00000000, 0x00000000}},  //   nnya, _bižu,   ,
  { {0x63a90f4b, 0x27e90666, 0xa5070ab7, 0x00000000}},  //   gpen, çant_, рења_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d560f4c, 0x7bcd0089, 0xd2570088, 0x00000000}},  //   knya, zrau, ицю_,
  { {0x2bc70061, 0x6126000c, 0x20090145, 0x00000000}},  //   _लिला, _sólr, _prai_,
  { {0xe53b00b6, 0x00000000, 0x00000000, 0x00000000}},  //   _בתאר,   ,   ,
  { {0x200900f4, 0x00000000, 0x00000000, 0x00000000}},  //   _vrai_,   ,   ,
  { {0x937b01ce, 0x00000000, 0x00000000, 0x00000000}},  //   _שטות,   ,   ,
  { {0x7bcd010a, 0x2009001d, 0xc0cb0e82, 0x00000000}},  //   trau, _trai_, _руке_,
  { {0x20090f4d, 0xbc790f4e, 0x2d9c0010, 0x00000000}},  // [1910] _urai_, убах_, _éven_,
  { {0x7bcd0f4f, 0xdab90439, 0x00000000, 0x00000000}},  //   rrau, اهات_,   ,
  { {0x81e40055, 0x63a9022b, 0xceb200a3, 0x00000000}},  //   নিক_, zpen, _מיי_,
  { {0x637d0666, 0x2739009d, 0x63a90f50, 0x00000000}},  //   mène, _mène_, ypen,
  { {0x9ac700a1, 0x98e40025, 0x63a90133, 0x00000000}},  //   _نگاہ_, تكنو, xpen,
  { {0x57a4007e, 0x00000000, 0x00000000, 0x00000000}},  //   ішча,   ,   ,
  { {0x80c20055, 0x7c2d006b, 0x80dd0044, 0x00000000}},  //   ষ্ট্, lyar, _বসন্,
  { {0x68e9003b, 0x63a90f51, 0x1e58009b, 0x00000000}},  //   _ubed, tpen, ישור_,
  { {0x7c2d0f52, 0x63a90f53, 0x637d009d, 0x00000000}},  //   nyar, upen, hène,
  { {0xf5e701fb, 0x63a90f54, 0x6d4d006c, 0x00000000}},  //   _відм, rpen, hiaa,
  { {0xa2d802f4, 0x7c2d01a3, 0x22490545, 0x00000000}},  //   _मार्, hyar, упни_,
  { {0x63a90292, 0x04950025, 0x645e0036, 0x00000000}},  //   ppen, _الإح, _śpie,
  { {0x6d4d0f55, 0x7c2d0009, 0x00000000, 0x00000000}},  //   diaa, jyar,   ,
  { {0x442d0263, 0xdced006b, 0x00000000, 0x00000000}},  //   mye_, tmağ,   ,
  { {0x442d0263, 0x443f0f56, 0x637d0f57, 0x00000000}},  //   lye_, lzu_, rènd,
  { {0xe0da012b, 0xdced0f58, 0x6d4d01a3, 0x00000000}},  //   _сви_, rmağ, giaa,
  { {0x442d0f59, 0xec7a0265, 0x7c2d0047, 0x00000000}},  // [1920] nye_, упа_, gyar,
  { {0x8a3a0057, 0x2ca00276, 0x442d0f5a, 0x00000000}},  //   ляет_, scid_, iye_,
  { {0xd910007a, 0xb4f90309, 0x442d0065, 0x00000000}},  //   ویس_, ्याय_, hye_,
  { {0x6d4d00b5, 0x7c2d0020, 0x442d0a20, 0x00000000}},  //   ciaa, byar, kye_,
  { {0x442d0f5b, 0x2912005a, 0x2bba0025, 0x00000000}},  //   jye_, ıya_, _حاجة_,
  { {0x443f001e, 0x7d040ad1, 0x442d0f5c, 0x00000000}},  //   dzu_, ldis, dye_,
  { {0x2d9a009d, 0x442d0f5d, 0xe7f4006e, 0x00000000}},  //   _jupe_, eye_, _इनका_,
  { {0x442d0263, 0x3e83009d, 0x00000000, 0x00000000}},  //   fye_, lété_,   ,
  { {0x442d0047, 0x7d040051, 0x2d9a0f5e, 0x00000000}},  //   gye_, idis, _lupe_,
  { {0xdced0ecc, 0x7d04021e, 0xd6d2031d, 0x00000000}},  //   vlač, hdis, _رقص_,
  { {0x443f00f6, 0x7d040460, 0x442d0f5f, 0x00000000}},  //   azu_, kdis, aye_,
  { {0xd2570ee0, 0x442d0f60, 0x753b0020, 0x00000000}},  //   сць_, bye_, chuz,
  { {0x7d0401bc, 0x506701e0, 0xa2b10061, 0x00000000}},  //   ddis, стна, _आजच्,
  { {0x3eba01c5, 0x6d5a009d, 0xdcef0089, 0x00000000}},  //   _cept_, étan, _ticī,
  { {0xdced037e, 0x8d77023c, 0x6d4d0f61, 0x00000000}},  //   slač, مارا, tiaa,
  { {0xdced0059, 0x2d9a00bb, 0x7d040058, 0x00000000}},  //   plač, _dupe_, gdis,
  { {0xac180f62, 0x6d4d021e, 0x7bd60093, 0x00000000}},  // [1930] боту_, riaa, guyu,
  { {0x6d4d021e, 0x64400089, 0x7c2d0f63, 0x00000000}},  //   siaa, izmi, ryar,
  { {0x7c2d0149, 0x443f0209, 0x637d0129, 0x00000000}},  //   syar, zzu_, lènc,
  { {0x2730001d, 0x26de0211, 0xcebc006b, 0x00000000}},  //   _hành_, _acto_, _şəxs_,
  { {0x81e40044, 0x186901fc, 0x2d9a016c, 0x00000000}},  //   নিট_, јали_, _zupe_,
  { {0xe7360265, 0x443f005f, 0x442d09e5, 0x00000000}},  //   жеш_, vzu_, vye_,
  { {0xf7700558, 0x27300082, 0x442d0f64, 0x00000000}},  //   راه_, _mành_, wye_,
  { {0x442d0263, 0x443f022b, 0x27300011, 0x00000000}},  //   tye_, tzu_, _lành_,
  { {0x442d0f65, 0xdce40107, 0x00000000, 0x00000000}},  //   uye_, slić,   ,
  { {0x442d0f66, 0x637d0129, 0x78bb00bb, 0x00000000}},  //   rye_, dènc, _heuv,
  { {0x442d0f67, 0x2d570f68, 0x443f0036, 0x00000000}},  //   sye_, għek_, szu_,
  { {0x2d9a016c, 0x3eba0f69, 0x442d01aa, 0x00000000}},  //   _rupe_, _sept_, pye_,
  { {0x637d0129, 0x2d9a0f6a, 0x41c5007d, 0x00000000}},  //   gènc, _supe_, _विकस,
  { {0x78bb00bb, 0x27300011, 0x7d040009, 0x00000000}},  //   _leuv, _cành_, wdis,
  { {0x2730001d, 0x78bb00f4, 0x7d0401a2, 0x00000000}},  //   _dành_, _oeuv, tdis,
  { {0x78bb0f6b, 0x2fcd0059, 0x6cd60076, 0x00000000}},  //   _neuv, šega_, تقرا,
  { {0x637d0129, 0x78a20f6c, 0xa3dc0061, 0x00000000}},  // [1940] cènc, vcov, तंय_,
  { {0x7bd6005d, 0x2d9a0020, 0x63a40051, 0x00000000}},  //   ruyu, _tupe_, _éine,
  { {0x7d040f6d, 0x6abe0c3f, 0x3e83009d, 0x00000000}},  //   pdis, rapf, rété_,
  { {0x1d0a0364, 0x69c30f6e, 0x27ff00e5, 0x00000000}},  //   _теми_, ânea, _bsun_,
  { {0x78a20142, 0x3860006b, 0xa81700a1, 0x00000000}},  //   rcov, çir_, قتور_,
  { {0x78a200ab, 0x3860002b, 0x00000000, 0x00000000}},  //   scov, ħir_,   ,
  { {0xa3dc04da, 0x78a20142, 0x00000000, 0x00000000}},  //   तून_, pcov,   ,
  { {0x6abc0030, 0x63740129, 0x7bc40006, 0x00000000}},  //   _herf, màni, osiu,
  { {0x54540f6f, 0x7bc404f5, 0x5397007e, 0x00000000}},  //   явит, nsiu, овыя_,
  { {0x29040093, 0x799c0590, 0x637d0129, 0x00000000}},  //   _hama_, _kurw, vènc,
  { {0x29040be3, 0x7bc400e0, 0x2ef801d6, 0x00000000}},  //   _kama_, hsiu, derf_,
  { {0x09cf0055, 0x2904006c, 0x29060f70, 0x00000000}},  //   _রহমা, _jama_, ndoa_,
  { {0x27e604cb, 0x29040727, 0x74130025, 0x00000000}},  //   nton_, _mama_, _يوما,
  { {0x2904020c, 0x637d04bd, 0x6abc04c1, 0x00000000}},  //   _lama_, rènc, _nerf,
  { {0xdcbb0f71, 0x637d0129, 0x313502b0, 0x00000000}},  //   ища_, sènc, _некр,
  { {0x5c9904af, 0x29040149, 0x27e60f72, 0x00000000}},  //   ская_, _nama_, kton_,
  { {0x7af70f73, 0xdfdb005e, 0x6abc0f74, 0x00000000}},  // [1950] text, _тъй_, _berf,
  { {0x501c00a0, 0x6abc0f75, 0x60dd0296, 0x00000000}},  //   _כוחו, _cerf, lgsm,
  { {0x78bb028c, 0x6abc0f76, 0x27e6008e, 0x00000000}},  //   _peuv, _derf, eton_,
  { {0x27e60f77, 0x2904029d, 0x7af7004a, 0x00000000}},  //   fton_, _cama_, sext,
  { {0x01e00055, 0x27e60011, 0x394f09b3, 0x00000000}},  //   ববিদ, gton_, rigs_,
  { {0x394f00f6, 0x2739000a, 0xdb0400c4, 0x00000000}},  //   sigs_, _bèna_, rpiã,
  { {0x6728037e, 0x27e600b0, 0x63740129, 0x00000000}},  //   _dodj, aton_, càni,
  { {0x21290058, 0x29040f6a, 0x69c50023, 0x00000000}},  //   _noah_, _gama_, mshe,
  { {0x69c504f2, 0x394d00ea, 0x27ff0f78, 0x00000000}},  //   lshe, _imes_, _usun_,
  { {0x466b01e0, 0x6f050146, 0x69c50f79, 0x00000000}},  //   _крем_, _nahc, oshe,
  { {0xe8030309, 0x2ef80f7a, 0x29040095, 0x00000000}},  //   लिका_, verf_, _yama_,
  { {0x67230ed8, 0x2ef8040f, 0x69c50133, 0x00000000}},  //   ljnj, werf_, ishe,
  { {0x88bd0036, 0x200f0285, 0x2ef801d6, 0x00000000}},  //   _rośl, _ágil_, terf_,
  { {0x69c50065, 0x395f0039, 0x2d9c0010, 0x00000000}},  //   kshe, _ljus_, _évek_,
  { {0x6b9d001f, 0x69c50f7b, 0x6b400abc, 0x00000000}},  //   _ausg, jshe, _högg,
  { {0x69c50030, 0x6abc01d6, 0x6b950089, 0x00000000}},  //   dshe, _serf, _aizg,
  { {0x29040f7c, 0x2cb20016, 0x69c50f7d, 0x00000000}},  // [1960] _rama_, rbyd_, eshe,
  { {0x2904020c, 0x4a9a008b, 0x7bc4001a, 0x00000000}},  //   _sama_, стаў_, rsiu,
  { {0x6abc0a9b, 0x6728037e, 0x4ae2001c, 0x00000000}},  //   _verf, _rodj, _पाठव,
  { {0x27e60866, 0x6abc0125, 0x2d82010e, 0x00000000}},  //   tton_, _werf, _uhke_,
  { {0x672801d9, 0x29040091, 0x6abc030c, 0x00000000}},  //   _podj, _vama_, _terf,
  { {0x395f0173, 0x47330088, 0x7d06014a, 0x00000000}},  //   _ejus_, нніс, _haks,
  { {0x7d060f7e, 0x2904006a, 0x27e60f7f, 0x00000000}},  //   _kaks, _tama_, ston_,
  { {0x27e60065, 0x7d060f80, 0xda5b00b3, 0x00000000}},  //   pton_, _jaks, _הכלל,
  { {0x7d060f81, 0x69c7016e, 0x00000000, 0x00000000}},  //   _maks, _zvje,   ,
  { {0x883b00b6, 0x637d0263, 0x63ab0145, 0x00000000}},  //   _התמו, tèna, _dtgn,
  { {0x76430046, 0x26cc018e, 0x6587000c, 0x00000000}},  //   czny, _iddo_, árhæ,
  { {0xf48704e1, 0x7d060052, 0x867b0049, 0x00000000}},  //   _کامی, _naks, _פראו,
  { {0x60dd00eb, 0xcfa7007c, 0xfc3f004a, 0x00000000}},  //   rgsm, яшни, _afín_,
  { {0x3da701be, 0x69c50f82, 0x7d060f83, 0x00000000}},  //   зраб, yshe, _aaks,
  { {0x7d060039, 0xdef8007e, 0x9e140088, 0x00000000}},  //   _baks, чыя_, ндрі,
  { {0x69c50190, 0x6b9d0089, 0x00000000, 0x00000000}},  //   vshe, _pusg,   ,
  { {0x69c70182, 0xfe70026c, 0xd11a0309, 0x00000000}},  // [1970] _svje, ندہ_, धारण_,
  { {0x69c50de8, 0x394d087a, 0x69c300c4, 0x00000000}},  //   tshe, _smes_, âneo,
  { {0x7d060f84, 0x6aa50f85, 0xf9f90380, 0x00000000}},  //   _faks, rchf, تفاع_,
  { {0x69c5008d, 0xac19003b, 0x26cc0016, 0x00000000}},  //   rshe, _дому_, _addo_,
  { {0x69c50efd, 0x394d0059, 0xfc64005e, 0x00000000}},  //   sshe, _vmes_, _зърн,
  { {0xe29a0011, 0x69c50f86, 0x00000000, 0x00000000}},  //   _ngư_, pshe,   ,
  { {0x69c70182, 0xba77089d, 0x945d0036, 0x00000000}},  //   _uvje, _راست, kańc,
  { {0xbe3c009b, 0x60cd0f87, 0x394d01ee, 0x00000000}},  //   מעות, _ndam, _umes_,
  { {0xb4ad03d7, 0x67d40088, 0x76430f88, 0x00000000}},  //   _कभी_, _поту, szny,
  { {0x60cd038c, 0xd75b0014, 0x644d0006, 0x00000000}},  //   _adam, _اجرا_, _žais,
  { {0x77640129, 0xa51d007e, 0x6ed70204, 0x00000000}},  //   éixe, _вялi, _बाजु,
  { {0xa3b0013d, 0x00000000, 0x00000000, 0x00000000}},  //   टीङ_,   ,   ,
  { {0x7d06001e, 0x6b400039, 0x60cd0016, 0x00000000}},  //   _raks, _höge, _ddam,
  { {0x7d0608b2, 0x6d4f0f89, 0x60cd013f, 0x00000000}},  //   _saks, _amca, _edam,
  { {0x7d06006a, 0x2d9e00f4, 0x1b060055, 0x00000000}},  //   _paks, ête_, রামে_,
  { {0x6b4009b0, 0x6d4f0009, 0x00000000, 0x00000000}},  //   _möge, _cmca,   ,
  { {0x7d060f8a, 0x5ed30044, 0xed5700ed, 0x00000000}},  // [1980] _vaks, দ্ধে, фот_,
  { {0x7d060145, 0x4c8300e2, 0x00000000, 0x00000000}},  //   _waks, тлув,   ,
  { {0xe0df00f6, 0xe800013d, 0x752b00d9, 0x00000000}},  //   ciòs_, लौना_, _oogz,
  { {0x637400d4, 0x00000000, 0x00000000, 0x00000000}},  //   lànt,   ,   ,
  { {0x07fa0f8b, 0x07a309e6, 0xf746012d, 0x00000000}},  //   تراع_, вачн, медо,
  { {0xeb9f02cc, 0xb865035b, 0x2fcf06ec, 0x00000000}},  //   _prøv_, رانو, _ægge_,
  { {0x8a030216, 0x00000000, 0x00000000, 0x00000000}},  //   _изре,   ,   ,
  { {0xa926007e, 0x00000000, 0x00000000, 0x00000000}},  //   _ўдал,   ,   ,
  { {0x671e0309, 0x14180025, 0x752b0023, 0x00000000}},  //   पादक_, سيدة_, _dogz,
  { {0xf7720054, 0x6b4000f8, 0x00000000, 0x00000000}},  //   _شاء_, _högb,   ,
  { {0x2fc902e7, 0x00000000, 0x00000000, 0x00000000}},  //   _svag_,   ,   ,
  { {0x92be0055, 0x914b01e1, 0xd2570a7c, 0x00000000}},  //   ইলে_, ічна_, ьцы_,
  { {0xe0df0026, 0xf41f00b0, 0x945d00b4, 0x00000000}},  //   rgò_, äät_, rańc,
  { {0x6b40000c, 0x00000000, 0x00000000, 0x00000000}},  //   _lögb,   ,   ,
  { {0xf206005e, 0x00000000, 0x00000000, 0x00000000}},  //   _цяло,   ,   ,
  { {0x9d18005e, 0x2c0b0061, 0x00000000, 0x00000000}},  //   мост_, हटलं_,   ,
  { {0x63ad0f8c, 0xfd1f0082, 0x37be0044, 0x00000000}},  // [1990] _çant, _chìa_, _উৎসর,
  { {0xdb0d000c, 0x637400f6, 0x00000000, 0x00000000}},  //   gsað, cànt,   ,
  { {0x6d4f0009, 0x00000000, 0x00000000, 0x00000000}},  //   _tmca,   ,   ,
  { {0xa2d8001c, 0x6562008d, 0xdce4014a, 0x00000000}},  //   _माझ्, _njoh, mliğ,
  { {0x7ac700aa, 0xdce4014a, 0x00000000, 0x00000000}},  //   _осве, lliğ,   ,
  { {0x2d99070c, 0x6d910142, 0x80380049, 0x00000000}},  //   _hise_, _sťah, ונדע_,
  { {0x58d501f9, 0xdce4011f, 0x2d990f8d, 0x00000000}},  //   _повт, nliğ, _kise_,
  { {0x6b4001a2, 0xd618006d, 0x00000000, 0x00000000}},  //   _vöge, بتها_,   ,
  { {0x2d990f8e, 0x47d50054, 0x443903f0, 0x00000000}},  //   _mise_, _سيار, ás_,
  { {0x42250057, 0x2d99014a, 0xdce4014a, 0x00000000}},  //   едов, _lise_, kliğ,
  { {0x4ae203d7, 0x78a40dbd, 0x2d9900f4, 0x00000000}},  //   _पासव, žive, _oise_,
  { {0x2d990b97, 0xa06a003b, 0x00000000, 0x00000000}},  //   _nise_, зама_,   ,
  { {0x98a40089, 0x1b060044, 0x00000000, 0x00000000}},  //   _jomā_, রাতে_,   ,
  { {0xa3570f8f, 0x2d990f90, 0xcad50044, 0x00000000}},  //   _تخصص, _aise_, স্তফ,
  { {0x2d990f91, 0x00000000, 0x00000000, 0x00000000}},  //   _bise_,   ,   ,
  { {0x62830f92, 0x00000000, 0x00000000, 0x00000000}},  //   _izno,   ,   ,
  { {0xe7da0055, 0x4f960f93, 0xbea6007c, 0x00000000}},  // [19a0] _ধন্য, _проу, _папк,
  { {0xdce40180, 0x2d990007, 0x2d9e00c4, 0x00000000}},  //   bliğ, _eise_, ítes_,
  { {0x5336007b, 0xdebb0097, 0xe8fa0f94, 0x00000000}},  //   ענען_, _ממיל, зле_,
  { {0xe1ff0046, 0xeb9a041f, 0xfd1f0082, 0x00000000}},  //   łów_, _ним_, _thìa_,
  { {0x6d56006b, 0x3f9a0052, 0x4e960014, 0x00000000}},  //   miya, _kipu_, _تشکر,
  { {0x6d56005d, 0x98a40089, 0x2d990035, 0x00000000}},  //   liya, _domā_, _zise_,
  { {0xceb300b6, 0x6b6306b6, 0x850400a1, 0x00000000}},  //   ניה_, _скра, ہوںن,
  { {0x6d560f95, 0x657b0f96, 0x6d4400c4, 0x00000000}},  //   niya, gluh, nhia,
  { {0xe3af01ef, 0xd9430f97, 0xa9670f98, 0x00000000}},  //   یری_, _сети, _чита_,
  { {0xfd1f001d, 0x6d5600e0, 0x68e20190, 0x00000000}},  //   _nhìn_, hiya, lgod,
  { {0x6d560f99, 0x6d4405cd, 0xf41f006c, 0x00000000}},  //   kiya, khia, äär_,
  { {0x88bd0036, 0x8466005e, 0x7afe01d6, 0x00000000}},  //   _dośw, _пъле, hept,
  { {0x6d560f9a, 0x54330380, 0x55770049, 0x00000000}},  //   diya, _مرور, _װעגן_,
  { {0x69de00b0, 0x2d990f9b, 0x15f4006e, 0x00000000}},  //   kupe, _sise_, _आहार_,
  { {0x2d99016c, 0x63a20f9c, 0xf8d00061, 0x00000000}},  //   _pise_, _huon, हणाय,
  { {0x63a2000b, 0x6d56005f, 0x6d440412, 0x00000000}},  //   _kuon, giya, ghia,
  { {0x2d990292, 0x63a200b0, 0x65600048, 0x00000000}},  // [19b0] _vise_, _juon, inmh,
  { {0x63a20020, 0x2d990133, 0xdced012d, 0x00000000}},  //   _muon, _wise_, klać,
  { {0x63a20f9d, 0xda670426, 0x2d990f9e, 0x00000000}},  //   _luon, رائي, _tise_,
  { {0x6d440198, 0x637d0263, 0xacbb00f4, 0x00000000}},  //   chia, vènm, _coût,
  { {0x7d0d000c, 0x63a20f9f, 0x66e50fa0, 0x00000000}},  //   mdas, _nuon, вола,
  { {0xf72b007e, 0x7d0d0ad1, 0x7bdf0026, 0x00000000}},  //   яцей_, ldas, muqu,
  { {0x7bdf008e, 0xc1790006, 0xae14006e, 0x00000000}},  //   luqu, ntės_, डियन_,
  { {0x63a20fa1, 0x7d0d0fa2, 0xacbb00f4, 0x00000000}},  //   _buon, ndas, _goût,
  { {0x63a20011, 0x6b4000f8, 0x00000000, 0x00000000}},  //   _cuon, _höga,   ,
  { {0x63a20fa3, 0x6d56006b, 0x88bd0036, 0x00000000}},  //   _duon, ziya, _pośw,
  { {0x216a0113, 0x26c70fa4, 0x614600e3, 0x00000000}},  //   дини_, mano_, вена,
  { {0x26c70198, 0x7afe0fa5, 0x8fa6007e, 0x00000000}},  //   lano_, zept, каме,
  { {0xf992007b, 0xa3a8001c, 0xaae201f5, 0x00000000}},  //   ירט_, _खूप_, _पालक,
  { {0x26c70207, 0x75290166, 0x6d5604be, 0x00000000}},  //   nano_, ljez, wiya,
  { {0x6d44018e, 0x6d560890, 0x50b60fa6, 0x00000000}},  //   thia, tiya, _испу,
  { {0x26120204, 0x7d0d0058, 0x7c24002d, 0x00000000}},  //   थिती_, gdas, txir,
  { {0x6449001f, 0x26c709bd, 0x7afe001a, 0x00000000}},  // [19c0] nzei, kano_, tept,
  { {0x6d56005f, 0x60c40fa7, 0x69de01ca, 0x00000000}},  //   siya, _heim, tupe,
  { {0x26c70036, 0x3ed9007b, 0x6449010f, 0x00000000}},  //   dano_, _אַרא, hzei,
  { {0x7afe0fa8, 0x79890016, 0x6c860025, 0x00000000}},  //   sept, _chew, _للجم,
  { {0x26c70fa9, 0x69de010e, 0x68e20faa, 0x00000000}},  //   fano_, supe, rgod,
  { {0x26c7016e, 0x60c400b0, 0x68e20016, 0x00000000}},  //   gano_, _leim, sgod,
  { {0x63a20207, 0x2d9c0047, 0x24800089, 0x00000000}},  //   _suon, _éves_, _šim_,
  { {0x60c40391, 0x6449010f, 0xe56f0439, 0x00000000}},  //   _neim, fzei, يطي_,
  { {0x07a60057, 0x26c700d6, 0x6b9c006c, 0x00000000}},  //   _разн, bano_, _kirg,
  { {0x26c70555, 0x394602d5, 0x7d0d0047, 0x00000000}},  //   cano_, lhos_, zdas,
  { {0x53d4001c, 0x61ea0009, 0x7d0d0279, 0x00000000}},  //   _दिवश, _qqfl, ydas,
  { {0x394602d5, 0x63a20fab, 0x5187012b, 0x00000000}},  //   nhos_, _tuon, ђуна,
  { {0x14d70476, 0x60c40fac, 0x934608d6, 0x00000000}},  //   _יואל_, _deim, _инде,
  { {0x5333025f, 0x6b9c01a2, 0x00000000, 0x00000000}},  //   _вешт, _nirg,   ,
  { {0x2fc0063c, 0x02fb0104, 0x60c40fad, 0x00000000}},  //   _ewig_, _חלומ, _feim,
  { {0x60c4000c, 0x26c70340, 0x6b9c0122, 0x00000000}},  //   _geim, zano_, _airg,
  { {0x7d0d0149, 0x6b9c0fae, 0x26c7011c, 0x00000000}},  // [19d0] rdas, _birg, yano_,
  { {0x7cde001a, 0x20090b97, 0x26c70faf, 0x00000000}},  //   tărâ, _isai_, xano_,
  { {0x26c70198, 0x6b9c0016, 0x7d0d046a, 0x00000000}},  //   vano_, _dirg, pdas,
  { {0x26c70fb0, 0x00000000, 0x00000000, 0x00000000}},  //   wano_,   ,   ,
  { {0x26c70fb1, 0x386903d1, 0x9bc4007e, 0x00000000}},  //   tano_, çar_, _вёск,
  { {0xa03c00b6, 0x386901d5, 0x6b9c0fb2, 0x00000000}},  //   ועדפ, ħar_, _girg,
  { {0x78a40119, 0xa3e50061, 0xa3a8006e, 0x00000000}},  //   živa, बून_, _खूब_,
  { {0xf3ff0fb3, 0x39460219, 0xb4ad001c, 0x00000000}},  //   ção_, chos_, कडे_,
  { {0xf8ae026c, 0x26c70fb4, 0x68e90066, 0x00000000}},  //   _رکن_, pano_, _iced,
  { {0x6449001f, 0x60c4010a, 0x753b0224, 0x00000000}},  //   rzei, _seim, skuz,
  { {0x64490fb5, 0x7ae50051, 0x2fc00fb6, 0x00000000}},  //   szei, ight, _swig_,
  { {0xe4cb007a, 0x26c5005b, 0x7bcd01b1, 0x00000000}},  //   _آبان_, _helo_, ksau,
  { {0xb4df024c, 0x25a50fb7, 0xfd1f0011, 0x00000000}},  //   तली_, _hull_, _chìm_,
  { {0x25a501d5, 0x60c404b2, 0x26c50e45, 0x00000000}},  //   _kull_, _weim, _jelo_,
  { {0x60c40fb8, 0x26c50181, 0x20090fb9, 0x00000000}},  //   _teim, _melo_, _esai_,
  { {0x2d8b0ce2, 0x61e100b0, 0xf1b200a0, 0x00000000}},  //   _chce_, mull, _פסח_,
  { {0x61e10127, 0xac86026b, 0x25a50fba, 0x00000000}},  // [19e0] lull, угал, _lull_,
  { {0xec770fbb, 0xaf060fbc, 0x68e900c4, 0x00000000}},  //   упу_, _спол, _aced,
  { {0x61e10fbd, 0x25a50541, 0x637d0129, 0x00000000}},  //   null, _null_, gèni,
  { {0x07a6007e, 0xb4ad0204, 0x6b40000c, 0x00000000}},  //   гадн, कडो_, _gögn,
  { {0x26c50181, 0x6b9c001e, 0x7e7e00b0, 0x00000000}},  //   _belo_, _tirg, _hypp,
  { {0x61e1008d, 0x26c501d9, 0xfaa3007e, 0x00000000}},  //   kull, _celo_, _гаро,
  { {0x212001cd, 0x26c501d9, 0x290d0022, 0x00000000}},  //   _onih_, _delo_, _faea_,
  { {0x9d220055, 0x61e10fbe, 0x2d8001d6, 0x00000000}},  //   _নতুন_, dull, nlie_,
  { {0x78660454, 0x26c50145, 0x00000000, 0x00000000}},  //   _сказ, _felo_,   ,
  { {0x25a50038, 0x61e100ab, 0x26c500c4, 0x00000000}},  //   _full_, full, _gelo_,
  { {0x61e10fbf, 0x00000000, 0x00000000, 0x00000000}},  //   gull,   ,   ,
  { {0x26c501d9, 0xa1590fc0, 0x64a6003b, 0x00000000}},  //   _zelo_, таму_, _сада,
  { {0xd0e602fb, 0x5436031d, 0x26c5011c, 0x00000000}},  //   _कारण_, _حرار, _yelo_,
  { {0xa2940451, 0x2d800fc1, 0x212000ca, 0x00000000}},  //   _калі, elie_, _enih_,
  { {0x61e100d4, 0x1df80783, 0x00000000, 0x00000000}},  //   cull, леры_,   ,
  { {0x2d8004b8, 0x7bcd0706, 0x20090085, 0x00000000}},  //   glie_, tsau, _tsai_,
  { {0x2009023a, 0x5c990147, 0x7bcd0be1, 0x00000000}},  // [19f0] _usai_, ткая_, usau,
  { {0x7ae500ab, 0x6d5a0e9d, 0x637d0173, 0x00000000}},  //   ught, étar, tèni,
  { {0x7bcd006c, 0x2d800fc2, 0x26c5011c, 0x00000000}},  //   ssau, blie_, _relo_,
  { {0x26c50209, 0x98c70025, 0x25a50fc3, 0x00000000}},  //   _selo_, اغان, _rull_,
  { {0xf7710025, 0x26c502d5, 0x25a50198, 0x00000000}},  //   يات_, _pelo_, _sull_,
  { {0x45d50517, 0x25a500ab, 0x39440fc4, 0x00000000}},  //   ацит, _pull_, _elms_,
  { {0x6b40001f, 0x26c508f7, 0x65c20242, 0x00000000}},  //   _mögl, _velo_, обща,
  { {0xb4df0183, 0x613f008d, 0x61e10fc5, 0x00000000}},  //   तले_, _qëll, vull,
  { {0xa3e5007d, 0x613f0065, 0x7d0f0010, 0x00000000}},  //   बंध_, _vëll, _macs,
  { {0x61e1008d, 0x7d0f041d, 0x25a500f8, 0x00000000}},  //   tull, _lacs, _tull_,
  { {0x2d80074e, 0xcb120097, 0xe1260088, 0x00000000}},  //   ylie_, קלט_, амни,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x22590036, 0x61e10329, 0x316901aa, 0x00000000}},  //   ńsk_, sull, _djaz_,
  { {0x61e10fc6, 0x3f9e0fc7, 0xdee60098, 0x00000000}},  //   pull, ötu_, јови,
  { {0x42790049, 0x3f84001e, 0xed5a007c, 0x00000000}},  //   _באַג, ēmu_, вов_,
  { {0x20560c96, 0xdca30900, 0xee3700e2, 0x00000000}},  //   _втор, жати, шнс_,
  { {0x0c26017f, 0x00000000, 0x00000000, 0x00000000}},  // [1a00] шман,   ,   ,
  { {0x2d800133, 0x7e7e0fc8, 0x00000000, 0x00000000}},  //   slie_, _typp,   ,
  { {0x7d0f031e, 0xa3e5007d, 0x6edb009b, 0x00000000}},  //   _facs, बूत_, _בחיפ,
  { {0xd946012b, 0xaae20061, 0xdb060023, 0x00000000}},  //   једи, _पाकक, _kukë,
  { {0x7d04021e, 0x78a4040d, 0xfaa60088, 0x00000000}},  //   meis, živo, _ваго,
  { {0x5777007e, 0xed590142, 0x00000000, 0x00000000}},  //   абіў_, ďže_,   ,
  { {0x645d000c, 0xe7370545, 0x60d60085, 0x00000000}},  //   úsin, реј_, _odym,
  { {0x7d04021e, 0x2b580544, 0x00000000, 0x00000000}},  //   neis, _hmrc_,   ,
  { {0x66e601fc, 0xc34a005e, 0x6b40000c, 0x00000000}},  //   _воза, вяне_, _lögm,
  { {0x7d040fc9, 0x79820038, 0x973c0107, 0x00000000}},  //   heis, llow, _biće,
  { {0x7d040ecb, 0x6d4600b0, 0x00000000, 0x00000000}},  //   keis, _olka,   ,
  { {0x9257007c, 0x8556025a, 0xdb060023, 0x00000000}},  //   рают_, _خیبر_, _bukë,
  { {0x320200b9, 0x7522016e, 0x7d040052, 0x00000000}},  //   ňky_, _inoz, deis,
  { {0x6d460fca, 0x7d0f096b, 0xc0580088, 0x00000000}},  //   _alka, _sacs, рію_,
  { {0xd3780119, 0x7d040016, 0x79820036, 0x00000000}},  //   moć_, feis, klow,
  { {0x929b00b6, 0x7d040abe, 0x7c87007c, 0x00000000}},  //   _ביות, geis, аузе,
  { {0xfaa7007c, 0x75220062, 0xdfd1006d, 0x00000000}},  // [1a10] ашен, _mnoz, _عيد_,
  { {0x6d460fcb, 0xd5a400a1, 0x78a40f3a, 0x00000000}},  //   _elka, _يہ_, živl,
  { {0x3f830ce4, 0x7d0f0fcc, 0xce68007c, 0x00000000}},  //   mlju_, _tacs, _вряд_,
  { {0xae1a009b, 0x3e160049, 0x79820036, 0x00000000}},  //   _עורכ, _פֿיל_, glow,
  { {0x1b0f0044, 0xf8070256, 0xd3780fcd, 0x00000000}},  //   সাবে_, рчен, koć_,
  { {0xd246002c, 0x4429002b, 0xdb2300a2, 0x00000000}},  //   _فن_, _ħa_, _بوسی,
  { {0x79820036, 0x69de012d, 0x5a44007e, 0x00000000}},  //   blow, crpe, _дэта,
  { {0x798200d9, 0x00000000, 0x00000000, 0x00000000}},  //   clow,   ,   ,
  { {0x1422007e, 0x461500a6, 0x00000000, 0x00000000}},  //   здым, _گوار,   ,
  { {0xc8c800a1, 0x75220087, 0x00000000, 0x00000000}},  //   _موہن_, _enoz,   ,
  { {0xc4cf00a1, 0x7d0400e7, 0x00000000, 0x00000000}},  //   _ہےں_, yeis,   ,
  { {0xcea90097, 0x973c012d, 0x00000000, 0x00000000}},  //   _טי_, _viće,   ,
  { {0x4429028c, 0x05740025, 0xd3a7003b, 0x00000000}},  //   _ça_, _بالد, _треп,
  { {0x63bb020c, 0x7d04010f, 0x0239004b, 0x00000000}},  //   mpun, weis, _مثبت_,
  { {0x7d040fce, 0x6ade0044, 0x68fb0036, 0x00000000}},  //   teis, ন্ডো, _obud,
  { {0x90c60893, 0x00000000, 0x00000000, 0x00000000}},  //   _убие,   ,   ,
  { {0x63bb0039, 0x3f830166, 0x6d580006, 0x00000000}},  // [1a20] npun, blju_, _įvad,
  { {0x7d0403b6, 0x68fb03c9, 0x798205d2, 0x00000000}},  //   seis, _abud, wlow,
  { {0x7d040292, 0xe9da0aed, 0x993a01e1, 0x00000000}},  //   peis, уке_, ляду_,
  { {0x63bb07af, 0x00000000, 0x00000000, 0x00000000}},  //   kpun,   ,   ,
  { {0xe73a017f, 0x1867012b, 0xacf700a1, 0x00000000}},  //   лед_, баци_, _اسپت,
  { {0x63bb0039, 0xdce4002b, 0x78250025, 0x00000000}},  //   dpun, kniċ, تعمل,
  { {0xa96a05f6, 0xceb300a3, 0x63bb00d9, 0x00000000}},  //   _бива_, ליג_, epun,
  { {0x63bb0fcf, 0x00000000, 0x00000000, 0x00000000}},  //   fpun,   ,   ,
  { {0x63bb011c, 0x00000000, 0x00000000, 0x00000000}},  //   gpun,   ,   ,
  { {0xaaba02fb, 0x68fb05c9, 0x1b0f0044, 0x00000000}},  //   ेरिक, _zbud, সাথে_,
  { {0x3f830091, 0x63bb002d, 0x4b7b0049, 0x00000000}},  //   vlju_, apun, רטיג,
  { {0x73e6008b, 0x1a9b0049, 0x7147007c, 0x00000000}},  //   _годз, טייע, схож,
  { {0x3f830107, 0x27e60058, 0x637d0129, 0x00000000}},  //   tlju_, nuon_, tènt,
  { {0x2e180173, 0x3ea500ea, 0x00000000, 0x00000000}},  //   _bčf_, ølt_,   ,
  { {0x2000000a, 0x27e60022, 0x00000000, 0x00000000}},  //   _epii_, huon_,   ,
  { {0x52830054, 0x78a40243, 0x3f830fd0, 0x00000000}},  //   _عليك, živj, slju_,
  { {0xfd4f001d, 0x2906002d, 0x09d10061, 0x00000000}},  // [1a30] _khiế, deoa_, हळ्य,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27ff000d, 0xc987017f, 0x3ce902e1, 0x00000000}},  //   _spun_, буди, pgav_,
  { {0x63bb0fd1, 0x00000000, 0x00000000, 0x00000000}},  //   ypun,   ,   ,
  { {0x6aa9001a, 0x6d4d0434, 0x4ae20204, 0x00000000}},  //   _şefu, mhaa, _पाचव,
  { {0x70b50164, 0xfd4f0011, 0x68fb0036, 0x00000000}},  //   ंडुल, _nhiế, _wbud,
  { {0xc5d50088, 0x00000000, 0x00000000, 0x00000000}},  //   ціль,   ,   ,
  { {0x63bb0fd2, 0x68fb0415, 0x27e60fd3, 0x00000000}},  //   tpun, _ubud, buon_,
  { {0x69da0073, 0x63bb00b0, 0x7c2d0129, 0x00000000}},  //   _åter, upun, nxar,
  { {0xfd4f001d, 0x63bb0fd4, 0xe1f9003b, 0x00000000}},  //   _chiế, rpun, аго_,
  { {0x63bb000d, 0x6f0700b9, 0x6d4d0fd5, 0x00000000}},  //   spun, dejc, khaa,
  { {0x63bb0ba0, 0x27e00340, 0xd24e0014, 0x00000000}},  //   ppun, šine_, خچه_,
  { {0x6d4d0518, 0x297a0049, 0x00000000, 0x00000000}},  //   dhaa, שטרא,   ,
  { {0x65690fd6, 0x6da60fd7, 0x973c016c, 0x00000000}},  //   lneh, жива, _kića,
  { {0x417600a6, 0xbea30a78, 0x8d5a0fd8, 0x00000000}},  //   _وابس, дарк, ашат_,
  { {0x63a30004, 0x6d43001a, 0x657b01ee, 0x00000000}},  //   _hinn, _înal, nouh,
  { {0x63a30004, 0x3c66008b, 0xfd1f0011, 0x00000000}},  // [1a40] _kinn, цкаг, _nhìu_,
  { {0x63a3002b, 0x63ab0fd9, 0xbad5007e, 0x00000000}},  //   _jinn, _mugn, зіцы,
  { {0xdce40fda, 0xdca6017a, 0x2d8c0fdb, 0x00000000}},  //   lnič, _мани, ïdes_,
  { {0x63a30004, 0x98a60893, 0x6d4d00b5, 0x00000000}},  //   _linn, циде, chaa,
  { {0xd90d025a, 0x38cb02fd, 0x6b40000c, 0x00000000}},  //   دیق_, شانی_, _lögi,
  { {0xd04e005f, 0x501b0104, 0x1754041f, 0x00000000}},  //   ükəs, יונו, явля,
  { {0xdce4092f, 0x63ab0fdc, 0x5693025f, 0x00000000}},  //   hnič, _augn, машт,
  { {0x6d44010a, 0x7d160fdd, 0x63a30051, 0x00000000}},  //   nkia, ndys, _ainn,
  { {0x63a3049b, 0xfd4f001d, 0xdce40213, 0x00000000}},  //   _binn, _phiế, jnič,
  { {0x63a3002a, 0xdce40466, 0x63ab0006, 0x00000000}},  //   _cinn, dnič, _dugn,
  { {0x62830016, 0x63a300ab, 0x6d4400b0, 0x00000000}},  //   _cyno, _dinn, kkia,
  { {0x63a30fde, 0x62830016, 0x63ab0fdf, 0x00000000}},  //   _einn, _dyno, _fugn,
  { {0x63a30332, 0xfd4f001d, 0x7d16005b, 0x00000000}},  //   _finn, _thiế, ddys,
  { {0x63a30fe0, 0x93770025, 0x26cc00ca, 0x00000000}},  //   _ginn, _وصور_, _jedo_,
  { {0x6d5f005f, 0x26cc0fe1, 0x6d4d0fe2, 0x00000000}},  //   tiqa, _medo_, thaa,
  { {0x63a3095d, 0x91b70167, 0x7c2d002d, 0x00000000}},  //   _zinn, _بطور_, txar,
  { {0x6d4d0fe3, 0x64400142, 0x6f070450, 0x00000000}},  // [1a50] rhaa, nymi, pejc,
  { {0xce95005e, 0x6d4d0020, 0xbcfb0fe4, 0x00000000}},  //   _напъ, shaa, _omég,
  { {0x60cd0169, 0x64400943, 0x2fc90058, 0x00000000}},  //   _keam, hymi, _hwag_,
  { {0x6d440048, 0x64400052, 0x00000000, 0x00000000}},  //   ckia, kymi,   ,
  { {0x880700e9, 0x6d5d002b, 0xb807023c, 0x00000000}},  //   تظام, _imsa, تباه,
  { {0x26cc08e1, 0x60cd0048, 0x644000b4, 0x00000000}},  //   _cedo_, _leam, dymi,
  { {0x63a3002a, 0xdce40142, 0x26cc0d8e, 0x00000000}},  //   _rinn, znič, _dedo_,
  { {0x60cd0fe5, 0x442d0411, 0x63ab0197, 0x00000000}},  //   _neam, txe_, _pugn,
  { {0x65690fe6, 0xb4bb03d7, 0x442d00c4, 0x00000000}},  //   rneh, _अभी_, uxe_,
  { {0x6d44022b, 0x6d930181, 0xaacb007d, 0x00000000}},  //   zkia, lçad, िरिक,
  { {0x63a30635, 0x6d440006, 0x443f0fe7, 0x00000000}},  //   _vinn, ykia, syu_,
  { {0x6d9309f7, 0xdce40091, 0x63a30fe8, 0x00000000}},  //   nçad, tnič, _winn,
  { {0x63a30fe9, 0x82350014, 0x62830036, 0x00000000}},  //   _tinn, زرگا, _wyno,
  { {0x61e80027, 0xdce40626, 0x6d5d0fea, 0x00000000}},  //   budl, rnič, _amsa,
  { {0x61460feb, 0xdce40209, 0x00000000, 0x00000000}},  //   _нека, snič,   ,
  { {0x60cd001a, 0x78a40247, 0x6d440006, 0x00000000}},  //   _geam, živi, ukia,
  { {0x6d440fec, 0x2fc90016, 0xb05b06d3, 0x00000000}},  // [1a60] rkia, _gwag_, lbän,
  { {0x78a90207, 0x8eea0088, 0x6d44042c, 0x00000000}},  //   _agev, _умов_, skia,
  { {0x26cc0039, 0x64400fed, 0x00000000, 0x00000000}},  //   _redo_, zymi,   ,
  { {0x26cc0133, 0xdb04004a, 0x00000000, 0x00000000}},  //   _sedo_, rpiñ,   ,
  { {0x2d8202cc, 0x0c23007e, 0x26cc008e, 0x00000000}},  //   _ikke_, _змян, _pedo_,
  { {0x6d9300c4, 0xeb97004d, 0x78a90146, 0x00000000}},  //   açad, _ния_, _egev,
  { {0x78ad0825, 0x26cc0fee, 0x945d0036, 0x00000000}},  //   žava, _vedo_, kańs,
  { {0x644000b0, 0xe5a3003b, 0x945d0036, 0x00000000}},  //   tymi, нији, jańs,
  { {0x60cd0035, 0x7bd60fef, 0x26cc0087, 0x00000000}},  //   _ream, nsyu, _tedo_,
  { {0x60cd094e, 0x65600066, 0x39460ff0, 0x00000000}},  //   _seam, simh, lkos_,
  { {0x628701d5, 0x60cd0004, 0x672801d5, 0x00000000}},  //   żjon, _peam, _indj,
  { {0xf8cc03d7, 0x3946010a, 0x673a0ff1, 0x00000000}},  //   ारिय, nkos_, _hotj,
  { {0x60cd008e, 0x39460ff2, 0xa30b00a1, 0x00000000}},  //   _veam, ikos_, _گرنے_,
  { {0x973c016c, 0x6d5d0145, 0x673a0906, 0x00000000}},  //   _mićo, _smsa, _jotj,
  { {0x60cd0ff3, 0xfe700025, 0x6fd90061, 0x00000000}},  //   _team, هدف_, _भटकं,
  { {0x6b40000c, 0x2d58007c, 0x2fc90058, 0x00000000}},  //   _mögu, пись_, _twag_,
  { {0x6b40000c, 0x6728016e, 0x25a60022, 0x00000000}},  // [1a70] _lögu, _ondj, _miol_,
  { {0x2d820ff4, 0x2aab003b, 0x673a012d, 0x00000000}},  //   _ekke_, стао_, _notj,
  { {0x7f3c034e, 0x62860036, 0x442b0011, 0x00000000}},  //   _לעזו, ękow, ̣c_,
  { {0xbcfb0211, 0x39460ff5, 0x6d5d0218, 0x00000000}},  //   _ejér, gkos_, _umsa,
  { {0x6d9300c4, 0xe7390893, 0x2ba70061, 0x00000000}},  //   rçad, жел_, _कंटा,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf8ae026c, 0x25a600ab, 0x673a01ed, 0x00000000}},  //   اکہ_, _biol_, _dotj,
  { {0xe3b901fb, 0x6b40000c, 0xf99300d3, 0x00000000}},  //   оби_, _dögu, _سبز_,
  { {0x394d0ff6, 0x25a6000a, 0x395f0319, 0x00000000}},  //   _iles_, _diol_, _imus_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x779000a2, 0x25a60ff7, 0x6f0c006b, 0x00000000}},  //   _حیوا, _fiol_, _öncə,
  { {0x69d80181, 0x6b400039, 0xb05b010f, 0x00000000}},  //   ávei, _högt, rbän,
  { {0x657c0010, 0x76430ff8, 0xb05b06d3, 0x00000000}},  //   _írha, lyny, sbän,
  { {0x6265025f, 0x394d0016, 0x25a600f6, 0x00000000}},  //   _овла, _lles_, _ziol_,
  { {0xdef9008b, 0x8fa3007c, 0x945d0036, 0x00000000}},  //   чыў_, таре, pańs,
  { {0xa187005e, 0x00000000, 0x00000000, 0x00000000}},  //   _обща_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [1a80]   ,   ,   ,
  { {0x394d000d, 0x5f06007e, 0x7bd6003f, 0x00000000}},  //   _ales_, _ўзна, rsyu,
  { {0xceb301f8, 0x6b520030, 0x394d0944, 0x00000000}},  //   _בית_, _lægg, _bles_,
  { {0x78ad092f, 0x3946010a, 0x9cb60014, 0x00000000}},  //   žavn, ukos_, _زمست,
  { {0x39460ff9, 0x6b40000c, 0x673a016e, 0x00000000}},  //   rkos_, _sögu, _potj,
  { {0x394d02d5, 0xd5ba0ffa, 0x39460dec, 0x00000000}},  //   _eles_, оси_, skos_,
  { {0x394d00bb, 0xda650025, 0xfbb00044, 0x00000000}},  //   _fles_, _كافي, _ছবিত,
  { {0xb4e800e8, 0x2d800026, 0x00000000, 0x00000000}},  //   बले_, noie_,   ,
  { {0xd90d0167, 0x25a60b50, 0xdc11006b, 0x00000000}},  //   _دین_, _viol_, _məğl,
  { {0x25f6013d, 0x628f0036, 0x00000000, 0x00000000}},  //   _एमपी_, ęcon,   ,
  { {0x6b400073, 0x3b180ffb, 0x21290022, 0x00000000}},  //   _högs, _marq_, _pnah_,
  { {0x056602dc, 0x2d8006f0, 0x2d4700fa, 0x00000000}},  //   _ювен, joie_, _põem_,
  { {0x6d43001a, 0x59ce0061, 0x104b0088, 0x00000000}},  //   _înai, हीतर, іями_,
  { {0x2bb5007d, 0x27e60ffc, 0x00000000, 0x00000000}},  //   _अंबा, iron_,   ,
  { {0x3da7008b, 0x6b4001e5, 0xbf9b01d6, 0x00000000}},  //   драб, _lögs, fwêr,
  { {0x98a4000a, 0x00000000, 0x00000000, 0x00000000}},  //   _anmč_,   ,   ,
  { {0x1eab0025, 0x27e60ed5, 0x00000000, 0x00000000}},  // [1a90] _وادي_, jron_,   ,
  { {0x6ec0001c, 0x27e6005b, 0xa3e6006e, 0x00000000}},  //   वडणु, dron_, _बटन_,
  { {0x27e60211, 0x27e003df, 0x1a65025a, 0x00000000}},  //   eron_, áinn_, ریری_,
  { {0x26de0058, 0x27e60ffd, 0xab5b0095, 0x00000000}},  //   _adto_, fron_, _stüd,
  { {0x7d0d001a, 0x6d4f0026, 0x25be0045, 0x00000000}},  //   meas, _ilca, _attl_,
  { {0xf7730426, 0x7d0d0038, 0xae030061, 0x00000000}},  //   خاص_, leas, _लहान_,
  { {0x27e60211, 0xb9050044, 0x00000000, 0x00000000}},  //   aron_, _বউ_,   ,
  { {0x7d0d001a, 0x00000000, 0x00000000, 0x00000000}},  //   neas,   ,   ,
  { {0xa775007e, 0x99850010, 0xf8b20097, 0x00000000}},  //   _злач, _élő_, _תשמ_,
  { {0x7d0d0051, 0x6b400039, 0x7c20016e, 0x00000000}},  //   heas, _högr, _šmrk,
  { {0x7d0d00b0, 0x26c70059, 0x6d4f0095, 0x00000000}},  //   keas, mbno_, _olca,
  { {0x361a00b6, 0xdb070023, 0x00000000, 0x00000000}},  //   _מועד, _bijë,   ,
  { {0x2d800ffe, 0x7d0d0fff, 0xab640279, 0x00000000}},  //   voie_, deas, lmüş,
  { {0x6d4f0919, 0x6b40009f, 0x3eac0030, 0x00000000}},  //   _alca, _lögr, ødt_,
  { {0x23650039, 0x6b5205b7, 0x2d9602ea, 0x00000000}},  //   milj_, _jæge, ерас,
  { {0x27e60f91, 0x7d0d0657, 0x1de10164, 0x00000000}},  //   yron_, geas, _फिरत,
  { {0x6b520030, 0xed5700ed, 0xec7702ea, 0x00000000}},  // [1aa0] _læge, хот_, епт_,
  { {0x78ad1000, 0x27e6062a, 0x6d4f0efe, 0x00000000}},  //   žavl, vron_, _elca,
  { {0x7d0d0035, 0xeef7009b, 0x817500a1, 0x00000000}},  //   beas, _אמיר_, _سنیچ,
  { {0xcee900a1, 0x7d0d0e5f, 0x00000000, 0x00000000}},  //   _ٹرین_, ceas,   ,
  { {0x58831001, 0x27e60068, 0x00000000, 0x00000000}},  //   лыша, uron_,   ,
  { {0xf093007b, 0x7bc4010a, 0x27e6088d, 0x00000000}},  //   אנד_, mpiu, rron_,
  { {0x3872001a, 0xe1e701fa, 0x06cf0044, 0x00000000}},  //   _ţară_, _حس_, _রাশি,
  { {0x27e61002, 0x85ba00a1, 0x69dc1003, 0x00000000}},  //   pron_, _ہاؤس_, _ivre,
  { {0x8881007a, 0xb6030089, 0xd7ca0025, 0x00000000}},  //   _پیون, āšan, _رواه_,
  { {0x41e601e1, 0x973c016c, 0x778302dc, 0x00000000}},  //   німа, _mićk, _блуз,
  { {0xdb07000a, 0xf6290025, 0x00000000, 0x00000000}},  //   _dijè, _يسمى_,   ,
  { {0x613f0065, 0x29020039, 0xd046006b, 0x00000000}},  //   _pëlq, _ökad_, lakə,
  { {0x2bb50164, 0xe53b009b, 0x7d0d0035, 0x00000000}},  //   _अंधा, _מתאר, veas,
  { {0x7d0d00e0, 0x4ea7007c, 0x69dc1004, 0x00000000}},  //   weas, ерба, _ovre,
  { {0x7d0d001a, 0x3ea50c75, 0xdcfd0066, 0x00000000}},  //   teas, ält_, _jisħ,
  { {0x2bb50309, 0xdcfd0066, 0x3a230085, 0x00000000}},  //   _अंदा, _misħ, _rrjp_,
  { {0x69dc1005, 0xe7cf013d, 0x7d0d1006, 0x00000000}},  // [1ab0] _avre, _सौंप, reas,
  { {0x7d0d0e5f, 0x64c4013e, 0x290400d9, 0x00000000}},  //   seas, lčič, _abma_,
  { {0x7d0d00b0, 0xdcfd0089, 0x26c700ca, 0x00000000}},  //   peas, _eksā, vbno_,
  { {0x64c400ca, 0x20090093, 0x21391007, 0x00000000}},  //   nčič, _kpai_, njsh_,
  { {0x69dc1008, 0x399e00b9, 0xdb0f00fa, 0x00000000}},  //   _evre, _růst_, _lucé,
  { {0x3f830006, 0x00000000, 0x00000000, 0x00000000}},  //   noju_,   ,   ,
  { {0xc8f50265, 0xf7700647, 0xceb40097, 0x00000000}},  //   _извъ, حان_, ניק_,
  { {0xab640279, 0x69c501ac, 0x00000000, 0x00000000}},  //   rmüş, mphe,   ,
  { {0x290f1009, 0x3f830036, 0x00000000, 0x00000000}},  //   mega_, koju_,   ,
  { {0x290f100a, 0x628a068f, 0x3f83007f, 0x00000000}},  //   lega_, _byfo, joju_,
  { {0x2fc0000c, 0x628a0016, 0x63aa0026, 0x00000000}},  //   _stig_, _cyfo, _difn,
  { {0x291d0d16, 0x290f01d9, 0x628a018e, 0x00000000}},  //   ndwa_, nega_, _dyfo,
  { {0x307600e2, 0x61e8100b, 0xc8da009b, 0x00000000}},  //   тунс, ardl, וקרט,
  { {0xdf1501fb, 0x290f006c, 0x2d9900f6, 0x00000000}},  //   льсь, hega_, _ahse_,
  { {0x5ed40055, 0x290f01d9, 0x628a0016, 0x00000000}},  //   _তাদে, kega_, _gyfo,
  { {0x290f100c, 0x00000000, 0x00000000, 0x00000000}},  //   jega_,   ,   ,
  { {0xc4d2007b, 0x290f0004, 0x291d0009, 0x00000000}},  // [1ac0] יגן_, dega_, ddwa_,
  { {0x7bc4007f, 0x00000000, 0x00000000, 0x00000000}},  //   rpiu,   ,   ,
  { {0xe8fa008b, 0xab5b010f, 0xbea601fc, 0x00000000}},  //   дле_, _stüc, _јанк,
  { {0x290f0059, 0x81bc0089, 0xd7e6013a, 0x00000000}},  //   gega_, lvēc, віко,
  { {0xa41c0055, 0x00000000, 0x00000000, 0x00000000}},  //   _তথ্য_,   ,   ,
  { {0x6d93100d, 0xbcfb0224, 0x69d801ca, 0x00000000}},  //   nçan, _jmén, áves,
  { {0x69dc037e, 0x6f03011f, 0x290f00ca, 0x00000000}},  //   _uvre, _önce, bega_,
  { {0x290f0107, 0x38c80123, 0x973c016c, 0x00000000}},  //   cega_, _ساری_, _mići,
  { {0x98a3003b, 0x49170061, 0xa507003b, 0x00000000}},  //   _вите, _नसतो_, тења_,
  { {0x5fdc03d7, 0xdc9b0049, 0xdcfd002b, 0x00000000}},  //   _बिजल, ויפל, _tisħ,
  { {0xe737026b, 0x6d560022, 0x00000000, 0x00000000}},  //   _шеф_, khya,   ,
  { {0xbcfb00f4, 0x27e90e3b, 0x628a0861, 0x00000000}},  //   _amén, šane_, _vyfo,
  { {0x5064012b, 0x3f830d90, 0x442005d7, 0x00000000}},  //   атра, toju_, _éi_,
  { {0x44260435, 0x643b0049, 0x628a0750, 0x00000000}},  //   _iro_, _קעגנ, _tyfo,
  { {0x3f8309a4, 0x00000000, 0x00000000, 0x00000000}},  //   roju_,   ,   ,
  { {0x44260570, 0xf1a4007e, 0x3f83100e, 0x00000000}},  //   _kro_, _крын, soju_,
  { {0x290f100f, 0x9da802dc, 0xdb0f00e5, 0x00000000}},  // [1ad0] vega_, търа_, _ducî,
  { {0x69c500bb, 0x3b54007e, 0x4426005b, 0x00000000}},  //   tphe, акур, _mro_,
  { {0x290f1010, 0x7c26010f, 0x2bdf0316, 0x00000000}},  //   tega_, _erkr, _फटका,
  { {0x69c501ed, 0x00000000, 0x00000000, 0x00000000}},  //   rphe,   ,   ,
  { {0x290f0059, 0x44261011, 0x69c51012, 0x00000000}},  //   rega_, _nro_, sphe,
  { {0x290f0004, 0x77840099, 0x6d4d0ac2, 0x00000000}},  //   sega_, аліз, lkaa,
  { {0x44260ed6, 0x290f1013, 0x7f3c0049, 0x00000000}},  //   _aro_, pega_, ועגו,
  { {0xdb0d0845, 0x7d1d002b, 0x6d4d021e, 0x00000000}},  //   mpañ, _jass, nkaa,
  { {0x442600ca, 0x38600051, 0xb4650014, 0x00000000}},  //   _cro_, úirt_, دگاه,
  { {0x7d1d001f, 0x44261014, 0xdced0091, 0x00000000}},  //   _lass, _dro_, dnač,
  { {0x6d4d021e, 0x44261015, 0xfb160049, 0x00000000}},  //   kkaa, _ero_, אַכט_,
  { {0x44260016, 0x6d4d1016, 0x7d1d0b8a, 0x00000000}},  //   _fro_, jkaa, _nass,
  { {0x442601aa, 0x79890020, 0x656900b0, 0x00000000}},  //   _gro_, _mkew, mieh,
  { {0x06e50044, 0xd6e50044, 0x65690142, 0x00000000}},  //   প্রি, প্রয, lieh,
  { {0x7d1d1017, 0xfce607ca, 0x6d9300f4, 0x00000000}},  //   _bass, лово, rçan,
  { {0x7d1d1017, 0xbacd0044, 0x6d4d1018, 0x00000000}},  //   _cass, _লাগছ, gkaa,
  { {0x5f761019, 0x0c26007e, 0x7d1d01a2, 0x00000000}},  // [1ae0] _مادر, ыман, _dass,
  { {0x6d5601dd, 0x6d4d00b0, 0x656901a2, 0x00000000}},  //   shya, akaa, hieh,
  { {0x7d1d101a, 0x60d600ea, 0x1efb0097, 0x00000000}},  //   _fass, _keym, _אליע,
  { {0x7d1d0056, 0x6d930181, 0x3940000c, 0x00000000}},  //   _gass, nçal, ðis_,
  { {0x6f1e0047, 0x48e30605, 0x65690190, 0x00000000}},  //   _kapc, сочв, dieh,
  { {0x7c24101b, 0x77910167, 0xe737005e, 0x00000000}},  //   mvir, قیقا, леч_,
  { {0xdced0161, 0x7c2401e5, 0x7d1d01a3, 0x00000000}},  //   znač, lvir, _yass,
  { {0x4426101c, 0x60d6101d, 0x645b00bb, 0x00000000}},  //   _pro_, _neym, fzui,
  { {0x136a064b, 0x69de101e, 0x7c240211, 0x00000000}},  //   ешни_, lspe, nvir,
  { {0xa3e503d7, 0xbcfb00f4, 0x07a6012b, 0x00000000}},  //   _फिर_, _amél, _сазн,
  { {0xe1350057, 0x929400c0, 0xa2940245, 0x00000000}},  //   анны, ранц, рані,
  { {0xd257008b, 0x518701f9, 0x4426101f, 0x00000000}},  //   уць_, ѓуна, _tro_,
  { {0x44260059, 0x7d0400eb, 0x6446006c, 0x00000000}},  //   _uro_, dfis, äkid,
  { {0x2b8f001f, 0x6f1e0035, 0x7d1d0207, 0x00000000}},  //   rück_, _capc, _sass,
  { {0xd904026c, 0x7d0400f4, 0x6d4d00b0, 0x00000000}},  //   _ٹی_, ffis, tkaa,
  { {0x62980119, 0x69de05ad, 0x9d181020, 0x00000000}},  //   _izvo, dspe, лост_,
  { {0x81b60055, 0x7d1d0056, 0x69de002d, 0x00000000}},  // [1af0] _ছবি_, _vass, espe,
  { {0x7d1d001f, 0x6569001f, 0x6d4d021e, 0x00000000}},  //   _wass, zieh, skaa,
  { {0x7d1d01bc, 0x69de0479, 0xda1500ed, 0x00000000}},  //   _tass, gspe, рдењ,
  { {0xe0e70044, 0x973c016c, 0xdce40036, 0x00000000}},  //   গ্রহ_, _miću, knię,
  { {0x6d9309f7, 0x69de0035, 0xdb0d004a, 0x00000000}},  //   nçam, aspe, spañ,
  { {0x6d58010a, 0x69de0048, 0x99d7002c, 0x00000000}},  //   _įvai, bspe, _مترا,
  { {0xb8db0055, 0xf8c900f4, 0x764a005b, 0x00000000}},  //   _আজ_, _créé_, gyfy,
  { {0x79a401f9, 0x7bdf0ddb, 0x00000000, 0x00000000}},  //   _груе, osqu,   ,
  { {0x65690193, 0xdb0f008e, 0x7bdf01a2, 0x00000000}},  //   rieh, _lucí, nsqu,
  { {0xe7871021, 0x60d6013f, 0x7bdf0181, 0x00000000}},  //   _субо, _seym, isqu,
  { {0x7d04000c, 0x291f006c, 0x60d60173, 0x00000000}},  //   yfis, _kaua_, _peym,
  { {0xc4f80025, 0x216a030d, 0x63a10022, 0x00000000}},  //   _معها_, тими_, smln,
  { {0xb4c302fb, 0x6d93005d, 0x291f0020, 0x00000000}},  //   ्री_, rçal, _maua_,
  { {0x2d8b0224, 0x69de01d6, 0x291f1022, 0x00000000}},  //   _akce_, yspe, _laua_,
  { {0x7d040332, 0x69de098e, 0xbea61023, 0x00000000}},  //   tfis, xspe, равк,
  { {0x7c24010a, 0x27e00f3a, 0x69de02e7, 0x00000000}},  //   tvir, šini_, vspe,
  { {0xab66008b, 0x7d04009f, 0xdee60242, 0x00000000}},  // [1b00] авал, rfis, _копи,
  { {0x7c24037e, 0x69de0a74, 0x68fb1024, 0x00000000}},  //   rvir, tspe, _acud,
  { {0xbd8a0188, 0x399c002a, 0x7d0400ea, 0x00000000}},  //   _لندن_, híse_, pfis,
  { {0x06cf0044, 0x6d43001a, 0xc7c6004d, 0x00000000}},  //   _রাগি, _înap, аски,
  { {0x779402fd, 0x27e00051, 0xdb0d000c, 0x00000000}},  //   میرا, éin_, ppað,
  { {0x2d921025, 0x18670467, 0x00000000, 0x00000000}},  //   llye_, шачи_,   ,
  { {0xdb0e0065, 0x06d80044, 0x09e30867, 0x00000000}},  //   _libë, _সাদি, _морн,
  { {0x27e9001e, 0xa5340c24, 0x399c0051, 0x00000000}},  //   šana_, снич, físe_,
  { {0x362400a1, 0xc955007e, 0x00000000, 0x00000000}},  //   _گواہ, _утры,   ,
  { {0x316b0036, 0x394400f6, 0xb35402b8, 0x00000000}},  //   wicz_, _homs_, скош,
  { {0x7c29002b, 0xe81e006e, 0x44e80044, 0x00000000}},  //   _ġerm, पिका_, ক্ষক_,
  { {0x26dc0ecf, 0x7bc60091, 0x8c48005d, 0x00000000}},  //   lavo_, _otku, _kağı,
  { {0x39440193, 0xb4d202d2, 0x1b1d0044, 0x00000000}},  //   _moms_, वरी_, নাতে_,
  { {0x200501d5, 0x26dc0006, 0x6d9300d4, 0x00000000}},  //   ċli_, navo_, rçam,
  { {0x139b0104, 0x539b009b, 0xc1790006, 0x00000000}},  //   _שבוע, _שיוו, urės_,
  { {0x39440fdb, 0x5d781026, 0x00000000, 0x00000000}},  //   _noms_, айся_,   ,
  { {0x60dd0058, 0x8c48006b, 0x31690032, 0x00000000}},  // [1b10] masm, _nağı, _imaz_,
  { {0x7bdf00f4, 0x68fb0207, 0x26dc0059, 0x00000000}},  //   rsqu, _scud, javo_,
  { {0x26dc0006, 0x6f15008e, 0x49b80439, 0x00000000}},  //   davo_, mezc, لاند_,
  { {0xdb0e1027, 0x8c48005d, 0x3944009d, 0x00000000}},  //   _libè, _bağı, _coms_,
  { {0xdc3500bd, 0x394400ea, 0x27ff009d, 0x00000000}},  //   _האָט_, _doms_, _qqun_,
  { {0x8c48005d, 0x26dc0006, 0xf3fe0044, 0x00000000}},  //   _dağı, gavo_, ্টার_,
  { {0xcf580104, 0x6b520190, 0xb34500fa, 0x00000000}},  //   שבות_, _mægl, _loçã,
  { {0xb4c301f5, 0x74150025, 0x5e78009b, 0x00000000}},  //   ्रे_, موعا, יתון_,
  { {0x69c70182, 0x26dc0059, 0x212009e4, 0x00000000}},  //   _htje, bavo_, _raih_,
  { {0x26dc1028, 0x43740088, 0xda0e007d, 0x00000000}},  //   cavo_, жуют, _सहमत_,
  { {0xe6950054, 0x6f15008e, 0x00000000, 0x00000000}},  //   _الاد, dezc,   ,
  { {0xf65201f8, 0x67211029, 0x8c480279, 0x00000000}},  //   _מצב_, _halj, _yağı,
  { {0x672103b6, 0xc882006b, 0x5fb80061, 0x00000000}},  //   _kalj, _peşə_, _आढळल,
  { {0x20020770, 0x69c70243, 0x00000000, 0x00000000}},  //   rtki_, _otje,   ,
  { {0xed5a102a, 0x6721003b, 0x2002102b, 0x00000000}},  //   гов_, _malj, stki_,
  { {0x26dc102c, 0x20020022, 0xc212009b, 0x00000000}},  //   zavo_, ptki_, _זהה_,
  { {0x39440299, 0x0ab60025, 0x69c70023, 0x00000000}},  // [1b20] _roms_, محاد, _atje,
  { {0xef1a012b, 0x6721102d, 0x3944049b, 0x00000000}},  //   _смо_, _nalj, _soms_,
  { {0x26dc0006, 0x2601004a, 0x316901c3, 0x00000000}},  //   vavo_, jóo_, _ymaz_,
  { {0xb4c30316, 0xd9100167, 0x69c3102e, 0x00000000}},  //   ्रो_, بیر_, ínea,
  { {0x67210107, 0xdb0e00f4, 0x2be2013d, 0x00000000}},  //   _balj, _libé, _पिटा,
  { {0xa09b061e, 0x06d80055, 0x7d160c87, 0x00000000}},  //   ניסט, _সাহি, leys,
  { {0x26dc102f, 0x6d46002d, 0x67210340, 0x00000000}},  //   ravo_, _koka, _dalj,
  { {0x6d460234, 0x7d161030, 0x26dc0059, 0x00000000}},  //   _joka, neys, savo_,
  { {0x6d460006, 0x67210065, 0x6843007c, 0x00000000}},  //   _moka, _falj, _ента,
  { {0x69c1028c, 0x8c1b009b, 0x60c40173, 0x00000000}},  //   _élec, נויי, _afim,
  { {0x60dd002d, 0x6d460007, 0x7179013b, 0x00000000}},  //   tasm, _ooka, ибор_,
  { {0x6d461031, 0x67211032, 0x27e00091, 0x00000000}},  //   _noka, _zalj, šinu_,
  { {0xd46705b5, 0xc05803e8, 0x60dd01a3, 0x00000000}},  //   _лице_, бір_, rasm,
  { {0xc0580245, 0x60c40146, 0x2bdb013d, 0x00000000}},  //   сію_, _efim, मीफा,
  { {0x6f150211, 0x6d9300d4, 0x00000000, 0x00000000}},  //   rezc, lçai,   ,
  { {0x22ae005f, 0x2b940210, 0x00000000, 0x00000000}},  //   mək_, bäck_,   ,
  { {0x69c71033, 0x6d93028c, 0x6d460213, 0x00000000}},  // [1b30] _stje, nçai, _doka,
  { {0x8aa70423, 0x69c7012d, 0x3f8a00d0, 0x00000000}},  //   бред, _ptje, cobu_,
  { {0x2bb501f5, 0x22ae013f, 0x2b5800e5, 0x00000000}},  //   _अंका, nək_, _dlrc_,
  { {0x6721037e, 0x6dbc0091, 0x75220027, 0x00000000}},  //   _salj, _očaj, _naoz,
  { {0x672108b2, 0x387f0066, 0xf74501ab, 0x00000000}},  //   _palj, _qxur_, жело,
  { {0x27e91034, 0x7bcd1035, 0xdb07004a, 0x00000000}},  //   šano_, mpau, _fijá,
  { {0x672101cd, 0x6723037e, 0x69c70182, 0x00000000}},  //   _valj, rdnj, _utje,
  { {0x22ae006b, 0xdb0e0923, 0x6b52000c, 0x00000000}},  //   dək_, _ribé, _nægj,
  { {0xe3b61036, 0x6721002b, 0x27e0002a, 0x00000000}},  //   обы_, _talj, áint_,
  { {0x798b005b, 0x98ad0142, 0xd6d800e2, 0x00000000}},  //   logw, _hneď_, _гтц_,
  { {0xe2990200, 0x442700d3, 0xd064006b, 0x00000000}},  //   ран_, _گراف, ərəs,
  { {0xe43504e8, 0x75220288, 0x00000000, 0x00000000}},  //   _وفاد, _gaoz,   ,
  { {0x6d461037, 0x2bb501f5, 0x656b0066, 0x00000000}},  //   _roka, _अंगा, _imgh,
  { {0x6d461038, 0xbf9b02d5, 0x83fd0010, 0x00000000}},  //   _soka, stên, rződ,
  { {0x22ae005f, 0x7d16021e, 0x3f8a0161, 0x00000000}},  //   cək_, teys, robu_,
  { {0x2fc90009, 0x2b9401a2, 0x3f8a0941, 0x00000000}},  //   _ftag_, päck_, sobu_,
  { {0xed5700ed, 0x7bcd011c, 0x7d161039, 0x00000000}},  // [1b40] цот_, gpau, reys,
  { {0x68e9014a, 0x6d460036, 0x290d0035, 0x00000000}},  //   _aded, _woka, _abea_,
  { {0x32050038, 0x6d46103a, 0xc8ca01af, 0x00000000}},  //   ntly_, _toka, لوان_,
  { {0xc27a0049, 0x25ef0061, 0x798b103b, 0x00000000}},  //   ברעי, ींनी_, gogw,
  { {0x68e9103c, 0x88160558, 0x57a600e2, 0x00000000}},  //   _dded, تباط, ошка,
  { {0x05ea103d, 0x68e90009, 0xe3a70355, 0x00000000}},  //   афии_, _eded, _زر_,
  { {0xd6d9103e, 0xd5b70057, 0xda0e03d7, 0x00000000}},  //   сті_, осы_, _सहित_,
  { {0x7c2904eb, 0x15d9009e, 0x00000000, 0x00000000}},  //   _šeri, حدوں_,   ,
  { {0x8d5b0049, 0xe0df01aa, 0x1b1d0044, 0x00000000}},  //   יכקי, chòy_, নারে_,
  { {0x46a6008b, 0xc7b90010, 0xd7640167, 0x00000000}},  //   _дазв, _erős_, _عنای,
  { {0x2fc9103f, 0x2b94010f, 0x3abb00a0, 0x00000000}},  //   _stag_, räch_, ימינ,
  { {0x81bc001e, 0x22ae005f, 0x6d9300f6, 0x00000000}},  //   lvēk, rək_, lçav,
  { {0x32050133, 0x22ae006b, 0x00000000, 0x00000000}},  //   atly_, sək_,   ,
  { {0xdefb008b, 0x6d930a06, 0x7c3b00f6, 0x00000000}},  //   шым_, nçav, _àuri,
  { {0xd2500054, 0x320500ab, 0x2cb0006b, 0x00000000}},  //   _سنة_, ctly_, əndə_,
  { {0x8d7700a1, 0x2fc90009, 0x5cb9007e, 0x00000000}},  //   زازا, _ttag_, слаў_,
  { {0x4c94007c, 0x0cab0d15, 0x00000000, 0x00000000}},  // [1b50] дитс, ртви_,   ,
  { {0x69c3004a, 0x88d70044, 0x00000000, 0x00000000}},  //   íneo, _হাইক,   ,
  { {0x39150242, 0x7bcd0006, 0x0a680751, 0x00000000}},  //   змер, spau, орци_,
  { {0x7bcd0052, 0x9b450014, 0x628e00b4, 0x00000000}},  //   ppau, _کنسو, żbow,
  { {0xdd3a009b, 0x798b1040, 0x00000000, 0x00000000}},  //   _הערכ, rogw,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd90f026c, 0x80dc0044, 0xb9010044, 0x00000000}},  //   _لیا_, _ভাস্, _দা_,
  { {0xea000011, 0xab5b01a2, 0x00000000, 0x00000000}},  //   _hiếp_, _stüh,   ,
  { {0x657e00f4, 0xb7d503ec, 0xf3f10025, 0x00000000}},  //   épha, _رقاب, رأة_,
  { {0xdce4014a, 0x00000000, 0x00000000, 0x00000000}},  //   kniğ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f420802, 0x320500ab, 0x00000000, 0x00000000}},  //   mské_, rtly_,   ,
  { {0x9f4201ca, 0x320500ab, 0x232900aa, 0x00000000}},  //   lské_, stly_, _голи_,
  { {0x443f002b, 0x13a700a1, 0x00000000, 0x00000000}},  //   mxu_, _بنتی_,   ,
  { {0x9f42004f, 0x6da60bbd, 0xd24e023c, 0x00000000}},  //   nské_, зива, _منو_,
  { {0xf8b90011, 0x657b1041, 0x442f0145, 0x00000000}},  //   _ngũ_, nnuh, _krg_,
  { {0x27e907a0, 0x442f00d9, 0x81a5023c, 0x00000000}},  // [1b60] šanj_, _jrg_, _تحول,
  { {0x8b26008b, 0x7d0f0061, 0xed160036, 0x00000000}},  //   ядзе, _ebcs, _łódź_,
  { {0x2d9e00d4, 0x69da0025, 0x442f0d96, 0x00000000}},  //   ïtes_, صباح_, _lrg_,
  { {0x442f1042, 0xa6d80044, 0x9f4201ca, 0x00000000}},  //   _org_, _সাইট, dské_,
  { {0x181800a2, 0x3eba012d, 0x00000000, 0x00000000}},  //   تراک_, _kgpt_,   ,
  { {0xbb4a0054, 0x7bcb056b, 0xf8af00a1, 0x00000000}},  //   _الآن_, ígue, اکِ_,
  { {0x442f00f8, 0x6b52000c, 0x00000000, 0x00000000}},  //   _arg_, _nægi,   ,
  { {0x6d440169, 0xceb300b3, 0xd90d0167, 0x00000000}},  //   njia, עיה_, _نیم_,
  { {0x9f590073, 0x00000000, 0x00000000, 0x00000000}},  //   ltså_,   ,   ,
  { {0x325400ed, 0x442f1043, 0xdb1d0181, 0x00000000}},  //   двор, _drg_, _ausê,
  { {0x442f015c, 0x27e61044, 0x98bf0066, 0x00000000}},  //   _erg_, lson_, _qmuħ_,
  { {0x463b0049, 0x443f0009, 0x55bb009b, 0x00000000}},  //   _לעבע, bxu_, _המאו,
  { {0x26de008d, 0x24aa0055, 0xdb050051, 0x00000000}},  //   _keto_, _গ্রহ, smhé,
  { {0x27e6028c, 0xd370007a, 0xbf9b009d, 0x00000000}},  //   ison_, _جهت_, ptêm,
  { {0x80dc0044, 0x26de0d94, 0x2cb90022, 0x00000000}},  //   _ভার্, _meto_, _pgsd_,
  { {0x5d99008b, 0x26de086e, 0xebd9005e, 0x00000000}},  //   ікаў_, _leto_, ждаш_,
  { {0x27e6016c, 0x61fa1045, 0x7bc0009d, 0x00000000}},  // [1b70] json_, lutl, _émul,
  { {0x8aa70072, 0x26de0181, 0x6d5f1046, 0x00000000}},  //   пред, _neto_, shqa,
  { {0x98bf001a, 0x61fa1047, 0x7c290066, 0x00000000}},  //   _nouă_, nutl, _ġeru,
  { {0x1a6801ef, 0x0dba00a1, 0x27e61048, 0x00000000}},  //   سیقی_, _گئیں_, fson_,
  { {0xea00001d, 0x26de1049, 0x7d0d0093, 0x00000000}},  //   _tiếp_, _beto_, mfas,
  { {0x7c2d021a, 0x9f420161, 0x49bb03ec, 0x00000000}},  //   mvar, tské_, _هارد_,
  { {0x442f063e, 0x68e201ee, 0xe708023c, 0x00000000}},  //   _srg_, baod, ستون_,
  { {0x9f42004f, 0x98bf000d, 0x53c90175, 0x00000000}},  //   rské_, _două_, огим_,
  { {0xb4bd001c, 0x7c2d104a, 0xbcfb0010, 0x00000000}},  //   _आली_, nvar, _elég,
  { {0x04ff0055, 0x9f4201dc, 0xdb1d0039, 0x00000000}},  //   ্যের_, pské_, _utsä,
  { {0x6d5d005d, 0x7d0d01c3, 0x7c2d104b, 0x00000000}},  //   _olsa, kfas, hvar,
  { {0x442f0059, 0x65600051, 0x5455104c, 0x00000000}},  //   _trg_, chmh, _овет,
  { {0x7d0d0190, 0x442f0085, 0x63a30022, 0x00000000}},  //   dfas, _urg_, _thnn,
  { {0xdfcf0054, 0x6d5d00f4, 0x442d0023, 0x00000000}},  //   شيف_, _alsa, mve_,
  { {0x7c2d0006, 0x7d0d104d, 0x00000000, 0x00000000}},  //   evar, ffas,   ,
  { {0x75290047, 0x78bb000b, 0x27e60ca4, 0x00000000}},  //   ndez, _nguv, yson_,
  { {0xdced0521, 0x442d0023, 0x6d440022, 0x00000000}},  // [1b80] znać, nve_, rjia,
  { {0x6d5d0232, 0xda660025, 0xeb9f0056, 0x00000000}},  //   _elsa, واضي, _spør_,
  { {0x0f5701f8, 0x27e60ca4, 0x26de008e, 0x00000000}},  //   _חיים_, wson_, _reto_,
  { {0x442d0119, 0x98a00059, 0x26de104e, 0x00000000}},  //   kve_, žič_, _seto_,
  { {0xa3f80055, 0x442d104f, 0x75290026, 0x00000000}},  //   _অন্য_, jve_, ddez,
  { {0x442d07fd, 0x6f1c005b, 0x6446006c, 0x00000000}},  //   dve_, nerc, äkim,
  { {0xe1e7009c, 0x442d00b5, 0x26de0052, 0x00000000}},  //   _جس_, eve_, _veto_,
  { {0x27e60c0d, 0x6f1c0161, 0x6d9300f6, 0x00000000}},  //   pson_, herc, lçar,
  { {0xea000011, 0x26de1050, 0x6f1c0232, 0x00000000}},  //   _khắp_, _teto_, kerc,
  { {0x6d930a0a, 0x6f1c00ca, 0x68e0014a, 0x00000000}},  //   nçar, jerc, _hemd,
  { {0x6f1c1051, 0x442d0207, 0x7d0d014a, 0x00000000}},  //   derc, ave_, yfas,
  { {0x39461052, 0x67280e61, 0x2fc0054c, 0x00000000}},  //   njos_, _hadj, _buig_,
  { {0x442d1053, 0x38660b41, 0x6f1c005b, 0x00000000}},  //   cve_, nzor_, ferc,
  { {0x6f1c1054, 0x61fa067c, 0x7c2d013f, 0x00000000}},  //   gerc, putl, vvar,
  { {0x67280065, 0x7d0d0066, 0x6e94007c, 0x00000000}},  //   _madj, tfas, виру,
  { {0xbcfb1055, 0x67280059, 0x2fc000d4, 0x00000000}},  //   _amér, _ladj, _fuig_,
  { {0x6f1c05d2, 0x7d0d001f, 0x25a60048, 0x00000000}},  // [1b90] berc, rfas, _mhol_,
  { {0x7c2d06a1, 0x6f1c1056, 0x6728037e, 0x00000000}},  //   rvar, cerc, _nadj,
  { {0x442d1057, 0xfe350049, 0x00000000, 0x00000000}},  //   zve_, _װאָך_,   ,
  { {0xb4bd001c, 0x8aa40242, 0x673a1058, 0x00000000}},  //   _आले_, труд, _antj,
  { {0xdd91026c, 0xe739008b, 0x27e91059, 0x00000000}},  //   _لوگ_, зел_, éan_,
  { {0x25a60047, 0x9f59009d, 0x442d00f8, 0x00000000}},  //   _ahol_, fusé_, vve_,
  { {0xf77001fa, 0xe61100a2, 0x69dc0016, 0x00000000}},  //   جان_, اشت_, _gwre,
  { {0x442d03f7, 0x94250893, 0x6f1c0428, 0x00000000}},  //   tve_, емие, zerc,
  { {0x442d0c60, 0x75290010, 0x291d105a, 0x00000000}},  //   uve_, rdez, mewa_,
  { {0x442d0004, 0x291d000b, 0x1b1d0055, 0x00000000}},  //   rve_, lewa_, নাকে_,
  { {0x63b8037e, 0x442d105b, 0x6f1c014a, 0x00000000}},  //   _divn, sve_, verc,
  { {0x6f1c0061, 0x2fc00129, 0x6728016c, 0x00000000}},  //   werc, _puig_, _zadj,
  { {0x394d0343, 0xdbd701c2, 0x6f1c0781, 0x00000000}},  //   _moes_, _jäät, terc,
  { {0x7ae504cb, 0x291d00e7, 0xdb1d009d, 0x00000000}},  //   jaht, hewa_, _fusé,
  { {0x291d0020, 0x42520355, 0x6298007f, 0x00000000}},  //   kewa_, _منور, _gyvo,
  { {0x6f1c059a, 0xb4bd0061, 0x2fc00058, 0x00000000}},  //   serc, _आलो_, _tuig_,
  { {0x6f1c04cb, 0xac86105c, 0xa802006b, 0x00000000}},  // [1ba0] perc, хгал, _çıxd,
  { {0xe625001d, 0x395f06ed, 0x6b520030, 0x00000000}},  //   _đông_, _alus_, _nægt,
  { {0x672801f3, 0xfce6012b, 0x68e0023a, 0x00000000}},  //   _radj, _поно, _pemd,
  { {0x8c4607e1, 0x707700a6, 0x67280059, 0x00000000}},  //   _земе, _آمیز_, _sadj,
  { {0x394d0975, 0x2d800036, 0xea000082, 0x00000000}},  //   _does_, mnie_, _thắp_,
  { {0x2d800046, 0x7c260213, 0x25ad0066, 0x00000000}},  //   lnie_, _iskr, emel_,
  { {0x56930407, 0xfaa3091b, 0x395f01d5, 0x00000000}},  //   лашт, _баро, _flus_,
  { {0xa5340216, 0x394d00ab, 0x2d800aba, 0x00000000}},  //   тнич, _goes_, nnie_,
  { {0x63b80161, 0x6728105d, 0x6b520146, 0x00000000}},  //   _pivn, _tadj, _fægt,
  { {0x2d800007, 0x3f85016c, 0xd62a00ed, 0x00000000}},  //   hnie_, čluk_, _нозе_,
  { {0x7d060073, 0x3f9100b9, 0x2d920173, 0x00000000}},  //   _ocks, vozu_, koye_,
  { {0xea00001d, 0x25d9007a, 0x2d800036, 0x00000000}},  //   _nhập_, _آهنگ_, jnie_,
  { {0x2d800046, 0xe5a3004d, 0x00000000, 0x00000000}},  //   dnie_, _сици,   ,
  { {0x2d800046, 0x291d105e, 0x21290022, 0x00000000}},  //   enie_, zewa_, _waah_,
  { {0xbe88007c, 0x7c26105f, 0x3da70745, 0x00000000}},  //   есте_, _askr, ераб,
  { {0x2d801060, 0x44260058, 0x2d920dfc, 0x00000000}},  //   gnie_, _kso_, goye_,
  { {0x7ae501c2, 0x4426012d, 0xab64014a, 0x00000000}},  // [1bb0] taht, _jso_, klüğ,
  { {0x6d5a008d, 0x4426001c, 0x2d800832, 0x00000000}},  //   ëtar, _mso_, anie_,
  { {0x395f032c, 0xf7710167, 0x2d920061, 0x00000000}},  //   _plus_, یات_, boye_,
  { {0x4426022b, 0xdbd7021e, 0x2d800036, 0x00000000}},  //   _oso_, _päät, cnie_,
  { {0x7ae5021e, 0xbcfb0211, 0x44261061, 0x00000000}},  //   paht, _eléc, _nso_,
  { {0x394d0343, 0x6d4f014a, 0x291d01a3, 0x00000000}},  //   _woes_, _hoca, sewa_,
  { {0x291d000b, 0x4426011c, 0x6d4f014a, 0x00000000}},  //   pewa_, _aso_, _koca,
  { {0x44261062, 0x1da7013d, 0x6d4f00d9, 0x00000000}},  //   _bso_, _कीमत, _joca,
  { {0x6d4f01ee, 0x42d5007e, 0x44261063, 0x00000000}},  //   _moca, кіну, _cso_,
  { {0x2d800ef2, 0x6b52000c, 0x60cd0082, 0x00000000}},  //   znie_, _hægr, _afam,
  { {0x44260b3c, 0x36d4007c, 0x31600c8f, 0x00000000}},  //   _eso_, _сохр, _pliz_,
  { {0x27e9001e, 0x29020039, 0x6d4f016e, 0x00000000}},  //   šanu_, _ökat_, _noca,
  { {0xd24e0167, 0x44260087, 0x2d920068, 0x00000000}},  //   منی_, _gso_, voye_,
  { {0x6b52000c, 0x2d800652, 0x636400f6, 0x00000000}},  //   _lægr, wnie_, _cònd,
  { {0x2d800046, 0x7c290107, 0xdee3007c, 0x00000000}},  //   tnie_, _šerp, роси,
  { {0xc5f20049, 0xab64014a, 0x2d8000d9, 0x00000000}},  //   ידל_, zlüğ, unie_,
  { {0x2d800036, 0x81bc01c5, 0x00000000, 0x00000000}},  // [1bc0] rnie_, svēt,   ,
  { {0x2d800036, 0xab5b010f, 0x998d0936, 0x00000000}},  //   snie_, _stür, _češ_,
  { {0x6d4f002a, 0x6dbc0cd6, 0xea000011, 0x00000000}},  //   _foca, _včas, _thập_,
  { {0x6d4f1064, 0x00000000, 0x00000000, 0x00000000}},  //   _goca,   ,   ,
  { {0xf74601b3, 0x7c260166, 0x4c83005e, 0x00000000}},  //   кедо, _uskr, _вляв,
  { {0x7d04011f, 0x7bd61065, 0x6d4f004a, 0x00000000}},  //   lgis, mpyu, _zoca,
  { {0x27ed00b1, 0xab64014a, 0x1602013d, 0x00000000}},  //   _even_, rlüğ, रंधर_,
  { {0x6d4f1066, 0x4426007f, 0x00000000, 0x00000000}},  //   _xoca, _pso_,   ,
  { {0x7c24010f, 0xd3a601ee, 0x00000000, 0x00000000}},  //   nwir, кроп,   ,
  { {0x44260059, 0x80dc0044, 0x60cd0026, 0x00000000}},  //   _vso_, _ভাগ্, _sfam,
  { {0xd5af007c, 0x81bc0089, 0xa266005e, 0x00000000}},  //   _вс_, evēr, тъпл,
  { {0x7c240a37, 0x9257007c, 0x44261067, 0x00000000}},  //   kwir, тают_, _tso_,
  { {0x4426049a, 0x6d4f06c2, 0x250b00a1, 0x00000000}},  //   _uso_, _roca, _آرمی_,
  { {0x6d4f0035, 0x7c24004a, 0xc7b40049, 0x00000000}},  //   _soca, dwir, רבֿ_,
  { {0x6d4f1068, 0x798200ab, 0xd3781069, 0x00000000}},  //   _poca, know, mić_,
  { {0xd3781069, 0x7d040a8e, 0x79820046, 0x00000000}},  //   lić_, ggis, jnow,
  { {0x7c24106a, 0xd0110025, 0x6c54030d, 0x00000000}},  // [1bd0] gwir, _الخ_, акту,
  { {0xd378106b, 0x31790036, 0x765800b0, 0x00000000}},  //   nić_, lisz_, kyvy,
  { {0xdb05002a, 0x27ed0039, 0x6d4f00d6, 0x00000000}},  //   gmhá, _sven_, _toca,
  { {0x7c240061, 0xd3780107, 0x6d4f016c, 0x00000000}},  //   bwir, hić_, _uoca,
  { {0x9f4201ca, 0xd3780091, 0xbcfb0051, 0x00000000}},  //   lská_, kić_, _gléa,
  { {0xd3780091, 0x628a00ab, 0x00000000, 0x00000000}},  //   jić_, _oxfo,   ,
  { {0x2d550018, 0x9f4206b8, 0xd3780091, 0x00000000}},  //   _fået_, nská_, dić_,
  { {0x2d550030, 0xdb1d0428, 0xceb400a0, 0x00000000}},  //   _gået_, _musí, סיק_,
  { {0xd378106c, 0xa898106d, 0xe7050014, 0x00000000}},  //   fić_, _акту_, _مسای,
  { {0x65620007, 0x29020039, 0xd3780091, 0x00000000}},  //   _eloh, _ökar_, gić_,
  { {0x3f830091, 0x2fd20007, 0x752b0032, 0x00000000}},  //   dnju_, _styg_, _tagz,
  { {0x7412007a, 0xf5300025, 0xd4350070, 0x00000000}},  //   جویا, _وإن_, _معتب,
  { {0xd378106e, 0x628a106f, 0x44240016, 0x00000000}},  //   bić_, _exfo, cwm_,
  { {0xd3781070, 0x2d991071, 0x00000000, 0x00000000}},  //   cić_, _akse_,   ,
  { {0x31791072, 0x79820036, 0x81bd0089, 0x00000000}},  //   bisz_, ynow, rvēr,
  { {0x7c240503, 0xbcfb0051, 0x81bd0089, 0x00000000}},  //   twir, _pléa, svēr,
  { {0x09cc001c, 0x3f830fcd, 0xeafa0025, 0x00000000}},  // [1be0] ाऱ्य, bnju_, فرات_,
  { {0xfbcd0055, 0x7c241073, 0x3f83016c, 0x00000000}},  //   _লিখত, rwir, cnju_,
  { {0x79820061, 0xe8fa1074, 0x7c241075, 0x00000000}},  //   tnow, еле_, swir,
  { {0xd378106e, 0x786a0010, 0x88e6007c, 0x00000000}},  //   zić_, _növé, ужде,
  { {0xe3c80011, 0x79820036, 0x00000000, 0x00000000}},  //   _mực_, rnow,   ,
  { {0xe3c8001d, 0xa5f81076, 0xdb1c008d, 0x00000000}},  //   _lực_, веку_, _mirë,
  { {0x6b63103e, 0xd37801cd, 0xb90a0055, 0x00000000}},  //   _укра, vić_, _মা_,
  { {0x7bc61077, 0x1db4001c, 0x3f83037e, 0x00000000}},  //   _kuku, ंगित, znju_,
  { {0xa3df001c, 0xd3780166, 0xe644005d, 0x00000000}},  //   धील_, tić_, ılığ,
  { {0x7bc60061, 0x4424018e, 0x06b90044, 0x00000000}},  //   _muku, rwm_, ঁড়ি,
  { {0x7bc61078, 0xd3780363, 0x362400a1, 0x00000000}},  //   _luku, rić_, _خواہ,
  { {0xe3c8001d, 0xd056005f, 0x2906022b, 0x00000000}},  //   _cực_, _heyə, ngoa_,
  { {0xd3781070, 0xf5930054, 0x69c100f4, 0x00000000}},  //   pić_, _النج, _élev,
  { {0x31790036, 0x9f420161, 0x00000000, 0x00000000}},  //   sisz_, tská_,   ,
  { {0x31790046, 0x3f830091, 0xddab1079, 0x00000000}},  //   pisz_, rnju_, етал_,
  { {0x7bc6008d, 0x3f830107, 0x9f420161, 0x00000000}},  //   _buku, snju_, rská_,
  { {0x7bc6107a, 0x3f830243, 0xbb750545, 0x00000000}},  // [1bf0] _cuku, pnju_, агај,
  { {0x7bc6023a, 0x9f420802, 0x332e0066, 0x00000000}},  //   _duku, pská_, _jafx_,
  { {0x0b88003b, 0x00000000, 0x00000000, 0x00000000}},  //   усти_,   ,   ,
  { {0x2d99006c, 0xf1c90082, 0xdc340161, 0x00000000}},  //   _ukse_, _hạc_, _zúča,
  { {0x7bc60061, 0x00000000, 0x00000000, 0x00000000}},  //   _guku,   ,   ,
  { {0x2906002d, 0x6d4d006c, 0x332e002b, 0x00000000}},  //   agoa_, ljaa, _nafx_,
  { {0x2002107b, 0xd056005f, 0x7bc6010f, 0x00000000}},  //   zuki_, _deyə, _zuku,
  { {0xf1c9001d, 0x6d4d107c, 0x69d5107d, 0x00000000}},  //   _lạc_, njaa, _itze,
  { {0x68eb011c, 0xe3c80011, 0x799b107e, 0x00000000}},  //   magd, _rực_, _ikuw,
  { {0x69c7000b, 0x68eb05ad, 0x466b0088, 0x00000000}},  //   _kuje, lagd, _прем_,
  { {0x216a107f, 0x672301d9, 0xdb1c01aa, 0x00000000}},  //   вини_, menj, _dirè,
  { {0x69c70219, 0x672301d9, 0x7c3b01d5, 0x00000000}},  //   _muje, lenj, _ġurn,
  { {0xe3c8001d, 0x660301d5, 0xf1c90011, 0x00000000}},  //   _vực_, lunk, _bạc_,
  { {0x7bc60518, 0x20021080, 0x67231081, 0x00000000}},  //   _ruku, ruki_, nenj,
  { {0x13da08b7, 0x7bc61082, 0x200204cb, 0x00000000}},  //   _দিয়, _suku, suki_,
  { {0x7bc60169, 0x64460039, 0x67231083, 0x00000000}},  //   _puku, åkig, henj,

  { {0x69d5022b, 0x672301d6, 0x68eb011c, 0x00000000}},  // [1c00] _atze, kenj, dagd,
  { {0x672300ee, 0xaaba0167, 0x65691084, 0x00000000}},  //   jenj, ندار_, hheh,
  { {0x672300ee, 0x6da60265, 0x66030006, 0x00000000}},  //   denj, _вина, junk,
  { {0x7bc61085, 0xe3c8001d, 0xd91002fd, 0x00000000}},  //   _tuku, _lựa_, ثیر_,
  { {0x386008cc, 0x65690020, 0x7e97025a, 0x00000000}},  //   áir_, dheh, _منیر_,
  { {0x66030142, 0x67231086, 0x7ae71087, 0x00000000}},  //   funk, genj, _gejt,
  { {0x25fd0164, 0x7aaa0061, 0x66030010, 0x00000000}},  //   रंगी_, _करिअ, gunk,
  { {0x3f980224, 0xa6e90011, 0x74140647, 0x00000000}},  //   horu_, _ngươ, موبا,
  { {0xdb07008e, 0x658800b9, 0x672301a2, 0x00000000}},  //   _gijó, běhn, benj,
  { {0x4aaa001c, 0x67231088, 0x60c41089, 0x00000000}},  //   _कराव, cenj, _agim,
  { {0x69c10047, 0x69c0016a, 0xe3c80011, 0x00000000}},  //   _élet, _kime, _dựa_,
  { {0x69c00f06, 0xf1c90011, 0x2c5e0089, 0x00000000}},  //   _jime, _sạc_, _kādā_,
  { {0xb4c201f5, 0x938a005e, 0x69c00d36, 0x00000000}},  //   ंशी_, _иска_, _mime,
  { {0x69c0000b, 0x09d70055, 0x2bb20061, 0x00000000}},  //   _lime, _হিসা, _जळगा,
  { {0xdef8008b, 0x7ae70010, 0xa1870783, 0x00000000}},  //   шыя_, _rejt, _выпл,
  { {0x6723037e, 0x69c70b94, 0x7ae70010, 0x00000000}},  //   zenj, _ruje, _sejt,
  { {0x69c7028c, 0x6d4d0149, 0x2ac7003b, 0x00000000}},  // [1c10] _suje, rjaa, аљев,
  { {0x69c000f4, 0x6d4d108a, 0x69c700d4, 0x00000000}},  //   _aime, sjaa, _puje,
  { {0x6723002b, 0x69c0065a, 0x7d160009, 0x00000000}},  //   venj, _bime, bfys,
  { {0x69c0108b, 0xdb0f004a, 0x00000000, 0x00000000}},  //   _cime, _pucó,   ,
  { {0x69c0108c, 0x67230a0f, 0x68eb011c, 0x00000000}},  //   _dime, tenj, ragd,
  { {0x6603108d, 0x69c7108e, 0x21cc013e, 0x00000000}},  //   tunk, _tuje, _něho_,
  { {0x6723016c, 0x69c001aa, 0x6569108f, 0x00000000}},  //   renj, _fime, theh,
  { {0x6723037e, 0x99850054, 0x66031090, 0x00000000}},  //   senj, _الرو, runk,
  { {0x681a001e, 0x66031091, 0x67231092, 0x00000000}},  //   gādā, sunk, penj,
  { {0x69c0000b, 0x656900e7, 0xb4e6013d, 0x00000000}},  //   _zime, sheh, _बड़ी_,
  { {0xb6350151, 0xcb1200b3, 0x26c501d6, 0x00000000}},  //   _دفاع, הלי_, _iglo_,
  { {0xd05d006b, 0x261c01f5, 0x3f980036, 0x00000000}},  //   lasə, _महती_, woru_,
  { {0x3f981093, 0x343804e1, 0x68e91094, 0x00000000}},  //   toru_, _پسند_, _meed,
  { {0x68e9006c, 0x98a00091, 0x50d8007d, 0x00000000}},  //   _leed, žić_, _भ्रष,
  { {0xc879001a, 0xbcfb009d, 0x25fd013d, 0x00000000}},  //   _deşi_, _elém, रंटी_,
  { {0x68e90038, 0xbf9b0181, 0x3f980b7d, 0x00000000}},  //   _need, quên, soru_,
  { {0x3f98014a, 0x7ff61095, 0x7d161096, 0x00000000}},  // [1c20] poru_, _اسبا, rfys,
  { {0x69c01097, 0x290d001a, 0x2b4300f6, 0x00000000}},  //   _sime, _acea_, _cnjc_,
  { {0xcf57012e, 0x69c00ac2, 0x627a0049, 0x00000000}},  //   _הבית_, _pime, ְנננ,
  { {0xb4e603d7, 0xea000011, 0x290d00e5, 0x00000000}},  //   _बजे_, _nhấp_, _ccea_,
  { {0x69c00020, 0x68e90133, 0x00000000, 0x00000000}},  //   _vime, _deed,   ,
  { {0xaa46005e, 0x98a40006, 0x681a0089, 0x00000000}},  //   _легл, _namą_, vādā,
  { {0x68e91098, 0x6b630a78, 0x1b7b0049, 0x00000000}},  //   _feed, _экра, _עטלע,
  { {0xea000011, 0x69c01099, 0x2c5e0089, 0x00000000}},  //   _chấp_, _uime, _tādā_,
  { {0x78660057, 0x7c29012d, 0x00000000, 0x00000000}},  //   _указ, _šerz,   ,
  { {0x681a001e, 0x68e900d9, 0x00000000, 0x00000000}},  //   rādā, _zeed,   ,
  { {0x6b9b007b, 0xcb9b00b3, 0x00000000, 0x00000000}},  //   רשיד, רסיט,   ,
  { {0xe5720084, 0x21670f13, 0x00000000, 0x00000000}},  //   _عطا_, стог,   ,
  { {0xf8ba00e8, 0x00000000, 0x00000000, 0x00000000}},  //   ेशिय,   ,   ,
  { {0x25ef0061, 0x995c013e, 0x00000000, 0x00000000}},  //   ींची_, jíž_,   ,
  { {0xf1c9001d, 0x995c00b9, 0x75d101c5, 0x00000000}},  //   _hạn_, díž_, _kāza,
  { {0x2fc90016, 0xf1c90082, 0x00000000, 0x00000000}},  //   _tuag_, _kạn_,   ,
  { {0x68e9109a, 0xd05d005f, 0x3b550069, 0x00000000}},  // [1c30] _reed, yasə, окар,
  { {0xf1c90011, 0x68e9109b, 0x88d20044, 0x00000000}},  //   _mạn_, _seed, ারফক,
  { {0x6aba000c, 0x68e9109c, 0x2d8b00fa, 0x00000000}},  //   _útfl, _peed, _tjce_,
  { {0xad270167, 0x8ed80167, 0xbcfb00b9, 0x00000000}},  //   _اردو, _پذیر_, _mlék,
  { {0xbae80055, 0xf1c90011, 0x68e9017b, 0x00000000}},  //   _পারছ, _nạn_, _veed,
  { {0x7c2f0198, 0x45d500ed, 0xe73901ab, 0x00000000}},  //   _iscr, оцит, рек_,
  { {0x68e9006c, 0x636d0325, 0x27e00089, 0x00000000}},  //   _teed, _húng, ģina_,
  { {0xf1c900ad, 0xf77301ef, 0x160b013d, 0x00000000}},  //   _bạn_, _کار_, संबर_,
  { {0x7c2f0050, 0xf1c90011, 0x972503e6, 0x00000000}},  //   _jscr, _cạn_, _وفرو,
  { {0x6d9301d5, 0x4374041f, 0xf1c90082, 0x00000000}},  //   lħad, зуют, _dạn_,
  { {0xea000011, 0xe12601bd, 0x31690087, 0x00000000}},  //   _thấp_, омни, _blaz_,
  { {0x26130181, 0x2419007c, 0x32050300, 0x00000000}},  //   mão_, _воды_, ruly_,
  { {0x26130181, 0x237e012d, 0x7c2f00e5, 0x00000000}},  //   lão_, bitj_, _nscr,
  { {0x88ba009b, 0x442f01e5, 0x5334007c, 0x00000000}},  //   יזרי, _isg_, _нечт,
  { {0x3ebe0039, 0x26130181, 0x442f109d, 0x00000000}},  //   ätt_, não_, _hsg_,
  { {0x443d0035, 0x7c2f0009, 0xf1c90082, 0x00000000}},  //   _krw_, _bscr, _hạo_,
  { {0x261300c4, 0x636d0048, 0xdca30088, 0x00000000}},  // [1c40] hão_, _cúng, дати,
  { {0x442f03e2, 0x443d004a, 0x8a3a007c, 0x00000000}},  //   _msg_, _mrw_, ияет_,
  { {0x261300c4, 0x2d9e00f4, 0xf1c90011, 0x00000000}},  //   jão_, îtes_, _mạo_,
  { {0x261302d5, 0x8c460478, 0x00000000, 0x00000000}},  //   dão_, _деме,   ,
  { {0x274a109e, 0x443d010f, 0x00000000, 0x00000000}},  //   ичко_, _nrw_,   ,
  { {0x29d70066, 0x261300c4, 0xf1c90082, 0x00000000}},  //   _bħad_, fão_, _nạo_,
  { {0x26130181, 0xf1c90011, 0xc2e80044, 0x00000000}},  //   gão_, _sạn_, _খালি_,
  { {0x5454109f, 0xdb1c00f6, 0x69de00b0, 0x00000000}},  //   звит, _mirí, mppe,
  { {0xf1c90011, 0x186709f1, 0xe9470014, 0x00000000}},  //   _bạo_, _дати_, _ظرفی,
  { {0x2d68011f, 0xf1c910a0, 0x68e200ea, 0x00000000}},  //   rşey_, _vạn_, lbod,
  { {0xf1c90011, 0x26130181, 0x443d0678, 0x00000000}},  //   _dạo_, cão_, _erw_,
  { {0xdb1d010f, 0x68e2054e, 0x443d10a1, 0x00000000}},  //   _zusä, nbod, _frw_,
  { {0xdb1c0051, 0xe73100a1, 0x98c5012d, 0x00000000}},  //   _airí, _غصے_, šuća_,
  { {0x6d46011f, 0xf1c90011, 0x7ada0061, 0x00000000}},  //   _anka, _gạo_, _प्लॅ,
  { {0xcdd8003b, 0xdb1c06c0, 0x00000000, 0x00000000}},  //   жњу_, _cirí,   ,
  { {0xdb1c008e, 0xd657009b, 0x31690091, 0x00000000}},  //   _dirí, חילת_, _ulaz_,
  { {0x26130181, 0x68e210a2, 0x20040129, 0x00000000}},  // [1c50] zão_, dbod, àmit_,
  { {0x69de001c, 0xfaa701fb, 0x8aa706e1, 0x00000000}},  //   fppe, ошен, оред,
  { {0x26130181, 0x539b009b, 0x00000000, 0x00000000}},  //   xão_, סיבו,   ,
  { {0x261300c4, 0x68e210a3, 0xdeb6009b, 0x00000000}},  //   vão_, gbod, _מפתח_,
  { {0x69de0026, 0x9cd600b3, 0xf7450745, 0x00000000}},  //   appe, _מורה_, зело,
  { {0x261302d5, 0x7d0d069e, 0x442f0007, 0x00000000}},  //   tão_, lgas, _rsg_,
  { {0xf9930188, 0x443d016b, 0xe778009e, 0x00000000}},  //   _قبر_, _srw_, تلوں_,
  { {0x261302d5, 0x7d0d0fa2, 0x442f009d, 0x00000000}},  //   rão_, ngas, _psg_,
  { {0x261302d5, 0x7c2d10a4, 0x68fb0058, 0x00000000}},  //   são_, nwar, _idud,
  { {0x26130181, 0x6d9301d5, 0x7c220023, 0x00000000}},  //   pão_, nħab, çori,
  { {0xe2990175, 0x7c2d001f, 0x636d0051, 0x00000000}},  //   сан_, hwar, _rúnd,
  { {0x3a310010, 0x661c006c, 0x225800f8, 0x00000000}},  //   _mszp_, _ärka, ärka_,
  { {0xf1c9001d, 0x81cc0044, 0x645d010f, 0x00000000}},  //   _tạo_, শীল_, äsid,
  { {0x7c2d10a5, 0x442d10a6, 0xdc3a006b, 0x00000000}},  //   dwar, mwe_, xçıv,
  { {0xf2d2007b, 0x442d0007, 0x2ca7006b, 0x00000000}},  //   _טעג_, lwe_, əndi_,
  { {0x7c2d10a7, 0x7d0d0f20, 0x442d0036, 0x00000000}},  //   fwar, ggas, owe_,
  { {0x7c2d01d5, 0xed5700ed, 0x2b580a86, 0x00000000}},  // [1c60] gwar, чот_, _porc_,
  { {0x636d10a8, 0xf1c90011, 0x442d01d6, 0x00000000}},  //   _fúne, _lạm_, iwe_,
  { {0xa92610a9, 0x442d0173, 0x68e20270, 0x00000000}},  //   здел, hwe_, tbod,
  { {0xc7c602a8, 0x31b201ca, 0x442d0020, 0x00000000}},  //   пски, báze_, kwe_,
  { {0x07a60072, 0x442d10aa, 0x68e200b5, 0x00000000}},  //   падн, jwe_, rbod,
  { {0xe3a704e8, 0x501b00b6, 0x656b10ab, 0x00000000}},  //   _سر_, מונו, _algh,
  { {0x442d0343, 0xbcfb0051, 0x68e20009, 0x00000000}},  //   ewe_, _sléi, pbod,
  { {0x6b9e10ac, 0x69ce001a, 0x75290009, 0x00000000}},  //   lopg, _iube, geez,
  { {0x69ce01a2, 0x442d10ad, 0xe3af0014, 0x00000000}},  //   _hube, gwe_, گري_,
  { {0x27f70224, 0x69ce0020, 0xb4bc0061, 0x00000000}},  //   ření_, _kube, _आणी_,
  { {0xcfc40055, 0x7c2d10ae, 0xe3b8005d, 0x00000000}},  //   ্ঠান, zwar, rmı_,
  { {0x79820046, 0x442d0b28, 0x69ce0022, 0x00000000}},  //   niow, bwe_, _mube,
  { {0x69ce0770, 0x434609da, 0xafe4007e, 0x00000000}},  //   _lube, _недв, ноўл,
  { {0x21200022, 0x798200ea, 0x00000000, 0x00000000}},  //   _ebih_, hiow,   ,
  { {0xd788001d, 0x212005fa, 0x798b018e, 0x00000000}},  //   yển_, _fbih_, yngw,
  { {0xbcfb008e, 0x7c2d0652, 0x3a230022, 0x00000000}},  //   _llév, twar, _rpjp_,
  { {0x2d580e09, 0x69dc0779, 0x7d0d01a3, 0x00000000}},  // [1c70] чить_, _atre, rgas,
  { {0x636d10af, 0x212b10b0, 0x69ce0062, 0x00000000}},  //   _túne, lech_, _bube,
  { {0x69ce00d4, 0x200b10b1, 0x442d10b2, 0x00000000}},  //   _cube, luci_, zwe_,
  { {0xfc3f10b3, 0x212b00b9, 0x69ce00b9, 0x00000000}},  //   _trí_, nech_, _dube,
  { {0xf77000d3, 0x2019023e, 0x69ca0b33, 0x00000000}},  //   گان_, ntsi_, ífer,
  { {0xf094007b, 0x3f830213, 0x7bdd0d58, 0x00000000}},  //   ענס_, niju_, _itsu,
  { {0xf7700318, 0x69ce023a, 0x442d0007, 0x00000000}},  //   دان_, _gube, wwe_,
  { {0x442d10b4, 0x79820036, 0x3f8301ee, 0x00000000}},  //   twe_, ciow, hiju_,
  { {0x200b10b5, 0x442d02ae, 0x75290f1d, 0x00000000}},  //   juci_, uwe_, reez,
  { {0xe1f9081e, 0x442d0343, 0xd2f7026c, 0x00000000}},  //   ого_, rwe_, سکتا_,
  { {0x3f830089, 0xf1c90011, 0x7bcf0145, 0x00000000}},  //   diju_, _tạm_, _lucu,
  { {0x290f10b6, 0x7bdd0004, 0xdb1c008e, 0x00000000}},  //   ngga_, _otsu, _mirá,
  { {0xbf9b0181, 0x200b0107, 0x3f8310b7, 0x00000000}},  //   rrên, guci_, fiju_,
  { {0x1b030044, 0x162101f5, 0x3f830091, 0x00000000}},  //   র্তে_, _महार_, giju_,
  { {0x7bcf028c, 0x7bdd007f, 0xad5a09c0, 0x00000000}},  //   _aucu, _atsu, орах_,
  { {0x7bcf000d, 0xc69201ce, 0x2120016c, 0x00000000}},  //   _bucu, דאל_, _ubih_,
  { {0x69dc0027, 0x3f8310b8, 0x672110b9, 0x00000000}},  // [1c80] _stre, biju_, _oblj,
  { {0x3f830bf1, 0x09e6081e, 0x2c0b00a1, 0x00000000}},  //   ciju_, дожн, تعفی_,
  { {0x7bc70169, 0xed5a004d, 0xe9da0140, 0x00000000}},  //   _diju, _дон_, цке_,
  { {0x7aee0007, 0xdb1c008e, 0x6b9e0030, 0x00000000}},  //   _webt, _dirá, sopg,
  { {0x7bcf0009, 0x2baf0164, 0x63a8101b, 0x00000000}},  //   _gucu, _जीवा, yldn,
  { {0x212b0667, 0x798210ba, 0x00000000, 0x00000000}},  //   zech_, siow,   ,
  { {0x69dc10bb, 0x8b0300b9, 0x79820036, 0x00000000}},  //   _utre, _úřad, piow,
  { {0xd826025f, 0x3f8310bc, 0x7434073b, 0x00000000}},  //   _одби, ziju_, ениф,
  { {0x61ea0061, 0x76410016, 0x212b013e, 0x00000000}},  //   _swfl, _erly, vech_,
  { {0xd37000b8, 0x200b0243, 0x212b0016, 0x00000000}},  //   اهد_, vuci_, wech_,
  { {0x212b0224, 0x69c80010, 0x63a80908, 0x00000000}},  //   tech_, _édes, rldn,
  { {0x80fb0309, 0x200b013e, 0x7c260190, 0x00000000}},  //   ्लेख_, tuci_, _opkr,
  { {0x212b0c0f, 0x320500ab, 0x3f830091, 0x00000000}},  //   rech_, arly_, tiju_,
  { {0xa294008b, 0x44260020, 0x212b00b9, 0x00000000}},  //   _палі, _ipo_, sech_,
  { {0x7bcf106f, 0x13e30055, 0x3f830ad8, 0x00000000}},  //   _sucu, _মিয়, riju_,
  { {0x3f8307a6, 0x7bc70020, 0xa2da0164, 0x00000000}},  //   siju_, _siju, पुर्,
  { {0x9f4201ca, 0x60cd10bd, 0x44260066, 0x00000000}},  // [1c90] lský_, _igam, _jpo_,
  { {0x2b4a10be, 0xdb1c10bf, 0x442610c0, 0x00000000}},  //   _cnbc_, _pirá, _mpo_,
  { {0x9f4201ca, 0x2d850010, 0x09e40088, 0x00000000}},  //   nský_, éles_, воєн,
  { {0xaadf02f4, 0x4adf02fb, 0x39490845, 0x00000000}},  //   _प्रक, _प्रव, ñas_,
  { {0xba7401ef, 0x636d0051, 0x7bc7029d, 0x00000000}},  //   _یافت, _lúna, _tiju,
  { {0xbcfb0181, 0x6d5d005b, 0xe73600d7, 0x00000000}},  //   _elét, _hosa, ееш_,
  { {0x4426008d, 0x6d5d0142, 0x386910c1, 0x00000000}},  //   _apo_, _kosa, šar_,
  { {0x60cd0697, 0x442610c2, 0x00000000, 0x00000000}},  //   _ngam, _bpo_,   ,
  { {0x6442028c, 0x442604be, 0x4ad30061, 0x00000000}},  //   _croi, _cpo_, _तलाव,
  { {0x6442028c, 0x60cd0169, 0xf1c90011, 0x00000000}},  //   _droi, _agam, _hại_,
  { {0x636d0051, 0x64420420, 0x442610c3, 0x00000000}},  //   _cúna, _eroi, _epo_,
  { {0x6d5d10c4, 0x644200f4, 0x25d60097, 0x00000000}},  //   _nosa, _froi, _טוען_,
  { {0xf1c9001d, 0x27ed01aa, 0x442610c5, 0x00000000}},  //   _mại_, _jwen_, _gpo_,
  { {0x27ed0607, 0xf1c900ad, 0x443f0117, 0x00000000}},  //   _mwen_, _lại_, mvu_,
  { {0x27ed01aa, 0x443f06ed, 0x6d5d10c6, 0x00000000}},  //   _lwen_, lvu_, _bosa,
  { {0x6d5d10c7, 0x27ed0016, 0xed5703f3, 0x00000000}},  //   _cosa, _owen_, нос_,
  { {0x6d5d06a6, 0xf1ca0011, 0x443f10c8, 0x00000000}},  // [1ca0] _dosa, _nại_, nvu_,
  { {0x99710036, 0xbcfb01e5, 0x909b009b, 0x00000000}},  //   jął_, _slét, _מספק,
  { {0xa3c00204, 0x6d5d10c9, 0x65690190, 0x00000000}},  //   ंगत_, _fosa, kkeh,
  { {0x443f0119, 0x7e610039, 0xf1ca0011, 0x00000000}},  //   kvu_, älpe, _bại_,
  { {0x63a10036, 0x9f4201dc, 0x186700e3, 0x00000000}},  //   koln, zský_, наци_,
  { {0xf1ca0011, 0x443f016c, 0xfc3f00b9, 0x00000000}},  //   _dại_, dvu_, _vzít_,
  { {0xe5c601e0, 0x443f06a3, 0x44260065, 0x00000000}},  //   нсио, evu_, _spo_,
  { {0x9f4206b8, 0x636d056f, 0xdb1c014a, 0x00000000}},  //   vský_, _rúna, _birç,
  { {0x27ed005b, 0xe4520257, 0x70af013d, 0x00000000}},  //   _gwen_, اضع_, _घरेल,
  { {0xbf9b00f4, 0x320c0058, 0x60cd0026, 0x00000000}},  //   trêm, tudy_, _sgam,
  { {0x9294007e, 0x00000000, 0x00000000, 0x00000000}},  //   танц,   ,   ,
  { {0x6442028c, 0x32020428, 0x9f420161, 0x00000000}},  //   _troi, čky_, rský_,
  { {0x6d5d10ca, 0x673a0059, 0x38660129, 0x00000000}},  //   _rosa, _katj, nyor_,
  { {0xbf9b009d, 0x9f420802, 0x00000000, 0x00000000}},  //   prêm, pský_,   ,
  { {0xf1a70057, 0x673a0059, 0x64470089, 0x00000000}},  //   _прин, _matj, ājie,
  { {0xbcfb0285, 0x29d701f3, 0x60cd0145, 0x00000000}},  //   _alér, _bħan_, _ugam,
  { {0x6d5d0129, 0xfbd30879, 0x6386009d, 0x00000000}},  // [1cb0] _vosa, اتر_, _génè,
  { {0x673a0182, 0xbcfb10cb, 0x753b012d, 0x00000000}},  //   _natj, _clér, zduz,
  { {0x6d5d002a, 0x61fa010f, 0x69c9001e, 0x00000000}},  //   _tosa, nstl, _piee,
  { {0xbcfb0047, 0x27ed0263, 0x25a60087, 0x00000000}},  //   _elér, _pwen_, _nkol_,
  { {0xe7390256, 0xa3c0007d, 0x29d701d5, 0x00000000}},  //   дел_, ंगा_, _għan_,
  { {0xdb050051, 0x61fa00ea, 0x00000000, 0x00000000}},  //   rmhó, kstl,   ,
  { {0x63a10802, 0x673a046a, 0xab940088, 0x00000000}},  //   voln, _datj, _сирі,
  { {0xf1ca00ad, 0x443f0213, 0x63a10036, 0x00000000}},  //   _tại_, tvu_, woln,
  { {0x02c90201, 0x6569010f, 0x2104010a, 0x00000000}},  //   रश्न, rkeh, nčių_,
  { {0x443f10cc, 0x21040006, 0x65690142, 0x00000000}},  //   rvu_, ičių_, skeh,
  { {0x779006c6, 0x395f01aa, 0x443f10cd, 0x00000000}},  //   _دیوا, _kous_, svu_,
  { {0x395f0173, 0x63a10010, 0x6386009d, 0x00000000}},  //   _jous_, soln, _pénè,
  { {0x63a101d9, 0x629800f6, 0x395f0068, 0x00000000}},  //   poln, _exvo, _mous_,
  { {0x25ad0004, 0xa283007a, 0x25bf001a, 0x00000000}},  //   llel_, _میخو, lmul_,
  { {0xbea60081, 0xe3c80011, 0x394d0b3f, 0x00000000}},  //   тавк, _cựu_, _ones_,
  { {0x395f10ce, 0x41b600a1, 0xa5c2000c, 0x00000000}},  //   _nous_, _جمعر, _þótt,
  { {0x29d7013f, 0x00000000, 0x00000000, 0x00000000}},  // [1cc0] _aça_,   ,   ,
  { {0x09ca007d, 0x394d0023, 0x00000000, 0x00000000}},  //   िद्य, _anes_,   ,
  { {0xc332012e, 0x395f10cf, 0x673a00d9, 0x00000000}},  //   שוב_, _bous_, _ratj,
  { {0x395f0026, 0x02b60049, 0x394d10d0, 0x00000000}},  //   _cous_, דלעך_, _cnes_,
  { {0x394d004f, 0x395f10d1, 0x673a0065, 0x00000000}},  //   _dnes_, _dous_, _patj,
  { {0xbf9b00f4, 0x394d0095, 0x9873007e, 0x00000000}},  //   quêt, _enes_, шліц,
  { {0x6aa3010f, 0x2bd8007d, 0x395f009d, 0x00000000}},  //   ünft, _भंडा, _fous_,
  { {0x3160002d, 0x2d9201a3, 0x2ef801a2, 0x00000000}},  //   _noiz_, nnye_, harf_,
  { {0x673a016c, 0x47c6008b, 0xd0e30164, 0x00000000}},  //   _tatj, _абав, _क्षण_,
  { {0xbcfb00f6, 0x31600288, 0xc4450014, 0x00000000}},  //   _llép, _aoiz_, ایون_,
  { {0xcb1300b6, 0x2ef8010f, 0x27e6023a, 0x00000000}},  //   בלת_, darf_, lpon_,
  { {0x25a6011c, 0x2104007f, 0x3a2a0145, 0x00000000}},  //   _ukol_, yčių_, _mpbp_,
  { {0x27e610d2, 0xf1bf10d3, 0x00000000, 0x00000000}},  //   npon_, rmá_,   ,
  { {0x29d701d5, 0x200510d4, 0x27e60058, 0x00000000}},  //   _bħal_, čli_, ipon_,
  { {0x636d0051, 0x3da700ed, 0xc33300b3, 0x00000000}},  //   _múnl, враб, _כוס_,
  { {0x3160002d, 0x00000000, 0x00000000, 0x00000000}},  //   _goiz_,   ,   ,
  { {0x0dc801fb, 0xc05b0088, 0x395f0087, 0x00000000}},  // [1cd0] тури_, _цій_, _rous_,
  { {0x395f028c, 0x2571000c, 0xbb74003b, 0x00000000}},  //   _sous_, _mála_, агуј,
  { {0x29d70f68, 0x21040006, 0x395f10d5, 0x00000000}},  //   _għal_, sčių_, _pous_,
  { {0x67d510d6, 0x00000000, 0x00000000, 0x00000000}},  //   году,   ,   ,
  { {0x395f0a8d, 0x6d4f10d7, 0xd8250081, 0x00000000}},  //   _vous_, _inca, удли,
  { {0xf1ca0011, 0x394d0016, 0x00000000, 0x00000000}},  //   _hạt_, _wnes_,   ,
  { {0x395f028c, 0x25bf0035, 0x63760035, 0x00000000}},  //   _tous_, tmul_, _mând,
  { {0x22490119, 0x845901f9, 0x394d04bd, 0x00000000}},  //   _čak_, ерот_, _unes_,
  { {0xc9840364, 0x25bf0938, 0xf1ca0082, 0x00000000}},  //   _тури, rmul_, _mạt_,
  { {0x25bf001a, 0xf1ca0011, 0x69d5014a, 0x00000000}},  //   smul_, _lạt_, _kuze,
  { {0x75150054, 0xa18a10d8, 0x200b0036, 0x00000000}},  //   _مواض, ебна_, erci_,
  { {0xd00a0893, 0x9f5e00b9, 0xdb1d01a2, 0x00000000}},  //   неме_, čtí_, _ausü,
  { {0x69d5002d, 0xe44e022a, 0x2ef8000c, 0x00000000}},  //   _luze, _уж_, tarf_,
  { {0x6d4f01f6, 0x63760f6e, 0xf367003b, 0x00000000}},  //   _anca, _când, _штен,
  { {0x539a00a0, 0xa3c00164, 0x63760035, 0x00000000}},  //   _איסו, ंगर_, _sâng,
  { {0x26140061, 0xcd3600a1, 0x3a380009, 0x00000000}},  //   नंती_, درآب, _rsrp_,
  { {0x7af510d9, 0x69d50035, 0x2d9208f8, 0x00000000}},  // [1ce0] _bezt, _auze, rnye_,
  { {0x6d4f04bd, 0x69d50065, 0x6376001a, 0x00000000}},  //   _enca, _buze, _gând,
  { {0xd9460088, 0x68e4004a, 0x22f60049, 0x00000000}},  //   лежи, ñido, רזען_,
  { {0xf1ca0082, 0xed570b5f, 0x22580961, 0x00000000}},  //   _gạt_, _бою_, ärki_,
  { {0x27e60145, 0xb6c800a1, 0x776100f6, 0x00000000}},  //   upon_, ھاتے_, _bolx,
  { {0x27e600e0, 0x69d50584, 0x07a3060e, 0x00000000}},  //   rpon_, _fuze, бачн,
  { {0x27e60129, 0xe1e710da, 0x69d5014a, 0x00000000}},  //   spon_, _دس_, _guze,
  { {0x7bce020c, 0x27e60145, 0x78b1000c, 0x00000000}},  //   _hibu, ppon_, ðkvæ,
  { {0x69d5022b, 0xa3c2001c, 0xb7160054, 0x00000000}},  //   _zuze, ्दल_, _مباش,
  { {0x3f8a000b, 0x69c20116, 0x00000000, 0x00000000}},  //   jibu_, lmoe,   ,
  { {0x6b7b01ce, 0x2d5c0b32, 0x7bce00e0, 0x00000000}},  //   גרינ, _díez_, _mibu,
  { {0x8446004b, 0x7bce0c35, 0xdb1c00c4, 0x00000000}},  //   _مختل, _libu, _cirú,
  { {0x200b009d, 0x133900a1, 0x29d701f3, 0x00000000}},  //   urci_, رتیں_, _rħam_,
  { {0x447b007b, 0x7bce0141, 0xf4870167, 0x00000000}},  //   _אנדע, _nibu, _حامی,
  { {0x63030025, 0x29040166, 0x63760adb, 0x00000000}},  //   _طويل, _odma_, _vând,
  { {0x7bce00e7, 0x00000000, 0x00000000, 0x00000000}},  //   _aibu,   ,   ,
  { {0x69d501d6, 0x3f8a10db, 0xf1ca0082, 0x00000000}},  // [1cf0] _suze, bibu_, _vạt_,
  { {0x29040066, 0x13d70044, 0x7bce0161, 0x00000000}},  //   _adma_, _দৌড়, _cibu,
  { {0x5a3510dc, 0x7bce020c, 0x65620058, 0x00000000}},  //   рнет, _dibu, _oooh,
  { {0x290410dd, 0x69c207a5, 0x6d4f00ab, 0x00000000}},  //   _cdma_, gmoe, _unca,
  { {0x68f90046, 0x200005aa, 0x69da00f4, 0x00000000}},  //   rawd, _xvii_, _éten,
  { {0xf7450264, 0x68f90016, 0x69d50062, 0x00000000}},  //   реко, sawd, _tuze,
  { {0x7f3c007b, 0xfaa9023c, 0x6f050173, 0x00000000}},  //   געוו, _شهري_, _mdhc,
  { {0x05650088, 0x3f8a0009, 0x7bce10de, 0x00000000}},  //   рвин, zibu_, _zibu,
  { {0x7bce0009, 0x320b0036, 0x67130061, 0x00000000}},  //   _yibu, ącym_, _ठाऊक_,
  { {0x25a001d9, 0x422500c0, 0xb7bd001a, 0x00000000}},  //   čila_, адов, _opţi,
  { {0x45d510df, 0x00000000, 0x00000000, 0x00000000}},  //   _тоес,   ,   ,
  { {0x69d80181, 0x798b0016, 0xa06a003b, 0x00000000}},  //   ívei, nigw, вама_,
  { {0x3f8a000b, 0x671c006e, 0x00000000, 0x00000000}},  //   tibu_, _नामक_,   ,
  { {0xb4c1007d, 0x798b10e0, 0x2d990146, 0x00000000}},  //   ंधी_, higw, _ajse_,
  { {0x3f8a000b, 0x0fc301fb, 0x7bce0169, 0x00000000}},  //   ribu_, ійсн, _ribu,
  { {0x257101ca, 0x7bce01a3, 0x3f8a06a9, 0x00000000}},  //   _málo_, _sibu, sibu_,
  { {0x3b86007e, 0x7d160232, 0x00000000, 0x00000000}},  // [1d00] алаг, rgys,   ,
  { {0xfbdf001d, 0x1db80061, 0xdcf6019a, 0x00000000}},  //   _trên_, _आठवत, ıcın,
  { {0x69c206b2, 0xca56025f, 0xe8fa00a8, 0x00000000}},  //   tmoe, штањ, вле_,
  { {0xc8ca023c, 0xfd120025, 0x7bce0045, 0x00000000}},  //   نوان_, _بجد_, _wibu,
  { {0x69c201b5, 0x97c610e1, 0x7bce0c1b, 0x00000000}},  //   rmoe, айде, _tibu,
  { {0x6376001a, 0x69c20032, 0x00000000, 0x00000000}},  //   _mânc, smoe,   ,
  { {0x798b0066, 0x9c8706b8, 0x656200d2, 0x00000000}},  //   bigw, počí, _pooh,
  { {0xa4f80123, 0x342602dc, 0x00000000, 0x00000000}},  //   اکار_, афов,   ,
  { {0xdb1c00ea, 0xa967003b, 0x68ed004a, 0x00000000}},  //   _birø, _тита_, ñade,
  { {0xf3660069, 0x76550010, 0x00000000, 0x00000000}},  //   ртин, ógyí,   ,
  { {0x1b030055, 0x0bb700b6, 0x81de0044, 0x00000000}},  //   র্কে_, שלים_, দীন_,
  { {0x51f70a78, 0xa194013a, 0x00000000, 0x00000000}},  //   шнюю_, жаюч,   ,
  { {0x04140044, 0x63760181, 0x49070061, 0x00000000}},  //   _তৈরী_, _cânc, हणतो_,
  { {0x93fb00b6, 0x2578013e, 0x637600e5, 0x00000000}},  //   _ילדי, _déle_, _dânc,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2129003f, 0x63a8016e, 0x25780010, 0x00000000}},  //   _ubah_, lodn, _féle_,
  { {0x91bc009b, 0x00000000, 0x00000000, 0x00000000}},  // [1d10] _במהי,   ,   ,
  { {0x8ae701fb, 0x3b5410e2, 0x3f150088, 0x00000000}},  //   ріал, окур, _удос,
  { {0xcfe20044, 0x69da0010, 0x2bc8022a, 0x00000000}},  //   _বিএন, _étel, руто_,
  { {0x63a80e80, 0x00000000, 0x00000000, 0x00000000}},  //   hodn,   ,   ,
  { {0x8d5a00b6, 0x63a80091, 0x798b10e3, 0x00000000}},  //   _עכשי, kodn, rigw,
  { {0xcc3a007b, 0xdc3a007b, 0x798b037f, 0x00000000}},  //   _געשט, _געשר, sigw,
  { {0x798b0020, 0x6446000c, 0x00000000, 0x00000000}},  //   pigw, ækin,   ,
  { {0xf1ca0011, 0x7bc510e4, 0x7d1d0045, 0x00000000}},  //   _nạp_, lmhu, _jcss,
  { {0x798910e5, 0x2613007d, 0x7bc500bb, 0x00000000}},  //   _imew, _धमकी_, omhu,
  { {0xf77300a6, 0x63a810e6, 0xc6a701fc, 0x00000000}},  //   _بار_, godn, _креи,
  { {0x636d10e7, 0x61460478, 0x00000000, 0x00000000}},  //   _júni, бена,   ,
  { {0xdb050039, 0xf1ca0082, 0x636d004a, 0x00000000}},  //   llhä, _cạp_, _múni,
  { {0x63a806a2, 0x2329013b, 0x2418007e, 0x00000000}},  //   bodn, _боли_, _вочы_,
  { {0x2bdb03d7, 0x53340242, 0xdee3003b, 0x00000000}},  //   _बढ़ा, _мечт, зори,
  { {0xdef9007e, 0x1d0a02dc, 0x225809b0, 0x00000000}},  //   шыў_, леви_, ärkt_,
  { {0xf1d00164, 0xa19301fc, 0x442f10e8, 0x00000000}},  //   _सूचन, _најч, _kpg_,
  { {0x442f001c, 0x443d03b2, 0x7d1d0045, 0x00000000}},  // [1d20] _jpg_, _jsw_, _dcss,
  { {0xf3f908b7, 0x200200ee, 0x79890020, 0x00000000}},  //   _আমার_, mski_, _amew,
  { {0x200210e9, 0x6e46007a, 0x442f10ea, 0x00000000}},  //   lski_, _انجم, _lpg_,
  { {0x9f49009f, 0xf8fa0025, 0x442f0190, 0x00000000}},  //   _hvað_, اءات_, _opg_,
  { {0x200200ee, 0xbf9b009d, 0x799b0022, 0x00000000}},  //   nski_, prêt, _djuw,
  { {0x6d44022b, 0x39400006, 0x7c2410eb, 0x00000000}},  //   ldia, žis_, mtir,
  { {0x644b022b, 0x8afb00b3, 0x65be0065, 0x00000000}},  //   _argi, _תהלי, hëhe,
  { {0x6d44022b, 0x25a001d9, 0x63a80046, 0x00000000}},  //   ndia, čilo_, wodn,
  { {0x7c2400d0, 0x200200ee, 0x69c000b0, 0x00000000}},  //   ntir, jski_, _ihme,
  { {0x7afe0010, 0x200210ec, 0x68e200bb, 0x00000000}},  //   napt, dski_, lcod,
  { {0xe1350a78, 0xdb1c00f4, 0x69c0016b, 0x00000000}},  //   онны, _chré, _khme,
  { {0xf651026c, 0x68e20141, 0x5a9b007b, 0x00000000}},  //   _کئے_, ncod, רשטא,
  { {0x6d440bc4, 0x63a80091, 0x442f0fd1, 0x00000000}},  //   ddia, podn, _gpg_,
  { {0x60d60047, 0x6d440638, 0x7c2401a2, 0x00000000}},  //   _egym, edia, dtir,
  { {0x41e603ec, 0xf1ca0011, 0xdb1c0051, 0x00000000}},  //   _استف, _tạp_, _ghré,
  { {0x1619001c, 0xd0110d3a, 0x20020aa9, 0x00000000}},  //   नंतर_, _قلب_, bski_,
  { {0x68e20e9c, 0xfe7000a1, 0x7c240058, 0x00000000}},  // [1d30] dcod, ودہ_, gtir,
  { {0x69c0014a, 0xda7b007e, 0x68e200d9, 0x00000000}},  //   _ahme, ляе_, ecod,
  { {0x6d4410ed, 0x7a350025, 0xce590478, 0x00000000}},  //   bdia, تفاص, _танц_,
  { {0xac19007c, 0x7c240035, 0x68e200bb, 0x00000000}},  //   _кому_, btir, gcod,
  { {0xe8f801ff, 0x7afe0068, 0x7c2400e5, 0x00000000}},  //   слі_, bapt, ctir,
  { {0x7afe10ee, 0x636d10ef, 0x443d10f0, 0x00000000}},  //   capt, _túni, _rsw_,
  { {0x442f023a, 0x443d01a2, 0x68e210f1, 0x00000000}},  //   _spg_, _ssw_, bcod,
  { {0x240910f2, 0x442f005b, 0x68e20197, 0x00000000}},  //   ании_, _ppg_, ccod,
  { {0x75ca0046, 0xdced0521, 0x657b059c, 0x00000000}},  //   _języ, jkač, rhuh,
  { {0x657b0020, 0x20020213, 0xa20510f3, 0x00000000}},  //   shuh, vski_, опод,
  { {0x20020046, 0xcb12019b, 0x7c24002d, 0x00000000}},  //   wski_, ולי_, ztir,
  { {0x20020ecc, 0x68fb00f4, 0xa4f70167, 0x00000000}},  //   tski_, _jeud, _اکثر_,
  { {0xbee5001c, 0x443d010f, 0x44240045, 0x00000000}},  //   कडून_, _usw_, ctm_,
  { {0x20020209, 0x9474039d, 0xdb1c0051, 0x00000000}},  //   rski_, _عدنا, _thré,
  { {0xfc3f10f4, 0x64490056, 0x68e20019, 0x00000000}},  //   _así_, lvei, ycod,
  { {0x200210f5, 0x68fb0062, 0x75290207, 0x00000000}},  //   pski_, _neud, nfez,
  { {0xab6601fe, 0x644910f6, 0x236710f7, 0x00000000}},  // [1d40] овал, nvei, _konj_,
  { {0x7c240207, 0x6d4410f8, 0x2fd70014, 0x00000000}},  //   rtir, sdia, _گوید_,
  { {0x7c240213, 0x68e20d4d, 0xdce40521, 0x00000000}},  //   stir, tcod, jkić,
  { {0x7c240091, 0x7afe0a3e, 0x68fb0544, 0x00000000}},  //   ptir, sapt, _ceud,
  { {0x1836006d, 0x68fb10f9, 0x68e2010f, 0x00000000}},  //   تراح, _deud, rcod,
  { {0x68e207eb, 0x69d810fa, 0xbb560025, 0x00000000}},  //   scod, íves, _بنسب,
  { {0x68e20019, 0x7afc001a, 0xd95a003b, 0x00000000}},  //   pcod, _iert, _краљ_,
  { {0x7ae9016c, 0x8ebf0044, 0x257807fd, 0x00000000}},  //   _đeti, _আলমগ, _béla_,
  { {0x7afc021e, 0x69dc00b5, 0x39440145, 0x00000000}},  //   _kert, _hure, _iams_,
  { {0x39460006, 0x69dc0b48, 0x7afc0035, 0x00000000}},  //   ldos_, _kure, _jert,
  { {0x7afc01a3, 0xc4e60d99, 0x39460dd1, 0x00000000}},  //   _mert, _джей, odos_,
  { {0x69dc10fb, 0xe1ef00a6, 0x7afc002d, 0x00000000}},  //   _mure, کسی_, _lert,
  { {0x39460b7f, 0x849610fc, 0x81ba0055, 0x00000000}},  //   idos_, _بجائ, _অংশ_,
  { {0x69dc049a, 0xdced00ca, 0x7afc10fd, 0x00000000}},  //   _oure, rkač, _nert,
  { {0xccfb012b, 0x69dc0095, 0x645d00b0, 0x00000000}},  //   ића_, _nure, äsiv,
  { {0x7afc10fe, 0x39440089, 0xfc3f0062, 0x00000000}},  //   _aert, _nams_, _psí_,
  { {0x7afc0653, 0x69dc10ff, 0x21390065, 0x00000000}},  // [1d50] _bert, _aure, mesh_,
  { {0x69dc05f2, 0x20190004, 0x39460181, 0x00000000}},  //   _bure, musi_, edos_,
  { {0x20191100, 0xea000011, 0x69dc0585, 0x00000000}},  //   lusi_, _đảo_, _cure,
  { {0xe9d8008b, 0x69dc001a, 0x3f910107, 0x00000000}},  //   ікі_, _dure, lizu_,
  { {0x69dc0288, 0x66e50256, 0x20190d90, 0x00000000}},  //   _eure, пола, nusi_,
  { {0x39461101, 0x7afc022b, 0x2139008d, 0x00000000}},  //   ados_, _gert, hesh_,
  { {0x7bdd1102, 0x7c39011f, 0x69dc002d, 0x00000000}},  //   _husu, şarı, _gure,
  { {0x20190dec, 0x7afc1103, 0x7bdd0c04, 0x00000000}},  //   kusi_, _zert, _kusu,
  { {0x20191104, 0x69dc09ce, 0x7bdd1105, 0x00000000}},  //   jusi_, _zure, _jusu,
  { {0x644904bd, 0x7bdd0996, 0x2571009f, 0x00000000}},  //   rvei, _musu, _máli_,
  { {0xcb1200bd, 0x64490ba5, 0xa91d010a, 0x00000000}},  //   עלט_, svei, _amži,
  { {0x291d1106, 0x2419007c, 0xb6ba0104, 0x00000000}},  //   ngwa_, _годы_, _הצעי,
  { {0x2019002d, 0x3169002d, 0x7bdd1107, 0x00000000}},  //   gusi_, _doaz_, _nusu,
  { {0x7bd50d53, 0x636d0051, 0x3946007f, 0x00000000}},  //   _nizu, _cúnt, zdos_,
  { {0xe2960888, 0xed5a0920, 0x272f005a, 0x00000000}},  //   _наш_, бов_, mını_,
  { {0x7afc020c, 0x20191108, 0xa0a6007c, 0x00000000}},  //   _sert, busi_, _найд,
  { {0x7afc020c, 0x69dc1109, 0xdca30216, 0x00000000}},  // [1d60] _pert, _sure, еати,
  { {0x69dc110a, 0xef860b7b, 0x272f005d, 0x00000000}},  //   _pure, _хлоп, nını_,
  { {0x19ba0077, 0x7bd5002d, 0x394400f6, 0x00000000}},  //   будь_, _dizu, _pams_,
  { {0x7ae50195, 0x7afc05ca, 0x39460006, 0x00000000}},  //   acht, _wert, udos_,
  { {0x7afc020c, 0x39460211, 0x25ad00c7, 0x00000000}},  //   _tert, rdos_, doel_,
  { {0x69dc0dc6, 0x6d46078f, 0x272f014a, 0x00000000}},  //   _ture, _haka, jını_,
  { {0x6d46006a, 0xfaa30a27, 0x272f0279, 0x00000000}},  //   _kaka, _заро, dını_,
  { {0x6d460390, 0x7ec70047, 0x7bdd014a, 0x00000000}},  //   _jaka, lépé, _yusu,
  { {0x6d46110b, 0x272f0279, 0x21390023, 0x00000000}},  //   _maka, fını_, vesh_,
  { {0x6d46110c, 0x20190ba5, 0x6843005e, 0x00000000}},  //   _laka, vusi_, _януа,
  { {0x21390065, 0x2d920c07, 0x25ad00bb, 0x00000000}},  //   tesh_, kiye_, boel_,
  { {0x6d460811, 0x20190004, 0x6364000a, 0x00000000}},  //   _naka, tusi_, _jònz,
  { {0x21390065, 0x2d92014a, 0x2d800697, 0x00000000}},  //   resh_, diye_, dhie_,
  { {0x2019110d, 0x7bdd008a, 0x21390065, 0x00000000}},  //   rusi_, _rusu, sesh_,
  { {0x6d46110e, 0x2019005f, 0x4ea40920, 0x00000000}},  //   _baka, susi_, ерта,
  { {0xf1a4008b, 0x2d92110f, 0xe3b80279, 0x00000000}},  //   _прын, giye_, llı_,
  { {0x6d460bbb, 0xea00001d, 0x5c9900a5, 0x00000000}},  // [1d70] _daka, _đạo_, цкая_,
  { {0xe3b801f6, 0x7ae5010f, 0x0bb4041f, 0x00000000}},  //   nlı_, ucht, ебую,
  { {0x7bd51110, 0x68ed0211, 0x6d46014a, 0x00000000}},  //   _vizu, ñado, _faka,
  { {0x2d801111, 0x6442021e, 0xe3b80180, 0x00000000}},  //   chie_, _osoi, hlı_,
  { {0x25ad00c7, 0xe3b8014a, 0xf7451112, 0x00000000}},  //   voel_, klı_, дело,
  { {0x6d4601d9, 0xe3b8026d, 0x00000000, 0x00000000}},  //   _zaka, jlı_,   ,
  { {0x6d46014a, 0xda34007e, 0x25ad0112, 0x00000000}},  //   _yaka, _перы, toel_,
  { {0x6faf0061, 0x5ebf0044, 0xd11f007d, 0x00000000}},  //   ंकडू, _আলাই, _भाषण_,
  { {0xe3b802b9, 0x272f0279, 0x25ad0022, 0x00000000}},  //   flı_, tını_, roel_,
  { {0xd3890088, 0x29d7002b, 0x27ed1113, 0x00000000}},  //   ійне_, _għar_, _iten_,
  { {0x272f01f6, 0x320500ab, 0xda7a0049, 0x00000000}},  //   rını_, usly_, ַנשר,
  { {0x272f01f6, 0x7207026c, 0xc6920104, 0x00000000}},  //   sını_, _ہفتہ_, _באב_,
  { {0xe3ae008b, 0xa01b0047, 0x6d461114, 0x00000000}},  //   _аб_, szön, _raka,
  { {0xdb1c002a, 0x2d921115, 0x753b00fa, 0x00000000}},  //   _phrí, wiye_, leuz,
  { {0x6d461116, 0x1d0a00ed, 0x2d8008ea, 0x00000000}},  //   _paka, жеби_, thie_,
  { {0x656b0313, 0x9f5900b0, 0xed570478, 0x00000000}},  //   _jogh, essä_, мос_,
  { {0x6d460ba5, 0x2d921117, 0x656b0066, 0x00000000}},  // [1d80] _vaka, riye_, _mogh,
  { {0x6d460be3, 0x656b0bd6, 0x290d1118, 0x00000000}},  //   _waka, _logh, _adea_,
  { {0x6d46021e, 0x2d801119, 0x637f0699, 0x00000000}},  //   _taka, phie_, _gêne,
  { {0xe3b80676, 0x443f0066, 0x29e8013f, 0x00000000}},  //   zlı_, kwu_, _ağac_,
  { {0x7d04021e, 0xd90d00a6, 0xe3b8005d, 0x00000000}},  //   mais, صیل_, ylı_,
  { {0x7d04021e, 0x75220197, 0x69cb01c3, 0x00000000}},  //   lais, _scoz, amge,
  { {0x27ed111a, 0x656b0030, 0x68e90016, 0x00000000}},  //   _eten_, _bogh, _ffed,
  { {0x7d04021e, 0x257800f4, 0x753b0020, 0x00000000}},  //   nais, _vélo_, geuz,
  { {0xe3b8047f, 0x443f0066, 0x656b111b, 0x00000000}},  //   tlı_, gwu_, _dogh,
  { {0x7d0400b0, 0x636d00f6, 0x656b0048, 0x00000000}},  //   hais, _búnq, _eogh,
  { {0x7d04021e, 0xa3de02fb, 0x81bd001e, 0x00000000}},  //   kais, _दूर_, stēm,
  { {0xe3b80180, 0x7d0400b0, 0x2d9e0010, 0x00000000}},  //   slı_, jais, étel_,
  { {0x637f01d6, 0x9f5900b0, 0xe3b801df, 0x00000000}},  //   _sêne, yssä_, plı_,
  { {0xe3b8005f, 0x81bd0089, 0xd2500647, 0x00000000}},  //   qlı_, otēk, _منت_,
  { {0xdfd41036, 0xd90400e9, 0x656b0239, 0x00000000}},  //   торы, _پی_, _yogh,
  { {0x7d04111c, 0x656b002b, 0x00000000, 0x00000000}},  //   gais, _xogh,   ,
  { {0xfbdf08c6, 0x3b5500ed, 0x4c94007c, 0x00000000}},  // [1d90] _quê_, нкар, витс,
  { {0x31a4005d, 0x60c003e1, 0xa3c3006e, 0x00000000}},  //   mıza_, ümme, ्षय_,
  { {0xdb1c009f, 0x27ed0193, 0xc915012b, 0x00000000}},  //   _virð, _sten_, едећ,
  { {0x7d04009d, 0x79820022, 0x00000000, 0x00000000}},  //   cais, ghow,   ,
  { {0x656b002a, 0x31a4005a, 0x69cb111d, 0x00000000}},  //   _rogh, nıza_, rmge,
  { {0xf1ca001d, 0x656b002a, 0xf6250131, 0x00000000}},  //   _dạy_, _sogh, едко,
  { {0x81bd001e, 0x45d5053c, 0xd90f0123, 0x00000000}},  //   rtēj, нцит, _نیا_,
  { {0x79820046, 0x443f0036, 0x81bd0089, 0x00000000}},  //   chow, twu_, stēj,
  { {0x656b0026, 0x27ed0056, 0xfbdf0082, 0x00000000}},  //   _vogh, _uten_, _trêu_,
  { {0x2d8c009d, 0x7d04007f, 0x00000000, 0x00000000}},  //   édez_, zais,   ,
  { {0x0322008b, 0x656b0051, 0x68e404eb, 0x00000000}},  //   ыдэн, _togh, žide,
  { {0x92df0044, 0x31a4014a, 0x00000000, 0x00000000}},  //   তরে_, fıza_,   ,
  { {0x7d04111e, 0x6007111f, 0xa806004a, 0x00000000}},  //   vais, нням_, mañó,
  { {0x7d040258, 0x00000000, 0x00000000, 0x00000000}},  //   wais,   ,   ,
  { {0x7d040778, 0xf77200a3, 0xed5a0242, 0x00000000}},  //   tais, נקל_, пов_,
  { {0x61ee008e, 0x7bc7006c, 0x00000000, 0x00000000}},  //   íble, _ahju,   ,
  { {0x7d041120, 0xc19b009b, 0xdb1e00b0, 0x00000000}},  // [1da0] rais, _משקי, ympä,
  { {0x7d041121, 0xdb1c0051, 0x60c40087, 0x00000000}},  //   sais, _bhrá, _izim,
  { {0xe9da0f09, 0xc33201f8, 0x7d04044e, 0x00000000}},  //   чке_, רוב_, pais,
  { {0xfbdf00f4, 0x2571000c, 0x307a0049, 0x00000000}},  //   _prêt_, _máls_, ּאַנ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x38cb089d, 0x60c40020, 0xdb1c0048, 0x00000000}},  //   سانی_, _mzim, _fhrá,
  { {0xe2870025, 0xdb1c0051, 0x00000000, 0x00000000}},  //   _إذ_, _ghrá,   ,
  { {0x0466017f, 0x75e7013f, 0x00000000, 0x00000000}},  //   етом, _qıza,   ,
  { {0x81e70055, 0x60c40020, 0x98a300e2, 0x00000000}},  //   মীম_, _nzim, _бите,
  { {0x8835007e, 0x00000000, 0x00000000, 0x00000000}},  //   _шэсц,   ,   ,
  { {0x60c40020, 0x637600fa, 0x00000000, 0x00000000}},  //   _azim, _jâni,   ,
  { {0x4a9b007b, 0x546a0265, 0xbcfb009d, 0x00000000}},  //   לייג, _наем_, _inég,
  { {0xc953019b, 0x25710010, 0x06d50044, 0x00000000}},  //   אמר_, _vált_, _স্পি,
  { {0xa3c302fb, 0x60c4001e, 0x25a00059, 0x00000000}},  //   ्षण_, _dzim, čilu_,
  { {0x60c40045, 0x00000000, 0x00000000, 0x00000000}},  //   _ezim,   ,   ,
  { {0x9f4900fa, 0x00000000, 0x00000000, 0x00000000}},  //   _itaí_,   ,   ,
  { {0x2ef50265, 0x321e00b4, 0xdb1c1122, 0x00000000}},  // [1db0] _изпр, luty_, _shrá,
  { {0xc5f60044, 0x8aa71123, 0x200b0197, 0x00000000}},  //   _ঘটনা_, нред, msci_,
  { {0x321e1124, 0xdd91023c, 0x200b0026, 0x00000000}},  //   nuty_, _نود_, lsci_,
  { {0x397801e1, 0x1a681125, 0x00000000, 0x00000000}},  //   нсію_, ریقی_,   ,
  { {0x6d5d0481, 0x200b0026, 0x00000000, 0x00000000}},  //   _insa, nsci_,   ,
  { {0x7c2d008d, 0x39490ebc, 0x6d4d00c7, 0x00000000}},  //   mtar, žas_, ldaa,
  { {0x7c2d000d, 0xfbdf02d5, 0xe7080076, 0x00000000}},  //   ltar, _três_, رتون_,
  { {0x6d4d02ae, 0x4904023c, 0x7c2d1126, 0x00000000}},  //   ndaa, _موفق, otar,
  { {0x200b1127, 0xbcfb1128, 0xd6db00ed, 0x00000000}},  //   jsci_, _inéd, _ете_,
  { {0x7c2d009f, 0x69da0923, 0x05960014, 0x00000000}},  //   itar, _éter, _یانگ,
  { {0x7c2d0a0d, 0x6d5d02ab, 0x20190197, 0x00000000}},  //   htar, _onsa, ersi_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7c2d0065, 0x1b0c0044, 0x65690166, 0x00000000}},  //   jtar, স্টে_, mjeh,
  { {0x6d5d1129, 0xa067003b, 0x321e0667, 0x00000000}},  //   _ansa, њара_, buty_,
  { {0x7c2d04f4, 0x2019112a, 0xee15007e, 0x00000000}},  //   etar, arsi_, льтэ,
  { {0x7c2d04cb, 0x65690065, 0xe8020061, 0x00000000}},  //   ftar, njeh, रीडा_,
  { {0x442d0555, 0x60c40091, 0x7c2d1002, 0x00000000}},  // [1dc0] nte_, _uzim, gtar,
  { {0x6d5d0cd4, 0xa3c1013d, 0x8ad60025, 0x00000000}},  //   _ensa, ंति_, نتائ,
  { {0x442d048a, 0xbcfb088a, 0x7c2d001a, 0x00000000}},  //   hte_, _poét, atar,
  { {0x69c9112b, 0x3f98003f, 0x637600c4, 0x00000000}},  //   _chee, liru_, _vâni,
  { {0x442d047c, 0xa3c302fb, 0x7c2d050a, 0x00000000}},  //   jte_, ्षा_, ctar,
  { {0x442d0030, 0xbb76005e, 0x3f98112c, 0x00000000}},  //   dte_, _румъ, niru_,
  { {0x442d0007, 0xd6d50044, 0x61e300a4, 0x00000000}},  //   ete_, _স্বয, _nunl,
  { {0x7bdc022b, 0x69c9112d, 0x6288112e, 0x00000000}},  //   _hiru, _ghee, vzdo,
  { {0x442d0343, 0x7bdc0209, 0x37e601fb, 0x00000000}},  //   gte_, _kiru, _розг,
  { {0x61e3005d, 0x20190107, 0x2904112f, 0x00000000}},  //   _bunl, vrsi_, _hema_,
  { {0x442d0038, 0x7bdc0550, 0x7c2d0e49, 0x00000000}},  //   ate_, _miru, ztar,
  { {0x442d04bd, 0x61e30253, 0x7c2d006b, 0x00000000}},  //   bte_, _dunl, ytar,
  { {0x442d04bd, 0x7c2d0543, 0x29040020, 0x00000000}},  //   cte_, xtar, _mema_,
  { {0x290400d4, 0x61e30082, 0xdce60089, 0x00000000}},  //   _lema_, _funl, _rokā,
  { {0x91e3012b, 0x7c2d0036, 0xcddb003b, 0x00000000}},  //   _које, wtar, дња_,
  { {0x2904009f, 0xdd11006b, 0x672d0166, 0x00000000}},  //   _nema_, _düşd, đaji,
  { {0x6d4d01b5, 0xd1b8007a, 0x69c901c3, 0x00000000}},  // [1dd0] rdaa, _جاوا_, _rhee,
  { {0x2d820100, 0xd9cb03d7, 0x7bdc029d, 0x00000000}},  //   _elke_, िष्ट, _ciru,
  { {0x442d022b, 0x7bdc1130, 0x6abc0016, 0x00000000}},  //   zte_, _diru, _cyrf,
  { {0x7c2d048a, 0x6d5d011c, 0x27e4023a, 0x00000000}},  //   ptar, _unsa, _bumn_,
  { {0x442d00f4, 0xec350049, 0x7bdc1131, 0x00000000}},  //   xte_, _גאָר_, _firu,
  { {0x69c900ab, 0x442d0161, 0x7bdc1132, 0x00000000}},  //   _whee, vte_, _giru,
  { {0x69c900bb, 0x6abc0016, 0xc7940014, 0x00000000}},  //   _thee, _gyrf, جشنب,
  { {0x61e300f6, 0x7bdc0032, 0x6f0500b9, 0x00000000}},  //   _runl, _ziru, _lehc,
  { {0x442d0e6d, 0x779304e1, 0xf1bf0027, 0x00000000}},  //   ute_, _پیغا, dlá_,
  { {0xf7700647, 0x657b0058, 0xe1f90517, 0x00000000}},  //   _وال_, skuh, нго_,
  { {0x3f980059, 0x65690243, 0x395f0030, 0x00000000}},  //   viru_, pjeh, _knus_,
  { {0x442d1133, 0x06d50044, 0x3f981134, 0x00000000}},  //   pte_, _স্থি, wiru_,
  { {0x394d018e, 0x442d0065, 0xd0960a78, 0x00000000}},  //   _maes_, qte_, ушны,
  { {0x649a007b, 0x749a061e, 0x00000000, 0x00000000}},  //   _אינה, _אינפ,   ,
  { {0xe1f10a90, 0x395f0ace, 0x3f9801ee, 0x00000000}},  //   _است_, _onus_, riru_,
  { {0x0ce20055, 0x3f980066, 0x22580030, 0x00000000}},  //   বর্ত, siru_, ærke_,
  { {0x29040096, 0x7bdc00b0, 0x3f980091, 0x00000000}},  // [1de0] _rema_, _piru, piru_,
  { {0xdd04038c, 0x09dc0061, 0x29041135, 0x00000000}},  //   ısın, यद्य, _sema_,
  { {0x75e7006b, 0x29040041, 0x00000000, 0x00000000}},  //   _qızl, _pema_,   ,
  { {0xfe9b00a3, 0x394d0325, 0x7bdc0036, 0x00000000}},  //   _טיימ, _caes_, _wiru,
  { {0x29040020, 0x7bdc01a3, 0x00000000, 0x00000000}},  //   _vema_, _tiru,   ,
  { {0xc3190044, 0x7d0600ea, 0x29040020, 0x00000000}},  //   ত্তি_, _heks, _wema_,
  { {0x29040c1b, 0x7d061136, 0x394d0016, 0x00000000}},  //   _tema_, _keks, _faes_,
  { {0x78260025, 0x5e57007b, 0x746a007c, 0x00000000}},  //   _معطل, ריקע_, еров_,
  { {0x7d061137, 0xd90d0014, 0x00000000, 0x00000000}},  //   _meks, _آیه_,   ,
  { {0x7d060056, 0x883b009b, 0x25bf0035, 0x00000000}},  //   _leks, _אתמו, alul_,
  { {0x4ebf0055, 0x317201d0, 0x877b071c, 0x00000000}},  //   _আল্ল, _boyz_, _ראבי,
  { {0x6fc00039, 0x25bf0035, 0x00000000, 0x00000000}},  //   böck, clul_,   ,
  { {0x637600e5, 0x00000000, 0x00000000, 0x00000000}},  //   _bânt,   ,   ,
  { {0x63761138, 0x1b1a0044, 0xf1bf04bb, 0x00000000}},  //   _cânt, ন্তে_, slá_,
  { {0xa3c10183, 0x7d060107, 0xa3c3006e, 0x00000000}},  //   ंतर_, _beks, ्षर_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7d060630, 0xbcfb008e, 0xcb1b00ed, 0x00000000}},  // [1df0] _deks, _anéc, еќе_,
  { {0x7d0600e0, 0x395f00f8, 0x3dc00058, 0x00000000}},  //   _eeks, _snus_, aliw_,
  { {0x394d00c4, 0x00000000, 0x00000000, 0x00000000}},  //   _paes_,   ,   ,
  { {0x4dfa007b, 0xa90701fa, 0x7d0600d9, 0x00000000}},  //   _שפרא, ابان, _geks,
  { {0x1b1a0044, 0x00000000, 0x00000000, 0x00000000}},  //   ন্ধে_,   ,   ,
  { {0x07a500ed, 0x6d4f1139, 0x17f80025, 0x00000000}},  //   јакн, _haca, ارنة_,
  { {0x6d4f0169, 0x25bf001a, 0x27f800ca, 0x00000000}},  //   _kaca, tlul_, _črne_,
  { {0x6d4f0181, 0x395f0022, 0x1b1a0044, 0x00000000}},  //   _jaca, _unus_, ন্দে_,
  { {0x6d4f0127, 0x87270084, 0xb81c007d, 0x00000000}},  //   _maca, _معام, _नियम_,
  { {0x6d4f106f, 0x00000000, 0x00000000, 0x00000000}},  //   _laca,   ,   ,
  { {0x49b800a1, 0x25bf113a, 0x651508d4, 0x00000000}},  //   _شاہد_, plul_, _نوائ,
  { {0x2496007a, 0xe2960454, 0x672d04eb, 0x00000000}},  //   انید_, раю_, đaju,
  { {0x7d06000c, 0x764e009f, 0x63760adb, 0x00000000}},  //   _reks, _ábyr, _pânt,
  { {0x64590719, 0x443d0022, 0x63760035, 0x00000000}},  //   _irwi, _ipw_, _dâns,
  { {0x3ebe000c, 0x645c0089, 0x7d06006c, 0x00000000}},  //   ætt_, ārie, _peks,
  { {0x6d4f001c, 0xa1930545, 0x645900b4, 0x00000000}},  //   _caca, _мајч, _krwi,
  { {0x81bd0089, 0x7d060056, 0x6d4f113b, 0x00000000}},  // [1e00] rtēt, _veks, _daca,
  { {0x6d4f113c, 0x2578000c, 0x907b0104, 0x00000000}},  //   _eaca, _hélt_, _סטיי,
  { {0x7d060292, 0x6d4f113d, 0xeb97012b, 0x00000000}},  //   _teks, _faca, јих_,
  { {0x6d4f0020, 0x32360049, 0x443d03b3, 0x00000000}},  //   _gaca, יטען_, _opw_,
  { {0x6d440035, 0x2d80113e, 0xa01b0010, 0x00000000}},  //   meia, mkie_, szöv,
  { {0x2d800046, 0x6d4f113f, 0x6d440056, 0x00000000}},  //   lkie_, _zaca, leia,
  { {0xfaa3008b, 0x2d800061, 0x7c241140, 0x00000000}},  //   _даро, okie_, luir,
  { {0x2d800343, 0x6d441141, 0xdb070056, 0x00000000}},  //   nkie_, neia, _skjø,
  { {0xb7160014, 0x2d8001d6, 0x69c2006c, 0x00000000}},  //   _نباش, ikie_, mloe,
  { {0x69c20016, 0x443d0093, 0x6e3e0056, 0x00000000}},  //   lloe, _dpw_, _oppb,
  { {0x2d800343, 0xa69602a8, 0x0cc302d2, 0x00000000}},  //   kkie_, _трај, _शर्म,
  { {0x7c24050f, 0x64590009, 0x00000000, 0x00000000}},  //   kuir, _frwi,   ,
  { {0x6d4400c4, 0x248d0036, 0x6e3e0203, 0x00000000}},  //   deia, czem_, _appb,
  { {0x6d4f1142, 0x7c240005, 0xdb050039, 0x00000000}},  //   _saca, duir, llhö,
  { {0x44240b15, 0x6d4f1143, 0x8de801e0, 0x00000000}},  //   lum_, _paca, ифта_,
  { {0x69c8001e, 0xdb1c0051, 0xccf8003b, 0x00000000}},  //   _ūden, _ghrú, ићу_,
  { {0x44240fa2, 0x7c240207, 0x6562004f, 0x00000000}},  // [1e10] num_, guir, _mnoh,
  { {0x25a91144, 0x6d4f04be, 0xde4702fd, 0x00000000}},  //   čali_, _waca, _پیرو_,
  { {0x6d4f002a, 0x5a35005e, 0x7f3c0104, 0x00000000}},  //   _taca, снет, _יעזו,
  { {0x44241145, 0x2d800046, 0x7c2404b4, 0x00000000}},  //   kum_, ckie_, buir,
  { {0x765a0046, 0x44241146, 0xbcfb0051, 0x00000000}},  //   _arty, jum_, _gnéa,
  { {0xbb850054, 0x44241147, 0xf74500ed, 0x00000000}},  //   _السي, dum_, секо,
  { {0x69c21148, 0x443d00bb, 0x7f3c0049, 0x00000000}},  //   bloe, _spw_, דעוו,
  { {0x4424009f, 0xa01b010f, 0x248d0129, 0x00000000}},  //   fum_, nzös, tzem_,
  { {0x44241149, 0xe3b9114a, 0x00000000, 0x00000000}},  //   gum_, лби_,   ,
  { {0xd7740054, 0x248d114b, 0x2d80114c, 0x00000000}},  //   _والع, rzem_, zkie_,
  { {0x248d0c59, 0x7d0d03b6, 0xe10a00e2, 0x00000000}},  //   szem_, kaas, ленд_,
  { {0x443d0584, 0xa06a003b, 0x7d0d01b1, 0x00000000}},  //   _tpw_, гама_, jaas,
  { {0x4424000d, 0x5552026c, 0x645d0030, 0x00000000}},  //   cum_, _رپور, æsid,
  { {0xa027009f, 0x64490016, 0x75290de1, 0x00000000}},  //   _stöð, mwei, lgez,
  { {0x51f50076, 0x6449010f, 0xd5ac00a1, 0x00000000}},  //   _استر, lwei, _سہی_,
  { {0x7529114d, 0x7c2404b4, 0x29d701d5, 0x00000000}},  //   ngez, tuir, _għax_,
  { {0x6449001f, 0x2d800007, 0x69c201b5, 0x00000000}},  // [1e20] nwei, rkie_, vloe,
  { {0x2d8009a2, 0x4f260242, 0x7c2404b4, 0x00000000}},  //   skie_, _удоб, ruir,
  { {0x6449001f, 0x44240047, 0x7c240107, 0x00000000}},  //   hwei, zum_, suir,
  { {0x4424014a, 0x64550089, 0x644900d9, 0x00000000}},  //   yum_, āzij, kwei,
  { {0x7c240038, 0xa3e7006e, 0xe80b013d, 0x00000000}},  //   quir, _मूल_, _सौदा_,
  { {0x64490016, 0x44240f11, 0x9f4000f6, 0x00000000}},  //   dwei, vum_, _juià_,
  { {0x44240036, 0x7529010f, 0xd5ba00aa, 0x00000000}},  //   wum_, fgez, лси_,
  { {0x7529069d, 0x3e5801aa, 0x644901a2, 0x00000000}},  //   ggez, _mčt_, fwei,
  { {0x64490abe, 0x77ca004d, 0x394600c4, 0x00000000}},  //   gwei, _благ_, meos_,
  { {0x4424114e, 0xf3660a30, 0xa3e70061, 0x00000000}},  //   rum_, стин, _मूळ_,
  { {0x4424114f, 0x3e5801aa, 0xb7d7006d, 0x00000000}},  //   sum_, _nčt_, _اولا_,
  { {0x79820046, 0x39461150, 0x656200b0, 0x00000000}},  //   nkow, neos_, _unoh,
  { {0x543306c6, 0x44240d82, 0x7d0d0052, 0x00000000}},  //   _فرور, qum_, vaas,
  { {0x3e580173, 0x7d0d00e7, 0x00000000, 0x00000000}},  //   _bčt_, waas,   ,
  { {0x63ba0161, 0x7a1c001a, 0x7d0d1151, 0x00000000}},  //   motn, nătă, taas,
  { {0x71a4025f, 0x63ba0059, 0x3253005e, 0x00000000}},  //   _најз, lotn, _хвър,
  { {0x2d58007c, 0x79820036, 0x7d0d0052, 0x00000000}},  // [1e30] щить_, dkow, raas,
  { {0x3e5801aa, 0x7d0d006c, 0x2d9e1152, 0x00000000}},  //   _fčt_, saas, éter_,
  { {0x27f80059, 0x3946008e, 0x644901a2, 0x00000000}},  //   _črna_, feos_, zwei,
  { {0x41c90183, 0xf1c90201, 0x63ba0161, 0x00000000}},  //   रतिस, रतिन, hotn,
  { {0x1869003b, 0x63ba0089, 0x00000000, 0x00000000}},  //   рали_, kotn,   ,
  { {0x36190057, 0xa09c0049, 0xb09c01ce, 0x00000000}},  //   ацию_, ניגט, ניגר,
  { {0x752900b5, 0xf1c90061, 0x3946008e, 0x00000000}},  //   tgez, रतान, beos_,
  { {0x64491153, 0xe579064b, 0x7bc500f8, 0x00000000}},  //   twei, рзи_, llhu,
  { {0x290f04d0, 0xe1010055, 0x61ea010f, 0x00000000}},  //   maga_, ্লাহ_, _aufl,
  { {0x290f006a, 0x6449001f, 0x7529059b, 0x00000000}},  //   laga_, rwei, sgez,
  { {0x6449001f, 0x76ab072b, 0x79891154, 0x00000000}},  //   swei, _став_, _klew,
  { {0x290f020c, 0x98a4002b, 0x00000000, 0x00000000}},  //   naga_, _qamħ_,   ,
  { {0x2bbe007d, 0x27fd01f3, 0x637f1155, 0x00000000}},  //   ्तमा, npwn_, _lêni,
  { {0x3e8a008b, 0x290f006c, 0x79890016, 0x00000000}},  //   айго_, haga_, _llew,
  { {0x290f006c, 0x79891156, 0xaf99041f, 0x00000000}},  //   kaga_, _olew, стях_,
  { {0x7242026c, 0x290f006c, 0xa3c30309, 0x00000000}},  //   _کھیل, jaga_, ्षक_,
  { {0x290f0ad1, 0x9f8400b0, 0xbcfb0068, 0x00000000}},  // [1e40] daga_, töä_, _inél,
  { {0x76410018, 0x3e5801aa, 0x79890a20, 0x00000000}},  //   _oply, _tčt_, _alew,
  { {0x79820046, 0xfce6003b, 0x61e4003c, 0x00000000}},  //   tkow, _моно, _kiil,
  { {0x5f4601ef, 0xed5a0057, 0x08c60769, 0x00000000}},  //   _انگل, _том_, обен,
  { {0x79821157, 0x61e41158, 0x394600dc, 0x00000000}},  //   rkow, _miil, reos_,
  { {0x39460211, 0x79820036, 0x39520006, 0x00000000}},  //   seos_, skow, žys_,
  { {0x63ba004f, 0x290f1159, 0x3946008e, 0x00000000}},  //   votn, baga_, peos_,
  { {0x6d560263, 0x61e400b0, 0x63ba0036, 0x00000000}},  //   ndya, _niil, wotn,
  { {0x7c3600eb, 0x61ea001a, 0x60c4115a, 0x00000000}},  //   ntyr, _sufl, _nyim,
  { {0xd37a08fc, 0xe72a02fd, 0x00000000, 0x00000000}},  //   рчи_, _خسرو_,   ,
  { {0x63ba0aa9, 0x32660088, 0x60cd115b, 0x00000000}},  //   rotn, ітов, _szam,
  { {0x63ba115c, 0x60c40045, 0xe5780089, 0x00000000}},  //   sotn, _byim, _puķu_,
  { {0x63ba0059, 0x9f4900c4, 0x1b110044, 0x00000000}},  //   potn, _itaú_, ালতে_,
  { {0x290f0569, 0x60cd0059, 0xa2940245, 0x00000000}},  //   zaga_, _vzam, _налі,
  { {0x290f0b5a, 0xdd9b025f, 0x61e4115d, 0x00000000}},  //   yaga_, аша_, _fiil,
  { {0x1b040055, 0x3f8307e0, 0x6e3500ea, 0x00000000}},  //   _লাগে_, skju_, rtzb,
  { {0x6ebb006e, 0x290f006c, 0x637f00c4, 0x00000000}},  // [1e50] _शुरु, vaga_, _sêni,
  { {0x290f0a71, 0x69c00d90, 0x637f00c4, 0x00000000}},  //   waga_, _akme, _pêni,
  { {0xdced0182, 0x290f011c, 0xdb07000c, 0x00000000}},  //   ljač, taga_, _skjó,
  { {0x2009115e, 0xc9840437, 0x00000000, 0x00000000}},  //   _kwai_, мучи,   ,
  { {0x290f115f, 0x6446005f, 0xa804008b, 0x00000000}},  //   raga_, çkil, дзіл,
  { {0x290f069e, 0x637f0181, 0x69c0014a, 0x00000000}},  //   saga_, _têni, _ekme,
  { {0x64421160, 0xf96b09b2, 0x290f010e, 0x00000000}},  //   _apoi, _край_, paga_,
  { {0xe795089d, 0x64420051, 0x799b011c, 0x00000000}},  //   _کارک, _bpoi, _umuw,
  { {0xdced0091, 0xc9520104, 0x68e901f3, 0x00000000}},  //   jjač, _אמן_, _iged,
  { {0x69d900b4, 0x61e401b1, 0x00000000, 0x00000000}},  //   lmwe, _siil,   ,
  { {0x4b7c007b, 0x61e40103, 0x69d91161, 0x00000000}},  //   יאזו, _piil, omwe,
  { {0x644f0030, 0xe802013d, 0x7c360023, 0x00000000}},  //   æcis, रीका_, ytyr,
  { {0x61e41162, 0xe5c4007e, 0x64421163, 0x00000000}},  //   _viil, _ўсхо, _gpoi,
  { {0x2d8b0555, 0x2215005e, 0x00000000, 0x00000000}},  //   _alce_, _ефир,   ,
  { {0x63a1002b, 0x61e40052, 0x00000000, 0x00000000}},  //   miln, _tiil,   ,
  { {0x68e91164, 0x63a10059, 0xf6520049, 0x00000000}},  //   _nged, liln, עצן_,
  { {0x27ed022b, 0x8b26007e, 0x27f80059, 0x00000000}},  // [1e60] _nuen_, здзе, _črno_,
  { {0x63a100ca, 0x68e91165, 0x69c00145, 0x00000000}},  //   niln, _aged, _skme,
  { {0x7c360018, 0x6ac60025, 0x5eda0044, 0x00000000}},  //   styr, أقام, _ব্রে,
  { {0x27ed0219, 0x290d000d, 0x7e610030, 0x00000000}},  //   _buen_, _ceea_, ælpe,
  { {0xa3cb02d2, 0x63a1010a, 0x7d041166, 0x00000000}},  //   लता_, kiln, mbis,
  { {0x27ed022b, 0x69d90455, 0x26c51167, 0x00000000}},  //   _duen_, amwe, _bylo_,
  { {0x63a11168, 0x68ed1169, 0xaa430364, 0x00000000}},  //   diln, žada, _перл,
  { {0x7f8b005f, 0xb60800b9, 0x69c00006, 0x00000000}},  //   _müqa, jišť, _ukme,
  { {0x63a10062, 0xdb05008e, 0x7d04116a, 0x00000000}},  //   filn, cohó, ibis,
  { {0x57fb009b, 0x7d040433, 0xfbbe0164, 0x00000000}},  //   _ללמו, hbis, ्तिम,
  { {0x27ed022b, 0x200900e7, 0x00000000, 0x00000000}},  //   _zuen_, _swai_,   ,
  { {0x7c24116b, 0x27ed0085, 0x00000000, 0x00000000}},  //   krir, _yuen_,   ,
  { {0x63a107e4, 0x777a002d, 0x5334007c, 0x00000000}},  //   biln, _kotx, _желт,
  { {0xdced016c, 0x00000000, 0x00000000, 0x00000000}},  //   rjač,   ,   ,
  { {0x433b00b6, 0x777a0c2f, 0xe3b30049, 0x00000000}},  //   _העוב, _motx, _אױס_,
  { {0x7c240207, 0x7d04011c, 0x442402d1, 0x00000000}},  //   frir, gbis, orm_,
  { {0x7c2401ed, 0xb60604eb, 0x00000000, 0x00000000}},  // [1e70] grir, lošć,   ,
  { {0x44240051, 0xeb9b0084, 0xdcef00e5, 0x00000000}},  //   irm_, حضرت_, _bocă,
  { {0x7d04116c, 0x7c240197, 0xb60604eb, 0x00000000}},  //   bbis, arir, nošć,
  { {0xdb1c0048, 0xf1bf00fa, 0x00000000, 0x00000000}},  //   _bhró, noá_,   ,
  { {0xdb17049a, 0x27ed116d, 0x98c70025, 0x00000000}},  //   loxí, _quen_, أغان,
  { {0x777a0129, 0x3dc910a5, 0x44240022, 0x00000000}},  //   _cotx, llaw_, drm_,
  { {0x63a101d9, 0xb606016c, 0x7d0f0010, 0x00000000}},  //   viln, jošć, _kecs,
  { {0x4975007e, 0x63a10036, 0x3dc90058, 0x00000000}},  //   _ўлас, wiln, nlaw_,
  { {0x63a10059, 0x69c3009d, 0x753b031a, 0x00000000}},  //   tiln, îneu, rfuz,
  { {0x645b00bb, 0x7d04116e, 0x7d0f0010, 0x00000000}},  //   rvui, zbis, _lecs,
  { {0x63a10059, 0xa91d0bf8, 0x65790600, 0x00000000}},  //   riln, _alži, _towh,
  { {0x7c24000c, 0x62810ad0, 0x7d0f00e5, 0x00000000}},  //   yrir, rylo, _necs,
  { {0x63a10dec, 0x3dc900e0, 0x31690288, 0x00000000}},  //   piln, dlaw_, _dnaz_,
  { {0x7c24116f, 0x25bf0a86, 0xf8ab0082, 0x00000000}},  //   vrir, loul_, _đời_,
  { {0x25ad0030, 0x7d040bb4, 0x7d0f1170, 0x00000000}},  //   onel_, tbis, _becs,
  { {0x25ad0549, 0x7c240065, 0x7f8b006b, 0x00000000}},  //   nnel_, trir, _vüqa,
  { {0x7d041171, 0xdca30bbd, 0x7c24115f, 0x00000000}},  // [1e80] rbis, вати, urir,
  { {0x7c24022b, 0x25bf000a, 0x00000000, 0x00000000}},  //   rrir, houl_,   ,
  { {0x3dc90016, 0x00000000, 0x00000000, 0x00000000}},  //   blaw_,   ,   ,
  { {0x7c240207, 0xdb1c0051, 0x3dc90051, 0x00000000}},  //   prir, _phró, claw_,
  { {0xb8f602d2, 0x25bf1172, 0x00000000, 0x00000000}},  //   _हर_, doul_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f8d000c, 0x00000000, 0x00000000, 0x00000000}},  //   nþá_,   ,   ,
  { {0xbf0a0061, 0x442400d9, 0x545400e2, 0x00000000}},  //   वरुन_, trm_, евит,
  { {0x29060020, 0x777a00d4, 0x660d016c, 0x00000000}},  //   mboa_, _totx, ćaka,
  { {0x4274007c, 0x2b580087, 0x00000000, 0x00000000}},  //   егос, _jarc_,   ,
  { {0x2b580129, 0x25bf1173, 0x32180161, 0x00000000}},  //   _marc_, boul_, éry_,
  { {0xc48601fb, 0xe4a6003b, 0xb606016c, 0x00000000}},  //   _олек, _орло, rošć,
  { {0xbf0a001c, 0xa3e703d7, 0xc0580245, 0x00000000}},  //   वरून_, _मंच_, мір_,
  { {0x0efb02fb, 0x47cc0044, 0x2b5809cc, 0x00000000}},  //   ्रेस_, াদকী, _narc_,
  { {0x3ceb1174, 0xf1bf00fa, 0x3dc90133, 0x00000000}},  //   _pgcv_, poá_, tlaw_,
  { {0xcdd8003b, 0x637f01c3, 0x00000000, 0x00000000}},  //   дњу_, _fêns,   ,
  { {0x7d0f0ede, 0x7d02008e, 0x2b58005b, 0x00000000}},  // [1e90] _vecs, ñosa, _barc_,
  { {0x8cd00061, 0xf4000044, 0x00000000, 0x00000000}},  //   _दररो, _এটার_,   ,
  { {0x7d0f005b, 0x2b5800fa, 0xdb1c0045, 0x00000000}},  //   _tecs, _darc_, _phrò,
  { {0x645c0089, 0x2d9201aa, 0x25f2013d, 0x00000000}},  //   ārij, chye_, ँदनी_,
  { {0x2b580b33, 0x201900b0, 0x6cfa00b3, 0x00000000}},  //   _farc_, nssi_, _מפרס,
  { {0x237c0521, 0x7c2d1175, 0x2b58004a, 0x00000000}},  //   _novj_, muar, _garc_,
  { {0x7c2d020c, 0x2bbe006e, 0x199500a5, 0x00000000}},  //   luar, ्तरा, _завя,
  { {0xc867005e, 0x290600f6, 0x00000000, 0x00000000}},  //   _отзи, cboa_,   ,
  { {0x25bf001a, 0x00000000, 0x00000000, 0x00000000}},  //   roul_,   ,   ,
  { {0x25ad0f46, 0x25bf1176, 0x69cb1177, 0x00000000}},  //   snel_, soul_, llge,
  { {0x25ad1178, 0x7c2d006c, 0x69cb0007, 0x00000000}},  //   pnel_, huar, olge,
  { {0x7c2d1179, 0xa3cf007d, 0x00000000, 0x00000000}},  //   kuar, _वीर_,   ,
  { {0x656b0375, 0xbcfb0051, 0x7c2d0065, 0x00000000}},  //   _ingh, _gnéi, juar,
  { {0xdb1e0065, 0x7c2d117a, 0x6d4d00e0, 0x00000000}},  //   ropë, duar, eeaa,
  { {0x442d0472, 0x20190026, 0x3c430089, 0x00000000}},  //   lue_, assi_, hīvā_,
  { {0x7c2d0048, 0x52740025, 0x00000000, 0x00000000}},  //   fuar, _جاهز,   ,
  { {0x2b5800f6, 0x7c2d0198, 0x442d030a, 0x00000000}},  // [1ea0] _parc_, guar, nue_,
  { {0x2d920061, 0x68fb000a, 0xe0d7007e, 0x00000000}},  //   shye_, _afud, _явы_,
  { {0xa926007c, 0x27ff0e65, 0x3ea600e2, 0x00000000}},  //   едел, _atun_, _чинг,
  { {0x442d117b, 0xb17b0039, 0x7c2d0023, 0x00000000}},  //   kue_, rmåg, buar,
  { {0xc7c601f9, 0x7c2d0f6a, 0x6e2e01bf, 0x00000000}},  //   нски, cuar, lubb,
  { {0x7d16117c, 0x656b117d, 0xfaa60069, 0x00000000}},  //   lays, _angh, _заго,
  { {0x442d009d, 0x21200022, 0xb81c0316, 0x00000000}},  //   eue_, _odih_, _निकम_,
  { {0x09e30098, 0x7d16011c, 0x442d00ea, 0x00000000}},  //   _босн, nays, fue_,
  { {0x6e2e0270, 0x98af007f, 0x00000000, 0x00000000}},  //   hubb, degė_,   ,
  { {0x656b018e, 0x5c370049, 0x2120000a, 0x00000000}},  //   _engh, ערין_, _adih_,
  { {0x7c2d1179, 0xbcfb009d, 0x2c520173, 0x00000000}},  //   zuar, _inév, _lņd_,
  { {0x6e2e1054, 0x442d117e, 0xdce60173, 0x00000000}},  //   dubb, bue_, _ankč,
  { {0x442d009d, 0x7c2d117f, 0xf1a4007e, 0x00000000}},  //   cue_, xuar, урэн,
  { {0x20190bac, 0x7c2d0023, 0x00000000, 0x00000000}},  //   rssi_, vuar,   ,
  { {0x656b018e, 0x6f150059, 0x6e2e0d47, 0x00000000}},  //   _yngh, razc, gubb,
  { {0x7c2201d5, 0x7c2d0238, 0x40950025, 0x00000000}},  //   ġorn, tuar, _للبر,
  { {0xb81c013d, 0x00000000, 0x00000000, 0x00000000}},  // [1eb0] _निगम_,   ,   ,
  { {0x6e2e0209, 0x7c2d1180, 0x3df50f93, 0x00000000}},  //   bubb, ruar, _изос,
  { {0x7d160061, 0x442d022b, 0x6d4d0961, 0x00000000}},  //   bays, zue_, peaa,
  { {0x3c430089, 0xa91d0059, 0x27ff0093, 0x00000000}},  //   tīvā_, _možg, _ptun_,
  { {0x7c2d0d87, 0xe10c0049, 0x442d1181, 0x00000000}},  //   quar, פּאָ, xue_,
  { {0x442d00f4, 0xa3cf013d, 0xf74501bd, 0x00000000}},  //   vue_, _वीं_, теко,
  { {0xead4007c, 0x00000000, 0x00000000, 0x00000000}},  //   _борь,   ,   ,
  { {0x442d00f4, 0x0565030d, 0x68fb005b, 0x00000000}},  //   tue_, твин, _ufud,
  { {0xe4320025, 0x00000000, 0x00000000, 0x00000000}},  //   لفيد,   ,   ,
  { {0x394f1182, 0x260e0061, 0xdb1e1183, 0x00000000}},  //   legs_, णीही_, topé,
  { {0x442d0038, 0x2000001a, 0x36750025, 0x00000000}},  //   sue_, _stii_, _جهاز,
  { {0xdb1e1184, 0x656b0412, 0x00000000, 0x00000000}},  //   ropé, _ungh,   ,
  { {0x442d032c, 0x8edf0055, 0x7bde0161, 0x00000000}},  //   que_, _ব্লগ, ympu,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6da600ed, 0x7d02004a, 0x00000000, 0x00000000}},  //   вива, ñoso,   ,
  { {0x12e80049, 0x320500ab, 0xdd920445, 0x00000000}},  //   _אַפּ, mply_, جور_,
  { {0xa91d0119, 0x2bf6007c, 0x6e2e0093, 0x00000000}},  // [1ec0] _možd, тябр, subb,
  { {0x6e2e01bc, 0x7d16006a, 0xaf0a0025, 0x00000000}},  //   pubb, says, _تقدم_,
  { {0x7d16009d, 0x00000000, 0x00000000, 0x00000000}},  //   pays,   ,   ,
  { {0x637e00b9, 0x00000000, 0x00000000, 0x00000000}},  //   _záně,   ,   ,
  { {0xe94700a1, 0xfbd100a1, 0xd90d009e, 0x00000000}},  //   ئرمی, شتے_, ثیق_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6ae00055, 0x98b2014a, 0x00000000, 0x00000000}},  //   _প্রো, ıyı_,   ,
  { {0x80d30061, 0x00000000, 0x00000000, 0x00000000}},  //   _ठरले,   ,   ,
  { {0xdb1c00b9, 0x00000000, 0x00000000, 0x00000000}},  //   _zkrá,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc56a0025, 0x00000000, 0x00000000, 0x00000000}},  //   _يحصل_,   ,   ,
  { {0x316d04a8, 0xfbdf0016, 0x00000000, 0x00000000}},  //   ñez_, _apêl_,   ,
  { {0x60d60036, 0x94760025, 0x9054007e, 0x00000000}},  //   _czym, _جداا, авяц,
  { {0x547b00b6, 0x32660264, 0x9e350a78, 0x00000000}},  //   _קטגו, _атив, легч,
  { {0xdb06013e, 0x00000000, 0x00000000, 0x00000000}},  //   ámýc,   ,   ,
  { {0x7bc705cb, 0x6288005b, 0xa91d0161, 0x00000000}},  //   _skju, mydo, _kože,
  { {0xdb1c1185, 0xfbd907d8, 0x6288007f, 0x00000000}},  // [1ed0] _skrá, едај_, lydo,
  { {0xa91d0119, 0x8f5501fb, 0x63a800e0, 0x00000000}},  //   _može, _свої, nidn,
  { {0x61ed1186, 0x75221187, 0x7ac4007e, 0x00000000}},  //   _kial, _odoz, асце,
  { {0x61ed0022, 0x798010e4, 0xafdb0190, 0x00000000}},  //   _jial, _comw, stød,
  { {0xa3c2001c, 0x6d5d0051, 0x61ed0036, 0x00000000}},  //   ंवा_, _iasa, _mial,
  { {0x75221188, 0x61ed1189, 0xab8401ab, 0x00000000}},  //   _adoz, _lial, _куск,
  { {0x6d5d0811, 0xe5a5019d, 0x27ec00ab, 0x00000000}},  //   _kasa, лики, _didn_,
  { {0xe459005e, 0x6d5d002d, 0x60cd118a, 0x00000000}},  //   ежи_, _jasa, _oyam,
  { {0x6d5d0d56, 0xa91d01ee, 0x69c90058, 0x00000000}},  //   _masa, _vožd, _ikee,
  { {0x6d5d118b, 0x7522022b, 0x2bd9013d, 0x00000000}},  //   _lasa, _edoz, _बीमा,
  { {0x61ed0a49, 0x60d60036, 0xe7840072, 0x00000000}},  //   _bial, _szym, _туто,
  { {0x61ed118c, 0x6d5d006a, 0x60cd0009, 0x00000000}},  //   _cial, _nasa, _byam,
  { {0x34390049, 0x7bc5006c, 0x60cd0009, 0x00000000}},  //   _נײַע, kohu, _cyam,
  { {0x94740879, 0x443f118d, 0x32050837, 0x00000000}},  //   _خدما, mtu_, pply_,
  { {0x6d5d006a, 0x62880036, 0x22580030, 0x00000000}},  //   _basa, cydo, ærkt_,
  { {0x6d5d00d6, 0x61ed0207, 0xed57007c, 0x00000000}},  //   _casa, _gial, лос_,
  { {0x6d5d020c, 0xbcfb00f6, 0x20040051, 0x00000000}},  // [1ee0] _dasa, _anés, ímid_,
  { {0x443f0288, 0xa09b01ce, 0x69c9118e, 0x00000000}},  //   itu_, _נייט, _akee,
  { {0x443f118f, 0x69db0051, 0x00000000, 0x00000000}},  //   htu_, _bhue,   ,
  { {0x69db001c, 0x644b0030, 0x8d560072, 0x00000000}},  //   _chue, _opgi, _сточ,
  { {0x443f1190, 0xa2ca007d, 0x8eb30014, 0x00000000}},  //   jtu_, _सुन्, _نمیش,
  { {0x6d5d1191, 0xdb1c0698, 0xcb76003b, 0x00000000}},  //   _zasa, _skræ, _сумњ,
  { {0x6d5d011f, 0xbb3b01ce, 0x56941192, 0x00000000}},  //   _yasa, _רעלי, райт,
  { {0xa91d0091, 0x7df50006, 0x77920014, 0x00000000}},  //   _pože, _sąsk, _گیتا,
  { {0x61ed002a, 0x63a80039, 0x2d8200ca, 0x00000000}},  //   _rial, tidn, _moke_,
  { {0x61ed005b, 0xa91d0a0f, 0x2d821092, 0x00000000}},  //   _sial, _vože, _loke_,
  { {0x61ed0169, 0x443f002d, 0x60cd04be, 0x00000000}},  //   _pial, atu_, _syam,
  { {0x443f0169, 0x3f811193, 0x62881194, 0x00000000}},  //   btu_, _sohu_, rydo,
  { {0x629a0e17, 0x6d5d0127, 0x61ed0207, 0x00000000}},  //   szto, _rasa, _vial,
  { {0x60cd0020, 0x6d5d1084, 0xd3700025, 0x00000000}},  //   _vyam, _sasa, _ذهب_,
  { {0xcddb03f3, 0x6d4403c5, 0x61ed0275, 0x00000000}},  //   ења_, ffia, _tial,
  { {0x7ae11195, 0x2d580e09, 0x2d8201a3, 0x00000000}},  //   _últi, лись_, _coke_,
  { {0x6d5d0a5c, 0x5b150242, 0x65600051, 0x00000000}},  // [1ef0] _vasa, имат, idmh,
  { {0x6d5d1196, 0x7bdc1197, 0x69c90160, 0x00000000}},  //   _wasa, _chru, _skee,
  { {0x6d5d1198, 0x443f022b, 0x2cae005f, 0x00000000}},  //   _tasa, ztu_, _əldə_,
  { {0x6d5d0051, 0xbcfb004a, 0x64400a2f, 0x00000000}},  //   _uasa, _enér, ktmi,
  { {0x443f01ca, 0x99870010, 0xb8fd006e, 0x00000000}},  //   xtu_, énő_, _डर_,
  { {0x8ae70822, 0x7d0d0190, 0x660500ed, 0x00000000}},  //   _бібл, lbas, апка,
  { {0x69db1199, 0x7d0d0288, 0x01d60044, 0x00000000}},  //   _thue, obas, _সংসদ,
  { {0x443f0f3c, 0x7c2d0207, 0x1425007c, 0x00000000}},  //   ttu_, orar, адим,
  { {0x99840054, 0x4375005e, 0x765a0016, 0x00000000}},  //   _القو, аунт, _esty,
  { {0x443f119a, 0x395f010f, 0x657b01c2, 0x00000000}},  //   rtu_, _haus_, sjuh,
  { {0x443f009f, 0x659503e0, 0xe10a026b, 0x00000000}},  //   stu_, _кажу, кенд_,
  { {0x9f49009f, 0x443f0209, 0x7c2d049d, 0x00000000}},  //   _stað_, ptu_, krar,
  { {0x7d0d0146, 0x2d820059, 0x395f119b, 0x00000000}},  //   dbas, _roke_, _maus_,
  { {0x765a018e, 0x23290088, 0x7c2d119c, 0x00000000}},  //   _ysty, _роки_, drar,
  { {0xdee60407, 0xeab00055, 0xa3c2024c, 0x00000000}},  //   рови, _কর্ম, ंवर_,
  { {0x442d0198, 0x7d0d119d, 0x395f00d4, 0x00000000}},  //   ore_, gbas, _naus_,
  { {0x442d00f4, 0x6d44119e, 0xed5700e2, 0x00000000}},  // [1f00] nre_, rfia, шот_,
  { {0x442d119f, 0x7d0d11a0, 0x3160002d, 0x00000000}},  //   ire_, abas, _haiz_,
  { {0x6f1c04bd, 0x442d001f, 0x7d0d0039, 0x00000000}},  //   marc, hre_, bbas,
  { {0x442d0e58, 0x7c2d00ab, 0xdb1c0039, 0x00000000}},  //   kre_, brar, _skrä,
  { {0x7c2d001a, 0x442d0030, 0x4bd100a1, 0x00000000}},  //   crar, jre_, _کےلئ,
  { {0x442d02cc, 0x7df50fed, 0x6f1c0122, 0x00000000}},  //   dre_, _sąsi, narc,
  { {0x442d0555, 0xd5ba00e3, 0x660300ed, 0x00000000}},  //   ere_, кси_, опја,
  { {0x442d11a1, 0x3160022b, 0x6f1c0051, 0x00000000}},  //   fre_, _naiz_, harc,
  { {0x6fc60061, 0x3e5801aa, 0x57ea0bb8, 0x00000000}},  //   लकां, _lōt_, _адам_,
  { {0x46a60265, 0x937800ed, 0x883b009b, 0x00000000}},  //   _казв, убот_, _בתמו,
  { {0x6440006c, 0x321e11a2, 0x442d11a3, 0x00000000}},  //   stmi, usty_, are_,
  { {0x442d11a4, 0x044600e3, 0x6f170240, 0x00000000}},  //   bre_, _ведн, _sexc,
  { {0x6f1c0544, 0x442d00f4, 0x2fc70011, 0x00000000}},  //   farc, cre_, _ưng_,
  { {0x6f1c027b, 0x7c2d03c7, 0xa91d11a5, 0x00000000}},  //   garc, vrar, _moža,
  { {0x31600180, 0xa91d016c, 0xbe8811a6, 0x00000000}},  //   _faiz_, _loža, асте_,
  { {0xf27b0452, 0x527b0104, 0x31600288, 0x00000000}},  //   _ירוש, _ינוא, _gaiz_,
  { {0x7d0d11a7, 0xdce60006, 0x395f010f, 0x00000000}},  // [1f10] rbas, _mokė, _raus_,
  { {0x7c2d11a8, 0x6f1c001a, 0x7d0d00ea, 0x00000000}},  //   rrar, carc, sbas,
  { {0x395f00f8, 0x7d0d0e9c, 0x442d0010, 0x00000000}},  //   _paus_, pbas, zre_,
  { {0x442d11a9, 0xa91d0825, 0x7c2d007f, 0x00000000}},  //   yre_, _boža, prar,
  { {0x4dda009b, 0x67d500ed, 0x9f4007f0, 0x00000000}},  //   _תחרו, боду, _guió_,
  { {0x442d028c, 0x6747007e, 0xd8740014, 0x00000000}},  //   vre_, рэдз, تامب,
  { {0xa6c903c8, 0x3618008b, 0xaa950025, 0x00000000}},  //   ылка_, ацыю_, _الأث,
  { {0x442d0a8d, 0xa2c10061, 0xa3cf0061, 0x00000000}},  //   tre_, _रुग्, _वीज_,
  { {0x442d03d5, 0x7f8b005f, 0x291d006a, 0x00000000}},  //   ure_, _hüqu, mawa_,
  { {0x291d006a, 0x61f80521, 0x316001a3, 0x00000000}},  //   lawa_, _buvl, _saiz_,
  { {0x442d0047, 0xa2ca0061, 0x6f1c0e1c, 0x00000000}},  //   sre_, _सुद्, varc,
  { {0x442d11aa, 0x291d006a, 0x568c007b, 0x00000000}},  //   pre_, nawa_, _שטאַ,
  { {0x7dfc01aa, 0xa4d40088, 0xafe60088, 0x00000000}},  //   _pčso, _доці, йомл,
  { {0x291d0127, 0xafe60d51, 0xb17b0c73, 0x00000000}},  //   hawa_, согл, lmål,
  { {0x291d0e74, 0x2d960930, 0x00000000, 0x00000000}},  //   kawa_, брас,   ,
  { {0x6f1c0412, 0x291d00e7, 0xb17b0ccc, 0x00000000}},  //   sarc, jawa_, nmål,
  { {0x6f1c11ab, 0xdd8f0025, 0xcaf60025, 0x00000000}},  // [1f20] parc, روك_, مساب,
  { {0xc4d208cd, 0x3b18002b, 0x00000000, 0x00000000}},  //   לגן_, _qerq_,   ,
  { {0x25ad11ac, 0xdb070047, 0xb17b043e, 0x00000000}},  //   kiel_, ámár, kmål,
  { {0x291d11ad, 0xa91d11ae, 0x38cb00a6, 0x00000000}},  //   gawa_, _poža, گامی_,
  { {0x53c702f4, 0x25ad0027, 0xb5fc002b, 0x00000000}},  //   रकाश, diel_, _irġi,
  { {0x9b960025, 0x6d56006b, 0xaa0800a1, 0x00000000}},  //   _الست, leya, _نعرے_,
  { {0x25ad02ae, 0x3a210061, 0x291d033b, 0x00000000}},  //   fiel_, cshp_, bawa_,
  { {0x2d8001d6, 0xd943017a, 0x1dc80061, 0x00000000}},  //   njie_, _неси, लवित,
  { {0x764310ed, 0xa91d047c, 0x61f811af, 0x00000000}},  //   atny, _kožn, _suvl,
  { {0x5c5b0476, 0x388e0089, 0x00000000, 0x00000000}},  //   נדיק, _vērā_,   ,
  { {0xa91d11b0, 0x25ad0250, 0xcb1300b3, 0x00000000}},  //   _možn, biel_, הלת_,
  { {0x25ad11b1, 0xa91d00b9, 0x7df50006, 0x00000000}},  //   ciel_, _ložn, _mąst,
  { {0x2d800007, 0x23e601e1, 0x7df50006, 0x00000000}},  //   djie_, _лікв, _ląst,
  { {0x291d0046, 0xdbf10224, 0x92940893, 0x00000000}},  //   zawa_, _příl, _малц,
  { {0x656200e0, 0x04b700a1, 0x291d05cd, 0x00000000}},  //   _kaoh, _نھیں_, yawa_,
  { {0x2d800023, 0x00000000, 0x00000000, 0x00000000}},  //   gjie_,   ,   ,
  { {0x4dd40025, 0x656211b2, 0x21290145, 0x00000000}},  // [1f30] ستفس, _maoh, _idah_,
  { {0xdea401ef, 0x291d09bd, 0x25ad0e42, 0x00000000}},  //   _کیفی, wawa_, ziel_,
  { {0x291d03b0, 0x9f84006c, 0xdab90025, 0x00000000}},  //   tawa_, töö_, جهات_,
  { {0x291d0020, 0xe3b8006b, 0x8f5500a2, 0x00000000}},  //   uawa_, hnı_, _انگش,
  { {0xf77006c6, 0x25ad010f, 0x2d99046a, 0x00000000}},  //   کان_, viel_, _ilse_,
  { {0x291d11b3, 0x7761006b, 0x5fc90061, 0x00000000}},  //   sawa_, _qalx, ळविल,
  { {0x1995007e, 0x291d11b4, 0x25ad0253, 0x00000000}},  //   _давя, pawa_, tiel_,
  { {0x7d1f0023, 0x764311b5, 0x200901a3, 0x00000000}},  //   naqs, rtny, _otai_,
  { {0x69cb00b5, 0x25ad028c, 0xb17b11b6, 0x00000000}},  //   moge, riel_, rmål,
  { {0x42250088, 0x249f11b7, 0xb17b11b8, 0x00000000}},  //   одов, rzum_, smål,
  { {0x80d10055, 0x25ad010f, 0x09b50049, 0x00000000}},  //   সেম্, piel_, ַפֿט_,
  { {0x2d9900d9, 0x00000000, 0x00000000, 0x00000000}},  //   _nlse_,   ,   ,
  { {0x6d560e9e, 0xb5c80014, 0x00000000, 0x00000000}},  //   veya, _اونم_,   ,
  { {0x6d560022, 0xaab9013d, 0x2d9900f6, 0x00000000}},  //   weya, _आशंक, _alse_,
  { {0x59c902fb, 0x2d800343, 0xa91d11b9, 0x00000000}},  //   िकार, tjie_, _rožn,
  { {0x753b000b, 0x69cb01ee, 0x7df5007f, 0x00000000}},  //   nguz, joge, _rąst,
  { {0x3b86005e, 0x6d5611ba, 0x8c4300ed, 0x00000000}},  // [1f40] олаг, reya, мете,
  { {0x2d990406, 0x6d5601aa, 0x394d0145, 0x00000000}},  //   _else_, seya, _abes_,
  { {0xe8fa0072, 0xa91d0f3a, 0x6d5611bb, 0x00000000}},  //   але_, _vožn, peya,
  { {0x69cb00eb, 0xfd120025, 0x7d1f006b, 0x00000000}},  //   goge, _تجد_, caqs,
  { {0x7d0411bc, 0xa91d0059, 0x386d00c4, 0x00000000}},  //   mcis, _tožn, _crer_,
  { {0x7c240051, 0x7d0411bd, 0xf0930104, 0x00000000}},  //   msir, lcis, ונד_,
  { {0x69cb0c53, 0x41ca0164, 0x7c240d61, 0x00000000}},  //   boge, रवास, lsir,
  { {0x69cb0211, 0x0d970049, 0x386d000a, 0x00000000}},  //   coge, ַכים_, _frer_,
  { {0x7c240363, 0xdb1e0030, 0xc31e0044, 0x00000000}},  //   nsir, ropæ, _দাবি_,
  { {0x7792007a, 0x7c2411be, 0x21290085, 0x00000000}},  //   _زیبا, isir, _sdah_,
  { {0x200911bf, 0x8afb0049, 0x7dfc0173, 0x00000000}},  //   _stai_, יליז, _dčsk,
  { {0x96330245, 0x7c240145, 0xa1940245, 0x00000000}},  //   _ініц, ksir, даюч,
  { {0x48b80044, 0xa2ca007d, 0x78a20161, 0x00000000}},  //   _জরুর, _सुर्, nzov,
  { {0x09b70164, 0xc05801fb, 0x69cb010f, 0x00000000}},  //   _अद्य, цію_, zoge,
  { {0x7c2603b1, 0x212900d6, 0x8d770025, 0x00000000}},  //   _avkr, _tdah_, يارا,
  { {0x7c24000b, 0x21290762, 0x752000e7, 0x00000000}},  //   fsir, _udah_, namz,
  { {0x69cb054e, 0x1b1f0044, 0x442601ee, 0x00000000}},  // [1f50] voge, _পাবে_, _jvo_,
  { {0x09b30365, 0x63ba010f, 0x69cb11c0, 0x00000000}},  //   ंच्य, nntn, woge,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x442601cd, 0x7d040026, 0x00000000, 0x00000000}},  //   _ovo_, ccis,   ,
  { {0x18690175, 0x442611c1, 0x6c790049, 0x00000000}},  //   сали_, _nvo_, _האָפ,
  { {0xbdf800a6, 0x7d1d010f, 0x69cb11c2, 0x00000000}},  //   _دریا_, _hess, soge,
  { {0x69cb00ea, 0x442605e0, 0x29dc11c3, 0x00000000}},  //   poge, _avo_, mían_,
  { {0xc4850331, 0x29dc11c4, 0x386d00ea, 0x00000000}},  //   злик, lían_, _trer_,
  { {0x7d1d11c5, 0x93790025, 0xe3b10355, 0x00000000}},  //   _mess, مصدر_, فرد_,
  { {0xf8ae00e9, 0x29dc0211, 0x798901b5, 0x00000000}},  //   _حکم_, nían_, _hoew,
  { {0x44260119, 0x6d4f0a32, 0x216a017f, 0x00000000}},  //   _evo_, _obca, бини_,
  { {0x7d1d024e, 0xe6100014, 0x00000000, 0x00000000}},  //   _ness, _ششم_,   ,
  { {0xb4fa00b6, 0x92b50123, 0x764b0006, 0x00000000}},  //   _הפני, تحکا, žnyč,
  { {0x7c24001c, 0x6dac014a, 0x798901a2, 0x00000000}},  //   vsir, rşam, _loew,
  { {0x7d1d001f, 0x29dc008e, 0x2d9607d0, 0x00000000}},  //   _bess, dían_, прас,
  { {0x7d1d11c6, 0xb88301dc, 0x91e3005e, 0x00000000}},  //   _cess, _klíč, _поще,
  { {0x7d0400ab, 0xe3190082, 0x21220068, 0x00000000}},  // [1f60] rcis, _điể, makh_,
  { {0x7c2401a3, 0xa01b00b0, 0x6d4f11c7, 0x00000000}},  //   rsir, pyör, _ebca,
  { {0x4efb00b6, 0x7c240acc, 0xc33200b6, 0x00000000}},  //   _להיו, ssir, תוב_,
  { {0x7d1d11c8, 0x7c2411c9, 0x44240133, 0x00000000}},  //   _gess, psir, ysm_,
  { {0x29dc0211, 0x7c2411ca, 0x61e40051, 0x00000000}},  //   bían_, qsir, _mhil,
  { {0xc7a303f3, 0x07a3012b, 0x29dc0211, 0x00000000}},  //   ничк, начн, cían_,
  { {0x44260359, 0xdb1e010f, 0x7d1d0145, 0x00000000}},  //   _svo_, ropä, _yess,
  { {0x2abb009b, 0x442611cb, 0x798901d6, 0x00000000}},  //   _המלא, _pvo_, _goew,
  { {0x3a3a01d5, 0xa507003b, 0x75200ba5, 0x00000000}},  //   lupp_, чења_, ramz,
  { {0xe44f0b59, 0x44260640, 0x00000000, 0x00000000}},  //   اضي_, _vvo_,   ,
  { {0x61e40048, 0x44240fd1, 0x00000000, 0x00000000}},  //   _bhil, ssm_,   ,
  { {0x61e409d9, 0x4426000c, 0x00000000, 0x00000000}},  //   _chil, _tvo_,   ,
  { {0x7d1d028c, 0xa91d11cc, 0x442611cd, 0x00000000}},  //   _ress, _božj, _uvo_,
  { {0x60c40009, 0x64470035, 0x61e40026, 0x00000000}},  //   _dxim, ăjit, _ehil,
  { {0x7d1d02d5, 0xd3e501ef, 0x29dc008e, 0x00000000}},  //   _pess, _تقوی, vían_,
  { {0x61e40035, 0x5d6402dc, 0x00000000, 0x00000000}},  //   _ghil, нтуз,   ,
  { {0x79890022, 0x29dc008e, 0x6ecd0309, 0x00000000}},  // [1f70] _roew, tían_, _दुरु,
  { {0x7d1d0168, 0x798911ce, 0x7e610190, 0x00000000}},  //   _wess, _soew, ælps,
  { {0x7d1d054f, 0x29dc0211, 0xecf90451, 0x00000000}},  //   _tess, rían_, _менш_,
  { {0xafdb00ea, 0x61e40023, 0x00000000, 0x00000000}},  //   ktøk, _xhil,   ,
  { {0xa3c10061, 0x6d4d0022, 0x00000000, 0x00000000}},  //   ्कम_, mfaa,   ,
  { {0x2d8b11cf, 0x6d4d04fd, 0x00000000, 0x00000000}},  //   _hoce_, lfaa,   ,
  { {0x6b83000c, 0x79890116, 0xc7c8007e, 0x00000000}},  //   öngu, _toew, чыце_,
  { {0x6d4d11d0, 0x2409007c, 0x799b0022, 0x00000000}},  //   nfaa, онии_, _uluw,
  { {0xd469007c, 0xafdb0190, 0x00000000, 0x00000000}},  //   ципе_, rtøj,   ,
  { {0x61e40020, 0x69d9010f, 0x9f53009d, 0x00000000}},  //   _shil, llwe, _fixé_,
  { {0x67230340, 0x95cb0954, 0x00000000, 0x00000000}},  //   manj, _луда_,   ,
  { {0x67230149, 0x2d8b07ad, 0x6f1e00e5, 0x00000000}},  //   lanj, _noce_, _sepc,
  { {0xbf090061, 0x81c20044, 0x291f00d4, 0x00000000}},  //   वडून_, ্গল_, _meua_,
  { {0x61e40038, 0x656911d1, 0x672311d2, 0x00000000}},  //   _whil, ldeh, nanj,
  { {0x2d8b0166, 0x00000000, 0x00000000, 0x00000000}},  //   _boce_,   ,   ,
  { {0x672311d3, 0xf2d20452, 0x656911d4, 0x00000000}},  //   hanj, _שעה_, ndeh,
  { {0x6449021e, 0x672301ae, 0x2d8b029d, 0x00000000}},  // [1f80] ntei, kanj, _doce_,
  { {0x67230e3b, 0xd9b8006e, 0x68fb0b33, 0x00000000}},  //   janj, ेक्ट, _agud,
  { {0x67230295, 0x64490bac, 0x236701d9, 0x00000000}},  //   danj, htei, _manj_,
  { {0x3a3a0039, 0x2d8b0023, 0xdce4012d, 0x00000000}},  //   rupp_, _goce_, ldič,
  { {0x26030219, 0xdcb90057, 0xdb0e000c, 0x00000000}},  //   _año_, _ещё_, þjón,
  { {0x67230e3b, 0x656900c1, 0x31bb0309, 0x00000000}},  //   ganj, edeh, _उद्ध,
  { {0xc34e0011, 0x6e3c004a, 0x64490052, 0x00000000}},  //   _bổng_, nurb, etei,
  { {0xc34e0011, 0x644900db, 0x00000000, 0x00000000}},  //   _cổng_, ftei,   ,
  { {0x672300ee, 0x29e8006b, 0x39440181, 0x00000000}},  //   banj, _uşaq_, _icms_,
  { {0x67230119, 0x6e3c000c, 0x96960c96, 0x00000000}},  //   canj, kurb, _ореш,
  { {0xa29401ff, 0x644911d5, 0x777a002d, 0x00000000}},  //   хані, atei, _intx,
  { {0x14af0061, 0x644901a2, 0x6e3c000c, 0x00000000}},  //   _जेवण, btei, durb,
  { {0x2d8b0224, 0x14e202f4, 0x644911d6, 0x00000000}},  //   _roce_, _परिण, ctei,
  { {0x61ee0027, 0x39440085, 0x6e3c0133, 0x00000000}},  //   _ďale, _lcms_, furb,
  { {0x2bbf0164, 0x6e3c000c, 0xdb0e00f6, 0x00000000}},  //   ्वसा, gurb, _imbè,
  { {0x23670381, 0x67230ecc, 0x7d160007, 0x00000000}},  //   _zanj_, zanj, gbys,
  { {0x2d8b11d7, 0x672311d8, 0xf1bf04bb, 0x00000000}},  // [1f90] _voce_, yanj, mná_,
  { {0x6e3c07b8, 0xf1bf015f, 0x291f0129, 0x00000000}},  //   burb, lná_, _seua_,
  { {0x6723092f, 0x6e3c0173, 0x644911d9, 0x00000000}},  //   vanj, curb, ztei,
  { {0x67230020, 0x777a002d, 0xf1bf0d86, 0x00000000}},  //   wanj, _antx, nná_,
  { {0x672301cd, 0xa91d00ca, 0x644911da, 0x00000000}},  //   tanj, _joži, xtei,
  { {0xf7710025, 0xa3dd013d, 0x06b00044, 0x00000000}},  //   طات_, _थीं_, _ছড়ি,
  { {0x672311db, 0x92c20055, 0xe9190088, 0x00000000}},  //   ranj, ্ধু_, _нові_,
  { {0x6723016c, 0x6449021e, 0xf1bf01ca, 0x00000000}},  //   sanj, ttei, jná_,
  { {0xf1bf01ca, 0x756800a1, 0xa91d040d, 0x00000000}},  //   dná_, بینہ_, _noži,
  { {0x644911dc, 0x43740152, 0x656901a2, 0x00000000}},  //   rtei, вуют, sdeh,
  { {0xc34e001d, 0xfbd200b6, 0xb34500c4, 0x00000000}},  //   _tổng_, רתי_, _acçã,
  { {0x395d07ec, 0xa91d0209, 0x644911dd, 0x00000000}},  //   news_, _boži, ptei,
  { {0x25bf000d, 0x4395007e, 0x6601006c, 0x00000000}},  //   mnul_, _падс, _hulk,
  { {0xa91d0340, 0x660100b0, 0x81bd0089, 0x00000000}},  //   _doži, _kulk, nsēj,
  { {0x6601021e, 0xe2990245, 0xf1bf06b8, 0x00000000}},  //   _julk, _хай_, bná_,
  { {0x6e3c00f6, 0xdd920355, 0xdb0e0299, 0x00000000}},  //   rurb, دور_, _imbé,
  { {0xdca30088, 0x7d1611de, 0xc5f200a0, 0x00000000}},  // [1fa0] гати, rbys, רדן_,
  { {0x672108b2, 0x7d16018e, 0xf4010055, 0x00000000}},  //   _nelj, sbys, _এবার_,
  { {0x1b1f0044, 0xdb1c11df, 0x25bf0c76, 0x00000000}},  //   _পাশে_, _skró, knul_,
  { {0x6da60088, 0xaa570025, 0x08c600e2, 0x00000000}},  //   _чима, علنا_, нбен,
  { {0x1b1f0055, 0x672100ca, 0xa3c1007d, 0x00000000}},  //   _পারে_, _belj, ्का_,
  { {0x660111e0, 0x672101d9, 0xd7ef0025, 0x00000000}},  //   _bulk, _celj, مكن_,
  { {0x66010173, 0x67210087, 0xdb1c0036, 0x00000000}},  //   _culk, _delj, _wkró,
  { {0x66010006, 0x25bf11e1, 0x6b8e0943, 0x00000000}},  //   _dulk, gnul_, _hobg,
  { {0xe73a00ed, 0x5ed20061, 0xf1bf06b8, 0x00000000}},  //   _неа_, _दुसऱ, vná_,
  { {0xc4530054, 0xa91d11e2, 0x25bf0035, 0x00000000}},  //   اضيع, _roži, anul_,
  { {0xf1bf0d86, 0x363600a2, 0xa91d00ca, 0x00000000}},  //   tná_, _سراس, _soži,
  { {0xa91d0027, 0x67210825, 0x00000000, 0x00000000}},  //   _poži, _zelj,   ,
  { {0x5577007b, 0xf1bf0428, 0x660111e3, 0x00000000}},  //   _רעדן_, rná_, _zulk,
  { {0xe47b0097, 0xf1bf0161, 0x6d460bca, 0x00000000}},  //   _מרדכ, sná_, _acka,
  { {0xf1bf0161, 0x00000000, 0x00000000, 0x00000000}},  //   pná_,   ,   ,
  { {0x13d50055, 0xcdd8012b, 0xa91d0059, 0x00000000}},  //   _হওয়, ењу_, _toži,
  { {0x41c40426, 0x00000000, 0x00000000, 0x00000000}},  // [1fb0] _حقيق,   ,   ,
  { {0x79990022, 0x752200fa, 0x00000000, 0x00000000}},  //   wkww, _leoz,   ,
  { {0x75e5008e, 0x672101ed, 0x7cea0010, 0x00000000}},  //   nózc, _relj, töré,
  { {0xc9840057, 0x752211e4, 0x98b900e2, 0x00000000}},  //   лучи, _neoz, млет_,
  { {0x660111e5, 0x67210e0d, 0xf7450264, 0x00000000}},  //   _sulk, _pelj, вело,
  { {0x66010089, 0xb17b00f8, 0xec3600b3, 0x00000000}},  //   _pulk, llåd, _באשר_,
  { {0x672111e6, 0x0cc40044, 0xbbbf0309, 0x00000000}},  //   _velj, ্ধৃত, ्वीक,
  { {0x25bf0035, 0x00000000, 0x00000000, 0x00000000}},  //   unul_,   ,   ,
  { {0x672111e7, 0x9f5304bd, 0x25bf001a, 0x00000000}},  //   _telj, _així_, rnul_,
  { {0x660111e8, 0xe8741019, 0xc6a7007c, 0x00000000}},  //   _tulk, _حافظ, _преи,
  { {0xb2f4007c, 0x2ca911e9, 0x332500fa, 0x00000000}},  //   ляющ, hzad_, ralx_,
  { {0xe2960b87, 0x7afa11ea, 0x75c8013e, 0x00000000}},  //   таю_, _útte, těze,
  { {0x2ca905fa, 0x00000000, 0x00000000, 0x00000000}},  //   jzad_,   ,   ,
  { {0x656b002a, 0x7522002d, 0x443f0052, 0x00000000}},  //   _hagh, _zeoz, muu_,
  { {0x443f00b0, 0x7e230545, 0x00000000, 0x00000000}},  //   luu_, идрж,   ,
  { {0xfce601e0, 0xdde90431, 0x656b002b, 0x00000000}},  //   вобо, فرقه_, _jagh,
  { {0x656b1084, 0x443f11eb, 0x00000000, 0x00000000}},  // [1fc0] _magh, nuu_,   ,
  { {0x656b11ec, 0x4e060242, 0xaaba02fd, 0x00000000}},  //   _lagh, _изоб, ودار_,
  { {0x6a86005e, 0xbea602e9, 0x443f00b0, 0x00000000}},  //   ължа, _ранк, huu_,
  { {0x443f11ed, 0x656b11ee, 0x3f8a0107, 0x00000000}},  //   kuu_, _nagh, ljbu_,
  { {0x92bd0055, 0x91fc001e, 0x443f006c, 0x00000000}},  //   _আরো_, nvār, juu_,
  { {0x6d440006, 0x244b0030, 0xeb9f068f, 0x00000000}},  //   lgia, døm_, _støv_,
  { {0x656b0190, 0x6459000a, 0xacbb009d, 0x00000000}},  //   _bagh, _apwi, _jeûn,
  { {0x6d44010a, 0x7bde06b9, 0x443f0020, 0x00000000}},  //   ngia, llpu, fuu_,
  { {0x443f0020, 0x656b011c, 0x91fc0089, 0x00000000}},  //   guu_, _dagh, jvār,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbb3b009b, 0x326302dc, 0xc7d7034e, 0x00000000}},  //   ועיי, атяв, _יומי_,
  { {0x80d10055, 0x69c20016, 0x443f1080, 0x00000000}},  //   _সৃষ্, nnoe, buu_,
  { {0x0443003b, 0x64a302dc, 0xb17b00f8, 0x00000000}},  //   _вечн, _каца, vlåd,
  { {0x644011ef, 0x656b11f0, 0x6d4403d3, 0x00000000}},  //   mumi, _zagh, egia,
  { {0x64400207, 0xa3c102fb, 0x75e50010, 0x00000000}},  //   lumi, ्कर_, lóza,
  { {0x6d440198, 0x656b11f1, 0x00000000, 0x00000000}},  //   ggia, _xagh,   ,
  { {0x644011f2, 0x00000000, 0x00000000, 0x00000000}},  // [1fd0] numi,   ,   ,
  { {0x765a0036, 0x5b140088, 0xd24d00a1, 0x00000000}},  //   _opty, имут, _بچی_,
  { {0x6440000b, 0x6d440082, 0x443f11f3, 0x00000000}},  //   humi, bgia, zuu_,
  { {0x644011f4, 0x99d10044, 0x61fe009d, 0x00000000}},  //   kumi, িষ্ক, _éplu,
  { {0x6440001e, 0x656b11f5, 0x97d90f62, 0x00000000}},  //   jumi, _ragh, ньку_,
  { {0x644006ad, 0xb60501c8, 0x7d0d0afb, 0x00000000}},  //   dumi, hláš, lcas,
  { {0x99670517, 0x656b006a, 0x45d50893, 0x00000000}},  //   _итал, _pagh, лцит,
  { {0x7d0d023a, 0x4efc00b6, 0x443f00b0, 0x00000000}},  //   ncas, ולוג, tuu_,
  { {0x644011f6, 0x656b0197, 0xa3c10164, 0x00000000}},  //   gumi, _vagh, ्कल_,
  { {0xa77400ed, 0x656b11f7, 0x7d0d0009, 0x00000000}},  //   _клуч, _wagh, hcas,
  { {0x656b01d5, 0x6d440016, 0xe29900ed, 0x00000000}},  //   _tagh, ygia, хан_,
  { {0x64400004, 0xe5700151, 0x443f03b6, 0x00000000}},  //   bumi, _وطن_, puu_,
  { {0xad9b00c4, 0x644000e7, 0x7c2d00f8, 0x00000000}},  //   _miúd, cumi, jsar,
  { {0x442d11f8, 0x7c2d0193, 0x442f009d, 0x00000000}},  //   mse_, dsar, _ivg_,
  { {0xd5ac026c, 0xed5a0057, 0x442d0905, 0x00000000}},  //   _رہی_, нов_, lse_,
  { {0x442d0273, 0x7d0d00f6, 0x69c30010, 0x00000000}},  //   ose_, gcas, énel,
  { {0x442d11f9, 0x70770025, 0x7c2d11fa, 0x00000000}},  // [1fe0] nse_, _مميز_, gsar,
  { {0x442d101a, 0x442f11fb, 0x6d440016, 0x00000000}},  //   ise_, _mvg_, sgia,
  { {0x644011fc, 0x8ad5008b, 0xb17b0030, 0x00000000}},  //   zumi, аюцц, slåe,
  { {0x442d061f, 0x9f5a0263, 0x7d0d0197, 0x00000000}},  //   kse_, _sipè_, ccas,
  { {0x442d11fd, 0x64e2006e, 0x69c211fe, 0x00000000}},  //   jse_, _परेश, rnoe,
  { {0x38cb01ef, 0x644011ff, 0x442d017b, 0x00000000}},  //   رانی_, vumi, dse_,
  { {0x442f0059, 0x499400d3, 0x442d1200, 0x00000000}},  //   _avg_, _پیشر, ese_,
  { {0x64401201, 0xad9b0051, 0x442d1202, 0x00000000}},  //   tumi, _giúd, fse_,
  { {0xd3260805, 0xb9930025, 0x48e305f6, 0x00000000}},  //   льни, _القب, _готв,
  { {0x644008b2, 0xf3660140, 0x39460006, 0x00000000}},  //   rumi, утин, lgos_,
  { {0x442d0038, 0x7c2d001e, 0x454605f3, 0x00000000}},  //   ase_, zsar, _مناق,
  { {0x39461203, 0x442f0197, 0x644000b0, 0x00000000}},  //   ngos_, _fvg_, pumi,
  { {0x442d1204, 0xc5f300b3, 0x2b4a0022, 0x00000000}},  //   cse_, _הדף_, _ocbc_,
  { {0x7d0d00ab, 0x00000000, 0x00000000, 0x00000000}},  //   wcas,   ,   ,
  { {0x7d0d1205, 0x539b00b3, 0x98ad00ca, 0x00000000}},  //   tcas, _איגו, _rdeč_,
  { {0x63ba004f, 0x7c2d1206, 0xc27b00a3, 0x00000000}},  //   litn, tsar, _טרוי,
  { {0x7d0d0207, 0x69c300f4, 0x61ed014a, 0x00000000}},  // [1ff0] rcas, énem, _ihal,
  { {0x212b1207, 0x7d0d023a, 0x3946008e, 0x00000000}},  //   lach_, scas, egos_,
  { {0x7c2d1208, 0x61ed01a3, 0x7d0d0f1d, 0x00000000}},  //   ssar, _khal, pcas,
  { {0x212b002a, 0x442d1209, 0x61ed0066, 0x00000000}},  //   nach_, yse_, _jhal,
  { {0x1869012b, 0x3949001e, 0x61ed0051, 0x00000000}},  //   тали_, ļas_, _mhal,
  { {0xe73600d7, 0x212b0051, 0x629a0006, 0x00000000}},  //   аеш_, hach_, kyto,
  { {0x212b0871, 0x442d0866, 0x16a60407, 0x00000000}},  //   kach_, wse_, ивши_,
  { {0x629a0a66, 0x212b0036, 0x61ed0af2, 0x00000000}},  //   dyto, jach_, _nhal,
  { {0x212b120a, 0x291d09df, 0x63ba00ca, 0x00000000}},  //   dach_, mbwa_, fitn,
  { {0x61ed022b, 0x68e9012d, 0x92f50088, 0x00000000}},  //   _ahal, _ized, ичні,
  { {0x61ed120b, 0x212b010f, 0x7bc50cba, 0x00000000}},  //   _bhal, fach_, inhu,
  { {0x442d008d, 0x442f027b, 0x212b120c, 0x00000000}},  //   pse_, _tvg_, gach_,
  { {0x7643120d, 0x15f40084, 0x61ed120e, 0x00000000}},  //   luny, _اسلح, _dhal,
  { {0x629a120f, 0x39460d94, 0x63ba0161, 0x00000000}},  //   byto, zgos_, citn,
  { {0x60cd0038, 0x629a1210, 0x212b03de, 0x00000000}},  //   _exam, cyto, bach_,
  { {0x61ed01d5, 0xd1ba026c, 0x4ad902fb, 0x00000000}},  //   _ghal, _جاتا_, _बुधव,

  { {0x4b2600e3, 0x76431211, 0x6da30545, 0x00000000}},  // [2000] имав, huny, цита,
  { {0x76431212, 0x109b00b3, 0x69c90022, 0x00000000}},  //   kuny, _סביב, _ajee,
  { {0x320704bd, 0x7f3b009b, 0x34e2013d, 0x00000000}},  //   _juny_, _בעיו, _पर्द,
  { {0xeae6001c, 0x3946010a, 0x26de0006, 0x00000000}},  //   _करीत_, ugos_, _ryto_,
  { {0x39461213, 0x8eb3007a, 0xa91d02aa, 0x00000000}},  //   rgos_, _همیش, _požr,
  { {0x81bd001e, 0x39460211, 0x212b0832, 0x00000000}},  //   lsēt, sgos_, zach_,
  { {0x7643008a, 0xb86600a1, 0x212b005b, 0x00000000}},  //   guny, _ھارو, yach_,
  { {0x6d560263, 0xe5c6012b, 0xd9430545, 0x00000000}},  //   nfya, јско, _меси,
  { {0x88bd0046, 0x29041214, 0x2fd80039, 0x00000000}},  //   _jeśl, _igma_, korg_,
  { {0x26de0224, 0x61ed1215, 0x38690065, 0x00000000}},  //   _tyto_, _shal, çare_,
  { {0x212b1216, 0x63ba0161, 0xe3af0380, 0x00000000}},  //   tach_, ritn, بري_,
  { {0x629a093c, 0x29dc008e, 0x00000000, 0x00000000}},  //   ryto, mías_,   ,
  { {0x212b120a, 0x7bdc0091, 0x29dc008e, 0x00000000}},  //   rach_, _okru, lías_,
  { {0x212b120a, 0x2d8201d5, 0x644f04bd, 0x00000000}},  //   sach_, _anke_, àcie,
  { {0x67281217, 0x61ed1218, 0x212b0036, 0x00000000}},  //   _medj, _thal, pach_,
  { {0x67280107, 0x61ed1219, 0xdce60089, 0x00000000}},  //   _ledj, _uhal, _sakā,
  { {0x2fd8033d, 0xdce60089, 0x6be50025, 0x00000000}},  // [2010] borg_, _pakā, مكرم,
  { {0x67280209, 0x69db05b7, 0xa3e6006e, 0x00000000}},  //   _nedj, _skue, पति_,
  { {0x290f001c, 0x7ff403ec, 0x7bc500f8, 0x00000000}},  //   tcga_, _بسيا, rnhu,
  { {0x2001121a, 0x29dc008e, 0x764309df, 0x00000000}},  //   _hihi_, días_, vuny,
  { {0x68e0018e, 0xe739005e, 0x7c8700c0, 0x00000000}},  //   _cymd, гел_, _туне,
  { {0x29dc0841, 0x785a001e, 0x8a1703ec, 0x00000000}},  //   fías_, dāvā, _نظرا,
  { {0xf770031d, 0x29dc0211, 0x20010288, 0x00000000}},  //   بان_, gías_, _mihi_,
  { {0x2fd800b5, 0x764304cb, 0x77630129, 0x00000000}},  //   zorg_, runy, senx,
  { {0x68e00016, 0x69d90036, 0x6728121b, 0x00000000}},  //   _gymd, mowe, _fedj,
  { {0x320700d4, 0x69d9077a, 0x29dc008e, 0x00000000}},  //   _puny_, lowe, bías_,
  { {0x29dc064d, 0xd575008b, 0x6b95121c, 0x00000000}},  //   cías_, _гуль, _mozg,
  { {0x69d90036, 0x35f50245, 0x13a70123, 0x00000000}},  //   nowe, _упер, انگی_,
  { {0xd24e01ef, 0x2fd8000c, 0x20090145, 0x00000000}},  //   ونی_, torg_, _cuai_,
  { {0x443f103c, 0xaad0013d, 0x69d900b4, 0x00000000}},  //   mru_, _तुझक, howe,
  { {0x394d0107, 0x69d90036, 0xdee60088, 0x00000000}},  //   _oces_, kowe, сови,
  { {0x7bdc121d, 0x2900010a, 0x2fd80a74, 0x00000000}},  //   _skru, žiai_, sorg_,
  { {0x69d90036, 0x20090197, 0x443f0471, 0x00000000}},  // [2020] dowe, _guai_, nru_,
  { {0x394d121e, 0x68e00039, 0x443f121f, 0x00000000}},  //   _aces_, _rymd, iru_,
  { {0x49060054, 0x29dc049a, 0x443f01a3, 0x00000000}},  //   مواق, xías_, hru_,
  { {0x5d860054, 0x705300e9, 0x443f0161, 0x00000000}},  //   _الحل, _بنیا, kru_,
  { {0x672801ee, 0x236500ca, 0x443f002b, 0x00000000}},  //   _pedj, kelj_, jru_,
  { {0x7bdc1220, 0x29dc02a0, 0x0f7a0049, 0x00000000}},  //   _ukru, tías_, ראַב,
  { {0x443f0096, 0x386d014a, 0x69d90036, 0x00000000}},  //   eru_, _eser_, bowe,
  { {0x29dc0958, 0x443f037e, 0x98a6025f, 0x00000000}},  //   rías_, fru_, _либе,
  { {0x443f001a, 0x29dc008e, 0x9f5a0026, 0x00000000}},  //   gru_, sías_, _pipì_,
  { {0x23650e0d, 0x29dc008e, 0x20090085, 0x00000000}},  //   gelj_, pías_, _ruai_,
  { {0x4df803d7, 0x2258007c, 0x443f00b4, 0x00000000}},  //   ंगाई_, шины_, aru_,
  { {0x443f0d6b, 0x25a60058, 0x00000000, 0x00000000}},  //   bru_, _ulol_,   ,
  { {0x443f000d, 0x23651221, 0x20090742, 0x00000000}},  //   cru_, belj_, _quai_,
  { {0x33f602a8, 0x236500ee, 0x69d9105e, 0x00000000}},  //   _учес, celj_, zowe,
  { {0x6b951222, 0x69d90020, 0xd357009b, 0x00000000}},  //   _rozg, yowe, _השוק_,
  { {0xd131007a, 0x44260cfe, 0x00000000, 0x00000000}},  //   _کمک_, _kwo_,   ,
  { {0xd01102fd, 0x6602007f, 0x6b950032, 0x00000000}},  // [2030] _تلخ_, _miok, _pozg,
  { {0x6ac4006e, 0x64400051, 0x69d91223, 0x00000000}},  //   वपूर, irmi, wowe,
  { {0x69d90036, 0x3cde001c, 0x29dc004a, 0x00000000}},  //   towe, _कुठे_, víar_,
  { {0x127b0049, 0x2365050f, 0x195900a5, 0x00000000}},  //   טאבע, zelj_, рады_,
  { {0x69d90036, 0xf09f04bd, 0x6d4f0066, 0x00000000}},  //   rowe, nyà_, _icca,
  { {0x01cf0044, 0x645c001a, 0x69d9114b, 0x00000000}},  //   রতিদ, ăril, sowe,
  { {0x44261224, 0x64401225, 0x443f0251, 0x00000000}},  //   _awo_, ermi, wru_,
  { {0x443f1226, 0x84591227, 0x44260061, 0x00000000}},  //   tru_, арот_, _bwo_,
  { {0x386d0038, 0x23650295, 0x443f1228, 0x00000000}},  //   _user_, telj_, uru_,
  { {0x443f01f3, 0xdb0e000c, 0xe3b9005e, 0x00000000}},  //   rru_, _embæ, рбо_,
  { {0x6d5d0428, 0x6d4f06e2, 0x443f1229, 0x00000000}},  //   _obsa, _occa, sru_,
  { {0x443f002b, 0x2365021c, 0x66020026, 0x00000000}},  //   pru_, selj_, _giok,
  { {0x44260263, 0x25bf001a, 0x00000000, 0x00000000}},  //   _gwo_, miul_,   ,
  { {0x6d4f0207, 0x25bf001a, 0x6d5d122a, 0x00000000}},  //   _acca, liul_, _absa,
  { {0xf1bf00fa, 0x00000000, 0x00000000, 0x00000000}},  //   biá_,   ,   ,
  { {0x25bf001a, 0x6d4f122b, 0x0c2602ea, 0x00000000}},  //   niul_, _ccca, жман,
  { {0x249f122c, 0x752b122d, 0xfce3122e, 0x00000000}},  // [2040] nyum_, _megz, дото,
  { {0x61e6122f, 0x25bf0035, 0x9e661230, 0x00000000}},  //   llkl, hiul_, _двод,
  { {0xed5a01f9, 0x3dc90058, 0x00000000, 0x00000000}},  //   _кон_, bnaw_,   ,
  { {0xe9da0175, 0xad5a007e, 0x25ad012d, 0x00000000}},  //   шке_, _трох_, jhel_,
  { {0x25bf000d, 0x999c0010, 0x00000000, 0x00000000}},  //   diul_, évő_,   ,
  { {0x44260061, 0xc7a309bb, 0x207b0049, 0x00000000}},  //   _rwo_, мичк, יאנא,
  { {0x81c30044, 0x7bce00bb, 0x00000000, 0x00000000}},  //   ্তত_, _ijbu,   ,
  { {0x2d921231, 0x7e9b0049, 0x25ad1232, 0x00000000}},  //   njye_, יסצו, ghel_,
  { {0xa73a0123, 0x2ca01233, 0xf1bf00fa, 0x00000000}},  //   _نثار_, nyid_, viá_,
  { {0x442600bb, 0x00000000, 0x00000000, 0x00000000}},  //   _vwo_,   ,   ,
  { {0x86c60379, 0xcb13009b, 0xb7d71234, 0x00000000}},  //   _بيان, ולת_, _بولا_,
  { {0x44260038, 0x25ad00f4, 0xb60601a8, 0x00000000}},  //   _two_, chel_, rišć,
  { {0x44260061, 0xcf00006b, 0x25d90014, 0x00000000}},  //   _uwo_, əşən_, _اهنگ_,
  { {0x43740014, 0x4ea702dc, 0x00000000, 0x00000000}},  //   _رهبر, орба,   ,
  { {0x3ea50047, 0xf1bf004a, 0x00000000, 0x00000000}},  //   ált_, piá_,   ,
  { {0x463b0049, 0x00000000, 0x00000000, 0x00000000}},  //   יעלע,   ,   ,
  { {0xa1f900a1, 0x030e013d, 0xc19c009b, 0x00000000}},  // [2050] _پڑھا_, _सलाह_, _כשהי,
  { {0x09d301f5, 0xda7b02dc, 0x00000000, 0x00000000}},  //   तव्य, ияе_,   ,
  { {0xfd4700a1, 0xaf010044, 0xdd9000a1, 0x00000000}},  //   _ویسٹ_, ্রহণ_, روے_,
  { {0x2ca00061, 0x249f1235, 0x67ed004a, 0x00000000}},  //   byid_, yyum_, dúja,
  { {0xb17c01ce, 0x6d4d018d, 0x98f4007e, 0x00000000}},  //   יטאר, mgaa, мяшч,
  { {0x81c30055, 0x6cfa009b, 0x7b640517, 0x00000000}},  //   ্তি_, _לפרס, _отсе,
  { {0x25ad0675, 0x67ed0010, 0x25bf001a, 0x00000000}},  //   thel_, gúja, tiul_,
  { {0x2d990f06, 0x6d4d0168, 0x391501e1, 0x00000000}},  //   _jose_, ngaa, _хмар,
  { {0x81c30055, 0x25bf001a, 0x395f1236, 0x00000000}},  //   ্তা_, riul_, _ibus_,
  { {0x2d991237, 0x25ad1238, 0x249f1239, 0x00000000}},  //   _lose_, shel_, ryum_,
  { {0x69cb000b, 0x95cb007c, 0x25bf001a, 0x00000000}},  //   onge, _куда_, piul_,
  { {0x2ca0013f, 0x2d99123a, 0x6d4d0bbc, 0x00000000}},  //   yyid_, _nose_, jgaa,
  { {0x6d4d123b, 0x920b013d, 0x26110082, 0x00000000}},  //   dgaa, _सूरज_, _háo_,
  { {0xa4fa009b, 0x69cb01a2, 0x6d4d123c, 0x00000000}},  //   _פלסט, hnge, egaa,
  { {0x2d99123d, 0x8e8300ed, 0x6d4d0250, 0x00000000}},  //   _bose_, нгре, fgaa,
  { {0x2d990198, 0x6d4d0343, 0x2ca00009, 0x00000000}},  //   _cose_, ggaa, tyid_,
  { {0xdb1e008d, 0x2d9900ab, 0x6449123e, 0x00000000}},  // [2060] qipë, _dose_, nuei,
  { {0x395f00f4, 0x2ca00009, 0x69cb021f, 0x00000000}},  //   _abus_, ryid_, enge,
  { {0x9f9b009b, 0x2d990962, 0x26110082, 0x00000000}},  //   _הסיפ, _fose_, _náo_,
  { {0x5f460752, 0x2d990032, 0xe8fa0140, 0x00000000}},  //   _بنگل, _gose_, бле_,
  { {0xa3bd04da, 0xa3cb0204, 0x7d7b009b, 0x00000000}},  //   ीचा_, रचा_, _הנכו,
  { {0x261100ad, 0x69cb01d6, 0xdb1e123f, 0x00000000}},  //   _báo_, ange, kipé,
  { {0x2611001d, 0x2d990061, 0xdbc70934, 0x00000000}},  //   _cáo_, _yose_, töös,
  { {0x69c30010, 0x7bde0052, 0x9418004d, 0x00000000}},  //   énet, lopu, ожит_,
  { {0x64491240, 0x7c3604d3, 0xdce40006, 0x00000000}},  //   guei, nsyr, keič,
  { {0x7bde1241, 0x69c21242, 0xdc9b0049, 0x00000000}},  //   nopu, lioe, צייל,
  { {0xe4d601ef, 0x5ec10044, 0xf773009b, 0x00000000}},  //   _کتاب, _শুনে, _רקע_,
  { {0xfbc40044, 0x9257007c, 0x64490129, 0x00000000}},  //   ্তিত, чают_, buei,
  { {0x6449028c, 0x7bde00b0, 0xad9b0051, 0x00000000}},  //   cuei, kopu, _diúl,
  { {0x22590036, 0x7bde016c, 0xa91d0087, 0x00000000}},  //   ńska_, jopu, _anžl,
  { {0x6d4d1243, 0xdb1e0051, 0x69cb1244, 0x00000000}},  //   tgaa, cipé, ynge,
  { {0x91e4012b, 0x00000000, 0x00000000, 0x00000000}},  //   _поје,   ,   ,
  { {0x113c009b, 0x9c190025, 0x2d990919, 0x00000000}},  // [2070] _התחל, زياء_, _vose_,
  { {0x09c50061, 0x6d4d0030, 0x2d990009, 0x00000000}},  //   लच्य, sgaa, _wose_,
  { {0x6d4d1245, 0x2d991246, 0x00000000, 0x00000000}},  //   pgaa, _tose_,   ,
  { {0x69cb0207, 0x69c20032, 0xdb1e00b0, 0x00000000}},  //   unge, gioe, enpä,
  { {0xeab000a1, 0x26110011, 0x69cb01a2, 0x00000000}},  //   نٹے_, _sáo_, rnge,
  { {0xfd1300a1, 0x69da00c4, 0xdb2302fd, 0x00000000}},  //   _تجھ_, _íten, _سوری,
  { {0xe730023c, 0x69c20288, 0x00000000, 0x00000000}},  //   اصه_, bioe,   ,
  { {0x69c203d1, 0x64490129, 0x49b8023c, 0x00000000}},  //   cioe, tuei, _فاقد_,
  { {0x79890253, 0x00000000, 0x00000000, 0x00000000}},  //   _inew,   ,   ,
  { {0x26110011, 0x644900d4, 0xad9b0051, 0x00000000}},  //   _táo_, ruei, _siúl,
  { {0x61460816, 0x799b1247, 0xf65500ed, 0x00000000}},  //   мена, _kouw, _цвеќ,
  { {0x5ec10044, 0x799b1248, 0xdb1e0068, 0x00000000}},  //   _শুভে, _jouw, ripé,
  { {0x64490ddb, 0xad9b00c4, 0x7a0c0095, 0x00000000}},  //   quei, _ciúm, _işte,
  { {0x69c2022b, 0x799b1249, 0xbef90061, 0x00000000}},  //   zioe, _louw, ंधून_,
  { {0x5de6007e, 0x79890275, 0x0ef9007e, 0x00000000}},  //   джва, _onew, зэты_,
  { {0x799b00d4, 0x69bf007d, 0xdb1c0327, 0x00000000}},  //   _nouw, लोमी, _imré,
  { {0x7bde016c, 0x5f7605d4, 0x61e40622, 0x00000000}},  // [2080] topu, _قادر, _ikil,
  { {0x78a200e7, 0xafdb00ea, 0x00000000, 0x00000000}},  //   vyov, ktøy,   ,
  { {0x81c30055, 0x7c36124a, 0x1d0a0184, 0x00000000}},  //   ্তর_, ssyr, _мени_,
  { {0x7bde0c76, 0x799b00d9, 0x7989005b, 0x00000000}},  //   sopu, _couw, _cnew,
  { {0x7bde0d59, 0x69c2002d, 0x799b0112, 0x00000000}},  //   popu, rioe, _douw,
  { {0x7a0c001a, 0x69c2124b, 0xe3a71095, 0x00000000}},  //   _aşte, sioe, _شر_,
  { {0x79890009, 0x6b9c0579, 0x69c20032, 0x00000000}},  //   _fnew, _iorg, pioe,
  { {0x6b9c0010, 0x320e0026, 0x799b0116, 0x00000000}},  //   _horg, _rufy_, _gouw,
  { {0x69c003a1, 0x6b9c0039, 0x236a00ec, 0x00000000}},  //   _imme, _korg, ојно_,
  { {0x6b9c0489, 0x61e40020, 0xf366003b, 0x00000000}},  //   _jorg, _akil, фтин,
  { {0xbcfb0051, 0x6b9c124c, 0x316b00b4, 0x00000000}},  //   _mbéa, _morg, tecz_,
  { {0x61f6010b, 0x6b9c124d, 0x79890066, 0x00000000}},  //   _chyl, _lorg, _xnew,
  { {0x6b9c0007, 0x0cc90044, 0x00000000, 0x00000000}},  //   _oorg, _শর্ত,   ,
  { {0x6b9c01e2, 0xe4c70014, 0xdb0e00f6, 0x00000000}},  //   _norg, _تصمی, _embú,
  { {0xdd9b013b, 0x69c00e38, 0xa3bd013d, 0x00000000}},  //   оша_, _omme, ीचर_,
  { {0xc5f80089, 0x31c4007e, 0x00000000, 0x00000000}},  //   _spēj_, _асьв,   ,
  { {0x6b9c124e, 0x799b00bb, 0x79890022, 0x00000000}},  // [2090] _borg, _rouw, _rnew,
  { {0x69c00207, 0x61fd0239, 0x6b9c0142, 0x00000000}},  //   _amme, lmsl, _corg,
  { {0xfd1000a1, 0x799b0173, 0x6b9c01e5, 0x00000000}},  //   اجہ_, _pouw, _dorg,
  { {0x4c9501fc, 0x9f5a00b0, 0x49b80014, 0x00000000}},  //   _зимс, _eipä_, واند_,
  { {0x6b9c124f, 0x7e620107, 0x2d8b014a, 0x00000000}},  //   _forg, _ćopi, _ince_,
  { {0x69c01250, 0xdce4011f, 0x6b9c032c, 0x00000000}},  //   _emme, ldiğ, _gorg,
  { {0x4ae4008b, 0x16a90581, 0x2fc10253, 0x00000000}},  //   _аўта, явки_, _mmhg_,
  { {0x6b9c02ae, 0xc8c0001c, 0xdce4014a, 0x00000000}},  //   _zorg, _शेवट, ndiğ,
  { {0x44391251, 0x6b9c1252, 0x290d0026, 0x00000000}},  //   és_, _yorg, _igea_,
  { {0x61e4009f, 0x61f600d2, 0x7bc500e7, 0x00000000}},  //   _skil, _shyl, nihu,
  { {0x2d8b00ab, 0x98a40035, 0x61f60133, 0x00000000}},  //   _once_, _temă_, _phyl,
  { {0x22590036, 0xe29a0082, 0xa91d0006, 0x00000000}},  //   ńsko_, _ngưu_, _požy,
  { {0xa5c6000c, 0x32090058, 0x7bc51253, 0x00000000}},  //   sjóð, _diay_, kihu,
  { {0x2d8b0089, 0x7bc50020, 0x09dc0061, 0x00000000}},  //   _ance_, jihu, _बऱ्य,
  { {0x24590263, 0x645b001a, 0x61f608c9, 0x00000000}},  //   lèm_, ltui, _thyl,
  { {0x6b9c03ae, 0x32090011, 0x61e400e7, 0x00000000}},  //   _sorg, _giay_, _ukil,
  { {0x8c43013b, 0x645b1254, 0xf3900011, 0x00000000}},  // [20a0] лете, ntui, _mảnh_,
  { {0x7bc50009, 0x290d0026, 0xe2c600a1, 0x00000000}},  //   gihu, _agea_, _آڈیو_,
  { {0x6b9c001f, 0x645b00b0, 0x68e90085, 0x00000000}},  //   _vorg, htui, _ayed,
  { {0x645b0007, 0x6b9c01d6, 0xe8fa0140, 0x00000000}},  //   ktui, _worg, пле_,
  { {0x6b9c0039, 0x69da0d62, 0xd7e605b8, 0x00000000}},  //   _torg, _ítem, ніко,
  { {0x7c240aa5, 0x290d00f6, 0x62830032, 0x00000000}},  //   mpir, _egea_, _orno,
  { {0xfa67026b, 0xd94601e0, 0x7c24095f, 0x00000000}},  //   _парк_, _певи, lpir,
  { {0xd5b71255, 0xf390001d, 0x69c01256, 0x00000000}},  //   есь_, _cảnh_, _umme,
  { {0x62831257, 0xb88601ca, 0xa3bd0061, 0x00000000}},  //   _arno, _blíž, ीचं_,
  { {0xafdb0190, 0xdb17006b, 0x00000000, 0x00000000}},  //   trøm, rixç,   ,
  { {0x6283037e, 0xf8bf009f, 0x0bb7009b, 0x00000000}},  //   _crno, _þér_, גלים_,
  { {0x645b0007, 0x628300ca, 0x7bc500e7, 0x00000000}},  //   btui, _drno, zihu,
  { {0xdce4014a, 0x777a0032, 0xf1c001f5, 0x00000000}},  //   vdiğ, _katx, शोधन,
  { {0x22940054, 0x7c240059, 0x777a0288, 0x00000000}},  //   _للتس, dpir, _jatx,
  { {0xfe7000a1, 0x777a1258, 0x00000000, 0x00000000}},  //   یدہ_, _matx,   ,
  { {0x777a0288, 0x00000000, 0x00000000, 0x00000000}},  //   _latx,   ,   ,
  { {0x3cfc001c, 0xdce4011f, 0xd164005e, 0x00000000}},  // [20b0] लेले_, rdiğ, _същи,
  { {0x657b003b, 0xe1ff0d62, 0xa91d0c6e, 0x00000000}},  //   zduh, lmó_, _inži,
  { {0xc333009b, 0xdcef001a, 0x7bc50738, 0x00000000}},  //   רוע_, _bacă, rihu,
  { {0x245901aa, 0x7c240270, 0x7bc50052, 0x00000000}},  //   yèm_, bpir, sihu,
  { {0x777a0ec8, 0xf3900011, 0xed60013e, 0x00000000}},  //   _batx, _rảnh_, ížet_,
  { {0xf7710355, 0xf3900082, 0x777a00d4, 0x00000000}},  //   شات_, _sảnh_, _catx,
  { {0xd915008b, 0x245901aa, 0x0675094b, 0x00000000}},  //   _адбы, wèm_, туля,
  { {0xd6ce0054, 0x645b00b0, 0x245901aa, 0x00000000}},  //   تقى_, ttui, tèm_,
  { {0xad9b0051, 0x777a05aa, 0x442400e0, 0x00000000}},  //   _ciúi, _fatx, gpm_,
  { {0x645b00c7, 0x5ed70055, 0x24591259, 0x00000000}},  //   rtui, _ধরনে, rèm_,
  { {0xcb120104, 0x645b1254, 0x6579015e, 0x00000000}},  //   ילי_, stui, _tawh,
  { {0x645b0035, 0xcec4013e, 0x00000000, 0x00000000}},  //   ptui, hoří_,   ,
  { {0x98a4010a, 0x75290020, 0x7c240045, 0x00000000}},  //   _temą_, mbez, xpir,
  { {0x64490016, 0x443d125a, 0x4345004c, 0x00000000}},  //   mrei, _ivw_, _рекв,
  { {0x6449125b, 0xed5a007c, 0xd0070679, 0x00000000}},  //   lrei, мов_, тере_,
  { {0xd00f026c, 0xb602009f, 0x661c0010, 0x00000000}},  //   صلہ_, _þátt, _érke,
  { {0x6449125c, 0x973c0091, 0xac0a00ed, 0x00000000}},  // [20c0] nrei, _hoće, днаа_,
  { {0x7c240089, 0xd00f0167, 0x442f0016, 0x00000000}},  //   rpir, _گلی_, _mwg_,
  { {0x6449125d, 0xf1c6013d, 0x2d9e00f4, 0x00000000}},  //   hrei, _लगान, êtes_,
  { {0x6449125e, 0xd00f0123, 0xdb1c0051, 0x00000000}},  //   krei, _دلی_, _imrí,
  { {0x777a002d, 0xb8220044, 0x38cb0014, 0x00000000}},  //   _patx, _নিহত_, واهی_,
  { {0xb17b0039, 0xda721125, 0x00000000, 0x00000000}},  //   llåt, _پُر_,   ,
  { {0x16370025, 0x2b580173, 0x660b0058, 0x00000000}},  //   نسية_, _icrc_, _bigk,
  { {0x6449125f, 0xd01a0055, 0x55740113, 0x00000000}},  //   frei, তীয়_, угит,
  { {0x64490fd1, 0x660b0007, 0xe8ea00a6, 0x00000000}},  //   grei, _digk, _آرزو_,
  { {0x75c800b9, 0x988b00a1, 0x442400fa, 0x00000000}},  //   tězs, _تحفہ_, rpm_,
  { {0x26110087, 0xf204013d, 0x442f06f2, 0x00000000}},  //   _cšod_, रगढ़_, _ewg_,
  { {0x64491260, 0x6738012d, 0x442f005b, 0x00000000}},  //   brei, lavj, _fwg_,
  { {0xe1ff0211, 0x64491261, 0x10740147, 0x00000000}},  //   rmó_, crei, аляю,
  { {0x9f5304bd, 0x26180011, 0x38690ab1, 0x00000000}},  //   _això_, _kéo_, çari_,
  { {0x4ea40265, 0x9f430065, 0x9f340088, 0x00000000}},  //   арта, lojë_, ресі,
  { {0x26180082, 0x00000000, 0x00000000, 0x00000000}},  //   _méo_,   ,   ,
  { {0x69c300f4, 0x9f430065, 0x26181262, 0x00000000}},  // [20d0] ènem, nojë_, _léo_,
  { {0x61ef0c3f, 0x752901ee, 0x6738016c, 0x00000000}},  //   llcl, zbez, javj,
  { {0x2618009d, 0x00000000, 0x00000000, 0x00000000}},  //   _néo_,   ,   ,
  { {0xdd9503c8, 0x21390065, 0x9f430065, 0x00000000}},  //   _самы, nash_, kojë_,
  { {0xf74500d7, 0xafdb0030, 0x394403e8, 0x00000000}},  //   гело, gsøg, рніг,
  { {0xdb070010, 0x26180011, 0x64491263, 0x00000000}},  //   _eljá, _béo_, vrei,
  { {0xcf9400a3, 0x21390023, 0x063200e2, 0x00000000}},  //   יטס_, kash_, бејџ,
  { {0x6449010f, 0x24860116, 0x973c012d, 0x00000000}},  //   trei, _brom_, _roće,
  { {0x75290fd4, 0x24860c51, 0x21391264, 0x00000000}},  //   rbez, _crom_, dash_,
  { {0x644907e6, 0x75291265, 0x62811266, 0x00000000}},  //   rrei, sbez, tvlo,
  { {0x6449010f, 0x248600bb, 0x660b00e0, 0x00000000}},  //   srei, _erom_, _tigk,
  { {0x24860a8a, 0x644905c6, 0x64460006, 0x00000000}},  //   _from_, prei, škia,
  { {0x3fc8007a, 0x248604eb, 0xd46900e2, 0x00000000}},  //   ندسی_, _grom_, _чиле_,
  { {0x61ef0026, 0xf5390142, 0x00000000, 0x00000000}},  //   alcl, lať_,   ,
  { {0x21390145, 0xfc3f00f6, 0x26180082, 0x00000000}},  //   bash_, _aví_, _xéo_,
  { {0x25ad046a, 0xf5390142, 0xf1aa0025, 0x00000000}},  //   nkel_, nať_, _ساعه_,
  { {0xb17b0039, 0x80a500a1, 0x5ed70044, 0x00000000}},  // [20e0] rlåt, _نمٹن, _ধরণে,
  { {0xb3460181, 0x9f5e00b0, 0x25ad006c, 0x00000000}},  //   moçõ, ötä_, hkel_,
  { {0x25ad1267, 0x5336007b, 0x9f430065, 0x00000000}},  //   kkel_, רנען_, zojë_,
  { {0x3ea51268, 0xe9e50088, 0x26180082, 0x00000000}},  //   älte_, аціо, _réo_,
  { {0xe89409b5, 0x07a60099, 0xf5390027, 0x00000000}},  //   раль, ладн, dať_,
  { {0xafdb0018, 0x9f430065, 0x21390023, 0x00000000}},  //   rsøg, vojë_, zash_,
  { {0x673801d9, 0xa91d0521, 0xad9b00c4, 0x00000000}},  //   ravj, _anžu, _viúv,
  { {0x6d56006a, 0x2d8000f4, 0xd49a00ed, 0x00000000}},  //   ngya, ndie_, еро_,
  { {0xa84a0879, 0x61e6001e, 0x2d801269, 0x00000000}},  //   _سلام_, dokl, idie_,
  { {0x9f430065, 0x261800fa, 0x21f2013e, 0x00000000}},  //   rojë_, _téo_, sáhl_,
  { {0x9f430065, 0x21390065, 0x61e60253, 0x00000000}},  //   sojë_, tash_, fokl,
  { {0x2486126a, 0x25ad03a1, 0x9f430023, 0x00000000}},  //   _trom_, ckel_, pojë_,
  { {0x2d800b36, 0x21390065, 0x00000000, 0x00000000}},  //   ddie_, rash_,   ,
  { {0x2a660036, 0x14d7009b, 0x21390023, 0x00000000}},  //   łoby_, _גודל_, sash_,
  { {0x2139126b, 0x00000000, 0x00000000, 0x00000000}},  //   pash_,   ,   ,
  { {0x6d560010, 0x61e60022, 0x00000000, 0x00000000}},  //   ggya, cokl,   ,
  { {0xdfd5007e, 0x00000000, 0x00000000, 0x00000000}},  // [20f0] _вопы,   ,   ,
  { {0x91fd001e, 0xf5390027, 0xdb1e004a, 0x00000000}},  //   stād, zať_, tipá,
  { {0x20d4089d, 0x25ad126c, 0x2ca90093, 0x00000000}},  //   _نتیج, ykel_, syad_,
  { {0x57dd0204, 0x3e41007f, 0x7aee0146, 0x00000000}},  //   यव्ह, mėt_, _dybt,
  { {0xf5390027, 0xa3d40061, 0xd5b10082, 0x00000000}},  //   vať_, सचा_, _lúc_,
  { {0x22590046, 0x39440436, 0x103800a3, 0x00000000}},  //   ński_, _edms_, נטום_,
  { {0x25ad006c, 0xf5390027, 0xa91d0087, 0x00000000}},  //   tkel_, tať_, _nažg,
  { {0x25ad037f, 0x00000000, 0x00000000, 0x00000000}},  //   ukel_,   ,   ,
  { {0x64460006, 0x98480265, 0x61e6126d, 0x00000000}},  //   škin, _бяха_, vokl,
  { {0x69cb0239, 0x25ad006c, 0x81bd0089, 0x00000000}},  //   lige, skel_, spēl,
  { {0x27e7126e, 0x25b00010, 0x2249005e, 0x00000000}},  //   monn_, álló_, ъпни_,
  { {0x69cb001f, 0x91e6026b, 0x27e7126f, 0x00000000}},  //   nige, роме, lonn_,
  { {0x6e25002a, 0xe3ae0140, 0x00000000, 0x00000000}},  //   _athb, _дб_,   ,
  { {0x753b0ba5, 0xdfd20025, 0x69cb010f, 0x00000000}},  //   lauz, زيز_, hige,
  { {0xa91d0428, 0x09b504da, 0x63a31270, 0x00000000}},  //   _každ, ंसाठ, _ionn,
  { {0x63a31271, 0x32da009b, 0x1d260088, 0x00000000}},  //   _honn, _שחקנ, рмам,
  { {0x63a31272, 0x2d801273, 0x69cb0292, 0x00000000}},  // [2100] _konn, rdie_, dige,
  { {0x63a300b0, 0x443f003c, 0xeab20025, 0x00000000}},  //   _jonn, isu_, يعا_,
  { {0x63a300f4, 0x69cb1274, 0x973c0091, 0x00000000}},  //   _monn, fige, _noća,
  { {0x443f0f81, 0x63a30051, 0xa01b000c, 0x00000000}},  //   ksu_, _lonn, kvöl,
  { {0x38cb00a6, 0x91fd0089, 0x764102e1, 0x00000000}},  //   پانی_, ltāc, _avly,
  { {0x63a30207, 0x98a400b9, 0x443f00ca, 0x00000000}},  //   _nonn, _země_, dsu_,
  { {0x29560265, 0x443f1275, 0xafdb05b7, 0x00000000}},  //   _възр, esu_, prøv,
  { {0xd3780363, 0x443f1276, 0x18a60152, 0x00000000}},  //   moći_, fsu_, _кабм,
  { {0x261603d7, 0x63a3032c, 0x79820066, 0x00000000}},  //   _पूरी_, _bonn, mdow,
  { {0x63a3032c, 0x798001dd, 0x27e700f6, 0x00000000}},  //   _conn, _hamw, conn_,
  { {0x6d460428, 0x63a30db6, 0x798009c7, 0x00000000}},  //   _odka, _donn, _kamw,
  { {0x7c260119, 0x31c71277, 0x753b1278, 0x00000000}},  //   _otkr, рсов, cauz,
  { {0x8463005e, 0x27ec0022, 0x63a30048, 0x00000000}},  //   _дъще, _kkdn_, _fonn,
  { {0x44260811, 0x69cb0f5d, 0x644200f4, 0x00000000}},  //   _ito_, zige, _ivoi,
  { {0xc3fb009b, 0x64400190, 0x7c260d90, 0x00000000}},  //   _שלוש, lsmi, _atkr,
  { {0xa91d1279, 0x44260620, 0x4255026c, 0x00000000}},  //   _kaže, _kto_, _انٹر,
  { {0x69cb0292, 0x61ed011c, 0x63a3009d, 0x00000000}},  // [2110] vige, _ikal, _yonn,
  { {0xa91d0006, 0x69cb0007, 0x69d800f4, 0x00000000}},  //   _maže, wige, éven,
  { {0x69cb001f, 0x79800061, 0x44260058, 0x00000000}},  //   tige, _bamw, _lto_,
  { {0x4426127a, 0x443f03d0, 0x6440127b, 0x00000000}},  //   _oto_, ysu_, ksmi,
  { {0x69cb127c, 0xfd96009b, 0xe6cb000c, 0x00000000}},  //   rige, _הדרך_, _íbúð,
  { {0x69cb127d, 0x64400089, 0x628a0016, 0x00000000}},  //   sige, dsmi, _orfo,
  { {0x4426008d, 0x63a30039, 0x6442127e, 0x00000000}},  //   _ato_, _ronn, _avoi,
  { {0x81bd001e, 0x443f0d49, 0x63a3001f, 0x00000000}},  //   spēj, tsu_, _sonn,
  { {0x27e70263, 0x64400030, 0x3f8111d1, 0x00000000}},  //   ponn_, gsmi, _oahu_,
  { {0x443f127f, 0x61ed006a, 0xd7fb1280, 0x00000000}},  //   rsu_, _akal, _руб_,
  { {0x443f009f, 0x44260bc9, 0x63a31267, 0x00000000}},  //   ssu_, _eto_, _vonn,
  { {0x63a30168, 0x44260022, 0x64400296, 0x00000000}},  //   _wonn, _fto_, bsmi,
  { {0x628a001f, 0x95c40025, 0x644f0b33, 0x00000000}},  //   _erfo, _بينه, ácid,
  { {0x23261281, 0x63ba0c4c, 0x3f810022, 0x00000000}},  //   _лоши_, chtn, _cahu_,
  { {0xa91d0627, 0xdfcf006d, 0x798200b4, 0x00000000}},  //   _zaže, ريف_, ydow,
  { {0x973c0091, 0x3d280014, 0x91e302dc, 0x00000000}},  //   _noćn, شتری_, _ноще,
  { {0x6da30242, 0x798000d9, 0x00000000, 0x00000000}},  // [2120] чита, _ramw,   ,
  { {0x69c9006c, 0x79820784, 0xa3ca007d, 0x00000000}},  //   _amee, wdow, रोप_,
  { {0x8e860054, 0x0a4a007c, 0x2bb901f5, 0x00000000}},  //   _الجه, узей_, _इतरा,
  { {0xe93a01b7, 0xe9da007c, 0x8d56005c, 0x00000000}},  //   اسات_, ыке_, _уточ,
  { {0x79820036, 0x69db004a, 0x3f810095, 0x00000000}},  //   rdow, _djue, _yahu_,
  { {0x798200e0, 0xa91d1282, 0x2d82059f, 0x00000000}},  //   sdow, _raže, _hake_,
  { {0x44261283, 0x79820857, 0x2d820059, 0x00000000}},  //   _sto_, pdow, _kake_,
  { {0xb8ce0055, 0xa91d0006, 0xdb1e0934, 0x00000000}},  //   _ওই_, _paže, sipä,
  { {0x2d820038, 0x442600c4, 0x64401284, 0x00000000}},  //   _make_, _qto_, usmi,
  { {0x61ed02e1, 0x6440032e, 0xd37a026b, 0x00000000}},  //   _skal, rsmi, учи_,
  { {0x44261285, 0xdddc0059, 0x779300a1, 0x00000000}},  //   _wto_, zvrš, _ریٹا,
  { {0xdb1c009f, 0x644002d8, 0x44260082, 0x00000000}},  //   _umræ, psmi, _tto_,
  { {0xafdb0637, 0x673a00b0, 0xd4f6025a, 0x00000000}},  //   drør, _ketj, _اثاث,
  { {0x823300a1, 0x661a1286, 0x00000000, 0x00000000}},  //   _کروا, _kutk,   ,
  { {0x25a61287, 0x2d82002d, 0x3f83012d, 0x00000000}},  //   _kool_, _bake_, rdju_,
  { {0x61ed00e7, 0x7bdc002b, 0x2d8200ab, 0x00000000}},  //   _ukal, _ajru, _cake_,
  { {0x3f810169, 0x21f90161, 0x661a0c1e, 0x00000000}},  // [2130] _tahu_, lého_, _lutk,
  { {0x673a01b5, 0x69c900c7, 0x7afc0009, 0x00000000}},  //   _netj, _smee, _bzrt,
  { {0x21f9004f, 0x2d820a60, 0x00000000, 0x00000000}},  //   ného_, _fake_,   ,
  { {0xd3780209, 0x725b0049, 0xad9b0048, 0x00000000}},  //   moću_, רכאפ, _dhúc,
  { {0x673a05b7, 0x973c04eb, 0xe7390478, 0x00000000}},  //   _betj, _voćn, аел_,
  { {0x2d820020, 0x21f90428, 0x661a1288, 0x00000000}},  //   _zake_, kého_, _butk,
  { {0x2d820be3, 0x2013002b, 0x56920184, 0x00000000}},  //   _yake_, _mixi_, дајт,
  { {0x25a600ab, 0x69c91242, 0x79a70545, 0x00000000}},  //   _cool_, _umee, _урге,
  { {0x7c2d022b, 0x57d500ed, 0x00000000, 0x00000000}},  //   npar, _доаѓ,   ,
  { {0x673a018d, 0xd8741289, 0x387f0288, 0x00000000}},  //   _getj, _عاقب, _isur_,
  { {0x5694091b, 0x27e00051, 0x25a60a6b, 0x00000000}},  //   _нафт, éine_, _fool_,
  { {0x7c2d03f1, 0x201300d4, 0x69d901a2, 0x00000000}},  //   kpar, _aixi_, nnwe,
  { {0xdbc6006c, 0x64a500e2, 0xdb0500f8, 0x00000000}},  //   mööb, _фала, lkhä,
  { {0x442d0018, 0x2d82128a, 0x7c2d0190, 0x00000000}},  //   mpe_, _sake_, dpar,
  { {0x442d0056, 0x2d82023a, 0x5fbb0061, 0x00000000}},  //   lpe_, _pake_, _उतरल,
  { {0x60000039, 0x201b128b, 0x442d0026, 0x00000000}},  //   döme, _fuqi_, ope_,
  { {0x442d0263, 0x90c30057, 0xfaf8001e, 0x00000000}},  // [2140] npe_, _объе, _šī_,
  { {0x7a0c005f, 0x442d128c, 0xdb1c044f, 0x00000000}},  //   _işti, ipe_, _områ,
  { {0x6da602e9, 0x2d820038, 0x65b50161, 0x00000000}},  //   _дина, _take_, _náho,
  { {0x7c2d128d, 0x673a0635, 0x442d01a3, 0x00000000}},  //   bpar, _setj, kpe_,
  { {0x661a0583, 0x673a128e, 0x7c2d0e07, 0x00000000}},  //   _sutk, _petj, cpar,
  { {0xe793012b, 0x661a00b0, 0x69d901d6, 0x00000000}},  //   дишњ, _putk, anwe,
  { {0xd5ba0517, 0x442d0007, 0x25a6109b, 0x00000000}},  //   иси_, epe_, _pool_,
  { {0x21f90428, 0x746a005c, 0x00000000, 0x00000000}},  //   vého_, аров_,   ,
  { {0x7c2905ff, 0x00000000, 0x00000000, 0x00000000}},  //   _çert,   ,   ,
  { {0x661a021e, 0x21f901ca, 0x25a60133, 0x00000000}},  //   _tutk, tého_, _wool_,
  { {0x741400d3, 0x25a600ab, 0x442d0adb, 0x00000000}},  //   _کوتا, _tool_, ape_,
  { {0xd46a007c, 0x21f90161, 0x7c2d128f, 0x00000000}},  //   _виде_, rého_, ypar,
  { {0x38660390, 0x321e0009, 0x55d90049, 0x00000000}},  //   ntor_, sqty_, _פֿענ,
  { {0x9f5a01aa, 0xa91d0006, 0x38661290, 0x00000000}},  //   _sipò_, _maža, itor_,
  { {0x7c2d1291, 0xa187007e, 0x0ef30044, 0x00000000}},  //   wpar, _дыпл, ছেনঃ_,
  { {0x3866020c, 0xd3780036, 0x65b501ca, 0x00000000}},  //   ktor_, leć_, _náhl,
  { {0xf1bf0051, 0xa91d0091, 0x38660065, 0x00000000}},  // [2150] mhá_, _naža, jtor_,
  { {0x7c2d1292, 0x66020093, 0xfc300025, 0x00000000}},  //   rpar, _lhok, ضحك_,
  { {0x7a40002a, 0x38660319, 0x442d1293, 0x00000000}},  //   _rátá, etor_, zpe_,
  { {0x442d0a59, 0x7e7a0049, 0x4e7a0049, 0x00000000}},  //   ype_, _פארז, _פארצ,
  { {0xf1b4009b, 0xd8b80076, 0x69d901a2, 0x00000000}},  //   וסף_, يدها_, rnwe,
  { {0xec36009b, 0xa91d0dec, 0x66020f45, 0x00000000}},  //   _מאשר_, _daža, _ahok,
  { {0x38661294, 0xdb0e0146, 0x00000000, 0x00000000}},  //   ator_, _albæ,   ,
  { {0x66020193, 0x31790036, 0xdb070065, 0x00000000}},  //   _chok, jesz_, _lojë,
  { {0x38661295, 0x442d028c, 0x31790010, 0x00000000}},  //   ctor_, upe_, desz_,
  { {0x442d1296, 0x65691297, 0x75d3001a, 0x00000000}},  //   rpe_, sfeh, văzu,
  { {0x6569001f, 0xa3ca02fb, 0x65151298, 0x00000000}},  //   pfeh, रोध_, _فوائ,
  { {0x442d1299, 0x216a0077, 0xd5b80089, 0x00000000}},  //   ppe_, щими_, _stāv_,
  { {0x6609129a, 0x43950088, 0x00000000, 0x00000000}},  //   mmek, _надс,   ,
  { {0x6609011f, 0x25bf00e0, 0x3f6a003b, 0x00000000}},  //   lmek, lhul_, љиво_,
  { {0xa3b803ec, 0xbcfb009d, 0x00000000, 0x00000000}},  //   _ظاهر_, _obés,   ,
  { {0x9c2600e3, 0x31790036, 0x6609129b, 0x00000000}},  //   здад, cesz_, nmek,
  { {0x90460025, 0x38660253, 0x1d07129c, 0x00000000}},  // [2160] _عنده, xtor_, зети_,
  { {0x0e66029b, 0xa91d129d, 0xdb070023, 0x00000000}},  //   _екон, _raža, _gojë,
  { {0x66091252, 0x25bf0022, 0xa91d04eb, 0x00000000}},  //   kmek, khul_, _saža,
  { {0x3866129e, 0x58860783, 0xd3780036, 0x00000000}},  //   ttor_, зыка, zeć_,
  { {0xd90d0167, 0xc18d0049, 0x6609006c, 0x00000000}},  //   لیف_, יטאָ, dmek,
  { {0x66020065, 0x3866129f, 0xa91d0091, 0x00000000}},  //   _shok, rtor_, _važa,
  { {0x7bce04e3, 0xad9b0048, 0x00000000, 0x00000000}},  //   _imbu, _mhún,   ,
  { {0x9adb00b6, 0xbcfb008e, 0x386612a0, 0x00000000}},  //   _החלט, _ibér, ptor_,
  { {0x6d4b0051, 0xa91d0091, 0x00000000, 0x00000000}},  //   ógai, _kažn,   ,
  { {0xad9b0011, 0x644f12a1, 0x00000000, 0x00000000}},  //   _nhún, ácia,   ,
  { {0xdcfd0089, 0x7bce0085, 0x00000000, 0x00000000}},  //   _masā, _mmbu,   ,
  { {0xa91d1279, 0x80ab0055, 0x25bf12a2, 0x00000000}},  //   _lažn, _চেষ্, chul_,
  { {0x7bce006b, 0x4420001a, 0xbcfb12a3, 0x00000000}},  //   _ombu, _îi_, _océa,
  { {0xad9b001d, 0xefc8005c, 0x00000000, 0x00000000}},  //   _chún, пуск_,   ,
  { {0xad9b0051, 0x00000000, 0x00000000, 0x00000000}},  //   _dhún,   ,   ,
  { {0x22f7009b, 0x7bce08d0, 0x63aa005b, 0x00000000}},  //   _מזון_, _ambu, _hofn,
  { {0xa91d0006, 0x6285000c, 0x00000000, 0x00000000}},  // [2170] _bažn, _áhor,   ,
  { {0x61ef0068, 0x7bce0085, 0x91fd0089, 0x00000000}},  //   locl, _cmbu, itām,
  { {0xa91d010a, 0xfe241001, 0x00000000, 0x00000000}},  //   _dažn, _пьян,   ,
  { {0x6aaa0073, 0x7bce01a3, 0x61ef0133, 0x00000000}},  //   äffa, _embu, nocl,
  { {0x2d9909eb, 0xdcfd01c5, 0x00000000, 0x00000000}},  //   _inse_, _fasā,   ,
  { {0xab84005e, 0xbcfb0051, 0x656200f6, 0x00000000}},  //   _пуск, _gcéa, _acoh,
  { {0x660912a4, 0x25bf12a5, 0x00000000, 0x00000000}},  //   tmek, thul_,   ,
  { {0x2d890eff, 0x75fe0065, 0x9f4a1128, 0x00000000}},  //   ndae_, tëza, robé_,
  { {0x91fd001e, 0x66091038, 0x443912a6, 0x00000000}},  //   rtāl, rmek, ès_,
  { {0x63aa12a7, 0xe3b10025, 0xe795025a, 0x00000000}},  //   _cofn, ئرة_, _تارک,
  { {0x91e600ed, 0x2d990007, 0x61ef0048, 0x00000000}},  //   доне, _onse_, focl,
  { {0x44b5007c, 0xa91d12a8, 0x61ef12a9, 0x00000000}},  //   _обес, _mažo, gocl,
  { {0xa3ca007d, 0x2d8901d6, 0x00000000, 0x00000000}},  //   रोह_, ddae_,   ,
  { {0x6b870213, 0x63aa0016, 0x3fcc0044, 0x00000000}},  //   _najg, _gofn, লক্ষ,
  { {0x394d0107, 0x248d00c4, 0xa91d016e, 0x00000000}},  //   _odes_, lvem_, _ražn,
  { {0xbcfb002a, 0x2616013d, 0x217601e1, 0x00000000}},  //   _scéa, _पंछी_, _цукр,
  { {0xdcfd001e, 0x64460107, 0x3fe6013b, 0x00000000}},  // [2180] _pasā, škiv, _ожив,
  { {0x394d00d4, 0x657b12aa, 0x00000000, 0x00000000}},  //   _ades_, heuh,   ,
  { {0xa91d0119, 0x00000000, 0x00000000, 0x00000000}},  //   _važn,   ,   ,
  { {0xe8fa12ab, 0x394d00fa, 0x00000000, 0x00000000}},  //   оле_, _cdes_,   ,
  { {0x6d440653, 0x00000000, 0x00000000, 0x00000000}},  //   maia,   ,   ,
  { {0x628312ac, 0x394d021e, 0x6d4412ad, 0x00000000}},  //   _osno, _edes_, laia,
  { {0xd90d026c, 0x5a55005e, 0xba2308fc, 0x00000000}},  //   لیہ_, _пъту, _адск,
  { {0x77b40129, 0x1dde013d, 0x6d440032, 0x00000000}},  //   _màxi, नचित, naia,
  { {0x186a003b, 0x62830288, 0x00000000, 0x00000000}},  //   _фази_, _asno,   ,
  { {0x6d44002d, 0x69c212ae, 0x69b40061, 0x00000000}},  //   haia, lhoe, _आवडी,
  { {0x6d440149, 0xc7d700b3, 0x973c04eb, 0x00000000}},  //   kaia, _קובי_, _noći,
  { {0x85060d3a, 0x225101ca, 0x69c200bb, 0x00000000}},  //   _قوان, ázka_, nhoe,
  { {0x6d44002d, 0x3c2412af, 0x64b603ab, 0x00000000}},  //   daia, _növ_, _تحار,
  { {0xafdb00ea, 0x00000000, 0x00000000, 0x00000000}},  //   msøk,   ,   ,
  { {0x6b8707b0, 0x6d4400fa, 0xafdb0056, 0x00000000}},  //   _rajg, faia, lsøk,
  { {0xa91d001e, 0x6d44065c, 0x973c01ee, 0x00000000}},  //   _ražo, gaia, _doći,
  { {0x2d8901d6, 0x75fe0023, 0x00000000, 0x00000000}},  // [2190] rdae_, hëzo,   ,
  { {0x2d890007, 0x09d70061, 0xe3b80180, 0x00000000}},  //   sdae_, ढच्य, nkı_,
  { {0x6d44002d, 0x248d01dc, 0x160e007d, 0x00000000}},  //   baia, zvem_, ागार_,
  { {0xd5a60445, 0xafdb00ea, 0x27e00048, 0x00000000}},  //   _صف_, ksøk, éinn_,
  { {0x6d4f12b0, 0xe3b8014a, 0x394d0065, 0x00000000}},  //   _idca, kkı_, _vdes_,
  { {0x65bc009d, 0xd7c804b1, 0x6d4f00d2, 0x00000000}},  //   _réha, وونه_, _hdca,
  { {0xd49200e5, 0x00000000, 0x00000000, 0x00000000}},  //   _arπ_,   ,   ,
  { {0x69c20181, 0x91fd0089, 0xff18009b, 0x00000000}},  //   choe, stāj, וקות_,
  { {0x60000039, 0x799b0058, 0xa9240161, 0x00000000}},  //   dömn, _inuw, _úžas,
  { {0xf77000a6, 0x65600051, 0xa3ca006e, 0x00000000}},  //   _نام_, agmh, रोल_,
  { {0xeb92007b, 0xe299003b, 0x00000000, 0x00000000}},  //   אָר_, чан_,   ,
  { {0xdb07009f, 0x56b60049, 0xafdb00ea, 0x00000000}},  //   _hljó, _אפען_, bsøk,
  { {0xbcfb12b1, 0x6d4400c4, 0xb143007e, 0x00000000}},  //   _scén, vaia, ынял,
  { {0x75290197, 0x6d4404cb, 0x7d1d00f6, 0x00000000}},  //   lcez, waia, _agss,
  { {0xdee30256, 0x644905da, 0x670f0309, 0x00000000}},  //   гори, lsei, ाधिक_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6449028c, 0x6d44065c, 0x6b560025, 0x00000000}},  // [21a0] nsei, raia, فضائ,
  { {0x7c2b12b2, 0x6d440653, 0x442f0a0b, 0x00000000}},  //   ígra, saia, _mtg_,
  { {0xc0a9007a, 0x443d12b3, 0x69c212b4, 0x00000000}},  //   _فایل_, _lww_, thoe,
  { {0xdca60072, 0x3940002a, 0xc86600e3, 0x00000000}},  //   _зами, úis_, етки,
  { {0x69c200c7, 0x79890011, 0xad1b009b, 0x00000000}},  //   rhoe, _daew, _מוכר,
  { {0x69c2046a, 0xc7a3005e, 0x61e40091, 0x00000000}},  //   shoe, личк, _ljil,
  { {0x69c20007, 0x644b00d8, 0x644901c3, 0x00000000}},  //   phoe, _avgi, esei,
  { {0x38cb089d, 0x9f4a01ca, 0x201a023a, 0x00000000}},  //   _کافی_, dobí_, _lipi_,
  { {0x69c0021e, 0xdb07000c, 0x91fd0089, 0x00000000}},  //   _ilme, _fljó, stāk,
  { {0xa3ca03d7, 0x61e4000b, 0x39460058, 0x00000000}},  //   रों_, _ajil, laos_,
  { {0xe3b8047f, 0xa15902e9, 0x443d12b5, 0x00000000}},  //   rkı_, ману_, _eww_,
  { {0x6449010f, 0x39460058, 0x75290197, 0x00000000}},  //   bsei, naos_, ccez,
  { {0x442f00e0, 0x61e401ee, 0x69c00022, 0x00000000}},  //   _gtg_, _djil, _mlme,
  { {0x6d4f0066, 0x41d201f5, 0x00000000, 0x00000000}},  //   _sdca, दोबस,   ,
  { {0x69c012b6, 0xa91d016c, 0x39460203, 0x00000000}},  //   _olme, _sažm, kaos_,
  { {0x61e40065, 0x3946071d, 0x00000000, 0x00000000}},  //   _gjil, jaos_,   ,
  { {0x394600e0, 0xa01b04ce, 0x00000000, 0x00000000}},  // [21b0] daos_, rvös,   ,
  { {0x69c012b7, 0x61fd03ed, 0x2a780022, 0x00000000}},  //   _alme, llsl, _bprb_,
  { {0x32090082, 0x290400e7, 0xb7b50082, 0x00000000}},  //   _khay_, _azma_, _lịc,
  { {0x201a00e7, 0x32370049, 0x3946004a, 0x00000000}},  //   _zipi_, גטאן_, gaos_,
  { {0x69c00045, 0x201a00f6, 0x186900e2, 0x00000000}},  //   _dlme, _yipi_, фали_,
  { {0x9a870265, 0x2d8b0219, 0xa91d010a, 0x00000000}},  //   _публ, _hace_, _kažk,
  { {0x2d8b0521, 0x442f009d, 0x00000000, 0x00000000}},  //   _kace_, _stg_,   ,
  { {0x644912b8, 0x442f01a3, 0x2d8b04eb, 0x00000000}},  //   tsei, _ptg_, _jace_,
  { {0x75290197, 0x2d8b0e0a, 0x291f00f6, 0x00000000}},  //   rcez, _mace_, _igua_,
  { {0x61f603b4, 0x7bc50082, 0xb7b50082, 0x00000000}},  //   _skyl, nhhu, _dịc,
  { {0x443d067b, 0x6449059e, 0x13090057, 0x00000000}},  //   _www_, ssei, ьной_,
  { {0x2d8b12b9, 0x320912ba, 0x442f12bb, 0x00000000}},  //   _nace_, _chay_, _ttg_,
  { {0x201a01a3, 0x442f12bc, 0x6446016c, 0x00000000}},  //   _pipi_, _utg_, škir,
  { {0x2b4300ca, 0x00000000, 0x00000000, 0x00000000}},  //   _nejc_,   ,   ,
  { {0x201a12bd, 0x2d8b0145, 0xdb070062, 0x00000000}},  //   _vipi_, _bace_, _bojí,
  { {0xd9bd0204, 0xc69200a3, 0xdb07004a, 0x00000000}},  //   ्फोट, סאן_, _cojí,
  { {0x201a057e, 0xa01b000c, 0x2d8b0089, 0x00000000}},  // [21c0] _tipi_, rvör, _dace_,
  { {0x291f0219, 0x25af0009, 0x00000000, 0x00000000}},  //   _agua_, _logl_,   ,
  { {0x68fb0219, 0x0f57007b, 0xcf5700b6, 0x00000000}},  //   _ayud, _ביים_, _בבית_,
  { {0x7e6e0009, 0x2d8b12be, 0x7a470010, 0x00000000}},  //   mtbp, _gace_, _sétá,
  { {0x2d80001a, 0x39460058, 0x63ba00ea, 0x00000000}},  //   meie_, raos_, yktn,
  { {0x2d8000ea, 0x2d8b0c51, 0x00000000, 0x00000000}},  //   leie_, _zace_,   ,
  { {0x692612bf, 0xfaa3007e, 0xaa4301ee, 0x00000000}},  //   _амба, _каро, _весл,
  { {0x5e570049, 0x24860b4a, 0xa2c5013d, 0x00000000}},  //   דיקע_, _psom_, ानन्,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3209103f, 0x394400eb, 0xa78512c0, 0x00000000}},  //   _shay_, _hems_, _مشمو,
  { {0xe3af0076, 0x2d800007, 0xd7ef0025, 0x00000000}},  //   تري_, keie_, _بكل_,
  { {0xb6d9007b, 0xa5da0257, 0x25af0045, 0x00000000}},  //   _אַנט, _غبار_, _gogl_,
  { {0x2d8b00ab, 0x61fd0146, 0x00000000, 0x00000000}},  //   _race_, rlsl,   ,
  { {0x040d0082, 0x394400c8, 0x00000000, 0x00000000}},  //   _mườn, _lems_,   ,
  { {0x3209001d, 0x2d8b12c1, 0xdb0e0065, 0x00000000}},  //   _thay_, _pace_, _dobë,
  { {0x60b500a1, 0x320900e0, 0x00000000, 0x00000000}},  //   _ممبئ, _uhay_,   ,
  { {0x7afc00c4, 0x00000000, 0x00000000, 0x00000000}},  // [21d0] _ayrt,   ,   ,
  { {0xe1ff12c2, 0x1ae70055, 0xad9b0051, 0x00000000}},  //   lló_, _করবে_, _mhúi,
  { {0x2d8b0375, 0xc9590025, 0x68fb0058, 0x00000000}},  //   _tace_, فلاش_, _syud,
  { {0xe1ff0047, 0xa91d016e, 0x68fb0058, 0x00000000}},  //   nló_, _kaži, _pyud,
  { {0x3da4008b, 0x040d0011, 0x7c220051, 0x00000000}},  //   _трэб, _cườn, íort,
  { {0xa91d010a, 0x040d0011, 0x7afc0c73, 0x00000000}},  //   _maži, _dườn, _fyrt,
  { {0xf770035b, 0x394400f6, 0xdb0e0173, 0x00000000}},  //   تان_, _fems_, _nobè,
  { {0xc7b8016c, 0x7f4501f3, 0x39440133, 0x00000000}},  //   _riđe_, _lehq, _gems_,
  { {0x7afc008d, 0xad9b002a, 0x9868026c, 0x00000000}},  //   _zyrt, _chúi, _لینے_,
  { {0x69d90e15, 0xd7740123, 0x52a90175, 0x00000000}},  //   liwe, _نامع, евом_,
  { {0x6146007e, 0xd57502be, 0xdb0e0065, 0x00000000}},  //   лена, _буль, _robë,
  { {0x69d91196, 0x60000039, 0xe1ff12c3, 0x00000000}},  //   niwe, römm, gló_,
  { {0x753b000b, 0xe3b30014, 0x00000000, 0x00000000}},  //   mbuz, _پرش_,   ,
  { {0x645b00c1, 0x3eb812c4, 0xe1ff004a, 0x00000000}},  //   mrui, tyrt_, aló_,
  { {0x3ebe009f, 0x69d90020, 0xe1ff12c5, 0x00000000}},  //   átt_, kiwe, bló_,
  { {0x69d90020, 0x753b00d9, 0x3f8c1238, 0x00000000}},  //   jiwe, nbuz, ždu_,
  { {0x2d8008db, 0xd00f00a1, 0x645b0882, 0x00000000}},  // [21e0] reie_, زلہ_, nrui,
  { {0x394412c6, 0x8b260cbc, 0x00000000, 0x00000000}},  //   _sems_, удже,   ,
  { {0x645b0051, 0x7c36000c, 0xe94400a1, 0x00000000}},  //   hrui, spyr, لرشی,
  { {0x91fd001e, 0x645b01bb, 0xa91d0161, 0x00000000}},  //   stāv, krui, _zaži,
  { {0x6d460089, 0x753b00d2, 0x00000000, 0x00000000}},  //   _ieka, dbuz,   ,
  { {0x91fd001e, 0x6d4612c7, 0xa6340088, 0x00000000}},  //   ltāt, _heka, анкі,
  { {0x6d46027e, 0xf1c101ca, 0xad9b0051, 0x00000000}},  //   _keka, ášky_, _shúi,
  { {0x545402b8, 0x645b0197, 0x040d0011, 0x00000000}},  //   авит, frui, _tườn,
  { {0x6d4612c8, 0xa2d90164, 0x136a005e, 0x00000000}},  //   _meka, _फेब्, ншни_,
  { {0x1ae708b7, 0x6d4610e9, 0x4274003b, 0x00000000}},  //   _করতে_, _leka, агос,
  { {0xb3450181, 0x7c2612c9, 0x75fe0065, 0x00000000}},  //   _seçã, _lukr, hëzi,
  { {0x6d4601d9, 0x645b015c, 0xd257008b, 0x00000000}},  //   _neka, brui, ыць_,
  { {0xa91d010a, 0x645b0d29, 0x7c2612ca, 0x00000000}},  //   _paži, crui, _nukr,
  { {0xa3e803d7, 0x69d910ba, 0x9f4a00c4, 0x00000000}},  //   _यदि_, ziwe, tobá_,
  { {0x6d4604d4, 0x4426000b, 0xa91d0006, 0x00000000}},  //   _beka, _huo_, _važi,
  { {0x6d4612cb, 0x628a002b, 0x44260006, 0x00000000}},  //   _ceka, _isfo, _kuo_,
  { {0x6d4600ef, 0x7c260161, 0x41c40380, 0x00000000}},  // [21f0] _deka, _cukr, _دقيق,
  { {0xf1bf01dc, 0x7c260006, 0x69d8009d, 0x00000000}},  //   lká_, _dukr, èven,
  { {0x442600b0, 0x6d4612cc, 0x3f83003b, 0x00000000}},  //   _luo_, _feka, meju_,
  { {0x89370054, 0x3ebe05b7, 0x6d4612cd, 0x00000000}},  //   اعضا, øtte_, _geka,
  { {0x442612ce, 0x69d912cf, 0x98a50594, 0x00000000}},  //   _nuo_, riwe, риле,
  { {0x62980047, 0xd2460355, 0x7bd5010f, 0x00000000}},  //   _orvo, _ون_, _umzu,
  { {0x44260203, 0xf40a0044, 0x00000000, 0x00000000}},  //   _auo_, রদার_,   ,
  { {0x4426011c, 0xf773025a, 0x3dc90022, 0x00000000}},  //   _buo_, _گار_, nhaw_,
  { {0x6298021e, 0x4426037e, 0x05a6007c, 0x00000000}},  //   _arvo, _cuo_, рвый_,
  { {0xf773004b, 0xe299012b, 0x645b0112, 0x00000000}},  //   _دار_, вао_, rrui,
  { {0x645b00bb, 0x3f83007f, 0xd5ae02fd, 0x00000000}},  //   srui, deju_, سفی_,
  { {0x645b040f, 0x628a0146, 0xa246009e, 0x00000000}},  //   prui, _dsfo, جیٹل_,
  { {0x6d4612d0, 0x628a0a0a, 0x629800b5, 0x00000000}},  //   _reka, _esfo, _ervo,
  { {0x6d46020c, 0x91fd0089, 0xbcfb0051, 0x00000000}},  //   _seka, tuāc, _gcéi,
  { {0x6d460169, 0x7c260dc6, 0x00000000, 0x00000000}},  //   _peka, _sukr,   ,
  { {0xf1bf0428, 0x65b50027, 0x44260173, 0x00000000}},  //   cká_, _záhr, _yuo_,
  { {0xd7c50061, 0x6d460483, 0x0b46007c, 0x00000000}},  // [2200] वसाच, _veka, инан,
  { {0x75fe008d, 0x91fd12d1, 0x6d4600d9, 0x00000000}},  //   rëzi, grāf, _weka,
  { {0xa91d0b4d, 0x6d4612d2, 0xa926007c, 0x00000000}},  //   _mažu, _teka, адел,
  { {0x25ad12d3, 0xda650025, 0x00000000, 0x00000000}},  //   jjel_, صامي,   ,
  { {0xe894085f, 0xd3780243, 0x83fd0010, 0x00000000}},  //   саль, liće_, ntős,
  { {0x91fd0580, 0xd90d00e9, 0x75220026, 0x00000000}},  //   ntār, ریل_, _sgoz,
  { {0x44260198, 0x4b7b019b, 0x64420046, 0x00000000}},  //   _suo_, _שאלו, _swoi,
  { {0x2d920607, 0xbcfb002a, 0x44260207, 0x00000000}},  //   ndye_, _scéi, _puo_,
  { {0xa4d4007e, 0x98bd0036, 0x00000000, 0x00000000}},  //   сопі, tawą_,   ,
  { {0x629804a3, 0xa507003b, 0x7e7e00e0, 0x00000000}},  //   _prvo, шења_, _oppp,
  { {0x3f830006, 0x9f430023, 0x98bd00b4, 0x00000000}},  //   veju_, snjë_, rawą_,
  { {0x442612d4, 0xf1d20164, 0x64420036, 0x00000000}},  //   _tuo_, दोलन, _twoi,
  { {0xe3af04e1, 0xdb0e011f, 0x75d30025, 0x00000000}},  //   سری_, _albü, _بينا,
  { {0xf1bf004f, 0x33f30445, 0x00000000, 0x00000000}},  //   ská_, _وسوس,   ,
  { {0x3f8312d5, 0x245200a1, 0x3dc900e0, 0x00000000}},  //   reju_, _انڈس, thaw_,
  { {0x3dc900e0, 0x82330379, 0x00000000, 0x00000000}},  //   uhaw_, _بروا,   ,
  { {0x91fd0089, 0x3f8301ee, 0x26e2013d, 0x00000000}},  // [2210] stās, peju_, गपुर_,
  { {0x60c00737, 0xd3780107, 0x3dc90675, 0x00000000}},  //   ømme, biće_, shaw_,
  { {0x200312d6, 0x6e950054, 0xd378012d, 0x00000000}},  //   mlji_, _الجا, ciće_,
  { {0x62860036, 0xaa580cb3, 0xdb0e004a, 0x00000000}},  //   łkow, рицу_, _albó,
  { {0x9f5100b9, 0x97d90f4e, 0x1821007d, 0x00000000}},  //   hozí_, льку_, मदेव_,
  { {0x26e20061, 0x6819000a, 0x600000b0, 0x00000000}},  //   गपूर_, _kňdi, tömi,
  { {0x7bc70066, 0x7c2d006b, 0x75fe0023, 0x00000000}},  //   _ilju, lqar, hëzu,
  { {0x59f90057, 0x6d4d025e, 0x3940009f, 0x00000000}},  //   _себя_, naaa, ðist_,
  { {0x7bc70bf8, 0x38600009, 0x7c2d12d7, 0x00000000}},  //   _klju, àirt_, nqar,
  { {0x68e40051, 0x25bf0093, 0xd6db0467, 0x00000000}},  //   úide, skul_, _ите_,
  { {0x6d4d0058, 0x27e700e0, 0x57fa0049, 0x00000000}},  //   kaaa, mnnn_, _עלעו,
  { {0xd3780107, 0xad9b0051, 0x930d0095, 0x00000000}},  //   viće_, _mhús, _ışık,
  { {0x34ab0025, 0x7bc712d8, 0x61e600f8, 0x00000000}},  //   _جداً_, _olju, rnkl,
  { {0x656901d6, 0x27e712d9, 0x6d4b000c, 0x00000000}},  //   lgeh, nnnn_, ðgan,
  { {0xada60680, 0x6da60081, 0x75fe0065, 0x00000000}},  //   бавл, бива, rëzv,
  { {0xd3780209, 0x6d4d001c, 0x6569010f, 0x00000000}},  //   riće_, gaaa, ngeh,
  { {0xd3780521, 0x9f580065, 0x69d8009d, 0x00000000}},  // [2220] siće_, norë_, èvem,
  { {0x6d4d001c, 0x65bc00f4, 0x7f860054, 0x00000000}},  //   aaaa, _véhi, _الدن,
  { {0x387f002d, 0x6d4d12da, 0xdb0e0173, 0x00000000}},  //   _apur_, baaa, _albò,
  { {0x6d4d001c, 0x27e90051, 0xdb1c0039, 0x00000000}},  //   caaa, éann_, _omrö,
  { {0x28d20316, 0xfbd100a1, 0x7bc7012d, 0x00000000}},  //   _देखि, ستے_, _flju,
  { {0xab2700ed, 0x3a3a0058, 0x7bc712db, 0x00000000}},  //   _гора_, pppp_, _glju,
  { {0x65690dcc, 0x7bde01a3, 0x8f9b009b, 0x00000000}},  //   fgeh, mipu, טיסי,
  { {0x7bde0169, 0x69cb12dc, 0x6569046a, 0x00000000}},  //   lipu, chge, ggeh,
  { {0xc34a09b2, 0xdb0e12dd, 0x00000000, 0x00000000}},  //   ляне_, _mobí,   ,
  { {0x325403f3, 0xd62a003b, 0xdcef0089, 0x00000000}},  //   овор, _боже_, _sacī,
  { {0xd5af005e, 0x6d4d1084, 0xa2a80061, 0x00000000}},  //   _ес_, yaaa, टमध्,
  { {0x645d0211, 0x7bde0be4, 0x31c7007c, 0x00000000}},  //   ásic, hipu, ссов,
  { {0x7bde12de, 0x644f004a, 0x69c20288, 0x00000000}},  //   kipu, ácit, ikoe,
  { {0x02a602dc, 0x75fe0065, 0xe29a0082, 0x00000000}},  //   _грим, rëzu, _trư_,
  { {0x6d4d001c, 0x7bde0c2f, 0x6377009b, 0x00000000}},  //   taaa, dipu, _הגוף_,
  { {0x1ae70055, 0x7c2d12df, 0x7bcb01c5, 0x00000000}},  //   _করলে_, tqar, īgum,
  { {0x22ae006b, 0x7bc70825, 0xcf8e0014, 0x00000000}},  // [2230] dəki_, _plju, رژی_,
  { {0xad9b0051, 0x6d4d12e0, 0x61ed03b4, 0x00000000}},  //   _chúr, saaa, _hjal,
  { {0x387f01a2, 0x61ed000c, 0x7bc700ca, 0x00000000}},  //   _spur_, _kjal, _vlju,
  { {0x394912e1, 0x6d4d0045, 0xdb0e00e5, 0x00000000}},  //   úas_, qaaa, _bobâ,
  { {0x27e9008e, 0x61ed12e2, 0x00000000, 0x00000000}},  //   éano_, _mjal,   ,
  { {0x98480a78, 0xdb0e001a, 0x207c0049, 0x00000000}},  //   сяца_, _dobâ, טאדא,
  { {0x61ed0211, 0x3ffc0049, 0x656912e3, 0x00000000}},  //   _ojal, אפגע, tgeh,
  { {0xe459012b, 0x9f580065, 0x8beb0044, 0x00000000}},  //   ажи_, torë_, _কঠিন_,
  { {0x6569010f, 0x69c90288, 0x00000000, 0x00000000}},  //   rgeh, _ilee,   ,
  { {0x61ed12e4, 0x394f000c, 0xd7fb0106, 0x00000000}},  //   _ajal, lags_, _суб_,
  { {0xf77006c6, 0x69c9017d, 0x9f580065, 0x00000000}},  //   _سال_, _klee, sorë_,
  { {0x216a004c, 0x9f5800d6, 0xb1da0088, 0x00000000}},  //   шими_, moré_, рьох_,
  { {0x61ed008d, 0xd00a0c96, 0x9f58009d, 0x00000000}},  //   _djal, иеме_, loré_,
  { {0xee3a0057, 0xd9b6013d, 0x69c212e5, 0x00000000}},  //   инг_, _अक्ट, zkoe,
  { {0x61ed12e6, 0x80db0055, 0x98bd0036, 0x00000000}},  //   _fjal, _যুদ্, rawę_,
  { {0x61ed12e7, 0xc692012f, 0x80660769, 0x00000000}},  //   _gjal, ואל_, _движ,
  { {0x7bde12e8, 0x394f0332, 0xd3780091, 0x00000000}},  // [2240] tipu, dags_, lića_,
  { {0x69db008e, 0x69c912e9, 0x81ac0044, 0x00000000}},  //   _amue, _alee, _গতি_,
  { {0x8eb300a1, 0xdb1501aa, 0x7bde12ea, 0x00000000}},  //   _ہمیش, _jozè, ripu,
  { {0x7ae305f4, 0x609700a1, 0x7bde00b0, 0x00000000}},  //   únta, _انیس_, sipu,
  { {0xd3780107, 0x69c20116, 0x91fd0089, 0x00000000}},  //   hića_, rkoe, duāl,
  { {0x69c20215, 0xa09b00a3, 0x5fce0061, 0x00000000}},  //   skoe, יינט, होचल,
  { {0x394f0719, 0xeb91007b, 0x69c90133, 0x00000000}},  //   bags_, _אָן_, _flee,
  { {0x69c9020f, 0xd3780091, 0x35f703ec, 0x00000000}},  //   _glee, dića_, يريد_,
  { {0xb7e602dc, 0x6b990048, 0x38660133, 0x00000000}},  //   _джак, _éagó, quor_,
  { {0x61ed000c, 0x9f58009d, 0x7de50006, 0x00000000}},  //   _sjal, boré_, rėsi,
  { {0xd3780107, 0x69c9021e, 0x86560084, 0x00000000}},  //   gića_, _ylee, _ذخائ,
  { {0x20180023, 0x1aec0044, 0x00000000, 0x00000000}},  //   emri_, _করাই_,   ,
  { {0xc953019b, 0xa50700e3, 0x7bdc046a, 0x00000000}},  //   ומר_, _деца_, _omru,
  { {0x425500a1, 0xcf270025, 0xd37804eb, 0x00000000}},  //   _کنٹر, ترحي, bića_,
  { {0xcddb098c, 0x25a600d9, 0x61ed000c, 0x00000000}},  //   ања_, _knol_, _tjal,
  { {0x7bdc0557, 0xad9b0048, 0x00000000, 0x00000000}},  //   _amru, _chúp,   ,
  { {0x61fd008e, 0xbcfb0249, 0x00000000, 0x00000000}},  // [2250] mosl, _acér,   ,
  { {0x69c900ab, 0x9f43004a, 0x61fd0142, 0x00000000}},  //   _slee, rojó_, losl,
  { {0x8ae701fb, 0xaa950025, 0x69c90168, 0x00000000}},  //   ціал, ثلاث, _plee,
  { {0x61fd0107, 0x63b80107, 0x3a2400e5, 0x00000000}},  //   nosl, _lovn, _cimp_,
  { {0x394f125b, 0x69c900c7, 0xe73900e3, 0x00000000}},  //   rags_, _vlee, бел_,
  { {0x2904018e, 0x61fd0142, 0x63b8016c, 0x00000000}},  //   _dyma_, hosl, _novn,
  { {0x61fd00b9, 0x91fd0089, 0x212912eb, 0x00000000}},  //   kosl, tuāl, _ogah_,
  { {0xd37801cd, 0xd90e00a1, 0x38600051, 0x00000000}},  //   vića_, ئیے_, áirc_,
  { {0x61fd09fc, 0x478b0057, 0x63b8012d, 0x00000000}},  //   dosl, _всем_, _bovn,
  { {0x7bc512ec, 0xd3780091, 0x394d12ed, 0x00000000}},  //   nkhu, tića_, _hees_,
  { {0x88bd0055, 0x6b9512ee, 0x394d00bb, 0x00000000}},  //   _অধিক, _mazg, _kees_,
  { {0xd3780182, 0x249d0016, 0x2001033b, 0x00000000}},  //   rića_, _trwm_, _akhi_,
  { {0x394d12ef, 0xd9bd0044, 0x7bc50022, 0x00000000}},  //   _mees_, _আগাম, kkhu,
  { {0x4375007b, 0x394d0100, 0x443f020c, 0x00000000}},  //   _זײַן_, _lees_, mpu_,
  { {0x443f018e, 0x6012009f, 0x6da6004d, 0x00000000}},  //   lpu_, væmd, пива,
  { {0xc8bd007d, 0x62830197, 0x7bc50116, 0x00000000}},  //   ्नाट, _ipno, ekhu,
  { {0xdd8f031d, 0x443f000a, 0x3c66007e, 0x00000000}},  // [2260] دوق_, npu_, якаг,
  { {0x3a2412f0, 0x443f00c4, 0x60000039, 0x00000000}},  //   _simp_, ipu_, röms,
  { {0x394d0436, 0x3a240d29, 0xc7b801ed, 0x00000000}},  //   _bees_, _pimp_, _rođ_,
  { {0x2d8901ee, 0x394d00bb, 0x32360049, 0x00000000}},  //   ceae_, _cees_, לטען_,
  { {0x6d4412f1, 0x394d01d6, 0x18670849, 0x00000000}},  //   mbia, _dees_, зачи_,
  { {0x3f98001a, 0x6d440006, 0x394d12f2, 0x00000000}},  //   ndru_, lbia, _eees_,
  { {0x3a24000d, 0x63b80428, 0x2bc10061, 0x00000000}},  //   _timp_, _rovn, _शकता,
  { {0x394d0343, 0x6fcb01df, 0x3f8a12f3, 0x00000000}},  //   _gees_, _müca, hebu_,
  { {0x61fd0c8a, 0x443f12f4, 0x628304e7, 0x00000000}},  //   vosl, gpu_, _apno,
  { {0x260a0061, 0x6027009d, 0x883b009b, 0x00000000}},  //   ातही_, hémè, _לתמו,
  { {0x61fd12f5, 0x63b812f6, 0xd6c40014, 0x00000000}},  //   tosl, _vovn, _تمای,
  { {0x25a60016, 0xdceb0e54, 0x3f980089, 0x00000000}},  //   _unol_, _žičn, edru_,
  { {0x61fd01ca, 0x859b009b, 0x53a60088, 0x00000000}},  //   rosl, _לשאו, _надб,
  { {0xb7bd001a, 0x3f8a12f7, 0x00000000, 0x00000000}},  //   _puţi, gebu_,   ,
  { {0x61fd01d9, 0x6b950295, 0xddd012f8, 0x00000000}},  //   posl, _razg, _šeši,
  { {0x7c3f0045, 0x660200d9, 0x00000000, 0x00000000}},  //   tpqr, _jkok,   ,
  { {0x394d005b, 0x7de50006, 0x3f8a012d, 0x00000000}},  // [2270] _rees_, dėst, bebu_,
  { {0xfe6e06c6, 0xbca40025, 0x60cf005d, 0x00000000}},  //   دگی_, عملي, ınmı,
  { {0x6d440ef1, 0x7bc501d6, 0x6b95014a, 0x00000000}},  //   bbia, rkhu, _vazg,
  { {0x3ebe12f9, 0x66020045, 0x3eac068f, 0x00000000}},  //   ätte_, _nkok, ådte_,
  { {0x31580476, 0x8819007e, 0x394d010e, 0x00000000}},  //   ליאן_, оўку_, _vees_,
  { {0x394d0343, 0x6d4f00ca, 0x7de50023, 0x00000000}},  //   _wees_, _heca, rėsu,
  { {0x6d4f0169, 0x394d0133, 0x00000000, 0x00000000}},  //   _keca, _tees_,   ,
  { {0x84590898, 0x1994007e, 0x7c27008a, 0x00000000}},  //   орот_, _пася, _hijr,
  { {0x8554007a, 0x6f0900b9, 0x6add01f5, 0x00000000}},  //   ریور_, řech, _मधुर,
  { {0x443f0006, 0x6d4f12fa, 0x00000000, 0x00000000}},  //   rpu_, _leca,   ,
  { {0x7c2f000d, 0x2bae0061, 0x6d440016, 0x00000000}},  //   _lucr, घाता, ybia,
  { {0x443f12fb, 0x6d4f12fc, 0x798b0016, 0x00000000}},  //   ppu_, _neca, negw,
  { {0xc4fb0014, 0x660912fd, 0x224012ac, 0x00000000}},  //   _اعضا_, mlek, _čike_,
  { {0x66090004, 0x6d5d12fe, 0x661b0205, 0x00000000}},  //   llek, _adsa, lmuk,
  { {0x6d4f0038, 0x442f000c, 0x3f8a0016, 0x00000000}},  //   _beca, _hug_, rebu_,
  { {0x442712ff, 0x7e61000c, 0x6d4f01a3, 0x00000000}},  //   _hin_, álpa, _ceca,
  { {0x6d44010a, 0xfce300ec, 0x442f0065, 0x00000000}},  // [2280] rbia, вото, _jug_,
  { {0x6d440365, 0x8bf10055, 0x442f1300, 0x00000000}},  //   sbia, _জীবন_, _mug_,
  { {0x442704d7, 0x442f1301, 0x6e261302, 0x00000000}},  //   _min_, _lug_, _tikb,
  { {0x44271303, 0x6d4f00bb, 0x442f0035, 0x00000000}},  //   _lin_, _geca, _oug_,
  { {0xa3cd0164, 0x66090646, 0xf4e80044, 0x00000000}},  //   रसा_, dlek, _পর্ব,
  { {0x442701f6, 0x66090020, 0xb8d6013d, 0x00000000}},  //   _nin_, elek, _छप_,
  { {0xd6d00054, 0x443d0093, 0x260a0061, 0x00000000}},  //   طقة_, _atw_, ातली_,
  { {0xd5b00054, 0x443d00b5, 0x442701a3, 0x00000000}},  //   افة_, _btw_, _ain_,
  { {0x442f1304, 0x92ea0044, 0x443d0d28, 0x00000000}},  //   _cug_, _মরে_, _ctw_,
  { {0xa3d803d7, 0x3946010a, 0xe8d700b3, 0x00000000}},  //   ठों_, lbos_, _חומר_,
  { {0x44271305, 0xbcfb1306, 0x66091016, 0x00000000}},  //   _din_, _idée, blek,
  { {0x44270c85, 0x7dc3006c, 0xf6690025, 0x00000000}},  //   _ein_, _tõsi, _رحمه_,
  { {0x44270e6d, 0x29f8016e, 0xf77100a1, 0x00000000}},  //   _fin_, mčad_, _جاۓ_,
  { {0x6d4f0149, 0x442701aa, 0x9f430065, 0x00000000}},  //   _seca, _gin_, mijë_,
  { {0x6d4f01a3, 0x7c2f00f4, 0x442f010f, 0x00000000}},  //   _peca, _sucr, _zug_,
  { {0x44271307, 0xa01b010f, 0x7c2f00fa, 0x00000000}},  //   _zin_, gwör, _pucr,
  { {0x6d4f1308, 0x4427013f, 0x00000000, 0x00000000}},  // [2290] _veca, _yin_,   ,
  { {0x2fc7001d, 0x44271309, 0x60c00039, 0x00000000}},  //   _ông_, _xin_, ämme,
  { {0x6d4f014a, 0x798b04c0, 0xf09f00f6, 0x00000000}},  //   _teca, tegw, lvà_,
  { {0x6d5d0030, 0x38660016, 0x7f55004a, 0x00000000}},  //   _udsa, fror_, lazq,
  { {0xdd3a012e, 0x798b130a, 0x660900ca, 0x00000000}},  //   _מערכ, regw, vlek,
  { {0xe739007c, 0xa6950098, 0xe6110014, 0x00000000}},  //   чек_, ериј, گشت_,
  { {0x44270811, 0x2d99130b, 0x27e905fa, 0x00000000}},  //   _rin_, _kase_, đan_,
  { {0x4427130c, 0xfc3f0051, 0x38660d2b, 0x00000000}},  //   _sin_, _tríd_, bror_,
  { {0x4427130d, 0x66090039, 0x661b0169, 0x00000000}},  //   _pin_, rlek, rmuk,
  { {0xe3b10054, 0x78a6000c, 0x6609014a, 0x00000000}},  //   ارة_, _ákva, slek,
  { {0x44270263, 0x660901d6, 0x0394007e, 0x00000000}},  //   _vin_, plek, трыя,
  { {0x2d99037e, 0x442f130e, 0x76430022, 0x00000000}},  //   _nase_, _tug_, mpny,
  { {0x44270a60, 0x00000000, 0x00000000, 0x00000000}},  //   _tin_,   ,   ,
  { {0x25bd1163, 0x4427023a, 0xd0120464, 0x00000000}},  //   _howl_, _uin_, الس_,
  { {0x91e601e0, 0x39460006, 0xdb1c01df, 0x00000000}},  //   _поке, ybos_, üzün,
  { {0x2d99130f, 0xdb1c00f4, 0x00000000, 0x00000000}},  //   _case_, _forê,   ,
  { {0xa3c3001c, 0x3dd2018e, 0x8fa60088, 0x00000000}},  // [22a0] _एका_, rhyw_, _запе,
  { {0xfc3f002a, 0x61e601f6, 0x395f001a, 0x00000000}},  //   _dtí_, likl, _adus_,
  { {0x160f013d, 0x66000020, 0xc3210044, 0x00000000}},  //   ातार_, yomk, পুরি_,
  { {0x61e607e4, 0x39460e20, 0x38660f3f, 0x00000000}},  //   nikl, ubos_, tror_,
  { {0xe894085f, 0x6d56049d, 0x3946049a, 0x00000000}},  //   таль, maya, rbos_,
  { {0x6d560149, 0x2d991310, 0x38661311, 0x00000000}},  //   laya, _zase_, rror_,
  { {0x66000062, 0xd90d00a1, 0xdb1c0065, 0x00000000}},  //   tomk, میہ_, _morë,
  { {0xceb300b6, 0x6d561312, 0x3f9a001e, 0x00000000}},  //   ריה_, naya, _lapu_,
  { {0x186701f9, 0x61e61313, 0x2ca00190, 0x00000000}},  //   _пати_, dikl, nvid_,
  { {0x6d560831, 0xb35600a6, 0xb34600c4, 0x00000000}},  //   haya, ریبا_, diçõ,
  { {0x6d561314, 0xd2570088, 0x61e60095, 0x00000000}},  //   kaya, нця_, fikl,
  { {0x6d560127, 0xab64014a, 0x25bd002b, 0x00000000}},  //   jaya, ldüğ, _gowl_,
  { {0x1ae70055, 0x6d560169, 0x7dca0428, 0x00000000}},  //   _করছে_, daya, _výsl,
  { {0x6fcb005f, 0x2d99001a, 0x2ca00039, 0x00000000}},  //   _gücl, _sase_, dvid_,
  { {0x2d990607, 0x2d801315, 0xdb1c0065, 0x00000000}},  //   _pase_, ffie_, _dorë,
  { {0x32530265, 0x6d561316, 0xb3460181, 0x00000000}},  //   _свър, gaya, biçõ,
  { {0x2d99037e, 0xacf80088, 0xdb150161, 0x00000000}},  // [22b0] _vase_, енту_, _vozí,
  { {0xdb1c0173, 0x9f5800f6, 0xa2c50061, 0x00000000}},  //   _korè, corà_, ानच्,
  { {0x6d561317, 0x3a750816, 0x20030006, 0x00000000}},  //   baya, тлер, moji_,
  { {0x20031318, 0x9f5800c4, 0x6d561319, 0x00000000}},  //   loji_, porã_, caya,
  { {0x7dda00b9, 0x83fd0010, 0xa01b000c, 0x00000000}},  //   růst, rtőz, rtöf,
  { {0x61e604a0, 0x20030006, 0x00000000, 0x00000000}},  //   zikl, noji_,   ,
  { {0x34c9013d, 0x00000000, 0x00000000, 0x00000000}},  //   िन्द,   ,   ,
  { {0x20030020, 0x00000000, 0x00000000, 0x00000000}},  //   hoji_,   ,   ,
  { {0x61e60378, 0x2240131a, 0x20030062, 0x00000000}},  //   vikl, _čika_, koji_,
  { {0xd759004b, 0xe4c80025, 0xf7700380, 0x00000000}},  //   _آلات_, عبين_, _هام_,
  { {0x61e60004, 0x27e7009f, 0x6d56006a, 0x00000000}},  //   tikl, minn_, yaya,
  { {0x27e7131b, 0xe3b1089d, 0xb34600c4, 0x00000000}},  //   linn_, ارک_, tiçõ,
  { {0x61e6131c, 0x799b107e, 0xc952009b, 0x00000000}},  //   rikl, _mauw, סמך_,
  { {0x200301d9, 0x61e6011f, 0xb3460181, 0x00000000}},  //   goji_, sikl, riçõ,
  { {0x6d56006a, 0xb3460181, 0x645b0116, 0x00000000}},  //   taya, siçõ, lsui,
  { {0x27e7131d, 0x799b131e, 0x69cb00bb, 0x00000000}},  //   hinn_, _nauw, jkge,
  { {0x27e7009f, 0x61e4131f, 0x645b01c3, 0x00000000}},  // [22c0] kinn_, _imil, nsui,
  { {0x6d56011f, 0x80db0055, 0xfaa61320, 0x00000000}},  //   saya, _যুক্, казо,
  { {0x6d560760, 0x81f70123, 0x7c360065, 0x00000000}},  //   paya, _سفیر_, sqyr,
  { {0x5e57007b, 0x186a00e2, 0x645b0052, 0x00000000}},  //   _ביטע_, дади_, ksui,
  { {0x27e7000c, 0xf7721095, 0x76410006, 0x00000000}},  //   finn_, لاغ_, _atly,
  { {0x27e70fde, 0xf09300a3, 0x00000000, 0x00000000}},  //   ginn_, ינד_,   ,
  { {0xbcfb1321, 0xd6cf006d, 0x7dc3006c, 0x00000000}},  //   _idéa, يقه_, _tõst,
  { {0x6b9c0149, 0xd87600a1, 0x69cb010f, 0x00000000}},  //   _harg, _لائب, ckge,
  { {0xb4be02f4, 0x3949027b, 0x6b9c0612, 0x00000000}},  //   ीने_, ñase_, _karg,
  { {0x61e40994, 0x6b9c0145, 0x799b0036, 0x00000000}},  //   _amil, _jarg, _zauw,
  { {0xa3e302d2, 0x6b9c124c, 0xd6c4089d, 0x00000000}},  //   _नगर_, _marg, _حمای,
  { {0x79820a44, 0xdb1c1184, 0x61e401ee, 0x00000000}},  //   nfow, _coré, _cmil,
  { {0x20031322, 0xdb1c009d, 0xf99300b3, 0x00000000}},  //   toji_, _doré, ברר_,
  { {0x61e40207, 0x6b9c1323, 0xbcfb002a, 0x00000000}},  //   _emil, _narg, _ndéa,
  { {0x20030059, 0x9e0701fb, 0xdb1c0051, 0x00000000}},  //   roji_, вчал, _foré,
  { {0x200300ca, 0xd3780166, 0x27e70173, 0x00000000}},  //   soji_, dići_, zinn_,
  { {0x27e70f99, 0x3209011c, 0x799b00bb, 0x00000000}},  // [22d0] yinn_, _ikay_, _rauw,
  { {0x6b9c0c2e, 0xfc3f008e, 0x2003006b, 0x00000000}},  //   _carg, _cría_, qoji_,
  { {0x6b9c0abe, 0x69c000b5, 0x799b0058, 0x00000000}},  //   _darg, _bome, _pauw,
  { {0x6442002d, 0x645b01d6, 0x27e7010f, 0x00000000}},  //   _otoi, ysui, winn_,
  { {0x27e71324, 0x26c7018e, 0x6b9c0056, 0x00000000}},  //   tinn_, wyno_, _farg,
  { {0x6b9c1325, 0x62980091, 0x628a0030, 0x00000000}},  //   _garg, _osvo, _opfo,
  { {0x27e70a4e, 0x3209011c, 0x69c0049a, 0x00000000}},  //   rinn_, _okay_, _fome,
  { {0x27e71326, 0x69c01327, 0x09ca0055, 0x00000000}},  //   sinn_, _gome, লোবা,
  { {0x6b9c014a, 0x3f91002d, 0x753b0026, 0x00000000}},  //   _yarg, kezu_, rcuz,
  { {0x69c000b5, 0x6b9c11c7, 0x3a2d1328, 0x00000000}},  //   _zome, _xarg, _hiep_,
  { {0xdb1c0181, 0x645b1329, 0x422602be, 0x00000000}},  //   _poré, ssui, лдов,
  { {0xa06a012b, 0x9f4e0161, 0xcb12009b, 0x00000000}},  //   нама_, čník_, מלי_,
  { {0x6fcb010f, 0xa91d0006, 0xd3780107, 0x00000000}},  //   _küch, _pažy, zići_,
  { {0x3a2d00bb, 0x83350049, 0xdee60a85, 0x00000000}},  //   _liep_, _גאַס_, гоги,
  { {0x2fc501e5, 0x00000000, 0x00000000, 0x00000000}},  //   ölga_,   ,   ,
  { {0x6b9c0089, 0xa01b0010, 0x68fb006b, 0x00000000}},  //   _sarg, gtöb, _oxud,
  { {0x6b9c006c, 0xb88600b9, 0x5baa132a, 0x00000000}},  // [22e0] _parg, _kníž, нкам_,
  { {0x69c00038, 0x628a0009, 0xd37811af, 0x00000000}},  //   _some, _ypfo, tići_,
  { {0x69c0132b, 0x68fb081d, 0xc33200b6, 0x00000000}},  //   _pome, _axud, צוא_,
  { {0x6b9c0149, 0xd378016e, 0x9f580129, 0x00000000}},  //   _warg, rići_, forç_,
  { {0x6b9c0a44, 0x17540827, 0x2d92011f, 0x00000000}},  //   _targ, авля, meye_,
  { {0x6fcb001f, 0x69c00038, 0x78a20161, 0x00000000}},  //   _rück, _wome, rvov,
  { {0x6442048c, 0x69c00036, 0xa2630082, 0x00000000}},  //   _stoi, _tome, _quố,
  { {0x2d92132c, 0x7c2e132d, 0x20d70061, 0x00000000}},  //   neye_, _hibr, डनमध,
  { {0xf7460069, 0x98a30069, 0x98760545, 0x00000000}},  //   _безо, _лите, _љубљ,
  { {0x7c2e0066, 0x08c3013b, 0x2d920045, 0x00000000}},  //   _jibr, _убун, heye_,
  { {0x8646132e, 0x2d92132c, 0x0bb700b3, 0x00000000}},  //   _снеж, keye_, אלים_,
  { {0xf651026c, 0x6fcb01a2, 0x00000000, 0x00000000}},  //   _گئے_, _züch,   ,
  { {0x7c2e002a, 0x2d920095, 0x3f9104eb, 0x00000000}},  //   _oibr, deye_, tezu_,
  { {0x403400e2, 0xf651009e, 0x00000000, 0x00000000}},  //   серс, _دئے_,   ,
  { {0x6298037e, 0x442e0912, 0x25af005b, 0x00000000}},  //   _usvo, _iif_, _yngl_,
  { {0x7c2e002a, 0x442e00f8, 0x32090487, 0x00000000}},  //   _aibr, _hif_, _ukay_,
  { {0x442e0f68, 0x3b550603, 0xdb6b0088, 0x00000000}},  // [22f0] _kif_, икар, ерел_,
  { {0x3a2d00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _siep_,   ,   ,
  { {0x7c2e132f, 0x442e04a5, 0xfc3f000c, 0x00000000}},  //   _dibr, _mif_, _grín_,
  { {0x442e0145, 0x2d920095, 0x6fcb01a2, 0x00000000}},  //   _lif_, ceye_, _süch,
  { {0x6d4d1330, 0xbcfb009d, 0x442e06ed, 0x00000000}},  //   mbaa, _idéo, _oif_,
  { {0xdcfd001e, 0xf771002c, 0x7c2e0007, 0x00000000}},  //   _lasī, زات_, _gibr,
  { {0x45d50113, 0xd3780107, 0x3a2d0082, 0x00000000}},  //   ицит, niću_, _tiep_,
  { {0x6d4d015c, 0xb88600b9, 0x442e1331, 0x00000000}},  //   nbaa, _sníž, _aif_,
  { {0xe456007e, 0x851f006e, 0x442e032e, 0x00000000}},  //   ажы_, मेंट_, _bif_,
  { {0x29f81332, 0x98170025, 0x78a90035, 0x00000000}},  //   nčan_, _إبرا, _irev,
  { {0x442e1333, 0x629e0cce, 0x6d4d049b, 0x00000000}},  //   _dif_, _špor, kbaa,
  { {0x78a91334, 0x10a6004d, 0x6d4d00bb, 0x00000000}},  //   _krev, аимн, jbaa,
  { {0x442e0190, 0x2d920f5c, 0x6d4d0328, 0x00000000}},  //   _fif_, veye_, dbaa,
  { {0x442e0365, 0xfe460264, 0x64491335, 0x00000000}},  //   _gif_, инго, mpei,
  { {0xed5a0404, 0x2d92014a, 0x7c2e0173, 0x00000000}},  //   ков_, teye_, _ribr,
  { {0x6d4d07a5, 0x64491336, 0x442e000a, 0x00000000}},  //   gbaa, opei, _zif_,
  { {0xd00f026c, 0x2d92132c, 0x64491337, 0x00000000}},  // [2300] سلہ_, reye_, npei,
  { {0x2d921338, 0xd3780107, 0x00000000, 0x00000000}},  //   seye_, biću_,   ,
  { {0x7f5c0fdb, 0x78a91339, 0xfc3f008e, 0x00000000}},  //   marq, _arev, _frío_,
  { {0x78a9133a, 0x22510161, 0x180e007d, 0x00000000}},  //   _brev, ázky_, ित्व_,
  { {0x38600051, 0x913b0049, 0x78a9133b, 0x00000000}},  //   éir_, דענק, _crev,
  { {0x78a90027, 0x7f5c06c2, 0xe66600ed, 0x00000000}},  //   _drev, narq, атио,
  { {0x442e133c, 0x78a9133d, 0xd91002fd, 0x00000000}},  //   _rif_, _erev, _کیش_,
  { {0x69d90bc6, 0x442e027b, 0x7dd8002a, 0x00000000}},  //   chwe, _sif_, _físe,
  { {0x030b03d7, 0x2e3c000c, 0xd378016c, 0x00000000}},  //   _सुबह_, _líf_, ziću_,
  { {0x66e60088, 0x2b5800d4, 0x442e000a, 0x00000000}},  //   _коза, _jerc_, _qif_,
  { {0xe737007c, 0x2b580ba8, 0x442e009d, 0x00000000}},  //   _тех_, _merc_, _vif_,
  { {0xd378037e, 0x9257007c, 0x9f8f013f, 0x00000000}},  //   viću_, шают_, _küç_,
  { {0x9098046c, 0x92b60044, 0x7dd101bf, 0x00000000}},  //   авят_, ছনে_, _såso,
  { {0xd378037e, 0xc8840477, 0x7f5c004a, 0x00000000}},  //   tiću_, mağı_, garq,
  { {0x6d4d133e, 0x6e2f00f6, 0x628100d9, 0x00000000}},  //   tbaa, _picb, ctlo,
  { {0xcdd8012b, 0x6d4d01d6, 0xdb1c00fa, 0x00000000}},  //   ању_, ubaa, _corí,
  { {0xdce6038c, 0x6d4d00c7, 0xd3780107, 0x00000000}},  // [2310] _bakı, rbaa, siću_,
  { {0x6d4d00c7, 0x6c6a00a1, 0x3ceb0061, 0x00000000}},  //   sbaa, اللہ_, _घेणे_,
  { {0x6d4d00c7, 0xfc3f008e, 0x29f8133f, 0x00000000}},  //   pbaa, _trío_, rčan_,
  { {0xf9930558, 0x7dd801dc, 0x64490052, 0x00000000}},  //   تبط_, _píse, ypei,
  { {0x98a50920, 0xaf080167, 0xf7450b86, 0x00000000}},  //   силе, _مقیم_, бело,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x5a44007e, 0x00000000, 0x00000000, 0x00000000}},  //   _мэта,   ,   ,
  { {0x78a91340, 0xdce80036, 0x29f800ca, 0x00000000}},  //   _trev, śląs, nčal_,
  { {0xdce6011f, 0xcdb8009b, 0x6fcb0477, 0x00000000}},  //   _yakı, שפחה_, _hücu,
  { {0xa3e103d7, 0xe299012b, 0x3cff013d, 0x00000000}},  //   नों_, гао_, _रखने_,
  { {0x644907e6, 0x11d60025, 0x2d8b067f, 0x00000000}},  //   spei, متحد, _obce_,
  { {0xc8840477, 0x9f510010, 0x64491341, 0x00000000}},  //   bağı_, kozó_, ppei,
  { {0xc884005d, 0x7f5c0181, 0xd4690aed, 0x00000000}},  //   cağı_, tarq, _силе_,
  { {0x66091342, 0xd91a01ce, 0x7dca000c, 0x00000000}},  //   loek, טורל, _lýst,
  { {0x7f5c1343, 0x6fd00a5d, 0x00000000, 0x00000000}},  //   rarq, _häck,   ,
  { {0x25bf0022, 0xdce6014a, 0xad9b000c, 0x00000000}},  //   njul_, _sakı, _ljúf,
  { {0x2b580010, 0x5b36006d, 0x30860025, 0x00000000}},  // [2320] _perc_, معار, _الخف,
  { {0x25bf00eb, 0x660900c7, 0x2f561344, 0x00000000}},  //   hjul_, hoek, _утис,
  { {0x6fd00039, 0x6609002d, 0x4e1a0167, 0x00000000}},  //   _läck, koek, _متحد_,
  { {0x200a1345, 0xa01b0cba, 0xc884019a, 0x00000000}},  //   lobi_, ntön, yağı_,
  { {0x1cba0d0b, 0xdce6011f, 0x06e50055, 0x00000000}},  //   _صاحب_, _takı, _পুলি,
  { {0x200a1346, 0x3a380065, 0x9ad605b8, 0x00000000}},  //   nobi_, _turp_, _любі,
  { {0xe0df0197, 0x91fd0089, 0x00000000, 0x00000000}},  //   zzò_, nsāc,   ,
  { {0x6fd003aa, 0xceb30104, 0xd6d90088, 0x00000000}},  //   _bäck, ליו_, шті_,
  { {0xdb1c00d4, 0x656f0048, 0x00000000, 0x00000000}},  //   _horà, ócha,   ,
  { {0x6fd00039, 0x249d000a, 0xc884019a, 0x00000000}},  //   _däck, _dswm_, rağı_,
  { {0x660901b5, 0x51f90088, 0x91fd0089, 0x00000000}},  //   boek, иною_, krāt,
  { {0x09ca0044, 0x00000000, 0x00000000, 0x00000000}},  //   লোরা,   ,   ,
  { {0x63bc0538, 0x200a0239, 0x91fd0089, 0x00000000}},  //   örns, fobi_, drāt,
  { {0x3fe70044, 0xe0df0026, 0x6574009e, 0x00000000}},  //   পক্ষ, rzò_, _ایکڑ_,
  { {0xd35b01f8, 0xe2460d3a, 0x6fd001a2, 0x00000000}},  //   _גדול, _اختي, _mäch,
  { {0x720700a1, 0x8e1501e1, 0x6fd0010f, 0x00000000}},  //   _دفعہ_, ідац, _läch,
  { {0xf1f800a6, 0x71f8006d, 0x320b0036, 0x00000000}},  // [2330] _دعوت_, _دروس_, mocy_,
  { {0x6fd0001f, 0x660902ae, 0x61ef060c, 0x00000000}},  //   _näch, zoek, licl,
  { {0x6fb5007a, 0xad270123, 0xfbd00025, 0x00000000}},  //   _همکا, _گردو, رتك_,
  { {0x7dd10018, 0x6fcb01df, 0x39150069, 0x00000000}},  //   _måsk, _vücu, омер,
  { {0x7dca004f, 0x9ccb0147, 0x89340025, 0x00000000}},  //   _výst, _сына_, أعما,
  { {0x6fd00039, 0x61ef12a0, 0x6d5f1347, 0x00000000}},  //   _räck, hicl, laqa,
  { {0x7ac401e0, 0x6fd00210, 0x6609044a, 0x00000000}},  //   _есте, _säck, toek,
  { {0x59f90057, 0xe61901f9, 0x3ebe0052, 0x00000000}},  //   _тебя_, јди_, ätti_,
  { {0x4425001c, 0x22470093, 0x38600051, 0x00000000}},  //   tml_, _stnk_, áirt_,
  { {0xdb1c1348, 0x66091349, 0x6498005e, 0x00000000}},  //   _horá, soek, стър_,
  { {0xdb1c134a, 0x2bde0061, 0x2ca90443, 0x00000000}},  //   _korá, फोटा, hvad_,
  { {0x6fd00039, 0x2ca900ea, 0x61ef0258, 0x00000000}},  //   _täck, kvad_, gicl,
  { {0x200a0022, 0x3494134b, 0xdb1c0161, 0x00000000}},  //   tobi_, _нацр, _morá,
  { {0x34b20a90, 0x2329134c, 0xbcfb00ea, 0x00000000}},  //   _آموز, _коли_, _idéh,
  { {0x443f0983, 0x200a0020, 0x63a30197, 0x00000000}},  //   lqu_, robi_, _iann,
  { {0x63a30198, 0xdd92004b, 0xa01b134d, 0x00000000}},  //   _hann, بور_, ltöl,
  { {0x63a30836, 0x443f0066, 0x2f23009d, 0x00000000}},  // [2340] _kann, nqu_, tégé_,
  { {0x63a3002b, 0x7bc7004a, 0x443f009d, 0x00000000}},  //   _jann, _coju, iqu_,
  { {0x63a3009f, 0x3f9801d9, 0x5fb7009b, 0x00000000}},  //   _mann, meru_, _והיא_,
  { {0x63a3134e, 0xdb1c0919, 0x6fd001a2, 0x00000000}},  //   _lann, _corá, _säch,
  { {0x91a00011, 0x6d440a55, 0x00000000, 0x00000000}},  //   _chỉ_, mcia,   ,
  { {0x6d440207, 0x466a01c0, 0x1ae601ee, 0x00000000}},  //   lcia, арим_, _догм,
  { {0xd90d026c, 0xdb1c0051, 0x443f002b, 0x00000000}},  //   نیہ_, _forá, equ_,
  { {0x6d44134f, 0x39420004, 0x63a301b5, 0x00000000}},  //   ncia, _üks_, _aann,
  { {0x63a31350, 0x6d441351, 0x61ef01ee, 0x00000000}},  //   _bann, icia, vicl,
  { {0x69c200c7, 0x63a300ab, 0x3f980166, 0x00000000}},  //   ljoe, _cann, jeru_,
  { {0x61ef028a, 0x63a30383, 0x3f980ad8, 0x00000000}},  //   ticl, _dann, deru_,
  { {0x260b0061, 0x63a30085, 0x00000000, 0x00000000}},  //   ावणी_, _eann,   ,
  { {0x63a30a8e, 0x3f98002b, 0x61ef1352, 0x00000000}},  //   _fann, feru_, ricl,
  { {0x65600b57, 0x80270025, 0x6d46101b, 0x00000000}},  //   lamh, ترجم, _afka,
  { {0xbcfb0181, 0xfeb80014, 0x24400082, 0x00000000}},  //   _idéi, يافت_, _hòm_,
  { {0x24400263, 0x65600051, 0x63a309e5, 0x00000000}},  //   _kòm_, namh, _zann,
  { {0x61ed1353, 0x3f981354, 0x63a3009d, 0x00000000}},  // [2350] _imal, beru_, _yann,
  { {0xdb1c0010, 0x7dd8000c, 0x2ca9010e, 0x00000000}},  //   _sorá, _vísa, rvad_,
  { {0xdd910054, 0x5a350517, 0x61ed0059, 0x00000000}},  //   _كود_, чнет, _kmal,
  { {0x6d440198, 0xfe9a0476, 0xf1bf12c5, 0x00000000}},  //   ccia, _פירמ, zmán_,
  { {0x6d5d001e, 0x24400173, 0x00000000, 0x00000000}},  //   _iesa, _nòm_,   ,
  { {0x6d5d038c, 0x67d4004d, 0x60c00933, 0x00000000}},  //   _hesa, мочу, ämmi,
  { {0x63a30fe9, 0x6d5d0db4, 0x61ed003c, 0x00000000}},  //   _rann, _kesa, _omal,
  { {0x63a303fa, 0xfb34008b, 0x6d5d0091, 0x00000000}},  //   _sann, _інтэ, _jesa,
  { {0x6d5d1355, 0x63a30004, 0xb4d5007d, 0x00000000}},  //   _mesa, _pann, सने_,
  { {0x61ed0127, 0x6d5d03fa, 0x443f0066, 0x00000000}},  //   _amal, _lesa, rqu_,
  { {0x63a30047, 0x443f028c, 0x3f980062, 0x00000000}},  //   _vann, squ_, veru_,
  { {0x63a30100, 0xdb1c0018, 0x24400263, 0x00000000}},  //   _wann, _foræ, _fòm_,
  { {0x63a31356, 0xe20b009f, 0xe4490025, 0x00000000}},  //   _tann, _slóð_, _التى_,
  { {0xf8a5007a, 0x0454026c, 0x69db1357, 0x00000000}},  //   _یک_, _آئند, _llue,
  { {0x6d5d0149, 0x7c3d1358, 0x443d0016, 0x00000000}},  //   _besa, _ausr, _huw_,
  { {0xf06604f9, 0xf1bf000c, 0x3f980145, 0x00000000}},  //   _екип, nmál_, seru_,
  { {0x7c350061, 0x3f980066, 0x3ea10065, 0x00000000}},  // [2360] _bizr, peru_, _esht_,
  { {0x6d440198, 0x69db021e, 0x00000000, 0x00000000}},  //   scia, _alue,   ,
  { {0xcf57009b, 0x291f0bb2, 0x69c90288, 0x00000000}},  //   _מבית_, _azua_, _boee,
  { {0x6d5d1359, 0x69db0133, 0x2018000c, 0x00000000}},  //   _gesa, _clue, llri_,
  { {0x2d820039, 0x27ec0022, 0x69c201c3, 0x00000000}},  //   _icke_, _pmdn_, rjoe,
  { {0x569401be, 0x2440135a, 0x69db135b, 0x00000000}},  //   дакт, _ròm_, _elue,
  { {0x69db01e3, 0x6d5d0541, 0x244001aa, 0x00000000}},  //   _flue, _yesa, _sòm_,
  { {0xe9a3007e, 0x75e6007e, 0x7c3d003f, 0x00000000}},  //   _пасп, яўле, _yusr,
  { {0x281600a1, 0xdb1c005a, 0x6560135c, 0x00000000}},  //   _فورس, _borç, ramh,
  { {0x46a60121, 0x61ed0866, 0x6560135d, 0x00000000}},  //   _назв, _smal, samh,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3946029d, 0x7ae10010, 0x00000000, 0x00000000}},  //   ncos_, _ülte,   ,
  { {0x3866135e, 0xdb1c09f7, 0x7dd800b9, 0x00000000}},  //   nsor_, _forç, _písn,
  { {0x9257007a, 0x6d5d135f, 0xa01b000c, 0x00000000}},  //   _کشور_, _sesa, mtök,
  { {0x6d5d020c, 0x7c3d0091, 0xdb050065, 0x00000000}},  //   _pesa, _susr, rdhë,
  { {0x61ed011c, 0x42fb009b, 0x7c3d1360, 0x00000000}},  //   _umal, _להוס, _pusr,
  { {0x6d5d00ea, 0xa01b1361, 0x4c941362, 0x00000000}},  // [2370] _vesa, ntök, нитс,
  { {0x6e99005e, 0x39461363, 0x2d820c92, 0x00000000}},  //   _двор_, ecos_, _ecke_,
  { {0x6d5d01a3, 0xdb58007c, 0x61fd0239, 0x00000000}},  //   _tesa, яют_, onsl,
  { {0x61fd009f, 0x973c012d, 0xc333009b, 0x00000000}},  //   nnsl, _baćo, גוע_,
  { {0x07a51364, 0xe73900e2, 0x61fd0332, 0x00000000}},  //   далн, оел_, insl,
  { {0x945d0036, 0x3946004a, 0x27c701ab, 0x00000000}},  //   zyńs, acos_, ящег,
  { {0x569200ec, 0x6446000c, 0x25a60048, 0x00000000}},  //   вајт, íkin, _baol_,
  { {0x394610c0, 0x63b8000a, 0x25a60048, 0x00000000}},  //   ccos_, _anvn, _caol_,
  { {0xf1bf0daf, 0xdb1c00c4, 0xfc3f00f6, 0x00000000}},  //   rmál_, _porç, _juí_,
  { {0xf1bf1365, 0x395f00bb, 0xa01b00b0, 0x00000000}},  //   smál_, _heus_, stöj,
  { {0xfc3f0051, 0x395f00b5, 0x9f5101aa, 0x00000000}},  //   _luí_, _keus_, mizè_,
  { {0x25a60048, 0x67210166, 0x644b012d, 0x00000000}},  //   _gaol_, _izlj, _ttgi,
  { {0x395f09f7, 0x644b067e, 0xdb1c0ddb, 0x00000000}},  //   _meus_, _utgi, _torç,
  { {0x61fd00bb, 0x7dd80142, 0x00000000, 0x00000000}},  //   ansl, _píso,   ,
  { {0x628800bb, 0xe7e50316, 0x00000000, 0x00000000}},  //   ctdo, _कतना_,   ,
  { {0x26130181, 0x395f1366, 0xa6af0044, 0x00000000}},  //   mãos_, _neus_, _কথাট,
  { {0x39a6010a, 0xfc3f0051, 0x9f9400b0, 0x00000000}},  // [2380] _jūsų_, _cuí_, _pää_,
  { {0x39a6010a, 0x6721016e, 0xafdb1367, 0x00000000}},  //   _mūsų_, _ozlj, spør,
  { {0x776300f6, 0xa5bd007f, 0x00000000, 0x00000000}},  //   danx, rmųj,   ,
  { {0xbcfb00f6, 0xfc3f008e, 0x395f00fa, 0x00000000}},  //   _adéu, _fuí_, _ceus_,
  { {0x5fd203d7, 0x395f02d5, 0x3946029d, 0x00000000}},  //   _हवाल, _deus_, rcos_,
  { {0x3946049a, 0x38660061, 0x25a61368, 0x00000000}},  //   scos_, rsor_, _saol_,
  { {0xc7b8001d, 0x69d80065, 0xdb1c0039, 0x00000000}},  //   _vnđ_, ëves, _borå,
  { {0x746a0373, 0x69d80089, 0x2d800020, 0x00000000}},  //   оров_, īves, ngie_,
  { {0xd49a0088, 0x00000000, 0x00000000, 0x00000000}},  //   іри_,   ,   ,
  { {0x1b210055, 0xd3700014, 0xa01b01e5, 0x00000000}},  //   _বলতে_, دهد_, rtök,
  { {0xc7b300b3, 0x26130181, 0xdb1c0637, 0x00000000}},  //   _שבע_, gãos_, _forå,
  { {0x22ac00b9, 0xa01b000c, 0x00000000, 0x00000000}},  //   _věk_, ptök,   ,
  { {0x7dd10073, 0x61fd032e, 0x2d800145, 0x00000000}},  //   _måst, rnsl, dgie_,
  { {0x7522002d, 0x2d8001c3, 0x00000000, 0x00000000}},  //   _izoz, egie_,   ,
  { {0x40340594, 0xfc3f0051, 0xa19502dc, 0x00000000}},  //   терс, _suí_, _зайч,
  { {0x2d800007, 0x442c00bb, 0x660200f6, 0x00000000}},  //   ggie_, lmd_, _jjok,
  { {0x395f0129, 0xfc3f0011, 0x2b4a0333, 0x00000000}},  // [2390] _reus_, _quí_, _bfbc_,
  { {0x395f1369, 0xd8380cce, 0x7e7c002d, 0x00000000}},  //   _seus_, _nič_, burp,
  { {0xe1ff008e, 0x395f0129, 0x7dd10039, 0x00000000}},  //   onó_, _peus_, _båst,
  { {0x20110a6e, 0x9f58008e, 0x1dd30316, 0x00000000}},  //   lozi_, boró_, _सवित,
  { {0x7b670057, 0x6e2d0946, 0x3869002a, 0x00000000}},  //   _отве, mmab, éar_,
  { {0x48e00044, 0x660200b0, 0x442c08d9, 0x00000000}},  //   বপূর, _ajok, jmd_,
  { {0x395f0a06, 0xe73600c0, 0xd83801ca, 0x00000000}},  //   _teus_, неш_, _dič_,
  { {0xdcef0477, 0x442c01b5, 0xd5b10137, 0x00000000}},  //   _hacı, emd_, افظ_,
  { {0x6602136a, 0x3160136b, 0x20110cd1, 0x00000000}},  //   _djok, _reiz_, kozi_,
  { {0x69d90116, 0x75220925, 0xe1900082, 0x00000000}},  //   lkwe, _dzoz, _cẳng_,
  { {0xd24e089d, 0x7dd810af, 0xb81b013d, 0x00000000}},  //   ینی_, _sísm, _पीएम_,
  { {0x69d9002b, 0x66020065, 0x7dd80161, 0x00000000}},  //   nkwe, _gjok, _písm,
  { {0xa3d50242, 0x7641011c, 0xf9da0049, 0x00000000}},  //   _подч, _huly, פֿטל,
  { {0x20110207, 0x661b003c, 0x2ca00009, 0x00000000}},  //   gozi_, lluk, vwid_,
  { {0x4427001f, 0xdee60407, 0xfc3f00d4, 0x00000000}},  //   _ihn_, хови, _orís_,
  { {0xd24e0025, 0x7641023a, 0x6da3003b, 0x00000000}},  //   _اني_, _muly, лиса,
  { {0x2011136c, 0xfce3012c, 0x92170049, 0x00000000}},  // [23a0] bozi_, гото, _אַזױ_,
  { {0xfc3f002a, 0x26e50055, 0xbea60545, 0x00000000}},  //   _arís_, _কখনো_, _заок,
  { {0x2f5b0452, 0x7dd103bd, 0x44270022, 0x00000000}},  //   _מדינ, _påst, _mhn_,
  { {0xceb30104, 0xf8660256, 0x69d90058, 0x00000000}},  //   _עיר_, евдо, gkwe,
  { {0xd838016c, 0x661b136d, 0x2365136e, 0x00000000}},  //   _pič_, dluk, kalj_,
  { {0x442701d6, 0x6602136f, 0xfb5600a2, 0x00000000}},  //   _nhn_, _sjok, _سپرد,
  { {0xfc0301bd, 0x09e601fb, 0x69961370, 0x00000000}},  //   _спро, _зовн, _прах,
  { {0x69d90f10, 0x7bce006c, 0x4427016b, 0x00000000}},  //   ckwe, _hobu, _ahn_,
  { {0x7bce1371, 0x09e30b87, 0x44271372, 0x00000000}},  //   _kobu, _сотн, _bhn_,
  { {0x7bce001a, 0x44271373, 0x00000000, 0x00000000}},  //   _jobu, _chn_,   ,
  { {0x442c00b5, 0x2011089f, 0x45e40011, 0x00000000}},  //   rmd_, vozi_, _đượ,
  { {0x79820036, 0x7bce0145, 0x661b016c, 0x00000000}},  //   ngow, _lobu, cluk,
  { {0x23650107, 0x78a20022, 0xe3b20063, 0x00000000}},  //   balj_, nwov, _مرغ_,
  { {0x644f1374, 0xa3d70061, 0x9f4a00fa, 0x00000000}},  //   ície, _सवय_, tibá_,
  { {0x20111375, 0xe28f0025, 0x6e940a1e, 0x00000000}},  //   rozi_, _هذي_, лиру,
  { {0x63aa03da, 0x20110009, 0x51871376, 0x00000000}},  //   _hafn, sozi_, _чука,
  { {0x7dd81377, 0x6e2d008e, 0x20111378, 0x00000000}},  // [23b0] _získ, rmab, pozi_,
  { {0x63aa009f, 0x7bce063c, 0x64420197, 0x00000000}},  //   _jafn, _cobu, _muoi,
  { {0xa03600b6, 0x9f8f006c, 0xbb840025, 0x00000000}},  //   _שאתה_, _müü_, المي,
  { {0x9f58009f, 0xdb0e00c4, 0x2b4d012d, 0x00000000}},  //   lorð_, _robô, _đecu_,
  { {0x69d90116, 0x661b0107, 0x99140088, 0x00000000}},  //   rkwe, vluk, льші,
  { {0x62981379, 0x63aa009f, 0x3f83000c, 0x00000000}},  //   _opvo, _nafn, ngju_,
  { {0x67d200e2, 0x00000000, 0x00000000, 0x00000000}},  //   роју,   ,   ,
  { {0xceb4061e, 0xf9930879, 0x442702d4, 0x00000000}},  //   ריק_, _حبس_, _shn_,
  { {0x661b020c, 0x44270ec1, 0x6442137a, 0x00000000}},  //   rluk, _phn_, _cuoi,
  { {0x9aa4026c, 0x7dd80802, 0x764100e0, 0x00000000}},  //   _جمہو, _písk, _tuly,
  { {0x386d137b, 0xd6db0057, 0xb17b05b7, 0x00000000}},  //   _hver_, _эта_, rhån,
  { {0x9998001e, 0x2365016c, 0xa06a137c, 0x00000000}},  //   _kurš_, salj_, мама_,
  { {0x442704cb, 0xd1320025, 0x91a00082, 0x00000000}},  //   _thn_, شمس_, _chí_,
  { {0xb4bf001c, 0xb4cd0061, 0xa0a300ed, 0x00000000}},  //   ीही_, रही_, јард,
  { {0x248d0010, 0x91a00011, 0x00000000, 0x00000000}},  //   ltem_, _thì_,   ,
  { {0x386d0f12, 0xbcfb009d, 0x248d00b4, 0x00000000}},  //   _over_, _adéq, otem_,
  { {0x248d0d9f, 0x9f58000c, 0xe7f2013d, 0x00000000}},  // [23c0] ntem_, borð_, _अगला_,
  { {0xeafa0647, 0x7bce137d, 0x00000000, 0x00000000}},  //   ورات_, _qobu,   ,
  { {0x386d0207, 0xed5a0088, 0x6f790049, 0x00000000}},  //   _aver_, _оон_, _אָרג,
  { {0xe9da0152, 0x248d137e, 0xc33200a0, 0x00000000}},  //   ьке_, ktem_, בוב_,
  { {0xe894085f, 0x7bce0006, 0x79820036, 0x00000000}},  //   уаль, _tobu, rgow,
  { {0x248d137f, 0x79821380, 0xd823004d, 0x00000000}},  //   dtem_, sgow, адчи,
  { {0x386d1381, 0x00000000, 0x00000000, 0x00000000}},  //   _ever_,   ,   ,
  { {0x63aa000c, 0xa01b0010, 0xe60f0439, 0x00000000}},  //   _safn, ltöt, يشي_,
  { {0x6442009d, 0x7c3c1382, 0x248d02fa, 0x00000000}},  //   _quoi, _kirr, gtem_,
  { {0xa8570097, 0x7c3c01d5, 0x32020027, 0x00000000}},  //   _סיבה_, _jirr, enky_,
  { {0x51f901ff, 0x7c3c00ab, 0xe81b013d, 0x00000000}},  //   енню_, _mirr, _पीटा_,
  { {0x7dd81383, 0xcb13019b, 0x64420082, 0x00000000}},  //   _físi, ילת_, _tuoi,
  { {0x6abf0204, 0x248d00d4, 0xfc3f06c2, 0x00000000}},  //   _एप्र, ctem_, _asín_,
  { {0x7c3c002b, 0xdb1c0190, 0x2005006c, 0x00000000}},  //   _nirr, _forø, õli_,
  { {0x9294008b, 0x9f58000c, 0x00000000, 0x00000000}},  //   _сайц, rorð_,   ,
  { {0x32530265, 0x1b210044, 0x00000000, 0x00000000}},  //   _твър, _বললে_,   ,
  { {0x7c3c0a19, 0xbddb009d, 0xdb050051, 0x00000000}},  // [23d0] _birr, _lièg, rdhí,
  { {0x7c3c00ea, 0x7c8401fc, 0xe7bd0044, 0x00000000}},  //   _cirr, јуте, _অত্য,
  { {0x7c3c01f3, 0x248d0010, 0x25ad00f6, 0x00000000}},  //   _dirr, ztem_, ydel_,
  { {0x443c1384, 0xe7e5007d, 0x973c0243, 0x00000000}},  //   _liv_, कसभा_, _gaći,
  { {0x67d501bd, 0x00000000, 0x00000000, 0x00000000}},  //   лоду,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6e3d0337, 0xb17b00f8, 0x00000000, 0x00000000}},  //   _kisb, thål,   ,
  { {0x248d0047, 0x06960054, 0x26c90091, 0x00000000}},  //   ttem_, انية_, ćao_,
  { {0x25ad00eb, 0x6e3d018d, 0xb17b0039, 0x00000000}},  //   rdel_, _misb, rhål,
  { {0x6e3d0181, 0x443c06f9, 0x7dd8009f, 0x00000000}},  //   _lisb, _civ_, _vísi,
  { {0x443c0365, 0x2003092f, 0x7d1d05cc, 0x00000000}},  //   _div_, dnji_, _lyss,
  { {0x64b5002c, 0x6e3d1385, 0x5ed70044, 0x00000000}},  //   _محتر, _nisb, _ডেভে,
  { {0x7d1d01d6, 0x79891386, 0x443c1387, 0x00000000}},  //   _nyss, _mcew, _fiv_,
  { {0x443c0030, 0x75fe0089, 0x9f580023, 0x00000000}},  //   _giv_, vīzi, mirë_,
  { {0x6e3d1388, 0xf3f00025, 0xdee3092b, 0x00000000}},  //   _bisb, _بأن_, бори,
  { {0x443c0107, 0xdca6003b, 0x7c3c006b, 0x00000000}},  //   _ziv_, лаби, _sirr,
  { {0x7c3c000c, 0x61e40eb0, 0x00000000, 0x00000000}},  // [23e0] _pirr, _ilil,   ,
  { {0xfc3f0051, 0x7d1d0190, 0x6e3d01a2, 0x00000000}},  //   _tsín_, _dyss, _eisb,
  { {0x62810161, 0x7c3c00b0, 0x78a91389, 0x00000000}},  //   nulo, _virr, _asev,
  { {0x6d4d001c, 0x7cda0089, 0x8e7b0049, 0x00000000}},  //   ccaa, _pārā, _אנטה,
  { {0xd91702f0, 0x7c3c01d5, 0x63a1138a, 0x00000000}},  //   льш_, _tirr, keln,
  { {0x6281011c, 0xbddb009d, 0x61e400f6, 0x00000000}},  //   kulo, _pièg, _llil,
  { {0x63a107e4, 0x1ae6007c, 0x443c00f8, 0x00000000}},  //   deln, _совм, _riv_,
  { {0x6281138b, 0xa01b0039, 0x45d4138c, 0x00000000}},  //   dulo, ntör, роис,
  { {0x6449001c, 0x69c00211, 0xd91000d3, 0x00000000}},  //   gqei, _inme, _بیش_,
  { {0x61e40020, 0x27f8000c, 0x63a10c75, 0x00000000}},  //   _alil, _örn_, geln,
  { {0x443c0263, 0xa01b138d, 0x62810395, 0x00000000}},  //   _viv_, ktör, gulo,
  { {0x15461364, 0xa01b00b0, 0x31c701a4, 0x00000000}},  //   _седм, ytös, усов,
  { {0x20030091, 0x6e3d138e, 0x00000000, 0x00000000}},  //   tnji_, _risb,   ,
  { {0x6281011c, 0x63a10107, 0xd7c70061, 0x00000000}},  //   bulo, celn, लायच,
  { {0x6d4d001c, 0x62810219, 0x539b00b6, 0x00000000}},  //   tcaa, culo, _ניהו,
  { {0x2003037e, 0x5d55026b, 0x7d1d043a, 0x00000000}},  //   snji_, ркат, _pyss,
  { {0x20030c0a, 0x8f550014, 0x6e3d138f, 0x00000000}},  // [23f0] pnji_, _پنجش, _visb,
  { {0x69c01390, 0x21290180, 0x6d4d00bb, 0x00000000}},  //   _anme, _izah_, scaa,
  { {0x6e3d0066, 0xa01b00b0, 0x61f6005b, 0x00000000}},  //   _tisb, stös, _ymyl,
  { {0x63a10036, 0xdb07000c, 0x6e3d01c3, 0x00000000}},  //   zeln, _snjó, _uisb,
  { {0x79c90123, 0x62810032, 0xad9b000c, 0x00000000}},  //   _یوسف_, zulo, _ljúk,
  { {0x69c01391, 0x2d84014a, 0x24491392, 0x00000000}},  //   _enme, _ömer_, _rúm_,
  { {0x0f58009b, 0xbddb009d, 0x63a11183, 0x00000000}},  //   ניהם_, _tièd, veln,
  { {0x660d0746, 0x9f580065, 0x0495007e, 0x00000000}},  //   čako, tirë_, ароў,
  { {0x63a101c8, 0xa78702fd, 0x78a9012d, 0x00000000}},  //   teln, _مشاو, _usev,
  { {0x6281006a, 0x66190093, 0x9f580023, 0x00000000}},  //   tulo, _wkwk, rirë_,
  { {0xdce40006, 0x9f580065, 0x63a110fa, 0x00000000}},  //   vaič, sirë_, reln,
  { {0x63a10235, 0xdb07093f, 0xb495003b, 0x00000000}},  //   seln, _nají, _видљ,
  { {0x7dd80224, 0x63a105d2, 0x3d04013d, 0x00000000}},  //   _míst, peln, _रखें_,
  { {0x6281011c, 0x7dd804bb, 0xdff5007e, 0x00000000}},  //   pulo, _líst, бясь,
  { {0x316b0046, 0xdb07004a, 0x00000000, 0x00000000}},  //   bacz_, _bají,   ,
  { {0x61e40503, 0x3a2d0082, 0x00000000, 0x00000000}},  //   _ulil, _nhep_,   ,

  { {0xab660a27, 0x22470066, 0xa01b1393, 0x00000000}},  // [2400] ивал, _hunk_, rtör,
  { {0x8b26007e, 0x973c016c, 0xfbdf0007, 0x00000000}},  //   адзе, _zaću, _stêr_,
  { {0x7bde01d6, 0x22470133, 0xa01b1394, 0x00000000}},  //   rkpu, _junk_, ptör,
  { {0x201804b4, 0xf2960049, 0x22470190, 0x00000000}},  //   lori_, יכער_, _munk_,
  { {0xc7c600ed, 0x69c00011, 0x9f510181, 0x00000000}},  //   иски, _vnme, lizá_,
  { {0x20181395, 0xdb070224, 0x2240006c, 0x00000000}},  //   nori_, _zají, _liik_,
  { {0xb76501fb, 0xa5f800ed, 0xf77200a1, 0x00000000}},  //   стій, леку_, ماں_,
  { {0xd5b70604, 0x2018018e, 0x3a3f0082, 0x00000000}},  //   ась_, hori_, _giup_,
  { {0xad9b009f, 0x20180010, 0x236702d0, 0x00000000}},  //   _sjúk, kori_, _benj_,
  { {0x9f58004a, 0xf1bf0010, 0xf7430900, 0x00000000}},  //   biré_, ymás_, _дефо,
  { {0xa6ca0054, 0x20180617, 0x0bb7009b, 0x00000000}},  //   _جوال_, dori_, בלים_,
  { {0x22470093, 0xdb1c0489, 0x7dd81396, 0x00000000}},  //   _dunk_, _horó, _míss,
  { {0x2bc90164, 0x2018005b, 0x7648011c, 0x00000000}},  //   रामा, fori_, _hudy,
  { {0x224706f8, 0xb7f8007d, 0x7a23006c, 0x00000000}},  //   _funk_, ्चिम_, võtm,
  { {0x224701f3, 0x623500e3, 0xdb1c02a0, 0x00000000}},  //   _gunk_, _леку, _moró,
  { {0x5d78007c, 0x236700e7, 0xfe79013e, 0x00000000}},  //   ийся_, _zenj_, čů_,
  { {0x61fd0119, 0x40950025, 0x20180091, 0x00000000}},  // [2410] misl, _الخر, bori_,
  { {0x61fd0890, 0x20180617, 0x3a3f0093, 0x00000000}},  //   lisl, cori_, _siup_,
  { {0x2bc90164, 0xdb0e0173, 0x2ac7003b, 0x00000000}},  //   राबा, _jabè, шљав,
  { {0x61fd0142, 0x29d70279, 0x9f58004a, 0x00000000}},  //   nisl, _açar_, viré_,
  { {0xa8a7007c, 0x76480036, 0xdb0e0e6d, 0x00000000}},  //   ррек, _audy, _labè,
  { {0xf7710464, 0x76480036, 0xab8400d7, 0x00000000}},  //   سات_, _budy, _муск,
  { {0x61fd01e5, 0x2ca90016, 0x9557009e, 0x00000000}},  //   kisl, lwad_, لیاء_,
  { {0x61fd1397, 0x644f1398, 0x2d8900e7, 0x00000000}},  //   jisl, ício, ngae_,
  { {0x61fd1399, 0x2240006c, 0x201801aa, 0x00000000}},  //   disl, _riik_, yori_,
  { {0x53c90175, 0x2247016e, 0x60dd01d6, 0x00000000}},  //   угом_, _punk_, dysm,
  { {0x2018037a, 0x7a23006c, 0x442e139a, 0x00000000}},  //   vori_, võtj, _dhf_,
  { {0x442e000c, 0x78bb139b, 0x2ca9000a, 0x00000000}},  //   _ehf_, _kruv, kwad_,
  { {0x2018139c, 0x63c200b9, 0x442e0173, 0x00000000}},  //   tori_, ávní, _fhf_,
  { {0xd91a009b, 0xe8df0011, 0x90d5007e, 0x00000000}},  //   רושל, _ngọn_, іцяч,
  { {0x20180747, 0xc2550151, 0xdee30072, 0x00000000}},  //   rori_, _اختت, пори,
  { {0xfbdf001d, 0x22910a50, 0xdb1c01a2, 0x00000000}},  //   _quên_, mák_, _vorü,
  { {0xbddb00f4, 0x7bd5014a, 0x2291139d, 0x00000000}},  // [2420] _sièc, _bozu, lák_,
  { {0xbddb028c, 0x9f860088, 0x6faa012b, 0x00000000}},  //   _pièc, _угод, _свог_,
  { {0xfe720379, 0x6c330025, 0x7bd5002d, 0x00000000}},  //   _عدد_, أفلا, _dozu,
  { {0xed5a005e, 0x00000000, 0x00000000, 0x00000000}},  //   _щом_,   ,   ,
  { {0xdb1c139e, 0x22b70082, 0x2291139f, 0x00000000}},  //   _poró, _lăk_, hák_,
  { {0x6e2401e5, 0xa09b00a3, 0x61fd016c, 0x00000000}},  //   llib, ריסט, zisl,
  { {0x2291134a, 0x3eb800ca, 0x1be700e2, 0x00000000}},  //   ják_, nvrt_, _удри_,
  { {0x545401f9, 0x61fd049a, 0x6e240058, 0x00000000}},  //   овит, xisl, nlib,
  { {0x61fd0428, 0x78bb0479, 0x92a80036, 0x00000000}},  //   visl, _gruv, _małż,
  { {0xb27413a0, 0x42740364, 0x61fd0016, 0x00000000}},  //   олош, огос, wisl,
  { {0x61fd13a1, 0x17570104, 0xdb9b0097, 0x00000000}},  //   tisl, _הסבר_, נסטר,
  { {0xd46a01f9, 0x9293007e, 0x6446000c, 0x00000000}},  //   _биде_, чаюц, íkis,
  { {0x6e2413a2, 0x3f98002b, 0x61fd13a3, 0x00000000}},  //   dlib, ffru_, risl,
  { {0x61fd13a4, 0x229113a5, 0x60dd0943, 0x00000000}},  //   sisl, bák_, rysm,
  { {0x7bd513a6, 0x61fd00ca, 0x8c000044, 0x00000000}},  //   _rozu, pisl, ্তান_,
  { {0xbcfb0047, 0x6e2413a7, 0x4cd10044, 0x00000000}},  //   _idéz, glib, _সেগু,
  { {0x7bd5006b, 0xe1ff0efe, 0x76420d16, 0x00000000}},  // [2430] _pozu, mió_, _mioy,
  { {0xe1ff13a8, 0x6aae0009, 0x2bc901f5, 0x00000000}},  //   lió_, _bsbf, राधा,
  { {0x6e2413a9, 0x7bd5012d, 0x00000000, 0x00000000}},  //   blib, _vozu,   ,
  { {0xe1ff0129, 0x3ebe0737, 0x6d460093, 0x00000000}},  //   nió_, ætte_, _ggka,
  { {0xeab000a1, 0x00000000, 0x00000000, 0x00000000}},  //   وٹے_,   ,   ,
  { {0x22910010, 0xd2460379, 0x00000000, 0x00000000}},  //   yák_, _ين_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x91a90011, 0x229113aa, 0x00000000, 0x00000000}},  //   _nhà_, vák_,   ,
  { {0xe1ff13ab, 0xb4e3006e, 0xa509005e, 0x00000000}},  //   dió_, नने_, репа_,
  { {0x229113a5, 0xdb0e13ac, 0xe2910025, 0x00000000}},  //   ták_, _sabé, وذج_,
  { {0xd5ae007a, 0xe2990098, 0x645b04fd, 0x00000000}},  //   رفی_, шан_, spui,
  { {0xe1ff13ad, 0x229113ae, 0x36340025, 0x00000000}},  //   gió_, rák_, _فرنس,
  { {0x2291139d, 0x661b0052, 0x601b0035, 0x00000000}},  //   sák_, mouk, tîmp,
  { {0xa2e5004c, 0x661b13af, 0x64590045, 0x00000000}},  //   _молд, louk, _itwi,
  { {0x7f430e09, 0xe1ff0211, 0x6609000b, 0x00000000}},  //   держ, bió_, onek,
  { {0xe1ff13b0, 0x6609055f, 0x644b0061, 0x00000000}},  //   ció_, nnek, _kugi,
  { {0x656b0047, 0x644313b1, 0x6e2404cb, 0x00000000}},  // [2440] _megh, _kini, rlib,
  { {0x9f58002a, 0xdb070047, 0x644b022b, 0x00000000}},  //   oirí_, _sajá, _mugi,
  { {0x442513b2, 0x9d4600da, 0x661b13b3, 0x00000000}},  //   ill_, _менд, kouk,
  { {0xa9260200, 0x18a60088, 0x661b00b0, 0x00000000}},  //   одел, жадм, jouk,
  { {0x9f43000c, 0xdce60087, 0x644b13b4, 0x00000000}},  //   mhjá_, _kekč, _nugi,
  { {0x64430036, 0x6609002d, 0xdb1c000c, 0x00000000}},  //   _nini, enek, _forð,
  { {0x644b010a, 0x656b0026, 0x98a30006, 0x00000000}},  //   _augi, _begh, _ąją_,
  { {0xe1ff0129, 0xd49a00aa, 0xd5ba0783, 0x00000000}},  //   xió_, аро_, рск_,
  { {0x6443006a, 0xe1ff13b5, 0x644b13b6, 0x00000000}},  //   _bini, vió_, _cugi,
  { {0x986800a1, 0xa2f40088, 0x644b0091, 0x00000000}},  //   _نیچے_, зпоч, _dugi,
  { {0xe1ff0211, 0xe3b8014a, 0x661b0341, 0x00000000}},  //   tió_, llık_, bouk,
  { {0x64430ea0, 0x644b03d1, 0x3a260253, 0x00000000}},  //   _eini, _fugi, nlop_,
  { {0xe1ff0211, 0x644306da, 0xe3b8014a, 0x00000000}},  //   rió_, _fini, nlık_,
  { {0xd2500054, 0xe1ff04bd, 0x6443011c, 0x00000000}},  //   _كنت_, sió_, _gini,
  { {0x3a2613b7, 0x2ee5000c, 0x2bc90204, 0x00000000}},  //   klop_, álf_, रासा,
  { {0x63a813b8, 0x660013b9, 0x62880016, 0x00000000}},  //   ledn, nimk, mudo,
  { {0x62880219, 0x7dd8008e, 0x201a000c, 0x00000000}},  // [2450] ludo, _vísp, ófið_,
  { {0x644313ba, 0x660d0087, 0x2ca20022, 0x00000000}},  //   _xini, čaki, _dpkd_,
  { {0x660013bb, 0x660913bc, 0x00000000, 0x00000000}},  //   kimk, ynek,   ,
  { {0xda7801ff, 0x660000b9, 0x63a80146, 0x00000000}},  //   іях_, jimk, hedn,
  { {0x442507b5, 0x998d0027, 0xad9b0010, 0x00000000}},  //   yll_, _tiež_, _amúg,
  { {0x63a80119, 0x644b13bd, 0x656b0197, 0x00000000}},  //   jedn, _rugi, _segh,
  { {0xfbd200b6, 0x644b13be, 0x64430065, 0x00000000}},  //   _אתם_, _sugi, _rini,
  { {0x6443006a, 0x644b13bf, 0x3a2600f6, 0x00000000}},  //   _sini, _pugi, clop_,
  { {0x644313c0, 0x656b0e66, 0x63a813c1, 0x00000000}},  //   _pini, _vegh, fedn,
  { {0x656b0168, 0x661b000a, 0x6609007f, 0x00000000}},  //   _wegh, souk, snek,
  { {0x6443000c, 0xf0890097, 0x4425005b, 0x00000000}},  //   _vini, _תנ_, rll_,
  { {0x644b006c, 0x644300b4, 0xe2961280, 0x00000000}},  //   _tugi, _wini, чаю_,
  { {0x6443006a, 0x63a8003b, 0x7bc700b5, 0x00000000}},  //   _tini, bedn, _onju,
  { {0x628813c2, 0xdfd205f3, 0x63a80142, 0x00000000}},  //   budo, ريز_, cedn,
  { {0xf1bf002a, 0xe3b8014a, 0x62880325, 0x00000000}},  //   mlán_, zlık_, cudo,
  { {0x67ef0030, 0xf1bf13c3, 0x6d4b13c4, 0x00000000}},  //   _højd, llán_, žgan,
  { {0xdca301f9, 0x32020161, 0x00000000, 0x00000000}},  // [2460] нати, miky_,   ,
  { {0xa09700a3, 0x66000279, 0x00000000, 0x00000000}},  //   _צדיק_, zimk,   ,
  { {0xca75007e, 0x3ce606b8, 0x3fdb009b, 0x00000000}},  //   дучы, šov_, _הקיב,
  { {0x63a80046, 0x8c46007c, 0x32020161, 0x00000000}},  //   zedn, _неме, niky_,
  { {0xd7c70061, 0xfbd100a1, 0xe8940b87, 0x00000000}},  //   लांच, رتے_, фаль,
  { {0xdb0e0219, 0x9f580c42, 0xe3b8014a, 0x00000000}},  //   _habí, nirà_, rlık_,
  { {0x63a80027, 0xa01b0210, 0x3a260093, 0x00000000}},  //   vedn, krön, plop_,
  { {0xceb3009b, 0xbb43022a, 0x682d0051, 0x00000000}},  //   תיה_, _ческ, rúda,
  { {0x660010ed, 0x67ef0146, 0x00000000, 0x00000000}},  //   rimk, _bøjd,   ,
  { {0x628813c5, 0x660000e7, 0xb05b00f8, 0x00000000}},  //   tudo, simk, lväg,
  { {0x63a80027, 0xa75b009b, 0x9f5813c6, 0x00000000}},  //   redn, _הדבר, dirà_,
  { {0xdb0e13c7, 0x62880030, 0x63a813c8, 0x00000000}},  //   _nabí, rudo, sedn,
  { {0x7a23006c, 0xf9930049, 0x2fda00d4, 0x00000000}},  //   mõtt, ערש_, _bopg_,
  { {0x2d9c0010, 0xa01b0010, 0xe47b0049, 0x00000000}},  //   ővel_, ltöz, _פרוכ,
  { {0x24520011, 0xe3b80276, 0xa3b5006e, 0x00000000}},  //   _hâm_, mdı_, _चोट_,
  { {0xe3b801f6, 0xdb0e0d7b, 0x00000000, 0x00000000}},  //   ldı_, _cabí,   ,
  { {0x61ed13c9, 0x67ef0030, 0x9f5813ca, 0x00000000}},  // [2470] _ilal, _høje, birà_,
  { {0xe3b801f6, 0x9f580197, 0x24520082, 0x00000000}},  //   ndı_, cirà_, _mâm_,
  { {0x2452001d, 0x61ed0107, 0xdb0e00fa, 0x00000000}},  //   _lâm_, _klal, _fabí,
  { {0x200300ee, 0x9f5800d6, 0xa9540088, 0x00000000}},  //   liji_, mirá_, екці,
  { {0x9f58004a, 0x61ed13cb, 0x00000000, 0x00000000}},  //   lirá_, _mlal,   ,
  { {0x200313cc, 0x7bc713cd, 0xb8d5006e, 0x00000000}},  //   niji_, _unju, _जन_,
  { {0xdce6001e, 0x9f580285, 0x67ef0030, 0x00000000}},  //   _iekā, nirá_, _nøje,
  { {0xb9c50426, 0x200313ce, 0xe459005e, 0x00000000}},  //   _تقري, hiji_, ожи_,
  { {0xdcfd005a, 0x69c900b5, 0xf1bf008e, 0x00000000}},  //   _kası, _inee, tlán_,
  { {0x2003000b, 0x61ed006a, 0x24520011, 0x00000000}},  //   jiji_, _alal, _dâm_,
  { {0x200313cf, 0x61ed0066, 0x32020161, 0x00000000}},  //   diji_, _blal, tiky_,
  { {0x471a007b, 0x69db028c, 0xd6d80057, 0x00000000}},  //   _וועג, _joue, _эту_,
  { {0x25090a90, 0x69db0f57, 0x05740439, 0x00000000}},  //   _برای_, _moue, _ساند,
  { {0xdcfd011f, 0xdce6001e, 0x69db00f4, 0x00000000}},  //   _nası, _nekā, _loue,
  { {0x9f5813d0, 0x5043007c, 0x69c913d1, 0x00000000}},  //   rirà_, терб, _onee,
  { {0x69db009d, 0x69c90045, 0x00000000, 0x00000000}},  //   _noue, _nnee,   ,
  { {0x2003012b, 0xdcfd0676, 0xfbc90061, 0x00000000}},  // [2480] biji_, _bası, रांम,
  { {0x20030295, 0x9f5800dc, 0x69c900c4, 0x00000000}},  //   ciji_, birá_, _anee,
  { {0x69db07f3, 0x9f58008e, 0xfc3f004a, 0x00000000}},  //   _boue, cirá_, _asís_,
  { {0x79a302a8, 0xef17008b, 0xa967137c, 0x00000000}},  //   врше, _імя_, дица_,
  { {0x7a230004, 0x33270052, 0xe3b8005d, 0x00000000}},  //   võtt, _lynx_, ydı_,
  { {0xb05b0039, 0xe3b8006b, 0x69c913d2, 0x00000000}},  //   sväg, xdı_, _enee,
  { {0x7a23006c, 0x245213d3, 0x69db009d, 0x00000000}},  //   tõtt, _sâm_, _foue,
  { {0xc883011f, 0x7bdc09fc, 0x69db0dce, 0x00000000}},  //   üğü_, _horu, _goue,
  { {0x7bdc0563, 0xe3b8006b, 0x9f5800c4, 0x00000000}},  //   _koru, tdı_, zirá_,
  { {0x88bd0046, 0x61ed01a3, 0x7bdc00ea, 0x00000000}},  //   _myśl, _slal, _joru,
  { {0x2003037e, 0xe3b801f6, 0x7bdc00c4, 0x00000000}},  //   viji_, rdı_, _moru,
  { {0xd257008b, 0x2452001d, 0x9f58004a, 0x00000000}},  //   ьць_, _tâm_, virá_,
  { {0x60f800a5, 0x20030ecc, 0xdb0e000a, 0x00000000}},  //   дняя_, tiji_, _labà,
  { {0x9f5813d4, 0x67ef0030, 0x00000000, 0x00000000}},  //   tirá_, _tøje,   ,
  { {0x61ed008e, 0xc7b8016c, 0xdb150173, 0x00000000}},  //   _tlal, _mađ_, _gazè,
  { {0x6009016c, 0x63b8068f, 0x9f580b33, 0x00000000}},  //   džme, _havn, rirá_,
  { {0x7bdc0059, 0x200313d5, 0x69db00f4, 0x00000000}},  // [2490] _boru, piji_, _roue,
  { {0x63b80de0, 0xfe7100e9, 0x7bdc049a, 0x00000000}},  //   _javn, _مگر_, _coru,
  { {0x7bdc04c8, 0x69db0e6d, 0xdcfd014a, 0x00000000}},  //   _doru, _poue, _vası,
  { {0x63b801aa, 0xc3330104, 0xdb0e00c4, 0x00000000}},  //   _lavn, דוע_, _sabã,
  { {0x1869041f, 0x07a5014c, 0xd5cf0082, 0x00000000}},  //   чали_, еалн, _bềnh_,
  { {0x63b802cc, 0x7bdc13d6, 0x76b3006b, 0x00000000}},  //   _navn, _goru, _həyə,
  { {0xd6d10a4f, 0x26c10224, 0x00000000, 0x00000000}},  //   اقع_, ího_,   ,
  { {0x7bdc014a, 0x22980010, 0x99980006, 0x00000000}},  //   _zoru, dék_, _durų_,
  { {0x7bdc011f, 0x5436026c, 0x629a13d7, 0x00000000}},  //   _yoru, کرٹر, etto,
  { {0xf6e70069, 0x2bd20061, 0x629a0203, 0x00000000}},  //   _оцен, साया, ftto,
  { {0xe9ff0011, 0x63b80091, 0xfbd2009b, 0x00000000}},  //   _giản_, _davn, אתי_,
  { {0x22490026, 0xbbdc006e, 0x386d000a, 0x00000000}},  //   _ciak_, _मक्क, _kwer_,
  { {0x64a5008b, 0x629a021e, 0x2bd20204, 0x00000000}},  //   _чала, atto, सामा,
  { {0x21290093, 0x63b80190, 0x25ad13d8, 0x00000000}},  //   _dyah_, _gavn, leel_,
  { {0x6da60175, 0xada6007c, 0x76b3006b, 0x00000000}},  //   нива, навл, _bəyə,
  { {0x7bdc0676, 0x25ad01b5, 0xc1ba13d9, 0x00000000}},  //   _soru, neel_, _رابط_,
  { {0x7bdc06a6, 0x76b3005f, 0x248d13da, 0x00000000}},  // [24a0] _poru, _dəyə, nuem_,
  { {0xa09b007b, 0x7bdc005f, 0x25ad0250, 0x00000000}},  //   _צייט, _qoru, heel_,
  { {0x88bd0046, 0x7bdc009f, 0xdb0e0010, 0x00000000}},  //   _wyśl, _voru, _babá,
  { {0xd9100123, 0x707702fd, 0x7a3100ea, 0x00000000}},  //   لیز_, _تمیز_, tåta,
  { {0x25ad00c7, 0x7bdc13db, 0x22980010, 0x00000000}},  //   deel_, _toru, zék_,
  { {0x25ad00bb, 0xdb0e00f6, 0x00000000, 0x00000000}},  //   eeel_, _tabà,   ,
  { {0x63b80bf8, 0x629a0009, 0x2cb20016, 0x00000000}},  //   _ravn, xtto, lwyd_,
  { {0x7c3e06d3, 0x63b813dc, 0x7af2014a, 0x00000000}},  //   lmpr, _savn, ıktı,
  { {0x2cb2018e, 0x248d09f7, 0x22490281, 0x00000000}},  //   nwyd_, guem_, _riak_,
  { {0xa87b012e, 0x22980010, 0xa01b03aa, 0x00000000}},  //   _מאמר, ték_, tröm,
  { {0x60c40032, 0x0566004d, 0x7c3e0026, 0x00000000}},  //   _arim, _звен, impr,
  { {0x60c413dd, 0x629a0052, 0x248d00c4, 0x00000000}},  //   _brim, rtto, buem_,
  { {0x60c41044, 0x644f1261, 0x629a00ea, 0x00000000}},  //   _crim, ícit, stto,
  { {0x2cb2018e, 0x6e260022, 0x60c40ad6, 0x00000000}},  //   dwyd_, _akkb, _drim,
  { {0x443e13de, 0x6e260093, 0x60c41045, 0x00000000}},  //   mmt_, _bkkb, _erim,
  { {0x60c4032e, 0x442c06a1, 0x644a0052, 0x00000000}},  //   _frim, lld_, _hifi,
  { {0x644a13df, 0x2cb20016, 0x442c13e0, 0x00000000}},  // [24b0] _kifi, gwyd_, old_,
  { {0x62880026, 0x644a0066, 0xdb0e0325, 0x00000000}},  //   ordo, _jifi, _sabá,
  { {0x442c000c, 0x67ef0030, 0x1df901ab, 0x00000000}},  //   ild_, _nøja, _жены_,
  { {0x644a000c, 0x443e01a2, 0x386d005b, 0x00000000}},  //   _lifi, hmt_, _pwer_,
  { {0x25ad0100, 0x644a002a, 0x67d50088, 0x00000000}},  //   veel_, _oifi, коду,
  { {0x644a13e1, 0x07a501fc, 0x6e2d051b, 0x00000000}},  //   _nifi, такн, llab,
  { {0x79a7008b, 0x443e0050, 0x25ad010e, 0x00000000}},  //   _прае, dmt_, teel_,
  { {0x6e2d011c, 0x442c13e2, 0x248d13e3, 0x00000000}},  //   nlab, eld_, tuem_,
  { {0x6e2d0038, 0x8cc403d7, 0x25ad00c7, 0x00000000}},  //   ilab, रियो, reel_,
  { {0xd7f80256, 0x60c40023, 0x00000000, 0x00000000}},  //   _пух_, _rrim,   ,
  { {0x6d5d01e5, 0x6e2d13e4, 0x25ad01d6, 0x00000000}},  //   _ofsa, klab, peel_,
  { {0x442c00b5, 0x443e01a2, 0x2cb2005b, 0x00000000}},  //   ald_, amt_, ywyd_,
  { {0x248d13e5, 0xe3ae041f, 0x62880471, 0x00000000}},  //   quem_, _кб_, ardo,
  { {0x65690030, 0x60c4016e, 0x6e2d095d, 0x00000000}},  //   lbeh, _vrim, elab,
  { {0x91fd0089, 0x7a380010, 0x6e2d0efe, 0x00000000}},  //   mpān, líte, flab,
  { {0x6e2d13e6, 0xa6e90011, 0x6569002d, 0x00000000}},  //   glab, _trươ, nbeh,
  { {0x1d0713e7, 0x44270093, 0x60c413e8, 0x00000000}},  // [24c0] вети_, _kkn_, _urim,
  { {0x2cb20016, 0x6e2d001a, 0x26c50197, 0x00000000}},  //   rwyd_, alab, _orlo_,
  { {0xeb9713e9, 0xee3a007c, 0x6e2d008e, 0x00000000}},  //   тих_, _оно_, blab,
  { {0x6e2d117e, 0x656900bb, 0x588600a5, 0x00000000}},  //   clab, jbeh, выка,
  { {0x442c068f, 0x443e06a1, 0x26c5002d, 0x00000000}},  //   yld_, ymt_, _arlo_,
  { {0x660200ab, 0x628800f8, 0x6b6302d3, 0x00000000}},  //   _smok, yrdo, _вкра,
  { {0x644a0207, 0x7bce13ea, 0x764b011c, 0x00000000}},  //   _rifi, _inbu, _bigy,
  { {0x644a0016, 0x6adb0044, 0x54b8004d, 0x00000000}},  //   _sifi, _যেকো, егия_,
  { {0x41d60309, 0x7a380010, 0x442c0035, 0x00000000}},  //   धानस, gíte, tld_,
  { {0x442c0038, 0x386613eb, 0x6e2d01c5, 0x00000000}},  //   uld_, mpor_, zlab,
  { {0x442c13ec, 0x443e0239, 0x764b0047, 0x00000000}},  //   rld_, rmt_, _figy,
  { {0x644a071d, 0x660200e0, 0x00000000, 0x00000000}},  //   _wifi, _umok,   ,
  { {0x644a13ed, 0x443e00f6, 0x7bce05a6, 0x00000000}},  //   _tifi, pmt_, _onbu,
  { {0x6e2d0048, 0xa91d012d, 0x00000000, 0x00000000}},  //   wlab, _udže,   ,
  { {0x6e2d0089, 0xdbdc000c, 0xd3780036, 0x00000000}},  //   tlab, _ráðl, mać_,
  { {0x6e24002d, 0x7bce13ee, 0xe3b8006b, 0x00000000}},  //   goib, _anbu, mlıq_,
  { {0x6e2d13ef, 0x31791072, 0xe3b8006b, 0x00000000}},  // [24d0] rlab, masz_, llıq_,
  { {0x31790047, 0x6e2d0089, 0xd3780036, 0x00000000}},  //   lasz_, slab, nać_,
  { {0xf09f13f0, 0x162202d2, 0xe3b8006b, 0x00000000}},  //   ltà_, मवार_, nlıq_,
  { {0xa01b000c, 0xf1bf00c4, 0xd37813f1, 0x00000000}},  //   fsög, ndá_, hać_,
  { {0xd3780046, 0xf09f13f2, 0x9d140088, 0x00000000}},  //   kać_, ntà_, _вдяч,
  { {0xe739026b, 0xf09f0197, 0xd3780036, 0x00000000}},  //   нел_, ità_, jać_,
  { {0xd3780046, 0x9f510211, 0x31790ef2, 0x00000000}},  //   dać_, lizó_, kasz_,
  { {0x26c50119, 0xe3b8005f, 0x7c2501ee, 0x00000000}},  //   _vrlo_, dlıq_, lohr,
  { {0x75f500b9, 0x9f51008e, 0x39150783, 0x00000000}},  //   _náze, nizó_, _смар,
  { {0x7a3813f3, 0x7c2501ca, 0xd3780036, 0x00000000}},  //   ríte, nohr, gać_,
  { {0x420a022a, 0xf09f0207, 0x7a3813f4, 0x00000000}},  //   енно_, età_, síte,
  { {0x7a3813f5, 0x09b10044, 0x00000000, 0x00000000}},  //   píte, ছাকা,   ,
  { {0x7c250d9b, 0x660900bb, 0xdb1c13f6, 0x00000000}},  //   kohr, miek, _carê,
  { {0x6609010a, 0x25bd018e, 0xd3780036, 0x00000000}},  //   liek, _hawl_, cać_,
  { {0x442513f7, 0x249f000c, 0x539a009b, 0x00000000}},  //   mol_, ltum_, _ניקו,
  { {0x6609001e, 0x4425002b, 0xe1f200d3, 0x00000000}},  //   niek, lol_, _دست_,
  { {0xa3c8006e, 0xf09f00f6, 0x00000000, 0x00000000}},  // [24e0] _लोड_, ctà_,   ,
  { {0x44250bc4, 0x249f01e5, 0x00000000, 0x00000000}},  //   nol_, itum_,   ,
  { {0x7f9b009b, 0xb05b0039, 0x91d80061, 0x00000000}},  //   _אביז, nvän, यापै,
  { {0x442513f8, 0x249f05ed, 0xd37813f9, 0x00000000}},  //   hol_, ktum_, zać_,
  { {0x4425006a, 0x7a1c00b9, 0xdbd2010e, 0x00000000}},  //   kol_, jčte, _küüs,
  { {0x44250129, 0x2ca003bd, 0xa01b000c, 0x00000000}},  //   jol_, mtid_, rsög,
  { {0x442513fa, 0x09a90055, 0x2ca00c72, 0x00000000}},  //   dol_, ওয়া, ltid_,
  { {0xd3780046, 0x200a047f, 0x963400ec, 0x00000000}},  //   wać_, hibi_, јниц,
  { {0x4425018e, 0x2ca00061, 0xc7960879, 0x00000000}},  //   fol_, ntid_, _مشاب,
  { {0x44251014, 0x3a260343, 0xe3b8006b, 0x00000000}},  //   gol_, loop_, tlıq_,
  { {0xd37813fb, 0x5334005e, 0x1666003b, 0x00000000}},  //   rać_, рент, _свем,
  { {0xf09f0198, 0xe3b8005f, 0xd3780036, 0x00000000}},  //   ttà_, rlıq_, sać_,
  { {0x442513fc, 0x3dc0018e, 0x200a13fd, 0x00000000}},  //   bol_, ddiw_, fibi_,
  { {0x4425000d, 0xf09f0a19, 0xc3560265, 0x00000000}},  //   col_, rtà_, _съдъ,
  { {0x3a2613fe, 0xf09f13ff, 0x70ae01f5, 0x00000000}},  //   koop_, stà_, टबॉल,
  { {0x270e005f, 0x443c0190, 0x9f51008e, 0x00000000}},  //   _mən_, _hhv_, tizó_,
  { {0x9f41008d, 0x1ae20055, 0x3a260007, 0x00000000}},  // [24f0] _kohë_, _গেলে_, doop_,
  { {0x320b0038, 0x66091400, 0x3eba0009, 0x00000000}},  //   licy_, ziek, _fspt_,
  { {0xddd00676, 0xa3d50164, 0x9e3501fc, 0x00000000}},  //   _çeşi, हात_, _венч,
  { {0x442510fa, 0x320b0036, 0xa91d00d0, 0x00000000}},  //   zol_, nicy_, _adža,
  { {0x44250f99, 0x2ca00016, 0x6925025f, 0x00000000}},  //   yol_, ctid_, јмла,
  { {0x66090036, 0x25bd0016, 0xba7703d6, 0x00000000}},  //   wiek, _sawl_, _مارت,
  { {0xec3600b6, 0x6609001e, 0x44251401, 0x00000000}},  //   _כאשר_, tiek, vol_,
  { {0x249f1402, 0x270e005f, 0x442501aa, 0x00000000}},  //   ttum_, _dən_, wol_,
  { {0x442504bd, 0x25bf1403, 0xfa340014, 0x00000000}},  //   tol_, rdul_, _طرفد,
  { {0x66091404, 0x249f01e5, 0x78bb0107, 0x00000000}},  //   siek, rtum_, _isuv,
  { {0x4425018e, 0x249f009f, 0xc5d501e1, 0x00000000}},  //   rol_, stum_, _віль,
  { {0x4425018e, 0x249f000c, 0xb05b0039, 0x00000000}},  //   sol_, ptum_, rvän,
  { {0x44250142, 0x200a006b, 0xdb1c0065, 0x00000000}},  //   pol_, tibi_, _parë,
  { {0x88bd0046, 0xb4fa009b, 0x645b0146, 0x00000000}},  //   _wyśw, _בפני, mqui,
  { {0x645b0219, 0x200a1405, 0xdb1c0065, 0x00000000}},  //   lqui, ribi_, _varë,
  { {0xdd9205f3, 0x06af0055, 0x8e5501fb, 0x00000000}},  //   تور_, কিপি, стрі,
  { {0xeb9a09da, 0x248d0093, 0x51f600a1, 0x00000000}},  // [2500] киа_, nrem_, _مسکر,
  { {0x907b0476, 0x307b009b, 0x2ca00056, 0x00000000}},  //   _שטיי, _שאינ, rtid_,
  { {0x703b026c, 0x2ca00004, 0xdb150181, 0x00000000}},  //   _جسٹس_, stid_, _razã,
  { {0x705301ef, 0x7ae30a3c, 0x61e400b0, 0x00000000}},  //   _دنیا, änta, _joil,
  { {0x270e005f, 0x3a2601d6, 0xdb1c00f4, 0x00000000}},  //   _sən_, roop_, _maré,
  { {0x1867012b, 0x248d1406, 0xdb071407, 0x00000000}},  //   шаљи_, drem_, _cajó,
  { {0x645b0b32, 0x5b35007e, 0xdb0501a2, 0x00000000}},  //   equi, _гэту, gehä,
  { {0xe5c60679, 0x248d1408, 0x61e40cc9, 0x00000000}},  //   рско, frem_, _noil,
  { {0x69c012bb, 0x91830082, 0x00000000, 0x00000000}},  //   _iame, _nếu_,   ,
  { {0xdb1c0263, 0x69c21409, 0xdb150010, 0x00000000}},  //   _parè, ldoe, _hazá,
  { {0x4b7b007b, 0x78a20161, 0x248d140a, 0x00000000}},  //   כטיג, ltov, arem_,
  { {0x69c200b5, 0x61e4140b, 0x69c000ab, 0x00000000}},  //   ndoe, _coil, _jame,
  { {0x78a20428, 0x69c0001a, 0xfeb801ef, 0x00000000}},  //   ntov, _mame, یافت_,
  { {0xb17b00ea, 0xdb07000a, 0xb22701e5, 0x00000000}},  //   gkår, _majò, _blæð,
  { {0x69c0000d, 0x61e4002a, 0x5187007e, 0x00000000}},  //   _oame, _foil, _купа,
  { {0x5d550113, 0xdb050073, 0x69c0140c, 0x00000000}},  //   скат, nehå, _name,
  { {0x78a2003b, 0xd7c60061, 0xbddb009d, 0x00000000}},  // [2510] jtov, लयाच, _bièr,
  { {0x6fb5025a, 0xeb930d3a, 0x0a6b06e3, 0x00000000}},  //   _امدا, تظر_, врди_,
  { {0x69c0140d, 0xcf92009b, 0x75f5140e, 0x00000000}},  //   _bame, _צטט_, _láza,
  { {0xc9870f09, 0x78a207ff, 0x00000000, 0x00000000}},  //   ружи, ftov,   ,
  { {0xf0940049, 0xf1bf0010, 0xb05b0039, 0x00000000}},  //   ַנק_, llás_, kväm,
  { {0x645d0211, 0xe8f8007e, 0x69c00085, 0x00000000}},  //   ísim, шлі_, _eame,
  { {0x69c000f4, 0x7a38140f, 0x657b011c, 0x00000000}},  //   _fame, síta, tauh,
  { {0x248d1410, 0x69c013ec, 0xff1800b3, 0x00000000}},  //   trem_, _game, יקות_,
  { {0x32f7005f, 0xf99200a3, 0x657b00b0, 0x00000000}},  //   məyə_, _מרן_, rauh,
  { {0x61e40949, 0x69c00027, 0x645b0576, 0x00000000}},  //   _soil, _zame, rqui,
  { {0x645b02d5, 0x61e41411, 0x69c0000b, 0x00000000}},  //   squi, _poil, _yame,
  { {0x245b0181, 0xa06a003b, 0xdb080010, 0x00000000}},  //   _têm_, лама_, ülés,
  { {0x61e4028c, 0x70560025, 0x27e5093e, 0x00000000}},  //   _voil, إنسا, _koln_,
  { {0x76aa005f, 0x51f60014, 0x32f7006b, 0x00000000}},  //   _həya, _گستر, həyə_,
  { {0x22950025, 0x52850025, 0x64590066, 0x00000000}},  //   _العس, _البك, _huwi,
  { {0x78a20428, 0x51f600d3, 0xdb0e033f, 0x00000000}},  //   ytov, _دستر, _tabú,
  { {0x2283011f, 0x5baa007e, 0x32f7006b, 0x00000000}},  // [2520] lık_, лкам_, dəyə_,
  { {0x69c00376, 0xaf9a003b, 0x78a20925, 0x00000000}},  //   _same, _стих_, vtov,
  { {0x69c01412, 0x62811413, 0xdcef001e, 0x00000000}},  //   _pame, nslo, _vecā,
  { {0x78a21414, 0x69c00ea9, 0x7db60025, 0x00000000}},  //   ttov, _qame, _اصدا,
  { {0x69c201b5, 0x175402d3, 0xb3b701f5, 0x00000000}},  //   rdoe, овля, _असंख,
  { {0x69c0000b, 0x78a20428, 0x69c20328, 0x00000000}},  //   _wame, rtov, sdoe,
  { {0x78a21415, 0x76aa005f, 0x75f50062, 0x00000000}},  //   stov, _bəya, _sáza,
  { {0x2283014a, 0x78a20142, 0xf1bf0051, 0x00000000}},  //   dık_, ptov, hlár_,
  { {0x62830107, 0x7a380010, 0x98b5013d, 0x00000000}},  //   _avno, líto, _आईएए,
  { {0x75f51416, 0x6459005b, 0x8cbb00a0, 0x00000000}},  //   _váza, _duwi, נציק,
  { {0x02a30805, 0xdb0500f8, 0x20180022, 0x00000000}},  //   прям, pehå, dnri_,
  { {0x22400ee1, 0x00000000, 0x00000000, 0x00000000}},  //   _chik_,   ,   ,
  { {0x25b7007a, 0xb114007e, 0x4de10044, 0x00000000}},  //   _دهند_, змяш, নসমূ,
  { {0x765a0010, 0xb4e40061, 0xb4d401f5, 0x00000000}},  //   _kuty, नही_, हमी_,
  { {0xa3d502fb, 0x32f7006b, 0x2283014a, 0x00000000}},  //   हार_, yəyə_, cık_,
  { {0x5ebb0044, 0x76aa006b, 0x75f500b9, 0x00000000}},  //   _উপদে, _xəya, _lázn,
  { {0x13ac0044, 0xc4b6007d, 0x00000000, 0x00000000}},  // [2530] _কোয়, _अनोख,   ,
  { {0x3a2d0007, 0x60cd008a, 0x765a01d6, 0x00000000}},  //   _skep_, _iram, _outy,
  { {0xbddb01aa, 0x1dc400e8, 0x60cd0091, 0x00000000}},  //   _chèc, _लोकत, _hram,
  { {0x777a0288, 0x2bf50061, 0x00000000, 0x00000000}},  //   _aetx, _इतकं_,   ,
  { {0x26cc1417, 0x32f7006b, 0x2283014a, 0x00000000}},  //   _ardo_, rəyə_, zık_,
  { {0x60cd0b4a, 0x628101ca, 0xf7710025, 0x00000000}},  //   _mram, yslo, ذات_,
  { {0xe739007c, 0xcf940049, 0x64590145, 0x00000000}},  //   шек_, לטס_, _suwi,
  { {0x7d090359, 0x60cd0197, 0x26c7021c, 0x00000000}},  //   _þess, _oram, rvno_,
  { {0x6aa50c0d, 0x442e0d25, 0xa3d5007d, 0x00000000}},  //   lthf, _bkf_, हाल_,
  { {0x981706dd, 0x2283011f, 0x52a91418, 0x00000000}},  //   _ابرا, tık_, авом_,
  { {0x60cd011f, 0xe9ff0011, 0x765a0009, 0x00000000}},  //   _aram, _nhẫn_, _guty,
  { {0x60cd137e, 0x6459011c, 0x75f50161, 0x00000000}},  //   _bram, _tuwi, _zázn,
  { {0x628101c9, 0x24191001, 0x645900e0, 0x00000000}},  //   sslo, _коды_, _uuwi,
  { {0x60cd1419, 0x7d0001e5, 0x3f9e010e, 0x00000000}},  //   _dram, _ýmsi, ütu_,
  { {0x60cd022b, 0xd3470014, 0x22400082, 0x00000000}},  //   _eram, _دیده_, _thik_,
  { {0x60cd141a, 0x7bd5010f, 0x61fd010f, 0x00000000}},  //   _fram, _anzu, chsl,
  { {0xdca30264, 0xac0a00ed, 0x00000000, 0x00000000}},  // [2540] мати, анаа_,   ,
  { {0x60260088, 0x91a600a1, 0x9f6000b0, 0x00000000}},  //   _єдна, _اچھے_, ärät_,
  { {0x2bce001c, 0x75f506b8, 0xda650025, 0x00000000}},  //   _होणा, _názo, كاني,
  { {0x7a380010, 0x7bd50288, 0x00000000, 0x00000000}},  //   ríto, _enzu,   ,
  { {0x7989018e, 0x2db7009b, 0x636601dc, 0x00000000}},  //   _ddew, _ולכן_, nční,
  { {0x7a3812c2, 0xdb1c008e, 0x2d801172, 0x00000000}},  //   píto, _harí, laie_,
  { {0xf1ca007d, 0x5694058e, 0x00000000, 0x00000000}},  //   ियान, чайт,   ,
  { {0x95ca012b, 0x442e141b, 0x2bce141c, 0x00000000}},  //   рука_, _skf_, _होता,
  { {0xe9ff0011, 0x75fc0010, 0x18670088, 0x00000000}},  //   _hiến_, _néze, _мати_,
  { {0xe9ff001d, 0x26cc00ca, 0x765a0045, 0x00000000}},  //   _kiến_, _trdo_, _tuty,
  { {0x60cd0295, 0x6fde0316, 0x75f50010, 0x00000000}},  //   _sram, मानं, _gázo,
  { {0x60cd010a, 0xe9ff0082, 0x00000000, 0x00000000}},  //   _pram, _miến_,   ,
  { {0x845a00ed, 0x4fc705bb, 0x00000000, 0x00000000}},  //   _трет_, осва,   ,
  { {0xe9ff0082, 0x00000000, 0x00000000, 0x00000000}},  //   _phẫn_,   ,   ,
  { {0x442c0030, 0xe29700ed, 0x22630142, 0x00000000}},  //   mod_, _дај_, ľské_,
  { {0x60cd141d, 0x442c141e, 0x2d58041f, 0x00000000}},  //   _tram, lod_, жить_,
  { {0xa802011f, 0x60cd0020, 0xdb1c008e, 0x00000000}},  // [2550] şıyo, _uram, _darí,
  { {0x442c141f, 0xe9ff001d, 0x7bc502c2, 0x00000000}},  //   nod_, _biến_, udhu,
  { {0x20111420, 0xdb1c00d4, 0x7bc50065, 0x00000000}},  //   mizi_, _farí, rdhu,
  { {0x442c1421, 0x24860119, 0x2011000b, 0x00000000}},  //   hod_, _ovom_, lizi_,
  { {0x442c09f3, 0x7e62089f, 0x6e2d059e, 0x00000000}},  //   kod_, _čopi, moab,
  { {0x2011047f, 0xcc760097, 0x7bd5010f, 0x00000000}},  //   nizi_, _מעשה_, _unzu,
  { {0xea63026c, 0x442c1422, 0x9675007e, 0x00000000}},  //   _آپری, dod_, чылі,
  { {0x20111423, 0x9f580026, 0x7642113e, 0x00000000}},  //   hizi_, nirò_, _choy,
  { {0x442c018e, 0x5884007e, 0x20110020, 0x00000000}},  //   fod_, _жыха, kizi_,
  { {0x442c006a, 0x20110091, 0x2d801424, 0x00000000}},  //   god_, jizi_, zaie_,
  { {0x20111425, 0x00000000, 0x00000000, 0x00000000}},  //   dizi_,   ,   ,
  { {0x27340051, 0x76420145, 0x00000000, 0x00000000}},  //   súnú_, _ghoy,   ,
  { {0xa01b010f, 0x442c018e, 0x455a0104, 0x00000000}},  //   rsön, bod_, _הכנס,
  { {0x7fd50099, 0x7649014a, 0x20111426, 0x00000000}},  //   місі, lmey, gizi_,
  { {0x2d80001a, 0xdee60088, 0xd0070140, 0x00000000}},  //   taie_, чови, чере_,
  { {0x661b1427, 0x7649014a, 0xee3a07d0, 0x00000000}},  //   nnuk, nmey, ёна_,
  { {0xd347007a, 0x2d800a86, 0x20110032, 0x00000000}},  // [2560] _دیگه_, raie_, bizi_,
  { {0x2d80009d, 0x5ebb0044, 0x20110035, 0x00000000}},  //   saie_, _উপরে, cizi_,
  { {0x05bd0061, 0x7a380010, 0x661b0058, 0x00000000}},  //   ्याब, sítm, knuk,
  { {0x442c1428, 0xdb1c1429, 0x98a60088, 0x00000000}},  //   zod_, _parâ, зиде,
  { {0xed520014, 0x442c011c, 0xdb1c00c4, 0x00000000}},  //   _سپس_, yod_, _barã,
  { {0xe9ff001d, 0xdb0e00b9, 0xdc6700aa, 0x00000000}},  //   _tiến_, _zabý, _хард_,
  { {0x8c4307ca, 0x24860119, 0x7649142a, 0x00000000}},  //   _чере, _svom_, fmey,
  { {0xd49a0216, 0xceb300b6, 0x442c0016, 0x00000000}},  //   бро_, גיה_, wod_,
  { {0x38c800d3, 0x442c142b, 0x7d04000b, 0x00000000}},  //   _بازی_, tod_, nzis,
  { {0xa2f40088, 0x7d00000c, 0x07a3142c, 0x00000000}},  //   дпоч, _ýmsu, _паун,
  { {0x442c0016, 0x64480089, 0x201100b9, 0x00000000}},  //   rod_, rmdi, vizi_,
  { {0xd257008b, 0x442c142d, 0x79820020, 0x00000000}},  //   яць_, sod_, naow,
  { {0x442c0119, 0x2011142e, 0x5067142f, 0x00000000}},  //   pod_, tizi_, ятна,
  { {0x1ae20055, 0x7d040036, 0xdb0e008e, 0x00000000}},  //   _গেছে_, dzis, _jabó,
  { {0x63ba073a, 0x533306e3, 0x20110041, 0x00000000}},  //   metn, _пешт, rizi_,
  { {0x63ba01d9, 0x67ef0030, 0x629a07b4, 0x00000000}},  //   letn, _højt, muto,
  { {0x629a011c, 0x20110173, 0x9f580026, 0x00000000}},  // [2570] luto, pizi_, rirò_,
  { {0xf0450167, 0x7a381430, 0x63ba04eb, 0x00000000}},  //   _تعبی, líth, netn,
  { {0x629a0489, 0x3f830119, 0xdb1c0129, 0x00000000}},  //   nuto, maju_, _carà,
  { {0x63ba0010, 0x3915007c, 0x7aea0039, 0x00000000}},  //   hetn, ммер, äfta,
  { {0x48ab01bd, 0x1a6800a1, 0x76aa006b, 0x00000000}},  //   стем_, _ہیلی_, _dəym,
  { {0x63ba11cc, 0x629a0142, 0xfe700014, 0x00000000}},  //   jetn, kuto, _جدی_,
  { {0x629a1431, 0x2ca9076a, 0x7649014a, 0x00000000}},  //   juto, ltad_, tmey,
  { {0x629a1432, 0x7bc70b37, 0x661b016c, 0x00000000}},  //   duto, _haju, unuk,
  { {0x7649011f, 0x2ca91433, 0x3f831434, 0x00000000}},  //   rmey, ntad_, kaju_,
  { {0x3f830119, 0x386d0197, 0xdb1c008e, 0x00000000}},  //   jaju_, _iter_, _hará,
  { {0x7bc706fe, 0x3f831435, 0x7d040197, 0x00000000}},  //   _maju, daju_, zzis,
  { {0x2ca91436, 0x7bc701a3, 0xe5e500a2, 0x00000000}},  //   ktad_, _laju, _تزئی,
  { {0x629a0ef7, 0xa3c802f4, 0x53a50b11, 0x00000000}},  //   auto, _लोक_, _жалб,
  { {0x629a1437, 0x63ba016c, 0xad9b00f6, 0x00000000}},  //   buto, cetn, _llúd,
  { {0xe9ff001d, 0x67ef0030, 0xbea302dc, 0x00000000}},  //   _nhắn_, _højs, карк,
  { {0xee3a0822, 0x00000000, 0x00000000, 0x00000000}},  //   іна_,   ,   ,
  { {0xbc6a0070, 0x3f830091, 0x7a380802, 0x00000000}},  // [2580] زمان_, baju_, sítk,
  { {0x3f83016c, 0x60c4011f, 0x7d04001a, 0x00000000}},  //   caju_, _isim, rzis,
  { {0x7a3806c2, 0xdb1c11e7, 0xfbd1026c, 0x00000000}},  //   líti, _bará, ھتے_,
  { {0xdb1c0489, 0x63ba1438, 0xad9b0051, 0x00000000}},  //   _cará, zetn, _clúd,
  { {0x307a0049, 0xdb1c077b, 0x61fd0065, 0x00000000}},  //   קאַנ, _dará, ërli,
  { {0x60c4000b, 0x466a017f, 0xdb0e0173, 0x00000000}},  //   _msim, орим_, _dabò,
  { {0xa3c802fb, 0x25ad063c, 0x63ba0059, 0x00000000}},  //   _लोग_, ffel_, vetn,
  { {0x3f830107, 0x60c404c6, 0xdb1c0387, 0x00000000}},  //   zaju_, _osim, _gará,
  { {0x63ba0059, 0x60c40009, 0x7bc700e7, 0x00000000}},  //   tetn, _nsim, _yaju,
  { {0x629a1439, 0xb05b010f, 0xa91d0087, 0x00000000}},  //   tuto, hwäc, _sežg,
  { {0x63ba143a, 0x3f831435, 0x65c60326, 0x00000000}},  //   retn, vaju_, _обжа,
  { {0x629a0039, 0x63ba021a, 0x741300a6, 0x00000000}},  //   ruto, setn, _یونا,
  { {0x3f83037e, 0xc5f3009b, 0x798001aa, 0x00000000}},  //   taju_, _בדף_, _memw,
  { {0x67ef0030, 0x7a380010, 0x60c40087, 0x00000000}},  //   _højr, síth, _dsim,
  { {0x60c408b2, 0x3f830119, 0x7bc7143b, 0x00000000}},  //   _esim, raju_, _raju,
  { {0x3f83037e, 0x2ca9143c, 0x7bc701c5, 0x00000000}},  //   saju_, ttad_, _saju,
  { {0x64580ac2, 0x7bc7143d, 0x3f830091, 0x00000000}},  // [2590] _kivi, _paju, paju_,
  { {0x2ca90211, 0x2c640039, 0x9f450010, 0x00000000}},  //   rtad_, _död_, óló_,
  { {0x2ca9143e, 0x61ed0142, 0x62880007, 0x00000000}},  //   stad_, _koal, nsdo,
  { {0x645811d1, 0xdb26007a, 0xceb2007b, 0x00000000}},  //   _livi, رونی, _גיט_,
  { {0x9f580051, 0x7bc70127, 0x61ed0035, 0x00000000}},  //   mhrá_, _taju, _moal,
  { {0x07a20893, 0xb05b0c4d, 0x27fe0022, 0x00000000}},  //   гашн, lväs, _cltn_,
  { {0x25ad000d, 0x49bb0014, 0x1995007e, 0x00000000}},  //   tfel_, _وارد_, _павя,
  { {0xcf58012e, 0x6b8504cb, 0x62880239, 0x00000000}},  //   ובות_, lahg, dsdo,
  { {0x6458143f, 0x25ad0678, 0x628a00ea, 0x00000000}},  //   _bivi, rfel_, _avfo,
  { {0xc747006d, 0xd9f50061, 0x13091001, 0x00000000}},  //   _قضاي, _आवडत_, зной_,
  { {0xa91d0059, 0x61ed001a, 0x60c401f3, 0x00000000}},  //   _deže, _boal, _ssim,
  { {0x61ed027b, 0x25e0001c, 0x69cb1440, 0x00000000}},  //   _coal, काणी_, ndge,
  { {0xe9ff001d, 0x61ed0032, 0x69c900e0, 0x00000000}},  //   _nhận_, _doal, _maee,
  { {0x7a381441, 0x64581442, 0x2c640039, 0x00000000}},  //   ríti, _givi, _röd_,
  { {0x62880045, 0x6e290161, 0x00000000, 0x00000000}},  //   csdo, čebn,   ,
  { {0x6458037e, 0x91fd0089, 0xa3c50061, 0x00000000}},  //   _zivi, spār, _उघड_,
  { {0xdd8f0318, 0x60c40020, 0xf6520049, 0x00000000}},  // [25a0] صول_, _usim, רצן_,
  { {0x61ed02ae, 0x26c50292, 0x69c900f6, 0x00000000}},  //   _zoal, _oslo_, _aaee,
  { {0xdb1c02d5, 0x8f9b01ce, 0x2c52000a, 0x00000000}},  //   _març, _ציטי, _jņdi_,
  { {0x427a0049, 0x27fe0022, 0xb05b00f8, 0x00000000}},  //   פאנג, _sltn_, mvär,
  { {0x27fe0093, 0xb05b00f8, 0x27ec0087, 0x00000000}},  //   _pltn_, lvär, _podn_,
  { {0xfaa6007e, 0xf7780066, 0x69cb01c3, 0x00000000}},  //   _паго, _roħs_, adge,
  { {0x64580207, 0x798001aa, 0x8f9b01ce, 0x00000000}},  //   _rivi, _temw, ליסי,
  { {0x6458099e, 0xc1ca006e, 0xa91d1443, 0x00000000}},  //   _sivi, ियोग, _seže,
  { {0x7659018e, 0xdb1c0129, 0x61ed013f, 0x00000000}},  //   _diwy, _barç, _roal,
  { {0xa01b0073, 0xb4c00061, 0x61ed1444, 0x00000000}},  //   rsök, _ंनी_, _soal,
  { {0x64580219, 0x61ed0035, 0x00000000, 0x00000000}},  //   _vivi, _poal,   ,
  { {0x2d820059, 0x62880125, 0xb05b00f8, 0x00000000}},  //   _neke_, rsdo, dvär,
  { {0xa91d050f, 0x61ed0b94, 0x7bdc0116, 0x00000000}},  //   _teže, _voal, _onru,
  { {0xdb1c1184, 0x00000000, 0x00000000, 0x00000000}},  //   _garç,   ,   ,
  { {0x2d820173, 0x76aa013f, 0x00000000, 0x00000000}},  //   _beke_, _bəyi,   ,
  { {0xbddb00f4, 0xe9ff0011, 0x7bdc010f, 0x00000000}},  //   _thèm, _phận_, _anru,
  { {0x76aa005f, 0x5d55026b, 0xa3d50061, 0x00000000}},  // [25b0] _dəyi, ткат, हाच_,
  { {0xb6030027, 0xfe710167, 0xf1bf1445, 0x00000000}},  //   čšin, _نگر_, leá_,
  { {0x20130066, 0xa01b0010, 0xb05b00f8, 0x00000000}},  //   _imxi_, kröz, sväs,
  { {0xe9ff0011, 0x38a91446, 0x7bdc0325, 0x00000000}},  //   _thận_, túr_, _enru,
  { {0x69cb037f, 0x28f803e8, 0x00000000, 0x00000000}},  //   rdge, нець_,   ,
  { {0x6b850045, 0x673a01d6, 0x00000000, 0x00000000}},  //   qahg, _bytj,   ,
  { {0x3d150061, 0x38a90a87, 0x2d820145, 0x00000000}},  //   _नेते_, súr_, _yeke_,
  { {0xa91d05fa, 0x9b5800aa, 0xb60601ed, 0x00000000}},  //   _vežb, _чист_, ješć,
  { {0xdb1c047f, 0xf1bf0027, 0x65690023, 0x00000000}},  //   _parç, deá_, rceh,
  { {0x75f50161, 0x00000000, 0x00000000, 0x00000000}},  //   _názv,   ,   ,
  { {0xf1dd0365, 0xfbd200b6, 0x41dd0061, 0x00000000}},  //   यांन, בתי_, यांस,
  { {0x22490263, 0x15150ae0, 0x7a380010, 0x00000000}},  //   _chak_, _идея, sítv,
  { {0x2d82003b, 0xd9e30044, 0x28c7013d, 0x00000000}},  //   _reke_, _মতাম, लिटि,
  { {0x35a7006e, 0x395f00e0, 0x22490032, 0x00000000}},  //   _गाड़, _lgus_, _ehak_,
  { {0x2d820020, 0x2be00067, 0x0eb90783, 0x00000000}},  //   _peke_, नासा, нуты_,
  { {0xc69201f8, 0xf1bf0051, 0x25bf00e5, 0x00000000}},  //   יאל_, ceá_, neul_,
  { {0xb05b0039, 0x25b2014a, 0xd24f0379, 0x00000000}},  // [25c0] rvär, _öyle_, _بني_,
  { {0x395f0195, 0x0e661447, 0xd00f0076, 0x00000000}},  //   _agus_, _икон, _ولي_,
  { {0xbad5008b, 0x76aa006b, 0x2d820056, 0x00000000}},  //   ліцы, _təyi, _teke_,
  { {0xb33c01d5, 0x2018011c, 0x60d60036, 0x00000000}},  //   ngħa, liri_, _krym,
  { {0x1867033c, 0x8b660151, 0x00000000, 0x00000000}},  //   вачи_, _لازم,   ,
  { {0xe9ff001d, 0x6d46115c, 0x7bdc01a2, 0x00000000}},  //   _phản_, _izka, _unru,
  { {0xcac70175, 0x2ca00250, 0x1ae3007c, 0x00000000}},  //   _игре_, luid_, _корм,
  { {0x20180020, 0x7c3e09b0, 0xbddb000a, 0x00000000}},  //   hiri_, llpr, _chèh,
  { {0x20181448, 0xb6060521, 0x2ca0010e, 0x00000000}},  //   kiri_, vešć, nuid_,
  { {0x2018000b, 0xe9ff0082, 0x9f5a00f6, 0x00000000}},  //   jiri_, _thản_, _alpí_,
  { {0x201804d4, 0xdd2f00b9, 0xf2c30605, 0x00000000}},  //   diri_, měťo, асян,
  { {0x7a380489, 0x2ca0006c, 0x25bf0035, 0x00000000}},  //   pítu, kuid_, ceul_,
  { {0x20180294, 0x66021449, 0x3eba062a, 0x00000000}},  //   firi_, _ilok, _appt_,
  { {0x201804d4, 0xdb170181, 0x3eba0093, 0x00000000}},  //   giri_, nexã, _bppt_,
  { {0x660201e3, 0x6d46002d, 0xb33c002b, 0x00000000}},  //   _klok, _azka, bgħa,
  { {0x60d60065, 0x7c3e144a, 0xe3b000a1, 0x00000000}},  //   _frym, elpr, _خرچ_,
  { {0x2018000b, 0x60d6144b, 0x2ca0004a, 0x00000000}},  // [25d0] biri_, _grym, guid_,
  { {0x2018144c, 0x61fd01d6, 0x25bf001a, 0x00000000}},  //   ciri_, lksl, zeul_,
  { {0x443e1274, 0x6602144d, 0x4975003b, 0x00000000}},  //   ilt_, _olok, глес,
  { {0x443e001f, 0x61fd007f, 0x7c3e144e, 0x00000000}},  //   hlt_, nksl, alpr,
  { {0x693400ed, 0x5d9a012f, 0xa91d144f, 0x00000000}},  //   анцу, _אברה, _beža,
  { {0x66020b80, 0x7e650022, 0x00000000, 0x00000000}},  //   _alok, _kuhp,   ,
  { {0x66020209, 0x7a380047, 0x25bf0035, 0x00000000}},  //   _blok, gíts, teul_,
  { {0x20180294, 0x00000000, 0x00000000, 0x00000000}},  //   ziri_,   ,   ,
  { {0x644a002a, 0x629a0211, 0x20181450, 0x00000000}},  //   _bhfi, erto, yiri_,
  { {0x6602021e, 0x3fce0044, 0x60d60065, 0x00000000}},  //   _elok, _রক্ষ, _rrym,
  { {0x6602009f, 0x2018014a, 0xb33c002b, 0x00000000}},  //   _flok, viri_, tgħa,
  { {0x443e06a8, 0x20180729, 0x00000000, 0x00000000}},  //   alt_, wiri_,   ,
  { {0x201811af, 0x25e002fb, 0x657b1451, 0x00000000}},  //   tiri_, कारी_, mbuh,
  { {0x5ebb0044, 0x04920025, 0x23290256, 0x00000000}},  //   _উপজে, _الوح, _поли_,
  { {0x2018000b, 0x7f1901ff, 0x629a00ca, 0x00000000}},  //   riri_, віту_, crto,
  { {0x20180da4, 0x61fd1452, 0x2ca0006c, 0x00000000}},  //   siri_, cksl, tuid_,
  { {0xfce30069, 0x248d1453, 0x271f013d, 0x00000000}},  // [25e0] бото, nsem_, यपुर_,
  { {0x6d4601dc, 0x207b0049, 0x2ca003b3, 0x00000000}},  //   _vzka, _ראיא, ruid_,
  { {0x23a60061, 0x7c3e0009, 0x657b011c, 0x00000000}},  //   _खासद, rlpr, kbuh,
  { {0x5336007b, 0x248d095c, 0x3f8a00a9, 0x00000000}},  //   אנען_, ksem_, labu_,
  { {0x81ce0055, 0x46140014, 0xddc40036, 0x00000000}},  //   রাপ_, یوتر, rmiń,
  { {0x660201c5, 0x67d40131, 0x3f8a00e7, 0x00000000}},  //   _slok, року, nabu_,
  { {0x66020006, 0x443e0190, 0xdcfd0089, 0x00000000}},  //   _plok, vlt_, _iesā,
  { {0x6e2401e5, 0x3f8a000b, 0x7bce01a3, 0x00000000}},  //   nnib, habu_, _habu,
  { {0x7bce1454, 0xa91d0746, 0x248d0010, 0x00000000}},  //   _kabu, _teža, gsem_,
  { {0x78a21455, 0x443e009d, 0x439401fc, 0x00000000}},  //   muov, ult_, јанс,
  { {0x7bce006a, 0x81ce0044, 0x3f85000c, 0x00000000}},  //   _mabu, রান_, ðlum_,
  { {0x7bce1456, 0x25e00061, 0xdb1c0051, 0x00000000}},  //   _labu, काळी_, _barú,
  { {0x78a20197, 0x00000000, 0x00000000, 0x00000000}},  //   nuov,   ,   ,
  { {0x7bce011c, 0x629a00ca, 0xcbbf0044, 0x00000000}},  //   _nabu, prto, _উচ্ছ,
  { {0x321908d2, 0xa91d1457, 0xb7db0049, 0x00000000}},  //   pisy_, _nežn, עקלי,
  { {0x821500a1, 0x7bce011c, 0x00000000, 0x00000000}},  //   _خوبص, _aabu,   ,
  { {0x3f8a000b, 0x69c21458, 0x9c3900ed, 0x00000000}},  // [25f0] babu_, deoe, впат_,
  { {0x5d5400ed, 0x7bce01a3, 0x26e4013d, 0x00000000}},  //   скут, _cabu, _कपूर_,
  { {0xdb150211, 0x5e470025, 0x7bce01c5, 0x00000000}},  //   _razó, _مضحك, _dabu,
  { {0x248d1083, 0xdb15004a, 0xa91d00ca, 0x00000000}},  //   ysem_, _sazó, _dežn,
  { {0x7bce1459, 0x225907e4, 0x00000000, 0x00000000}},  //   _fabu, írky_,   ,
  { {0xb8cd03d7, 0x7bce145a, 0xa695098c, 0x00000000}},  //   _कम_, _gabu, ариј,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bce0027, 0x3f8a0087, 0x6b87012d, 0x00000000}},  //   _zabu, zabu_, _hejg,
  { {0x81ce0055, 0xccf2007b, 0xdb05010f, 0x00000000}},  //   রাম_, ַכט_, gehö,
  { {0x3ea30065, 0x798b0058, 0x7d0d016c, 0x00000000}},  //   kujt_, lagw, izas,
  { {0x248d0181, 0xfbcf0044, 0x657b011c, 0x00000000}},  //   ssem_, রাপত, pbuh,
  { {0xdb0503a9, 0xa06a0c27, 0xc1060025, 0x00000000}},  //   behö, кама_, لوجي,
  { {0x3f8a000b, 0xa91d01c5, 0x00000000, 0x00000000}},  //   tabu_, _mežo,   ,
  { {0x8fa601f9, 0x661b010a, 0x660901d5, 0x00000000}},  //   јаве, liuk, lhek,
  { {0x3f8a0020, 0xa2250014, 0x539a009b, 0x00000000}},  //   rabu_, _گروه, _סיקו,
  { {0x3f8a0020, 0x661b0006, 0x442508d9, 0x00000000}},  //   sabu_, niuk, lnl_,
  { {0xed5a01f9, 0x3b86005e, 0x7bce13b1, 0x00000000}},  // [2600] тоа_, илаг, _pabu,
  { {0x4f960153, 0x9b850647, 0x644100ff, 0x00000000}},  //   _триу, مؤمن, nlli,
  { {0x644100f4, 0xbf9b00a3, 0x661b0a64, 0x00000000}},  //   illi, _בייש, kiuk,
  { {0x7bce145b, 0xe8fa012b, 0xbcfb0047, 0x00000000}},  //   _wabu, кле_, _igén,
  { {0x7fe904e1, 0x7d0d0036, 0x8d630088, 0x00000000}},  //   _شریف_, czas, _євре,
  { {0x48130088, 0xa91d0ecc, 0x69c20032, 0x00000000}},  //   оміс, _težn, seoe,
  { {0xddc40089, 0x2cb20007, 0xe5c6030d, 0x00000000}},  //   rmiņ, ltyd_, аспо,
  { {0x8881026c, 0x6441021e, 0xa01b145c, 0x00000000}},  //   _کیون, elli, nsör,
  { {0x2cb201d6, 0x186a0088, 0x75fc000a, 0x00000000}},  //   ntyd_, _рази_, _jézi,
  { {0xf366098c, 0xe9ff001d, 0x6908005d, 0x00000000}},  //   штин, _phần_, ırdı,
  { {0x7bd90049, 0x5334005e, 0x326602ea, 0x00000000}},  //   אַרק, сент, јтов,
  { {0xd5b002fd, 0x9f580051, 0x66090020, 0x00000000}},  //   _رفت_, bhrú_, chek,
  { {0x6441145d, 0x600200c4, 0xba5708cd, 0x00000000}},  //   blli, _cômo, יסטו_,
  { {0xe9ff001d, 0xfe73031d, 0x2005000c, 0x00000000}},  //   _thần_, قدر_, óli_,
  { {0x54390049, 0x22940025, 0x3a2600bb, 0x00000000}},  //   _געװא, _البس, knop_,
  { {0x2cb201d6, 0xb7fe0044, 0x75fc009d, 0x00000000}},  //   ftyd_, ্চিত_, _bézi,
  { {0x6b870065, 0xacf802e9, 0x7c87007c, 0x00000000}},  // [2610] _pejg, анту_, рубе,
  { {0x60cd0013, 0x81ce0044, 0x3ea30065, 0x00000000}},  //   _isam, রাণ_, pujt_,
  { {0xa91d145e, 0xdce70180, 0x6fb6009e, 0x00000000}},  //   _pežo, ılıd, _امپا,
  { {0xa2d7006e, 0x00000000, 0x00000000, 0x00000000}},  //   यित्,   ,   ,
  { {0x491103d7, 0x644100b0, 0x798b0f65, 0x00000000}},  //   _देखो_, ylli, ragw,
  { {0x60cd0020, 0x798b107e, 0x8d5a009b, 0x00000000}},  //   _msam, sagw, _תכשי,
  { {0x660905c6, 0x7bc5145f, 0xfeca0049, 0x00000000}},  //   thek, mehu, ָמפּ,
  { {0xc4850265, 0x60cd06a6, 0x7bc50146, 0x00000000}},  //   блик, _osam, lehu,
  { {0xf795008b, 0xe9ff0011, 0x64411460, 0x00000000}},  //   _газэ, _chấn_, tlli,
  { {0xf09f01e8, 0x66090f87, 0xf7700025, 0x00000000}},  //   drà_, shek, _قام_,
  { {0xd7f80b87, 0x60cd07ed, 0x7c2200f4, 0x00000000}},  //   _тут_, _asam, éori,
  { {0x64411461, 0x7bc50065, 0x60cd0145, 0x00000000}},  //   slli, hehu, _bsam,
  { {0x7bc500ea, 0x79890112, 0xf09f00f6, 0x00000000}},  //   kehu, _meew, grà_,
  { {0x43850054, 0x18350049, 0x249f0190, 0x00000000}},  //   _الثق, מאָל_, mrum_,
  { {0x60cd06bd, 0x7bc50190, 0xf09f0129, 0x00000000}},  //   _esam, dehu, arà_,
  { {0xf09f00d4, 0x249f1462, 0x4d66007e, 0x00000000}},  //   brà_, orum_, скав,
  { {0x1b150055, 0x61e41463, 0xfce30140, 0x00000000}},  // [2620] _তুলে_, _inil, пото,
  { {0x7bc50030, 0xf1bf0051, 0x61f600e0, 0x00000000}},  //   gehu, nnán_, _hoyl,
  { {0x249f0180, 0x2cb20007, 0x201a00e0, 0x00000000}},  //   hrum_, styd_, _impi_,
  { {0x994a0025, 0x9b9602fd, 0xc332009b, 0x00000000}},  //   هلال_, _گلست, הוב_,
  { {0x2d800020, 0x98a30242, 0x5e570049, 0x00000000}},  //   mbie_, зиче, _ליטע_,
  { {0x249f1464, 0x2d800bd3, 0xdb1e1465, 0x00000000}},  //   drum_, lbie_, lepí,
  { {0x05240044, 0x667400a6, 0x201a0022, 0x00000000}},  //   _পরের_, زگار, _mmpi_,
  { {0xe5c6007c, 0xe9ff0011, 0x443c000c, 0x00000000}},  //   сско, _phấn_, _skv_,
  { {0x32ee006b, 0x8cdb006e, 0xb9060364, 0x00000000}},  //   məyi_, नियो, _узак,
  { {0x61e40f6a, 0xf09f0207, 0x2ca00f9b, 0x00000000}},  //   _anil, vrà_, irid_,
  { {0x61f6014a, 0x249f00f6, 0x60cd00ea, 0x00000000}},  //   _boyl, arum_, _ssam,
  { {0xf09f04b9, 0x64a6007e, 0x201a1466, 0x00000000}},  //   trà_, _гада, _ampi_,
  { {0x339407d0, 0x7bc500e7, 0x44fa0439, 0x00000000}},  //   _далё, yehu, _حراج_,
  { {0x3e6e0224, 0xf09f1467, 0x2ca01468, 0x00000000}},  //   _být_, rrà_, drid_,
  { {0x7bc50190, 0x61f60544, 0x32b70025, 0x00000000}},  //   vehu, _foyl, _هدية_,
  { {0xf09f0197, 0x60cd0051, 0x2ceb007c, 0x00000000}},  //   prà_, _tsam, льзо_,
  { {0x60cd0091, 0x7bc51469, 0x00000000, 0x00000000}},  // [2630] _usam, tehu,   ,
  { {0x7b67146a, 0xbddb146b, 0xdcfd0006, 0x00000000}},  //   стае, _chèr, _nesą,
  { {0x2d800ace, 0x2ca00004, 0x79890022, 0x00000000}},  //   bbie_, arid_, _peew,
  { {0x80cc0044, 0x7bc50190, 0xdb1c000c, 0x00000000}},  //   ামর্, sehu, _farþ,
  { {0x7bc50190, 0x75fc0010, 0xe3b80095, 0x00000000}},  //   pehu, _jézu, kfı_,
  { {0x4cba0049, 0xbddb009d, 0x8699007c, 0x00000000}},  //   _דזשו, _thès, атит_,
  { {0x3209005a, 0x7989146c, 0x24860022, 0x00000000}},  //   _olay_, _teew, _awom_,
  { {0x249f092d, 0xb05b010f, 0x32ee006b, 0x00000000}},  //   trum_, swäh, cəyi_,
  { {0xdb1e001a, 0x61f60203, 0x00000000, 0x00000000}},  //   cepâ, _royl,   ,
  { {0x61e4000c, 0x3209146d, 0x249f000c, 0x00000000}},  //   _snil, _alay_, rrum_,
  { {0x81ce0044, 0xf1bf13ab, 0x320900d4, 0x00000000}},  //   রাস_, rnán_, _blay_,
  { {0x2d8b146e, 0xcad6009b, 0x32090133, 0x00000000}},  //   _nece_, קורת_, _clay_,
  { {0xa06a0816, 0x628e0010, 0xb5c80014, 0x00000000}},  //   рага_, ábor, _دونم_,
  { {0x320907b1, 0xee3f0142, 0x00000000, 0x00000000}},  //   _elay_, _aký_,   ,
  { {0x32090b3d, 0x9e0501f5, 0x61f6013f, 0x00000000}},  //   _flay_, रसंघ_, _toyl,
  { {0x61e40093, 0x3d150061, 0x2d8b01ed, 0x00000000}},  //   _unil, _नइखे_, _cece_,
  { {0x2d8b003b, 0xee370245, 0xbddb00f4, 0x00000000}},  // [2640] _dece_, іну_, _chèq,
  { {0x8b26007e, 0xeb9a0d99, 0x2ca008ce, 0x00000000}},  //   одзе, риж_, rrid_,
  { {0x2d8b0207, 0xf1bf0010, 0x6ac603d6, 0x00000000}},  //   _fece_, knál_, تقام,
  { {0xa3d503d7, 0x752f0036, 0x2d8b01df, 0x00000000}},  //   ाएँ_, żczy, _gece_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xec3400a6, 0x2d8b001a, 0x00000000, 0x00000000}},  //   _روزگ, _zece_,   ,
  { {0xdb1c0065, 0x491a013d, 0xab270517, 0x00000000}},  //   _mbrë, _मेरो_, _дора_,
  { {0x16370054, 0x7ae10047, 0xd5b7041f, 0x00000000}},  //   يسية_, _álta, ось_,
  { {0xa3d503d7, 0x6fca0061, 0x442a003b, 0x00000000}},  //   ाएं_, ाजां, ицом_,
  { {0x22400047, 0x344a00e2, 0x00000000, 0x00000000}},  //   _akik_, јчин_,   ,
  { {0x32090038, 0xe73a0088, 0x2a6400e7, 0x00000000}},  //   _play_, _теж_, _kimb_,
  { {0x60100073, 0x78a20062, 0x80ac006e, 0x00000000}},  //   _jämf, orov, _जमशे,
  { {0xd258008b, 0x2d8b001a, 0xf9930104, 0x00000000}},  //   юць_, _rece_, ורר_,
  { {0x2d8b016c, 0x600b146f, 0x78a2007f, 0x00000000}},  //   _sece_, _sümb, irov,
  { {0x28d1007d, 0xed8b003b, 0x6579009d, 0x00000000}},  //   _दैनि, исак_, _éché,
  { {0xdb1c010f, 0x31350f62, 0x00000000, 0x00000000}},  //   _darü, _нейр,   ,
  { {0x2d8b037e, 0x31690010, 0x69c6000c, 0x00000000}},  // [2650] _vece_, _igaz_, _ókey,
  { {0x9f58009f, 0x78a20142, 0x26de0197, 0x00000000}},  //   skrá_, drov, _orto_,
  { {0x81ce0055, 0x3f910107, 0xa91d0059, 0x00000000}},  //   রার_, mazu_, _težk,
  { {0x3f910091, 0x2a64008a, 0xdb1c004a, 0x00000000}},  //   lazu_, _cimb_, _aaró,
  { {0x78a20387, 0xdb150181, 0xe9d8007e, 0x00000000}},  //   grov, _razõ, ўкі_,
  { {0xf7710137, 0xa91d0142, 0x3f91016c, 0x00000000}},  //   رات_, _ježi, nazu_,
  { {0x1ab4081e, 0xf4200044, 0x26de0087, 0x00000000}},  //   _обря, নকার_, _crto_,
  { {0x78a2049c, 0xa91d1470, 0xc4850256, 0x00000000}},  //   brov, _leži, плик,
  { {0xdb1c1471, 0x26de0026, 0x7bd504eb, 0x00000000}},  //   _abrè, _erto_, _kazu,
  { {0xa91d1472, 0xb68600a1, 0xf1bf0010, 0x00000000}},  //   _neži, _کھول_, snál_,
  { {0x7bd50ba3, 0x3f91002d, 0x442e1473, 0x00000000}},  //   _mazu, dazu_, _djf_,
  { {0x7bd500ca, 0xdb1c0036, 0x06c30044, 0x00000000}},  //   _lazu, _zaró, ্মদি,
  { {0xad9b0051, 0x442e0087, 0x386d004a, 0x00000000}},  //   _glúi, _fjf_, _juer_,
  { {0xdb1c0173, 0x31690288, 0x25ad010e, 0x00000000}},  //   _marò, _egaz_, lgel_,
  { {0x25ad0016, 0x6d4f004a, 0x25e00061, 0x00000000}},  //   ogel_, _azca, काची_,
  { {0x386d0007, 0x3f91012d, 0xe9ff0082, 0x00000000}},  //   _ouer_, aazu_, _thẹn_,
  { {0x7bd51474, 0xed5700ed, 0x00000000, 0x00000000}},  // [2660] _bazu, зот_,   ,
  { {0x7bd5000d, 0x91a800a1, 0x799b0085, 0x00000000}},  //   _cazu, _انکے_, _aduw,
  { {0x7bd501a2, 0x6d4f004a, 0x00000000, 0x00000000}},  //   _dazu, _ezca,   ,
  { {0x78a20027, 0x38c800a6, 0x6abb016c, 0x00000000}},  //   trov, قاتی_, _ćuft,
  { {0x2d921475, 0xdb1c090b, 0x79820036, 0x00000000}},  //   maye_, _paró, rbow,
  { {0x25ad010f, 0x2fca0a26, 0x7bd50035, 0x00000000}},  //   egel_, nebg_, _gazu,
  { {0x78a2012b, 0xdb1c008e, 0x386d01a2, 0x00000000}},  //   srov, _varó, _euer_,
  { {0x78a20038, 0x25ad0010, 0x2d921476, 0x00000000}},  //   prov, ggel_, naye_,
  { {0xb4d60164, 0x98a3007c, 0x7bd500e7, 0x00000000}},  //   ाटे_, _пите, _yazu,
  { {0xd7760025, 0x2d921477, 0xb8650025, 0x00000000}},  //   _رائع, haye_, _قالو,
  { {0x600b005f, 0x056606e1, 0x2d92055b, 0x00000000}},  //   _nüma, _евен, kaye_,
  { {0x7c3e0253, 0x442e0045, 0xa91d00ca, 0x00000000}},  //   hopr, _wjf_, _seži,
  { {0x2d92000b, 0x7c3e0c8a, 0x463b0049, 0x00000000}},  //   daye_, kopr, _פעדע,
  { {0x54530088, 0x644f0666, 0xa3e30316, 0x00000000}},  //   _звіт, ïcit, _पोप_,
  { {0x645a0fde, 0x7bd50295, 0x3f910387, 0x00000000}},  //   mmti, _razu, razu_,
  { {0x443e006a, 0x2d920061, 0x6d460007, 0x00000000}},  //   lot_, gaye_, _byka,
  { {0x423801f8, 0x7bd51478, 0x443e0007, 0x00000000}},  // [2670] _מנהל_, _pazu, oot_,
  { {0x443e001e, 0xf092019b, 0x442c000c, 0x00000000}},  //   not_, _שני_, nnd_,
  { {0x2d92000b, 0x644801e5, 0x7bd5001a, 0x00000000}},  //   baye_, ildi, _vazu,
  { {0x7bd50020, 0x2d920009, 0xa2a4006e, 0x00000000}},  //   _wazu, caye_, _किन्,
  { {0xddc4038c, 0x443e006a, 0x89370054, 0x00000000}},  //   lmiş, kot_, أعضا,
  { {0xd3660b59, 0x443e001e, 0x7c3e0197, 0x00000000}},  //   _له_, jot_, copr,
  { {0x443e1479, 0x6e2d05f0, 0xddc4005a, 0x00000000}},  //   dot_, onab, nmiş,
  { {0x442c05d0, 0x644800c7, 0x386d009d, 0x00000000}},  //   end_, eldi, _tuer_,
  { {0x442c009f, 0x62980207, 0x69cb147a, 0x00000000}},  //   fnd_, _avvo, mege,
  { {0x443e147b, 0x69cb03a1, 0x442c0009, 0x00000000}},  //   got_, lege, gnd_,
  { {0x81d70055, 0xdb1c000c, 0xd1ca007c, 0x00000000}},  //   সান_, _jarð, олне_,
  { {0x6448022b, 0x69d9147c, 0x442c01b5, 0x00000000}},  //   aldi, ndwe, and_,
  { {0x20040181, 0x6e2d0016, 0x628a01f3, 0x00000000}},  //   êmio_, dnab, _ewfo,
  { {0x443e0687, 0x2d920263, 0x81ce0044, 0x00000000}},  //   cot_, waye_, রাই_,
  { {0x2d92147d, 0x7f43007c, 0x7c3e09fc, 0x00000000}},  //   taye_, верж, vopr,
  { {0x6281147e, 0x6e2d000c, 0x7649014a, 0x00000000}},  //   mplo, gnab, nley,
  { {0x7c3e0263, 0x2d920173, 0x60c400e7, 0x00000000}},  // [2680] topr, raye_, _upim,
  { {0x2d92147f, 0x69d901c3, 0x7649049d, 0x00000000}},  //   saye_, edwe, hley,
  { {0x600b006c, 0x7649014a, 0x62810173, 0x00000000}},  //   _kümn, kley, nplo,
  { {0x6b8e022b, 0x69cb05c6, 0x443e0089, 0x00000000}},  //   _webg, gege, zot_,
  { {0x442c009f, 0x443e0058, 0x69c00061, 0x00000000}},  //   ynd_, yot_, _vbme,
  { {0x69d901d6, 0x443e1480, 0x656b0026, 0x00000000}},  //   adwe, xot_, _aggh,
  { {0x443e004f, 0x69cb054e, 0xdb1c000c, 0x00000000}},  //   vot_, bege, _garð,
  { {0xd49a00d7, 0xceb300b6, 0x442c10a5, 0x00000000}},  //   оро_, דיה_, wnd_,
  { {0x443e1481, 0x7d040093, 0x64a300ed, 0x00000000}},  //   tot_, nyis, вања,
  { {0x442c1482, 0x9f5a0023, 0xb05b01a2, 0x00000000}},  //   und_, _copë_, hwär,
  { {0x443e001e, 0x442c00db, 0xe57a008b, 0x00000000}},  //   rot_, rnd_, _дзе_,
  { {0x443e0089, 0x7d0400b0, 0x84ea01d8, 0x00000000}},  //   sot_, kyis, _وفاق_,
  { {0x443e1483, 0x92be0044, 0xdb1e0961, 0x00000000}},  //   pot_, ঁটে_, lepä,
  { {0xa29401ff, 0xdb1e0181, 0xddc4005d, 0x00000000}},  //   _закі, cepç, tmiş,
  { {0x81d70044, 0x69d90016, 0xb05b01a2, 0x00000000}},  //   সাব_, ydwe, fwär,
  { {0xddc4038c, 0x76400319, 0xc333009b, 0x00000000}},  //   rmiş, nomy, _שוק_,
  { {0x6e2d000c, 0x69cb1484, 0xdc5501fc, 0x00000000}},  // [2690] rnab, vege, евањ,
  { {0x69cb07eb, 0x9f89000c, 0x6e2d00f8, 0x00000000}},  //   wege, _góðu_, snab,
  { {0x76400006, 0x7649014a, 0xe0df0026, 0x00000000}},  //   komy, yley, lvò_,
  { {0xdb1c009f, 0x76400036, 0xdddd0036, 0x00000000}},  //   _varð, jomy, _wisł,
  { {0x69cb0599, 0x7d160036, 0x999600a1, 0x00000000}},  //   rege, czys, رپور_,
  { {0x69cb0059, 0x78ab00c7, 0xd76300a1, 0x00000000}},  //   sege, rugv, نچای,
  { {0x76491402, 0x69cb0030, 0x628100b4, 0x00000000}},  //   tley, pege, xplo,
  { {0xb8d50055, 0x00000000, 0x00000000, 0x00000000}},  //   _জন_,   ,   ,
  { {0x3e750039, 0xe7e00164, 0x764903fb, 0x00000000}},  //   _låt_, _गोवा_, rley,
  { {0x764906b5, 0x62810116, 0x00000000, 0x00000000}},  //   sley, tplo,   ,
  { {0x3e750039, 0x7649011c, 0xc7d6009b, 0x00000000}},  //   _nåt_, pley, _רועי_,
  { {0x6281088d, 0x76400912, 0x31790009, 0x00000000}},  //   rplo, comy, gcsz_,
  { {0x62810209, 0x00000000, 0x00000000, 0x00000000}},  //   splo,   ,   ,
  { {0x25bf0951, 0x3e7500d8, 0x660905b7, 0x00000000}},  //   lful_, _båt_, lkek,
  { {0x64410091, 0x6e241485, 0x8464005e, 0x00000000}},  //   moli, tiib, _ръце,
  { {0xee3a01fb, 0x7d04021e, 0xa2a40204, 0x00000000}},  //   їна_, tyis, _कित्,
  { {0xdca30216, 0x44251486, 0x25bf04be, 0x00000000}},  // [26a0] лати, oil_, iful_,
  { {0x7d160046, 0x64410016, 0x6e241487, 0x00000000}},  //   rzys, noli, siib,
  { {0xa3b70204, 0x387f1488, 0xad9b0d62, 0x00000000}},  //   _छान_, _atur_, _clús,
  { {0x6441018e, 0x44250811, 0x7d041489, 0x00000000}},  //   holi, hil_, pyis,
  { {0x6441091e, 0x25bf0016, 0x4973007e, 0x00000000}},  //   koli, dful_, уліс,
  { {0x442501a3, 0xf093009b, 0x6441073a, 0x00000000}},  //   jil_, ננו_, joli,
  { {0x6441148a, 0x442507ac, 0x7640013e, 0x00000000}},  //   doli, dil_, tomy,
  { {0xdb1e006c, 0xd90d00a1, 0xcb67007e, 0x00000000}},  //   repä, _ڈیم_, _часе_,
  { {0xddde001e, 0xdb1e01b1, 0x764005ac, 0x00000000}},  //   _atpū, sepä, romy,
  { {0x6441018e, 0x442503b0, 0x600b0279, 0x00000000}},  //   goli, gil_, _cüml,
  { {0x60d60133, 0xdb1c00f6, 0xb05b01a2, 0x00000000}},  //   _asym, _obrí, ltäg,
  { {0x44250051, 0x6609148b, 0xad9b00f6, 0x00000000}},  //   ail_, ckek, _llúr,
  { {0x6441148c, 0xb5fb0104, 0xc05b0088, 0x00000000}},  //   boli, _מלאכ, зів_,
  { {0x20d60107, 0x64410207, 0x31790061, 0x00000000}},  //   džić_, coli, scsz_,
  { {0xdd95007e, 0x80c40044, 0x00000000, 0x00000000}},  //   кавы, শিষ্,   ,
  { {0x931200a1, 0x3e7502e1, 0x629a148d, 0x00000000}},  //   _لوڈش, _våt_, msto,
  { {0x629a001e, 0x61ed148e, 0xd2f8026c, 0x00000000}},  // [26b0] lsto, _inal, _رکھا_,
  { {0x600b0eaa, 0x629a0052, 0x00000000, 0x00000000}},  //   _kümm, osto,   ,
  { {0xd011026c, 0x61ed0030, 0x76aa006b, 0x00000000}},  //   _ملک_, _knal, _təyy,
  { {0x6441148f, 0x629a00b0, 0xdbd7003c, 0x00000000}},  //   zoli, isto, _sääs,
  { {0xdbd70368, 0x442506db, 0xfd9601f8, 0x00000000}},  //   _pääs, yil_, _בדרך_,
  { {0x629a0ade, 0x4425005f, 0x2ca900f8, 0x00000000}},  //   ksto, xil_, mrad_,
  { {0x4425060b, 0x629a0091, 0xe7e00061, 0x00000000}},  //   vil_, jsto, _गोळा_,
  { {0x44250016, 0x64411490, 0x78a4016e, 0x00000000}},  //   wil_, woli, šiva,
  { {0x629a0027, 0x25bf00ab, 0x66090145, 0x00000000}},  //   esto, rful_, rkek,
  { {0x69db022b, 0x629a000c, 0x2b9c00b9, 0x00000000}},  //   _haue, fsto, mácí_,
  { {0x629a127f, 0x69db1491, 0x38bb01d6, 0x00000000}},  //   gsto, _kaue, lêr_,
  { {0x44251492, 0x412a02d3, 0xe5e500a2, 0x00000000}},  //   sil_, домо_, _جزئی,
  { {0x44250607, 0x66060047, 0x69db010f, 0x00000000}},  //   pil_, ökke, _maue,
  { {0x2ca91493, 0x629a01a2, 0x69db0e42, 0x00000000}},  //   drad_, bsto, _laue,
  { {0xa067132e, 0x629a1494, 0x7db60131, 0x00000000}},  //   тара_, csto, ксац,
  { {0x6458008d, 0x3ea51430, 0xf1bf008e, 0x00000000}},  //   _zhvi, álta_, lián_,
  { {0x2ca9012b, 0x8e5501fb, 0xdd8f01d8, 0x00000000}},  // [26c0] grad_, утрі, زول_,
  { {0x61ed091e, 0x81ce0044, 0x62860107, 0x00000000}},  //   _znal, রাও_, ćkov,
  { {0x69db010f, 0x3f9801ed, 0x93bc0035, 0x00000000}},  //   _baue, maru_, onăr,
  { {0x2ca9006c, 0xa2a4006e, 0x69db0f57, 0x00000000}},  //   brad_, _किस्, _caue,
  { {0x69db0fa5, 0xa967017f, 0x629a0087, 0x00000000}},  //   _daue, вица_, zsto,
  { {0xbcfb0047, 0x629a0036, 0x81ce0044, 0x00000000}},  //   _egés, ysto, রাট_,
  { {0x48ee03d7, 0x59dd0061, 0x629a1495, 0x00000000}},  //   _आपको_, _नोकर, xsto,
  { {0x7bdc0149, 0xe5c60679, 0x76591496, 0x00000000}},  //   _haru, тско, _chwy,
  { {0x26030219, 0x3f980089, 0x7bdc1497, 0x00000000}},  //   _años_, karu_, _karu,
  { {0x7bde00c7, 0x629a05c6, 0x7bdc1498, 0x00000000}},  //   ndpu, tsto, _jaru,
  { {0x7bdc1499, 0x81dc0055, 0x629a00b0, 0x00000000}},  //   _maru, ঠান_, usto,
  { {0x7bdc149a, 0x3f93149b, 0xe8df0082, 0x00000000}},  //   _laru, _sexu_, _uyển_,
  { {0x629a0056, 0x3f9804c0, 0xf1bf149c, 0x00000000}},  //   ssto, faru_, bián_,
  { {0x7bdc149d, 0x629a0056, 0x4394005e, 0x00000000}},  //   _naru, psto, _сакс,
  { {0x5f940594, 0x81ce0044, 0xc43400a1, 0x00000000}},  //   рист, রাজ_, _لکھت,
  { {0x2ca908c9, 0x61ed016a, 0x7bdc149e, 0x00000000}},  //   trad_, _unal, _aaru,
  { {0x68e2003b, 0x7bdc00f0, 0x3f980142, 0x00000000}},  // [26d0] jvod, _baru, baru_,
  { {0x600b038c, 0x7bdc001a, 0x2ca9010f, 0x00000000}},  //   _mümk, _caru, rrad_,
  { {0xba740379, 0x69db0032, 0x68e20035, 0x00000000}},  //   لانت, _paue, evod,
  { {0xc33300b6, 0xb05b0a5d, 0x60100039, 0x00000000}},  //   בוע_, städ, _jämn,
  { {0x7659018e, 0x80d9013d, 0x7bdc149f, 0x00000000}},  //   _rhwy, मिटे, _faru,
  { {0x60100073, 0x7bdc1108, 0x386c0022, 0x00000000}},  //   _lämn, _garu, _cidr_,
  { {0xaa670780, 0x8cdb006e, 0x76590016, 0x00000000}},  //   _атак, निको, _phwy,
  { {0x7bdc04c8, 0x3f9814a0, 0x60100039, 0x00000000}},  //   _zaru, zaru_, _nämn,
  { {0x29190039, 0x7bdc00e7, 0x2459009d, 0x00000000}},  //   _åsa_, _yaru, hème_,
  { {0x87d70879, 0x23d50478, 0x6b9514a1, 0x00000000}},  //   _جغرا, уцир, _jezg,
  { {0x3f980027, 0x6b95008f, 0xf1bf0142, 0x00000000}},  //   varu_, _mezg, rián_,
  { {0x3f9814a2, 0x79990085, 0x394d0173, 0x00000000}},  //   waru_, naww, _kyes_,
  { {0x3f98016e, 0x00000000, 0x00000000, 0x00000000}},  //   taru_,   ,   ,
  { {0x70560426, 0x6b950825, 0x2a6d01a2, 0x00000000}},  //   انسا, _nezg, _lieb_,
  { {0xdb1c0428, 0x68e204c8, 0x6da6041f, 0x00000000}},  //   _obrá, zvod, лива,
  { {0x7bdc001e, 0x3f9801c5, 0x2bc6013d, 0x00000000}},  //   _saru, saru_, र्ना,
  { {0x3f980089, 0x6b950ad8, 0x229800b9, 0x00000000}},  // [26e0] paru_, _bezg, _týká_,
  { {0xb05b00b0, 0xd0f7009b, 0xdb1c10c9, 0x00000000}},  //   ttäe, _עמית_, _abrá,
  { {0x7bdc0ac2, 0x81d70055, 0x2a6d002b, 0x00000000}},  //   _varu, সার_, _bieb_,
  { {0x7bdc0a70, 0xe947025a, 0x02b60049, 0x00000000}},  //   _waru, گرمی, טלעך_,
  { {0xa3b301f5, 0x7bdc04cb, 0x69c2018d, 0x00000000}},  //   टला_, _taru, rfoe,
  { {0xd6da017f, 0xa2a40164, 0x600b006b, 0x00000000}},  //   ети_, _किल्, _cümh,
  { {0x394d00ab, 0xfd500082, 0x68e2013e, 0x00000000}},  //   _eyes_, _nghẹ, svod,
  { {0xa5bd0006, 0x00000000, 0x00000000, 0x00000000}},  //   liųj,   ,   ,
  { {0x27ef0224, 0x20180022, 0x9916007e, 0x00000000}},  //   ální_, khri_, _сьві,
  { {0x1cbb0049, 0xd5a4009e, 0x77920241, 0x00000000}},  //   עמיע, _چلای, _ایثا,
  { {0x2bc602f4, 0xe9ff0011, 0x2bf70104, 0x00000000}},  //   र्या, _chặn_, אמין_,
  { {0x54e6004b, 0xdb0501a2, 0xf1bf0062, 0x00000000}},  //   _مستق, pfhö, ciál_,
  { {0x62830056, 0x75d30379, 0x00000000, 0x00000000}},  //   _etno, _دينا,   ,
  { {0x2bc602fb, 0xc5bc0044, 0xddd00340, 0x00000000}},  //   र्मा, _অফটপ, _češk,
  { {0xe1ff0010, 0x00000000, 0x00000000, 0x00000000}},  //   tmód_,   ,   ,
  { {0x66020004, 0xfc240055, 0x62880a7e, 0x00000000}},  //   _jook, বকোষ_, mpdo,
  { {0x82340167, 0x2001006c, 0x2a6d14a3, 0x00000000}},  // [26f0] _دروا, _tohi_, _rieb_,
  { {0x66020038, 0x6fb2013d, 0x60cd011c, 0x00000000}},  //   _look, _जाएं, _ipam,
  { {0xdddc11af, 0xf09f00f6, 0x00000000, 0x00000000}},  //   sprš, lsà_,   ,
  { {0x394d14a4, 0x5efa00a0, 0xfde9007d, 0x00000000}},  //   _pyes_, _ספרד, _ऑफिस_,
  { {0x0ff800a1, 0x7c840140, 0x6b950823, 0x00000000}},  //   _شعیب_, _гусе, _tezg,
  { {0x601003a9, 0x60cd14a5, 0x79990145, 0x00000000}},  //   _näml, _mpam, saww,
  { {0x66020038, 0xe5710025, 0x4ac90061, 0x00000000}},  //   _book, يطة_, _रहिव,
  { {0x660201a6, 0x7aea0030, 0x1b1e0044, 0x00000000}},  //   _cook, æfte, _বুকে_,
  { {0xf1bf0161, 0xc7d9005e, 0x660214a6, 0x00000000}},  //   riál_, _имах_, _dook,
  { {0x291d00e7, 0x4ac90061, 0xe4c80025, 0x00000000}},  //   mzwa_, _रहाव, ابين_,
  { {0xfbd200b6, 0x60cd0085, 0x2d9b0023, 0x00000000}},  //   חתי_, _apam, kaqe_,
  { {0x01660ae0, 0xb34500f6, 0x998f0006, 0x00000000}},  //   икно, _alçà, mogų_,
  { {0xe0d70265, 0x2bc60061, 0x291d00e7, 0x00000000}},  //   авя_, र्डा, nzwa_,
  { {0x249f0022, 0x660204a5, 0x6e260145, 0x00000000}},  //   msum_, _zook, _smkb,
  { {0x44d60046, 0x69c900d4, 0x92f601fa, 0x00000000}},  //   _zł_, _obee, _نفوذ_,
  { {0x409601ee, 0x442700e0, 0x68e90203, 0x00000000}},  //   _крот, _hmn_, _ored,
  { {0x249f0a16, 0x8fa6003b, 0x6010044e, 0x00000000}},  // [2700] nsum_, _капе, _hämm,
  { {0x81d70044, 0x69c904e6, 0x601014a7, 0x00000000}},  //   সাঃ_, _abee, _kämm,
  { {0xdef9008b, 0xf77801d5, 0x68e90544, 0x00000000}},  //   _быў_, _naħa_, _ared,
  { {0x68e90239, 0xda650025, 0xb05b0039, 0x00000000}},  //   _bred, ماني, ptäc,
  { {0x601000b0, 0x3e7c0082, 0x7e64010e, 0x00000000}},  //   _lämm, _hít_, mmip,
  { {0xb8ce02d2, 0x68e914a8, 0x4427011c, 0x00000000}},  //   _कि_, _dred, _nmn_,
  { {0x68e914a9, 0xfaa3007e, 0x8f9b0049, 0x00000000}},  //   _ered, _маро, דיצי,
  { {0x68e904d7, 0x2d8014aa, 0x3e7c0224, 0x00000000}},  //   _fred, ncie_, _mít_,
  { {0x3e7c14ab, 0x2bc60061, 0x2ca014ac, 0x00000000}},  //   _lít_, र्था, nsid_,
  { {0xe3b8027d, 0x442714ad, 0x2a78006c, 0x00000000}},  //   lnız_, _cmn_, _kurb_,
  { {0x2d8014ae, 0x44270022, 0x68e90d0a, 0x00000000}},  //   kcie_, _dmn_, _zred,
  { {0x2ca00004, 0x2d800036, 0x2bc6007d, 0x00000000}},  //   ksid_, jcie_, र्ता,
  { {0x25a60c3b, 0x44270023, 0x601000f8, 0x00000000}},  //   _idol_, _fmn_, _täml,
  { {0x2d800036, 0x44270093, 0x3e7c0011, 0x00000000}},  //   ecie_, _gmn_, _bít_,
  { {0xf09f04b9, 0x442c14af, 0x6d4f0675, 0x00000000}},  //   ssà_, mid_, _syca,
  { {0x442c0004, 0xef190036, 0x1317009b, 0x00000000}},  //   lid_, ąż_, _כחול_,
  { {0x442c00bb, 0x60cd0a0f, 0x44270022, 0x00000000}},  // [2710] oid_, _upam, _ymn_,
  { {0x442c0b83, 0x6448046a, 0x1fa70478, 0x00000000}},  //   nid_, nodi, _триг,
  { {0x68e90bf8, 0x2bc6007d, 0x25a6002d, 0x00000000}},  //   _sred, र्धा, _odol_,
  { {0x68e913a1, 0x442c005f, 0x64480161, 0x00000000}},  //   _pred, hid_, hodi,
  { {0x442c0b1a, 0x2ca014b0, 0xb9c40025, 0x00000000}},  //   kid_, csid_, تقني,
  { {0x6e2d14b1, 0x68e9037a, 0x442c0427, 0x00000000}},  //   liab, _vred, jid_,
  { {0x442c017b, 0x7d0d14b2, 0x2d9901ee, 0x00000000}},  //   did_, lyas, _kese_,
  { {0x68e901e2, 0xdb160051, 0x6e2d14b3, 0x00000000}},  //   _tred, _ócái, niab,
  { {0x68e91034, 0x7d0d047f, 0x2d990207, 0x00000000}},  //   _ured, nyas, _mese_,
  { {0x644810ec, 0x249f0270, 0x2d990292, 0x00000000}},  //   godi, rsum_, _lese_,
  { {0x249f14b4, 0x8c1a009b, 0x2d800036, 0x00000000}},  //   ssum_, רותי, ycie_,
  { {0x2d99008d, 0x442c14b5, 0x7d0d0173, 0x00000000}},  //   _nese_, aid_, kyas,
  { {0x442c006c, 0x644814b6, 0x44270145, 0x00000000}},  //   bid_, bodi, _tmn_,
  { {0x2d9906c2, 0x7d0d09e5, 0x3e7c14b7, 0x00000000}},  //   _aese_, dyas, _pít_,
  { {0x81bf0055, 0x2d9901aa, 0xddc60006, 0x00000000}},  //   ীয়_, _bese_, _aikš,
  { {0xf2d20049, 0x2ca0006c, 0xdb1700c4, 0x00000000}},  //   _זעה_, tsid_, nexõ,
  { {0x2d8014b8, 0x7d0d0010, 0x6e360006, 0x00000000}},  // [2720] rcie_, gyas, rnyb,
  { {0x2d800036, 0x2ca0006c, 0x3e7c0082, 0x00000000}},  //   scie_, rsid_, _tít_,
  { {0x2ca009e7, 0x2d990065, 0xd24f00a2, 0x00000000}},  //   ssid_, _fese_, _زنی_,
  { {0x6e2d0f6a, 0x2d990007, 0x753d0036, 0x00000000}},  //   ciab, _gese_, ższy,
  { {0xdb1e0010, 0x442c013f, 0x28f80194, 0x00000000}},  //   lepü, yid_, рель_,
  { {0xf093009b, 0x00000000, 0x00000000, 0x00000000}},  //   לנד_,   ,   ,
  { {0x64480340, 0x24860116, 0x07a3025f, 0x00000000}},  //   vodi, _stom_, чајн,
  { {0x442c018e, 0x3f9a05fa, 0xf1bf0010, 0x00000000}},  //   wid_, _lepu_, riák_,
  { {0x64480142, 0x38cb00a6, 0xa3b30061, 0x00000000}},  //   todi, _مالی_, टलं_,
  { {0x3e410006, 0x79820036, 0x00000000, 0x00000000}},  //   mėte_, lcow,   ,
  { {0x442c14b9, 0x644814ba, 0x95ca01fb, 0x00000000}},  //   rid_, rodi, _була_,
  { {0x442c061f, 0x26de14bb, 0x64480010, 0x00000000}},  //   sid_, _isto_, sodi,
  { {0x64480059, 0x6e2d00d6, 0x2d9914bc, 0x00000000}},  //   podi, viab, _rese_,
  { {0x442c0003, 0x3f9a04be, 0xddc6129d, 0x00000000}},  //   qid_, _cepu_, _rikš,
  { {0x533314bd, 0x877b01f8, 0x6e2d08a8, 0x00000000}},  //   _нешт, ראלי, tiab,
  { {0x7d0d14be, 0x00000000, 0x00000000, 0x00000000}},  //   tyas,   ,   ,
  { {0x2d9914bf, 0x78a2016c, 0x443c013f, 0x00000000}},  // [2730] _vese_, jsov, _kjv_,
  { {0x224b0030, 0x2d9914c0, 0x78a214c1, 0x00000000}},  //   lock_, _wese_, dsov,
  { {0x2d9900c4, 0x7d0d09e5, 0x6d410036, 0x00000000}},  //   _tese_, syas, _ślad,
  { {0x75200061, 0x224b0b3d, 0x13e10044, 0x00000000}},  //   kzmz, nock_, বায়,
  { {0x6e3d14c2, 0x7d0d006b, 0xc879006b, 0x00000000}},  //   _ijsb, qyas, _quş_,
  { {0x18690437, 0x6d5d0089, 0x224b14c3, 0x00000000}},  //   шали_, _izsa, hock_,
  { {0xb05b021e, 0xe3ae0044, 0x661b0258, 0x00000000}},  //   ytän, কভাব, thuk,
  { {0xc485012b, 0x0609005e, 0x34a9012b, 0x00000000}},  //   олик, рник_, авио_,
  { {0x26de0219, 0xe3b10076, 0x2bc6007d, 0x00000000}},  //   _esto_, ورد_, र्वा,
  { {0x661b000b, 0x799b01d6, 0x42c900e2, 0x00000000}},  //   shuk, _heuw, агон_,
  { {0xd7f80011, 0xb05b00b0, 0xe2990098, 0x00000000}},  //   _khăn_, ttän, јам_,
  { {0xb68600a1, 0xcf8900a0, 0x00000000, 0x00000000}},  //   _بھول_, _יט_,   ,
  { {0xb05b14c4, 0x799b00d9, 0x443c1408, 0x00000000}},  //   rtän, _meuw, _fjv_,
  { {0xb05b14c5, 0x799b0022, 0x248d14c6, 0x00000000}},  //   stän, _leuw, mpem_,
  { {0xdee30072, 0x7bd714c7, 0x3f6a05a5, 0x00000000}},  //   мори, dexu, риво_,
  { {0x799b010f, 0xe1ff008e, 0xd7f80082, 0x00000000}},  //   _neuw, lmón_, _nhăn_,
  { {0xad66007a, 0x3f9a0145, 0x00000000, 0x00000000}},  // [2740] زاره, _tepu_,   ,
  { {0x61e60bc7, 0x6b560a27, 0xb05b00b0, 0x00000000}},  //   ldkl, отех, ntäl,
  { {0x61e4006a, 0x41b3009e, 0xfe460ab6, 0x00000000}},  //   _kail, _عمیر, _мноо,
  { {0xd7f80011, 0x78a20e38, 0xdcfd0006, 0x00000000}},  //   _chăn_, tsov, _nesė,
  { {0x61e414c8, 0xe89409b5, 0xc7ba008b, 0x00000000}},  //   _mail, чаль, аёй_,
  { {0xacd9007b, 0x2cb2018e, 0x61e400b0, 0x00000000}},  //   _פֿרי, mryd_, _lail,
  { {0x78a20161, 0xa01b00b0, 0x26de0026, 0x00000000}},  //   ssov, mpöt, _qsto_,
  { {0x78ad0119, 0x6b9c14c9, 0x61e414ca, 0x00000000}},  //   šava, _herg, _nail,
  { {0x6b9c0004, 0x7aee0059, 0xdb07000a, 0x00000000}},  //   _kerg, _hrbt, _adjè,
  { {0x3eb80065, 0x2fd80030, 0xdb1c00c4, 0x00000000}},  //   kurt_, jerg_, _acré,
  { {0x61e4002a, 0x4b7b0049, 0x6b9c14cb, 0x00000000}},  //   _bail, יטיג, _merg,
  { {0x61e4002a, 0x201a0197, 0x6b9c0203, 0x00000000}},  //   _cail, _alpi_, _lerg,
  { {0x61e40273, 0x660f0a5d, 0x2d920133, 0x00000000}},  //   _dail, öcke, dbye_,
  { {0xcbd50055, 0x3eb8010f, 0x6b9c00b5, 0x00000000}},  //   _হচ্ছ, furt_, _nerg,
  { {0xdd9b0216, 0x93cb00a1, 0x69c00009, 0x00000000}},  //   иша_, _خانہ_, _ocme,
  { {0x3ead004f, 0x61e414cc, 0x7bce01d5, 0x00000000}},  //   čet_, _gail, _abbu,
  { {0x2fd806d3, 0x6b9c020c, 0xc05b01fb, 0x00000000}},  // [2750] berg_, _berg, _він_,
  { {0x61e4002d, 0x69c014cd, 0x3eb8010f, 0x00000000}},  //   _zail, _acme, burt_,
  { {0x6b9c14ce, 0x23c2006e, 0xb05b00b0, 0x00000000}},  //   _derg, _शानद, ntäm,
  { {0x6b9c0116, 0x2cb20016, 0x69c0000a, 0x00000000}},  //   _eerg, bryd_, _ccme,
  { {0x6b9c002b, 0x6d5d14cf, 0xd94500e2, 0x00000000}},  //   _ferg, _uzsa, џели,
  { {0x3abb007a, 0xa69500ec, 0x6b9c14d0, 0x00000000}},  //   _پاسخ_, приј, _gerg,
  { {0x09c20055, 0x199514d1, 0x290200f6, 0x00000000}},  //   োয়া, _навя, _àkan_,
  { {0x6b9c022b, 0xd6ce0379, 0x6b850016, 0x00000000}},  //   _zerg, اقي_, lchg,
  { {0x69d914d2, 0x6d43010f, 0x61e400ab, 0x00000000}},  //   mewe, ßnah, _rail,
  { {0x69d90007, 0x61e40238, 0x9422007c, 0x00000000}},  //   lewe, _sail, емье,
  { {0x81e50055, 0x61e40ffc, 0xef200036, 0x00000000}},  //   নান_, _pail, ążki_,
  { {0xb05b0073, 0x614600ed, 0x628a004a, 0x00000000}},  //   stäl, зема, _dtfo,
  { {0x61e40dd9, 0x61e614d3, 0xf992009b, 0x00000000}},  //   _vail, rdkl, ערך_,
  { {0xdff5007e, 0x27e50022, 0xe3b30014, 0x00000000}},  //   мясь, _jaln_, _آرش_,
  { {0x61e400f4, 0x69d900ea, 0x26c70f3a, 0x00000000}},  //   _tail, kewe, ntno_,
  { {0x69d9020f, 0x2cb20007, 0xbc760025, 0x00000000}},  //   jewe, tryd_, كهرب,
  { {0x69d900b5, 0xee370088, 0x721b009b, 0x00000000}},  // [2760] dewe, їну_, _לוקח,
  { {0x63a114d4, 0x26c714d5, 0xdce6001e, 0x00000000}},  //   naln, ktno_, _iekļ,
  { {0x6b9c14d6, 0xc986017a, 0x9f97009b, 0x00000000}},  //   _verg, пули, _מדיה_,
  { {0x69d90168, 0x63a100ca, 0x32090011, 0x00000000}},  //   gewe, haln, _xoay_,
  { {0x63a101d9, 0x6b9c0169, 0xc5c30044, 0x00000000}},  //   kaln, _terg, ্যাপ,
  { {0x63a10213, 0xfaa60088, 0x3a3f002f, 0x00000000}},  //   jaln, _наго, _ejup_,
  { {0x69d90c0c, 0x7c2e001a, 0x8c1b009b, 0x00000000}},  //   bewe, _imbr, _פולי,
  { {0x44f40764, 0xbb3b00b3, 0x09e301ee, 0x00000000}},  //   дпис, _העלי, _посн,
  { {0x81e50044, 0x3e41007f, 0x00000000, 0x00000000}},  //   নাম_, nėta_,   ,
  { {0xb05b021e, 0x2281000c, 0x00000000, 0x00000000}},  //   ttäm, _bók_,   ,
  { {0xe1d901fb, 0x316014d7, 0x7e7e05e0, 0x00000000}},  //   одні_, _aziz_, _nupp,
  { {0xe71700a0, 0x63a1006c, 0xa1940245, 0x00000000}},  //   _מחבר_, aaln, наюч,
  { {0xd6250025, 0xb05b14d8, 0x7c2e03e2, 0x00000000}},  //   _تعلي, stäm, _ombr,
  { {0x63a114d9, 0x3e41007f, 0x00000000, 0x00000000}},  //   caln, dėta_,   ,
  { {0x442e0010, 0x7e7e0190, 0x628a01c9, 0x00000000}},  //   _imf_, _cupp, _utfo,
  { {0x7e7e00ea, 0xc333009b, 0x433b009b, 0x00000000}},  //   _dupp, _רוק_, _לעוב,
  { {0x442e0697, 0xb05b0b6f, 0x69d90253, 0x00000000}},  // [2770] _kmf_, ntäk, vewe,
  { {0x31380097, 0x70550014, 0xf7780066, 0x00000000}},  //   _מנחם_, _زنجا, _daħk_,
  { {0xd7f8001d, 0x6b85010f, 0x69d90112, 0x00000000}},  //   _chăm_, rchg, tewe,
  { {0x63a114da, 0xf1bf14db, 0x7c2e14dc, 0x00000000}},  //   zaln, ngá_, _embr,
  { {0x37e500da, 0x7e7e0197, 0x69d90a6b, 0x00000000}},  //   долг, _zupp, rewe,
  { {0x69d90c4c, 0x442e04a5, 0x00000000, 0x00000000}},  //   sewe, _nmf_,   ,
  { {0x63a101d9, 0xb05b021e, 0x00000000, 0x00000000}},  //   valn, ttäj,   ,
  { {0x60100039, 0x26c70059, 0x442e00f8, 0x00000000}},  //   _hämt, rtno_, _amf_,
  { {0x26c701d9, 0xf2b60044, 0x93fd007e, 0x00000000}},  //   stno_, _জনগণ, аўнi,
  { {0x52a914dd, 0x60100039, 0x442e0145, 0x00000000}},  //   овом_, _jämt, _cmf_,
  { {0x63a114de, 0x2bcf0309, 0x387f01b5, 0x00000000}},  //   raln, स्या, _huur_,
  { {0x63a10169, 0x7e7e0109, 0x387f0cf0, 0x00000000}},  //   saln, _rupp, _kuur_,
  { {0x7e7e030a, 0x63a10aa9, 0xa5bd010a, 0x00000000}},  //   _supp, paln, siųs,
  { {0x2281009f, 0xa2d8013d, 0x387f00c7, 0x00000000}},  //   _tók_, _फैक्, _muur_,
  { {0x41c6013d, 0x00000000, 0x00000000, 0x00000000}},  //   _वापस,   ,   ,
  { {0x25bf048f, 0x00000000, 0x00000000, 0x00000000}},  //   ngul_,   ,   ,
  { {0xed5701f9, 0xdca30088, 0x387f06a4, 0x00000000}},  // [2780] дот_, кати, _nuur_,
  { {0x8d63007c, 0x7e7e006c, 0x4d630088, 0x00000000}},  //   твуе, _tupp, ткув,
  { {0x78a90198, 0x0e6614df, 0xb9e60088, 0x00000000}},  //   _avev, _окон, діли,
  { {0x81e50044, 0x8b650257, 0x387f14e0, 0x00000000}},  //   নাথ_, رالم, _buur_,
  { {0xd37805fa, 0x00000000, 0x00000000, 0x00000000}},  //   leće_,   ,   ,
  { {0xd7f8001d, 0x387f01b5, 0x368a0088, 0x00000000}},  //   _thăm_, _duur_, осин_,
  { {0xd378016c, 0x6a8300ed, 0x660b0190, 0x00000000}},  //   neće_, _алса, _bogk,
  { {0x973c0091, 0x25bf0169, 0xd5b000a1, 0x00000000}},  //   _neće, ggul_, اہش_,
  { {0xe3ce001d, 0x47c6012b, 0x442e00f6, 0x00000000}},  //   _dựng_, _обав, _pmf_,
  { {0x7c3e0145, 0x7e660022, 0x4ad20061, 0x00000000}},  //   nnpr, _lhkp, _सहाव,
  { {0x0bb700b6, 0xd3780166, 0xe2f80088, 0x00000000}},  //   ולים_, jeće_, чені_,
  { {0xd3780091, 0x442e0e42, 0x00000000, 0x00000000}},  //   deće_, _wmf_,   ,
  { {0x442e00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _tmf_,   ,   ,
  { {0xdb1c1343, 0x8ca2013d, 0x442e14e1, 0x00000000}},  //   _acrí, गठनो, _umf_,
  { {0x443e02e1, 0x7687014a, 0xadd5003b, 0x00000000}},  //   mnt_, _kıya, новљ,
  { {0x645a018e, 0xf1d0001d, 0x6010010f, 0x00000000}},  //   llti, _hạng_, _sämt,
  { {0x2d5807ca, 0x443e0e94, 0xf4bc0044, 0x00000000}},  // [2790] дить_, ont_, _অনুব,
  { {0x443e14e2, 0x7c3e0146, 0x2bbb0025, 0x00000000}},  //   nnt_, gnpr, تارة_,
  { {0x443e016d, 0xf1d0001d, 0x387f14e3, 0x00000000}},  //   int_, _mạng_, _suur_,
  { {0x443e010f, 0xdb1c0051, 0x32190007, 0x00000000}},  //   hnt_, _gcrí, nksy_,
  { {0x7e6d00f8, 0x645a012d, 0x625d0068, 0x00000000}},  //   mmap, klti, véol,
  { {0xb90702d2, 0x81d30055, 0x7e6d006c, 0x00000000}},  //   _बन_, _হোম_, lmap,
  { {0x7ac40216, 0x973c012d, 0x443e0133, 0x00000000}},  //   _исте, _odću, dnt_,
  { {0x443e028c, 0xceb4061e, 0xb05b14e4, 0x00000000}},  //   ent_, דיק_, stäh,
  { {0x2bcf02f4, 0x79c805f3, 0x443e000c, 0x00000000}},  //   स्था, _توقف_, fnt_,
  { {0x6932026c, 0x7305025f, 0x443e092e, 0x00000000}},  //   _حکمر, епоз, gnt_,
  { {0xf1d0001d, 0x65620032, 0x00000000, 0x00000000}},  //   _dạng_, _ezoh,   ,
  { {0x443e018e, 0x2bcf02fb, 0x645a0dd7, 0x00000000}},  //   ant_, स्ता, alti,
  { {0xa1550265, 0x973c0166, 0x7e6d0085, 0x00000000}},  //   върш, _veće, dmap,
  { {0xdb1c002a, 0x443e14e5, 0x6606000c, 0x00000000}},  //   _scrí, cnt_, ökkv,
  { {0xd3780107, 0x60100039, 0x6d59002b, 0x00000000}},  //   teće_, _säms, żwal,
  { {0x201814e6, 0x7e6d00e0, 0x7c3e14e7, 0x00000000}},  //   skri_, gmap, wnpr,
  { {0xfe430500, 0xc7a500a1, 0x1016007e, 0x00000000}},  // [27a0] унто, _پڑ_, _зьня,
  { {0xaf9a007c, 0x00000000, 0x00000000, 0x00000000}},  //   _этих_,   ,   ,
  { {0x3f9814e8, 0x2bc601f5, 0xe80300e8, 0x00000000}},  //   mbru_, र्गा, लाना_,
  { {0x2d96081e, 0xda650025, 0x0f370049, 0x00000000}},  //   _ярос, ناني, _טריט_,
  { {0x443e14e9, 0x3f98012d, 0x00000000, 0x00000000}},  //   ynt_, obru_,   ,
  { {0xb05b021e, 0x7d160052, 0x00000000, 0x00000000}},  //   ttäi, myys,   ,
  { {0x8c430805, 0xd6d70a78, 0x765b008e, 0x00000000}},  //   _сере, еты_, fluy,
  { {0xcfe90044, 0x7bde14ea, 0x443e14eb, 0x00000000}},  //   খায়_, lepu, wnt_,
  { {0x29020065, 0x684600ed, 0xdb1c00c4, 0x00000000}},  //   _çka_, _знаа, _ucrâ,
  { {0xe8d700b6, 0x443e00ab, 0x69c2040f, 0x00000000}},  //   _אומר_, unt_, lgoe,
  { {0xa1950147, 0x443e03a1, 0x68e2005b, 0x00000000}},  //   канч, rnt_, lwod,
  { {0x765b0211, 0x69c2002d, 0x3eb80009, 0x00000000}},  //   cluy, ngoe, drrt_,
  { {0x6e240020, 0x7bde0065, 0xf1d00082, 0x00000000}},  //   dhib, kepu, _tạng_,
  { {0xb05b021e, 0x60100039, 0x251b0049, 0x00000000}},  //   htäv, _sämr, _צוגא,
  { {0x7e6d0062, 0x2cab0052, 0x00000000, 0x00000000}},  //   tmap, _svcd_,   ,
  { {0x09d50044, 0x2ca90614, 0xddc4013f, 0x00000000}},  //   _সোনা, tsad_, rliş,
  { {0xd90401ef, 0xdb1c0036, 0x2ca900e0, 0x00000000}},  // [27b0] _ای_, _obró, usad_,
  { {0x7bde0240, 0x7e6d0c7a, 0x2bd8013d, 0x00000000}},  //   gepu, smap, ड़गा,
  { {0x2ca90039, 0xa3d20164, 0x1eab006d, 0x00000000}},  //   ssad_, ह्य_, _عادي_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x601005b4, 0x9f5a0173, 0x2604006e, 0x00000000}},  //   _kämp, _anpè_, वानी_,
  { {0xec35007b, 0x7bde000d, 0x69c20032, 0x00000000}},  //   _יאָר_, cepu, agoe,
  { {0xf4c20055, 0x765b014a, 0x99850025, 0x00000000}},  //   ্টোব, tluy, _للزو,
  { {0x60100bf4, 0x644711cc, 0x00000000, 0x00000000}},  //   _lämp, čjim,   ,
  { {0xe1ff0036, 0x00000000, 0x00000000, 0x00000000}},  //   lmów_,   ,   ,
  { {0xa93400ed, 0x6e2400ca, 0x24960014, 0x00000000}},  //   _сеуш, zhib, کنید_,
  { {0x232914ec, 0x2bc60204, 0x00000000, 0x00000000}},  //   фони_, र्टा,   ,
  { {0x65950175, 0x7aea0030, 0x7bde0036, 0x00000000}},  //   _раду, æfti, zepu,
  { {0xc2431280, 0xbcfb0010, 0x00000000, 0x00000000}},  //   рняк, _szén,   ,
  { {0x66091382, 0xd2b9009e, 0x00000000, 0x00000000}},  //   ljek, _قابض_,   ,
  { {0x60100210, 0x6e240020, 0x8fa3007e, 0x00000000}},  //   _dämp, thib, расе,
  { {0x63a305ce, 0x68e2018e, 0x7bd5010f, 0x00000000}},  //   _henn, ywod, _abzu,
  { {0x644114ed, 0x6026008b, 0x7af5010f, 0x00000000}},  // [27c0] onli, _адпа, _arzt,
  { {0x6e2414ee, 0x644114ef, 0xd3780107, 0x00000000}},  //   shib, nnli, leća_,
  { {0x81e508b7, 0xb05b021e, 0x7bde002d, 0x00000000}},  //   নার_, ttäv, repu,
  { {0x63a30f39, 0x6441010f, 0x7bde14f0, 0x00000000}},  //   _lenn, hnli, sepu,
  { {0xe3a704e1, 0x69c200b5, 0x62830058, 0x00000000}},  //   _پر_, rgoe, _luno,
  { {0x63a300db, 0x644100b5, 0xb05b0c4d, 0x00000000}},  //   _nenn, jnli, stäv,
  { {0x2900000d, 0xc5eb0055, 0x628314f1, 0x00000000}},  //   ţia_, কানা_, _nuno,
  { {0xd3780182, 0x644101b5, 0x661b011c, 0x00000000}},  //   jeća_, enli, gkuk,
  { {0x63a314f2, 0xd378037e, 0x70dc0061, 0x00000000}},  //   _benn, deća_, यबोल,
  { {0x63a30027, 0x62830058, 0xb05b14f3, 0x00000000}},  //   _cenn, _buno, ntät,
  { {0x63a305d5, 0x6283000d, 0xddc40059, 0x00000000}},  //   _denn, _cuno, zmiš,
  { {0x27ec0133, 0x644114f4, 0x00000000, 0x00000000}},  //   _hadn_, anli,   ,
  { {0xc05b01fb, 0x63a30047, 0x81e50044, 0x00000000}},  //   дів_, _fenn, নাল_,
  { {0x63a314f5, 0x4425090d, 0xe44f0123, 0x00000000}},  //   _genn, chl_, _وضو_,
  { {0x64580089, 0x80d60044, 0x6283001a, 0x00000000}},  //   _ikvi, দিষ্, _guno,
  { {0x63a80161, 0x337700b6, 0x63a314f6, 0x00000000}},  //   ladn, _בתוך_, _zenn,
  { {0x63a30283, 0xde580088, 0x61ed0058, 0x00000000}},  // [27d0] _yenn, таті_, _iaal,
  { {0x63a80a14, 0x61ed0157, 0x06d90044, 0x00000000}},  //   nadn, _haal, থিতি,
  { {0x61ed14f7, 0xfe6e02fd, 0xddc414f8, 0x00000000}},  //   _kaal, تگی_, smiš,
  { {0xc333009b, 0xf9890014, 0x61ef14f9, 0x00000000}},  //   סוף_, رنتي_, ndcl,
  { {0x61ed0b37, 0x394902d5, 0x645801ae, 0x00000000}},  //   _maal, ças_, _okvi,
  { {0xd378037e, 0x973c01a8, 0xab9401fb, 0x00000000}},  //   zeća_, _seća, _вирі,
  { {0x63a314fa, 0x973c0521, 0x644114fb, 0x00000000}},  //   _renn, _peća, vnli,
  { {0x63a3000c, 0x628300b0, 0x61ed14fc, 0x00000000}},  //   _senn, _runo, _naal,
  { {0x7e7d0173, 0x6283011c, 0x34b20025, 0x00000000}},  //   _misp, _suno, مميز,
  { {0x6283008d, 0x660914fd, 0x7bc5033b, 0x00000000}},  //   _puno, sjek, nghu,
  { {0xc5d501fb, 0x6d5d05ad, 0x63a30292, 0x00000000}},  //   _біль, _lysa, _venn,
  { {0x63a3037f, 0x7e7d14fe, 0x2604006e, 0x00000000}},  //   _wenn, _nisp, वाणी_,
  { {0x04c80025, 0x63a30e69, 0x61ed00bb, 0x00000000}},  //   _لوني_, _tenn, _daal,
  { {0xf77801d5, 0x6283011c, 0x34b20014, 0x00000000}},  //   _taħt_, _tuno, _اموز,
  { {0xb05b0002, 0x7e7d14ff, 0x61ed1500, 0x00000000}},  //   kräf, _bisp, _faal,
  { {0xc6920476, 0xfce6025f, 0x7e7d0048, 0x00000000}},  //   מאל_, лобо, _cisp,
  { {0x4d66007e, 0xdd8f01fa, 0xb05b059f, 0x00000000}},  // [27e0] укав, سول_, ttät,
  { {0x309b019b, 0x69c9000d, 0xab2a026b, 0x00000000}},  //   _רשימ, _acee, ноза_,
  { {0x68e90016, 0xb05b04ce, 0x00000000, 0x00000000}},  //   _ased, rtät,   ,
  { {0xb05b010f, 0x63a80059, 0x2906002d, 0x00000000}},  //   stät, zadn, txoa_,
  { {0x522d0049, 0x00000000, 0x00000000, 0x00000000}},  //   וואַ,   ,   ,
  { {0xcaa60025, 0xdd3b0049, 0x00000000, 0x00000000}},  //   _مصري, _װעלכ,   ,
  { {0x63a81501, 0xd5e20082, 0x3a260a60, 0x00000000}},  //   vadn, _phò, phop_,
  { {0xe4e601fb, 0xa2810036, 0x64581502, 0x00000000}},  //   гіон, łość_, _skvi,
  { {0x3946012b, 0x61ed00bb, 0x00000000, 0x00000000}},  //   _снаг, _raal,   ,
  { {0x61ed006c, 0x250700a1, 0x00000000, 0x00000000}},  //   _saal, ارٹی_,   ,
  { {0x26040309, 0x61ed011c, 0xb05b00f8, 0x00000000}},  //   वादी_, _paal, ktär,
  { {0xa2270014, 0x387e00ca, 0x64a6007e, 0x00000000}},  //   ارده, _hitr_, _бада,
  { {0x7e7d0409, 0x61ed0158, 0x41c601f5, 0x00000000}},  //   _risp, _vaal, _वारस,
  { {0x4394008b, 0xf1bf002a, 0x7e7d0263, 0x00000000}},  //   _такс, chán_, _sisp,
  { {0x61ed0168, 0x5f9401fc, 0x3e410006, 0x00000000}},  //   _taal, сист, lėti_,
  { {0x92b30445, 0x00000000, 0x00000000, 0x00000000}},  //   _احوا,   ,   ,
  { {0x7e7d001e, 0x3e410006, 0xc047025a, 0x00000000}},  // [27f0] _visp, nėti_, _مخدو,
  { {0x25a6018e, 0x7e7d0ace, 0x6d5d01ca, 0x00000000}},  //   _leol_, _wisp, _vysa,
  { {0x7bc507a9, 0xb05b09f0, 0x78bc0089, 0x00000000}},  //   rghu, träf, _ārva,
  { {0x3e410006, 0x636f0010, 0x2bc70164, 0x00000000}},  //   kėti_, lóné, _लावा,
  { {0x05260044, 0x00000000, 0x00000000, 0x00000000}},  //   মপুর_,   ,   ,
  { {0x3e41010a, 0x25a90059, 0x973c016c, 0x00000000}},  //   dėti_, _žal_, _većn,
  { {0x3dd90022, 0x00000000, 0x00000000, 0x00000000}},  //   _kbsw_,   ,   ,
  { {0x25a6002a, 0x38c900a1, 0x24861503, 0x00000000}},  //   _ceol_, _لائی_, _buom_,
  { {0x68e91504, 0xf1bf0051, 0x387e0da4, 0x00000000}},  //   _used, thán_, _fitr_,
  { {0x2249003f, 0x24860145, 0x00000000, 0x00000000}},  //   _ajak_, _duom_,   ,
  { {0x63bc000c, 0x31690010, 0xe7840014, 0x00000000}},  //   órna, _azaz_, _المپ,
  { {0xd57509b5, 0xe3b100a6, 0xa4d50088, 0x00000000}},  //   _куль, حرک_, _воді,
  { {0x2249012d, 0x00000000, 0x00000000, 0x00000000}},  //   _djak_,   ,   ,
  { {0xa06a008b, 0xfaf80089, 0xe3b90131, 0x00000000}},  //   тага_, _šīm_, _рбк_,
  { {0x43750049, 0xb05b00b0, 0x6e36004d, 0x00000000}},  //   _דײַן_, ttär, ахах,
  { {0x644f00f4, 0x22490065, 0x9ac70066, 0x00000000}},  //   écif, _gjak_, _miċħ,

  { {0xc0e6026b, 0x6fd60088, 0xb05b04ce, 0x00000000}},  // [2800] _топк, _кінц, rtär,
  { {0xb05b09b0, 0xd00f0025, 0x00000000, 0x00000000}},  //   stär, _يلي_,   ,
  { {0x394d06fa, 0x395f0058, 0x79a600e2, 0x00000000}},  //   _axes_, _ayus_, арле,
  { {0xb05b001f, 0x2a6d00b9, 0x2efa1505, 0x00000000}},  //   träg, _cheb_, _irpf_,
  { {0x2604006e, 0x25a61506, 0xda650379, 0x00000000}},  //   वासी_, _reol_, حالي,
  { {0x25a6002a, 0x6843007c, 0x6352013e, 0x00000000}},  //   _seol_, онча, něné,
  { {0x6f1c0016, 0x973c04eb, 0x03ee0044, 0x00000000}},  //   nyrc, _većo, জামী_,
  { {0xb05b0788, 0x6b630088, 0x00000000, 0x00000000}},  //   präg, _єкта,   ,
  { {0x87da02fd, 0x6f1c0016, 0x746a0140, 0x00000000}},  //   _لباس_, hyrc, кров_,
  { {0xbcfb0010, 0x3e410006, 0x2604007d, 0x00000000}},  //   _szék, rėti_, वाही_,
  { {0x23380147, 0xb6cb00a1, 0x20131507, 0x00000000}},  //   упны_, _لانے_, _roxi_,
  { {0xd377008b, 0xd2580088, 0x00000000, 0x00000000}},  //   шчы_, иця_,   ,
  { {0x04940379, 0x625d009d, 0x00000000, 0x00000000}},  //   _التح, déot,   ,
  { {0x04db01ce, 0x26040061, 0x251b0097, 0x00000000}},  //   _סקול, वावी_, _בודא,
  { {0x6f1c018e, 0xbe880407, 0x660205d5, 0x00000000}},  //   gyrc, исте_, _knok,
  { {0x30a71508, 0xdd980aed, 0xe37b00b3, 0x00000000}},  //   _кров, ишу_, _ברור,
  { {0x629a0a0e, 0xb05b0039, 0x786d00c4, 0x00000000}},  // [2810] lpto, träd, lúve,
  { {0x2bb80025, 0x00000000, 0x00000000, 0x00000000}},  //   لامة_,   ,   ,
  { {0x5fdc0097, 0xb05b053d, 0x66020087, 0x00000000}},  //   _יחזק, rräd, _onok,
  { {0x4975034b, 0x9f430023, 0x00000000, 0x00000000}},  //   блес, hejë_,   ,
  { {0x8cf4008b, 0x26de0285, 0xe8030204, 0x00000000}},  //   _дзяц, _apto_, लाला_,
  { {0x1d16009b, 0x660204a5, 0x3dc900e0, 0x00000000}},  //   _הקשר_, _anok, lgaw_,
  { {0x6dbb00b4, 0x00000000, 0x00000000, 0x00000000}},  //   ałał,   ,   ,
  { {0xb8cd0055, 0x3dc9011c, 0x26de008e, 0x00000000}},  //   _কম_, ngaw_, _dpto_,
  { {0xe45900e3, 0x81d60044, 0x629a0168, 0x00000000}},  //   лжи_, _সফল_, epto,
  { {0x9b44009c, 0x9814007a, 0x68fb022b, 0x00000000}},  //   _انہو, _وبلا, _irud,
  { {0xe71904e8, 0x00000000, 0x00000000, 0x00000000}},  //   _حيات_,   ,   ,
  { {0x68fb0d44, 0x66020026, 0x00000000, 0x00000000}},  //   _krud, _gnok,   ,
  { {0x26040201, 0x291d1509, 0x8505007a, 0x00000000}},  //   वारी_, nywa_, _دوشن,
  { {0x3cfe00b9, 0x33950025, 0xe3b8014a, 0x00000000}},  //   _čtv_, _الغز, lkın_,
  { {0xfbcd0044, 0x442700ea, 0xd7f10082, 0x00000000}},  //   রজাত, _iln_, _mã_,
  { {0x0d86012b, 0x25ad01d6, 0x68fb016c, 0x00000000}},  //   слан, nael_, _orud,
  { {0x61e6150a, 0x44270022, 0x00000000, 0x00000000}},  // [2820] mekl, _kln_,   ,
  { {0x69db0211, 0x442704be, 0x61e6014a, 0x00000000}},  //   _abue, _jln_, lekl,
  { {0x6d4f06c2, 0x442709a8, 0xfc3f04bd, 0x00000000}},  //   _exca, _mln_, _avís_,
  { {0x80cb0055, 0x61e6011f, 0xb3460181, 0x00000000}},  //   িবর্, nekl, leçõ,
  { {0xddcd0477, 0x25ad0016, 0x7e64150b, 0x00000000}},  //   llaş, dael_, mlip,
  { {0x61e6129a, 0x6602150c, 0x00000000, 0x00000000}},  //   hekl, _snok,   ,
  { {0xddcd027d, 0x25ad00d6, 0x61e6014a, 0x00000000}},  //   nlaş, fael_, kekl,
  { {0x44270026, 0x7e64011c, 0x7c3e010e, 0x00000000}},  //   _aln_, nlip, lipr,
  { {0x68fb150d, 0xa9260057, 0x61e60010, 0x00000000}},  //   _grud, _удал, dekl,
  { {0xddcd011f, 0x7c3e00ea, 0xe82400a1, 0x00000000}},  //   klaş, nipr, _بذری,
  { {0x5c5b007b, 0x2bf7009b, 0x63a4012d, 0x00000000}},  //   רדיק, זמין_, _đind,
  { {0xad9b02d5, 0xcb13009b, 0xc0cb003b, 0x00000000}},  //   _anún, ללת_, луге_,
  { {0x661d0c4d, 0x7bdc0738, 0xdb070023, 0x00000000}},  //   öske, _obru, _pejë,
  { {0x133900a1, 0x4427016b, 0x629a150e, 0x00000000}},  //   اتیں_, _gln_, ppto,
  { {0x443e150f, 0x543b007b, 0x645a1510, 0x00000000}},  //   mit_, _געגא, moti,
  { {0x443e006a, 0x645a0089, 0x7bdc0207, 0x00000000}},  //   lit_, loti, _abru,
  { {0x973c0521, 0x68e4006b, 0x9c3900e2, 0x00000000}},  // [2830] _bećk, çidl, апат_,
  { {0x443e1511, 0x645a0089, 0x628a1512, 0x00000000}},  //   nit_, noti, _kufo,
  { {0x6448022b, 0x207c0049, 0x7bce0022, 0x00000000}},  //   indi, _גאזא, _dcbu,
  { {0x443e0b9a, 0x1df90057, 0x7e64094e, 0x00000000}},  //   hit_, _темы_, clip,
  { {0x443e0d56, 0x00000000, 0x00000000, 0x00000000}},  //   kit_,   ,   ,
  { {0x629804a3, 0x443e1513, 0x7c3e0375, 0x00000000}},  //   _otvo, jit_, cipr,
  { {0x645a0ba5, 0xa3be006e, 0x628a007f, 0x00000000}},  //   doti, ेलन_, _nufo,
  { {0x68fb1514, 0x6e2d1515, 0xe61901f9, 0x00000000}},  //   _trud, nhab, рди_,
  { {0x44271516, 0x644806d6, 0xddcd0180, 0x00000000}},  //   _pln_, fndi, zlaş,
  { {0x443e006a, 0xddcd011f, 0x63aa018e, 0x00000000}},  //   git_, ylaş, _cefn,
  { {0x63aa018e, 0x27e71517, 0xdb1c0051, 0x00000000}},  //   _defn, menn_, _scrú,
  { {0x443e1518, 0x64480020, 0x69cb020c, 0x00000000}},  //   ait_, andi, ngge,
  { {0xe3ae0373, 0x61e6011f, 0x6e2d1519, 0x00000000}},  //   _об_, rekl, dhab,
  { {0x443e151a, 0x645a0089, 0x442c0061, 0x00000000}},  //   cit_, coti, chd_,
  { {0x26c70709, 0x61e6014a, 0xa3d2013d, 0x00000000}},  //   nuno_, pekl, _हॉट_,
  { {0xddcd0180, 0x22b50089, 0xa3d70061, 0x00000000}},  //   rlaş, māk_, ाभव_,
  { {0x81d30055, 0xd7c90316, 0x22b5001e, 0x00000000}},  // [2840] _হোক_, _रांच, lāk_,
  { {0xebe30081, 0xddcd0180, 0x69d900d9, 0x00000000}},  //   моуп, plaş, efwe,
  { {0x22b50089, 0xd24f0167, 0x27e70173, 0x00000000}},  //   nāk_, _سنی_, denn_,
  { {0x443e151b, 0xe8fa151c, 0x6e2d008e, 0x00000000}},  //   zit_, иле_, chab,
  { {0x3ead037e, 0x6448009f, 0x443e0148, 0x00000000}},  //   ćete_, yndi, yit_,
  { {0x443e0f51, 0x7bdc0190, 0x645a151d, 0x00000000}},  //   xit_, _ubru, xoti,
  { {0xdcf6038c, 0x645a0119, 0x26c70211, 0x00000000}},  //   mayı, voti, guno_,
  { {0xdcf6038c, 0x765b01aa, 0x628a00fa, 0x00000000}},  //   layı, gouy, _rufo,
  { {0x443e151e, 0x645a0089, 0x62980119, 0x00000000}},  //   tit_, toti, _stvo,
  { {0x186a0265, 0x64481153, 0x47c301e0, 0x00000000}},  //   _тази_, undi, _обув,
  { {0x443e071e, 0x1bfb0049, 0x2bcf006e, 0x00000000}},  //   rit_, בליב, स्टा,
  { {0x95c7003b, 0x443e151f, 0x645a0089, 0x00000000}},  //   _душа_, sit_, soti,
  { {0x443e006a, 0xda7b00b6, 0x645a016e, 0x00000000}},  //   pit_, ינטר, poti,
  { {0xddcd1520, 0x7640010a, 0x22b5001e, 0x00000000}},  //   dmaš, limy, bāk_,
  { {0x69cb0693, 0x6e2d0051, 0x539b00b3, 0x00000000}},  //   ygge, thab, _דיוו,
  { {0xd3780166, 0x2bdd0309, 0x6e2400e0, 0x00000000}},  //   jeći_, न्ना, gkib,
  { {0xd3780119, 0x6e2d014a, 0xacf80451, 0x00000000}},  // [2850] deći_, rhab, онту_,
  { {0x6e2d0020, 0x26c71521, 0xad9b0181, 0x00000000}},  //   shab, yuno_, _inúm,
  { {0x76401522, 0x6e2d028a, 0x00000000, 0x00000000}},  //   kimy, phab,   ,
  { {0x26c700e7, 0x27e7000a, 0x00000000, 0x00000000}},  //   vuno_, wenn_,   ,
  { {0x22b50089, 0x22a70010, 0x443c064f, 0x00000000}},  //   zāk_, zők_, _omv_,
  { {0xf8071523, 0x26c70016, 0x443c0087, 0x00000000}},  //   ючен, tuno_, _nmv_,
  { {0xd3780107, 0x27e701aa, 0x2a6600e0, 0x00000000}},  //   beći_, renn_, blob_,
  { {0x06090072, 0x22b50089, 0x22a70010, 0x00000000}},  //   сник_, vāk_, vők_,
  { {0xe4d60025, 0x27e71524, 0x26c700e0, 0x00000000}},  //   كويت_, penn_, suno_,
  { {0x87070025, 0x26c71525, 0x22a70010, 0x00000000}},  //   _وبال, puno_, tők_,
  { {0x2bdd0201, 0x443c00bb, 0x625d009d, 0x00000000}},  //   न्या, _dmv_, téop,
  { {0x22b5001e, 0x26f903d7, 0x2c6d0428, 0x00000000}},  //   rāk_, ्मीर_, _vždy_,
  { {0x973c012d, 0x22b50089, 0x22a70010, 0x00000000}},  //   _reći, sāk_, sők_,
  { {0xb4fa009b, 0x16090061, 0xd3780091, 0x00000000}},  //   _לפני, वावर_, zeći_,
  { {0x64410475, 0x0e6a0025, 0x973c04eb, 0x00000000}},  //   mili, مصري_, _peći,
  { {0xe1ff1526, 0x64410504, 0xa2c0006e, 0x00000000}},  //   llón_, lili, _वित्,
  { {0x973c0119, 0x6e241527, 0x2bc70061, 0x00000000}},  // [2860] _veći, rkib, _लाखा,
  { {0x61f60284, 0x66190093, 0x6e241528, 0x00000000}},  //   _hayl, _lowk, skib,
  { {0x61f61163, 0xd3780363, 0xdcf6005d, 0x00000000}},  //   _kayl, teći_, rayı,
  { {0x6441011c, 0x201a1529, 0x98a0152a, 0x00000000}},  //   hili, _hopi_, šič_,
  { {0x6441000b, 0x61f607b1, 0xd3780091, 0x00000000}},  //   kili, _mayl, reći_,
  { {0x61f607b1, 0x64410020, 0xb05b010f, 0x00000000}},  //   _layl, jili, hrän,
  { {0x6441000b, 0x7640000a, 0xe9a60088, 0x00000000}},  //   dili, timy, _навп,
  { {0xa3d9006e, 0x443c0c48, 0xf77200a1, 0x00000000}},  //   ड्स_, _smv_, واں_,
  { {0x6441152b, 0xb05b053d, 0x682f0190, 0x00000000}},  //   fili, drän, _bødd,
  { {0xa2c002f4, 0x644108a1, 0x3a2601d6, 0x00000000}},  //   _विद्, gili, lkop_,
  { {0x46a3003b, 0x644f028c, 0xe7b3025a, 0x00000000}},  //   _захв, écia, _سمند,
  { {0xb05b152c, 0x7ae1010f, 0x3a26018f, 0x00000000}},  //   grän, _älte, nkop_,
  { {0x6441152d, 0x216709b5, 0x682f01e3, 0x00000000}},  //   bili, ятог, _fødd,
  { {0x201a0016, 0x6e3d0066, 0xe1ff004a, 0x00000000}},  //   _copi_, _smsb, clón_,
  { {0x629c004f, 0xf1c60204, 0x33db009b, 0x00000000}},  //   írod, _वाचन, _החוד,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbcfb0047, 0xc1bc009b, 0x91bc009b, 0x00000000}},  // [2870] _azér, _המחש, _המחי,
  { {0x201a005b, 0x682f0190, 0x32090082, 0x00000000}},  //   _gopi_, _køde, _hnay_,
  { {0x998900b9, 0x682f043e, 0x61f6005a, 0x00000000}},  //   íkům_, _jøde, _yayl,
  { {0x682f0030, 0x3a26011c, 0x78a9000a, 0x00000000}},  //   _møde, gkop_, _pwev,
  { {0xa3be024c, 0xbcfb0047, 0xf8ae00a1, 0x00000000}},  //   ेला_, _ezér, لکل_,
  { {0x64410ddd, 0xd3780521, 0x00000000, 0x00000000}},  //   xili, leću_,   ,
  { {0x3209014a, 0x682f0190, 0x2d9f010e, 0x00000000}},  //   _onay_, _rødd, _õues_,
  { {0x6441018e, 0xc7440054, 0xdb0700b9, 0x00000000}},  //   wili, عضوي, _její,
  { {0x64410b1a, 0x280800b9, 0xdb0702a0, 0x00000000}},  //   tili, átní_, _mejí,
  { {0xe7b500d3, 0x61f6006b, 0x32090058, 0x00000000}},  //   _آماد, _sayl, _anay_,
  { {0x6441005f, 0x61f60676, 0x1b1f0055, 0x00000000}},  //   rili, _payl, _যেতে_,
  { {0x6441152e, 0xdb0e0181, 0xd3780243, 0x00000000}},  //   sili, _bebê, jeću_,
  { {0x6441006a, 0x22420292, 0xb05b0c4d, 0x00000000}},  //   pili, rikk_, rrän,
  { {0x682f05b7, 0xdee6007c, 0x22420056, 0x00000000}},  //   _føde, моги, sikk_,
  { {0x61f605ac, 0x25af0087, 0x682f0146, 0x00000000}},  //   _tayl, _kegl_, _gøde,
  { {0x7bc3000c, 0x61f6013f, 0x00000000, 0x00000000}},  //   ónun, _uayl,   ,
  { {0x201a11a7, 0x2ca0152f, 0xdb0e01d6, 0x00000000}},  // [2880] _topi_, upid_, _gebê,
  { {0x2ca00009, 0x25dd0204, 0x3a2d0068, 0x00000000}},  //   rpid_, क्ती_, _alep_,
  { {0x63bc1530, 0x248701aa, 0xa2a10061, 0x00000000}},  //   órni, _minm_, कीच्,
  { {0xa2c002fb, 0xfaf8001e, 0xc7b8012d, 0x00000000}},  //   _विस्, _šīs_, _mođe_,
  { {0x3a26123c, 0xd83a007e, 0x08970025, 0x00000000}},  //   rkop_, жэй_, وضوع_,
  { {0x3a260235, 0x68ed00c4, 0x0ee2006e, 0x00000000}},  //   skop_, çada, _पहाड,
  { {0x3a26067c, 0x7c2e0026, 0x66e30545, 0x00000000}},  //   pkop_, _ilbr, воја,
  { {0x26c012f8, 0x2487002a, 0x44f40216, 0x00000000}},  //   čio_, _ainm_, епис,
  { {0x25af0026, 0x682f0190, 0x00000000, 0x00000000}},  //   _degl_, _søde,   ,
  { {0x83fc0182, 0x22400f37, 0x00000000, 0x00000000}},  //   kođe, _amik_,   ,
  { {0xd6cf004b, 0x97260014, 0x78a201ed, 0x00000000}},  //   _نقل_, _تفاو, lpov,
  { {0xc7b80091, 0x64a6007e, 0x7afa000c, 0x00000000}},  //   _dođe_, _жада, _áttu,
  { {0xe8030061, 0x7c2e00b4, 0x00000000, 0x00000000}},  //   लाचा_, _olbr,   ,
  { {0x656f010f, 0x9f43013e, 0x00000000, 0x00000000}},  //   üche, sejí_,   ,
  { {0x83fc0166, 0x442e0288, 0x00000000, 0x00000000}},  //   gođe, _ilf_,   ,
  { {0x41e70822, 0x7c2e01a2, 0xddc40036, 0x00000000}},  //   _ціка, _albr, enił,
  { {0x5c750057, 0x7bde010f, 0x101800a1, 0x00000000}},  // [2890] елат, ffpu, سکیں_,
  { {0x78a206b8, 0x3a2d1531, 0x83fc0091, 0x00000000}},  //   dpov, _slep_, bođe,
  { {0xb5fd003b, 0x00000000, 0x00000000, 0x00000000}},  //   loše,   ,   ,
  { {0xd37b0049, 0xdb1c004a, 0x2cc4019a, 0x00000000}},  //   קראט, _acró, ürdü_,
  { {0x5d8501d8, 0xb5fd0340, 0x682f068f, 0x00000000}},  //   _سلسل, noše, _rødb,
  { {0x46f50088, 0xec350049, 0x2c05013d, 0x00000000}},  //   ечит, _טאָר_, राओं_,
  { {0xa2c00309, 0x661d0c43, 0x00000000, 0x00000000}},  //   _विष्, ösko,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb1c01aa, 0x260401f5, 0xb5fd0645, 0x00000000}},  //   _adrè, वाजी_, joše,
  { {0xa2c002fb, 0xb5fd050f, 0x7af50036, 0x00000000}},  //   _विश्, doše, _kszt,
  { {0x442e0190, 0x31690276, 0xe5e1007e, 0x00000000}},  //   _dlf_, _ayaz_, _былi_,
  { {0x349503f3, 0x83fc0091, 0xdb0e000a, 0x00000000}},  //   _задр, vođe, _debè,
  { {0x6594012b, 0xb5fd0b18, 0x660b1532, 0x00000000}},  //   _рачу, goše, _ingk,
  { {0x26c70207, 0x7af50047, 0x95cc006b, 0x00000000}},  //   orno_, _oszt, _çərç,
  { {0xbcfb0047, 0x26040061, 0xdee30256, 0x00000000}},  //   _szép, वाची_, лори,
  { {0x9f580919, 0x433a009b, 0x83fc0166, 0x00000000}},  //   ndré_, _מעצב, rođe,
  { {0x61e41533, 0x7af50010, 0x93f30061, 0x00000000}},  // [28a0] _ibil, _aszt, _असाच_,
  { {0x4d631534, 0x3ec5005a, 0xa7fc014a, 0x00000000}},  //   укув, üstü_, _akın,
  { {0x4fd7007b, 0x7fd7007b, 0x660b10ed, 0x00000000}},  //   _אויב_, _אויס_, _ongk,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61e4000b, 0x67d401fc, 0x7af50010, 0x00000000}},  //   _mbil, волу, _eszt,
  { {0x660b1535, 0x25dd006e, 0xfaf100a1, 0x00000000}},  //   _angk, क्सी_, دثے_,
  { {0x61e40091, 0x78a2057c, 0xad9b000c, 0x00000000}},  //   _obil, spov, _snúi,
  { {0x660b0085, 0xdb0e0173, 0x00000000, 0x00000000}},  //   _cngk, _rebè,   ,
  { {0x54541536, 0x69c000f6, 0x442e0203, 0x00000000}},  //   квит, _idme, _plf_,
  { {0xccf300b6, 0x61e41537, 0x290403ba, 0x00000000}},  //   רכז_, _abil, _irma_,
  { {0xdb0e0b76, 0x61e401f3, 0x7e660022, 0x00000000}},  //   _bebé, _bbil, _okkp,
  { {0x5ab700bd, 0x7e6600e0, 0x00000000, 0x00000000}},  //   עלכע_, _nkkp,   ,
  { {0x442e0018, 0xdb0e004a, 0xd83f00ca, 0x00000000}},  //   _tlf_, _debé, _ščit_,
  { {0xb5fd0627, 0x442e02e1, 0xdb070010, 0x00000000}},  //   roše, _ulf_, _lejá,
  { {0xc0ab00a6, 0x69c00465, 0x2baf006e, 0x00000000}},  //   _کابل_, _odme, टरसा,
  { {0xb5fd016c, 0x29041538, 0x27ee0016, 0x00000000}},  //   poše, _orma_, hefn_,
  { {0xf1bf1539, 0x61ef153a, 0x8bc7153b, 0x00000000}},  // [28b0] nkám_, mecl, есед,
  { {0x69c0153c, 0x61e4016e, 0x61fd0056, 0x00000000}},  //   _adme, _zbil, ldsl,
  { {0x7e660022, 0xdb070010, 0x00000000, 0x00000000}},  //   _fkkp, _bejá,   ,
  { {0x61fd06a1, 0x68ed153d, 0x61ef153e, 0x00000000}},  //   ndsl, çado, necl,
  { {0xd366007a, 0x7e6d153f, 0x60dd1540, 0x00000000}},  //   _چه_, mlap, ntsm,
  { {0x7e6d0010, 0xd3660014, 0x69c000e0, 0x00000000}},  //   llap, _نه_, _edme,
  { {0x8f9c0049, 0x29040145, 0xcc54005e, 0x00000000}},  //   ליגי, _erma_, _свръ,
  { {0x7e6d0010, 0x24990285, 0x61fd0030, 0x00000000}},  //   nlap, ísmo_, jdsl,
  { {0xe895008b, 0x61ef1541, 0x9f4a0129, 0x00000000}},  //   _разь, decl, rebé_,
  { {0x7e6d00b0, 0x61e40197, 0x00000000, 0x00000000}},  //   hlap, _sbil,   ,
  { {0x3f8c016c, 0xe6c70379, 0x26dc0f6c, 0x00000000}},  //   žduk_, _ستاي, ctvo_,
  { {0x660b0169, 0x60dd01a2, 0xa6960097, 0x00000000}},  //   _ungk, ftsm, _סכנה_,
  { {0x463a007b, 0x7e6d0089, 0x60dd0030, 0x00000000}},  //   _קענע, dlap, gtsm,
  { {0x6a7810af, 0x25dd007d, 0x701901e1, 0x00000000}},  //   mífe, क्री_, ніст_,
  { {0x61e4006b, 0x998f0006, 0x6a781542, 0x00000000}},  //   _tbil, nigų_, lífe,
  { {0x61e40825, 0xc6920049, 0xa7fc014a, 0x00000000}},  //   _ubil, שאן_, _akıl,
  { {0x6a78052a, 0x3e5a013e, 0x60dd0045, 0x00000000}},  // [28c0] nífe, jďte_, ctsm,
  { {0xe0b7061e, 0x9f5a0065, 0xfce3142c, 0x00000000}},  //   _שליט_, _japë_, рофо,
  { {0x68e906c0, 0xe9da007c, 0x3daa007c, 0x00000000}},  //   _aped, дке_, _окно_,
  { {0x98a60081, 0x831a0049, 0x60c9016c, 0x00000000}},  //   виде, וועז, šeme,
  { {0x64430006, 0x00000000, 0x00000000, 0x00000000}},  //   _omni,   ,   ,
  { {0x6b9c00c4, 0x26ce004a, 0x00000000, 0x00000000}},  //   _ufrg, tufo_,   ,
  { {0x8c43025f, 0xddcd001a, 0x69c00009, 0x00000000}},  //   _тере, noaş, _tdme,
  { {0x35f40331, 0xceb300b3, 0x69c008c8, 0x00000000}},  //   упир, ביה_, _udme,
  { {0x26dc016c, 0x2904000d, 0xd9100123, 0x00000000}},  //   stvo_, _urma_, _دیش_,
  { {0xa84a025a, 0x26dc012d, 0x00000000, 0x00000000}},  //   _غلام_, ptvo_,   ,
  { {0x1db20164, 0x0bb700b3, 0x64430009, 0x00000000}},  //   जरात, כלים_, _dmni,
  { {0x27e9037e, 0x60dd02e1, 0x6443014a, 0x00000000}},  //   đane_, ttsm, _emni,
  { {0x61fd1543, 0x041e0044, 0x61ef0585, 0x00000000}},  //   rdsl, যোগী_, recl,
  { {0xdb05000c, 0x61ef009d, 0xa4b7009b, 0x00000000}},  //   rahú, secl, _ילדה_,
  { {0xb5fd01c5, 0x7e6d0010, 0xf1bf0010, 0x00000000}},  //   loša, tlap, nkák_,
  { {0x64480996, 0x2d8f0030, 0x64430036, 0x00000000}},  //   lidi, øge_, _zmni,
  { {0xb5fd001e, 0x3d0d013d, 0x9f5a01aa, 0x00000000}},  // [28d0] noša, समें_, _lapè_,
  { {0x7e6d010a, 0xd0f8012f, 0x64481544, 0x00000000}},  //   slap, _יצחק_, nidi,
  { {0x68e90198, 0xe0df0197, 0x7e6d1545, 0x00000000}},  //   _sped, ltò_, plap,
  { {0xe1ff0010, 0x64480b1f, 0x628d0066, 0x00000000}},  //   ndó_, hidi, _jiao,
  { {0x6e2d0020, 0xe0df0e5d, 0x89a80088, 0x00000000}},  //   mkab, ntò_, тків_,
  { {0xb5fd001e, 0x628d01f3, 0x644809d8, 0x00000000}},  //   doša, _liao, jidi,
  { {0x36690057, 0x64480006, 0x81cb0044, 0x00000000}},  //   нако_, didi, র্য_,
  { {0x83fc0091, 0xc7b804eb, 0x6a7803d1, 0x00000000}},  //   vođa, _vođa_, tífe,
  { {0x64480b1f, 0x9f4300b0, 0x5a44007e, 0x00000000}},  //   fidi, lejä_, _тэра,
  { {0x6448014a, 0x81cb0044, 0x683400f6, 0x00000000}},  //   gidi, র্ম_, _pàde,
  { {0x6e2d014a, 0x05130044, 0x8458005e, 0x00000000}},  //   kkab, িনের_, ърът_,
  { {0x83fc0107, 0x823604e8, 0x628d0197, 0x00000000}},  //   rođa, اردا, _ciao,
  { {0x64480b62, 0x628d1546, 0x7d0904eb, 0x00000000}},  //   bidi, _diao, _šesn,
  { {0x64480919, 0xddc400b9, 0x64431547, 0x00000000}},  //   cidi, dliš, _umni,
  { {0x3ebe009f, 0x75290047, 0x00000000, 0x00000000}},  //   étt_, lyez,   ,
  { {0x81cb0055, 0x661b020c, 0x6e2d011c, 0x00000000}},  //   র্ব_, njuk, gkab,
  { {0x75291483, 0xdcff006b, 0xddc4007f, 0x00000000}},  // [28e0] nyez, faqı, gliš,
  { {0xbc6a023c, 0x661b0934, 0x00000000, 0x00000000}},  //   رمان_, hjuk,   ,
  { {0x49ca1548, 0x9f8b010e, 0x00000000, 0x00000000}},  //   елен_, _söök_,   ,
  { {0x6e2d003b, 0x64480142, 0xddc40087, 0x00000000}},  //   ckab, zidi, bliš,
  { {0x28f80e09, 0x627c0036, 0xad9b0027, 0x00000000}},  //   тель_, _głoś, _vnút,
  { {0x64480096, 0xb5fd0089, 0x00000000, 0x00000000}},  //   xidi, voša,   ,
  { {0x7d04044e, 0x644809dd, 0xfaa300ec, 0x00000000}},  //   lvis, vidi, _гасо,
  { {0xb5fd001e, 0xceb3009b, 0x6448018e, 0x00000000}},  //   toša, זיה_, widi,
  { {0x81cb0055, 0x644811c6, 0x7d0405fe, 0x00000000}},  //   র্ড_, tidi, nvis,
  { {0xb5fd0089, 0x5c370049, 0x2a66011c, 0x00000000}},  //   roša, ָרטן_, loob_,
  { {0xd7930054, 0x442c1549, 0xddc401ca, 0x00000000}},  //   _المخ, rkd_, zliš,
  { {0x3ce004d3, 0x6448005d, 0x667600a1, 0x00000000}},  //   ktiv_, sidi, _صدار,
  { {0x7d04154a, 0xe1ff154b, 0xc5f300b6, 0x00000000}},  //   jvis, rdó_, _לדף_,
  { {0x7d0400b5, 0xe0df0197, 0x9f530066, 0x00000000}},  //   dvis, rtò_, _paxà_,
  { {0xd904026c, 0xf8d1006e, 0x63ba154c, 0x00000000}},  //   _کی_, _सम्प, matn,
  { {0x63ba154d, 0x7d040146, 0x00000000, 0x00000000}},  //   latn, fvis,   ,
  { {0xdb0e008e, 0x2fda0009, 0x5bcb003b, 0x00000000}},  // [28f0] _debí, _fcpg_, ећег_,
  { {0xad9b0917, 0x224b154e, 0x6e2d0030, 0x00000000}},  //   _saúd, lick_, skab,
  { {0x09bc0055, 0x1a6500a1, 0x81cb0044, 0x00000000}},  //   _ইউজা, لیسی_, র্ণ_,
  { {0x224b154f, 0xdb070039, 0x63ba1550, 0x00000000}},  //   nick_, _rejä, hatn,
  { {0x212b1551, 0x63ba033b, 0x3ce0001a, 0x00000000}},  //   nych_, katn, ctiv_,
  { {0x63ba0119, 0x2ca900f8, 0x224b01a2, 0x00000000}},  //   jatn, mpad_, hick_,
  { {0x63ba01d9, 0x224b098e, 0x75d50014, 0x00000000}},  //   datn, kick_, ليغا,
  { {0x06090057, 0x81cb0044, 0xf625034b, 0x00000000}},  //   тник_, র্ত_, рдио,
  { {0x680b001e, 0x63ba04be, 0x2ca90168, 0x00000000}},  //   _pēdē, fatn, npad_,
  { {0x212b1552, 0x1309007c, 0x63ba0010, 0x00000000}},  //   dych_, вной_, gatn,
  { {0x35f5041f, 0xb05b01a2, 0x9f5a0068, 0x00000000}},  //   _впер, nräu, _tapé_,
  { {0x224b0039, 0x7d0400b0, 0x2ca9046a, 0x00000000}},  //   gick_, yvis, kpad_,
  { {0xae000061, 0x63ba04cb, 0x25ad1553, 0x00000000}},  //   _लोगन_, batn, mbel_,
  { {0x7d040a19, 0x645d00f4, 0x98a00166, 0x00000000}},  //   vvis, ésid, šić_,
  { {0xc447026c, 0xdfcf0025, 0x81c00044, 0x00000000}},  //   _لیکن_, ظيف_, ুভব_,
  { {0x7d040089, 0x3ce001d5, 0x3126005e, 0x00000000}},  //   tvis, ttiv_, _вдиг,
  { {0x212b0046, 0x1c46008b, 0x00000000, 0x00000000}},  // [2900] cych_, анам,   ,
  { {0x69db0211, 0x629e029d, 0x3ce01554, 0x00000000}},  //   _acue, _époc, rtiv_,
  { {0x3ce01140, 0x2ca90f02, 0x68fb12b6, 0x00000000}},  //   stiv_, apad_, _asud,
  { {0x7d040010, 0x25ad00b5, 0x63ba1555, 0x00000000}},  //   pvis, jbel_, zatn,
  { {0xb5fd1556, 0x7d0400f8, 0x9f580129, 0x00000000}},  //   tošn, qvis, ldrà_,
  { {0x25ad021f, 0xd90d0167, 0x69db004a, 0x00000000}},  //   ebel_, عیل_, _ecue,
  { {0x63ba01cd, 0x212b0046, 0x9f580129, 0x00000000}},  //   vatn, zych_, ndrà_,
  { {0x27e9037e, 0x2c0a001c, 0xb05b0a2f, 0x00000000}},  //   đana_, _होतं_, lrät,
  { {0x63ba0387, 0x15e20164, 0x98a30478, 0x00000000}},  //   tatn, क्षर_, _мите,
  { {0x3cf9013d, 0xb05b0210, 0x224b0133, 0x00000000}},  //   _उनसे_, nrät, wick_,
  { {0x212b0046, 0x3a240091, 0x2ca900ca, 0x00000000}},  //   wych_, _komp_, zpad_,
  { {0x212b0832, 0xdb15000a, 0xbddb000a, 0x00000000}},  //   tych_, _dezè, _emèj,
  { {0x224b01d5, 0x63ba0169, 0x9258005e, 0x00000000}},  //   rick_, patn, раят_,
  { {0x212b1557, 0x104b004c, 0x3a240168, 0x00000000}},  //   rych_, тями_, _lomp_,
  { {0xe29701f9, 0xc05801fb, 0x645d0f57, 0x00000000}},  //   _кај_, рія_, ésie,
  { {0x2ca901d6, 0x00000000, 0x00000000, 0x00000000}},  //   tpad_,   ,   ,
  { {0xdb05002a, 0xb5fd0465, 0x22490022, 0x00000000}},  // [2910] rbhí, došl, _imak_,
  { {0x2ca91558, 0x63b81559, 0xdd110066, 0x00000000}},  //   rpad_, _jevn, _iżże,
  { {0x2ca90107, 0xdb150010, 0xb9950025, 0x00000000}},  //   spad_, _kezé, ملاب,
  { {0x63b800b9, 0x2ca900f8, 0x00000000, 0x00000000}},  //   _levn, ppad_,   ,
  { {0xa3b60164, 0xe1ff155a, 0x20010058, 0x00000000}},  //   जरा_, llós_, _kahi_,
  { {0x81dd0055, 0x9f58008e, 0x20030022, 0x00000000}},  //   ড়ি_, ldrá_, ndji_,
  { {0x26c10428, 0xad9b0181, 0x62980207, 0x00000000}},  //   ého_, _gaúc, _nuvo,
  { {0xa2c002d2, 0xcf5801f8, 0x9f580211, 0x00000000}},  //   _विज्, יבות_, ndrá_,
  { {0x81dd0055, 0x68fb1434, 0x25ad155b, 0x00000000}},  //   ড়া_, _usud, rbel_,
  { {0xc6e701fb, 0x2001022b, 0x395f155c, 0x00000000}},  //   _відп, _nahi_, _ixus_,
  { {0xd6db012b, 0x63b80173, 0xe365004c, 0x00000000}},  //   _шта_, _devn, скни,
  { {0xf5950054, 0x81cb0044, 0x6298083f, 0x00000000}},  //   _الإج, র্স_, _duvo,
  { {0x66ea006b, 0x20010085, 0x661d01e5, 0x00000000}},  //   _təkc, _bahi_, ösku,
  { {0x8fa3003b, 0xa8790049, 0xf66a000c, 0x00000000}},  //   заре, טאָר, phæð_,
  { {0x2001155d, 0xb05b00f8, 0x00000000, 0x00000000}},  //   _dahi_, vrät,   ,
  { {0x7bc71468, 0xb05b155e, 0x682f0146, 0x00000000}},  //   _adju, tsäc, _bødk,
  { {0x3a2400bb, 0x66ea006b, 0x6298010f, 0x00000000}},  // [2920] _romp_, _məka, _zuvo,
  { {0xddcd0036, 0x00000000, 0x00000000, 0x00000000}},  //   gnał,   ,   ,
  { {0x5f061036, 0xb05b155f, 0x3a2400bb, 0x00000000}},  //   _узна, rrät, _pomp_,
  { {0xb05b0039, 0x9acb00a1, 0x68e20197, 0x00000000}},  //   srät, ادلہ_, ttod,
  { {0xa3d70164, 0xb05b0039, 0x628600ca, 0x00000000}},  //   िला_, prät, imko,
  { {0x6c3600a6, 0xc5e50044, 0xd6da02d3, 0x00000000}},  //   _افسا, _খোলা_, гти_,
  { {0x68e20207, 0x63b81560, 0xb5fd04eb, 0x00000000}},  //   stod, _revn, pošl,
  { {0xb8ce08b7, 0x63b800ca, 0xf1bf0010, 0x00000000}},  //   _কি_, _sevn, nkát_,
  { {0x629814f8, 0x63b80161, 0xdb050276, 0x00000000}},  //   _suvo, _pevn, zahü,
  { {0x96ba1561, 0x22491562, 0x932600a1, 0x00000000}},  //   _буду_, _smak_, مرجن,
  { {0xe6960025, 0xd5af02e9, 0x888102fd, 0x00000000}},  //   _الصد, _нс_, _تیون,
  { {0xe71700b6, 0x80dd0055, 0xfbde0044, 0x00000000}},  //   _לחבר_, যবস্, ড়িত,
  { {0xdb150010, 0x85761234, 0x067b0049, 0x00000000}},  //   _vezé, _ادائ, _ענדל,
  { {0x25de0204, 0xf1db0309, 0xdb1c0030, 0x00000000}},  //   _गाडी_, _भावन, _idræ,
  { {0xfbde0044, 0x9f340088, 0xadbd007e, 0x00000000}},  //   ড়াত, пері, кавi,
  { {0x66020004, 0x6a78004a, 0x200100e7, 0x00000000}},  //   _jaok, dífo, _wahi_,
  { {0xd7c80061, 0x61ed011c, 0x20011563, 0x00000000}},  // [2930] रणाच, _ibal, _tahi_,
  { {0x44e2000c, 0x81cb0044, 0xb6060521, 0x00000000}},  //   ið_, র্শ_, lašć,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66020627, 0x998d1556, 0xb05b010f, 0x00000000}},  //   _naok, _aleš_, präs,
  { {0x61ed000b, 0x7bc3009f, 0x69d91564, 0x00000000}},  //   _mbal, ónus, rgwe,
  { {0x16a9005c, 0xbcfb00f4, 0xdb050048, 0x00000000}},  //   авки_, _exéc, abhá,
  { {0xb21b000c, 0xe7390827, 0x682f1565, 0x00000000}},  //   tmæl, рей_, _jødi,
  { {0xe7f503d7, 0x79e700a1, 0x644a0142, 0x00000000}},  //   _इसका_, _دورہ_, _amfi,
  { {0xb5fd0e3b, 0x845900ed, 0x7ae50022, 0x00000000}},  //   lošk, ирот_, ltht,
  { {0x61ed011c, 0x00000000, 0x00000000, 0x00000000}},  //   _abal,   ,   ,
  { {0x60c40119, 0xfbd2019b, 0x61ed1566, 0x00000000}},  //   _svim, ותי_, _bbal,
  { {0x7c270065, 0x7b200107, 0xe5ef00b0, 0x00000000}},  //   _lojr, _ušuš, äkää,
  { {0x644f00f4, 0x25bf0433, 0x61ed00d4, 0x00000000}},  //   écis, maul_, _dbal,
  { {0x61ed002d, 0xb5fd0142, 0xdfd20025, 0x00000000}},  //   _ebal, košk, بيس_,
  { {0x44271567, 0x81b90044, 0xb5fd0166, 0x00000000}},  //   _ion_, _চার_, jošk,
  { {0x44271568, 0x78a90224, 0x3d060061, 0x00000000}},  //   _hon_, _otev, हटले_,
  { {0x44271569, 0xec4a007c, 0x0c260088, 0x00000000}},  // [2940] _kon_, азал_, оман,
  { {0x4427156a, 0x69c90145, 0x61ed156b, 0x00000000}},  //   _jon_, _adee, _zbal,
  { {0x4427028c, 0x290d130f, 0xb5fd0bf8, 0x00000000}},  //   _mon_, _area_, gošk,
  { {0x44270011, 0x290d0a49, 0x38c802fd, 0x00000000}},  //   _lon_, _brea_, ماتی_,
  { {0xb05b0444, 0x442700b0, 0x69c90045, 0x00000000}},  //   isän, _oon_, _ddee,
  { {0x442705d3, 0x764b018e, 0x290d012d, 0x00000000}},  //   _non_, _amgy, _drea_,
  { {0xab2a0017, 0xd6d00025, 0x3e480035, 0x00000000}},  //   _това_, رقة_, eşti_,
  { {0x4427002a, 0xcf93009b, 0x7d09012d, 0x00000000}},  //   _aon_, וטו_, _šesi,
  { {0x4427156c, 0xe4e601fb, 0x25eb0061, 0x00000000}},  //   _bon_, ційн, _अउरी_,
  { {0x4427156d, 0x44e2009f, 0x61ed04b8, 0x00000000}},  //   _con_, rð_, _sbal,
  { {0x4427156e, 0xd251007a, 0x2be20204, 0x00000000}},  //   _don_, فند_, _पाना,
  { {0x9258007c, 0x25bf00e5, 0x00000000, 0x00000000}},  //   жают_, caul_,   ,
  { {0x442701aa, 0xc21801fb, 0x855603ec, 0x00000000}},  //   _fon_, ією_, _بخاط,
  { {0x9f4c004f, 0x4427156f, 0xdb1e00c4, 0x00000000}},  //   ždý_, _gon_, rapê,
  { {0x764b018e, 0xb6060521, 0x7ae50045, 0x00000000}},  //   _ymgy, pašć, xtht,
  { {0x61ed0020, 0xc7b80166, 0x7c270009, 0x00000000}},  //   _ubal, _dođi_, _sojr,
  { {0x44270607, 0x2d8f001f, 0x645a1570, 0x00000000}},  // [2950] _yon_, äge_, onti,
  { {0x645a1571, 0x44270f1d, 0xb5fd1572, 0x00000000}},  //   nnti, _xon_, tošk,
  { {0x645a00b0, 0x443e01a2, 0xdefb007e, 0x00000000}},  //   inti, iht_, _тып_,
  { {0x290d000d, 0xb5fd01d9, 0xf9c701fb, 0x00000000}},  //   _prea_, rošk, іщен,
  { {0x8d8702be, 0xf99003ec, 0x443e0982, 0x00000000}},  //   _фунд, نبه_, kht_,
  { {0x290d000d, 0x2be20061, 0x09340025, 0x00000000}},  //   _vrea_, _पाया, برمج,
  { {0x4427000d, 0x2b570014, 0x7ac4005c, 0x00000000}},  //   _ron_, _بیاد_, _осте,
  { {0x682f02cc, 0x569200ec, 0x443e010f, 0x00000000}},  //   _nødv, најт, eht_,
  { {0x442701a3, 0x290d0300, 0xb5fd10d9, 0x00000000}},  //   _pon_, _urea_, noši,
  { {0x443e0866, 0x645a00ea, 0x00000000, 0x00000000}},  //   ght_, gnti,   ,
  { {0x442708ba, 0xdb0e010f, 0xa8220014, 0x00000000}},  //   _von_, _gebä, _سکون,
  { {0xfc3f1573, 0x645a0006, 0x442700ab, 0x00000000}},  //   _stíl_, anti, _won_,
  { {0x4427028c, 0xb05b04ce, 0xb5fd0089, 0x00000000}},  //   _ton_, rsän, joši,
  { {0x443e1574, 0xc7b80107, 0x9f5a0197, 0x00000000}},  //   cht_, _pođi_, _papà_,
  { {0xe7ed0365, 0xfbd200a1, 0x25bd00e0, 0x00000000}},  //   च्या_, ہتا_, _kewl_,
  { {0x9f4b0010, 0x00000000, 0x00000000, 0x00000000}},  //   áját_,   ,   ,
  { {0xdb1c00c4, 0x229a0089, 0x629600e0, 0x00000000}},  // [2960] _gerê, _rīki_, _iiyo,
  { {0x6296047b, 0x9f580023, 0x00000000, 0x00000000}},  //   _hiyo, nerë_,   ,
  { {0xeb970088, 0x62961575, 0x628400ea, 0x00000000}},  //   чих_, _kiyo, _khio,
  { {0xdb1c0065, 0x9f580065, 0x628701dc, 0x00000000}},  //   _herë, herë_, ňkov,
  { {0x645a1576, 0x62840051, 0x6e240d16, 0x00000000}},  //   ynti, _mhio, mjib,
  { {0x9f580023, 0x00000000, 0x00000000, 0x00000000}},  //   jerë_,   ,   ,
  { {0x81d40055, 0xe3c30044, 0x8f9b00a3, 0x00000000}},  //   স্য_, ্ভাব, זיצי,
  { {0x645a0b78, 0x6296011c, 0x6e360006, 0x00000000}},  //   wnti, _niyo, nkyb,
  { {0x6d440198, 0xa3d70061, 0x682f08c8, 0x00000000}},  //   nzia, िलं_, _rødv,
  { {0x81b90055, 0x7bde1577, 0x53340478, 0x00000000}},  //   _চাই_, ngpu, деот,
  { {0x62961578, 0xddcd00b9, 0x645a00f8, 0x00000000}},  //   _biyo, hlaš, rnti,
  { {0x443e048a, 0x6284111b, 0xa77b0049, 0x00000000}},  //   sht_, _chio, _פראפ,
  { {0x6296034f, 0x443e0658, 0x62840048, 0x00000000}},  //   _diyo, pht_, _dhio,
  { {0x6d441579, 0xc95300b6, 0xc05b0451, 0x00000000}},  //   dzia, תמש_, сім_,
  { {0x6284002a, 0x7e6d0161, 0x9f5a008e, 0x00000000}},  //   _fhio, toap, _papá_,
  { {0x337700b6, 0x443c0011, 0xb5fd0089, 0x00000000}},  //   _מתוך_, _hlv_, toši,
  { {0x7e6d000d, 0xddcd0ce4, 0x8d770025, 0x00000000}},  // [2970] roap, glaš, سارا,
  { {0x62960288, 0x7e6d0035, 0x7a33026d, 0x00000000}},  //   _ziyo, soap, _içti,
  { {0x3cf903d7, 0x539b0104, 0x443c00d9, 0x00000000}},  //   _उनके_, ציאו, _mlv_,
  { {0xddcd0059, 0x6e3602d4, 0xdb1c00f6, 0x00000000}},  //   blaš, ckyb, _merè,
  { {0x8c3b001f, 0x998400b9, 0x443c01c3, 0x00000000}},  //   _auße, _domů_, _olv_,
  { {0x66ea005f, 0xe8f8007e, 0x7d0d0232, 0x00000000}},  //   _təkl, ялі_, mvas,
  { {0x7d0d157a, 0x00000000, 0x00000000, 0x00000000}},  //   lvas,   ,   ,
  { {0x7d0d0784, 0x443c00b0, 0x00000000, 0x00000000}},  //   ovas, _alv_,   ,
  { {0x7d0d00b0, 0x3a84007e, 0x58d4157b, 0x00000000}},  //   nvas, _чырв, _потт,
  { {0x62961338, 0x62840048, 0xdb1c000a, 0x00000000}},  //   _siyo, _shio, _berè,
  { {0x6fd70061, 0xcfe30055, 0xb05b0039, 0x00000000}},  //   _बाजू, য়ান, rsäl,
  { {0x1c0a001c, 0x5eac0055, 0x443c121b, 0x00000000}},  //   _होईल_, _ছিলে, _elv_,
  { {0xd012026c, 0xdb1c008d, 0xdb1e008e, 0x00000000}},  //   پلز_, _perë, rapé,
  { {0x4095029b, 0x6609022b, 0xddcd0107, 0x00000000}},  //   ерст, ldek, vlaš,
  { {0xdee301fb, 0x6284002a, 0x6441056f, 0x00000000}},  //   кори, _thio, mhli,
  { {0x6609011f, 0x6d44022b, 0x7c3c00e0, 0x00000000}},  //   ndek, tzia, _slrr,
  { {0x15e202fb, 0x7d0d12c3, 0x6e240022, 0x00000000}},  // [2980] क्टर_, gvas, rjib,
  { {0x6d440207, 0x26c7089f, 0x443c00f6, 0x00000000}},  //   rzia, ksno_, _xlv_,
  { {0x7d0d157c, 0xf0930104, 0xdb051259, 0x00000000}},  //   avas, _שנת_, nchè,
  { {0xddcd0089, 0x8c48005f, 0xceb300b3, 0x00000000}},  //   plaš, _başç, _שיר_,
  { {0x81cb0055, 0x66090066, 0x81d40044, 0x00000000}},  //   র্ক_, ddek, স্থ_,
  { {0x76aa0d51, 0x9f5801aa, 0x645d009d, 0x00000000}},  //   отив_, terè_, ésil,
  { {0x6441157d, 0x8c3b010f, 0x66ea006b, 0x00000000}},  //   dhli, _fußb, _təkm,
  { {0x81d40055, 0xa3b00164, 0x66090058, 0x00000000}},  //   স্ত_, टुन_, gdek,
  { {0x6ad30044, 0x69c00089, 0xb7bc0089, 0x00000000}},  //   _সহযো, _ieme, _loģi,
  { {0x69c0022b, 0x644100ab, 0x682f01e3, 0x00000000}},  //   _heme, ghli, _døds,
  { {0x69c0020c, 0xbbd70097, 0x3946004a, 0x00000000}},  //   _keme, וויץ_, lzos_,
  { {0x78a001dd, 0x682f01e3, 0x69c01303, 0x00000000}},  //   _kumv, _føds, _jeme,
  { {0x69c0020c, 0x3946157e, 0x656f010f, 0x00000000}},  //   _meme, nzos_, ücht,
  { {0x6441001f, 0x69c00010, 0xbe0500a1, 0x00000000}},  //   chli, _leme, کورٹ,
  { {0xfe730188, 0x3267005e, 0x9f410197, 0x00000000}},  //   ندر_, _отив, _xchè_,
  { {0x27e9037e, 0x69c0157f, 0xe508001d, 0x00000000}},  //   đani_, _neme, _kỷ_,
  { {0x6a78045b, 0xddc40514, 0xa2da0201, 0x00000000}},  // [2990] cífi, bliž, पूर्,
  { {0x61fd1580, 0x244001aa, 0x6609014a, 0x00000000}},  //   lesl, _fòme_, zdek,
  { {0x3ce91581, 0x69c01582, 0x2904008a, 0x00000000}},  //   stav_, _beme, _asma_,
  { {0xfe35007b, 0x61fd1556, 0x78a00009, 0x00000000}},  //   _נאָך_, nesl, _bumv,
  { {0x69c00483, 0xadd6019b, 0x78a0001a, 0x00000000}},  //   _deme, _אורח_, _cumv,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c0000d, 0x7bc5011c, 0x660900b5, 0x00000000}},  //   _feme, mahu, tdek,
  { {0x69c0037f, 0x7bc51583, 0xd90e026c, 0x00000000}},  //   _geme, lahu, جیے_,
  { {0x6609033b, 0x64410124, 0x29040087, 0x00000000}},  //   rdek, thli, _gsma_,
  { {0x69c0001e, 0xc9840072, 0x7bc5036b, 0x00000000}},  //   _zeme, _руси, nahu,
  { {0x69c0011f, 0x35b501fb, 0x69cc00b9, 0x00000000}},  //   _yeme, _збер, ůlež,
  { {0xcb12007b, 0x61fd00c7, 0x683404bd, 0x00000000}},  //   אלט_, gesl, _ràdi,
  { {0x7bc5011c, 0x25b9000c, 0x6d5b0079, 0x00000000}},  //   kahu, ðslu_, _žuan,
  { {0xf8b2009b, 0x6a781261, 0x7bc5010e, 0x00000000}},  //   רשם_, rífi, jahu,
  { {0x3a3f014a, 0x5e960025, 0x61fd002d, 0x00000000}},  //   _olup_, فلسط, besl,
  { {0x61e4041a, 0x2be20061, 0x66ea006b, 0x00000000}},  //   _ucil, _पाहा, _səkk,
  { {0xc692061e, 0x8fa601e1, 0x7afb01a8, 0x00000000}},  // [29a0] ראן_, _папе, _ćuta,
  { {0x69c01584, 0x09d80061, 0x7bc50eb0, 0x00000000}},  //   _seme, डल्य, gahu,
  { {0x69c004fa, 0x4fbb00a0, 0x3a2d01c3, 0x00000000}},  //   _peme, _מציא, _boep_,
  { {0x4ad10061, 0xc9861585, 0x0f570097, 0x00000000}},  //   _हिरव, нули, _טיים_,
  { {0x7bc50058, 0xa3cf0309, 0x69c00065, 0x00000000}},  //   bahu, षणा_, _veme,
  { {0x26dc0556, 0x39461586, 0x69c00168, 0x00000000}},  //   tuvo_, rzos_, _weme,
  { {0x8c1b007b, 0x316c0046, 0x81cb0055, 0x00000000}},  //   _צולי, ędzy_, র্ট_,
  { {0x7c2e0190, 0x9b17009b, 0x3a3f0091, 0x00000000}},  //   _hobr, _אחלה_, _glup_,
  { {0x7c2e002d, 0xb21b0030, 0x61fd1587, 0x00000000}},  //   _kobr, llæg, vesl,
  { {0xb806026c, 0xb05b0039, 0x73380216, 0x00000000}},  //   _سکتے_, rsäk, дзор_,
  { {0xb21b0f4b, 0x22400168, 0xe1ff0051, 0x00000000}},  //   nlæg, _blik_, nnóg_,
  { {0xe508001d, 0x60dd03b6, 0x22401588, 0x00000000}},  //   _tỷ_, tusm, _clik_,
  { {0xdb051321, 0x7bc50020, 0xe5080011, 0x00000000}},  //   rché, yahu, _uỷ_,
  { {0x7c2e1589, 0x61fd006b, 0xb4be0061, 0x00000000}},  //   _nobr, sesl, ेळी_,
  { {0x60dd006c, 0xddc40036, 0xb5fd0091, 0x00000000}},  //   susm, bliż, pošt,
  { {0x442e037f, 0xb21b0030, 0x7bc50020, 0x00000000}},  //   _hof_, dlæg, wahu,
  { {0x7bc5020c, 0x442e158a, 0x3a2d07a5, 0x00000000}},  // [29b0] tahu, _kof_, _roep_,
  { {0xddeb007a, 0xe1ff158b, 0x3a2d00bb, 0x00000000}},  //   _کرده_, leó_, _soep_,
  { {0x442e0145, 0x3a2d0116, 0x00000000, 0x00000000}},  //   _mof_, _poep_,   ,
  { {0x442e01d6, 0x7bc50428, 0x60cd00ea, 0x00000000}},  //   _lof_, sahu, _kvam,
  { {0xbddb0129, 0x26cc0521, 0x7bc50058, 0x00000000}},  //   _elèc, _avdo_, pahu,
  { {0x81cb0055, 0xbddb03eb, 0x46f50088, 0x00000000}},  //   র্চ_, _flèc, вчит,
  { {0x1c0a03d7, 0xaa59158c, 0xddcd0036, 0x00000000}},  //   _होटल_, _живу_, miał,
  { {0x7c2e0428, 0x60cd04eb, 0x9f4a00ea, 0x00000000}},  //   _zobr, _ovam, rebø_,
  { {0xe1ff0010, 0x98f4002c, 0x26cc0022, 0x00000000}},  //   deó_, _مثلا, _evdo_,
  { {0x22400292, 0x442e0016, 0xddcd0036, 0x00000000}},  //   _slik_, _cof_, niał,
  { {0xb21b0f4b, 0x60cd006c, 0x22400036, 0x00000000}},  //   klæd, _avam, _plik_,
  { {0x442e158d, 0x6b9a000c, 0x27e90521, 0x00000000}},  //   _eof_, _útge, đanu_,
  { {0xa509158e, 0xf1bf0047, 0xdd0100b9, 0x00000000}},  //   _цела_, pján_, čtět,
  { {0xd4790049, 0x628f0ace, 0x660b000c, 0x00000000}},  //   _קאַל, amco, _hagk,
  { {0xe456007b, 0x7c2e1089, 0x60cd0f4a, 0x00000000}},  //   _ביסט_, _robr, _evam,
  { {0x7c2e00d6, 0xb17b0039, 0x22400056, 0x00000000}},  //   _sobr, mgån, _ulik_,
  { {0xed570113, 0x660b006a, 0xdca301e0, 0x00000000}},  // [29c0] вот_, _magk, иати,
  { {0x14d40061, 0x213701ce, 0x660b02e7, 0x00000000}},  //   _दिसण, _סטיל_, _lagk,
  { {0x9f4800b0, 0x8b9606e7, 0x403b00b3, 0x00000000}},  //   ähän_, трач, _חגיג,
  { {0xb21b158f, 0x660b006a, 0x7c2e0016, 0x00000000}},  //   rlæg, _nagk, _wobr,
  { {0xd94601e0, 0x61f6008d, 0xd8380107, 0x00000000}},  //   ъеди, _mbyl, _liče_,
  { {0xddcd0036, 0x98730451, 0x7c2e0107, 0x00000000}},  //   ciał, аліц, _uobr,
  { {0x442000ad, 0xd8380107, 0x442e1590, 0x00000000}},  //   _đi_, _niče_, _rof_,
  { {0x442e0173, 0x261901f5, 0xb17b0039, 0x00000000}},  //   _sof_, भागी_, dgån,
  { {0x2ca6002a, 0x442e0638, 0x57ea00ed, 0x00000000}},  //   íodh_, _pof_, _одам_,
  { {0x6a780325, 0xe9670467, 0x683400f6, 0x00000000}},  //   rífu, _раул_, _pàdu,
  { {0x60cd01bf, 0x660b0292, 0x442e00bb, 0x00000000}},  //   _svam, _fagk, _vof_,
  { {0x7d0406a9, 0xddcd0036, 0xd838016c, 0x00000000}},  //   kwis, ział, _diče_,
  { {0x442e00bb, 0x628f00bb, 0x6a78000c, 0x00000000}},  //   _tof_, rmco, lífs,
  { {0x6e2f0082, 0x66001591, 0x7d040544, 0x00000000}},  //   _socb, lemk, dwis,
  { {0x67380010, 0x7afb012d, 0xbcfb00f6, 0x00000000}},  //   nyvj, _ćuto, _txék,
  { {0x30a70a1e, 0x6d0e0309, 0xddcd0036, 0x00000000}},  //   _иров, सिंग_, wiał,
  { {0xd90406c6, 0x2d5805c7, 0x2259080a, 0x00000000}},  // [29d0] _بی_, вить_, misk_,
  { {0x764207be, 0x225905ad, 0x61f6013e, 0x00000000}},  //   _lloy, lisk_, _zbyl,
  { {0xddcd0036, 0x98b80089, 0x0ba41592, 0x00000000}},  //   riał, _ārā_, ршум,
  { {0x225901c4, 0x629e00f4, 0x7d040058, 0x00000000}},  //   nisk_, _épou, bwis,
  { {0x4dda019b, 0xdb1c0f6e, 0xa3e20061, 0x00000000}},  //   _אחרו, _cerâ, धला_,
  { {0x764200e7, 0x660b1593, 0xd3660439, 0x00000000}},  //   _aloy, _sagk, _هه_,
  { {0x660b0811, 0x63ba0009, 0x225902e1, 0x00000000}},  //   _pagk, dbtn, kisk_,
  { {0xf5090d03, 0x3eb30082, 0x9f9c009b, 0x00000000}},  //   енил_, _mtxt_, וסופ,
  { {0x2259004e, 0x03a5017f, 0x79ea00a1, 0x00000000}},  //   disk_, липо, _سولہ_,
  { {0x58870783, 0x7642000a, 0x2c1c013d, 0x00000000}},  //   _рыба, _eloy, नाएं_,
  { {0x7d041594, 0xc735035b, 0x225901e3, 0x00000000}},  //   zwis, _حفاظ, fisk_,
  { {0x2259080a, 0x7d040036, 0xb17b0039, 0x00000000}},  //   gisk_, ywis, rgån,
  { {0x3eb30009, 0x25ad1595, 0x00000000, 0x00000000}},  //   _atxt_, mcel_,   ,
  { {0xdb1c0e7c, 0xd8381000, 0x25ad008e, 0x00000000}},  //   _serí, _tiče_, lcel_,
  { {0xdb1c1596, 0x3eb30009, 0x2259043e, 0x00000000}},  //   _perí, _ctxt_, bisk_,
  { {0x25ad0284, 0x6d41005f, 0x7d0400b5, 0x00000000}},  //   ncel_, _əlav, twis,
  { {0xdb1c0142, 0x00000000, 0x00000000, 0x00000000}},  // [29e0] _verí,   ,   ,
  { {0x7d040046, 0xc0060256, 0x660006b8, 0x00000000}},  //   rwis, _спок, zemk,
  { {0xe9da0140, 0x7d0401a2, 0x660000e7, 0x00000000}},  //   еке_, swis, yemk,
  { {0x66ea005f, 0x61e604be, 0x9f580c42, 0x00000000}},  //   _məkt, ngkl, merà_,
  { {0x9f580197, 0x00000000, 0x00000000, 0x00000000}},  //   lerà_,   ,   ,
  { {0xdcfd0089, 0x6d48006b, 0x7e6400ca, 0x00000000}},  //   _uzsā, _ədal, lnip,
  { {0xf1ba001d, 0x9f580197, 0x66001597, 0x00000000}},  //   _đơn_, nerà_, temk,
  { {0x9634025f, 0x7e64006c, 0xfb1b00b3, 0x00000000}},  //   рниц, nnip, _אולמ,
  { {0x89660454, 0xc966008b, 0x8886025f, 0x00000000}},  //   _скаж, _свай, _блаж,
  { {0x26190061, 0x5454005e, 0xb05b1598, 0x00000000}},  //   _मोठी_, рвот, nsät,
  { {0xa3e50183, 0x225901c4, 0xb8930025, 0x00000000}},  //   _फार_, tisk_, _اللع,
  { {0x9f580207, 0xbb3b0049, 0x6443007f, 0x00000000}},  //   derà_, געטי, _elni,
  { {0x225901c4, 0xf1bf0010, 0xe3af0014, 0x00000000}},  //   risk_, lják_, غری_,
  { {0x2259080a, 0x3394007e, 0x00000000, 0x00000000}},  //   sisk_, _калё,   ,
  { {0x645a006a, 0x21390065, 0x225911b6, 0x00000000}},  //   miti, sysh_, pisk_,
  { {0x442c1599, 0x443e159a, 0xdb0e013f, 0x00000000}},  //   ljd_, lkt_, _debü,
  { {0xdc55098c, 0x5d99007e, 0x26c10010, 0x00000000}},  // [29f0] авањ, ткаў_, ához_,
  { {0xe7e00201, 0x68e20006, 0xb05b0039, 0x00000000}},  //   _नागप, duod, gsät,
  { {0x443e159b, 0xcb55012b, 0xdb0e010f, 0x00000000}},  //   ikt_, јвећ, _gebü,
  { {0xdb1c02d5, 0x39150057, 0x645a0020, 0x00000000}},  //   _serã, имер, hiti,
  { {0x645a0020, 0x628d131d, 0xfc3f0051, 0x00000000}},  //   kiti, _mhao, _dtír_,
  { {0x645a1089, 0x443e02ae, 0x7c3e06d3, 0x00000000}},  //   jiti, jkt_, ckpr,
  { {0x645a0038, 0xfc3f0211, 0x6a78049a, 0x00000000}},  //   diti, _guía_, rífr,
  { {0x6e2d023a, 0xceb40097, 0xea63026c, 0x00000000}},  //   njab, זיק_, _اپری,
  { {0xdb1c0181, 0x69cb0866, 0x7bc7003f, 0x00000000}},  //   _terã, mage, _keju,
  { {0x69cb06d3, 0x6448120b, 0x7bc7159c, 0x00000000}},  //   lage, ghdi, _jeju,
  { {0x20030802, 0x38ab0030, 0x60dd00bb, 0x00000000}},  //   deji_, _hør_, ersm,
  { {0x628d0051, 0x69cb0038, 0x7bc71308, 0x00000000}},  //   _chao, nage, _leju,
  { {0x645a159d, 0x628d002a, 0x9f58159e, 0x00000000}},  //   biti, _dhao, derá_,
  { {0x443e001f, 0x69cb0030, 0x9f58159f, 0x00000000}},  //   ckt_, hage, terà_,
  { {0x7e56004c, 0x69cb01e3, 0x38ab0737, 0x00000000}},  //   атац, kage, _lør_,
  { {0x628d0051, 0x9f580cdd, 0xfe43053f, 0x00000000}},  //   _ghao, rerà_, онсо,
  { {0x69cb0239, 0xb05b09f0, 0x753b0dfc, 0x00000000}},  // [2a00] dage, tsät, nyuz,
  { {0x9f580197, 0xdb1c0051, 0x628d02d4, 0x00000000}},  //   perà_, _aerá, _zhao,
  { {0x9f5815a0, 0xb05b0a5d, 0x69cb0190, 0x00000000}},  //   berá_, rsät, fage,
  { {0x645a000d, 0x9f58029d, 0xfce6025f, 0x00000000}},  //   ziti, cerá_, _комо,
  { {0x394015a1, 0x443e0056, 0x7bc70023, 0x00000000}},  //   áis_, ykt_, _feju,
  { {0xf1bf0047, 0x2c1c013d, 0x26dc01a8, 0x00000000}},  //   tják_, नाओं_, trvo_,
  { {0x645a15a2, 0x12e00044, 0x78ab0009, 0x00000000}},  //   viti, _বন্দ, aqgv,
  { {0x2619007d, 0x38ab02cc, 0x69cb15a3, 0x00000000}},  //   _मोदी_, _før_, cage,
  { {0x38ab0018, 0x645a15a4, 0xd9430aed, 0x00000000}},  //   _gør_, titi, _дети,
  { {0x628d002a, 0x443e0089, 0x26dc016c, 0x00000000}},  //   _shao, ukt_, prvo_,
  { {0x645a15a5, 0x443e15a6, 0xd5af004d, 0x00000000}},  //   riti, rkt_, _мс_,
  { {0x443e15a7, 0x60dd0009, 0x7649000a, 0x00000000}},  //   skt_, trsm, chey,
  { {0x645a000b, 0x9f580181, 0xc05b01fb, 0x00000000}},  //   piti, verá_, вів_,
  { {0x02a601fb, 0x69cb0181, 0xc05b0088, 0x00000000}},  //   _крим, zage, тім_,
  { {0x69cb00f4, 0xa2e301f9, 0x44f000f4, 0x00000000}},  //   yage, _дојд, là_,
  { {0x7bc70169, 0xb05b00b0, 0x69cb00c4, 0x00000000}},  //   _seju, tsäs, xage,
  { {0x629f00f4, 0x69cb15a8, 0xdb1e006c, 0x00000000}},  // [2a10] _époq, vage, hapä,
  { {0xdb1c0211, 0x69cb010f, 0x6d4d00b5, 0x00000000}},  //   _será, wage, rzaa,
  { {0x69cb04d7, 0x38ab0056, 0x6486000c, 0x00000000}},  //   tage, _sør_, yðin,
  { {0xceb200bd, 0xbddb0173, 0xe0df0026, 0x00000000}},  //   _מיט_, _klèm, orò_,
  { {0x69cb15a6, 0xdb1c064d, 0xe9d8007e, 0x00000000}},  //   rage, _verá, ркі_,
  { {0x69cb15a9, 0xdb050051, 0x44f000d4, 0x00000000}},  //   sage, achá, dà_,
  { {0x69cb0061, 0xb9e70088, 0x61ed00b4, 0x00000000}},  //   page, _візи, _ocal,
  { {0x81cc0044, 0x683d0129, 0x38ab0030, 0x00000000}},  //   _লাভ_, _mèdi, _tør_,
  { {0x6486009f, 0x79800016, 0xf8070088, 0x00000000}},  //   rðin, _gymw, _вчен,
  { {0x69c900bb, 0xe0df0197, 0x61ed0d7b, 0x00000000}},  //   _heee, drò_, _acal,
  { {0x78a90211, 0x9f580129, 0x60c400ab, 0x00000000}},  //   _huev, merç_, _swim,
  { {0x66ea006b, 0x78a115aa, 0x69c9016e, 0x00000000}},  //   _təkr, _hilv, _jeee,
  { {0x78a915ab, 0x69c90a9d, 0xf6740a4f, 0x00000000}},  //   _juev, _meee, _بالخ,
  { {0x78a90211, 0xf1bf0181, 0x69c901ee, 0x00000000}},  //   _muev, abá_, _leee,
  { {0x7ae5006c, 0x3e860025, 0xf1bf0010, 0x00000000}},  //   juht, مشرف, bbá_,
  { {0x25bf011f, 0xf8a5007a, 0x64410fcf, 0x00000000}},  //   nbul_, _يک_, lkli,
  { {0x78a90219, 0x644115ac, 0x925a0123, 0x00000000}},  // [2a20] _nuev, okli, _لشکر_,
  { {0x09d00061, 0x64410aba, 0xdd8f1095, 0x00000000}},  //   हण्य, nkli, رول_,
  { {0xb09b009b, 0xd91000a1, 0x7c350b4a, 0x00000000}},  //   _תייר, ڈیز_, _dozr,
  { {0xd91004e1, 0x61ed01f3, 0x281900a1, 0x00000000}},  //   ویز_, _xcal, یفنگ_,
  { {0x627b007b, 0x6441002b, 0x78a9008e, 0x00000000}},  //   ננננ, kkli, _cuev,
  { {0x78a1001e, 0x69c90045, 0xfc4400a1, 0x00000000}},  //   _cilv, _eeee, _بھرپ,
  { {0x1ae30264, 0x22420145, 0x569401bd, 0x00000000}},  //   _норм, kkkk_, оакт,
  { {0x44f00409, 0x44b401fb, 0xbb3b0049, 0x00000000}},  //   tà_, обис, _געלי,
  { {0x7afb0107, 0xdb1c00c4, 0x78a115ad, 0x00000000}},  //   _ćuti, _berç, _filv,
  { {0x44f015ae, 0x61ed085d, 0xe0df0197, 0x00000000}},  //   rà_, _scal, vrò_,
  { {0x6d41005f, 0xd764026c, 0x44f000d4, 0x00000000}},  //   _əlaq, _بنای, sà_,
  { {0x64410007, 0x3ea20036, 0xe0df0197, 0x00000000}},  //   akli, _nikt_, trò_,
  { {0xdb1c00b0, 0x644115af, 0xf5960025, 0x00000000}},  //   _herä, bkli, _الشج,
  { {0x64410073, 0xdb1c15b0, 0xe0df0197, 0x00000000}},  //   ckli, _gerç, rrò_,
  { {0xc05801e1, 0x7c3515b1, 0xce6b005e, 0x00000000}},  //   сія_, _rozr, град_,
  { {0x4caa0055, 0xe0df0026, 0x61ed006b, 0x00000000}},  //   _চৌধু, prò_, _ucal,
  { {0x7c350027, 0x69c915b2, 0x3ea215b3, 0x00000000}},  // [2a30] _pozr, _reee, _dikt_,
  { {0x4d9804af, 0x69c915b4, 0x99ba0044, 0x00000000}},  //   скую_, _seee, ুলোক,
  { {0xa91d0087, 0x69c9004a, 0x22490eff, 0x00000000}},  //   _izži, _peee, _klak_,
  { {0x78a10335, 0x3a2400fa, 0x7ae50943, 0x00000000}},  //   _silv, _cnmp_, ruht,
  { {0x78a115b5, 0xbcfb0181, 0x7ae50103, 0x00000000}},  //   _pilv, _exér, suht,
  { {0x8aa70216, 0xdb1c0073, 0xdd310036, 0x00000000}},  //   _град, _berä, zęśc,
  { {0x81d408b7, 0x78a100d9, 0x78bc016c, 0x00000000}},  //   স্ট_, _vilv, _črve,
  { {0xd8380087, 0xb05b01a2, 0x00000000, 0x00000000}},  //   _fičo_, lpäd,   ,
  { {0x89370123, 0x78a115b6, 0x64410039, 0x00000000}},  //   _اعزا, _tilv, tkli,
  { {0x99480025, 0x224915b7, 0x7d0f0009, 0x00000000}},  //   _الكل_, _alak_, _mscs,
  { {0x644115b8, 0xdb1c010f, 0xb21b0030, 0x00000000}},  //   rkli, _gerä, rlæn,
  { {0x81e20055, 0x7d0f0061, 0x6441006c, 0x00000000}},  //   ন্ন_, _oscs, skli,
  { {0xdb1c0181, 0x3ea202e1, 0xbddb0173, 0x00000000}},  //   _terç, _rikt_, _elèk,
  { {0x224915b9, 0x3ea20479, 0x2d8201d6, 0x00000000}},  //   _elak_, _sikt_, _ryke_,
  { {0x03250088, 0x22490ce3, 0x7d1d00d9, 0x00000000}},  //   _єдин, _flak_, _arss,
  { {0x3f840089, 0x00e6058e, 0x00000000, 0x00000000}},  //   āmu_, _джин,   ,
  { {0x3ea20039, 0x2cb901c3, 0x00000000, 0x00000000}},  // [2a40] _vikt_, _ctsd_,   ,
  { {0x628606d3, 0x3942006c, 0x2cb90082, 0x00000000}},  //   llko, _üksi_, _dtsd_,
  { {0x6da60200, 0xe7ed01f5, 0x3ea20089, 0x00000000}},  //   _мина, च्छा_, _tikt_,
  { {0x387e0022, 0x00000000, 0x00000000, 0x00000000}},  //   _sktr_,   ,   ,
  { {0xa3e90183, 0x00000000, 0x00000000, 0x00000000}},  //   यला_,   ,   ,
  { {0xd6da103e, 0xdb1c00b0, 0x00000000, 0x00000000}},  //   ати_, _perä,   ,
  { {0x27e0011f, 0x81e20055, 0xdca301fc, 0x00000000}},  //   ğin_, ন্য_, _цари,
  { {0xdb1c010f, 0x27e00279, 0xa5340603, 0x00000000}},  //   _verä, şin_, знич,
  { {0xd4060242, 0x69c20116, 0x746a007c, 0x00000000}},  //   ояни, mboe, иров_,
  { {0x81e20055, 0xb3540088, 0x69c215ba, 0x00000000}},  //   ন্ম_, зкош, lboe,
  { {0x2249083a, 0x683d00f6, 0x68e40048, 0x00000000}},  //   _plak_, _cèdu, áidf,
  { {0x64a615bb, 0x69c200b5, 0x27fe0009, 0x00000000}},  //   _дада, nboe, _hbtn_,
  { {0x1a9b007b, 0xba9b012f, 0x2beb0164, 0x00000000}},  //   ייטע, יסטי, _चालू_,
  { {0x9f5a01aa, 0x74140014, 0x27fe0145, 0x00000000}},  //   _rapò_, _روبا, _jbtn_,
  { {0x22490161, 0xd8380cd6, 0x69c20116, 0x00000000}},  //   _tlak_, _moč_, kboe,
  { {0x68e20006, 0xa91d00b9, 0x5f940545, 0x00000000}},  //   krod, _lyža, фист,
  { {0xa3ae03d7, 0x5d550113, 0xfbab041f, 0x00000000}},  // [2a50] _कला_, чкат, атей_,
  { {0x68e210fd, 0x64dd0061, 0xd8380059, 0x00000000}},  //   drod, _मिसळ, _noč_,
  { {0xb5fd15bc, 0x00000000, 0x00000000, 0x00000000}},  //   liše,   ,   ,
  { {0xc333007b, 0x69c200c7, 0x244001aa, 0x00000000}},  //   ווע_, gboe, _dòmi_,
  { {0x2ca302ae, 0x68e20036, 0x7d1d0068, 0x00000000}},  //   _tijd_, grod, _urss,
  { {0x9f580026, 0x7d0d00e7, 0x387c016c, 0x00000000}},  //   ffrè_, mwas, govr_,
  { {0x3ffc007b, 0x4429001d, 0x7d0d15bd, 0x00000000}},  //   יפגע, _đa_, lwas,
  { {0x68e207ac, 0xecdf03d7, 0x7d0d00e7, 0x00000000}},  //   brod, _फटाफ, owas,
  { {0xdb05001f, 0x81e20055, 0x68e204d2, 0x00000000}},  //   schä, ন্ড_, crod,
  { {0x7d0d0058, 0x67f4000c, 0x00000000, 0x00000000}},  //   iwas, rþjó,   ,
  { {0x59cf0309, 0x7d0d15be, 0x5884007e, 0x00000000}},  //   _हजार, hwas, _цыта,
  { {0x80b30044, 0xdb120010, 0xdb070065, 0x00000000}},  //   _জিজ্, égév, _agjë,
  { {0xa5670014, 0x271c0011, 0x660915bf, 0x00000000}},  //   _بدان, _ảnh_, meek,
  { {0x660915c0, 0xdb15010f, 0x3af500f8, 0x00000000}},  //   leek, _bezü, kåp_,
  { {0x442715c1, 0x00000000, 0x00000000, 0x00000000}},  //   _inn_,   ,   ,
  { {0x7d0d15c2, 0xdd920025, 0x7c270022, 0x00000000}},  //   fwas, فوز_, _anjr,
  { {0x7d0d15c3, 0x00000000, 0x00000000, 0x00000000}},  // [2a60] gwas,   ,   ,
  { {0x8b960517, 0x4c8315c4, 0xac830264, 0x00000000}},  //   преч, елув, егул,
  { {0x442701f3, 0x103b009b, 0x69c20112, 0x00000000}},  //   _mnn_, _הגיע, tboe,
  { {0xdca60265, 0x7d0d097e, 0x2018000c, 0x00000000}},  //   _нами, bwas, ldri_,
  { {0x291f0051, 0xb05b006c, 0x69c201b5, 0x00000000}},  //   _crua_, späe, rboe,
  { {0x68e2005b, 0x69c20112, 0xb17b15c5, 0x00000000}},  //   rrod, sboe, mgåt,
  { {0xa09b01ce, 0x7bdc0093, 0xe73700ec, 0x00000000}},  //   זיסט, _idru, зеј_,
  { {0x442715c6, 0x81e20055, 0x54b80242, 0x00000000}},  //   _ann_, ন্ত_, огия_,
  { {0x7bce0149, 0x48e30849, 0x291f0065, 0x00000000}},  //   _kebu, _потв, _grua_,
  { {0xb5fd0ce4, 0x200a11af, 0x29040087, 0x00000000}},  //   više, jebi_, _ipma_,
  { {0x67bb009b, 0x44270082, 0x66090032, 0x00000000}},  //   _המבק, _dnn_, beek,
  { {0x442705d1, 0x7bce0f4d, 0xb5fd012d, 0x00000000}},  //   _enn_, _lebu, tiše,
  { {0xba570049, 0x7bdc15c7, 0xbddb000a, 0x00000000}},  //   לסטו_, _odru, _klèv,
  { {0x7bce0cd5, 0xb5fd016c, 0xc058008b, 0x00000000}},  //   _nebu, riše, піс_,
  { {0xff04007c, 0x5433035b, 0x81e20044, 0x00000000}},  //   нятн, _سرور, ন্ধ_,
  { {0x7d0d011c, 0xb5fd0c1e, 0x7bdc0145, 0x00000000}},  //   twas, piše, _adru,
  { {0x62560964, 0x41c3007d, 0xdcef0089, 0x00000000}},  // [2a70] ršot, _व्यस, _izcī,
  { {0x81e20055, 0xe0df01aa, 0x200a00c4, 0x00000000}},  //   ন্দ_, ryòd_, cebi_,
  { {0x7d0d15be, 0x78bb0cb2, 0x290400f6, 0x00000000}},  //   swas, _stuv, _apma_,
  { {0xfd1f0011, 0x320b009d, 0x61ef0082, 0x00000000}},  //   _trì_, necy_, ngcl,
  { {0x9f510211, 0x7bce033b, 0xdb050051, 0x00000000}},  //   pezó_, _febu, nchú,
  { {0x7bce010f, 0x66090116, 0xdb1501aa, 0x00000000}},  //   _gebu, week, _dezò,
  { {0x660900b0, 0xe736005e, 0xac94033c, 0x00000000}},  //   teek, дещ_, _чарш,
  { {0x7e6d0d88, 0x7bdc0465, 0x291f05d7, 0x00000000}},  //   nnap, _zdru, _trua_,
  { {0x14dd0061, 0x660901b5, 0x81cc0044, 0x00000000}},  //   _मिळण, reek, _লাল_,
  { {0x68e4002a, 0x66090052, 0x7e6d01a2, 0x00000000}},  //   áide, seek, hnap,
  { {0xe29a0216, 0x420a0d99, 0x7e6d15c8, 0x00000000}},  //   жан_, онно_, knap,
  { {0xd9ff007d, 0x7bc50048, 0x21200087, 0x00000000}},  //   ोजित_, hbhu, _prih_,
  { {0x7e6d0381, 0xd4350025, 0x24190783, 0x00000000}},  //   dnap, _يعتب, _моды_,
  { {0x6721016c, 0xa91d0161, 0x00000000, 0x00000000}},  //   _krlj, _lyžo,   ,
  { {0x7bce12e0, 0x10a30131, 0xa0a302ea, 0x00000000}},  //   _rebu, тирн, тард,
  { {0x7bce0149, 0x7bdc00b9, 0x7e6d0010, 0x00000000}},  //   _sebu, _sdru, gnap,
  { {0x6aae15c9, 0x62840034, 0x7bce0022, 0x00000000}},  // [2a80] _subf, _ikio, _pebu,
  { {0xfce30256, 0x8b6a0a85, 0x00000000, 0x00000000}},  //   тофо, оизв_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bce0190, 0x53360049, 0xc98601ab, 0x00000000}},  //   _webu, ונען_, мули,
  { {0xb17b0cb2, 0x644f0089, 0x7bce15ca, 0x00000000}},  //   lgår, īcij, _tebu,
  { {0x7bdc0166, 0x7e6407a4, 0x00000000, 0x00000000}},  //   _udru, liip,   ,
  { {0x2bc40164, 0x68e40051, 0xb17b02e7, 0x00000000}},  //   _ल्या, áidb, ngår,
  { {0x44201305, 0x7c3c0238, 0x8c3b01a2, 0x00000000}},  //   _şi_, _horr, _wußt,
  { {0x7c3c0cfd, 0xd838037e, 0x6d4404cb, 0x00000000}},  //   _korr, _liči_, nyia,
  { {0x62840020, 0xdb1c05b7, 0x7c3c002d, 0x00000000}},  //   _akio, _berø, _jorr,
  { {0x7c3c0181, 0x7d060022, 0xbddb000a, 0x00000000}},  //   _morr, _lpks, _klèt,
  { {0x7c3c00f4, 0x81e20044, 0x63ad15cb, 0x00000000}},  //   _lorr, ন্স_, _şant,
  { {0x61fd000c, 0x7c3c01d6, 0x20010022, 0x00000000}},  //   rfsl, _oorr, _pbhi_,
  { {0x7c3c0073, 0x62840288, 0xdb050048, 0x00000000}},  //   _norr, _ekio, rchú,
  { {0xe800001c, 0x9f5f011f, 0x1ee700a1, 0x00000000}},  //   ल्या_, _ürün_, ظوری_,
  { {0x443c0afd, 0x7d060022, 0x7e640058, 0x00000000}},  //   _hov_, _bpks, giip,
  { {0x443c0dc6, 0x7c3c1295, 0x7e6d15cc, 0x00000000}},  // [2a90] _kov_, _borr, rnap,
  { {0xe3b80676, 0x6fc00061, 0x6f050011, 0x00000000}},  //   ncı_, वडणू, _tphc,
  { {0x7c3c0c54, 0x30780025, 0x7bc50048, 0x00000000}},  //   _dorr, _تحية_, rbhu,
  { {0x60cd0be3, 0x443c05b7, 0x752204f3, 0x00000000}},  //   _kwam, _lov_, _oroz,
  { {0x7c3c0d22, 0xa803014a, 0xf8b1025a, 0x00000000}},  //   _forr, _çıkt, اکر_,
  { {0x443c01d9, 0x7c3c002d, 0x60cd0020, 0x00000000}},  //   _nov_, _gorr, _mwam,
  { {0x39490ebc, 0xddc401d9, 0x6e3d0007, 0x00000000}},  //   šas_, lniš, _kosb,
  { {0x7c3c15cd, 0x75220107, 0xfc3f0051, 0x00000000}},  //   _zorr, _broz, _cuív_,
  { {0x443c15ce, 0x6e3d0023, 0xd7fb15cf, 0x00000000}},  //   _bov_, _mosb, _муж_,
  { {0x20cd01c5, 0xdb2600a1, 0x6e3d01d6, 0x00000000}},  //   dži_, _توہی, _losb,
  { {0x13a700e9, 0x60cd0020, 0x443c0197, 0x00000000}},  //   بندی_, _awam, _dov_,
  { {0x23bf007d, 0x60cd0a5f, 0xf089009b, 0x00000000}},  //   _श्रद, _bwam, _הנ_,
  { {0x7522001e, 0xc56b025a, 0xddc40059, 0x00000000}},  //   _groz, _بحال_, jniš,
  { {0x6aa915d0, 0x443c1042, 0xddc401ae, 0x00000000}},  //   _lief, _gov_, dniš,
  { {0x44f90263, 0x752215b1, 0x661915d1, 0x00000000}},  //   lè_, _zroz, _kawk,
  { {0x661b15d2, 0xb17b01bf, 0x6e3d0016, 0x00000000}},  //   nduk, rgår, _cosb,
  { {0x7c3c002d, 0x44f90263, 0x6e3d018e, 0x00000000}},  // [2aa0] _porr, nè_, _dosb,
  { {0x31570049, 0x7d1b002b, 0x7c3c15d3, 0x00000000}},  //   _ניין_, _ġust, _qorr,
  { {0x7c3c15d4, 0xb5fd016c, 0x201a12aa, 0x00000000}},  //   _vorr, ziša, _iapi_,
  { {0xddc401d9, 0x7ae315d5, 0x661b016e, 0x00000000}},  //   bniš, ánta, jduk,
  { {0x44f90263, 0x6aa90112, 0x201a15d6, 0x00000000}},  //   jè_, _dief, _kapi_,
  { {0x98a310a9, 0x201a002f, 0xb5fd00ca, 0x00000000}},  //   гиче, _japi_, viša,
  { {0x09e601fb, 0x752215d7, 0x201a00ca, 0x00000000}},  //   _повн, _sroz, _mapi_,
  { {0x443c0239, 0x44f901aa, 0x6aa90026, 0x00000000}},  //   _sov_, fè_, _gief,
  { {0x443c15d8, 0xc8ca03ec, 0x66190036, 0x00000000}},  //   _pov_, _روان_, _dawk,
  { {0x07a60106, 0x201a0010, 0x60cd09df, 0x00000000}},  //   _зазн, _napi_, _rwam,
  { {0xcf120044, 0xddc40059, 0x39460010, 0x00000000}},  //   হমুদ_, zniš, lyos_,
  { {0x76490039, 0xb5fd040d, 0x752215d9, 0x00000000}},  //   ckey, lišn, _troz,
  { {0x81a90055, 0x39460047, 0x443c0145, 0x00000000}},  //   খুন_, nyos_, _tov_,
  { {0xddc4092f, 0x201a0197, 0xc5690d3a, 0x00000000}},  //   vniš, _capi_, _تحمل_,
  { {0x6e3d0007, 0x141b009b, 0x201a0386, 0x00000000}},  //   _posb, _מוגב, _dapi_,
  { {0xddc410b9, 0x60cd15da, 0x6d1c007d, 0x00000000}},  //   tniš, _twam, निंग_,
  { {0x30a70373, 0x313501f9, 0x22ac00b9, 0x00000000}},  // [2ab0] _пров, _репр, _věku_,
  { {0xddc40059, 0xbbcb0061, 0x31580049, 0x00000000}},  //   rniš, िरेक, _ריזן_,
  { {0xb5fd0119, 0xcfb6009b, 0x99f5007e, 0x00000000}},  //   dišn, _בלתי_, вялі,
  { {0x44f90263, 0xddc40fd0, 0x201a15db, 0x00000000}},  //   yè_, pniš, _zapi_,
  { {0x201a15dc, 0xca7415dd, 0x00000000, 0x00000000}},  //   _yapi_, دالغ,   ,
  { {0x6bd4004b, 0x44f915de, 0x00000000, 0x00000000}},  //   _متفر, vè_,   ,
  { {0x6aa9010f, 0x79c90379, 0x44f901aa, 0x00000000}},  //   _tief, _يوسف_, wè_,
  { {0x44f90263, 0x3eab0022, 0x00000000, 0x00000000}},  //   tè_, _jict_,   ,
  { {0x764915df, 0x661b04a0, 0x3a2d00c4, 0x00000000}},  //   rkey, rduk, _inep_,
  { {0x7bd715e0, 0x2d8b00bb, 0x44f901aa, 0x00000000}},  //   naxu, _myce_, rè_,
  { {0x3a3f01aa, 0x44f901aa, 0x35f5007e, 0x00000000}},  //   _koup_, sè_, _апер,
  { {0x201a023a, 0x44f915e1, 0xd83801aa, 0x00000000}},  //   _sapi_, pè_, _chčf_,
  { {0x2124002a, 0x6486000c, 0x9f58000c, 0x00000000}},  //   ímh_, gðis, rfrí_,
  { {0x3a3f009d, 0xb05b04ce, 0x00000000, 0x00000000}},  //   _loup_, spän,   ,
  { {0xfc3f15e2, 0xe1ff15e3, 0x00000000, 0x00000000}},  //   _luís_, mión_,   ,
  { {0x201a0020, 0x337600b3, 0x2ee5000c, 0x00000000}},  //   _wapi_, _בעצם_, álfa_,
  { {0x201a0149, 0xada6008b, 0xbea309b2, 0x00000000}},  // [2ac0] _tapi_, таал, ратк,
  { {0xe1ff0219, 0xddc9012d, 0x22400288, 0x00000000}},  //   nión_, čošk, _hoik_,
  { {0xb5fd0166, 0x8fa600ec, 0x3a3f0173, 0x00000000}},  //   višn, _јане, _boup_,
  { {0x3a3f00f4, 0x7524016c, 0xc33200b3, 0x00000000}},  //   _coup_, _šizm, יוב_,
  { {0x3ea015e4, 0x99dd000a, 0x00000000, 0x00000000}},  //   mmit_, _alňs,   ,
  { {0xdb1c0047, 0x3ea00065, 0xb7d80025, 0x00000000}},  //   _kerü, lmit_, روبا_,
  { {0x7c2e0fcf, 0xb5fd0e00, 0xe70402fd, 0x00000000}},  //   _inbr, rišn, استی,
  { {0xeb97004c, 0x9f58004a, 0x00000000, 0x00000000}},  //   _рис_, leró_,   ,
  { {0xb5fd0825, 0x00000000, 0x00000000, 0x00000000}},  //   mišl,   ,   ,
  { {0xe1ff15e5, 0x9f58008e, 0x3ea00023, 0x00000000}},  //   gión_, neró_, hmit_,
  { {0x22520007, 0x00000000, 0x00000000, 0x00000000}},  //   _blyk_,   ,   ,
  { {0xdb1c15e6, 0xacbb00f4, 0x3ea015e7, 0x00000000}},  //   _heró, _brûl, jmit_,
  { {0x81cc0044, 0x7c2e0112, 0x00000000, 0x00000000}},  //   _লাখ_, _onbr,   ,
  { {0xe1ff0819, 0x14d7007b, 0x6486009f, 0x00000000}},  //   ción_, _יודל_, rðis,
  { {0x3eab0061, 0x9f58008e, 0x00000000, 0x00000000}},  //   _pict_, deró_,   ,
  { {0x320f0047, 0x7c2e0240, 0x02a400a5, 0x00000000}},  //   _úgy_, _anbr, _крым,
  { {0x628f01c3, 0xcc990184, 0x5c750745, 0x00000000}},  // [2ad0] mlco, евац_, глат,
  { {0x3a2d15e8, 0x7ae315e9, 0x628f01ed, 0x00000000}},  //   _snep_, ánto, llco,
  { {0x3ea00866, 0xdb1c010f, 0x5ba7017f, 0x00000000}},  //   bmit_, _gerü, траз,
  { {0x3ce901d9, 0x2011094f, 0x7c2e15ea, 0x00000000}},  //   prav_, lezi_, _enbr,
  { {0x26de15eb, 0x628f000a, 0x9f580919, 0x00000000}},  //   _avto_, ilco, beró_,
  { {0x2011001a, 0xe1ff0211, 0x81d90044, 0x00000000}},  //   nezi_, xión_, ালি_,
  { {0x27e901f6, 0x3a3f01aa, 0x9f580026, 0x00000000}},  //   ğan_, _toup_, lerò_,
  { {0x27e915ec, 0x7bd50032, 0x201115ed, 0x00000000}},  //   şan_, _hezu, hezi_,
  { {0xe800024c, 0x2a640265, 0x2717005f, 0x00000000}},  //   ल्हा_, _търг, _mənə_,
  { {0x3ea0008d, 0x69d915ee, 0x7bd515ef, 0x00000000}},  //   zmit_, lawe, _jezu,
  { {0x7bd515f0, 0x442e0146, 0x9f580197, 0x00000000}},  //   _mezu, _dnf_, herò_,
  { {0xe1ff15f1, 0x69d9000b, 0x442e15f2, 0x00000000}},  //   sión_, nawe, _enf_,
  { {0x6486000c, 0x442e0085, 0xd5ae0257, 0x00000000}},  //   rðir, _fnf_, _عفو_,
  { {0x201115f3, 0x9f580197, 0xb5fd0b54, 0x00000000}},  //   gezi_, derò_, zišl,
  { {0x37d80044, 0x2d8f010f, 0x9f58004a, 0x00000000}},  //   _সামর, ügen_, veró_,
  { {0xdb050051, 0x69d915f4, 0xfbcd0044, 0x00000000}},  //   hchó, jawe, _লাগত,
  { {0x62860429, 0x7bd5010f, 0xed5700ed, 0x00000000}},  // [2ae0] moko, _bezu, гот_,
  { {0x6286011c, 0xdb1c0047, 0x3ea00089, 0x00000000}},  //   loko, _terü, smit_,
  { {0x272301f6, 0x7bd502eb, 0xdb1c00d4, 0x00000000}},  //   _nın_, _dezu, _aerò,
  { {0x248515f5, 0x69d90fb6, 0x9f41008e, 0x00000000}},  //   holm_, gawe, _echó_,
  { {0x9f58008e, 0xdb1c008e, 0xc7ba007e, 0x00000000}},  //   peró_, _peró, нёй_,
  { {0x628615f6, 0x7bd50ab3, 0x26dc041a, 0x00000000}},  //   hoko, _gezu, tsvo_,
  { {0x628600b0, 0xdb1c008e, 0x7d160016, 0x00000000}},  //   koko, _veró, lwys,
  { {0x60c415f7, 0x61e40020, 0x628615f8, 0x00000000}},  //   _otim, _ndil, joko,
  { {0x628615f9, 0x60c415fa, 0x54540069, 0x00000000}},  //   doko, _ntim, ивит,
  { {0x61e415fb, 0xe6440279, 0x6aa215fc, 0x00000000}},  //   _adil, ılış, lmof,
  { {0x439401f9, 0x20110035, 0x60c415fd, 0x00000000}},  //   ранс, vezi_, _atim,
  { {0xe45206c6, 0x2011000b, 0x62860266, 0x00000000}},  //   _گفتگ, wezi_, goko,
  { {0x2011000b, 0x61e40016, 0x855700a1, 0x00000000}},  //   tezi_, _ddil, _میٹر_,
  { {0x61e415fe, 0x2717006b, 0x442e01ee, 0x00000000}},  //   _edil, _sənə_, _unf_,
  { {0x60c4049a, 0x2011002d, 0x69d900e7, 0x00000000}},  //   _etim, rezi_, yawe,
  { {0x20110035, 0x9f580197, 0x6728012d, 0x00000000}},  //   sezi_, terò_, _mrdj,
  { {0xdb05010f, 0x7bd50065, 0x2beb00ed, 0x00000000}},  // [2af0] schü, _pezu, еќен_,
  { {0x69d90020, 0x69c015ff, 0x9f580197, 0x00000000}},  //   wawe, _afme, rerò_,
  { {0x7bd50107, 0x8af9005e, 0x69d90020, 0x00000000}},  //   _vezu, тнес_, tawe,
  { {0xd01100a1, 0x7f3a0049, 0x7d160016, 0x00000000}},  //   _الگ_, _סערו, bwys,
  { {0x80a402fd, 0xe0df0e5d, 0x67281600, 0x00000000}},  //   _خمین, nsò_, _ardj,
  { {0xb346014a, 0x62860e49, 0x6353006b, 0x00000000}},  //   _kaçı, zoko, sənə,
  { {0xe7390373, 0x764201d6, 0xdb050a41, 0x00000000}},  //   тей_, _booy, rchó,
  { {0x8aa4004c, 0xb5fd0006, 0x26c70e0d, 0x00000000}},  //   _груд, mišk, rpno_,
  { {0xb5fd09f4, 0xf1c800b9, 0x76421601, 0x00000000}},  //   lišk, ndář_, _dooy,
  { {0x32090058, 0x290d00c4, 0x44651602, 0x00000000}},  //   _abay_, _ipea_, рвов,
  { {0x62861603, 0x60c4010f, 0xe29a012b, 0x00000000}},  //   toko, _stim, као_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x628601d9, 0xe44e0131, 0x2d8f01a2, 0x00000000}},  //   roko, _дж_, ügel_,
  { {0x3209001c, 0x9f58000c, 0x25bf1604, 0x00000000}},  //   _ebay_, ferð_, lcul_,
  { {0x8fa60265, 0xb5fd00d0, 0x62860142, 0x00000000}},  //   раве, jišk, poko,
  { {0xb5fd0b4d, 0x13da0055, 0x64430abe, 0x00000000}},  //   dišk, _দায়, _honi,
  { {0x64431605, 0xbc661606, 0x60c400e7, 0x00000000}},  // [2b00] _koni, авак, _utim,
  { {0x7d160343, 0x64430006, 0x78a30009, 0x00000000}},  //   rwys, _joni, jmnv,
  { {0xb5fd0006, 0xe9da0cee, 0x00000000, 0x00000000}},  //   gišk, вке_,   ,
  { {0xa9260102, 0x539a00b3, 0x62870fcd, 0x00000000}},  //   идел, דיעו, čkog,
  { {0x6728003b, 0x764201d6, 0xd3780091, 0x00000000}},  //   _srdj, _rooy, maće_,
  { {0xdb1c009f, 0x9866026c, 0x6aa201aa, 0x00000000}},  //   _ferð, جیئے_, smof,
  { {0xd6d704af, 0xdb1c009f, 0x290d002d, 0x00000000}},  //   аты_, _gerð, _epea_,
  { {0x963400e1, 0xd01f0044, 0x960a007e, 0x00000000}},  //   сниц, দায়_, тэка_,
  { {0x3ce01607, 0xd90e00a6, 0x993400a1, 0x00000000}},  //   nsiv_, _آیت_, _دہشت,
  { {0x656f1608, 0x27e50022, 0x32090058, 0x00000000}},  //   úcha, _gdln_, _sbay_,
  { {0x0bb700b6, 0x6f090046, 0xc5e80055, 0x00000000}},  //   ילים_, łecz, ক্ষা_,
  { {0xd3780107, 0x9f58000c, 0x21290340, 0x00000000}},  //   jaće_, verð_, _prah_,
  { {0xdfdb0265, 0xc693009b, 0x64430016, 0x00000000}},  //   къв_, _ואף_, _foni,
  { {0x644300d0, 0xd48f0088, 0xe0df0026, 0x00000000}},  //   _goni, _єр_, rsò_,
  { {0x09d70055, 0xe0df0c42, 0xb346006b, 0x00000000}},  //   _হাসা, ssò_, _qaçı,
  { {0xb5fd010a, 0x877b0049, 0x443e00f8, 0x00000000}},  //   višk, דאלי, ljt_,
  { {0x64430022, 0x2d8f0030, 0x8bb70025, 0x00000000}},  // [2b10] _yoni, æge_, لإضا,
  { {0xb5fd0006, 0x270e006b, 0xa8020477, 0x00000000}},  //   tišk, _kənd_, çıla,
  { {0xf2d30049, 0xd3780521, 0x95ff0044, 0x00000000}},  //   ַעס_, baće_, ্যতম_,
  { {0xdb1c0359, 0xb5fd09f4, 0x270e006b, 0x00000000}},  //   _verð, rišk, _zəng_,
  { {0x634a005f, 0xb5fd010a, 0x728a0049, 0x00000000}},  //   lənd, sišk, נננְ,
  { {0x893401d8, 0x1ed80167, 0xb5fd0006, 0x00000000}},  //   تعما, _حبیب_, pišk,
  { {0x81e20055, 0x64431609, 0x36690ca6, 0x00000000}},  //   ন্ট_, _roni, лако_,
  { {0x64430211, 0x80b80055, 0x7e6d0035, 0x00000000}},  //   _soni, _অবস্, niap,
  { {0x64430046, 0x6d4d04cb, 0x25bf001a, 0x00000000}},  //   _poni, nyaa, rcul_,
  { {0x645a00ab, 0x25bf160a, 0x7e6d160b, 0x00000000}},  //   ghti, scul_, hiap,
  { {0xd7950054, 0xe1ff0010, 0x64430006, 0x00000000}},  //   _الاخ, ciók_, _voni,
  { {0xc049061e, 0x644300c1, 0x634a006b, 0x00000000}},  //   _אז_, _woni, dənd,
  { {0x7e6d0cfe, 0xd3780107, 0x2ba70061, 0x00000000}},  //   diap, vaće_, केता,
  { {0x645a160c, 0x46130014, 0x00000000, 0x00000000}},  //   chti, _دوچر,   ,
  { {0xd3780521, 0xddc40035, 0x634a013f, 0x00000000}},  //   taće_, ghiş, gənd,
  { {0x765b160d, 0x7e6d0d96, 0x00000000, 0x00000000}},  //   nhuy, giap,   ,
  { {0xd3780107, 0x6da30920, 0x26c2012d, 0x00000000}},  // [2b20] raće_, зита, _čkom_,
  { {0x3ce000ea, 0xd3780521, 0x00000000, 0x00000000}},  //   rsiv_, saće_,   ,
  { {0xff260140, 0x6d4d04cb, 0xeafa0431, 0x00000000}},  //   _умно, ayaa, طرات_,
  { {0xeb970e09, 0xddcd001a, 0x00000000, 0x00000000}},  //   щих_, rnaţ,   ,
  { {0xdd920084, 0x2d8400f4, 0x645a00b0, 0x00000000}},  //   _روس_, _âme_, yhti,
  { {0x6e24002d, 0x13af0044, 0x7d04094f, 0x00000000}},  //   ldib, চুয়, mtis,
  { {0x7d040207, 0x09d70044, 0x6b63005e, 0x00000000}},  //   ltis, _হারা, _екра,
  { {0x6e24059a, 0xceb300b6, 0x645d0065, 0x00000000}},  //   ndib, היה_, ësin,
  { {0xb05b00b0, 0x645a0023, 0x00000000, 0x00000000}},  //   späi, thti,   ,
  { {0x634a005f, 0x7bde04be, 0x7d040051, 0x00000000}},  //   yənd, napu, itis,
  { {0x53980088, 0x7d0403b6, 0x9f45005a, 0x00000000}},  //   рвня_, htis, ülü_,
  { {0x645a008d, 0x7bde04cb, 0x7ae3008e, 0x00000000}},  //   shti, hapu, ánti,
  { {0x7bde011c, 0x68e2160e, 0xc05b0088, 0x00000000}},  //   kapu, nsod, гів_,
  { {0x80b80055, 0x634a005f, 0x7bde0052, 0x00000000}},  //   _অবশ্, tənd, japu,
  { {0x7e6d0032, 0x7bde160f, 0x9f5801aa, 0x00000000}},  //   tiap, dapu, ngrè_,
  { {0x7d0401e5, 0x634a006b, 0xdceb0142, 0x00000000}},  //   ftis, rənd, žičk,
  { {0x7d041002, 0x7e6d1610, 0x6f1e00fa, 0x00000000}},  // [2b30] gtis, riap, _espc,
  { {0x7e6d1611, 0xb5fd016e, 0x7bde027c, 0x00000000}},  //   siap, riši, gapu,
  { {0x2004006b, 0x6d4d01a3, 0x7e6d0c1b, 0x00000000}},  //   əmi_, syaa, piap,
  { {0xb5fd07a0, 0x7d1d0058, 0x02fb0049, 0x00000000}},  //   piši, _tsss, רלאמ,
  { {0xe9d8008b, 0x64580219, 0x7d0402a4, 0x00000000}},  //   скі_, _olvi, ctis,
  { {0x7bde00d6, 0xe9d90036, 0x7e7d1612, 0x00000000}},  //   capu, _weź_, _hjsp,
  { {0x07a20517, 0x765b0082, 0x70b5013d, 0x00000000}},  //   машн, thuy, ंदुल,
  { {0x245b028c, 0x64580181, 0xb658007e, 0x00000000}},  //   _même_, _alvi, йшых_,
  { {0xe4590794, 0x69db0016, 0x81bf0044, 0x00000000}},  //   ижи_, _ieue, ইরা_,
  { {0xdb1c05e9, 0x69db01a2, 0x395200ea, 0x00000000}},  //   _verö, _heue, øyse_,
  { {0x7af701f3, 0x7c250048, 0x00000000, 0x00000000}},  //   nuxt, idhr,   ,
  { {0x7de60010, 0x7d04000c, 0xdb1c014a, 0x00000000}},  //   _késő, ytis, _terö,
  { {0x7bde09e4, 0x3eba1613, 0x69db00d4, 0x00000000}},  //   yapu, _supt_, _meue,
  { {0x9f5800f4, 0x69db0007, 0x66091614, 0x00000000}},  //   lgré_, _leue, lfek,
  { {0xe29a0680, 0x1faa081e, 0x75291615, 0x00000000}},  //   _как_, ркви_, lvez,
  { {0x69db001f, 0xe1ff0036, 0x7d040e2d, 0x00000000}},  //   _neue, diów_, ttis,
  { {0x7bde1616, 0x1c46005e, 0x7d0400b0, 0x00000000}},  // [2b40] tapu, онам, utis,
  { {0x7659018e, 0x7d040038, 0x6e2406c2, 0x00000000}},  //   _llwy, rtis, sdib,
  { {0x20180207, 0x9f060076, 0x69db1617, 0x00000000}},  //   meri_, _بوجو, _beue,
  { {0x20181355, 0x7ff602fd, 0x7bde0ed1, 0x00000000}},  //   leri_, _اسکا, sapu,
  { {0xcaa50054, 0x7bde04d4, 0x69db00d4, 0x00000000}},  //   أصلي, papu, _deue,
  { {0x20180208, 0xab2a1618, 0x75290010, 0x00000000}},  //   neri_, _кога_, dvez,
  { {0xf8bf02ae, 0x69db010f, 0x68e2002b, 0x00000000}},  //   _één_, _feue, ssod,
  { {0xe3b8047f, 0x7bdc01e7, 0x76590016, 0x00000000}},  //   rdım_, _heru, _clwy,
  { {0x7bdc020c, 0x2018014a, 0xdb2100b0, 0x00000000}},  //   _keru, keri_, ätös,
  { {0xddc40b41, 0x2018016e, 0x3a240146, 0x00000000}},  //   jniž, jeri_, _hamp_,
  { {0x7bdc0149, 0x3a240030, 0x7659018e, 0x00000000}},  //   _meru, _kamp_, _flwy,
  { {0xbddb00f4, 0x6abc00e5, 0x75290059, 0x00000000}},  //   _poèm, _murf, bvez,
  { {0xe3af026c, 0x29061619, 0xddcd00b9, 0x00000000}},  //   ٹری_, ntoa_, chař,
  { {0x20180281, 0xe3af025a, 0x270e006b, 0x00000000}},  //   geri_, عری_, _gənc_,
  { {0xcddb00e1, 0xff040783, 0x04200044, 0x00000000}},  //   иња_, мятн, বাদী_,
  { {0x7bdc001a, 0xb3bc0044, 0x29060032, 0x00000000}},  //   _aeru, _আজিজ, ktoa_,
  { {0x7bdc0281, 0x2018161a, 0x69db00d9, 0x00000000}},  // [2b50] _beru, beri_, _reue,
  { {0x2018161b, 0xb5fd0209, 0x7bdc001a, 0x00000000}},  //   ceri_, lišt, _ceru,
  { {0x7bdc161c, 0x20010016, 0x6abc161d, 0x00000000}},  //   _deru, _ichi_, _curf,
  { {0x61fd0292, 0xb5fd0340, 0x3a2401cb, 0x00000000}},  //   ngsl, ništ, _camp_,
  { {0x3ea9021e, 0x3a2400eb, 0x61fd161e, 0x00000000}},  //   mmat_, _damp_, igsl,
  { {0x7bdc00c7, 0x3ea90ae4, 0xb5fd0059, 0x00000000}},  //   _geru, lmat_, hišt,
  { {0x7bc5161f, 0x69db010f, 0x645d0065, 0x00000000}},  //   mchu, _teue, ësim,
  { {0xe9df009f, 0xb5fd1620, 0x7bdc002d, 0x00000000}},  //   _þú_, jišt, _zeru,
  { {0xb5fd036a, 0x1a680cd9, 0x3e7701d5, 0x00000000}},  //   dišt, _بینی_, għti_,
  { {0x2001000b, 0x75290047, 0x7bc50051, 0x00000000}},  //   _nchi_, rvez, nchu,
  { {0x7ae50065, 0x7bc5010f, 0x3ea904cb, 0x00000000}},  //   nsht, ichu, kmat_,
  { {0x212000ca, 0x61fd00f8, 0x7bc50048, 0x00000000}},  //   _psih_, ggsl, hchu,
  { {0x20181092, 0x55ba009b, 0x3ea90127, 0x00000000}},  //   teri_, _המנו, dmat_,
  { {0x2a7f07d1, 0xb5fd016c, 0x394000b0, 0x00000000}},  //   _ljub_, rišu, äisi_,
  { {0x4375007b, 0x2018001a, 0x634a006b, 0x00000000}},  //   _מײַן_, reri_, rənc,
  { {0x7bdc033b, 0x3ea900ea, 0x20010638, 0x00000000}},  //   _seru, gmat_, _echi_,
  { {0x7bdc04d4, 0x2018008d, 0x3a24046a, 0x00000000}},  // [2b60] _peru, peri_, _ramp_,
  { {0x8fa601a4, 0x20180065, 0x6abc0544, 0x00000000}},  //   _напе, qeri_, _purf,
  { {0x7bdc012b, 0x3a2400e0, 0x68f900bb, 0x00000000}},  //   _veru, _pamp_, euwd,
  { {0x7bdc1621, 0xda65006d, 0x290600b0, 0x00000000}},  //   _weru, واني, ttoa_,
  { {0x3a26040f, 0x29060883, 0xf9180014, 0x00000000}},  //   rdop_, utoa_, تراژ_,
  { {0x7bc501d6, 0x7c5a0025, 0x6e26011c, 0x00000000}},  //   cchu, _السر_, _hakb,
  { {0x29061622, 0x6e260460, 0xdc370049, 0x00000000}},  //   stoa_, _kakb, _צאלט_,
  { {0xb86600e9, 0xa534003b, 0x6e260036, 0x00000000}},  //   _کارو, днич, _jakb,
  { {0xb5fd00b9, 0x04200044, 0x6e260095, 0x00000000}},  //   višt, বাসী_, _makb,
  { {0x22490784, 0x3ea90023, 0xe9ff0082, 0x00000000}},  //   _soak_, zmat_, _toản_,
  { {0xb5fd013e, 0x04fe0044, 0xe9ff0082, 0x00000000}},  //   tišt, ্টের_, _hoạn_,
  { {0x20011623, 0x76bb009b, 0x6e260288, 0x00000000}},  //   _schi_, _המאפ, _nakb,
  { {0xb5fd0091, 0x321913c2, 0x61fd0239, 0x00000000}},  //   rišt, resy_, rgsl,
  { {0x75221624, 0x04200044, 0x00000000, 0x00000000}},  //   _isoz, বাহী_,   ,
  { {0xb5fd00b9, 0xe9ff0011, 0x6e2604d3, 0x00000000}},  //   pišt, _loạn_, _bakb,
  { {0x5f940088, 0x5eb4058e, 0x644a0657, 0x00000000}},  //   хист, ейст, _hofi,
  { {0x61ed0107, 0x628f0142, 0x644a00e7, 0x00000000}},  // [2b70] _idal, moco, _kofi,
  { {0x5ba700ed, 0x60cd1335, 0x628f00c4, 0x00000000}},  //   през, _itam, loco,
  { {0x7bc51625, 0xa1340123, 0xe7a50089, 0x00000000}},  //   rchu, _قریش, ādīš,
  { {0x7bc51626, 0x7ae5008d, 0x628f1627, 0x00000000}},  //   schu, rsht, noco,
  { {0xa95401fb, 0x61ed0eb0, 0x00000000, 0x00000000}},  //   нкці, _mdal,   ,
  { {0xf7700a90, 0x60cd0020, 0x644a1628, 0x00000000}},  //   گاه_, _mtam, _nofi,
  { {0x16a90264, 0x61ed014a, 0xab950088, 0x00000000}},  //   овки_, _odal, _циві,
  { {0x61ed008d, 0x60cd002d, 0x7c271002, 0x00000000}},  //   _ndal, _otam, _hajr,
  { {0x68e40051, 0x60cd1629, 0x644a00d4, 0x00000000}},  //   áidt, _ntam, _bofi,
  { {0x61ed020c, 0x644a018e, 0x55ff0044, 0x00000000}},  //   _adal, _cofi, ্যেক_,
  { {0x5884008b, 0x60cd162a, 0x644a00b4, 0x00000000}},  //   _чыта, _atam, _dofi,
  { {0x60cd0009, 0x00000000, 0x00000000, 0x00000000}},  //   _btam,   ,   ,
  { {0x61ed0016, 0x644a162b, 0x98a4001a, 0x00000000}},  //   _ddal, _fofi, _urmă_,
  { {0x7c270142, 0x764b162c, 0x661b11fe, 0x00000000}},  //   _najr, _hogy, leuk,
  { {0x4427001a, 0x628f04d4, 0x92e80025, 0x00000000}},  //   _ian_, boco, _فريق_,
  { {0x661b162d, 0x764b04be, 0xbea3003b, 0x00000000}},  //   neuk, _jogy, васк,
  { {0xfce30057, 0x1d0701fc, 0x7c270065, 0x00000000}},  // [2b80] кото, мети_, _bajr,
  { {0x4427060b, 0x61ed07e4, 0xb05b0614, 0x00000000}},  //   _jan_, _zdal, spär,
  { {0x4427162e, 0xe1ff162f, 0xe9ff0011, 0x00000000}},  //   _man_, ciós_, _soạn_,
  { {0x44271630, 0xe1ff0036, 0x7c270032, 0x00000000}},  //   _lan_, chód_, _eajr,
  { {0xe3e30055, 0x44270011, 0x3e77002b, 0x00000000}},  //   _মানব, _oan_, għtu_,
  { {0x44271631, 0xd943003b, 0x00000000, 0x00000000}},  //   _nan_, тељи,   ,
  { {0x644a0635, 0x69c901cf, 0x628f10c9, 0x00000000}},  //   _rofi, _ffee, yoco,
  { {0x4427049b, 0x644a0039, 0x661b0020, 0x00000000}},  //   _aan_, _sofi, geuk,
  { {0x442702d4, 0xe7cf0164, 0xd7cf007d, 0x00000000}},  //   _ban_, _स्वप, _स्वच,
  { {0x44270a8a, 0x00000000, 0x00000000, 0x00000000}},  //   _can_,   ,   ,
  { {0x44270149, 0x60cd0198, 0x764b0047, 0x00000000}},  //   _dan_, _stam, _fogy,
  { {0x4427022b, 0x9258007c, 0xc7b80166, 0x00000000}},  //   _ean_, дают_, _nađi_,
  { {0x628f1632, 0xe1ff147e, 0x644a006b, 0x00000000}},  //   roco, rgó_, _tofi,
  { {0x44271633, 0x628f0197, 0xa3df007d, 0x00000000}},  //   _gan_, soco, तरण_,
  { {0x764b0390, 0xe5800089, 0x00000000, 0x00000000}},  //   _yogy, šķā_,   ,
  { {0x61ed1634, 0x13e30055, 0x44271635, 0x00000000}},  //   _udal, _মায়, _zan_,
  { {0x4427006a, 0x60cd1636, 0x6e94004c, 0x00000000}},  // [2b90] _yan_, _utam, титу,
  { {0x69c900c1, 0x4427006b, 0x4cc80044, 0x00000000}},  //   _sfee, _xan_, _লিখু,
  { {0x68e90255, 0x634a006b, 0x7c270ede, 0x00000000}},  //   _sved, zənn, _vajr,
  { {0xdd910879, 0xdb0e0010, 0x37d80044, 0x00000000}},  //   _موج_, áján, _সাগর,
  { {0xcce70025, 0xe6ed0027, 0x7c270066, 0x00000000}},  //   _تسجي, _väčš, _tajr,
  { {0x3eb9049a, 0x07a504f9, 0xa158009b, 0x00000000}},  //   _hist_, налн, ובדה_,
  { {0x4427018e, 0x3eb91637, 0x00000000, 0x00000000}},  //   _ran_, _kist_,   ,
  { {0x44270071, 0xd0280044, 0x1995007e, 0x00000000}},  //   _san_, মায়_, _забя,
  { {0x68e9004f, 0x3eb9054e, 0xe579007c, 0x00000000}},  //   _uved, _mist_, язи_,
  { {0x3eb90038, 0x44271638, 0x98ad016c, 0x00000000}},  //   _list_, _qan_, _kreč_,
  { {0x4427049b, 0xe29a00c0, 0x2d9908e0, 0x00000000}},  //   _van_, зан_, _lyse_,
  { {0x442701a3, 0x80d40044, 0x3eb901ed, 0x00000000}},  //   _wan_, _তিব্, _nist_,
  { {0xdb1c0039, 0x4427060b, 0x634a006b, 0x00000000}},  //   _ifrå, _tan_, lənl,
  { {0x44270093, 0x00000000, 0x00000000, 0x00000000}},  //   _uan_,   ,   ,
  { {0x3eb9010f, 0x66c7014a, 0x322900b0, 0x00000000}},  //   _bist_, _yıka, ötyä_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61e60996, 0x3eb90555, 0x6e9300f3, 0x00000000}},  // [2ba0] makl, _dist_, القا,
  { {0x61e6066b, 0x4f261534, 0x3eb900bb, 0x00000000}},  //   lakl, _здоб, _eist_,
  { {0x09d70055, 0xb3460181, 0x20c60011, 0x00000000}},  //   _হাজা, maçõ, _hôi_,
  { {0x2cb8001f, 0xb3460181, 0x61e6014a, 0x00000000}},  //   _wird_, laçõ, nakl,
  { {0x2d990146, 0x00000000, 0x00000000, 0x00000000}},  //   _gyse_,   ,   ,
  { {0x20c6001d, 0xeee7007a, 0xd6da005e, 0x00000000}},  //   _môi_, _تغیی, пти_,
  { {0xf09300a3, 0x20c60011, 0x61e61109, 0x00000000}},  //   אנג_, _lôi_, kakl,
  { {0x3546017f, 0x61e61639, 0x7e6400e7, 0x00000000}},  //   ехов, jakl, nhip,
  { {0x7afe163a, 0x61e6163b, 0x20c60082, 0x00000000}},  //   lupt, dakl, _nôi_,
  { {0x54540113, 0xdb1c0023, 0x00000000, 0x00000000}},  //   твот, _ngrë,   ,
  { {0xb34600c4, 0x66c70095, 0x00000000, 0x00000000}},  //   daçõ, _tıka,   ,
  { {0xa75b034e, 0x20c60011, 0x634a006b, 0x00000000}},  //   _מדבר, _bôi_, səno,
  { {0x5184003b, 0xc68f00a1, 0x20c60082, 0x00000000}},  //   гура, _اِن_, _côi_,
  { {0xb3460181, 0x634a006b, 0x3eb901c9, 0x00000000}},  //   gaçõ, lənm, _sist_,
  { {0x61e6163c, 0x443c0716, 0x61f40039, 0x00000000}},  //   bakl, _inv_, ådlö,
  { {0x61e6011f, 0x78ba163d, 0x645d0065, 0x00000000}},  //   cakl, _litv, ësiv,
  { {0x442c018e, 0x4f5800a1, 0x3f9e000c, 0x00000000}},  // [2bb0] odd_, وجہد_, ýtur_,
  { {0xb34602d5, 0x634a006b, 0x3eb900b5, 0x00000000}},  //   caçõ, yənl, _wist_,
  { {0x442c163e, 0x2d990007, 0x7afe01f3, 0x00000000}},  //   idd_, _wyse_, gupt,
  { {0x7e640035, 0x7c3c12b2, 0x2003163f, 0x00000000}},  //   chip, _enrr, lgji_,
  { {0x6e3d010f, 0x20c60082, 0x78ba00b9, 0x00000000}},  //   _insb, _xôi_, _bitv,
  { {0xa3bc03d7, 0x6e2d000c, 0x7d0d007f, 0x00000000}},  //   _अलग_, ldab, mtas,
  { {0x7d0d1640, 0xddcd001a, 0x81e70044, 0x00000000}},  //   ltas, ciaţ, _পান_,
  { {0x442c018e, 0xb3460181, 0x7f3c0049, 0x00000000}},  //   edd_, zaçõ, לעוו,
  { {0xc4850088, 0x12bd0044, 0x2c640039, 0x00000000}},  //   клик, _আবেদ, _född_,
  { {0x443c0a8b, 0x69d901a2, 0x00000000, 0x00000000}},  //   _cnv_, lbwe,   ,
  { {0x61e6009f, 0x7d0d006c, 0x06f40076, 0x00000000}},  //   takl, htas, _مسنج,
  { {0x27e708cc, 0x7d0d014a, 0x443c009d, 0x00000000}},  //   lann_, ktas, _env_,
  { {0xb3460181, 0x61e6014a, 0x443c0f0a, 0x00000000}},  //   taçõ, rakl, _fnv_,
  { {0x27e7002a, 0x7d0d0030, 0x10a61641, 0x00000000}},  //   nann_, dtas, тигн,
  { {0xb34602d5, 0xdee30081, 0x7d0d0026, 0x00000000}},  //   raçõ, иори, etas,
  { {0x20c600ad, 0x27e71642, 0x6d44002d, 0x00000000}},  //   _tôi_, hann_, txia,
  { {0x7d0d011c, 0xb3460181, 0x27e7000c, 0x00000000}},  // [2bc0] gtas, paçõ, kann_,
  { {0x61e405d1, 0xe3b8027d, 0x3f9a08d2, 0x00000000}},  //   _heil, mdır_, _typu_,
  { {0xbddb0f57, 0x27e71643, 0x09e600da, 0x00000000}},  //   _poèt, dann_, воен,
  { {0x7afe121e, 0x60c40020, 0x6abb07ae, 0x00000000}},  //   rupt, _kuim, _ciuf,
  { {0x442c0bc4, 0x61e4028c, 0xe3b80279, 0x00000000}},  //   ydd_, _meil, ndır_,
  { {0xcee906c6, 0x27e7002a, 0x61e40181, 0x00000000}},  //   _ترین_, gann_, _leil,
  { {0xa7fc005a, 0x60c40051, 0x78ba00f8, 0x00000000}},  //   _alıc, _luim, _vitv,
  { {0xfaa60069, 0x61e4006c, 0x442c018e, 0x00000000}},  //   _рабо, _neil, wdd_,
  { {0x27e71644, 0x090600ec, 0x47e10055, 0x00000000}},  //   bann_, _шпан, _নারী,
  { {0x78ba049b, 0xdb1c00f4, 0x27e70051, 0x00000000}},  //   _uitv, _agré, cann_,
  { {0x442c018e, 0x7d0d1645, 0xa279003b, 0x00000000}},  //   rdd_, ztas, ебну_,
  { {0xd3780166, 0x7d0d000c, 0x443c0b3d, 0x00000000}},  //   naći_, ytas, _wnv_,
  { {0x61e4009f, 0x60c4002a, 0xd251025a, 0x00000000}},  //   _deil, _cuim, لنگ_,
  { {0x2bfe0309, 0x645d0065, 0x443c00d9, 0x00000000}},  //   _लागू_, ësit, _unv_,
  { {0x61e40056, 0x20030065, 0x260f006e, 0x00000000}},  //   _feil, rgji_, थ्वी_,
  { {0x7d0d0635, 0x61e41440, 0x60c4008e, 0x00000000}},  //   ttas, _geil, _fuim,
  { {0x60c40181, 0x27e70058, 0x7d0d1646, 0x00000000}},  // [2bd0] _guim, yann_, utas,
  { {0x7d0d022b, 0x6aa90065, 0x61e405c6, 0x00000000}},  //   rtas, _shef, _zeil,
  { {0x7d0d0004, 0x27e71647, 0xddc60036, 0x00000000}},  //   stas, vann_, _dokł,
  { {0x27e7010f, 0x99d4006d, 0x21290085, 0x00000000}},  //   wann_, لتها, _ksah_,
  { {0xe9d80ee0, 0x27e71648, 0xee3f0142, 0x00000000}},  //   ткі_, tann_, _iný_,
  { {0xfa230044, 0xd7091649, 0x00000000, 0x00000000}},  //   ফাইল_, енке_,   ,
  { {0x27e70263, 0x12bd0055, 0xe3b8005a, 0x00000000}},  //   rann_, _আব্দ, zdır_,
  { {0x27e70263, 0xddcd001e, 0x9980049c, 0x00000000}},  //   sann_, skaņ, žiš_,
  { {0x61e400b0, 0x27e701aa, 0xf8070088, 0x00000000}},  //   _reil, pann_, _ачен,
  { {0x61e41014, 0x60c4015c, 0xe3e30055, 0x00000000}},  //   _seil, _ruim, _মাহব,
  { {0x60c4164a, 0x65690010, 0x91e6004d, 0x00000000}},  //   _suim, szeh, лоне,
  { {0xe3b8006b, 0x00000000, 0x00000000, 0x00000000}},  //   tdır_,   ,   ,
  { {0x61e402ae, 0x645d008d, 0x60c40211, 0x00000000}},  //   _veil, ësis, _quim,
  { {0xe3b801f6, 0x61e4010f, 0x26c508e3, 0x00000000}},  //   rdır_, _weil, _kulo_,
  { {0x61e4164b, 0x99750036, 0x21290145, 0x00000000}},  //   _teil, nęło_, _esah_,
  { {0x26c50026, 0x60c40755, 0x3a2d00d2, 0x00000000}},  //   _mulo_, _tuim, _naep_,
  { {0x0eb904af, 0x4c860265, 0xe3b8006b, 0x00000000}},  // [2be0] туры_, глав, qdır_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26c5164c, 0x2240040f, 0xfaa6003b, 0x00000000}},  //   _nulo_, _knik_, гажо,
  { {0x3ce80316, 0x1efb0049, 0xc986005e, 0x00000000}},  //   _चौथे_, _אלטע, лули,
  { {0xed57004d, 0xf99201b7, 0xc27b071c, 0x00000000}},  //   _боя_, حبا_, ערני,
  { {0x3ea0164d, 0x66c7011f, 0xf772026c, 0x00000000}},  //   llit_, _tıkl, یاں_,
  { {0x26c50e1d, 0xd3780243, 0x22400032, 0x00000000}},  //   _culo_, paći_, _onik_,
  { {0x7c2e0211, 0x3ea0000c, 0x26c5011c, 0x00000000}},  //   _habr, nlit_, _dulo_,
  { {0x634a005f, 0x290f001c, 0x7c2e01aa, 0x00000000}},  //   məni, ctga_, _kabr,
  { {0x634a005f, 0x22400058, 0x24520035, 0x00000000}},  //   ləni, _anik_, _câmp_,
  { {0x360605f3, 0x3ea0006c, 0x26c5011c, 0x00000000}},  //   _مواف, klit_, _gulo_,
  { {0x21b501fb, 0xdbdf000c, 0xa2950245, 0x00000000}},  //   ийня, _líðu, рамі,
  { {0x667b0049, 0x463b0049, 0x067b0097, 0x00000000}},  //   _אטאק, _רעדע, _אנאל,
  { {0x7c2e0091, 0x3e67006c, 0x634a006b, 0x00000000}},  //   _nabr, _mõte_, həni,
  { {0x634a005f, 0x442e0039, 0x316b0036, 0x00000000}},  //   kəni, _iaf_, szcz_,
  { {0x442e0016, 0x3ea00d9c, 0x7c2e00e0, 0x00000000}},  //   _haf_, glit_, _aabr,
  { {0x3cee03d7, 0x634a005f, 0x9f4300b9, 0x00000000}},  // [2bf0] ेंगे_, dəni, mají_,
  { {0x442e002b, 0x3ea000b0, 0x9f4300b9, 0x00000000}},  //   _jaf_, alit_, lají_,
  { {0x2baa001c, 0x442e00d9, 0x3ea0164e, 0x00000000}},  //   _करणा, _maf_, blit_,
  { {0x9f4300b9, 0x442e0095, 0x3ea000e5, 0x00000000}},  //   nají_, _laf_, clit_,
  { {0xd945007c, 0xd37804eb, 0x00000000, 0x00000000}},  //   рели, maću_,   ,
  { {0x442e002b, 0x26c51577, 0x2c14007d, 0x00000000}},  //   _naf_, _pulo_, न्दू_,
  { {0xf77103ec, 0x366903f3, 0x270e006b, 0x00000000}},  //   غات_, како_, _yəni_,
  { {0x7c2e037b, 0xbb840054, 0x2baa001c, 0x00000000}},  //   _zabr, _الفي, _करता,
  { {0x81eb0055, 0x9f4300b9, 0x442e164f, 0x00000000}},  //   মলা_, dají_, _baf_,
  { {0x26c51449, 0xf8b90076, 0x22401650, 0x00000000}},  //   _tulo_, _شهاب_, _snik_,
  { {0xd3780107, 0x52aa003b, 0x53a500e2, 0x00000000}},  //   kaću_, квом_, ранб,
  { {0x67b800f9, 0xcb12009b, 0x442e0dfc, 0x00000000}},  //   _صالح_, חלט_, _eaf_,
  { {0x442e1651, 0xd37804eb, 0x00000000, 0x00000000}},  //   _faf_, daću_,   ,
  { {0x442e1652, 0x270e006b, 0x05a80088, 0x00000000}},  //   _gaf_, _səni_, _свій_,
  { {0x634a006b, 0xa2a70061, 0xdee60088, 0x00000000}},  //   yəni, _टीव्, роби,
  { {0xdbdf009f, 0x7c2e01a3, 0x22400390, 0x00000000}},  //   _síðu, _sabr, _unik_,

  { {0x7c2e023a, 0x3ea0000c, 0x645c1653, 0x00000000}},  // [2c00] _pabr, rlit_, örig,
  { {0xa7fc01f6, 0x3ea01654, 0x00000000, 0x00000000}},  //   _alın, slit_,   ,
  { {0x62870428, 0x634a006b, 0xd3780521, 0x00000000}},  //   čkov, təni, baću_,
  { {0xeb970373, 0x628611b2, 0x2c640039, 0x00000000}},  //   ших_, nnko, _döda_,
  { {0x7c2e0093, 0x634a006b, 0x62860cba, 0x00000000}},  //   _tabr, rəni, inko,
  { {0x7d04000b, 0xceb4006b, 0x6e24010f, 0x00000000}},  //   muis, lmə_, leib,
  { {0x7d04021e, 0xa2ca0164, 0x00000000, 0x00000000}},  //   luis, _संध्,   ,
  { {0x442e019a, 0x95d7005e, 0x634a006b, 0x00000000}},  //   _saf_, адът_, qəni,
  { {0x9f4300b9, 0x7d04009d, 0x442e1655, 0x00000000}},  //   vají_, nuis, _paf_,
  { {0x62861656, 0x6e24010f, 0xb8060014, 0x00000000}},  //   enko, heib, _خبره,
  { {0x7d040007, 0x4394025f, 0x1c0b013d, 0x00000000}},  //   huis, санс, स्टल_,
  { {0x7d0400b0, 0x442e0173, 0x628600ea, 0x00000000}},  //   kuis, _waf_, gnko,
  { {0x442e09e2, 0xe4d4025a, 0x61f6018e, 0x00000000}},  //   _taf_, _اقتد, _ddyl,
  { {0xdb1c0df5, 0x7d0400f4, 0x03770123, 0x00000000}},  //   _agrí, duis, احیت_,
  { {0x60d600ea, 0xf0b40088, 0xd3780521, 0x00000000}},  //   _etym, ійсь, taću_,
  { {0x2c640039, 0x5f94003b, 0xdce6014a, 0x00000000}},  //   _röda_, цист, _aykı,
  { {0xa2ca007d, 0x7d0400f4, 0xd90402fd, 0x00000000}},  // [2c10] _सूत्, guis, _تی_,
  { {0x80dd0044, 0xd3780645, 0x00000000, 0x00000000}},  //   _বিপ্, saću_,   ,
  { {0x5b150679, 0x00000000, 0x00000000, 0x00000000}},  //   смет,   ,   ,
  { {0xe8f50025, 0x7d040207, 0x6aa201ee, 0x00000000}},  //   مستخ, buis, glof,
  { {0x3cfe03d7, 0xb927007c, 0x7d04009d, 0x00000000}},  //   _लिये_, рфей, cuis,
  { {0xf1bf0010, 0x00000000, 0x00000000, 0x00000000}},  //   ldás_,   ,   ,
  { {0x81bf0044, 0xda350147, 0x62860024, 0x00000000}},  //   েরি_, _левы, ynko,
  { {0x7c251657, 0x80dd0044, 0xf1bf0010, 0x00000000}},  //   lehr, _বিন্, ndás_,
  { {0x673a01d6, 0x00000000, 0x00000000, 0x00000000}},  //   _ertj,   ,   ,
  { {0xb4650057, 0x9865026c, 0x81bf0044, 0x00000000}},  //   скол, _دیتے_, েরা_,
  { {0x6e241658, 0x673a00d9, 0x60d600b4, 0x00000000}},  //   yeib, _grtj, _stym,
  { {0x99800027, 0x6286002d, 0x00000000, 0x00000000}},  //   žiť_, unko,   ,
  { {0xf65200b6, 0x628602e1, 0xd5480380, 0x00000000}},  //   _מצא_, rnko, _نجوم_,
  { {0x7536007b, 0x1c030061, 0x200c006c, 0x00000000}},  //   _לאנד_, _लागल_, üdi_,
  { {0x44251659, 0x64431446, 0xceb4006b, 0x00000000}},  //   mel_, _inni, tmə_,
  { {0x7d040625, 0x752900e7, 0x00000000, 0x00000000}},  //   tuis, owez,   ,
  { {0x6e24010f, 0x752900b5, 0xceb4006b, 0x00000000}},  // [2c20] reib, nwez, rmə_,
  { {0x4425011f, 0x313700a0, 0x7d040dc9, 0x00000000}},  //   nel_, _פנים_, ruis,
  { {0x291f00b0, 0x7d040052, 0x00000000, 0x00000000}},  //   _apua_, suis,   ,
  { {0xa2ca02f4, 0x4425165a, 0x7d040c7e, 0x00000000}},  //   _संस्, hel_, puis,
  { {0x6443021e, 0x7d04051b, 0x660901b5, 0x00000000}},  //   _onni, quis, dgek,
  { {0xd90d00e9, 0xbb46165b, 0xab2a004d, 0x00000000}},  //   ئیل_, _легк, _йога_,
  { {0x44250390, 0xf1c80164, 0xfaa6007e, 0x00000000}},  //   del_, रखान, _гаво,
  { {0x44250250, 0x6609123b, 0x6443165c, 0x00000000}},  //   eel_, ggek, _anni,
  { {0x44250562, 0x896600da, 0xc966007e, 0x00000000}},  //   fel_, _укаж, _увай,
  { {0xe8d7009b, 0x290600e7, 0x00000000, 0x00000000}},  //   _לומר_, muoa_,   ,
  { {0x2f380173, 0xdc9b08cd, 0x00000000, 0x00000000}},  //   _nčg_, רייל,   ,
  { {0x32670920, 0x6443018e, 0x46690088, 0x00000000}},  //   стов, _enni, _крім_,
  { {0x4425165d, 0x2018002b, 0x00000000, 0x00000000}},  //   bel_, ffri_,   ,
  { {0x44250142, 0x27ee000c, 0xe81b0164, 0x00000000}},  //   cel_, nafn_, प्पा_,
  { {0x447b009b, 0x7c25013e, 0x00000000, 0x00000000}},  //   _תנוע, vehr,   ,
  { {0x7c25010f, 0x290600e7, 0x00000000, 0x00000000}},  //   wehr, kuoa_,   ,
  { {0xdc55012b, 0x463b0049, 0xa7fc014a, 0x00000000}},  // [2c30] овањ, נעמע, _alım,
  { {0xba3d00b9, 0x00000000, 0x00000000, 0x00000000}},  //   _lhůt,   ,   ,
  { {0x50d404e1, 0x212b018e, 0x99d70025, 0x00000000}},  //   _وزیر, lwch_, متشا,
  { {0x4425079a, 0x61ef0035, 0x2be90044, 0x00000000}},  //   zel_, nacl, খলেই_,
  { {0x4425165e, 0x212b018e, 0xa2bc0049, 0x00000000}},  //   yel_, nwch_, אמאט,
  { {0x4425077d, 0x7e6d165f, 0x27ee0016, 0x00000000}},  //   xel_, lhap, gafn_,
  { {0x44251660, 0x2bdf02d2, 0xb8d0007d, 0x00000000}},  //   vel_, _प्या, _टी_,
  { {0x44251661, 0x628d012d, 0x0f7c009b, 0x00000000}},  //   wel_, _njao, טרול,
  { {0x66090007, 0x75290b43, 0x395200ea, 0x00000000}},  //   rgek, uwez, øyst_,
  { {0x6609144a, 0x212b018e, 0x44250bed, 0x00000000}},  //   sgek, dwch_, uel_,
  { {0x224a02b3, 0x7e6d017b, 0x634a013f, 0x00000000}},  //   апни_, khap, dəns,
  { {0x4425061f, 0xe29a06b6, 0xd6ab05d4, 0x00000000}},  //   sel_, рам_, _صدام_,
  { {0xa4f70167, 0x212b0016, 0x2f380087, 0x00000000}},  //   _اکبر_, gwch_, _sčg_,
  { {0x6443000c, 0x316c0036, 0x61ef0045, 0x00000000}},  //   _unni, ądz_, aacl,
  { {0x1fb51662, 0xae7a013a, 0xe81b01f5, 0x00000000}},  //   зстр, асах_, प्या_,
  { {0x00ca1663, 0x7e6d011c, 0x7bd500bb, 0x00000000}},  //   _клик_, ghap, _afzu,
  { {0x63a3018e, 0xf1bf0051, 0x9f4300c4, 0x00000000}},  // [2c40] _hynn, leán_, rajá_,
  { {0xad9b049a, 0x63a31664, 0xdb1c1665, 0x00000000}},  //   _acús, _kynn, _agrá,
  { {0x49ca1666, 0xddc40035, 0xad9b0048, 0x00000000}},  //   ален_, ghiţ, _scút,
  { {0x7e6d1667, 0x09e300ed, 0x63a31668, 0x00000000}},  //   chap, доцн, _mynn,
  { {0x63a301d6, 0x522d0049, 0x00000000, 0x00000000}},  //   _lynn, טואַ,   ,
  { {0x6e36010a, 0x7e640052, 0x00000000, 0x00000000}},  //   ldyb, lkip,   ,
  { {0x7d161669, 0x7c22012d, 0x61ef013f, 0x00000000}},  //   ltys, đord, yacl,
  { {0x27ee009f, 0xf1bf0051, 0x7bc70065, 0x00000000}},  //   safn_, deán_, _zgju,
  { {0xceb3019b, 0x7d160bd7, 0x61ef00d9, 0x00000000}},  //   ויה_, ntys, vacl,
  { {0x31e30183, 0x63a3018e, 0xb86604e8, 0x00000000}},  //   पर्ध, _bynn, _بارو,
  { {0x63a30bc4, 0x61ef0129, 0xe3b8014a, 0x00000000}},  //   _cynn, tacl, ldız_,
  { {0x212b018e, 0x63a30016, 0x00000000, 0x00000000}},  //   twch_, _dynn,   ,
  { {0xa2ca0309, 0x26cc166a, 0x00000000, 0x00000000}},  //   _सूर्, _hudo_,   ,
  { {0x80dd0055, 0x26cc0065, 0x212b0016, 0x00000000}},  //   _বিদ্, _kudo_, rwch_,
  { {0x63a3166b, 0x8f34166c, 0x7e6d0058, 0x00000000}},  //   _gynn, мерц, thap,
  { {0x26cc0325, 0x64580052, 0xa19501e1, 0x00000000}},  //   _mudo_, _hovi, _найч,
  { {0x629d0211, 0x645800b0, 0x7e6d166d, 0x00000000}},  // [2c50] moso, _kovi, rhap,
  { {0x61ed0038, 0x6458003b, 0x2ba7012b, 0x00000000}},  //   _heal, _jovi, ојев,
  { {0x64580866, 0x26cc166e, 0x60cd00e7, 0x00000000}},  //   _movi, _nudo_, _huam,
  { {0x6458001a, 0x7522166f, 0x60cd000b, 0x00000000}},  //   _lovi, _opoz, _kuam,
  { {0xcfbd0044, 0x6d4b0039, 0xd92b005e, 0x00000000}},  //   _অভিন, ågad, рцел_,
  { {0x61ed0066, 0x629d005b, 0x60cd12d9, 0x00000000}},  //   _leal, hoso, _muam,
  { {0x629d1670, 0x26cc1671, 0x25a9050f, 0x00000000}},  //   koso, _cudo_, _šal_,
  { {0x26cc1672, 0xdb1c0010, 0x61ed0471, 0x00000000}},  //   _dudo_, _ugrá, _neal,
  { {0x63a31673, 0x629d008e, 0x65600016, 0x00000000}},  //   _synn, doso, gymh,
  { {0xf1bf0051, 0x645801ed, 0x1309007c, 0x00000000}},  //   teán_, _covi, бной_,
  { {0x61ed1674, 0xbddb00f6, 0x752200f5, 0x00000000}},  //   _beal, _anèm, _epoz,
  { {0xf1bf002a, 0x629d0020, 0x61ed0fff, 0x00000000}},  //   reán_, goso, _ceal,
  { {0xf1bf002a, 0x63a3005b, 0x661b00e7, 0x00000000}},  //   seán_, _wynn, mfuk,
  { {0x653a007b, 0x645801c5, 0x63a30016, 0x00000000}},  //   _לענד, _govi, _tynn,
  { {0x1eaa023c, 0x61ed1675, 0xdfcf0380, 0x00000000}},  //   ماري_, _feal, ايف_,
  { {0x6446001e, 0x61ed0051, 0x7d160052, 0x00000000}},  //   ēkie, _geal, ttys,
  { {0xf1bf002a, 0x60cd01a3, 0x6e360190, 0x00000000}},  // [2c60] neál_, _guam, rdyb,
  { {0x7e641676, 0x61ed00ab, 0x76591677, 0x00000000}},  //   skip, _zeal, _lowy,
  { {0xe8050164, 0x7d161678, 0x6d4b0039, 0x00000000}},  //   _राजा_, stys, ägar,
  { {0x76590046, 0x7d161562, 0x0ae90025, 0x00000000}},  //   _nowy, ptys, تركي_,
  { {0x63a60036, 0x00000000, 0x00000000, 0x00000000}},  //   ękni,   ,   ,
  { {0x26cc0211, 0xa3ab0061, 0x7d041679, 0x00000000}},  //   _pudo_, _खरं_, mris,
  { {0x7522167a, 0x25c1005f, 0xe1ff0036, 0x00000000}},  //   _spoz, ərlə_, chów_,
  { {0x6458167b, 0x80dd0055, 0xfaa301fb, 0x00000000}},  //   _sovi, _বিস্, _засо,
  { {0x6458040d, 0x68e90016, 0x629d02bb, 0x00000000}},  //   _povi, _gwed, voso,
  { {0x26cc02d5, 0x7d04002a, 0x61ed167c, 0x00000000}},  //   _tudo_, iris, _seal,
  { {0xe61a0057, 0x61ed0004, 0x229501e0, 0x00000000}},  //   _где_, _peal, диня,
  { {0x7d040020, 0xbddb01aa, 0xd377007e, 0x00000000}},  //   kris, _enèj, ячы_,
  { {0x629d167d, 0xe534007c, 0x64580052, 0x00000000}},  //   roso, _цель, _tovi,
  { {0x7d040089, 0x61e0005a, 0x55bb00b3, 0x00000000}},  //   dris, ımla, _המדו,
  { {0x629d167e, 0x7c350ed8, 0x25af010f, 0x00000000}},  //   poso, _razr, _zzgl_,
  { {0x7d04010f, 0x816b003b, 0xe0df0026, 0x00000000}},  //   fris, _гроб_, ppò_,
  { {0x823403ec, 0x22490027, 0x786f06ec, 0x00000000}},  // [2c70] _سريا, _inak_, _høve,
  { {0xdfd10025, 0x00000000, 0x00000000, 0x00000000}},  //   _جيد_,   ,   ,
  { {0xaac70070, 0x7d04006c, 0xde590088, 0x00000000}},  //   ستان, aris, _дані_,
  { {0x7d18002a, 0x68e9006a, 0x7d04016e, 0x00000000}},  //   éasá, _pwed, bris,
  { {0x7d0408d3, 0x3ea90039, 0x786f08e0, 0x00000000}},  //   cris, mlat_, _løve,
  { {0x3ea90065, 0x07a50751, 0xc7a50088, 0x00000000}},  //   llat_, малн, милк,
  { {0x12c70055, 0x7659047a, 0x2249167f, 0x00000000}},  //   _শব্দ, _powy, _onak_,
  { {0xd877007a, 0x645c1680, 0x569202ea, 0x00000000}},  //   _کارب, örin, кајт,
  { {0xbddb0173, 0xddcd0006, 0xb8150098, 0x00000000}},  //   _anèk, kiaž, _одај,
  { {0x22491451, 0x249e0009, 0x25a60173, 0x00000000}},  //   _anak_, gotm_, _dyol_,
  { {0x3ea90169, 0x04ff0044, 0x80dd0044, 0x00000000}},  //   klat_, ্বের_, _বিষ্,
  { {0x7d04000c, 0x1fc50044, 0xcfc50044, 0x00000000}},  //   yris, ্রাস, ্রান,
  { {0x66c7014a, 0x3ea90058, 0x22490288, 0x00000000}},  //   _fıkr, dlat_, _dnak_,
  { {0x80dd0055, 0x638501fc, 0x22491681, 0x00000000}},  //   _বিশ্, _огла, _enak_,
  { {0xe29f000c, 0x3ea90035, 0x7d040016, 0x00000000}},  //   boð_, flat_, wris,
  { {0x3ea91682, 0xecea0ae0, 0x00000000, 0x00000000}},  //   glat_, ждал_,   ,
  { {0x32d3001d, 0x7d041683, 0xd12f007a, 0x00000000}},  // [2c80] _hãy_, uris, _نمي_,
  { {0x7d0401bc, 0x22490091, 0x3ac8006b, 0x00000000}},  //   rris, _znak_, _aşpa_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7d04032c, 0x3ea900d4, 0x201e0173, 0x00000000}},  //   pris, clat_, òtif_,
  { {0x20d408b2, 0xaac50014, 0xbdfb0bb6, 0x00000000}},  //   _jäi_, رتمن, _برپا_,
  { {0xd6da107f, 0x1867017f, 0x00000000, 0x00000000}},  //   оти_, мачи_,   ,
  { {0xf793008b, 0x32d30082, 0xdc3701ce, 0x00000000}},  //   кашэ, _nãy_, _קאלט_,
  { {0xa3c302fb, 0xa534017a, 0x3ea01684, 0x00000000}},  //   ्शन_, енич, noit_,
  { {0x64c80164, 0x26c600e7, 0x786f0146, 0x00000000}},  //   रदेश, _vioo_, _døvb,
  { {0x22490030, 0x80dd0044, 0x00000000, 0x00000000}},  //   _snak_, _বিল্,   ,
  { {0xd37a0aef, 0xe29f01e5, 0x00000000, 0x00000000}},  //   ючи_, toð_,   ,
  { {0x32d30011, 0x0566142c, 0x00000000, 0x00000000}},  //   _dãy_, _овен,   ,
  { {0xa2ca006e, 0xf1ab0014, 0x3ea00035, 0x00000000}},  //   _संक्, تاده_, doit_,
  { {0xdbf30279, 0x961d0089, 0x104b0088, 0x00000000}},  //   _işçi, miņa, цями_,
  { {0xc05801e1, 0x3ea90222, 0x32d30082, 0x00000000}},  //   фія_, tlat_, _gãy_,
  { {0x442c1685, 0x3ea90831, 0x2906012d, 0x00000000}},  //   led_, ulat_, kroa_,
  { {0x3ea91686, 0x442c0016, 0xdfd51001, 0x00000000}},  // [2c90] rlat_, oed_, _попы,
  { {0x442c0038, 0x3ea90224, 0xa1f900a1, 0x00000000}},  //   ned_, slat_, _بڑھا_,
  { {0x3ea90035, 0x628f0cfe, 0x442c005b, 0x00000000}},  //   plat_, onco, ied_,
  { {0x442c1687, 0x2bdf02fb, 0xfbdf02f4, 0x00000000}},  //   hed_, _प्रा, _प्रम,
  { {0x442c0038, 0x26de0207, 0xd82500ed, 0x00000000}},  //   ked_, _atto_, едли,
  { {0x442c0209, 0x6e2d0051, 0x7d0d04cb, 0x00000000}},  //   jed_, leab, muas,
  { {0x442c0038, 0xa2ca02fb, 0x7d0d0169, 0x00000000}},  //   ded_, _संग्, luas,
  { {0xbb48007a, 0x6e2d004a, 0x442c06ed, 0x00000000}},  //   _تلفن_, neab, eed_,
  { {0x79a703f3, 0x442c0016, 0x7d0d0048, 0x00000000}},  //   _црве, fed_, nuas,
  { {0xa2ca02fb, 0xe4510054, 0x442c1688, 0x00000000}},  //   _संख्, اضة_, ged_,
  { {0xe2860751, 0x00000000, 0x00000000, 0x00000000}},  //   елни,   ,   ,
  { {0x644a00f4, 0x7d0d04cb, 0x442c006c, 0x00000000}},  //   _enfi, kuas, aed_,
  { {0x442c0ace, 0x764b0047, 0x1fe10044, 0x00000000}},  //   bed_, _ingy, _বয়স,
  { {0x442c0038, 0x2bdf006e, 0xa06a007e, 0x00000000}},  //   ced_, _प्ला, чага_,
  { {0x3ea0010e, 0x625800fa, 0x00000000, 0x00000000}},  //   toit_, _mãoz,   ,
  { {0x6e2d02a4, 0x7d0d0020, 0x68e20022, 0x00000000}},  //   geab, fuas, ypod,
  { {0x62860288, 0x3ea01689, 0x7d0d168a, 0x00000000}},  // [2ca0] miko, roit_, guas,
  { {0x69db008e, 0xef1a0478, 0xc19b0104, 0x00000000}},  //   _afue, _емо_, _משפי,
  { {0x961d0089, 0xb5fd0089, 0x9f430142, 0x00000000}},  //   ziņa, ekšm, zajú_,
  { {0x442c168b, 0x2906002d, 0x6e2d0133, 0x00000000}},  //   zed_, troa_, ceab,
  { {0x442c0038, 0xd83801d9, 0x6f0e012d, 0x00000000}},  //   yed_, _pač_, lubc,
  { {0x62860d49, 0x2906022b, 0x442c00ab, 0x00000000}},  //   hiko, rroa_, xed_,
  { {0x442c0038, 0x62860315, 0xe66600ec, 0x00000000}},  //   ved_, kiko, етпо,
  { {0x442c168c, 0x6286168d, 0x68e2009d, 0x00000000}},  //   wed_, jiko, ppod,
  { {0x442c0a8a, 0x6286002d, 0xdb1c0051, 0x00000000}},  //   ted_, diko, _ngrú,
  { {0x6aa200c7, 0x9980010a, 0x628601c3, 0x00000000}},  //   loof, žių_, eiko,
  { {0x442c0a8a, 0xb21b00ea, 0x00000000, 0x00000000}},  //   red_, dnær,   ,
  { {0x442c109b, 0x6286168e, 0x00000000, 0x00000000}},  //   sed_, giko,   ,
  { {0x442c00ab, 0x6e2d0056, 0x628f00d9, 0x00000000}},  //   ped_, veab, rnco,
  { {0x6aa20168, 0x74130014, 0x7bce00e0, 0x00000000}},  //   hoof, _موها, _ngbu,
  { {0x02a7102a, 0x53340827, 0x6286168f, 0x00000000}},  //   _прим, _рейт, biko,
  { {0x7bdc0065, 0xb21b101b, 0x00000000, 0x00000000}},  //   _afru, rnæs,   ,
  { {0x6e2d0051, 0x9f4a1690, 0xbbeb0025, 0x00000000}},  // [2cb0] reab, rabá_, كرام_,
  { {0x6e2d008e, 0xf8b80082, 0x00000000, 0x00000000}},  //   seab, _nhĩ_,   ,
  { {0x68fb037e, 0x3944112b, 0x7afc0e0d, 0x00000000}},  //   _svud, _arms_, _cvrt,
  { {0x636b0010, 0x7d0d04cb, 0xd7f10082, 0x00000000}},  //   lönö, puas, _sẽ_,
  { {0x7d0d0026, 0x3a240022, 0xb5fd0006, 0x00000000}},  //   quas, _dbmp_, ukšm,
  { {0x62860006, 0x9be7009e, 0x00000000, 0x00000000}},  //   ziko, _سورۃ_,   ,
  { {0xa695025f, 0x62860a63, 0xe7390256, 0x00000000}},  //   криј, yiko, фей_,
  { {0x6286084b, 0x6edc00ca, 0xbddb000a, 0x00000000}},  //   xiko, _učbe, _enèv,
  { {0xf993004b, 0x628601b1, 0x58d50088, 0x00000000}},  //   _صبر_, viko, _розт,
  { {0x58d400e3, 0x44650679, 0x290f1691, 0x00000000}},  //   _софт, твов, muga_,
  { {0x62861692, 0xfbd200b6, 0xe29a012b, 0x00000000}},  //   tiko, יתי_, дан_,
  { {0x20010022, 0x63aa005b, 0x00000000, 0x00000000}},  //   _adhi_, _dyfn,   ,
  { {0x6286022b, 0xa5640025, 0x290f006c, 0x00000000}},  //   riko, _مدون, nuga_,
  { {0x62860e33, 0x291d0020, 0x78a30052, 0x00000000}},  //   siko, itwa_, nonv,
  { {0x8fa6026b, 0x63aa0016, 0x290f0fc7, 0x00000000}},  //   таве, _gyfn, huga_,
  { {0x291d01aa, 0x7bdc0207, 0x290f006c, 0x00000000}},  //   ktwa_, _sfru, kuga_,
  { {0xc5f20097, 0x78a31693, 0x290f1694, 0x00000000}},  // [2cc0] ידן_, konv, juga_,
  { {0x290f033b, 0x20040006, 0x00000000, 0x00000000}},  //   duga_, ėmis_,   ,
  { {0x78a3000a, 0x00000000, 0x00000000, 0x00000000}},  //   donv,   ,   ,
  { {0xc98601ee, 0x290f00e7, 0x00000000, 0x00000000}},  //   кули, fuga_,   ,
  { {0x6aa2010e, 0x78a300ea, 0x290f010e, 0x00000000}},  //   roof, fonv, guga_,
  { {0x7afc016e, 0xa7fc005d, 0xa3c3013d, 0x00000000}},  //   _tvrt, _alır, ्शा_,
  { {0x7c3c002a, 0x7afc016c, 0x394400fa, 0x00000000}},  //   _iarr, _uvrt, _wrms_,
  { {0x7c3c1695, 0x6d4601ee, 0x7c3e1696, 0x00000000}},  //   _harr, _krka, ldpr,
  { {0x7c3c022b, 0x291d0036, 0x81d80044, 0x00000000}},  //   _karr, ctwa_, িরা_,
  { {0x7c3c022b, 0x78a31697, 0x62840173, 0x00000000}},  //   _jarr, conv, _amio,
  { {0x7c3c071e, 0xd25101ef, 0x64a300ed, 0x00000000}},  //   _marr, مند_, раќа,
  { {0x7c3c022b, 0x6d460039, 0xa77b0049, 0x00000000}},  //   _larr, _orka, _קראפ,
  { {0x95530014, 0x316d004a, 0xaf340014, 0x00000000}},  //   _نخوا, áez_, یرفت,
  { {0x8c080055, 0x25840089, 0x3e750292, 0x00000000}},  //   র্তন_, rīlī_, _måte_,
  { {0x54330188, 0x3ce2142a, 0x6d46114e, 0x00000000}},  //   _ضرور, _atkv_, _arka,
  { {0x443e0018, 0x443c00eb, 0x3cfe006e, 0x00000000}},  //   ldt_, _hav_, _लिखे_,
  { {0x7c3c1698, 0x961d001e, 0x80dd0044, 0x00000000}},  // [2cd0] _barr, ziņo, _বিক্,
  { {0x443e1699, 0x7c3c169a, 0x290f169b, 0x00000000}},  //   ndt_, _carr, vuga_,
  { {0x7c3c04bd, 0x6d46169c, 0x443e00d9, 0x00000000}},  //   _darr, _erka, idt_,
  { {0x7c3c002a, 0x443c0030, 0x99840006, 0x00000000}},  //   _earr, _lav_, _namų_,
  { {0x7c3c0051, 0xe8df0011, 0x443c169d, 0x00000000}},  //   _farr, _trọn_, _oav_,
  { {0x443c169e, 0x7c3c022b, 0x6e3d03b0, 0x00000000}},  //   _nav_, _garr, _hasb,
  { {0x291d169f, 0x46f4007e, 0x290f006c, 0x00000000}},  //   stwa_, ачыт, suga_,
  { {0xc1e30316, 0x443e00b5, 0x7c3c0032, 0x00000000}},  //   _क्लब_, edt_, _zarr,
  { {0x7c3c0095, 0x6e3d033b, 0x7e6d16a0, 0x00000000}},  //   _yarr, _masb, ikap,
  { {0x649d04bd, 0x7c3c16a1, 0x6e3d0116, 0x00000000}},  //   nèix, _xarr, _lasb,
  { {0x461503ec, 0x7e6d00b0, 0xf770023c, 0x00000000}},  //   _موار, kkap, _وام_,
  { {0xe0c9007b, 0x32ba0025, 0x443e00d9, 0x00000000}},  //   _זײ_, عددة_, adt_,
  { {0x443c0048, 0x81ac0044, 0x321e0036, 0x00000000}},  //   _fav_, কেন_, ęty_,
  { {0x40950bbd, 0x443c05cb, 0x80dd0044, 0x00000000}},  //   арст, _gav_, _বিখ্,
  { {0x4427006b, 0x6e3d163c, 0x9f580023, 0x00000000}},  //   _ibn_, _basb, marë_,
  { {0x7c3c022b, 0x7e6d011c, 0x443c0087, 0x00000000}},  //   _sarr, gkap, _zav_,
  { {0x614601f9, 0x1d0700c0, 0x65690093, 0x00000000}},  // [2ce0] _сепа, лети_, nyeh,
  { {0x7c3c002b, 0x9f580023, 0x786f0190, 0x00000000}},  //   _qarr, narë_, _søvn,
  { {0x7c3c0065, 0x16030061, 0x645c0934, 0x00000000}},  //   _varr, ळणार_, örii,
  { {0xe3c50044, 0x7c3c00ab, 0x998d0036, 0x00000000}},  //   _এভাব, _warr, _oceń_,
  { {0x7c3c04bd, 0x443e16a2, 0x6e2402c2, 0x00000000}},  //   _tarr, ydt_, mfib,
  { {0x61f60279, 0x60d60058, 0x6d4416a3, 0x00000000}},  //   _leyl, _muym, mvia,
  { {0x6d4400d4, 0x443c0253, 0x9f580023, 0x00000000}},  //   lvia, _rav_, darë_,
  { {0x443c16a4, 0x9b930054, 0xfaa616a5, 0x00000000}},  //   _sav_, _الفت, _сабо,
  { {0x6d440a53, 0xd94301e0, 0x443c007f, 0x00000000}},  //   nvia, _лети, _pav_,
  { {0x443e00bb, 0xe8d70104, 0xd5c0013d, 0x00000000}},  //   udt_, _עובר_, शेषज,
  { {0x443e0662, 0x61f6014a, 0x7e6d011c, 0x00000000}},  //   rdt_, _beyl, ykap,
  { {0x201a0066, 0x61f60095, 0x443e00d9, 0x00000000}},  //   _acpi_, _ceyl, sdt_,
  { {0x443c0ed6, 0x6d440027, 0x61f8007e, 0x00000000}},  //   _tav_, jvia, ыняў_,
  { {0x60d6005a, 0x00000000, 0x00000000, 0x00000000}},  //   _duym,   ,   ,
  { {0xb4c002fb, 0xb4c2007d, 0x7e6d16a6, 0x00000000}},  //   ंगी_, ्दी_, tkap,
  { {0xe80e013d, 0x764016a7, 0x38bb01d6, 0x00000000}},  //   _साझा_, ndmy, mêre_,
  { {0xb8040164, 0x5d55026b, 0x7d1d0009, 0x00000000}},  // [2cf0] रणाम_, шкат, _qqss,
  { {0x7e6d0292, 0x9ed900e3, 0x673a006c, 0x00000000}},  //   skap, _имот_, _ostj,
  { {0x649d0129, 0x6e3d16a8, 0xd1b800a1, 0x00000000}},  //   rèix, _tasb, _لایا_,
  { {0x81f30044, 0x61f6006b, 0x6e3d0093, 0x00000000}},  //   _ঝাঁপ_, _xeyl, _uasb,
  { {0xc27c0049, 0xe9d8007e, 0x527c0049, 0x00000000}},  //   ערדי, укі_, ענדא,
  { {0x1bd416a9, 0x7d0d0f3e, 0xa96600e2, 0x00000000}},  //   _горя, mras, риша_,
  { {0x9f580023, 0x00000000, 0x00000000, 0x00000000}},  //   varë_,   ,   ,
  { {0x673a0087, 0x00000000, 0x00000000, 0x00000000}},  //   _dstj,   ,   ,
  { {0x9f580065, 0x7d0d014a, 0x4427107b, 0x00000000}},  //   tarë_, nras, _pbn_,
  { {0x032500ec, 0xddc40006, 0x291f00f6, 0x00000000}},  //   адон, nkiš, _iqua_,
  { {0xe1ff0046, 0x3a3f069e, 0x44270296, 0x00000000}},  //   nków_, _kaup_, _vbn_,
  { {0x80dd0055, 0x216a0088, 0x614600a5, 0x00000000}},  //   _বিজ্, вими_, аема,
  { {0x34950264, 0xe2970057, 0x44270082, 0x00000000}},  //   _кадр, рая_, _tbn_,
  { {0xd466012b, 0x6d440197, 0xe5c4007e, 0x00000000}},  //   _више_, vvia, _усхо,
  { {0x26cf0009, 0x6e240026, 0x7d0d16aa, 0x00000000}},  //   _kigo_, tfib, eras,
  { {0x7d0d049a, 0xe1ff0036, 0x9f5812b2, 0x00000000}},  //   fras, dków_, naré_,
  { {0xac860088, 0x26cf008e, 0x629d004a, 0x00000000}},  // [2d00] агал, _migo_, éroe,
  { {0xd12f089d, 0x0eb80061, 0x26cf16ab, 0x00000000}},  //   _کمی_, _आठवड, _ligo_,
  { {0x6d4406c2, 0xdddd0010, 0x2abc008e, 0x00000000}},  //   svia, _első, híbe_,
  { {0x6da60088, 0x64410022, 0x7d0d16ac, 0x00000000}},  //   _вима, hdli, bras,
  { {0x44e916ad, 0x29000181, 0x9f580b32, 0x00000000}},  //   _nº_, éia_, daré_,
  { {0x201816ae, 0x3706007c, 0x3eb216af, 0x00000000}},  //   ngri_, ачив, llyt_,
  { {0x64410186, 0x26cf16b0, 0x291f0026, 0x00000000}},  //   ddli, _bigo_, _equa_,
  { {0x6441010f, 0x22400149, 0xeb9701fb, 0x00000000}},  //   edli, _naik_, _тис_,
  { {0xd5b707ca, 0x26cf0b76, 0x44250678, 0x00000000}},  //   ись_, _digo_, ffl_,
  { {0xb4c003d7, 0x38bb0007, 0x64410270, 0x00000000}},  //   ंगे_, têre_, gdli,
  { {0x22400149, 0x39460006, 0x3e750039, 0x00000000}},  //   _baik_, lvos_, _låta_,
  { {0xc5f00055, 0x644116b1, 0x9f5816b2, 0x00000000}},  //   _টাকা_, adli, caré_,
  { {0x22400022, 0x867b00a0, 0x00000000, 0x00000000}},  //   _daik_, _בראו,   ,
  { {0x83f80069, 0x7d0d16b3, 0x27fc05ba, 0x00000000}},  //   _секс_, vras, navn_,
  { {0x06fd00b9, 0x224016b4, 0x3eb200ea, 0x00000000}},  //   žívá_, _faik_, flyt_,
  { {0x27fc0030, 0x2c190061, 0x2a64000a, 0x00000000}},  //   havn_, _पाहू_, _nomb_,
  { {0x6d400059, 0xdb1c0036, 0x3a3f0022, 0x00000000}},  // [2d10] _šmar, _ogró, _raup_,
  { {0x7d0d021e, 0xe1ff0036, 0x9f5816b5, 0x00000000}},  //   rras, tków_, zaré_,
  { {0x291f0061, 0x3a3f000a, 0x2a640133, 0x00000000}},  //   _squa_, _paup_, _bomb_,
  { {0x7d0d1669, 0x61fd001c, 0xde590245, 0x00000000}},  //   pras, nasl, _самі_,
  { {0x39490211, 0x0dcb00ed, 0xd9450726, 0x00000000}},  //   ías_, _јуни_, сели,
  { {0x26cf0211, 0x3ea913a2, 0xf8a8007e, 0x00000000}},  //   _sigo_, loat_, авік_,
  { {0x61fd022b, 0x9f580b32, 0x261b0204, 0x00000000}},  //   kasl, taré_, _यादी_,
  { {0x2f98009b, 0x61fd0089, 0x7d1b01a2, 0x00000000}},  //   יכון_, jasl, _äuss,
  { {0x26cf049a, 0x880704e8, 0x497516b6, 0x00000000}},  //   _vigo_, _نظام, _улас,
  { {0x9f5812b2, 0x26cf00e7, 0x26c40026, 0x00000000}},  //   saré_, _wigo_, ammo_,
  { {0x644104b2, 0xa25b00c4, 0x9f58009d, 0x00000000}},  //   rdli, rmôn, paré_,
  { {0x27210211, 0x6f1504a8, 0x625a0364, 0x00000000}},  //   món_, duzc, урор_,
  { {0x272116b7, 0xa5090088, 0x95cb003b, 0x00000000}},  //   lón_, _села_, _ружа_,
  { {0x645c00b0, 0x00000000, 0x00000000, 0x00000000}},  //   örit,   ,   ,
  { {0x2721027b, 0xb21b0030, 0xdee6007c, 0x00000000}},  //   nón_, dhæf, соби,
  { {0x39460006, 0x225200d6, 0xbda60025, 0x00000000}},  //   yvos_, _unyk_, محذو,
  { {0xed5708d6, 0x272116b8, 0x00000000, 0x00000000}},  // [2d20] бот_, hón_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x272116b9, 0xdb1c00d4, 0x5f460426, 0x00000000}},  //   jón_, _agrò, _انجل,
  { {0x2721008e, 0x82d60049, 0xa3c90061, 0x00000000}},  //   dón_, צונג_, लेय_,
  { {0xceb4006b, 0x186a0088, 0x92e30044, 0x00000000}},  //   mlə_, лади_, _ফটো_,
  { {0xfce30057, 0x39460010, 0x27210027, 0x00000000}},  //   _хоро, rvos_, fón_,
  { {0x27210211, 0xa3c901f5, 0x61e40035, 0x00000000}},  //   gón_, लेम_, _ofil,
  { {0xceb4006b, 0x20cf0066, 0x2d8001c3, 0x00000000}},  //   nlə_, _ażil_, ozie_,
  { {0x2d8016ba, 0xb5fd0089, 0x61fd0010, 0x00000000}},  //   nzie_, ekšs, vasl,
  { {0xd6d205f3, 0xb86516bb, 0x2721008e, 0x00000000}},  //   _فقط_, _والو, bón_,
  { {0xceb4005f, 0x27210efe, 0x61fd01c5, 0x00000000}},  //   klə_, cón_, tasl,
  { {0x41e4007e, 0x9c87093f, 0x29000006, 0x00000000}},  //   зіра, _kočá, šiau_,
  { {0x61fd00ee, 0xb5fd007f, 0x645c16bc, 0x00000000}},  //   rasl, rkšt, öris,
  { {0x2d8016bd, 0x61fd006b, 0x236a0025, 0x00000000}},  //   dzie_, sasl, _محبي_,
  { {0x61e4018e, 0x4fc40b49, 0x93fb0097, 0x00000000}},  //   _ffil, зста, _גלוי,
  { {0x5f94005e, 0xa195005e, 0x00000000, 0x00000000}},  //   чист, _майч,   ,
  { {0x27210845, 0x2d58041f, 0x628f16be, 0x00000000}},  // [2d30] zón_, бить_, mico,
  { {0xebc7003b, 0x6f1504de, 0x9d1800e2, 0x00000000}},  //   бљен, puzc, софт_,
  { {0xb5fd0059, 0xb21b000c, 0x2721004a, 0x00000000}},  //   ljše, rhæf, xón_,
  { {0x2721004a, 0x61e416bf, 0x7e6600d9, 0x00000000}},  //   vón_, _xfil, _gokp,
  { {0xae1a007b, 0xd5a600a1, 0xb5fd00ca, 0x00000000}},  //   _דורכ, _آف_, njše,
  { {0x272116c0, 0x628f0035, 0x00000000, 0x00000000}},  //   tón_, hico,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27210211, 0xb5fd0089, 0x628f0466, 0x00000000}},  //   rón_, ekšr, jico,
  { {0x2721027b, 0x628f029d, 0x00000000, 0x00000000}},  //   són_, dico,   ,
  { {0x27210211, 0x73050088, 0x61e40197, 0x00000000}},  //   pón_, опоз, _sfil,
  { {0x628f029d, 0x32090058, 0xe7ef0061, 0x00000000}},  //   fico, _bday_, _घ्या_,
  { {0x628f029d, 0xd57516c1, 0xe297078e, 0x00000000}},  //   gico, _муль, жаю_,
  { {0x2a3a0049, 0xceb4006b, 0x7e6600e0, 0x00000000}},  //   בערמ, vlə_, _rokp,
  { {0x201e16c2, 0x00000000, 0x00000000, 0x00000000}},  //   üti_,   ,   ,
  { {0xceb4005f, 0x7e660058, 0x64430035, 0x00000000}},  //   tlə_, _pokp, _iani,
  { {0x661b16c3, 0x394d145d, 0xee3a00e1, 0x00000000}},  //   nguk, _ores_, јна_,
  { {0x64430811, 0x7fd60099, 0xceb4005f, 0x00000000}},  // [2d40] _kani, _міні, rlə_,
  { {0xceb4006b, 0x2d800142, 0x00000000, 0x00000000}},  //   slə_, rzie_,   ,
  { {0xe9da0aed, 0x6a8616c4, 0x2904012d, 0x00000000}},  //   аке_, олжа, _svma_,
  { {0x644316c5, 0x9c8700b9, 0x394d005b, 0x00000000}},  //   _lani, _počá, _bres_,
  { {0x81ac0055, 0x59a50061, 0xdb0700b9, 0x00000000}},  //   কের_, गॅलर, _vyjá,
  { {0x6443006a, 0xc17300b6, 0xd90d007a, 0x00000000}},  //   _nani, וחד_, ایل_,
  { {0x8b2302a8, 0x394d0211, 0xe3a70084, 0x00000000}},  //   _одре, _eres_, _آر_,
  { {0xba1a0025, 0x64430058, 0x7d040dc9, 0x00000000}},  //   _خيرا_, _aani, osis,
  { {0x6443001a, 0x628f0142, 0xd90d025a, 0x00000000}},  //   _bani, vico, _مین_,
  { {0x64430bab, 0x7d0416c6, 0xe46a09da, 0x00000000}},  //   _cani, isis, ршил_,
  { {0x628f10d7, 0x7d040d85, 0x00000000, 0x00000000}},  //   tico, hsis,   ,
  { {0x7d04021e, 0xd377008b, 0xdb211152, 0x00000000}},  //   ksis, ючы_, étét,
  { {0x628f0198, 0x644316c7, 0x66d50006, 0x00000000}},  //   rico, _fani, _iška,
  { {0x6443006a, 0x628f0489, 0x66000145, 0x00000000}},  //   _gani, sico, lamk,
  { {0x628f0181, 0x442e04b3, 0x44e00011, 0x00000000}},  //   pico, _ibf_, _hò_,
  { {0x644300ee, 0x7c2e16c8, 0x44e00263, 0x00000000}},  //   _zani, _abbr, _kò_,
  { {0xd90400e9, 0x7d04006a, 0xdddd0036, 0x00000000}},  // [2d50] _جی_, gsis, _posł,
  { {0x44e016c9, 0xfc330025, 0x6ed50036, 0x00000000}},  //   _mò_, بحر_, _dąbr,
  { {0x68e902cc, 0x44e012ba, 0x66001636, 0x00000000}},  //   _sted, _lò_, kamk,
  { {0x7c2e065d, 0x660005cd, 0x787d000a, 0x00000000}},  //   _ebbr, jamk, _mève,
  { {0x44e001aa, 0x2292089f, 0x81cd0044, 0x00000000}},  //   _nò_, nška_, শুর_,
  { {0x628d000a, 0x3e7c00b9, 0x442e00d9, 0x00000000}},  //   _lmao, _víte_, _nbf_,
  { {0xf771031d, 0x6443037e, 0x68e90036, 0x00000000}},  //   عات_, _rani, _wted,
  { {0x394d16ca, 0x44e016cb, 0x05650088, 0x00000000}},  //   _tres_, _bò_, звин,
  { {0x644316cc, 0x79820036, 0x44e00082, 0x00000000}},  //   _pani, czow, _cò_,
  { {0x442e00c4, 0x44e016cd, 0xd87701af, 0x00000000}},  //   _cbf_, _dò_, _بارب,
  { {0xf1a900bd, 0x2292010a, 0x0322007e, 0x00000000}},  //   _עס_, eška_, ндэн,
  { {0xe29a08fd, 0x64430149, 0x44e00263, 0x00000000}},  //   сам_, _wani, _fò_,
  { {0x64430036, 0x2bb802f4, 0x44e00011, 0x00000000}},  //   _tani, _अर्थ, _gò_,
  { {0x7ae916ce, 0x15420478, 0xf09f00d4, 0x00000000}},  //   _četn, _чешм, dràs_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3e6e009f, 0x7d0400b0, 0x6d4f0087, 0x00000000}},  //   _nýtt_, tsis, _brca,
  { {0xed5700ed, 0x44e0159f, 0x7d0400e5, 0x00000000}},  // [2d60] пот_, _xò_, usis,
  { {0x7d0416cf, 0x6e2f0061, 0xe0580014, 0x00000000}},  //   rsis, _ebcb, _بیست_,
  { {0x6d4f0095, 0x66000022, 0x00000000, 0x00000000}},  //   _erca, yamk,   ,
  { {0x61e60b3d, 0x7d0400b0, 0xfaa30245, 0x00000000}},  //   nckl, psis, нахо,
  { {0x7d040023, 0x6d4f16d0, 0x9f5800d4, 0x00000000}},  //   qsis, _grca, larà_,
  { {0x79820036, 0x44e00082, 0x91bb009b, 0x00000000}},  //   rzow, _rò_, זמני,
  { {0xa3ab03d7, 0x6d4f16d1, 0x44e016d2, 0x00000000}},  //   _कुल_, _zrca, _sò_,
  { {0x44e016d3, 0x442e0203, 0x7e760146, 0x00000000}},  //   _pò_, _sbf_, nkyp,
  { {0x660001a3, 0x3f83002b, 0xa3c9007d, 0x00000000}},  //   ramk, zzju_, लेस_,
  { {0x69c00119, 0x628d002a, 0x66000218, 0x00000000}},  //   _izme, _smao, samk,
  { {0xd25100d3, 0x442e16d4, 0x9f5800d4, 0x00000000}},  //   نند_, _vbf_, jarà_,
  { {0x9f580129, 0xa75b009b, 0x44e0099c, 0x00000000}},  //   darà_, _לדבר, _tò_,
  { {0xc05b01fb, 0x6ed60204, 0x2906012d, 0x00000000}},  //   бів_, _मंजु, nsoa_,
  { {0x26de027f, 0x2292050f, 0x9f5800f6, 0x00000000}},  //   _kuto_, rška_, farà_,
  { {0xb5fd01ae, 0x6458051b, 0x9f580129, 0x00000000}},  //   ljša, _invi, garà_,
  { {0x81ac0055, 0x02a4008b, 0x26de16d5, 0x00000000}},  //   কেই_, _прым, _muto_,
  { {0x2d580057, 0xb5fd0059, 0x442c00bb, 0x00000000}},  // [2d70] пить_, njša, ofd_,
  { {0x6d4f0107, 0x9f580129, 0xddc6000a, 0x00000000}},  //   _vrca, barà_, _makň,
  { {0x200316d6, 0x644816d7, 0x629d068f, 0x00000000}},  //   maji_, iddi, onso,
  { {0x20030052, 0x2ea80061, 0x629d00ea, 0x00000000}},  //   laji_, ककृत, nnso,
  { {0x186900c0, 0x9f580b33, 0x6d4f001a, 0x00000000}},  //   жали_, mará_, _urca,
  { {0x200316d8, 0x26de13b1, 0x9f5816d9, 0x00000000}},  //   naji_, _buto_, lará_,
  { {0x47d00044, 0x6d4d01d6, 0x61e600f8, 0x00000000}},  //   _স্বী, lvaa, yckl,
  { {0x6e2d004e, 0x9f5800dc, 0x442c00b5, 0x00000000}},  //   nfab, nará_, efd_,
  { {0x200316da, 0x6d4d16db, 0x442c16dc, 0x00000000}},  //   kaji_, nvaa, ffd_,
  { {0xd90d026c, 0x200316dd, 0x2b430066, 0x00000000}},  //   _میچ_, jaji_, _ksjc_,
  { {0x20030235, 0x06d70044, 0x3e7c000c, 0x00000000}},  //   daji_, _সবকি, _líta_,
  { {0x64480061, 0x9f5816de, 0x60c500e0, 0x00000000}},  //   addi, jará_, _ahhm,
  { {0x9f580b33, 0x26de0107, 0x765901c3, 0x00000000}},  //   dará_, _zuto_, _inwy,
  { {0x9f580129, 0x20030020, 0x76490c87, 0x00000000}},  //   tarà_, gaji_, ldey,
  { {0x6e2d16df, 0x7e640093, 0x98a4007f, 0x00000000}},  //   ffab, tjip, _esmė_,
  { {0x9f581195, 0x7649014a, 0x00000000, 0x00000000}},  //   gará_, ndey,   ,
  { {0x7529001a, 0xdb0e01dc, 0xe8df0011, 0x00000000}},  // [2d80] ntez, _vybí, _trộn_,
  { {0x69db00c4, 0xfbd201d8, 0x7e7d02a9, 0x00000000}},  //   _ague, نتا_, _elsp,
  { {0xaec616e0, 0x9f580285, 0x0ae90025, 0x00000000}},  //   _обол, bará_, كرني_,
  { {0x9f58029d, 0x99dd0161, 0x290600b0, 0x00000000}},  //   cará_, _daňo, tsoa_,
  { {0x64480bc4, 0x752911b7, 0xa96701fc, 0x00000000}},  //   yddi, jtez, мица_,
  { {0xd6ea092b, 0x3ead0618, 0x69db002d, 0x00000000}},  //   офил_, čete_, _egue,
  { {0x290602d5, 0x75290026, 0x00000000, 0x00000000}},  //   ssoa_, etez,   ,
  { {0x2003000b, 0xc9560057, 0x786f0146, 0x00000000}},  //   zaji_, _отзы, _bøvs,
  { {0x200316e1, 0x6f1c031e, 0x69c00091, 0x00000000}},  //   yaji_, hurc, _uzme,
  { {0x26de16e2, 0x1620001c, 0x9f580b76, 0x00000000}},  //   _tuto_, _यावर_, zará_,
  { {0xd62a16e3, 0x6448018e, 0x200300ca, 0x00000000}},  //   _може_, rddi, vaji_,
  { {0x6f1c010f, 0x20030020, 0x7d1600ea, 0x00000000}},  //   durc, waji_, krys,
  { {0x2003000b, 0x60d70142, 0x9f580b33, 0x00000000}},  //   taji_, _pixm, vará_,
  { {0x656f010f, 0x7d160065, 0x7bdc0022, 0x00000000}},  //   äche, drys, _ngru,
  { {0x9f580489, 0xa295008b, 0x200316e4, 0x00000000}},  //   tará_, _пакі, raji_,
  { {0x7bdc06c2, 0x4ea400e3, 0x6d4d00b5, 0x00000000}},  //   _agru, вруа, tvaa,
  { {0x9f580489, 0x20030020, 0xdd940147, 0x00000000}},  // [2d90] rará_, paji_, ваты,
  { {0x315600b6, 0x6d4d16e5, 0x9f580b33, 0x00000000}},  //   _ניתן_, rvaa, sará_,
  { {0x9f580285, 0x6f1c0035, 0x6d4d00b0, 0x00000000}},  //   pará_, curc, svaa,
  { {0x75290065, 0x7d1616e6, 0x2249006c, 0x00000000}},  //   ytez, brys, _jaak_,
  { {0x224906b2, 0x801806c6, 0xf5480011, 0x00000000}},  //   _maak_, _عزیز_, _nụ_,
  { {0x68e016e7, 0x2a660026, 0x2b4300d4, 0x00000000}},  //   _dumd, ajob_, _tsjc_,
  { {0x7afc018e, 0x38c900a1, 0x2001006c, 0x00000000}},  //   _gwrt, _ہائی_, _mehi_,
  { {0x060901e0, 0x75290282, 0x26c600e7, 0x00000000}},  //   чник_, ttez, _choo_,
  { {0xf548001d, 0x7649014a, 0x75290026, 0x00000000}},  //   _cụ_, rdey, utez,
  { {0x75290181, 0x336516e8, 0xf5480011, 0x00000000}},  //   rtez, евог, _dụ_,
  { {0xa3c9006e, 0x291d011c, 0xe8d6009b, 0x00000000}},  //   लें_, luwa_, _נוער_,
  { {0xbbdc013d, 0x2292050f, 0x75290035, 0x00000000}},  //   _बल्क, rško_, ptez,
  { {0x20010032, 0x45220044, 0x26cd0026, 0x00000000}},  //   _behi_, _বৈঠক_, mmeo_,
  { {0x03a50256, 0x2a6d006c, 0x6f1c0145, 0x00000000}},  //   _пило, _loeb_, turc,
  { {0xc7b2007b, 0x2a7f005f, 0x2baf03d7, 0x00000000}},  //   ָבן_, _olub_, _जुला,
  { {0x291d0be3, 0x9f5c0359, 0x6833038c, 0x00000000}},  //   kuwa_, _því_, lıdı,
  { {0xafe600ed, 0x291d00e7, 0xe3b8014a, 0x00000000}},  // [2da0] _попл, juwa_, ngın_,
  { {0x2a66152f, 0x224900b5, 0xb21b0030, 0x00000000}},  //   wjob_, _zaak_, nhæn,
  { {0x2a660066, 0x2a7f0cfe, 0xddcd0091, 0x00000000}},  //   tjob_, _blub_, rkaš,
  { {0x09e603e0, 0x7d160fb6, 0xb9060783, 0x00000000}},  //   ходн, prys, ездк,
  { {0x2a6616e9, 0x3ea00052, 0x1c1e0061, 0x00000000}},  //   rjob_, mnit_, _पाऊल_,
  { {0x3b0a0c96, 0x6d4601d9, 0x3ea016ea, 0x00000000}},  //   _него_, _iska, lnit_,
  { {0x3ea00065, 0x7c3e16eb, 0x2a6616ec, 0x00000000}},  //   onit_, mepr, pjob_,
  { {0x3ea009f0, 0x9405006b, 0xa5340088, 0x00000000}},  //   nnit_, milə_, внич,
  { {0x224916ed, 0x3ea01449, 0xb21b0030, 0x00000000}},  //   _raak_, init_, fhæn,
  { {0xf548001d, 0x224916ee, 0x26c6016b, 0x00000000}},  //   _vụ_, _saak_, _whoo_,
  { {0x7ae910ec, 0xd7640014, 0x00000000, 0x00000000}},  //   _četk, _جنای,   ,
  { {0x6d46006c, 0x09d40055, 0xf5480011, 0x00000000}},  //   _oska, _হ্যা, _tụ_,
  { {0x224902ae, 0x638600f4, 0x7c3e00ea, 0x00000000}},  //   _vaak_, _béné, kepr,
  { {0x7c3e05d5, 0x224901d6, 0x660216ef, 0x00000000}},  //   jepr, _waak_, _heok,
  { {0x443e048a, 0x6d4616f0, 0x224900c7, 0x00000000}},  //   met_, _aska, _taak_,
  { {0x443e04d3, 0x626706b4, 0x644a1402, 0x00000000}},  //   let_, _سابق, _hafi,
  { {0x7c3e0019, 0x61ed16f1, 0xdb0e0161, 0x00000000}},  // [2db0] fepr, _ifal, _rybá,
  { {0x6386028c, 0x64840009, 0x7c3e01a2, 0x00000000}},  //   _géné, _dòig, gepr,
  { {0x6d46022b, 0x644a16f2, 0x7f450065, 0x00000000}},  //   _eska, _mafi, _ushq,
  { {0x443e16f3, 0x81ac0055, 0xd9990054, 0x00000000}},  //   het_, কেও_, ونات_,
  { {0x443e0047, 0xd94500d7, 0x61ed0020, 0x00000000}},  //   ket_, тели, _mfal,
  { {0x443e16f4, 0x7c3e049a, 0xa3c2024c, 0x00000000}},  //   jet_, cepr, ्धा_,
  { {0x443e0374, 0x9424006b, 0x61ed0016, 0x00000000}},  //   det_, _ötən_, _ofal,
  { {0x81ac0044, 0x443e00b0, 0x2f5c0049, 0x00000000}},  //   কেট_, eet_, לדונ,
  { {0x443e00f4, 0x644a0061, 0x660200e0, 0x00000000}},  //   fet_, _bafi, _deok,
  { {0x443e05ec, 0x3ea0013e, 0xf990023c, 0x00000000}},  //   get_, znit_, _طبق_,
  { {0x70270044, 0x6833005d, 0x644a16f5, 0x00000000}},  //   য়াজ_, rıdı, _dafi,
  { {0x7c3e0036, 0x6833005d, 0x638600f4, 0x00000000}},  //   zepr, sıdı, _séné,
  { {0x443e0018, 0x6386009d, 0x7c3e0023, 0x00000000}},  //   bet_, _péné, yepr,
  { {0x61ed018e, 0x764b0047, 0x644a01a3, 0x00000000}},  //   _efal, _hagy, _gafi,
  { {0x44270009, 0x7c3e0023, 0x6386009d, 0x00000000}},  //   _icn_, vepr, _véné,
  { {0x644a0471, 0x9405006b, 0x7c3e05d2, 0x00000000}},  //   _zafi, vilə_, wepr,
  { {0x764b0047, 0x3ea016f6, 0x7c3e0207, 0x00000000}},  // [2dc0] _magy, rnit_, tepr,
  { {0x3ea00030, 0x711b0049, 0x9405006b, 0x00000000}},  //   snit_, _קויפ, tilə_,
  { {0x290d000d, 0x7c3e002d, 0x6d460036, 0x00000000}},  //   _avea_, repr, _wska,
  { {0x443e16f7, 0x764b0047, 0x7c3e16f8, 0x00000000}},  //   zet_, _nagy, sepr,
  { {0x443e011f, 0x9405006b, 0x6d4600b0, 0x00000000}},  //   yet_, silə_, _uska,
  { {0x68ed00c4, 0x443e0239, 0x44270045, 0x00000000}},  //   íada, xet_, _ncn_,
  { {0x443e004e, 0x644a06fe, 0x37d50044, 0x00000000}},  //   vet_, _rafi, _স্বর,
  { {0x6e24011c, 0x443e0046, 0x44270129, 0x00000000}},  //   ngib, wet_, _acn_,
  { {0x7ae90166, 0x48e601fb, 0x442716f9, 0x00000000}},  //   _četi, _розв, _bcn_,
  { {0x443e0030, 0x5453007c, 0x644a071f, 0x00000000}},  //   uet_, авьт, _qafi,
  { {0x443e05ec, 0x8c1b0476, 0x261b001c, 0x00000000}},  //   ret_, וויי, _याची_,
  { {0x443e0f3c, 0x92580057, 0x644a0020, 0x00000000}},  //   set_, вают_, _wafi,
  { {0x443e0292, 0x44270190, 0x644a16fa, 0x00000000}},  //   pet_, _fcn_, _tafi,
  { {0x84380054, 0x443e16fb, 0x7414026c, 0x00000000}},  //   _أكثر_, qet_, _صوبا,
  { {0x6aa20f45, 0x61ed0066, 0x00000000, 0x00000000}},  //   knof, _tfal,   ,
  { {0x6e240197, 0x61ed16fc, 0x3e750039, 0x00000000}},  //   ggib, _ufal, _nått_,
  { {0x51870245, 0xa3c20164, 0x70590131, 0x00000000}},  // [2dd0] _шука, ्धव_, _запр_,
  { {0x04140055, 0x673a1220, 0x1acb0309, 0x00000000}},  //   ত্রী_, _optj, िष्ठ,
  { {0xc61a0044, 0x764000b0, 0xdfd1023c, 0x00000000}},  //   থ্যা_, kemy, _ديد_,
  { {0xb21b0030, 0x6aa201d6, 0xdea1025a, 0x00000000}},  //   skæf, gnof, _ایری,
  { {0x76400271, 0x0d64005e, 0x66ea0036, 0x00000000}},  //   demy, _кърм, _ręka,
  { {0x66d50006, 0xfaf3083e, 0x6aa201c3, 0x00000000}},  //   _iški, _نثر_, anof,
  { {0x3e75067e, 0x4427008e, 0x764b16fd, 0x00000000}},  //   _fått_, _rcn_, _pagy,
  { {0x3e75093b, 0x7bc70bf1, 0x25a00b4a, 0x00000000}},  //   _gått_, _izju, _žila_,
  { {0x764b0047, 0xdd12005a, 0x95550025, 0x00000000}},  //   _vagy, _müşt, اخبا,
  { {0x6e240c0a, 0x7c250fb8, 0x22920059, 0x00000000}},  //   zgib, nghr, mški_,
  { {0xe29a0081, 0x7c250048, 0x6d440036, 0x00000000}},  //   еан_, ighr, zwia,
  { {0xad9b029d, 0x955501f7, 0x7d0d16fe, 0x00000000}},  //   _reún, _مختا, ksas,
  { {0xd5bb008b, 0x44270082, 0x9f5816ff, 0x00000000}},  //   _ўсе_, _tcn_, mbré_,
  { {0x62860065, 0x20cf01f3, 0x7d0d0190, 0x00000000}},  //   shko, _bżiq_, dsas,
  { {0x644102ae, 0xe29a0200, 0x44e90082, 0x00000000}},  //   meli, _пак_, _hú_,
  { {0x6441014a, 0xdd920257, 0xb226017a, 0x00000000}},  //   leli, موز_, _смил,
  { {0x6e240240, 0x7d0d006a, 0x44e9000c, 0x00000000}},  // [2de0] rgib, gsas, _jú_,
  { {0x644105fb, 0x44251700, 0x76400036, 0x00000000}},  //   neli, ngl_, zemy,
  { {0x44e90051, 0x61e91701, 0x6441001a, 0x00000000}},  //   _lú_, žele, ieli,
  { {0xa3ab062e, 0x644108b2, 0xaaba00a6, 0x00000000}},  //   _कुछ_, heli, ردار_,
  { {0x44e9009f, 0x64411702, 0x6aa20bc7, 0x00000000}},  //   _nú_, keli, rnof,
  { {0x6441096f, 0x7ae90ce4, 0x200a006a, 0x00000000}},  //   jeli, _četv, nabi_,
  { {0xd6da00d7, 0x26dd0263, 0x62841703, 0x00000000}},  //   нти_, _biwo_, _olio,
  { {0x44e90011, 0x60de01c5, 0x66c50010, 0x00000000}},  //   _bú_, _lipm, tóka,
  { {0x764004b3, 0x64411704, 0x49ca012b, 0x00000000}},  //   remy, feli, _члан_,
  { {0x644102ae, 0x27f701c8, 0x6284000b, 0x00000000}},  //   geli, čení_, _alio,
  { {0xd7ef0054, 0x44e90027, 0x628404a5, 0x00000000}},  //   _ركن_, _eú_, _blio,
  { {0x75200020, 0x62841705, 0xf12700c2, 0x00000000}},  //   pumz, _clio, льго,
  { {0x5184013b, 0xd37800b4, 0x00000000, 0x00000000}},  //   бура, syć_,   ,
  { {0x6441014a, 0x224d018b, 0x6284006c, 0x00000000}},  //   celi, žek_, _elio,
  { {0x447b007b, 0x1ee7007a, 0xdfd50783, 0x00000000}},  //   _אנגע, اوری_, ровы,
  { {0x7d0d0943, 0x62841706, 0xf3130688, 0x00000000}},  //   tsas, _glio, _ابوظ,
  { {0xe2140380, 0xddc60006, 0x320b0133, 0x00000000}},  // [2df0] _طبيع, _pokš, macy_,
  { {0x7d0d1707, 0x320b0036, 0x7af70045, 0x00000000}},  //   rsas, lacy_, tpxt,
  { {0x7d0d00b0, 0x6284021e, 0x9f51004a, 0x00000000}},  //   ssas, _ylio, razó_,
  { {0x7c250051, 0xdb1c0065, 0x639b0049, 0x00000000}},  //   sghr, _zyrë, עסאנ,
  { {0x44250016, 0x6441014a, 0x7ae900ca, 0x00000000}},  //   ygl_, yeli, _četu,
  { {0x7e6d006c, 0x26dd01aa, 0xfc67005e, 0x00000000}},  //   ljap, _siwo_, _съмн,
  { {0x44e91708, 0xb5fd0059, 0x26dd1709, 0x00000000}},  //   _sú_, ljši, _piwo_,
  { {0x6441046a, 0x7f3c007b, 0xb8eb0044, 0x00000000}},  //   weli, געהו, _রং_,
  { {0x64410027, 0xc4850098, 0x26c30089, 0x00000000}},  //   teli, илик, ējo_,
  { {0x99840054, 0x7ae7008d, 0x62840051, 0x00000000}},  //   _الكو, _kujt, _slio,
  { {0x6266170a, 0x61ef0061, 0x200a00ca, 0x00000000}},  //   авна, fccl, vabi_,
  { {0x44e90195, 0xe29a008b, 0xc5d501fb, 0x00000000}},  //   _tú_, там_, _кіль,
  { {0x644100b0, 0x2731001d, 0x200a011c, 0x00000000}},  //   peli, _hơn_, tabi_,
  { {0xe3b00014, 0x00000000, 0x00000000, 0x00000000}},  //   _کره_,   ,   ,
  { {0xb4c30201, 0xb4c10164, 0x200a0087, 0x00000000}},  //   ्षी_, ंती_, rabi_,
  { {0x6284000b, 0x200a006a, 0x320b0133, 0x00000000}},  //   _ulio, sabi_, cacy_,
  { {0xb2bb00b6, 0x614600ed, 0x61e403d8, 0x00000000}},  // [2e00] _במקר, _тепа, _igil,
  { {0x6723033b, 0xc5d70044, 0xf8a50167, 0x00000000}},  //   kunj, _সভাপ, _رک_,
  { {0x0b4607e1, 0xa3c90061, 0x67230093, 0x00000000}},  //   рнен, लेच_, junj,
  { {0x5336007b, 0xb4c102f4, 0x7e6d0023, 0x00000000}},  //   ינען_, ंतु_, cjap,
  { {0x656f010f, 0xe6da000c, 0x00000000, 0x00000000}},  //   ächl, ðsíð,   ,
  { {0x57f303f3, 0xfb260014, 0x00000000, 0x00000000}},  //   општ, _پرسپ,   ,
  { {0x27310011, 0xa7b80a78, 0x61e400f8, 0x00000000}},  //   _cơn_, ылку_, _ogil,
  { {0x66c5009f, 0x61e4170b, 0xfaa60245, 0x00000000}},  //   sókn, _ngil, _табо,
  { {0x320b1537, 0x54b8005e, 0x2292016c, 0x00000000}},  //   vacy_, лгия_, nšku_,
  { {0x2bbf0061, 0x6723170c, 0x7ae00048, 0x00000000}},  //   _्रमा, bunj, _himt,
  { {0x947306ea, 0x69c00ced, 0x6723016c, 0x00000000}},  //   تديا, _hyme, cunj,
  { {0x7ae00066, 0x9f61009d, 0x69c00052, 0x00000000}},  //   _jimt, _épée_, _kyme,
  { {0xe298008b, 0x320b077a, 0xe69304e8, 0x00000000}},  //   раў_, racy_, _بلند,
  { {0x61e4170d, 0x653b00a3, 0x69c001a3, 0x00000000}},  //   _egil, _סעוד, _myme,
  { {0x9e07003b, 0xcebb012b, 0xa3b70167, 0x00000000}},  //   ичал, вља_, _پاور_,
  { {0x70270044, 0x33db009b, 0x7ae0170e, 0x00000000}},  //   য়েও_, _בחוד, _nimt,
  { {0x629d001a, 0xe1ff0f11, 0x7e6d01b1, 0x00000000}},  // [2e10] miso, mbó_, rjap,
  { {0x629d00b0, 0xfd4d001d, 0x91bc009b, 0x00000000}},  //   liso, _khoả, _במחי,
  { {0x69c00f57, 0x7ae00022, 0x00000000, 0x00000000}},  //   _ayme, _bimt,   ,
  { {0x67230020, 0x629d0161, 0x69c00007, 0x00000000}},  //   vunj, niso, _byme,
  { {0x2731001d, 0x69c0018e, 0xc87900e5, 0x00000000}},  //   _sơn_, _cyme, _huşi_,
  { {0x6c850054, 0x67230169, 0x00000000, 0x00000000}},  //   _السم, tunj,   ,
  { {0x629d0883, 0x3e7c00b9, 0x00000000, 0x00000000}},  //   kiso, _síti_,   ,
  { {0x9aa5007a, 0x7ae00006, 0x629d170f, 0x00000000}},  //   _امرو, _gimt, jiso,
  { {0xddc60046, 0x69c00016, 0x629d071e, 0x00000000}},  //   _zakł, _gyme, diso,
  { {0xd8740054, 0xb4c3001c, 0x67230091, 0x00000000}},  //   _والب, ्षे_, punj,
  { {0xdb1c00f4, 0x91e60581, 0xe3b10025, 0x00000000}},  //   _pyré, йоне, ثرة_,
  { {0x68e113e4, 0xeb3a0049, 0x629d09a3, 0x00000000}},  //   _hild, נערש, giso,
  { {0x68e101e3, 0x940c006b, 0x00000000, 0x00000000}},  //   _kild, hidə_,   ,
  { {0x037900e9, 0x940c006b, 0x629d0068, 0x00000000}},  //   _محبت_, kidə_, aiso,
  { {0xe3b30070, 0x00000000, 0x00000000, 0x00000000}},  //   _برش_,   ,   ,
  { {0x629d00c4, 0x681b0089, 0x394d0068, 0x00000000}},  //   ciso, lādē, _oses_,
  { {0x7ae00006, 0x00000000, 0x00000000, 0x00000000}},  // [2e20] _rimt,   ,   ,
  { {0x7ae91710, 0x7ae01711, 0xcb6a003b, 0x00000000}},  //   _četr, _simt, лазе_,
  { {0x394d004a, 0x69c01712, 0x80b60061, 0x00000000}},  //   _ases_, _syme, ृतीं,
  { {0x7f3b0049, 0x69c0008e, 0x68e10016, 0x00000000}},  //   _געטו, _pyme, _aild,
  { {0x39130088, 0xb5fd00ca, 0x44fb0325, 0x00000000}},  //   змір, njšu, _nª_,
  { {0xbcfb000c, 0x96f8007e, 0x68e11713, 0x00000000}},  //   _bréf, аект_, _cild,
  { {0xd6d00647, 0x68e1049d, 0xbb860025, 0x00000000}},  //   وقت_, _dild, _الأي,
  { {0x44f40175, 0x629d1714, 0xdd080027, 0x00000000}},  //   опис, xiso, _môže,
  { {0xc9aa008b, 0x68e100f8, 0x68e900c4, 0x00000000}},  //   _свае_, _fild, _gued,
  { {0x68e1009f, 0x0466012b, 0x629d005b, 0x00000000}},  //   _gild, стим, wiso,
  { {0x629d00b0, 0x291903b1, 0x00000000, 0x00000000}},  //   tiso, _åsar_,   ,
  { {0x68e100c4, 0x00000000, 0x00000000, 0x00000000}},  //   _zild,   ,   ,
  { {0x787d0263, 0x629d0835, 0xe1ff1715, 0x00000000}},  //   _sèvi, riso, rbó_,
  { {0x629d0a5b, 0xfd4d0011, 0x7d1f0045, 0x00000000}},  //   siso, _thoả, vrqs,
  { {0x629d0b41, 0x66d50006, 0xe437009b, 0x00000000}},  //   piso, _iškr, _הרוח_,
  { {0x442e0203, 0x7c2e00fa, 0x6e94019d, 0x00000000}},  //   _hcf_, _acbr, пису,
  { {0xe29f009f, 0x5c750745, 0xcc99003b, 0x00000000}},  // [2e30] mið_, олат, авац_,
  { {0xe29f009f, 0x68e91716, 0x00000000, 0x00000000}},  //   lið_, _rued,   ,
  { {0x68e91717, 0xda7b0245, 0xa036009b, 0x00000000}},  //   _sued, ляд_, _ואתה_,
  { {0x68e91718, 0x66f1001e, 0xe29f009f, 0x00000000}},  //   _pued, _nāka, nið_,
  { {0x68e91719, 0x68e10004, 0xa969012b, 0x00000000}},  //   _qued, _pild, рила_,
  { {0x46f50072, 0xbcfb028c, 0x26c40197, 0x00000000}},  //   очит, _préf, elmo_,
  { {0xe29f009f, 0x68e103b4, 0x3ea905f7, 0x00000000}},  //   kið_, _vild, onat_,
  { {0x3ea9171a, 0x68e10f12, 0x68e90016, 0x00000000}},  //   nnat_, _wild, _tued,
  { {0x68e101e3, 0xe29f000c, 0x394d00ab, 0x00000000}},  //   _tild, dið_, _uses_,
  { {0x442e02d0, 0x3ea9171b, 0x68e10026, 0x00000000}},  //   _ccf_, hnat_, _uild,
  { {0xe29f009f, 0x37ab0088, 0x442e171c, 0x00000000}},  //   fið_, _стан_, _dcf_,
  { {0x6d4f002a, 0xe29f009f, 0x6d5d0039, 0x00000000}},  //   _osca, gið_, _orsa,
  { {0x3ea900b9, 0xa509007c, 0x442e0009, 0x00000000}},  //   dnat_, _тела_, _fcf_,
  { {0x394002b9, 0x6e3d171d, 0x00000000, 0x00000000}},  //   çisi_, _absb,   ,
  { {0x6d5d101d, 0x6d4f171e, 0xe3d70044, 0x00000000}},  //   _arsa, _asca, _দ্রব,
  { {0x3ea900f6, 0xd5f90049, 0x6d5d0145, 0x00000000}},  //   gnat_, שפּר, _brsa,
  { {0x660b0047, 0x3ce300b5, 0x648d0051, 0x00000000}},  // [2e40] _megk, _bijv_, _cúig,
  { {0x852103d7, 0x660b171f, 0xa7fc01df, 0x00000000}},  //   _मिनट_, _legk, _anın,
  { {0x6d5d1720, 0x3ea91721, 0xbddb0173, 0x00000000}},  //   _ersa, bnat_, _abèd,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbcfb1722, 0x82d70049, 0x00000000, 0x00000000}},  //   _créd, קונג_,   ,
  { {0x3ea01723, 0xb4b3013d, 0x66f10089, 0x00000000}},  //   liit_, झको_, _sāka,
  { {0x443c00d9, 0x2a640022, 0x442e1724, 0x00000000}},  //   _rbv_, _tnmb_, _rcf_,
  { {0x7bce1140, 0xbcfb00f4, 0x9f58008e, 0x00000000}},  //   _izbu, _fréd, laró_,
  { {0x442e0f36, 0x94aa00ed, 0x2d801725, 0x00000000}},  //   _pcf_, итоа_, nyie_,
  { {0x3ea90e25, 0x3ead10f7, 0x7a40000c, 0x00000000}},  //   znat_, četi_, _fátæ,
  { {0xe29f009f, 0x249e0035, 0x442e01a2, 0x00000000}},  //   tið_, ritm_, _vcf_,
  { {0x442e0066, 0x81af0044, 0x00000000, 0x00000000}},  //   _wcf_, _করব_,   ,
  { {0xe29f0359, 0x3ea90802, 0x443c00d9, 0x00000000}},  //   rið_, vnat_, _tbv_,
  { {0xe29f009f, 0xf8ca013d, 0x443c00d6, 0x00000000}},  //   sið_, ितिय, _ubv_,
  { {0xc05801fb, 0x4fc40099, 0x3f850161, 0x00000000}},  //   ція_, дста, álu_,
  { {0x64481726, 0xe2980080, 0x82f700a6, 0x00000000}},  //   ledi, _мај_, _بروز_,
  { {0x3ea90a16, 0x442c00bb, 0x2d58007c, 0x00000000}},  // [2e50] rnat_, ogd_, оить_,
  { {0x6448018e, 0x442c03ed, 0x4d9807d0, 0x00000000}},  //   nedi, ngd_, цкую_,
  { {0x20111727, 0x442c00b5, 0x3ea91728, 0x00000000}},  //   mazi_, igd_, pnat_,
  { {0x20110119, 0xbcfb1729, 0x6448172a, 0x00000000}},  //   lazi_, _préd, hedi,
  { {0x6d4f172b, 0x64480792, 0x6d5d010f, 0x00000000}},  //   _usca, kedi, _ursa,
  { {0x64480363, 0xbcfb028c, 0x1fdf0044, 0x00000000}},  //   jedi, _crée, _ব্যস,
  { {0x64480016, 0x6d4d0112, 0xf7730445, 0x00000000}},  //   dedi, lwaa, باش_,
  { {0x6e2d0f4f, 0x201100e7, 0xbcfb0051, 0x00000000}},  //   ngab, hazi_, _tréd,
  { {0x2011000b, 0x64480adc, 0x6d4d172c, 0x00000000}},  //   kazi_, fedi, nwaa,
  { {0x660b172d, 0x442c0039, 0xa3cf0309, 0x00000000}},  //   _wegk, ggd_, _शरद_,
  { {0xe7f0013d, 0x395f0022, 0x779000a2, 0x00000000}},  //   _चलता_, _hrus_, _لیوا,
  { {0x442c00b5, 0x6d4d01a3, 0x395f172e, 0x00000000}},  //   agd_, kwaa, _krus_,
  { {0x6448172f, 0x6e2d0b5a, 0x6f150036, 0x00000000}},  //   bedi, dgab, eszc,
  { {0x644806c2, 0xb4fa009b, 0x6e2d0197, 0x00000000}},  //   cedi, _הפסי, egab,
  { {0x6e2d010f, 0x66f10089, 0x75290035, 0x00000000}},  //   fgab, _māko, luez,
  { {0x68fb0107, 0x628f0082, 0x88d10044, 0x00000000}},  //   _otud, chco, াদিক,
  { {0x2011002d, 0x9f580129, 0x4c8601fc, 0x00000000}},  // [2e60] bazi_, taró_, плав,
  { {0x313700b6, 0x66f10089, 0x3ea011f6, 0x00000000}},  //   _צריך_, _nāko, siit_,
  { {0x307b00b6, 0x395f0169, 0x6e2d01a2, 0x00000000}},  //   _האינ, _arus_, bgab,
  { {0x316004cd, 0x62860056, 0x64480232, 0x00000000}},  //   _kriz_, nkko, zedi,
  { {0x442c1730, 0x9f58008e, 0xb9e30088, 0x00000000}},  //   ygd_, paró_, ніши,
  { {0x7d1600ea, 0x644800d9, 0x648d0048, 0x00000000}},  //   msys, xedi, _lúib,
  { {0x68fb00f4, 0xa7370025, 0x64480738, 0x00000000}},  //   _etud, كثير_, vedi,
  { {0xd90d089d, 0x2011000b, 0x64480016, 0x00000000}},  //   _چین_, zazi_, wedi,
  { {0x6448011f, 0x7d16010f, 0x75290032, 0x00000000}},  //   tedi, nsys, guez,
  { {0x6aa20020, 0x6f150036, 0xc9170097, 0x00000000}},  //   liof, yszc, _מחמת_,
  { {0x442c00b5, 0x20110020, 0x6d4d00b5, 0x00000000}},  //   rgd_, vazi_, zwaa,
  { {0x20111731, 0xa25b00f4, 0x31601732, 0x00000000}},  //   wazi_, plôm, _briz_,
  { {0x2011001a, 0xd6270088, 0x00000000, 0x00000000}},  //   tazi_, _хоче_,   ,
  { {0xe4d70014, 0xe3af0123, 0x44f2005b, 0x00000000}},  //   _فونت_, ئری_, _iâ_,
  { {0x2011022b, 0x643b009b, 0x543b0049, 0x00000000}},  //   razi_, _העונ, _לעגא,
  { {0x6d4d0112, 0x8c090044, 0x31601733, 0x00000000}},  //   twaa, _লাইন_, _friz_,
  { {0x6e2d1073, 0x7d160270, 0x6d4d00e0, 0x00000000}},  // [2e70] rgab, gsys, uwaa,
  { {0x6d4d015c, 0x6e2d125c, 0x787d009d, 0x00000000}},  //   rwaa, sgab, _lèvr,
  { {0x81af0055, 0x6d4d0b36, 0x29000035, 0x00000000}},  //   _করি_, swaa, ţial_,
  { {0x7aee0129, 0xfbd00025, 0x66f10089, 0x00000000}},  //   _dubt, اتك_, _sāko,
  { {0x81df0044, 0x5c07094b, 0x44f20544, 0x00000000}},  //   দুর_, _нява, _nâ_,
  { {0x81af08b7, 0x224b01a2, 0xccf2009b, 0x00000000}},  //   _করা_, heck_, _בכך_,
  { {0xe7391734, 0x00000000, 0x00000000, 0x00000000}},  //   цей_,   ,   ,
  { {0x395f0169, 0x61e911cc, 0xbcfb0142, 0x00000000}},  //   _trus_, želj, _gréc,
  { {0xb34502d5, 0x09db0044, 0x7d29006b, 0x00000000}},  //   _opçã, _ড্রা, əssü,
  { {0xdeff01d5, 0xb21b0190, 0x628d0052, 0x00000000}},  //   ċċju_, skæl, _alao,
  { {0xdc380049, 0x78a300ca, 0x00000000, 0x00000000}},  //   לאזט_, minv,   ,
  { {0x628d0051, 0x316006af, 0x78a30052, 0x00000000}},  //   _clao, _priz_, linv,
  { {0x6286021e, 0x7529029d, 0x7d160203, 0x00000000}},  //   rkko, quez, xsys,
  { {0x62860004, 0x92ae0055, 0x78a30052, 0x00000000}},  //   skko, কতে_, ninv,
  { {0x1fb50256, 0x81df0044, 0x224b01a2, 0x00000000}},  //   естр, দুল_, beck_,
  { {0xee3a008b, 0x212b010f, 0x628d0051, 0x00000000}},  //   ўна_, buch_, _glao,
  { {0x7afc1735, 0xec7a00c0, 0x78a30190, 0x00000000}},  // [2e80] _strt, опа_, kinv,
  { {0x79820020, 0x00000000, 0x00000000, 0x00000000}},  //   vyow,   ,   ,
  { {0xbcfb028c, 0x00000000, 0x00000000, 0x00000000}},  //   _préc,   ,   ,
  { {0x8b650025, 0x49ca1736, 0x1e831737, 0x00000000}},  //   عالم, олен_, _алюм,
  { {0xd910007a, 0x6aa20197, 0x7bc7000c, 0x00000000}},  //   ایط_, riof, _eyju,
  { {0x787d009d, 0x6aa21738, 0x78a3141a, 0x00000000}},  //   _sèvr, siof, ginv,
  { {0x44f20035, 0x00000000, 0x00000000, 0x00000000}},  //   _sâ_,   ,   ,
  { {0xdb0e0036, 0x7c3e0253, 0xdced0095, 0x00000000}},  //   _wybó, lfpr, nyağ,
  { {0xfaa3003b, 0xfbb00044, 0x00000000, 0x00000000}},  //   _рато, _করিত,   ,
  { {0x337400c0, 0xb8661739, 0x00000000, 0x00000000}},  //   егор, _تارو,   ,
  { {0xe8ca0061, 0xd2510076, 0x224b01a2, 0x00000000}},  //   ितीच, هند_, teck_,
  { {0x68e80339, 0x6d460190, 0x3267173a, 0x00000000}},  //   _hidd, _opka, фтов,
  { {0x68e8173b, 0x656f010f, 0xbcfb009d, 0x00000000}},  //   _kidd, ächt, _oréa,
  { {0x5577007b, 0x212b010f, 0x68e802c0, 0x00000000}},  //   _קעגן_, ruch_, _jidd,
  { {0x68e80141, 0x212b010f, 0x6d4608ad, 0x00000000}},  //   _midd, such_, _apka,
  { {0x645803db, 0x443e173c, 0x645a0190, 0x00000000}},  //   _havi, lft_, ldti,
  { {0x6458173d, 0x7bca010f, 0xbcfb0051, 0x00000000}},  // [2e90] _kavi, üfun, _bréa,
  { {0xbcfb028c, 0x443e001f, 0x68e8002b, 0x00000000}},  //   _créa, nft_, _nidd,
  { {0x64580334, 0x443e173e, 0xbcfb0051, 0x00000000}},  //   _mavi, ift_, _dréa,
  { {0x64580263, 0x41d301f5, 0x68e8006b, 0x00000000}},  //   _lavi, _सरास, _aidd,
  { {0xdb1c01ca, 0x78a31603, 0xbcfb0048, 0x00000000}},  //   _vyrá, tinv, _fréa,
  { {0xbcfb002a, 0x68e8038c, 0x443e02ae, 0x00000000}},  //   _gréa, _cidd, jft_,
  { {0x68e8018e, 0x78a30f80, 0xf09400b3, 0x00000000}},  //   _didd, rinv, כנס_,
  { {0x443e173f, 0x61ed1740, 0x68e8018e, 0x00000000}},  //   eft_, _ngal, _eidd,
  { {0x443e1741, 0x64580091, 0x7e7d0065, 0x00000000}},  //   fft_, _bavi, _mosp,
  { {0x64581352, 0x68e81742, 0xe1fa02d2, 0x00000000}},  //   _cavi, _gidd, ूर्ण_,
  { {0x64581743, 0x53c90088, 0x7ae90006, 0x00000000}},  //   _davi, ягом_, _kiet,
  { {0xb607008b, 0x7e7d0089, 0x68e8006b, 0x00000000}},  //   _цяжк, _nosp, _zidd,
  { {0x7ae91744, 0x64580061, 0x656205e8, 0x00000000}},  //   _miet, _favi, _groh,
  { {0x7ae91745, 0x6458007f, 0x61ed00e5, 0x00000000}},  //   _liet, _gavi, _egal,
  { {0x7e7d01d6, 0xb4cb00e8, 0xf8b2009b, 0x00000000}},  //   _bosp, लती_, אשם_,
  { {0x7ae902ae, 0x64580b54, 0x7e7d1746, 0x00000000}},  //   _niet, _zavi, _cosp,
  { {0x7e7d0161, 0xbcfb0aea, 0x753b0266, 0x00000000}},  // [2ea0] _dosp, _préa, ntuz,
  { {0x64580129, 0xe0d2002c, 0x32120199, 0x00000000}},  //   _xavi, _حزب_, _heyy_,
  { {0x7ae903a8, 0xa09b0049, 0xcb090088, 0x00000000}},  //   _biet, _זייט, дхід_,
  { {0x68e80030, 0xc332009b, 0x7ae90089, 0x00000000}},  //   _sidd, רוא_, _ciet,
  { {0xe94700a1, 0x753b016c, 0x64430036, 0x00000000}},  //   ٹرنی, jtuz, _obni,
  { {0x7ae901d6, 0x64430066, 0xe8ca0061, 0x00000000}},  //   _eiet, _nbni, ितेच,
  { {0x64580368, 0x7ae90dbc, 0x7d040197, 0x00000000}},  //   _ravi, _fiet, lpis,
  { {0x64580a5c, 0xd6d703c8, 0x7d0400b0, 0x00000000}},  //   _savi, нты_, opis,
  { {0x64580ba5, 0xe4a6004c, 0xa90a006d, 0x00000000}},  //   _pavi, ерно, _ريال_,
  { {0xd91b00b6, 0x443e010f, 0x81af0044, 0x00000000}},  //   _מומל, uft_, _করল_,
  { {0x443e000c, 0x645a00eb, 0x229501e0, 0x00000000}},  //   rft_, rdti, виня,
  { {0x273a0065, 0xda10006e, 0x64580908, 0x00000000}},  //   mën_, ारित_, _wavi,
  { {0x273a008d, 0xd251007a, 0x1a9b007b, 0x00000000}},  //   lën_, هنگ_, ליטע,
  { {0x7e7d0207, 0x7d040b41, 0xe73100a1, 0x00000000}},  //   _sosp, dpis, _حصے_,
  { {0xd904026c, 0x7e7d0627, 0x273a008d, 0x00000000}},  //   _گی_, _posp, nën_,
  { {0x61ed0f2f, 0x00000000, 0x00000000, 0x00000000}},  //   _ugal,   ,   ,
  { {0xd904089d, 0x273a008d, 0x7ae90dec, 0x00000000}},  // [2eb0] _دی_, hën_, _riet,
  { {0x7ae90253, 0x273a008d, 0x387e00ca, 0x00000000}},  //   _siet, kën_, _notr_,
  { {0x7ae9001e, 0x273a0065, 0xb09c01ce, 0x00000000}},  //   _piet, jën_, _מיזר,
  { {0xed51026c, 0x273a0065, 0x7e7d012d, 0x00000000}},  //   _پھر_, dën_, _uosp,
  { {0x7ae90ba5, 0xe8f80245, 0x273a00b5, 0x00000000}},  //   _viet, елі_, eën_,
  { {0x07a506e1, 0x2ca5000c, 0x5c140123, 0x00000000}},  //   калн, _öld_, _مظفر,
  { {0x7ae91747, 0x648d009f, 0x273a0065, 0x00000000}},  //   _tiet, _búin, gën_,
  { {0xdddd001e, 0xd90c025a, 0xf1bf1748, 0x00000000}},  //   _nosū, _کیو_, ngás_,
  { {0x648d002a, 0x765b0996, 0x387e00ca, 0x00000000}},  //   _dúin, rduy, _fotr_,
  { {0xb4cb006e, 0x273a0023, 0x765901c3, 0x00000000}},  //   लते_, bën_, _wawy,
  { {0x753b15bc, 0x7d040059, 0x273a0065, 0x00000000}},  //   stuz, zpis, cën_,
  { {0x7d040cba, 0x00000000, 0x00000000, 0x00000000}},  //   ypis,   ,   ,
  { {0xe29704af, 0x660901a3, 0x00000000, 0x00000000}},  //   тая_, mbek,   ,
  { {0x9345026b, 0xbcfb00f4, 0xa28400a1, 0x00000000}},  //   _анке, _prén, ئیکو,
  { {0xc059008b, 0x00000000, 0x00000000, 0x00000000}},  //   хіў_,   ,   ,
  { {0xe3e8007b, 0x7d040091, 0x644101a2, 0x00000000}},  //   _אַפֿ, tpis, lfli,
  { {0x7bd50207, 0xdee300ed, 0x273a0065, 0x00000000}},  // [2ec0] _azzu, роти, zën_,
  { {0x0cbe013d, 0x7d0404cb, 0x2a6d0802, 0x00000000}},  //   ्तेम, rpis, _aneb_,
  { {0x20180129, 0x6609012b, 0x91f6013d, 0x00000000}},  //   mari_, kbek, _इलाज_,
  { {0x201816df, 0x273a0065, 0x7d0403b6, 0x00000000}},  //   lari_, vën_, ppis,
  { {0x2a7f01aa, 0xdb0e0039, 0x66090240, 0x00000000}},  //   _doub_, _nybö, dbek,
  { {0x2018022b, 0x273a008d, 0xfc03004c, 0x00000000}},  //   nari_, tën_, _впро,
  { {0xdca3004c, 0xd6da0184, 0xdb1c080a, 0x00000000}},  //   _тари, мти_, _byrå,
  { {0x20180281, 0x273a008d, 0x6b8303a9, 0x00000000}},  //   hari_, rën_, änge,
  { {0x20180ad4, 0x273a008d, 0xd946012b, 0x00000000}},  //   kari_, sën_, _јези,
  { {0x20181749, 0x273a0065, 0x3eb200b0, 0x00000000}},  //   jari_, pën_, hnyt_,
  { {0x201801a3, 0x75290197, 0x273a0065, 0x00000000}},  //   dari_, arez, qën_,
  { {0x75290325, 0x26cd174a, 0x26c60020, 0x00000000}},  //   brez, cleo_, _ukoo_,
  { {0x7529174b, 0x2018174c, 0x00000000, 0x00000000}},  //   crez, fari_,   ,
  { {0x2b580061, 0x26c4174d, 0x4ec40055, 0x00000000}},  //   _osrc_, lomo_, ্দোল,
  { {0xbcfb009d, 0x14b101f5, 0x78ad009d, 0x00000000}},  //   _préo, ीकरण, éavi,
  { {0x26c4049a, 0xceb8003b, 0x5eb4174e, 0x00000000}},  //   nomo_, вљу_, айст,
  { {0x20180be3, 0x00000000, 0x00000000, 0x00000000}},  // [2ed0] bari_,   ,   ,
  { {0x660900d9, 0x00000000, 0x00000000, 0x00000000}},  //   zbek,   ,   ,
  { {0x26c40416, 0x2b580022, 0x00000000, 0x00000000}},  //   komo_, _csrc_,   ,
  { {0x3e04005e, 0x00000000, 0x00000000, 0x00000000}},  //   _вярв,   ,   ,
  { {0x26c40036, 0xf9900379, 0x3ea900d4, 0x00000000}},  //   domo_, يبه_, miat_,
  { {0x475901e0, 0x2b580009, 0x7c871364, 0x00000000}},  //   ерия_, _fsrc_, _руме,
  { {0x46a5005e, 0x2bc80e75, 0x660901a2, 0x00000000}},  //   лакв, _ауто_, tbek,
  { {0x201804f8, 0x75290eb5, 0xcc1400a1, 0x00000000}},  //   zari_, trez, _مذہب,
  { {0xd41503c8, 0x2018174f, 0x66090513, 0x00000000}},  //   льны, yari_, rbek,
  { {0x13090057, 0x7529022b, 0x3ea90035, 0x00000000}},  //   нной_, rrez, hiat_,
  { {0x201801cd, 0x26cd0219, 0x6441037f, 0x00000000}},  //   vari_, pleo_, rfli,
  { {0x2018107e, 0x26c40207, 0x644101d6, 0x00000000}},  //   wari_, como_, sfli,
  { {0x3ea9001a, 0xe56e012b, 0x291d01aa, 0x00000000}},  //   diat_, _уз_, nswa_,
  { {0x03190054, 0x291f0020, 0xbcfb009d, 0x00000000}},  //   _كتبت_, _mvua_, _crém,
  { {0x20180982, 0x212b001c, 0x3eb20146, 0x00000000}},  //   rari_, arch_, tnyt_,
  { {0x3ea901a3, 0xe3b0023c, 0x00000000, 0x00000000}},  //   giat_, _بره_,   ,
  { {0xcbb00055, 0x20180010, 0x8d660eb1, 0x00000000}},  // [2ee0] _করেছ, pari_, ывае,
  { {0x7af50032, 0x26c400e7, 0x00000000, 0x00000000}},  //   _buzt, zomo_,   ,
  { {0x4b260175, 0x1bba0025, 0x26c40020, 0x00000000}},  //   умев, رائع_, yomo_,
  { {0x3ea905f7, 0x648d0051, 0x00000000, 0x00000000}},  //   ciat_, _súil,   ,
  { {0xa9670867, 0x229200b9, 0x00000000, 0x00000000}},  //   лица_, ušky_,   ,
  { {0x62960023, 0x321900b4, 0xbddb000a, 0x00000000}},  //   ëzoj, zasy_, _obèj,
  { {0x7af5022b, 0x26c41750, 0x29060032, 0x00000000}},  //   _guzt, tomo_, spoa_,
  { {0x21200119, 0x7f3b007b, 0x212b0016, 0x00000000}},  //   _ovih_, געקו, yrch_,
  { {0xa836025a, 0x1836031d, 0x7ae20052, 0x00000000}},  //   _معاش, _مراح, mmot,
  { {0xb9930054, 0x26c40020, 0xb80a0025, 0x00000000}},  //   _الكب, somo_, _أيام_,
  { {0x61ea006b, 0x04630930, 0x212b005b, 0x00000000}},  //   əllə, стым, wrch_,
  { {0x7bce01d6, 0x9258007c, 0x6b8100f6, 0x00000000}},  //   _mybu, гают_, _àlge,
  { {0x3ea90129, 0xe5a30098, 0xbddb000a, 0x00000000}},  //   viat_, _лици, _ebèj,
  { {0x92b50055, 0x859b034e, 0xe3a40014, 0x00000000}},  //   ঝতে_, _אשדו, _پشتی,
  { {0x7ae200f8, 0x3ea911eb, 0x15d700a1, 0x00000000}},  //   kmot, tiat_, _لگیں_,
  { {0x5e5801fb, 0x64840045, 0x25a904eb, 0x00000000}},  //   лися_, _tòis, _žali_,
  { {0xbcfb0923, 0x00000000, 0x00000000, 0x00000000}},  // [2ef0] _trém,   ,   ,
  { {0xe1ff0d62, 0x3ea901a3, 0x7af50032, 0x00000000}},  //   lcó_, siat_, _puzt,
  { {0x60c71751, 0x75eb0010, 0x3ea900e5, 0x00000000}},  //   mojm, _közü, piat_,
  { {0x628f0e9c, 0x7ae2130e, 0xe1ff008e, 0x00000000}},  //   nkco, gmot, ncó_,
  { {0x22490093, 0x00000000, 0x00000000, 0x00000000}},  //   _mbak_,   ,   ,
  { {0x316900ca, 0x60c70065, 0xf77101af, 0x00000000}},  //   _mraz_, nojm, قاب_,
  { {0x7ae200c4, 0xdd0e0095, 0x00000000, 0x00000000}},  //   bmot, _kışl,   ,
  { {0x31690046, 0x06850216, 0xa525017f, 0x00000000}},  //   _oraz_, ргин, амид,
  { {0x60c71752, 0xef190036, 0x04190044, 0x00000000}},  //   kojm, ąży_, _দাবী_,
  { {0x66f1001e, 0xbcfb009d, 0x60c70023, 0x00000000}},  //   _sāku, _préj, jojm,
  { {0xe29a102a, 0x21200119, 0x798b0016, 0x00000000}},  //   ван_, _svih_, lygw,
  { {0x91e60256, 0x316900c4, 0x61fa013e, 0x00000000}},  //   ионе, _braz_, ětlo,
  { {0x6f050051, 0x7d090023, 0x75eb013f, 0x00000000}},  //   _athc, _çesh, _dözü,
  { {0x661b1082, 0x31690521, 0x60c70023, 0x00000000}},  //   lauk, _draz_, gojm,
  { {0x44fb1753, 0x7ae21754, 0x23760063, 0x00000000}},  //   _hê_, ymot, _نمود_,
  { {0x661b1755, 0x44fb001d, 0x628f0019, 0x00000000}},  //   nauk, _kê_, ckco,
  { {0x316901a2, 0x6e361756, 0x00000000, 0x00000000}},  // [2f00] _graz_, rgyb,   ,
  { {0x44fb0011, 0x6e36018e, 0x661b1757, 0x00000000}},  //   _mê_, sgyb, hauk,
  { {0x44fb1758, 0x66f1001e, 0x394d01c5, 0x00000000}},  //   _lê_, _māks, _apes_,
  { {0x661b1759, 0x4fbb0104, 0x6b830039, 0x00000000}},  //   jauk, _יציא, änga,
  { {0x7ae204cb, 0x44fb160d, 0x661b002d, 0x00000000}},  //   rmot, _nê_, dauk,
  { {0x9915008b, 0x62840032, 0x00000000, 0x00000000}},  //   сьці, _loio,   ,
  { {0x78aa053d, 0x44fb00fa, 0x00000000, 0x00000000}},  //   rifv, _aê_,   ,
  { {0x44fb0011, 0x35460088, 0x62840197, 0x00000000}},  //   _bê_, ахов, _noio,
  { {0x66f10089, 0x44fb00fa, 0x245b007f, 0x00000000}},  //   _sākt, _cê_, kšmė_,
  { {0x07a601fc, 0x44fb0701, 0x75eb0279, 0x00000000}},  //   _казн, _dê_, _sözü,
  { {0x3169013e, 0x2bf700a0, 0x60c70023, 0x00000000}},  //   _sraz_, ימין_, vojm,
  { {0x31690375, 0x661b0022, 0x44fb1612, 0x00000000}},  //   _praz_, cauk, _fê_,
  { {0x60c70065, 0xe1ff02a0, 0x628f00d9, 0x00000000}},  //   tojm, rcó_, rkco,
  { {0xe1ff175a, 0x00000000, 0x00000000, 0x00000000}},  //   scó_,   ,   ,
  { {0xd4c50025, 0x443c0129, 0x62960606, 0x00000000}},  //   _اغني, _icv_, _flyo,
  { {0x443c05e6, 0x31690181, 0x60c70065, 0x00000000}},  //   _hcv_, _traz_, sojm,
  { {0x44fb0082, 0x60c709fc, 0x9df80140, 0x00000000}},  // [2f10] _xê_, pojm, рнут_,
  { {0x705506c6, 0xcc74012b, 0x7d020048, 0x00000000}},  //   _اندا, огућ, íosa,
  { {0x443c175b, 0x394d01e5, 0x6a170025, 0x00000000}},  //   _mcv_, _spes_, لبشر,
  { {0x99d90025, 0x00000000, 0x00000000, 0x00000000}},  //   هواء_,   ,   ,
  { {0x661b175c, 0x00000000, 0x00000000, 0x00000000}},  //   vauk,   ,   ,
  { {0x88c801fb, 0x6d5d0bd5, 0xab87132a, 0x00000000}},  //   алів_, _issa, _кубк,
  { {0xfbe508b7, 0x44fb1273, 0xbb850054, 0x00000000}},  //   _প্রত, _sê_, _الزي,
  { {0x443c00d9, 0xcfb8009b, 0xbcfb1059, 0x00000000}},  //   _acv_, ילוי_, _préh,
  { {0x661b0ba5, 0x056801f9, 0xa3e40316, 0x00000000}},  //   rauk, ајќи_, पेस_,
  { {0x661b001e, 0x44fb175d, 0xbcfb0129, 0x00000000}},  //   sauk, _vê_, _créi,
  { {0x661b00b0, 0xe6430279, 0xb4d70061, 0x00000000}},  //   pauk, şmış, _ाठी_,
  { {0x44fb08c6, 0xc7b2009b, 0x644a0009, 0x00000000}},  //   _tê_, _צבא_, _ebfi,
  { {0x75220107, 0xd6c6007a, 0xe3b100a2, 0x00000000}},  //   _gvoz, _امنی, ترک_,
  { {0xbcfb0051, 0x4095005e, 0x443c05d2, 0x00000000}},  //   _gréi, орст, _gcv_,
  { {0xdfd20379, 0x00000000, 0x00000000, 0x00000000}},  //   سير_,   ,   ,
  { {0xb21b0030, 0x00000000, 0x00000000, 0x00000000}},  //   skær,   ,   ,
  { {0x6b830a5d, 0x0c260088, 0xa2c5007d, 0x00000000}},  // [2f20] ängn, йман, रवर्,
  { {0x6aa90020, 0x4427009d, 0x8db50088, 0x00000000}},  //   _amef, _jdn_, істі,
  { {0x6d5d028c, 0x0b4601fb, 0xa3db0061, 0x00000000}},  //   _essa, снен, ढेच_,
  { {0x66190ace, 0xc33200b3, 0x442700d2, 0x00000000}},  //   _newk, לוב_, _ldn_,
  { {0xda65006d, 0x6abb0022, 0x823b0049, 0x00000000}},  //   تالي, _djuf, רענצ,
  { {0xddcd0477, 0xc7b000a1, 0x764b00e5, 0x00000000}},  //   ldaş, وڑا_, _abgy,
  { {0x6d44175e, 0x656b175f, 0x9f58008e, 0x00000000}},  //   ltia, _argh, mbró_,
  { {0xddcd0279, 0x201a0925, 0x7e64006c, 0x00000000}},  //   ndaş, _lepi_, ndip,
  { {0xbcfb124d, 0x44270145, 0x661d000c, 0x00000000}},  //   _préi, _bdn_, ðska,
  { {0x44270061, 0x81ae0044, 0x6d441760, 0x00000000}},  //   _cdn_, কথা_, itia,
  { {0x6d441761, 0xddcd0276, 0x00000000, 0x00000000}},  //   htia, kdaş,   ,
  { {0x6d4409e4, 0x44270ca4, 0x00000000, 0x00000000}},  //   ktia, _edn_,   ,
  { {0xe298008b, 0x752212ac, 0xbcfb002a, 0x00000000}},  //   саў_, _uvoz, _tréi,
  { {0x443c004a, 0x00000000, 0x00000000, 0x00000000}},  //   _ucv_,   ,   ,
  { {0x201a0263, 0xddcd006b, 0x6d5d00e0, 0x00000000}},  //   _depi_, fdaş, _sssa,
  { {0x644801d6, 0x6d441762, 0x66190066, 0x00000000}},  //   lfdi, ftia, _xewk,
  { {0x6d440058, 0x00000000, 0x00000000, 0x00000000}},  // [2f30] gtia,   ,   ,
  { {0x44270061, 0x2caa00f6, 0x00000000, 0x00000000}},  //   _xdn_, _cmbd_,   ,
  { {0xd9f9026b, 0x6d441763, 0x00000000, 0x00000000}},  //   анец_, atia,   ,
  { {0x70550063, 0x629d0082, 0x00000000, 0x00000000}},  //   _انگا, nhso,   ,
  { {0xa92401fb, 0x6d5d01c3, 0x6d4f0085, 0x00000000}},  //   зділ, _ussa, _upca,
  { {0x20030046, 0x186900ed, 0xd7091764, 0x00000000}},  //   ncji_, раки_, анке_,
  { {0x7d0d1765, 0x00000000, 0x00000000, 0x00000000}},  //   lpas,   ,   ,
  { {0x442701a3, 0x6aa90020, 0x941e013f, 0x00000000}},  //   _sdn_, _umef, mitə_,
  { {0x20030046, 0x7d0d1766, 0x44270085, 0x00000000}},  //   kcji_, npas, _pdn_,
  { {0x395f1767, 0x8d5c00b3, 0x00000000, 0x00000000}},  //   _isus_, רכזי,   ,
  { {0x6d44022b, 0xddcd0477, 0x65640087, 0x00000000}},  //   ztia, ydaş, _šiht,
  { {0x68fb01b0, 0x7d0d04be, 0x201a04cb, 0x00000000}},  //   _kuud, kpas, _sepi_,
  { {0x7d0d00bb, 0x68fb0934, 0x656b0048, 0x00000000}},  //   jpas, _juud, _urgh,
  { {0x68fb0004, 0xa06a008b, 0x00000000, 0x00000000}},  //   _muud, шага_,   ,
  { {0x7d0d1768, 0x68fb1487, 0x6723012d, 0x00000000}},  //   epas, _luud, nsnj,
  { {0x6d440dc9, 0x629d0109, 0x76490016, 0x00000000}},  //   ttia, chso, nfey,
  { {0x7d0d011c, 0xddcd006b, 0x6496001a, 0x00000000}},  // [2f40] gpas, rdaş, _mâin,
  { {0xd91000a1, 0x3a3f00f6, 0xd00a003b, 0x00000000}},  //   ہیر_, _acup_, _њене_,
  { {0x7d0d142e, 0x00000000, 0x00000000, 0x00000000}},  //   apas,   ,   ,
  { {0x6d440023, 0x00000000, 0x00000000, 0x00000000}},  //   ptia,   ,   ,
  { {0x18741769, 0x76490016, 0xc983007c, 0x00000000}},  //   згля, dfey, дущи,
  { {0xbcfb176a, 0x24870263, 0x941e006b, 0x00000000}},  //   _prév, _nonm_, bitə_,
  { {0xab271227, 0x7bdc176b, 0x00000000, 0x00000000}},  //   _мора_, _uzru,   ,
  { {0x6496001a, 0x76490016, 0x00000000, 0x00000000}},  //   _câin, gfey,   ,
  { {0x20030036, 0x22b60089, 0x7e9b00a3, 0x00000000}},  //   ycji_, cāki_, יסקו,
  { {0x7afc011f, 0x60c20051, 0x3946008f, 0x00000000}},  //   _kurt, _íomh, mtos_,
  { {0x39460325, 0xc606008b, 0x7afc01e5, 0x00000000}},  //   ltos_, _дзей, _jurt,
  { {0x7afc00b0, 0x9294008b, 0x2a64012d, 0x00000000}},  //   _murt, даюц, _jamb_,
  { {0x39460df9, 0xdb07000c, 0x506705f6, 0x00000000}},  //   ntos_, _ólög, отва,
  { {0x3946176c, 0xc0cb0783, 0x2a64176d, 0x00000000}},  //   itos_, руме_, _lamb_,
  { {0x14c70183, 0xa295007e, 0x7afc1459, 0x00000000}},  //   रकरण, _накі, _nurt,
  { {0xc333009b, 0x39460dec, 0x7d0d176e, 0x00000000}},  //   _חוק_, ktos_, tpas,
  { {0x7afc022b, 0x3ebe000c, 0x20030036, 0x00000000}},  // [2f50] _aurt, étta_, pcji_,
  { {0x7afc176f, 0x68fb003c, 0x21390023, 0x00000000}},  //   _burt, _ruud, mush_,
  { {0x68fb006c, 0x39461770, 0x7d0d0781, 0x00000000}},  //   _suud, etos_, spas,
  { {0xbcfb027b, 0x68fb0004, 0x7d0d059f, 0x00000000}},  //   _brét, _puud, ppas,
  { {0xa9690175, 0x4e7a00a0, 0xbcfb009d, 0x00000000}},  //   сила_, _הארצ, _crét,
  { {0x7afc00ab, 0xe9d8008b, 0xacfa009b, 0x00000000}},  //   _furt, цкі_, _להשכ,
  { {0x7afc0f30, 0xddcd016c, 0x64960035, 0x00000000}},  //   _gurt, njaž, _pâin,
  { {0xbcfb009f, 0x2139008d, 0xba770380, 0x00000000}},  //   _frét, kush_, _باست,
  { {0x39461771, 0x22590168, 0xc7b80521, 0x00000000}},  //   ctos_, desk_, _ređe_,
  { {0x7afc014a, 0x76490016, 0x65691772, 0x00000000}},  //   _yurt, sfey, rveh,
  { {0x61f1006b, 0xc7b8012d, 0x27070082, 0x00000000}},  //   ədlə, _peđe_, _qđnd_,
  { {0x21390022, 0x00000000, 0x00000000, 0x00000000}},  //   fush_,   ,   ,
  { {0x2139012d, 0x24870173, 0x00000000, 0x00000000}},  //   gush_, _tonm_,   ,
  { {0x648d0051, 0x00000000, 0x00000000, 0x00000000}},  //   _cúit,   ,   ,
  { {0x39460010, 0x66de0065, 0xdee60088, 0x00000000}},  //   ztos_, lëka, зови,
  { {0x21391511, 0x39460006, 0x531a0049, 0x00000000}},  //   bush_, ytos_, _פופצ,
  { {0x7afc00f4, 0xd00f026c, 0x39460df5, 0x00000000}},  // [2f60] _surt, ئلہ_, xtos_,
  { {0x7afc04b4, 0xe1ff073f, 0xc1730097, 0x00000000}},  //   _purt, ndón_, _נחת_,
  { {0xbcfb0eb4, 0x7afc006b, 0x6ffb00b3, 0x00000000}},  //   _brés, _qurt, _להיפ,
  { {0x394600c4, 0xbcfb00f4, 0x37d10044, 0x00000000}},  //   ttos_, _prét, াধার,
  { {0x394600b0, 0x00000000, 0x00000000, 0x00000000}},  //   utos_,   ,   ,
  { {0x98a301be, 0x7afc046e, 0x22b60089, 0x00000000}},  //   ниче, _turt, māku_,
  { {0xfbc301e1, 0x2a6406c0, 0x7afc00b5, 0x00000000}},  //   _збро, _tamb_, _uurt,
  { {0x39461773, 0xb9020044, 0xdb1c0036, 0x00000000}},  //   ptos_, _নং_, _wyró,
  { {0xf7f601d8, 0x7e66000a, 0x00000000, 0x00000000}},  //   _فساد, _makp,   ,
  { {0x3ebf00ca, 0x7e660022, 0x00000000, 0x00000000}},  //   čuti_, _lakp,   ,
  { {0x62351020, 0x22590190, 0x00000000, 0x00000000}},  //   мену, tesk_,   ,
  { {0x0bb70104, 0x7e6600e0, 0x5187007c, 0x00000000}},  //   ללים_, _nakp, пуга,
  { {0x22590ea9, 0x648d0051, 0xcfaa0044, 0x00000000}},  //   resk_, _cúis, _খুলন,
  { {0xa3b401fb, 0x212d01dc, 0x65621241, 0x00000000}},  //   _облі, šeho_, _isoh,
  { {0x4fc4012b, 0x645a0b25, 0xc7b80082, 0x00000000}},  //   еста, meti, _gdđt_,
  { {0x443e0374, 0x3ea01774, 0x00000000, 0x00000000}},  //   lgt_, ghit_,   ,
  { {0x645a0026, 0x443e00bb, 0x7e6600d9, 0x00000000}},  // [2f70] oeti, ogt_, _dakp,
  { {0x645a0612, 0x67280182, 0xa2c5007d, 0x00000000}},  //   neti, _ovdj, रवक्,
  { {0xbcfb028c, 0x9e150088, 0x443e059b, 0x00000000}},  //   _prés, _одні, igt_,
  { {0x645a1775, 0xd366007a, 0x629d0065, 0x00000000}},  //   heti, _یه_, ëroh,
  { {0x645a014a, 0xd914007e, 0x22b60089, 0x00000000}},  //   keti, едчы, cāku_,
  { {0x645a0247, 0x443e02ae, 0xbcfb0068, 0x00000000}},  //   jeti, jgt_, _frér,
  { {0x645a002d, 0xbcfb1776, 0x65620045, 0x00000000}},  //   deti, _trés, _asoh,
  { {0x443e1777, 0x22b60089, 0x67280087, 0x00000000}},  //   egt_, nākt_, _dvdj,
  { {0xdddd0046, 0x645a166d, 0x00000000, 0x00000000}},  //   _hasł, feti,   ,
  { {0x443e1778, 0x648d0051, 0x3ea00065, 0x00000000}},  //   ggt_, _rúis, zhit_,
  { {0x9c8700b9, 0xe1ff1779, 0xd6ce02fd, 0x00000000}},  //   _začá, rdón_, طقی_,
  { {0xd5ae089d, 0xe2971734, 0x443e00b5, 0x00000000}},  //   افی_, даю_, agt_,
  { {0x645a177a, 0x648d002a, 0x2d8001c3, 0x00000000}},  //   beti, _dúir, xxie_,
  { {0x443e001c, 0x645a00b9, 0x7e660056, 0x00000000}},  //   cgt_, ceti, _sakp,
  { {0x3ea0177b, 0x7e66011c, 0x21290203, 0x00000000}},  //   thit_, _pakp, _evah_,
  { {0xdee3007c, 0x3d02006e, 0xdee601ee, 0x00000000}},  //   воси, _वंदे_, фоби,
  { {0x3ea001d6, 0x6fe7009d, 0x290d0022, 0x00000000}},  // [2f80] rhit_, técé, _ntea_,
  { {0x6286037e, 0x3ea00065, 0x013700a0, 0x00000000}},  //   ljko, shit_, _קרית_,
  { {0x307b009b, 0x4a46017f, 0x290d002d, 0x00000000}},  //   _ואינ, днев, _atea_,
  { {0x645a177c, 0xe9da0679, 0x3a2d0035, 0x00000000}},  //   zeti, оке_, _cdep_,
  { {0xbcfb0aea, 0x645a014a, 0x443e0239, 0x00000000}},  //   _fréq, yeti, ygt_,
  { {0x96f80594, 0x645a002d, 0xf2bb007d, 0x00000000}},  //   пект_, xeti, _उद्घ,
  { {0x22b60089, 0x36d40069, 0x290d00e5, 0x00000000}},  //   nāks_, нокр, _etea_,
  { {0xcfc00044, 0x6e2400e7, 0x64430146, 0x00000000}},  //   _ইরান, naib, _acni,
  { {0x645a008d, 0xdddd0036, 0x3a0900a1, 0x00000000}},  //   teti, _zasł, _رکنی_,
  { {0x6e240c97, 0x443e01a2, 0x84e70025, 0x00000000}},  //   haib, ugt_, وفيق_,
  { {0x645a011f, 0x443e177d, 0x6e24011c, 0x00000000}},  //   reti, rgt_, kaib,
  { {0x645a037e, 0x6b83177e, 0x753b0009, 0x00000000}},  //   seti, ängi, buuz,
  { {0x6596004b, 0x7c2e05fa, 0x6e240032, 0x00000000}},  //   _تجار, _odbr, daib,
  { {0xe3af06c6, 0xf9930097, 0x61f8007e, 0x00000000}},  //   اری_, דרש_, ьняў_,
  { {0xceb4005f, 0xdfd4007e, 0xdfd8005e, 0x00000000}},  //   fiə_, воры, дът_,
  { {0x76400061, 0x7c2e0093, 0x6e240327, 0x00000000}},  //   ngmy, _adbr, gaib,
  { {0xbcfb009d, 0x3d1a007d, 0x00000000, 0x00000000}},  // [2f90] _crép, मीले_,   ,
  { {0x66de0065, 0x22b60089, 0x61e0014a, 0x00000000}},  //   këko, sākt_, ümle,
  { {0x290d0899, 0x5a351281, 0x3eb00051, 0x00000000}},  //   _stea_, енет, últú_,
  { {0x6e240b51, 0x6aa20016, 0x628d00c4, 0x00000000}},  //   caib, ghof, _joao,
  { {0x49b80014, 0xc7b8016c, 0x00000000, 0x00000000}},  //   واهد_, _ređa_,   ,
  { {0x442e02d4, 0x00000000, 0x00000000, 0x00000000}},  //   _ndf_,   ,   ,
  { {0xe739041f, 0xc7b80521, 0x46f50077, 0x00000000}},  //   чей_, _peđa_, нчит,
  { {0x442e00d4, 0x32c40477, 0x6aa20020, 0x00000000}},  //   _adf_, kıya_, chof,
  { {0x81b40055, 0x04b50ae0, 0x5a44007e, 0x00000000}},  //   _জুন_, есня, _шэра,
  { {0xb21b0030, 0x7c250471, 0x00000000, 0x00000000}},  //   sjæl, nahr,   ,
  { {0x442e177f, 0x889a009b, 0x6286012d, 0x00000000}},  //   _ddf_, _צבעי, tjko,
  { {0x442e009d, 0x753b0020, 0x51f700a1, 0x00000000}},  //   _edf_, puuz, کسپر,
  { {0x3495008b, 0x442e1780, 0xbddb00f4, 0x00000000}},  //   _падр, _fdf_, _scèn,
  { {0x92c20055, 0x7c25010f, 0x6e2400e7, 0x00000000}},  //   ্গে_, jahr, waib,
  { {0x44251781, 0x6e241782, 0x6609012d, 0x00000000}},  //   mal_, taib, ocek,
  { {0x44250643, 0xbcfb00f4, 0x64410007, 0x00000000}},  //   lal_, _prép, lgli,
  { {0x7c25001f, 0xed5701f9, 0xee37008b, 0x00000000}},  // [2fa0] fahr, нот_, энт_,
  { {0x644106d3, 0x7d040065, 0x6e241783, 0x00000000}},  //   ngli, rqis, saib,
  { {0x201801d5, 0x64411784, 0x4425005b, 0x00000000}},  //   mbri_, igli, ial_,
  { {0x4425006a, 0x629d0006, 0x2ea800a1, 0x00000000}},  //   hal_, ūrov, _کھڑی_,
  { {0x44250127, 0x7bc700f6, 0x6aa201a2, 0x00000000}},  //   kal_, _exju, rhof,
  { {0x44251785, 0xfbd1026c, 0x6aa2021f, 0x00000000}},  //   jal_, اتے_, shof,
  { {0x442e1786, 0xf093009b, 0x2bbe0061, 0x00000000}},  //   _rdf_, רנו_, ्थळा,
  { {0x442e009d, 0x41b20061, 0x6441010e, 0x00000000}},  //   _sdf_, ीपास, egli,
  { {0x4425018e, 0x00000000, 0x00000000, 0x00000000}},  //   fal_,   ,   ,
  { {0x6441098e, 0x1828007a, 0x33740077, 0x00000000}},  //   ggli, _آقای_, вгор,
  { {0x5c370049, 0xc61f0044, 0x00000000, 0x00000000}},  //   ערטן_, _ধারা_,   ,
  { {0x44251787, 0x64411788, 0x3bbb0104, 0x00000000}},  //   aal_, agli, למיד,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44250038, 0x32c401df, 0x00000000, 0x00000000}},  //   cal_, rıya_,   ,
  { {0x7ea30004, 0xdfd50783, 0xbcfb0010, 0x00000000}},  //   _lõpe, товы, _esél,
  { {0x7c25010f, 0x6b8100f6, 0x32c4026d, 0x00000000}},  //   wahr, _àlgi, pıya_,
  { {0x661d009f, 0x2d580194, 0xa2ce013d, 0x00000000}},  // [2fb0] ðski, нить_, सवर्,
  { {0x6ac90201, 0x2d870091, 0x00000000, 0x00000000}},  //   िक्र, ćne_,   ,
  { {0x212b010f, 0x2be60061, 0x00000000, 0x00000000}},  //   lsch_, _करणं_,   ,
  { {0x44251789, 0xc3330104, 0xc5fe0089, 0x00000000}},  //   zal_, רוף_, šējo_,
  { {0x212b0a35, 0x4425060b, 0x68fa013f, 0x00000000}},  //   nsch_, yal_, _bitd,
  { {0x4425006b, 0x212b010f, 0x7e6d0058, 0x00000000}},  //   xal_, isch_, ldap,
  { {0x2bb80054, 0x46a513e7, 0x6d4d178a, 0x00000000}},  //   _كافة_, какв, ltaa,
  { {0x7e6d020c, 0x44250504, 0xcb120452, 0x00000000}},  //   ndap, wal_, _כלל_,
  { {0x6d4d061f, 0x6441001f, 0x6609014a, 0x00000000}},  //   ntaa, tgli, rcek,
  { {0x97a7003b, 0xd90d007a, 0x6441178b, 0x00000000}},  //   _прел, _هیچ_, ugli,
  { {0x6d4d00b0, 0x61e40010, 0x7afb178c, 0x00000000}},  //   htaa, _szil, _kiut,
  { {0x6441018e, 0xddc4001a, 0x6d4d0dde, 0x00000000}},  //   sgli, ndiţ, ktaa,
  { {0x4425049a, 0x7afb0010, 0x00000000, 0x00000000}},  //   pal_, _miut,   ,
  { {0x7e7d010f, 0xe3b9178d, 0x4425178e, 0x00000000}},  //   _ansp, _обл_, qal_,
  { {0x03a20088, 0x00000000, 0x00000000, 0x00000000}},  //   _вищо,   ,   ,
  { {0x6d4d04fd, 0x7e6d0058, 0x212b01a2, 0x00000000}},  //   ftaa, gdap, bsch_,
  { {0x6d4d178f, 0x00000000, 0x00000000, 0x00000000}},  // [2fc0] gtaa,   ,   ,
  { {0x7afb0198, 0x7e7d01aa, 0xdd8f0318, 0x00000000}},  //   _aiut, _ensp, غول_,
  { {0x6d4d001c, 0x8fa604af, 0x0a4a008b, 0x00000000}},  //   ataa, _ране, дзей_,
  { {0x7afb04bd, 0x78a11790, 0x7ae90020, 0x00000000}},  //   _ciut, _allv, _chet,
  { {0x6d4d001c, 0x7ceb010f, 0x7afb003f, 0x00000000}},  //   ctaa, dürf, _diut,
  { {0xf77206dd, 0x672a00ea, 0x00000000, 0x00000000}},  //   لاع_, tsfj,   ,
  { {0x6b8304ce, 0x7afb07ad, 0x00000000, 0x00000000}},  //   ängt, _fiut,   ,
  { {0x7afb0026, 0x212b0032, 0x68fa01d6, 0x00000000}},  //   _giut, ysch_, _witd,
  { {0xceb300b6, 0x7bdc0052, 0x27e5004a, 0x00000000}},  //   ייה_, _hyru, _ezln_,
  { {0x68fa00c7, 0xb4cc013d, 0xb86502fd, 0x00000000}},  //   _uitd, लवे_, _مامو,
  { {0xa2950099, 0x29040f68, 0x387e000d, 0x00000000}},  //   гані, _huma_, _intr_,
  { {0x26c00006, 0x212b03a1, 0x29041791, 0x00000000}},  //   čios_, tsch_, _kuma_,
  { {0xe298008b, 0xe5340147, 0x29040020, 0x00000000}},  //   таў_, _сель, _juma_,
  { {0x212b010f, 0x29041792, 0x7ceb1793, 0x00000000}},  //   rsch_, _muma_, mürg,
  { {0xff040242, 0x29041794, 0x386c00e5, 0x00000000}},  //   иятн, _luma_, _madr_,
  { {0x6d4d1795, 0x29040007, 0x212b1796, 0x00000000}},  //   ttaa, _ouma_, psch_,
  { {0x29040181, 0x7e6d020c, 0x7afb1797, 0x00000000}},  // [2fd0] _numa_, rdap, _riut,
  { {0x7ae90020, 0x629d01d6, 0x80c10044, 0x00000000}},  //   _shet, lkso, _শীর্,
  { {0x6d4d0d6f, 0x50b8057d, 0x7afb1798, 0x00000000}},  //   staa, _جديد_, _piut,
  { {0x629d0146, 0x290400bb, 0x6d4d003f, 0x00000000}},  //   nkso, _buma_, ptaa,
  { {0x29040127, 0xb5fd01ee, 0x8d8400ed, 0x00000000}},  //   _cuma_, neše, _курд,
  { {0x98e50054, 0x7ae900ab, 0x6b8304ce, 0x00000000}},  //   دكتو, _whet, ängs,
  { {0x00580104, 0x2249014a, 0x386c00e5, 0x00000000}},  //   דשות_, _ocak_, _dadr_,
  { {0xdb240195, 0xd756023c, 0x387e0068, 0x00000000}},  //   _úsái, اليت_, _entr_,
  { {0x60d50c8a, 0xb5fd0243, 0x290401ed, 0x00000000}},  //   kozm, ješe, _guma_,
  { {0x34850b87, 0x20010011, 0x22490093, 0x00000000}},  //   угог, _nghi_, _acak_,
  { {0x947500d3, 0x29040657, 0xe81901f5, 0x00000000}},  //   ندگا, _zuma_, _न्या_,
  { {0x29041352, 0x20010026, 0x7ceb01a2, 0x00000000}},  //   _yuma_, _aghi_, bürg,
  { {0x661b1799, 0xd46801b2, 0x00000000, 0x00000000}},  //   mbuk, رحیم_,   ,
  { {0x55ba009b, 0x9103007c, 0x629d0065, 0x00000000}},  //   _אמנו, спре, ëror,
  { {0x2d8f0002, 0xf8b2009b, 0xb4c10309, 0x00000000}},  //   ägen_, משך_, ्की_,
  { {0x661b179a, 0xc24601ee, 0x00000000, 0x00000000}},  //   nbuk, _сник,   ,
  { {0x83fc0091, 0x3f9e179b, 0x661b0020, 0x00000000}},  // [2fe0] ređe, štu_, ibuk,
  { {0xf06601f9, 0xf28a00a1, 0x3a2400fa, 0x00000000}},  //   _скоп, _آپکو_, _semp_,
  { {0x2904179c, 0xddd40036, 0x7ceb019a, 0x00000000}},  //   _suma_, _łańc, dürd,
  { {0x753b057c, 0x7524014a, 0x094a00ed, 0x00000000}},  //   kruz, _çizg, ечки_,
  { {0x38a2000c, 0x82d70049, 0x753b016c, 0x00000000}},  //   _aðra_, נונג_, jruz,
  { {0x4b2603ec, 0x753b0107, 0x31570049, 0x00000000}},  //   _معرف, druz, ריסן_,
  { {0x3a24086a, 0xd6d012c0, 0x00000000, 0x00000000}},  //   _temp_, يقت_,   ,
  { {0xa534003b, 0x29040020, 0x6b830039, 0x00000000}},  //   анич, _tuma_, ånge,
  { {0x7d06179d, 0x753b0035, 0x29040058, 0x00000000}},  //   _juks, gruz, _uuma_,
  { {0xd5630265, 0x7d060052, 0x00000000, 0x00000000}},  //   стъп, _muks,   ,
  { {0x2ee00279, 0x00000000, 0x00000000, 0x00000000}},  //   klif_,   ,   ,
  { {0x753b0026, 0x81e90044, 0x66e31079, 0x00000000}},  //   bruz, _বলব_, _лоха,
  { {0x629d0378, 0xc05b01fb, 0x753b0285, 0x00000000}},  //   rkso, нів_, cruz,
  { {0x6fd60316, 0xf48402fd, 0x00000000, 0x00000000}},  //   _मुहू, _خاصی,   ,
  { {0x7d06008f, 0xb5fd179e, 0x60d5179f, 0x00000000}},  //   _auks, reše, rozm,
  { {0x7d06006a, 0x6e20010e, 0xd9f60061, 0x00000000}},  //   _buks, _õmbl, ेशात_,
  { {0xa3b80061, 0xb5fd00ca, 0x6e260328, 0x00000000}},  // [2ff0] _घेत_, peše, _dekb,
  { {0x7d060065, 0x20010026, 0x6e2600d9, 0x00000000}},  //   _duks, _ughi_, _eekb,
  { {0x70fa009b, 0x03e20082, 0x60fa009b, 0x00000000}},  //   _שהתח, _đuốn, _שהתק,
  { {0x19b9008b, 0x7ceb010f, 0xc333009b, 0x00000000}},  //   куль_, würd, מוע_,
  { {0xa9690175, 0x645809dd, 0x7ceb0279, 0x00000000}},  //   тила_, _obvi, türd,
  { {0x7c870147, 0x3ea90010, 0x2bd001f5, 0x00000000}},  //   _суме, lhat_, _तुका,
  { {0x07a5005e, 0x7522000a, 0x00000000, 0x00000000}},  //   райн, _awoz,   ,
  { {0x753b0282, 0x3ea917a0, 0xe7080014, 0x00000000}},  //   truz, nhat_, دتون_,
  { {0x661b020c, 0x7847025a, 0xca48023c, 0x00000000}},  //   rbuk, _مضام, _حلقه_,
  { {0xb4c10201, 0x6602022b, 0x753b01bc, 0x00000000}},  //   ्के_, _egok, rruz,
  { {0xe28604f9, 0x61e1005f, 0x987a0049, 0x00000000}},  //   ални, əlli, _שרעק,
  { {0x6d5d0030, 0x25b60014, 0x7c270030, 0x00000000}},  //   _opsa, اهید_, _lejr,
  { {0x3ea91002, 0xcad6009b, 0x75220c28, 0x00000000}},  //   dhat_, שורת_, _gwoz,
  { {0x7c2700b9, 0x6e260093, 0x7d060733, 0x00000000}},  //   _nejr, _sekb, _ruks,
  { {0x7d0617a1, 0x6d5d17a2, 0x442700d4, 0x00000000}},  //   _suks, _apsa, _ien_,
  { {0x442703cd, 0x3ea917a3, 0xee3717a4, 0x00000000}},  //   _hen_, ghat_, инс_,

  { {0xcbe208b7, 0x44270343, 0x25ad0342, 0x00000000}},  // [3000] _বলেছ, _ken_, nzel_,
  { {0x44270224, 0xac830230, 0x4c8300ed, 0x00000000}},  //   _jen_, огул, олув,
  { {0x80a60167, 0x9f4c00b0, 0x00000000, 0x00000000}},  //   _ممکن, ädä_,   ,
  { {0x44270027, 0x3ea900b9, 0x00000000, 0x00000000}},  //   _len_, chat_,   ,
  { {0x6d5d002d, 0x7c2717a5, 0x4427005b, 0x00000000}},  //   _gpsa, _fejr, _oen_,
  { {0x7e640e33, 0xddcd0035, 0x7c270022, 0x00000000}},  //   leip, leaş, _gejr,
  { {0x6d440035, 0xf727007e, 0x656b074e, 0x00000000}},  //   luia, ацый_, _asgh,
  { {0x3ea00943, 0xdc2e006b, 0x83fc0243, 0x00000000}},  //   nkit_, _yığm, jeđa,
  { {0x442717a6, 0xf8af00a1, 0x6d4417a7, 0x00000000}},  //   _ben_, سکے_, nuia,
  { {0x7ae217a8, 0x4427042e, 0x3ea90010, 0x00000000}},  //   llot, _cen_, zhat_,
  { {0x48070264, 0x3ea017a9, 0x7ae208a6, 0x00000000}},  //   _техн_, kkit_, olot,
  { {0x4427017c, 0x96fa031d, 0x6b810325, 0x00000000}},  //   _een_, _شعار_, _álge,
  { {0x442704cd, 0x7ae20026, 0x20d70025, 0x00000000}},  //   _fen_, ilot, لتسج,
  { {0x44270607, 0x3ea90133, 0x00000000, 0x00000000}},  //   _gen_, what_,   ,
  { {0x442c17aa, 0xb5fd003b, 0x3ea90010, 0x00000000}},  //   mad_, meša, that_,
  { {0x4427022b, 0x93fb007b, 0x2bda013d, 0x00000000}},  //   _zen_, _בלוי, _भड़ा,
  { {0x6d4f001c, 0x442717ab, 0x7ae217ac, 0x00000000}},  // [3010] _qqca, _yen_, dlot,
  { {0x6448000c, 0x3ea90065, 0x44270082, 0x00000000}},  //   ngdi, shat_, _xen_,
  { {0x7c270030, 0x81e90044, 0x3ea917ad, 0x00000000}},  //   _vejr, _বলি_, phat_,
  { {0x442c109a, 0xdd91026c, 0x3ea0059f, 0x00000000}},  //   had_, _فوج_, ckit_,
  { {0x442c0119, 0x777a002d, 0x6d5d17ae, 0x00000000}},  //   kad_, _artx, _upsa,
  { {0x442c0004, 0x81e90055, 0xb5fd0243, 0x00000000}},  //   jad_, _বলা_, ješa,
  { {0x442c1718, 0x4427022b, 0xccf2009b, 0x00000000}},  //   dad_, _ren_, _מכך_,
  { {0x4427021e, 0x7ae2059a, 0x442c17af, 0x00000000}},  //   _sen_, clot, ead_,
  { {0x44270904, 0xddc601d9, 0x442c0051, 0x00000000}},  //   _pen_, _kakš, fad_,
  { {0x442c001e, 0x44270065, 0x6e2d01f3, 0x00000000}},  //   gad_, _qen_, haab,
  { {0x44270018, 0xc6260055, 0xe29a0364, 0x00000000}},  //   _ven_, _যারা_, ган_,
  { {0x44270007, 0xddc60091, 0x64480112, 0x00000000}},  //   _wen_, _lakš, agdi,
  { {0x442c17b0, 0x83fc0521, 0xc7b8012d, 0x00000000}},  //   bad_, ređa, _ređi_,
  { {0x7cf00bfe, 0x7649014a, 0xb5fd016c, 0x00000000}},  //   märg, lgey, ceša,
  { {0xc7b8012d, 0x8fa300c0, 0x628f00f6, 0x00000000}},  //   _peđi_, паре, bjco,
  { {0x7649000c, 0x422617b1, 0x539a0104, 0x00000000}},  //   ngey, _удив, _תיקו,
  { {0x3ea00943, 0x7d260123, 0x518500e2, 0x00000000}},  // [3020] rkit_, صفان, _дуќа,
  { {0x6296008e, 0x6d4417b2, 0x00000000, 0x00000000}},  //   _hoyo, ruia,   ,
  { {0x2d8f0737, 0xe1ff00d4, 0x395f17b3, 0x00000000}},  //   øger_, bdós_, _apus_,
  { {0x442c016c, 0xc5f20044, 0x6b830039, 0x00000000}},  //   zad_, ছুটা_, ånga,
  { {0x442c006a, 0x6d441343, 0x62960020, 0x00000000}},  //   yad_, quia, _moyo,
  { {0x7ae202ae, 0x307a0049, 0x7ea3006c, 0x00000000}},  //   slot, ראַנ, _lõpl,
  { {0x442c061f, 0x7ae201ca, 0xd6da05a5, 0x00000000}},  //   vad_, plot, лти_,
  { {0x442c011c, 0xe6660264, 0x7cf000f8, 0x00000000}},  //   wad_, стко, färg,
  { {0xb21b06ec, 0x00000000, 0x00000000, 0x00000000}},  //   kjær,   ,   ,
  { {0x62840036, 0x6aa2042e, 0x442c17b4, 0x00000000}},  //   _anio, lkof, uad_,
  { {0x442c0073, 0x62960093, 0x6e2d0022, 0x00000000}},  //   rad_, _boyo, yaab,
  { {0x442c17b5, 0x6aa20a20, 0xd6270893, 0x00000000}},  //   sad_, nkof, _гоце_,
  { {0xb5fd17b6, 0x39460006, 0x914b007e, 0x00000000}},  //   lešn, nuos_, ычна_,
  { {0x442c17b7, 0x66de0023, 0x6e2d0258, 0x00000000}},  //   qad_, rëku, waab,
  { {0xdbf10224, 0xe4570049, 0x6e2d17b8, 0x00000000}},  //   _přím, _ליגט_, taab,
  { {0x7cf004ce, 0x00000000, 0x00000000, 0x00000000}},  //   härd,   ,   ,
  { {0x38ab0737, 0x6e9417b9, 0x998d04eb, 0x00000000}},  // [3030] _høre_, читу, _odeš_,
  { {0x394617ba, 0x38ab0030, 0xa3cc013d, 0x00000000}},  //   duos_, _køre_, _रखा_,
  { {0x6296000b, 0x395f000d, 0xce95005e, 0x00000000}},  //   _yoyo, _spus_, _данъ,
  { {0xdb080010, 0x38ab1565, 0x00000000, 0x00000000}},  //   álás, _møre_,   ,
  { {0xc7b80119, 0xddc601d9, 0x394617bb, 0x00000000}},  //   _među_, _takš, guos_,
  { {0x7cf00039, 0x61ed0020, 0x58d417bc, 0x00000000}},  //   gärd, _mzal, почт,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66f201fc, 0x6aa201a2, 0x060901bd, 0x00000000}},  //   мпју, ckof, шник_,
  { {0xf9930025, 0x1a680167, 0x3afa0049, 0x00000000}},  //   _عبر_, _دینی_, _כּמע,
  { {0x6296009d, 0xd8380087, 0x65690b19, 0x00000000}},  //   _soyo, _gdč_, rweh,
  { {0x61ed17bd, 0x626617be, 0x656901a2, 0x00000000}},  //   _azal, овна, sweh,
  { {0x38ab0030, 0x26dd0045, 0xe7300025, 0x00000000}},  //   _døre_, _ukwo_, _أصل_,
  { {0x6296009d, 0x7cf009b0, 0x00000000, 0x00000000}},  //   _voyo, läre,   ,
  { {0x03a5012b, 0x62840036, 0x6aa90016, 0x00000000}},  //   _мило, _wnio, _llef,
  { {0x629601cf, 0x38ab0018, 0x7cf00a5d, 0x00000000}},  //   _toyo, _gøre_, näre,
  { {0x628402f1, 0xb5fd17bf, 0x00000000, 0x00000000}},  //   _unio, nešo,   ,
  { {0xe1ff15e3, 0x85f60049, 0x00000000, 0x00000000}},  // [3040] león_, ַמעס_,   ,
  { {0x61e4014a, 0x6aa90a8e, 0x60de0133, 0x00000000}},  //   _iyil, _alef, _ukpm,
  { {0xbcfb028c, 0x8b6a0057, 0x7cf003af, 0x00000000}},  //   _spéc, риев_, värd,
  { {0x6aa917c0, 0xb5fd0059, 0x394617c1, 0x00000000}},  //   _clef, ješo, tuos_,
  { {0x7ceb006b, 0x00000000, 0x00000000, 0x00000000}},  //   süra,   ,   ,
  { {0x98a301e0, 0x2d54006c, 0x7cf00039, 0x00000000}},  //   миче, mäe_, färe,
  { {0xf0930476, 0xfaa6007e, 0xb8650025, 0x00000000}},  //   ונג_, _даво, ثانو,
  { {0x96340364, 0xb5fd0c30, 0x60dc003f, 0x00000000}},  //   чниц, rešn, horm,
  { {0x61e40047, 0x6d56006b, 0x60dc0010, 0x00000000}},  //   _nyil, ntya, korm,
  { {0x81e90044, 0xb5fd17c2, 0x60dc0173, 0x00000000}},  //   _বলল_, pešn, jorm,
  { {0x61ed115b, 0x60dc117e, 0xb5fd012d, 0x00000000}},  //   _szal, dorm, lešl,
  { {0x2bbd013d, 0xddcd001a, 0x00000000, 0x00000000}},  //   ्पता, ndaţ,   ,
  { {0x672d0166, 0x00000000, 0x00000000, 0x00000000}},  //   ćaje,   ,   ,
  { {0x6ab70164, 0xd8380173, 0x60dc0203, 0x00000000}},  //   _आग्र, _elčv_, gorm,
  { {0x09b702fb, 0xb4e601f5, 0xcebb003b, 0x00000000}},  //   _अध्य, पती_, аља_,
  { {0x9d1517c3, 0x645a01e5, 0x73f90049, 0x00000000}},  //   здач, lfti, _פּסו,
  { {0x5fdb007d, 0xbddb00f6, 0x61e40010, 0x00000000}},  // [3050] _मुरल, _acèr, _gyil,
  { {0x645a05c4, 0xb5fd013e, 0x00000000, 0x00000000}},  //   nfti, dešl,   ,
  { {0xd7df0061, 0x7cf001a2, 0x00000000, 0x00000000}},  //   _पुढच, färb,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x0dc801f9, 0xa9240088, 0x6aa90065, 0x00000000}},  //   _дури_, дділ, _vlef,
  { {0x27951662, 0x7cf017c4, 0x21290828, 0x00000000}},  //   зшир, täre, _mwah_,
  { {0x24890011, 0x291d01aa, 0x38670190, 0x00000000}},  //   _đam_, spwa_, renr_,
  { {0x3209001d, 0xfbd200a0, 0x6abb0009, 0x00000000}},  //   _ngay_, _נתן_, _umuf,
  { {0x60dc014a, 0x645a0016, 0x7cf017c5, 0x00000000}},  //   yorm, ffti, säre,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3a2d0038, 0x60dc17c6, 0x65620107, 0x00000000}},  //   _keep_, vorm, _epoh,
  { {0x216a005e, 0x29050459, 0x21290145, 0x00000000}},  //   бими_, _hila_, _bwah_,
  { {0x2905000b, 0xb7bc001e, 0x60dc0142, 0x00000000}},  //   _kila_, _reģi, torm,
  { {0x2d54006c, 0xf992009b, 0x3a2d0203, 0x00000000}},  //   väe_, תרך_, _leep_,
  { {0xd00f1095, 0xa3b80061, 0x6b8300f8, 0x00000000}},  //   الف_, _घेऊ_, ångl,
  { {0x60dc00f4, 0x539a009b, 0xf7720049, 0x00000000}},  //   sorm, _ליצו, עקן_,
  { {0x60dc006a, 0xa1130025, 0xbcfb0048, 0x00000000}},  // [3060] porm, _كويت, _spéa,
  { {0x2905006a, 0x6d560010, 0xf8a50167, 0x00000000}},  //   _nila_, rtya, _شک_,
  { {0x309b009b, 0x3a2d0145, 0xa09b00a0, 0x00000000}},  //   _השימ, _beep_, _הייט,
  { {0x7ceb050d, 0xed5a02dc, 0x29050052, 0x00000000}},  //   büro, _лом_, _aila_,
  { {0x29051092, 0x6e24020e, 0x3a2d00ab, 0x00000000}},  //   _bila_, mbib, _deep_,
  { {0x2905008d, 0x6e2400ea, 0x7ceb005a, 0x00000000}},  //   _cila_, lbib, nürl,
  { {0x36d4072b, 0x56940d99, 0x2905011c, 0x00000000}},  //   мокр, дайт, _dila_,
  { {0x6d44010e, 0x00000000, 0x00000000, 0x00000000}},  //   oria,   ,   ,
  { {0xd94300c0, 0x9c8300ca, 0x7c2e00ea, 0x00000000}},  //   _пети, ščet, _kebr,
  { {0x6d440fdd, 0x2905003f, 0x691c014a, 0x00000000}},  //   iria, _gila_, rçeğ,
  { {0x7ceb014a, 0x7c2e00f6, 0x645a17c7, 0x00000000}},  //   dürl, _mebr, rfti,
  { {0x7c2e1706, 0x6d440006, 0xa3bd013d, 0x00000000}},  //   _lebr, kria, _इधर_,
  { {0x867b00b6, 0xc50a0025, 0x5187003b, 0x00000000}},  //   _לראו, _اتصل_, чуна,
  { {0xbcfb049a, 0x6d4417c8, 0x7ceb014a, 0x00000000}},  //   _apén, dria, gürl,
  { {0x443c0197, 0x712700a6, 0xbef80204, 0x00000000}},  //   _idv_, _کربل, ंगून_,
  { {0x442e009f, 0x6d44027b, 0x6e24006a, 0x00000000}},  //   _hef_, fria, gbib,
  { {0x1df80147, 0x6d4417c9, 0x443c014a, 0x00000000}},  // [3070] зеты_, gria, _kdv_,
  { {0xd0110084, 0x3a2d0abf, 0x442e0602, 0x00000000}},  //   _جلد_, _seep_, _jef_,
  { {0x7c2e121b, 0x442e12fe, 0xdced0166, 0x00000000}},  //   _debr, _mef_, hvać,
  { {0x6d44027b, 0x290517ca, 0x3f57006b, 0x00000000}},  //   bria, _sila_, mçu_,
  { {0x7c2e17cb, 0x3f57006b, 0x6d4400c4, 0x00000000}},  //   _febr, lçu_, cria,
  { {0x7c2e17cc, 0x3a2d0319, 0x442e03d0, 0x00000000}},  //   _gebr, _weep_, _nef_,
  { {0x290509f7, 0x3f5717cd, 0xb8f5006e, 0x00000000}},  //   _vila_, nçu_, _हद_,
  { {0xaa58012b, 0x7c2e0036, 0x443c0851, 0x00000000}},  //   _нису_, _zebr, _adv_,
  { {0x290517ce, 0x442e17cf, 0x7cf00039, 0x00000000}},  //   _tila_, _bef_, lära,
  { {0xb5fd0a0f, 0x6e240107, 0x442e00c4, 0x00000000}},  //   lešk, zbib, _cef_,
  { {0x6203005f, 0xa91d17d0, 0x443c0059, 0x00000000}},  //   ətlə, _drže, _ddv_,
  { {0x7c25002a, 0x7d0702ae, 0x442e0141, 0x00000000}},  //   hbhr, _lijs, _eef_,
  { {0x7ceb17d1, 0x27e0014a, 0x442e17d2, 0x00000000}},  //   türl, ğine_, _fef_,
  { {0x3ce301f3, 0x442e01e5, 0x1dd8013d, 0x00000000}},  //   _nkjv_, _gef_, _भुगत,
  { {0x7c2e17d3, 0x910300e1, 0xdee60a27, 0x00000000}},  //   _rebr, тпре, дови,
  { {0x6d440142, 0x7c2e0181, 0xd12f00a1, 0x00000000}},  //   tria, _sebr, طمہ_,
  { {0xed5701f9, 0x6d440a0e, 0xd00f00a1, 0x00000000}},  // [3080] мот_, uria, الہ_,
  { {0x6d440238, 0x1c39007e, 0x442e00f6, 0x00000000}},  //   rria, зяць_, _xef_,
  { {0x6d440022, 0xdced0645, 0x6e2f0022, 0x00000000}},  //   sria, zvać, _fecb,
  { {0x6d440388, 0x7d0f0555, 0x20180026, 0x00000000}},  //   pria, _fucs, lcri_,
  { {0x7c2e17d4, 0x26cd0521, 0xd83800d0, 0x00000000}},  //   _tebr, dneo_, _loče_,
  { {0xab2a0265, 0xfbd9013d, 0x7d0700d9, 0x00000000}},  //   _мога_, _बुकम, _gijs,
  { {0x442e17d5, 0x443c009d, 0xfc0301e1, 0x00000000}},  //   _ref_, _rdv_, _апро,
  { {0x6b830018, 0x442e018e, 0x443c0087, 0x00000000}},  //   ænge, _sef_, _sdv_,
  { {0x443c0091, 0xa91d04eb, 0x00000000, 0x00000000}},  //   _pdv_, _prže,   ,
  { {0x442e0023, 0x752417d6, 0x00000000, 0x00000000}},  //   _qef_, _çizm,   ,
  { {0x442e17d7, 0xf7720025, 0xa91d17d8, 0x00000000}},  //   _vef_, _جاء_, _vrže,
  { {0xe5c603f4, 0x2d8201ee, 0x38ab0190, 0x00000000}},  //   _осло, _orke_, _jørn_,
  { {0xa308026c, 0x26c40006, 0xa91d0059, 0x00000000}},  //   _کرتے_, mimo_, _trže,
  { {0x26c4045e, 0x394602d5, 0x7ceb17d9, 0x00000000}},  //   limo_, iros_, türm,
  { {0x7d0700b5, 0x4fc40d68, 0x2d820f46, 0x00000000}},  //   _rijs, вста, _arke_,
  { {0x26c4010a, 0x39460006, 0x3f5717cd, 0x00000000}},  //   nimo_, kros_, rçu_,
  { {0x2fdf0036, 0xb5fd0059, 0x2d82012d, 0x00000000}},  // [3090] ług_, vešk, _crke_,
  { {0x39461049, 0x26c40dc7, 0x3f810161, 0x00000000}},  //   dros_, himo_, _trhu_,
  { {0x38ab0018, 0x26c4010a, 0x92c30055, 0x00000000}},  //   _børn_, kimo_, ্তী_,
  { {0x26c4010a, 0x7d0700b5, 0x693517da, 0x00000000}},  //   jimo_, _wijs, енду,
  { {0x39460211, 0xe1ff0010, 0x2d820107, 0x00000000}},  //   gros_, deók_, _grke_,
  { {0x7cf00004, 0x99d4007a, 0x7b670401, 0x00000000}},  //   pära, ختما, _отбе,
  { {0xc878005d, 0x83fc012d, 0x3946004a, 0x00000000}},  //   _dağ_, beđi, aros_,
  { {0x39460219, 0x3ea90010, 0x26c40006, 0x00000000}},  //   bros_, nkat_, gimo_,
  { {0x394615a3, 0x2f1517db, 0xf5050072, 0x00000000}},  //   cros_, _låg_, нзио,
  { {0xb5fd17dc, 0x7e6d0051, 0x26cd012d, 0x00000000}},  //   neši, heap, sneo_,
  { {0x26c40087, 0xc2c60025, 0x3ea917dd, 0x00000000}},  //   bimo_, فيدي, kkat_,
  { {0x26c40059, 0x7cf00039, 0xc5d501e1, 0x00000000}},  //   cimo_, järn, _піль,
  { {0x7e6d001a, 0xc878005a, 0xa3de013e, 0x00000000}},  //   deap, _yağ_, _měří_,
  { {0xb5fd0243, 0x0ef8013d, 0x6d4d006c, 0x00000000}},  //   ješi, ंग्स_, duaa,
  { {0xb4bd001c, 0x7ea30004, 0xb4cb01f5, 0x00000000}},  //   ीची_, _lõpu, रची_,
  { {0x20180061, 0x3ea917de, 0x7eaa0161, 0x00000000}},  //   scri_, gkat_, _výpo,
  { {0xac8609b2, 0xf1bf004a, 0x00000000, 0x00000000}},  // [30a0] нгал, lbán_,   ,
  { {0x394602d5, 0x26c40091, 0x201a00c4, 0x00000000}},  //   vros_, zimo_, _ufpi_,
  { {0x291f17df, 0x2d8f0a35, 0x2057009b, 0x00000000}},  //   _atua_, äger_, _אייל_,
  { {0x394600d6, 0x26c40489, 0x3ea90039, 0x00000000}},  //   tros_, ximo_, ckat_,
  { {0x26c4010a, 0xb5fd016c, 0x394617e0, 0x00000000}},  //   vimo_, beši, uros_,
  { {0x39460df9, 0x672d037e, 0x20070129, 0x00000000}},  //   rros_, ćajn, _únic_,
  { {0x26c40817, 0x2d80009d, 0xcb670aed, 0x00000000}},  //   timo_, lvie_, _паре_,
  { {0x2d800026, 0x00000000, 0x00000000, 0x00000000}},  //   ovie_,   ,   ,
  { {0x7ae2003c, 0xceb3009b, 0x0cc40044, 0x00000000}},  //   moot, טיה_, ্তীত,
  { {0x22400127, 0xed57009b, 0x7ae217e1, 0x00000000}},  //   _adik_, עביר_, loot,
  { {0x26c417e2, 0xd6cf007e, 0x21200145, 0x00000000}},  //   pimo_, _бт_, _atih_,
  { {0x7ae217e3, 0x7ceb005a, 0x3ea90032, 0x00000000}},  //   noot, türk, xkat_,
  { {0x64a6008b, 0x245809b5, 0x2f1501c9, 0x00000000}},  //   _пада, _жаль_, _såg_,
  { {0x7ae202c2, 0x92c30044, 0x251b0097, 0x00000000}},  //   hoot, ্তে_, _צווא,
  { {0xdfd4008b, 0x7e6d17e4, 0x30a4005e, 0x00000000}},  //   горы, teap, уряв,
  { {0x6d4d03b6, 0x6e3600e0, 0x3ea900d2, 0x00000000}},  //   tuaa, gayb, ukat_,
  { {0x628d000b, 0xdce40046, 0x7e6d10e4, 0x00000000}},  // [30b0] _inao, zwią, reap,
  { {0x3ea900b9, 0x7e6d00ea, 0x2f150039, 0x00000000}},  //   skat_, seap, _tåg_,
  { {0x6e3617e5, 0xb5fd12ac, 0x7ae20061, 0x00000000}},  //   bayb, reši, foot,
  { {0x629f002b, 0x9f960104, 0x60c717e6, 0x00000000}},  //   _joqo, _סדרה_, lijm,
  { {0x628d17e7, 0x7e9a00a0, 0x00000000, 0x00000000}},  //   _mnao, _חסרו,   ,
  { {0xf7450072, 0xf77101f7, 0x00000000, 0x00000000}},  //   веко, لاب_,   ,
  { {0xa91d00ee, 0x00000000, 0x00000000, 0x00000000}},  //   _drža,   ,   ,
  { {0x7ae200bb, 0x629f0066, 0x0cc40044, 0x00000000}},  //   coot, _noqo, ্তৃত,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb4bd0183, 0x628d0cd7, 0xb4cb0061, 0x00000000}},  //   ीचे_, _anao, रचे_,
  { {0x68e30e69, 0x21200091, 0x00000000, 0x00000000}},  //   mond, _stih_,   ,
  { {0x68e307ef, 0x83fc0fcd, 0x00000000, 0x00000000}},  //   lond, jeđu,   ,
  { {0x645c0129, 0x6a3a009b, 0x00000000, 0x00000000}},  //   òric, וגרפ,   ,
  { {0x64a20887, 0x68e30020, 0x628d00d4, 0x00000000}},  //   _ваша, nond, _enao,
  { {0xafe6004c, 0x68e30032, 0x7e560900, 0x00000000}},  //   товл, iond, ктац,
  { {0x68e300bb, 0x661b17e8, 0x22400022, 0x00000000}},  //   hond, ncuk, _udik_,
  { {0xec7a005e, 0xe0da003b, 0x7ae209fc, 0x00000000}},  // [30c0] мпа_, _ови_, voot,
  { {0x313700b6, 0x21370049, 0x2d80009d, 0x00000000}},  //   _שנים_, _שטיל_, rvie_,
  { {0x7ae2006c, 0x83fc0521, 0xfe460194, 0x00000000}},  //   toot, beđu, _инно,
  { {0x0a6700ec, 0x4420001a, 0x753b0340, 0x00000000}},  //   врши_, _și_, ksuz,
  { {0x68e31017, 0x7ae200b5, 0x38650022, 0x00000000}},  //   fond, root, _bblr_,
  { {0x68e31428, 0x91bb009b, 0x48d00044, 0x00000000}},  //   gond, ומני, িত্র,
  { {0xb8ea013d, 0x98a3003b, 0x7ae20058, 0x00000000}},  //   _लग_, рије, poot,
  { {0xfaa317e9, 0x00000000, 0x00000000, 0x00000000}},  //   _касо,   ,   ,
  { {0xa91d0e0d, 0xfaa30140, 0x0906007e, 0x00000000}},  //   _trža, _тато, _апан,
  { {0x68e3051b, 0xd838016c, 0x7cf000f8, 0x00000000}},  //   cond, _foča_, kärm,
  { {0x7cf00039, 0x61f60826, 0x290c0052, 0x00000000}},  //   värl, _azyl, _iida_,
  { {0xa91d037e, 0x02a70264, 0xd7ef0025, 0x00000000}},  //   _mržn, тром, _بكم_,
  { {0x61f60046, 0xc6490025, 0xc05b0088, 0x00000000}},  //   _czyl, _أجمل_, мів_,
  { {0x290c0263, 0x00000000, 0x00000000, 0x00000000}},  //   _jida_,   ,   ,
  { {0x290c17ea, 0x92b70076, 0x4034007c, 0x00000000}},  //   _mida_, _لحظا, ресс,
  { {0x628d000b, 0x68e302ae, 0x32550216, 0x00000000}},  //   _unao, zond, _свир,
  { {0x68e30279, 0x83fc0091, 0x00000000, 0x00000000}},  // [30d0] yond, ređu,   ,
  { {0x6adb02fb, 0xb5fd003b, 0x290c007f, 0x00000000}},  //   यक्र, mešt, _nida_,
  { {0x68e302ae, 0xddc40006, 0x6aa000fa, 0x00000000}},  //   vond, reiš, _bomf,
  { {0x68e301bb, 0x290c01a3, 0x6aa000ab, 0x00000000}},  //   wond, _aida_, _comf,
  { {0xb5fd17eb, 0x68e307ec, 0x290c0760, 0x00000000}},  //   nešt, tond, _bida_,
  { {0x394f17ec, 0x7e7d16f8, 0x290c00fa, 0x00000000}},  //   rugs_, _hasp, _cida_,
  { {0x68e302ae, 0xf094061e, 0xdce40036, 0x00000000}},  //   rond, ינס_, jwię,
  { {0x68e307f8, 0x7cf00103, 0xf7700558, 0x00000000}},  //   sond, järj, تاه_,
  { {0x68e3028c, 0x7e7d0173, 0xb5fd0243, 0x00000000}},  //   pond, _masp, ješt,
  { {0x290c002d, 0x38ab068f, 0x2d84012d, 0x00000000}},  //   _gida_, _mørk_, _šmek_,
  { {0x61ed0e7f, 0x7afb16da, 0x7e7d0035, 0x00000000}},  //   _ayal, _khut, _oasp,
  { {0x7e7d0059, 0x7cf00039, 0x61ed03cc, 0x00000000}},  //   _nasp, värm, _byal,
  { {0xfdbe0044, 0x78a1141a, 0x60c500f6, 0x00000000}},  //   _আড্ড, _kolv, _bmhm,
  { {0x43850054, 0xdddd0046, 0x61ed01aa, 0x00000000}},  //   _ملتق, _obsł, _dyal,
  { {0x7afb01c2, 0x6d5d01f3, 0x7e7d005b, 0x00000000}},  //   _ohut, _aqsa, _basp,
  { {0x7ea30004, 0x63b5012d, 0x00000000, 0x00000000}},  //   _sõpr, đanč,   ,
  { {0x7c350036, 0x61ed0010, 0xde35007e, 0x00000000}},  // [30e0] _bezr, _gyal, рэсь,
  { {0x7cf017ed, 0xddc6004f, 0x7e7d0051, 0x00000000}},  //   märk, _takž, _easp,
  { {0x7afb17ee, 0x5f7603ec, 0x290c0614, 0x00000000}},  //   _bhut, _صادر, _rida_,
  { {0xe9da102a, 0x7e7d096e, 0xbae501fb, 0x00000000}},  //   нке_, _gasp, ацій,
  { {0x9e63007e, 0x290c008e, 0x78a1000c, 0x00000000}},  //   _увяд, _pida_, _bolv,
  { {0xa91d0059, 0x7e7d016e, 0x290c006b, 0x00000000}},  //   _tržn, _zasp, _qida_,
  { {0x290c06f4, 0x69dc0046, 0xf6e6026b, 0x00000000}},  //   _vida_, _śred, лцин,
  { {0x7afb0051, 0x00000000, 0x00000000, 0x00000000}},  //   _ghut,   ,   ,
  { {0x45d403f3, 0xbcfb0051, 0x290c0056, 0x00000000}},  //   ропс, _spéi, _tida_,
  { {0xb5fd003b, 0x7ea30004, 0x63a805b7, 0x00000000}},  //   vešt, _lõpp, tydn,
  { {0x61ed0022, 0x7d0e000a, 0x00000000, 0x00000000}},  //   _syal, _mibs,   ,
  { {0x7d0e002b, 0x63a80190, 0xd83800ca, 0x00000000}},  //   _libs, rydn, _kočo_,
  { {0x7e7d17ef, 0xe534007c, 0xf486007e, 0x00000000}},  //   _rasp, _тель, _буйн,
  { {0x7e7d17f0, 0x00000000, 0x00000000, 0x00000000}},  //   _sasp,   ,   ,
  { {0x387e17f1, 0x3ea200bb, 0x7e640bdc, 0x00000000}},  //   _matr_, _bokt_, ffip,
  { {0x4ea4012b, 0x00000000, 0x00000000, 0x00000000}},  //   бруа,   ,   ,
  { {0x6d5d0061, 0x7e7d003b, 0xdd94007c, 0x00000000}},  // [30f0] _qqsa, _vasp, баты,
  { {0x7e7d10ed, 0x80d30044, 0x7afb0edd, 0x00000000}},  //   _wasp, _দীর্, _shut,
  { {0x7e7d1750, 0xda1500ed, 0x7afb0082, 0x00000000}},  //   _tasp, адењ, _phut,
  { {0x78a11341, 0xa3c300b9, 0x8f9a0097, 0x00000000}},  //   _solv, náší_, _סירי,
  { {0x78a108d3, 0x3cea0087, 0x442c0022, 0x00000000}},  //   _polv, _fkbv_, kbd_,
  { {0x07a50265, 0x6b830039, 0xe8f8007e, 0x00000000}},  //   иалн, ångs, глі_,
  { {0x78a10219, 0x6447008e, 0x6d4d108a, 0x00000000}},  //   _volv, ójim, lraa,
  { {0x6f0f0066, 0x78a10d29, 0x46a501ab, 0x00000000}},  //   _jicc, _wolv, раив,
  { {0x6f0f0197, 0x6d4d0dde, 0x78a117f2, 0x00000000}},  //   _micc, nraa, _tolv,
  { {0x99d4004b, 0x6f0f0026, 0x7eaa0161, 0x00000000}},  //   _اتفا, _licc, _výpi,
  { {0xf7990123, 0x6e2d0725, 0x6d4d0dd7, 0x00000000}},  //   _جناب_, kbab, hraa,
  { {0x6f0f17f3, 0x6d4d006c, 0x7cf003a9, 0x00000000}},  //   _nicc, kraa, tärk,
  { {0x7ceb0276, 0x644e0325, 0x00000000, 0x00000000}},  //   nürs, óbic,   ,
  { {0x6d4d01b5, 0x75290181, 0x00000000, 0x00000000}},  //   draa, mpez,   ,
  { {0x6f0f17f4, 0x7eb100ea, 0x7d0e0146, 0x00000000}},  //   _bicc, _våpn, _ribs,
  { {0xddc60046, 0x6e2d006a, 0x6f0f0207, 0x00000000}},  //   _takż, gbab, _cicc,
  { {0x6f0f029a, 0x6d4d017d, 0x00000000, 0x00000000}},  // [3100] _dicc, graa,   ,
  { {0x8c460088, 0x00000000, 0x00000000, 0x00000000}},  //   реже,   ,   ,
  { {0x6f0f0779, 0x6e2d16a7, 0x7cf00614, 0x00000000}},  //   _ficc, bbab, näri,
  { {0x6d4d0116, 0x8b230088, 0x7eb806c2, 0x00000000}},  //   braa, ідче, _bípe,
  { {0x394017f5, 0x2d84009d, 0x798902f1, 0x00000000}},  //   éis_, _éme_, _crew,
  { {0x79890036, 0x7cf000b0, 0x00000000, 0x00000000}},  //   _drew, käri,   ,
  { {0xd90d06c6, 0xd6da0517, 0xbb4303e0, 0x00000000}},  //   ریم_, кти_, _мерк,
  { {0x2f1c0010, 0xa5340088, 0x7989000a, 0x00000000}},  //   _míg_, бнич, _frew,
  { {0x79890544, 0x6f040048, 0xd8380087, 0x00000000}},  //   _grew, imic, _hočm_,
  { {0xd4060242, 0x00000000, 0x00000000, 0x00000000}},  //   ияни,   ,   ,
  { {0x6f040119, 0xdddd0089, 0x7eb800fa, 0x00000000}},  //   kmic, _pasū, _zípe,
  { {0xf2c70264, 0x20cd010a, 0x6f040107, 0x00000000}},  //   рсон, džia_, jmic,
  { {0x6f0f0207, 0x6f0411e4, 0x442c0093, 0x00000000}},  //   _ricc, dmic, pbd_,
  { {0x6d4d015c, 0x6f0f0207, 0x14f3007e, 0x00000000}},  //   vraa, _sicc, _дзіў,
  { {0x6f0f0198, 0x04040044, 0x13a90014, 0x00000000}},  //   _picc, _শ্রী_, _منوی_,
  { {0x5eb401be, 0x6f04016c, 0x6e2d01c3, 0x00000000}},  //   ойст, gmic, ubab,
  { {0x6e2d01a3, 0x6f0f0010, 0xf1a4007e, 0x00000000}},  // [3110] rbab, _vicc, _дрэн,
  { {0x6f0f0066, 0x6d4d01b5, 0xd83800d0, 0x00000000}},  //   _wicc, rraa, _neč_,
  { {0x6f0f0afb, 0x6d4d17f6, 0x2ef201c3, 0x00000000}},  //   _ticc, sraa, blyf_,
  { {0x6e9501b7, 0x6d4d00c7, 0x38b900f4, 0x00000000}},  //   _الحا, praa, _mère_,
  { {0xda7804dd, 0xdced0166, 0xd83804eb, 0x00000000}},  //   рях_, svađ, _beč_,
  { {0x7ceb0279, 0x31e40044, 0x00000000, 0x00000000}},  //   rürs, নেকশ,   ,
  { {0x4738007e, 0x798901d6, 0x00000000, 0x00000000}},  //   ачыў_, _wrew,   ,
  { {0x7cf003b6, 0x79890544, 0x24890276, 0x00000000}},  //   väri, _trew, _şam_,
  { {0x798901f3, 0x00000000, 0x00000000, 0x00000000}},  //   _urew,   ,   ,
  { {0x6f041144, 0x8b0800b9, 0x7cf017f7, 0x00000000}},  //   zmic, pořá, täri,
  { {0x130a007c, 0x752901a2, 0x972300a1, 0x00000000}},  //   лной_, spez, _بہبو,
  { {0xfbd200b6, 0x752917f8, 0x00000000, 0x00000000}},  //   לתי_, ppez,   ,
  { {0xd46901f9, 0x86c40380, 0x00000000, 0x00000000}},  //   _биле_, _بينن,   ,
  { {0x6023012b, 0x7cf017f9, 0xd7f10082, 0x00000000}},  //   здра, päri, _kỹ_,
  { {0xf41200b6, 0x2d8b008e, 0x38b9009d, 0x00000000}},  //   _צפה_, _arce_, _gère_,
  { {0xd7f10082, 0x93240464, 0x2d8b0087, 0x00000000}},  //   _mỹ_, _برون, _brce_,
  { {0xbea317fa, 0xdce60089, 0x25bf17fb, 0x00000000}},  // [3120] чатк, _apkā, nzul_,
  { {0xc5f200a3, 0x6f040091, 0xeb9a01ab, 0x00000000}},  //   לדן_, smic, лиз_,
  { {0x7f860054, 0xd838012b, 0xdee601ee, 0x00000000}},  //   _الجن, _reč_, _гони,
  { {0xba160055, 0x93bc001a, 0x7cf017fc, 0x00000000}},  //   ার্ড_, mbăt, järv,
  { {0x2fd70167, 0xa3a90061, 0xd8380910, 0x00000000}},  //   _نوید_, _गॅस_, _peč_,
  { {0x3ea7000d, 0x48e30265, 0x6d560058, 0x00000000}},  //   _într_, почв, muya,
  { {0xd83817fd, 0xf1bf0047, 0x6d56011c, 0x00000000}},  //   _več_, zzá_, luya,
  { {0x7e760943, 0xc6f8003b, 0x00000000, 0x00000000}},  //   neyp, јних_,   ,
  { {0xe8fa01ee, 0xd8380087, 0x00000000, 0x00000000}},  //   _бла_, _teč_,   ,
  { {0xb86601ef, 0x7c3e0232, 0x38b900f4, 0x00000000}},  //   _دارو, napr, _père_,
  { {0xd25102fd, 0x7e7617fe, 0x6d56002d, 0x00000000}},  //   وند_, keyp, huya,
  { {0x6d56011c, 0xddcd001a, 0x3f85000c, 0x00000000}},  //   kuya, neaţ, ælum_,
  { {0x9c8301d9, 0x7cf0010f, 0x41e7007e, 0x00000000}},  //   ščit, läru, сіна,
  { {0x9a290011, 0x6d560f9f, 0x7c3e010e, 0x00000000}},  //   _mươi_, duya, japr,
  { {0x443e04be, 0x2d8b0825, 0xaab803d7, 0x00000000}},  //   mat_, _srce_, _आतंक,
  { {0xd251026c, 0xff0701e1, 0x3ea00065, 0x00000000}},  //   _کچھ_, сягн, gjit_,
  { {0x38ab0030, 0x22490281, 0xf2d40049, 0x00000000}},  // [3130] _kørt_, _idak_, _מעק_,
  { {0x645a0006, 0xd99900a1, 0xbcfb009d, 0x00000000}},  //   ngti, ینات_, _apér,
  { {0x443e001a, 0x68ea01c3, 0x00000000, 0x00000000}},  //   iat_, dofd,   ,
  { {0x443e170b, 0x6d560058, 0x2d8b0107, 0x00000000}},  //   hat_, buya, _trce_,
  { {0x443e0281, 0x5d33026c, 0x7cf0006c, 0x00000000}},  //   kat_, _رہائ, värv,
  { {0x443e021e, 0x02c60204, 0xac180437, 0x00000000}},  //   jat_, _लग्न, _гору_,
  { {0x443e17ff, 0xccf200a0, 0x3eb9000c, 0x00000000}},  //   dat_, _חכם_, _klst_,
  { {0x224909e4, 0x645a063f, 0x00000000, 0x00000000}},  //   _ndak_, egti,   ,
  { {0x443e0149, 0x99d40025, 0x3eb90009, 0x00000000}},  //   fat_, _فتكا, _mlst_,
  { {0xe4c501fb, 0x20cd010a, 0x25ad0f5c, 0x00000000}},  //   ійни, džio_, ryel_,
  { {0x7cf000b0, 0x25ad0173, 0x69cd0316, 0x00000000}},  //   märt, syel_, _देती,
  { {0x7c3e0032, 0xf7700257, 0x420a0581, 0x00000000}},  //   zapr, _سام_, инно_,
  { {0x443e020c, 0x7c3e0c2c, 0x38ab043e, 0x00000000}},  //   bat_, yapr, _ført_,
  { {0x443e1800, 0x6ac60061, 0x53a50025, 0x00000000}},  //   cat_, _वष्र, _ومشك,
  { {0xa91d1144, 0x6d4b1801, 0x7c3e1802, 0x00000000}},  //   _drži, ágan, vapr,
  { {0x765b0011, 0x6d561803, 0x93bc001a, 0x00000000}},  //   nguy, tuya, rbăt,
  { {0x27e0011f, 0x6296006a, 0x7c3e1804, 0x00000000}},  // [3140] ğini_, _inyo, tapr,
  { {0x6284001a, 0x27e01805, 0x6286006c, 0x00000000}},  //   _haio, şini_, ldko,
  { {0x7c3e0065, 0x62841806, 0xbea60216, 0x00000000}},  //   rapr, _kaio, _данк,
  { {0x443e1807, 0x6286001f, 0x7c3e0089, 0x00000000}},  //   zat_, ndko, sapr,
  { {0x628402d5, 0x443e12d9, 0x7c3e0006, 0x00000000}},  //   _maio, yat_, papr,
  { {0x443e1808, 0xceb4006b, 0xed4301e1, 0x00000000}},  //   xat_, lkə_, _інсп,
  { {0x443e1809, 0x6d44180a, 0x99490036, 0x00000000}},  //   vat_, lsia, góły_,
  { {0x7c3c0756, 0x443e170b, 0x9a290011, 0x00000000}},  //   _herr, wat_, _tươi_,
  { {0x443e120d, 0x7c3c021e, 0x628600ea, 0x00000000}},  //   tat_, _kerr, ddko,
  { {0x6296180b, 0x443e088c, 0xc9d50014, 0x00000000}},  //   _anyo, uat_, _عملک,
  { {0x7c3c008d, 0x6284002d, 0x4394003b, 0x00000000}},  //   _merr, _baio, чанс,
  { {0x443e020c, 0x7c3c180c, 0x6d440ed1, 0x00000000}},  //   sat_, _lerr, ksia,
  { {0x443e0475, 0x7792025a, 0xd25100a2, 0x00000000}},  //   pat_, _ریکا, ونگ_,
  { {0x84380054, 0x443e0312, 0x629600d4, 0x00000000}},  //   _اكثر_, qat_, _enyo,
  { {0x6d44007f, 0x6d4601c9, 0x224904be, 0x00000000}},  //   esia, _avka, _tdak_,
  { {0x443c0374, 0x764001e5, 0x628400c4, 0x00000000}},  //   _hev_, namy, _gaio,
  { {0x7c3c180d, 0xa91d0091, 0x21290133, 0x00000000}},  // [3150] _berr, _trži, _utah_,
  { {0x7c3c0219, 0x7640180e, 0x6284002d, 0x00000000}},  //   _cerr, hamy, _zaio,
  { {0x443c0007, 0x6d4401b1, 0x7eaa0161, 0x00000000}},  //   _mev_, asia, _výpr,
  { {0x0f7a007b, 0x7cf003a2, 0x443c0142, 0x00000000}},  //   _פארב, färs, _lev_,
  { {0x7c3c0917, 0x6b8e180f, 0xdb050010, 0x00000000}},  //   _ferr, _erbg, gyhá,
  { {0x7c3c002d, 0x3f810065, 0x7aeb1810, 0x00000000}},  //   _gerr, _kshu_, sogt,
  { {0x7d1d01a3, 0xe7390057, 0x78a80107, 0x00000000}},  //   _huss, щей_, _dodv,
  { {0x7c3c022b, 0x7d1d0112, 0x7c25005b, 0x00000000}},  //   _zerr, _kuss, lchr,
  { {0x7d1d00b0, 0x62841290, 0xa43d0451, 0x00000000}},  //   _juss, _raio, льнi,
  { {0x6e3d0365, 0x7d1d010f, 0x6aa900b5, 0x00000000}},  //   _lesb, _muss, _hoef,
  { {0x443c1811, 0x7d1d01bc, 0x62840026, 0x00000000}},  //   _dev_, _luss, _paio,
  { {0x6d440bd0, 0x6e3d1742, 0x443c0066, 0x00000000}},  //   ysia, _nesb, _eev_,
  { {0x361a0476, 0x5ec30055, 0x443c1812, 0x00000000}},  //   _הונד, ্কাই, _fev_,
  { {0x7e6f1813, 0x6abb00f6, 0xd8380087, 0x00000000}},  //   _abcp, _lluf, _poči_,
  { {0x7d1d1814, 0xdfd20025, 0x6abb0190, 0x00000000}},  //   _auss, رير_, _oluf,
  { {0x7c3c0181, 0x7d15001e, 0x7d1d006c, 0x00000000}},  //   _serr, _aizs, _buss,
  { {0x7c3c0211, 0x6d44010a, 0x6e3d022b, 0x00000000}},  // [3160] _perr, usia, _desb,
  { {0x7e6f001c, 0x6e240197, 0x4425013e, 0x00000000}},  //   _ebcp, scib, ncl_,
  { {0x6d44085d, 0x44270638, 0x7d1d1815, 0x00000000}},  //   ssia, _mfn_, _euss,
  { {0x64411816, 0x7c3c002b, 0x13ae0044, 0x00000000}},  //   hali, _werr, _ছেড়,
  { {0x44271817, 0x7d1d01a2, 0xe0df00f6, 0x00000000}},  //   _ofn_, _guss, cròs_,
  { {0x64410da1, 0x6f1e00ee, 0x69c202ae, 0x00000000}},  //   jali, _kupc, rzoe,
  { {0xf09300b6, 0xa3cb013d, 0x6abb10c5, 0x00000000}},  //   תנו_, _रेल_, _fluf,
  { {0x443c0089, 0x6441006c, 0x7d1d00a9, 0x00000000}},  //   _sev_, eali, _yuss,
  { {0x644105b7, 0x44271818, 0x7ae31819, 0x00000000}},  //   fali, _bfn_, énte,
  { {0x6441181a, 0xb21b000c, 0x442700d2, 0x00000000}},  //   gali, rdæm, _cfn_,
  { {0x81aa0055, 0x39460b33, 0x442711a8, 0x00000000}},  //   _গেল_, lsos_, _dfn_,
  { {0x39461505, 0x64410103, 0x3267007c, 0x00000000}},  //   osos_, aali, чтов,
  { {0x6441181b, 0x443c001e, 0xfbc40044, 0x00000000}},  //   bali, _tev_, ্থিত,
  { {0x64a3008b, 0x20cd07e4, 0x00000000, 0x00000000}},  //   _пача, mžik_,   ,
  { {0x61e4033f, 0x7d1d054f, 0x2d82002d, 0x00000000}},  //   _exil, _suss, _aske_,
  { {0x7d1d001c, 0x33db009b, 0x394612ea, 0x00000000}},  //   _puss, _לחוד, ksos_,
  { {0x7c25181c, 0x7b03010e, 0x7cf000f8, 0x00000000}},  // [3170] tchr, nõue, värr,
  { {0xad9b008e, 0xc1bc009b, 0x6aa900d9, 0x00000000}},  //   _azúc, _למחש, _soef,
  { {0x2d820263, 0x7c25181d, 0x7d150047, 0x00000000}},  //   _eske_, rchr, _vizs,
  { {0x7c2504e5, 0x7d1d0100, 0x6441181e, 0x00000000}},  //   schr, _tuss, zali,
  { {0x64410263, 0x6934181f, 0x00000000, 0x00000000}},  //   yali, енчу,   ,
  { {0x6441005f, 0x9ce700a1, 0xec290025, 0x00000000}},  //   xali, _روزے_, _ذكرى_,
  { {0x64410004, 0x238c00b9, 0x6aa91820, 0x00000000}},  //   vali, _něj_, _toef,
  { {0x6441105e, 0x7e6d0026, 0x00000000, 0x00000000}},  //   wali, nfap,   ,
  { {0x64411821, 0x26c3010a, 0xc6480025, 0x00000000}},  //   tali, ėjo_, سجيل_,
  { {0xf34902dc, 0x644100e5, 0x3a3f0112, 0x00000000}},  //   опол_, uali, _heup_,
  { {0x644109fb, 0x2242002b, 0x68e40048, 0x00000000}},  //   rali, takk_, éide,
  { {0x6441006a, 0xe29a1822, 0x291f0020, 0x00000000}},  //   sali, цам_, _kuua_,
  { {0x64411616, 0xf65200b3, 0x442700f8, 0x00000000}},  //   pali, _יצא_, _tfn_,
  { {0xd838012d, 0x6441013f, 0x00000000, 0x00000000}},  //   _foču_, qali,   ,
  { {0xdce401d5, 0x291f006c, 0xbef90061, 0x00000000}},  //   stiċ, _luua_, ंतून_,
  { {0x61f600b0, 0x61e4002d, 0x2d820022, 0x00000000}},  //   _tyyl, _txil, _pske_,
  { {0x65690089, 0xf1bf1823, 0x3eab005b, 0x00000000}},  // [3180] nteh, lcán_, _doct_,
  { {0x315700bd, 0x24870263, 0xec770140, 0x00000000}},  //   _קיין_, _janm_, мпу_,
  { {0x24870263, 0x6569010e, 0x00000000, 0x00000000}},  //   _manm_, hteh,   ,
  { {0x39460943, 0x212001a3, 0x24870173, 0x00000000}},  //   tsos_, _kuih_, _lanm_,
  { {0x397a06f1, 0x39460006, 0x3a261824, 0x00000000}},  //   تصاد_, usos_, rcop_,
  { {0x394603d1, 0x3a261825, 0x2240000c, 0x00000000}},  //   rsos_, scop_, _leik_,
  { {0x39460ca7, 0xdce40213, 0xdb8300e3, 0x00000000}},  //   ssos_, ntič, _игри,
  { {0x81c40055, 0x38c806c6, 0x2d8008e7, 0x00000000}},  //   _এখন_, _کاری_, owie_,
  { {0x786601be, 0x248701aa, 0xe5c6007c, 0x00000000}},  //   _оказ, _banm_, ьско,
  { {0xdce400ee, 0x7eb100ea, 0xd8380087, 0x00000000}},  //   ktič, _håpt, _poču_,
  { {0xb8651826, 0x61fa006b, 0x2487000a, 0x00000000}},  //   _سالو, ətli, _danm_,
  { {0x9294008b, 0x212005cd, 0xe6930025, 0x00000000}},  //   ваюц, _buih_, _للمد,
  { {0x24870263, 0xf5b6004b, 0xf1bf008e, 0x00000000}},  //   _fanm_, _تصاد, acán_,
  { {0xfd4f0011, 0x2d800036, 0x00000000, 0x00000000}},  //   _triế, dwie_,   ,
  { {0xc588001d, 0x22400443, 0x00000000, 0x00000000}},  //   _hồ_, _feik_,   ,
  { {0x24871827, 0x6e3601d6, 0x00000000, 0x00000000}},  //   _zanm_, gbyb,   ,
  { {0xfd1f1828, 0x00000000, 0x00000000, 0x00000000}},  // [3190] _quì_,   ,   ,
  { {0xc5880011, 0x00000000, 0x00000000, 0x00000000}},  //   _mồ_,   ,   ,
  { {0xc5880011, 0x50d4006d, 0xf4290052, 0x00000000}},  //   _lồ_, _جزير, lkää_,
  { {0x527c0049, 0x0dcb0cb3, 0x00000000, 0x00000000}},  //   ַנוא, _дуги_,   ,
  { {0x5e56007b, 0x39490051, 0x00000000, 0x00000000}},  //   _אירע_, éas_,   ,
  { {0x6f0d016e, 0xb06600b0, 0x6b830190, 0x00000000}},  //   lmac, _ikää, ængs,
  { {0x66020e49, 0x7ceb1829, 0x26cf00c4, 0x00000000}},  //   _azok, kürz, _pmgo_,
  { {0xc5880011, 0xf4060044, 0x6569032e, 0x00000000}},  //   _bồ_, োডার_, tteh,
  { {0x9875007e, 0x2240182a, 0x78880089, 0x00000000}},  //   _плац, _reik_, _būvē,
  { {0x6f0d010f, 0x6569182b, 0x660201ee, 0x00000000}},  //   hmac, rteh, _dzok,
  { {0x6569001f, 0x6f0d00b5, 0xccf2009b, 0x00000000}},  //   steh, kmac, רכי_,
  { {0x87b6007b, 0xe7b60049, 0x60d5065e, 0x00000000}},  //   _אלעס_, _אהער_, eizm,
  { {0x463a00bd, 0xf1bf0051, 0xa3d40164, 0x00000000}},  //   _זענע, scán_, _सेठ_,
  { {0x73e50265, 0x6721182c, 0x3075007c, 0x00000000}},  //   _полз, _kulj, кусс,
  { {0x91030081, 0x2d8f0190, 0x21200093, 0x00000000}},  //   упре, ægen_, _wuih_,
  { {0x6721182d, 0x2d800036, 0x6d56005b, 0x00000000}},  //   _mulj, twie_, trya,
  { {0xdce40340, 0x672101d5, 0xf3890011, 0x00000000}},  // [31a0] stič, _lulj, _hả_,
  { {0x9f860245, 0x60d514a8, 0x6c860025, 0x00000000}},  //   _згод, cizm, علام,
  { {0x6e46025f, 0x103b009b, 0x26df0166, 0x00000000}},  //   _пенз, _מגיע, knuo_,
  { {0xe6070379, 0x6da60aa2, 0x00000000, 0x00000000}},  //   _مش_, _зима,   ,
  { {0xd6d0089d, 0xda650025, 0x7ae3008e, 0x00000000}},  //   یقت_, ضاني, énta,
  { {0x98a30057, 0x67210091, 0xc5880082, 0x00000000}},  //   личе, _bulj, _rồ_,
  { {0x6602182e, 0xfce3004c, 0x00000000, 0x00000000}},  //   _szok, _соро,   ,
  { {0x67210243, 0x26df0166, 0x7d1b00f6, 0x00000000}},  //   _dulj, gnuo_, _èusc,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x07a6008b, 0x6721182f, 0xf3890082, 0x00000000}},  //   _пазн, _fulj, _bả_,
  { {0xf389001d, 0x67211830, 0x9259007e, 0x00000000}},  //   _cả_, _gulj, мант_,
  { {0x95ca05a5, 0x66e302dc, 0xf4290052, 0x00000000}},  //   _нула_, _йоха, tkää_,
  { {0x67210e00, 0xe0df00d4, 0x00000000, 0x00000000}},  //   _zulj, bsòl_,   ,
  { {0x6f0d00bb, 0x13f4005e, 0x645c1831, 0x00000000}},  //   wmac, _изля, órid,
  { {0x6f0d010f, 0xf3890082, 0x00000000, 0x00000000}},  //   tmac, _gả_,   ,
  { {0x25e70061, 0x60d50b30, 0x752200e7, 0x00000000}},  //   _जखमी_, sizm, _kuoz,
  { {0x75220006, 0x00000000, 0x00000000, 0x00000000}},  // [31b0] _juoz,   ,   ,
  { {0x6f0d054e, 0x26df04eb, 0x00000000, 0x00000000}},  //   smac, znuo_,   ,
  { {0xc4d3007b, 0xf3890011, 0x00000000, 0x00000000}},  //   נגע_, _xả_,   ,
  { {0x7642004a, 0x00000000, 0x00000000, 0x00000000}},  //   _neoy,   ,   ,
  { {0x67211832, 0x79820a81, 0x00000000, 0x00000000}},  //   _sulj, gwow,   ,
  { {0x3ea9002b, 0xdb2301ef, 0x9dd6009b, 0x00000000}},  //   ljat_, _موسی, _יורק_,
  { {0x26df0107, 0xf09401ce, 0x07a50c4e, 0x00000000}},  //   tnuo_, טנס_, тайн,
  { {0x3ea90065, 0x00000000, 0x00000000, 0x00000000}},  //   njat_,   ,   ,
  { {0xceb4061e, 0x26df04eb, 0xf3890082, 0x00000000}},  //   טיק_, rnuo_, _sả_,
  { {0x26df0166, 0x752200d9, 0x249c00e5, 0x00000000}},  //   snuo_, _duoz, _cnvm_,
  { {0x3fdc0044, 0x00000000, 0x00000000, 0x00000000}},  //   _ধর্ষ,   ,   ,
  { {0xe2970454, 0xf3890011, 0x3ea90066, 0x00000000}},  //   ваю_, _vả_, jjat_,
  { {0xcb12007b, 0x20d601fb, 0x3ea90066, 0x00000000}},  //   ילט_, вівс, djat_,
  { {0xf3890011, 0x3ea9082f, 0x00000000, 0x00000000}},  //   _tả_, ejat_,   ,
  { {0x10a3003b, 0x7eb810af, 0xddca0036, 0x00000000}},  //   ширн, _hípi, łoży,
  { {0x20cd0006, 0x3ea90ea9, 0x00000000, 0x00000000}},  //   džiu_, gjat_,   ,
  { {0x6443008a, 0xe0d20014, 0xa7fc005a, 0x00000000}},  // [31c0] _keni, _نزد_, _acıl,
  { {0x6443020c, 0x3ea900b0, 0x2004013f, 0x00000000}},  //   _jeni, ajat_, əmin_,
  { {0x6443020c, 0x394d0285, 0xaa460fd8, 0x00000000}},  //   _meni, _aves_, веел,
  { {0x79820036, 0x656b0066, 0xdb210010, 0x00000000}},  //   twow, _oqgh, átás,
  { {0x20cd016c, 0x3eab0161, 0x00000000, 0x00000000}},  //   rživ_, žitá_,   ,
  { {0x64430065, 0x79820036, 0x00000000, 0x00000000}},  //   _neni, rwow,   ,
  { {0xbb430256, 0x394d1833, 0x00000000, 0x00000000}},  //   _веск, _eves_,   ,
  { {0x7d1c00f2, 0xd6d70783, 0x7e64010e, 0x00000000}},  //   _hirs, кты_, ngip,
  { {0x6443011f, 0x2d9201aa, 0x2b5a00f6, 0x00000000}},  //   _beni, nvye_, lrpc_,
  { {0x64431834, 0xd90e0167, 0xe7ed006e, 0x00000000}},  //   _ceni, _بیت_, _चुका_,
  { {0x7d1c01c5, 0x6443114e, 0x3dc9002b, 0x00000000}},  //   _mirs, _deni, zzaw_,
  { {0x7ae217a9, 0x394d00f4, 0x7d1c116b, 0x00000000}},  //   nnot, _yves_, _lirs,
  { {0xb35606c6, 0x7ae20052, 0x7d1c00d9, 0x00000000}},  //   ریکا_, inot, _oirs,
  { {0x64431835, 0x00000000, 0x00000000, 0x00000000}},  //   _geni,   ,   ,
  { {0x64480091, 0x3ea91836, 0x251b00a3, 0x00000000}},  //   madi, tjat_, _קווא,
  { {0x7d1c1837, 0x644304a7, 0xaf340014, 0x00000000}},  //   _airs, _zeni, شرفت,
  { {0x7ae2004f, 0x644301f6, 0x3ea90bf4, 0x00000000}},  // [31d0] dnot, _yeni, rjat_,
  { {0x3e53001d, 0x628f00d9, 0x27e9001a, 0x00000000}},  //   ệt_, ldco, şani_,
  { {0x7d1c0101, 0x5a35005e, 0x442e1838, 0x00000000}},  //   _dirs, гнет, _mff_,
  { {0x9415007b, 0x628f1768, 0x64481839, 0x00000000}},  //   אַנד_, ndco, hadi,
  { {0x7d1c0038, 0x442e0038, 0xd5a6031d, 0x00000000}},  //   _firs, _off_, _اف_,
  { {0x6448183a, 0x7c3406e7, 0x6f1d01c3, 0x00000000}},  //   jadi, _верх, _hisc,
  { {0xccf2009b, 0x64430023, 0x8af9006b, 0x00000000}},  //   _לכך_, _reni, _atəş,
  { {0xb5fd0089, 0x6e2d01a3, 0x7ae200ca, 0x00000000}},  //   egša, ncab, cnot,
  { {0x6d4d0158, 0xc867003b, 0x644800fa, 0x00000000}},  //   nsaa, _атеи, fadi,
  { {0x6448049a, 0x64430065, 0x6f1d0bad, 0x00000000}},  //   gadi, _qeni, _lisc,
  { {0x6443000d, 0x442e0045, 0x00000000, 0x00000000}},  //   _veni, _dff_,   ,
  { {0x6443001f, 0x68ed002a, 0x442e0061, 0x00000000}},  //   _weni, éadf, _eff_,
  { {0x644304bd, 0x6448000b, 0x645c029d, 0x00000000}},  //   _teni, badi, óric,
  { {0x6f1d002a, 0xa3d40164, 0x6d4d0007, 0x00000000}},  //   _aisc, _सेव_, dsaa,
  { {0xd36e0025, 0x7ae20784, 0x6d4d01d6, 0x00000000}},  //   _فهو_, ynot, esaa,
  { {0x6d4d0007, 0x63bc05b7, 0x7d1c01c5, 0x00000000}},  //   fsaa, ørne, _sirs,
  { {0xed5701f9, 0x7e640181, 0x7ae2183b, 0x00000000}},  // [31e0] лот_, rgip, vnot,
  { {0x7ff60025, 0x7ae21733, 0x6f1d0e93, 0x00000000}},  //   _مسجا, wnot, _eisc,
  { {0x7ae20e40, 0x7d1c1104, 0xf4250044, 0x00000000}},  //   tnot, _virs, _মজার_,
  { {0x64480aab, 0x6e2d1003, 0xeafa023c, 0x00000000}},  //   zadi, ccab, ررات_,
  { {0x2d8400f4, 0x7d1c0030, 0x7ae2142e, 0x00000000}},  //   _ème_, _tirs, rnot,
  { {0x7ae216ae, 0x2cb100ca, 0x644800fa, 0x00000000}},  //   snot, _gozd_, xadi,
  { {0x6448010a, 0x9cd7019b, 0xe3a70464, 0x00000000}},  //   vadi, _עולה_, _ار_,
  { {0x6448183c, 0x65aa003b, 0x6f1d0d62, 0x00000000}},  //   wadi, етог_, _xisc,
  { {0x6448183d, 0x442c00e5, 0xceb300b3, 0x00000000}},  //   tadi, tcd_, מיה_,
  { {0x6560141b, 0x297b0049, 0x25a00066, 0x00000000}},  //   rumh, _אטמא, _ġild_,
  { {0x6448183e, 0xd6d90036, 0x442e183f, 0x00000000}},  //   radi, bił_, _vff_,
  { {0x6448005f, 0x291e1840, 0xd6d90036, 0x00000000}},  //   sadi, _hita_, cił_,
  { {0x6f1d0d60, 0x291e0149, 0x628f0857, 0x00000000}},  //   _risc, _kita_, rdco,
  { {0x4394005e, 0xf1c20059, 0x93f5006b, 0x00000000}},  //   _вакс, dišč_, çəcə,
  { {0x14d700a0, 0x291e0020, 0x4034007c, 0x00000000}},  //   _גוגל_, _mita_, сесс,
  { {0xf1a70264, 0x291e01c9, 0x6d4d0dde, 0x00000000}},  //   _брон, _lita_, tsaa,
  { {0x2d580194, 0x6e2d01a3, 0x272a0082, 0x00000000}},  // [31f0] лить_, rcab, _lùn_,
  { {0x6d4d0007, 0x224b0061, 0x6e2d0211, 0x00000000}},  //   rsaa, lack_, scab,
  { {0x6d4d0368, 0x6f1d010f, 0xbc070242, 0x00000000}},  //   ssaa, _tisc, учай,
  { {0x6f1d002a, 0x69cb010f, 0x291e0d49, 0x00000000}},  //   _uisc, tzge, _aita_,
  { {0x18690a27, 0x291e074d, 0x00000000, 0x00000000}},  //   вали_, _bita_,   ,
  { {0xd6d90036, 0x224b1841, 0x2d99008e, 0x00000000}},  //   wił_, hack_, _irse_,
  { {0x291e0065, 0xa3d4006e, 0x00000000, 0x00000000}},  //   _dita_, _सेल_,   ,
  { {0xca480054, 0x2d99016c, 0x291e1842, 0x00000000}},  //   _ملفه_, _krse_, _eita_,
  { {0x7afb12ad, 0x291e03d1, 0x7ac4003b, 0x00000000}},  //   _ikut, _fita_, _усре,
  { {0x291e096e, 0xa509003b, 0x04b5004d, 0x00000000}},  //   _gita_, ђена_, рсия,
  { {0x645c0181, 0x7ae900ea, 0xaab90061, 0x00000000}},  //   ória, _kjet, _आवाक,
  { {0x95d9007c, 0xb6050618, 0x8c1a009b, 0x00000000}},  //   _идет_, _pišč, כותי,
  { {0x7afb000b, 0x7ae90065, 0x2611007d, 0x00000000}},  //   _mkut, _mjet, देशी_,
  { {0x7ae90182, 0x7eb800f6, 0x27e90035, 0x00000000}},  //   _ljet, _lípt, şanu_,
  { {0x2d990951, 0x7afb0c07, 0x7ae900b9, 0x00000000}},  //   _arse_, _okut, _ojet,
  { {0x5de6026b, 0x7ae90023, 0xb60511a5, 0x00000000}},  //   ажба, _njet, _tišč,
  { {0x1c461843, 0xf8c50309, 0x00000000, 0x00000000}},  // [3200] инам, वसाय,   ,
  { {0x7ae90efc, 0x3b96003b, 0x91bb009b, 0x00000000}},  //   _ajet, ијет, _סמיי,
  { {0x2d8b0207, 0x60dc0058, 0x2d9901c3, 0x00000000}},  //   _esce_, mirm, _erse_,
  { {0x291e1844, 0x2bda001c, 0x60dc005a, 0x00000000}},  //   _sita_, _येणा, lirm,
  { {0x291e023a, 0x7ae90182, 0xed57005e, 0x00000000}},  //   _pita_, _djet, _коя_,
  { {0xd8f70088, 0x60dc0058, 0xd90d00a6, 0x00000000}},  //   анії_, nirm, فیق_,
  { {0x291e01f4, 0x3cf50061, 0x7ae90023, 0x00000000}},  //   _vita_, ्तरे_, _fjet,
  { {0x12c10055, 0x7ae91845, 0x7eb80010, 0x00000000}},  //   _উদ্দ, _gjet, _típu,
  { {0x2bda0061, 0x291e011c, 0xe4a6007c, 0x00000000}},  //   _येता, _tita_, арно,
  { {0xd49a01f9, 0x291e001a, 0x27fe0062, 0x00000000}},  //   три_, _uita_, _tytn_,
  { {0x60dc038c, 0x929500ec, 0x224b14f9, 0x00000000}},  //   dirm, банц, tack_,
  { {0x81c30089, 0x56930088, 0x63ba1846, 0x00000000}},  //   ņēmi, _маєт, rytn,
  { {0x60dc11be, 0xd5341847, 0x3a240022, 0x00000000}},  //   firm, _افتخ, _mgmp_,
  { {0x55bb009b, 0x224b01a2, 0x332700d9, 0x00000000}},  //   _במדו, sack_, _funx_,
  { {0x2327045e, 0xb5e80055, 0xd4370049, 0x00000000}},  //   _који_, _পরিচ, _דרוק_,
  { {0x61ed002d, 0x67281848, 0x60dc0009, 0x00000000}},  //   _txal, _mudj, airm,
  { {0x60dc008e, 0x5d99007e, 0x3209014a, 0x00000000}},  // [3210] birm, ыкаў_, _uzay_,
  { {0x7afb0387, 0x7ae90209, 0x60dc1849, 0x00000000}},  //   _skut, _sjet, cirm,
  { {0x443e010f, 0x68f8184a, 0x7ae90065, 0x00000000}},  //   ibt_, dovd, _pjet,
  { {0x8f9a009b, 0x66e800b9, 0x212905cd, 0x00000000}},  //   _עירי, děko, _kuah_,
  { {0x7ae9105b, 0xe9f80088, 0x0dcb01e4, 0x00000000}},  //   _vjet, анці_, _руни_,
  { {0xe8f802f0, 0x672800b0, 0x26c60085, 0x00000000}},  //   алі_, _budj, _aloo_,
  { {0x7ae9008d, 0x6728016c, 0x7b03006c, 0x00000000}},  //   _tjet, _cudj, nõuk,
  { {0x7afb0020, 0x7ae911b9, 0x645c000c, 0x00000000}},  //   _ukut, _ujet, órin,
  { {0x60dc006b, 0x2eaa0049, 0xb93400e2, 0x00000000}},  //   yirm, רשפּ, _метј,
  { {0x7af90e9c, 0x21210022, 0x7b2c0276, 0x00000000}},  //   lowt, _nihh_, _oğul,
  { {0x6728184b, 0x80ab0164, 0x60dc005d, 0x00000000}},  //   _gudj, ञाने, virm,
  { {0x2129027e, 0x1b7a0049, 0xe1ff004a, 0x00000000}},  //   _buah_, נטרע, rgón_,
  { {0x60dc184c, 0x443e0039, 0xd36e0014, 0x00000000}},  //   tirm, bbt_, وهی_,
  { {0x7af90126, 0x753b00f6, 0x3f9a012d, 0x00000000}},  //   howt, mpuz, _prpu_,
  { {0xbea600e3, 0x60dc000c, 0x4f95019d, 0x00000000}},  //   бавк, rirm, орту,
  { {0xc24601e0, 0x00000000, 0x00000000, 0x00000000}},  //   _уник,   ,   ,
  { {0x5e3300a1, 0x60dc0058, 0x93bc001a, 0x00000000}},  // [3220] سّلا, pirm, scăt,
  { {0x30860025, 0x00000000, 0x00000000, 0x00000000}},  //   _الدف,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6286184d, 0x248501a2, 0x799b01d6, 0x00000000}},  //   neko, helm_, _bruw,
  { {0x6f04010f, 0x67280243, 0x38cb0014, 0x00000000}},  //   mlic, _sudj, گانی_,
  { {0x6f04184e, 0x6286006c, 0x6728184f, 0x00000000}},  //   llic, heko, _pudj,
  { {0x68f801d5, 0x62860056, 0x38cb02fd, 0x00000000}},  //   rovd, keko, دانی_,
  { {0x6f04001f, 0x62860209, 0x9f5f009d, 0x00000000}},  //   nlic, jeko, érée_,
  { {0x645c1850, 0x6286002d, 0xceb4006b, 0x00000000}},  //   ório, deko, mməd_,
  { {0x67281851, 0x6f04010f, 0x443e010f, 0x00000000}},  //   _tudj, hlic, ubt_,
  { {0x6f041852, 0x443e1853, 0x224900ab, 0x00000000}},  //   klic, rbt_, _peak_,
  { {0x6286037f, 0xbc1b0049, 0xd5a402fd, 0x00000000}},  //   geko, טויש, _ولای,
  { {0x6f04001f, 0xc05b01fb, 0x7ae3008e, 0x00000000}},  //   dlic, лів_, énti,
  { {0xf61700b6, 0x22491854, 0x00000000, 0x00000000}},  //   _החדש_, _weak_,   ,
  { {0x6f04010f, 0x6286002d, 0xf48700a2, 0x00000000}},  //   flic, beko, _دانی,
  { {0x6f041855, 0x66021856, 0x644a1857, 0x00000000}},  //   glic, _kyok, _hefi,
  { {0xdced0161, 0xd04e006b, 0x6b9c0146, 0x00000000}},  // [3230] stač, hibə, _arrg,
  { {0x644a01ee, 0x6f04004a, 0x00000000, 0x00000000}},  //   _jefi, alic,   ,
  { {0x66020249, 0x6d460066, 0xebd900e2, 0x00000000}},  //   _lyok, _ewka, јдеш_,
  { {0x6f04001c, 0x99990256, 0x799b06f6, 0x00000000}},  //   clic, икет_, _pruw,
  { {0x64580059, 0x660200e7, 0x00000000, 0x00000000}},  //   _odvi, _nyok,   ,
  { {0x47590265, 0x62861858, 0x98a200e3, 0x00000000}},  //   ария_, zeko, дише,
  { {0xe7390057, 0x6602011c, 0x16a9007c, 0x00000000}},  //   шей_, _ayok, ивки_,
  { {0x2ee9018e, 0x64580f44, 0x66020173, 0x00000000}},  //   nnaf_, _advi, _byok,
  { {0x644a0109, 0x785b0089, 0x66020045, 0x00000000}},  //   _befi, tāvē, _cyok,
  { {0x644a1859, 0x753b185a, 0xe6c4012d, 0x00000000}},  //   _cefi, rpuz, ćešć,
  { {0x644a185b, 0x6286022b, 0xdce40091, 0x00000000}},  //   _defi, teko, stić,
  { {0x24850191, 0x6458185c, 0x6722004a, 0x00000000}},  //   selm_, _edvi, _gioj,
  { {0x412a0057, 0x349500ed, 0x236501ee, 0x00000000}},  //   рого_, _мадр, sulj_,
  { {0x644a000c, 0xa06a01fc, 0x7e6f01f3, 0x00000000}},  //   _gefi, јава_, _accp,
  { {0x64410343, 0x6f04001f, 0x68e4002a, 0x00000000}},  //   mbli, tlic, éidi,
  { {0xee3a00d7, 0x7523010f, 0xf412009b, 0x00000000}},  //   рна_, _hinz, _קפה_,
  { {0x6f04001f, 0x764b0047, 0x75230066, 0x00000000}},  // [3240] rlic, _megy, _kinz,
  { {0x764b0047, 0x7c650025, 0x75230066, 0x00000000}},  //   _legy, كامل, _jinz,
  { {0x61fb01d5, 0x7523185d, 0x44270203, 0x00000000}},  //   żult, _minz, _mgn_,
  { {0x764b185e, 0xaf3500a1, 0xbebb01d6, 0x00000000}},  //   _negy, _ڈویژ, _hiën,
  { {0x67220211, 0x442709ea, 0x2d8f0030, 0x00000000}},  //   _rioj, _ogn_, æget_,
  { {0x764b00ea, 0x4427185f, 0x752301f3, 0x00000000}},  //   _aegy, _ngn_, _ninz,
  { {0x764b02cc, 0x644a1860, 0x68ed0051, 0x00000000}},  //   _begy, _refi, éada,
  { {0x35b400d7, 0x442702d8, 0x644a0035, 0x00000000}},  //   збир, _agn_, _sefi,
  { {0x94aa01f9, 0xd04e005f, 0x2db70049, 0x00000000}},  //   атна_, sibə, ַלטן_,
  { {0x2cb81861, 0x75231862, 0x7c3b016c, 0x00000000}},  //   _jord_, _cinz, _đurk,
  { {0x2cb80239, 0x44270169, 0x644a000c, 0x00000000}},  //   _mord_, _dgn_, _vefi,
  { {0x7523001f, 0x04fc0055, 0x050a0044, 0x00000000}},  //   _einz, ীদের_, রদের_,
  { {0x64410409, 0x75231863, 0x66de0089, 0x00000000}},  //   bbli, _finz, lūko,
  { {0x64580018, 0x75231864, 0x00000000, 0x00000000}},  //   _udvi, _ginz,   ,
  { {0x7659005b, 0x00000000, 0x00000000, 0x00000000}},  //   _ydwy,   ,   ,
  { {0x442700bb, 0x00000000, 0x00000000, 0x00000000}},  //   _zgn_,   ,   ,
  { {0x2cb81865, 0x00000000, 0x00000000, 0x00000000}},  // [3250] _bord_,   ,   ,
  { {0x75231866, 0x2cb80133, 0xf1bf004a, 0x00000000}},  //   _xinz, _cord_, scás_,
  { {0xfe7000a1, 0x2fc500ea, 0x00000000, 0x00000000}},  //   عدہ_, ølgd_,   ,
  { {0x6ffa009b, 0x00000000, 0x00000000, 0x00000000}},  //   _להתפ,   ,   ,
  { {0x6441018e, 0xd9451867, 0x00000000, 0x00000000}},  //   ybli, чели,   ,
  { {0x752b1868, 0x00000000, 0x00000000, 0x00000000}},  //   _rugz,   ,   ,
  { {0x3eb900b5, 0x75231869, 0x8ae70088, 0x00000000}},  //   _kost_, _rinz, _діал,
  { {0xc9870265, 0x7e6d020c, 0x752300e7, 0x00000000}},  //   _музи, ngap, _sinz,
  { {0x3eb9124f, 0x95550025, 0x44270093, 0x00000000}},  //   _most_, أخبا, _pgn_,
  { {0xe7330054, 0x3eb900ab, 0x6441186a, 0x00000000}},  //   _قصص_, _lost_, ubli,
  { {0x64411440, 0xe29a025f, 0xf7700025, 0x00000000}},  //   rbli, бан_, _لان_,
  { {0x2907002b, 0x752301a2, 0x3eb90089, 0x00000000}},  //   llna_, _winz, _nost_,
  { {0x27310011, 0x7aeb0051, 0x7523186b, 0x00000000}},  //   _hán_, ingt, _tinz,
  { {0x9742037e, 0x659a012f, 0x859a009b, 0x00000000}},  //   šćen, _לינק, _לשנו,
  { {0x3f570f68, 0x3eb9186c, 0x8fa300ed, 0x00000000}},  //   għu_, _bost_, наре,
  { {0x3eb900ab, 0x273111ea, 0x2cb80584, 0x00000000}},  //   _cost_, _mán_, _sord_,
  { {0x3eb901ca, 0x273108cc, 0x4d66007e, 0x00000000}},  // [3260] _dost_, _lán_, якав,
  { {0x6296011c, 0x27310082, 0x7aeb0045, 0x00000000}},  //   _hayo, _oán_, engt,
  { {0x3eb91305, 0x6296011c, 0x2d8f0190, 0x00000000}},  //   _fost_, _kayo, æger_,
  { {0x2cb80aba, 0x3eb9186d, 0x2fc50637, 0x00000000}},  //   _word_, _gost_, ølge_,
  { {0xe8940228, 0x62960781, 0x2cb80946, 0x00000000}},  //   даль, _mayo, _tord_,
  { {0x273100ad, 0x62960339, 0x6d560093, 0x00000000}},  //   _bán_, _layo, msya,
  { {0xd6da0077, 0x27310011, 0xaa46025f, 0x00000000}},  //   йти_, _cán_, _невл,
  { {0x7c3b0107, 0x987801d9, 0x27310011, 0x00000000}},  //   _đuri, _išči_, _dán_,
  { {0x6d56186e, 0x7ae20639, 0x00000000, 0x00000000}},  //   nsya, miot,   ,
  { {0x7ae20a64, 0x6296011c, 0x38c80167, 0x00000000}},  //   liot, _aayo, _باری_,
  { {0x78a80698, 0xd91b071c, 0xb80a006d, 0x00000000}},  //   _indv, _פובל, _ايام_,
  { {0xddc4001e, 0x7ae20a59, 0x60de0022, 0x00000000}},  //   maiņ, niot, _ampm,
  { {0x64a6186f, 0x6296011c, 0x3eb9001a, 0x00000000}},  //   _нада, _dayo, _rost_,
  { {0x760b007b, 0x7ae20197, 0x1543025f, 0x00000000}},  //   _פּאַ, hiot, _џејм,
  { {0x2005000c, 0xd4970104, 0x78ba1870, 0x00000000}},  //   æli_, _זכות_, _motv,
  { {0x6296011c, 0x00000000, 0x00000000, 0x00000000}},  //   _gayo,   ,   ,
  { {0x7e6d1871, 0xa2aa006e, 0x3eb90068, 0x00000000}},  // [3270] rgap, टार्, _vost_,
  { {0xb035004d, 0xddd60010, 0x78ba1872, 0x00000000}},  //   _юнош, ggyő, _notv,
  { {0x316c0036, 0x62960009, 0x2b58012d, 0x00000000}},  //   ądze_, _yayo, _cvrc_,
  { {0x7ae20912, 0x27311873, 0x78a81874, 0x00000000}},  //   giot, _rán_, _andv,
  { {0x78ba0a5e, 0x27310082, 0x00000000, 0x00000000}},  //   _botv, _sán_,   ,
  { {0x273104bb, 0xf7710688, 0x00000000, 0x00000000}},  //   _pán_, ناب_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x78a80030, 0x7ae21875, 0xe559012b, 0x00000000}},  //   _endv, ciot, ојој_,
  { {0x6296005f, 0x7827023c, 0xbbdd0316, 0x00000000}},  //   _rayo, _فعال, _मधुक,
  { {0x62961876, 0x27311877, 0xddc41878, 0x00000000}},  //   _sayo, _tán_, ngiš,
  { {0x6296103f, 0x68e31879, 0x00000000, 0x00000000}},  //   _payo, mind,   ,
  { {0x31790009, 0x91e600ed, 0x00000000, 0x00000000}},  //   ftsz_, доме,   ,
  { {0x656900fa, 0x6abb0068, 0x00000000, 0x00000000}},  //   queh, _mouf,   ,
  { {0x7ae2187a, 0x6296187b, 0xf992009b, 0x00000000}},  //   ziot, _wayo, דרך_,
  { {0x6296006a, 0x6aa9046a, 0x1eaa04e8, 0x00000000}},  //   _tayo, _onef, ياري_,
  { {0x68e3187c, 0x646201c5, 0x00000000, 0x00000000}},  //   hind, ētiņ,   ,
  { {0x68e30edb, 0x7ae2187d, 0x00000000, 0x00000000}},  // [3280] kind, viot,   ,
  { {0x3cfa013d, 0x6d56187e, 0x69c20020, 0x00000000}},  //   ्तें_, rsya, vyoe,
  { {0x68e30ddd, 0xb4fa0049, 0x7ae200b0, 0x00000000}},  //   dind, קלער, tiot,
  { {0x68e30146, 0x00000000, 0x00000000, 0x00000000}},  //   eind,   ,   ,
  { {0x68e3187f, 0x7ae2002d, 0x6abb00b9, 0x00000000}},  //   find, riot, _douf,
  { {0x68e301a3, 0x7ae3008e, 0x97a601ee, 0x00000000}},  //   gind, éntr, дрил,
  { {0xf76f06dd, 0xad9b0010, 0xda660025, 0x00000000}},  //   لاي_, _nyúj, _ياري,
  { {0x68e30022, 0x6abb009d, 0x00000000, 0x00000000}},  //   aind, _gouf,   ,
  { {0x68e3152d, 0x00000000, 0x00000000, 0x00000000}},  //   bind,   ,   ,
  { {0x78a80d32, 0x68e3014a, 0x6abb07e4, 0x00000000}},  //   _undv, cind, _zouf,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x25a900ee, 0xe7691880, 0x658700f8, 0x00000000}},  //   _šale_, _رحمن_, örhå,
  { {0xf4930063, 0x471b1881, 0x98a400e5, 0x00000000}},  //   رشید, _וואג, _gumă_,
  { {0x660f010f, 0x3cfa013d, 0x00000000, 0x00000000}},  //   ücke, ्तों_,   ,
  { {0xcebb003b, 0xdfd50a7c, 0x00000000, 0x00000000}},  //   оља_, ховы,   ,
  { {0x68e3005f, 0x00000000, 0x00000000, 0x00000000}},  //   zind,   ,   ,
  { {0x68e3027d, 0x9d15007e, 0x6abb0e6d, 0x00000000}},  // [3290] yind, едач, _rouf,
  { {0x6abb11aa, 0x68e3006b, 0xa2c70061, 0x00000000}},  //   _souf, xind, ासक्,
  { {0xf092009b, 0x6abb1882, 0x00000000, 0x00000000}},  //   _גני_, _pouf,   ,
  { {0x68e30125, 0x00000000, 0x00000000, 0x00000000}},  //   wind,   ,   ,
  { {0x68e3005f, 0x1958007e, 0x69af0061, 0x00000000}},  //   tind, дачы_, ंमधी,
  { {0x7b03006c, 0xd5af009e, 0x00000000, 0x00000000}},  //   tõus, یہا_,   ,
  { {0x68e301f6, 0x6abb1339, 0x98a40035, 0x00000000}},  //   rind, _touf, _sumă_,
  { {0x68e3038c, 0x6aa9004a, 0x00000000, 0x00000000}},  //   sind, _unef,   ,
  { {0x68e3000b, 0x32090058, 0x00000000, 0x00000000}},  //   pind, _nyay_,   ,
  { {0x97420091, 0x00000000, 0x00000000, 0x00000000}},  //   šćan,   ,   ,
  { {0x28ac006e, 0xe29a132e, 0x320900e0, 0x00000000}},  //   चारि, пан_, _ayay_,
  { {0xd055006b, 0xe29a007e, 0xdce4014a, 0x00000000}},  //   mizə, чам_, ktiğ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x257901aa, 0x657b00e7, 0x00000000, 0x00000000}},  //   mèl_, mtuh,   ,
  { {0x3f1600ed, 0x60c101e5, 0x394d000a, 0x00000000}},  //   еќат, ölma, _lwes_,
  { {0x116800a2, 0x00000000, 0x00000000, 0x00000000}},  //   _قلبی_,   ,   ,
  { {0x25790263, 0x7c3b02b9, 0x2bec0044, 0x00000000}},  // [32a0] nèl_, _şura, _করেই_,
  { {0xfa150044, 0x00000000, 0x00000000, 0x00000000}},  //   িশাল_,   ,   ,
  { {0x22520058, 0x612b002b, 0x0b46005e, 0x00000000}},  //   _keyk_, _iżla, хнен,
  { {0x657b011c, 0x29050095, 0x00000000, 0x00000000}},  //   ktuh, _akla_,   ,
  { {0x28ac013d, 0x19941883, 0x28be013d, 0x00000000}},  //   चालि, таля, ्सलि,
  { {0x26cf1884, 0x25790263, 0xd90d00a6, 0x00000000}},  //   _algo_, dèl_, قیق_,
  { {0x56941523, 0x6625006b, 0x62841885, 0x00000000}},  //   вайт, ərkə, _obio,
  { {0xd6d70057, 0x29050173, 0x20d4006c, 0x00000000}},  //   еть_, _ekla_, _häid_,
  { {0x88860751, 0x6d4415ea, 0xa967005e, 0x00000000}},  //   _плаж, npia, _пита_,
  { {0x62841886, 0x20d4006c, 0x6d440006, 0x00000000}},  //   _abio, _jäid_, ipia,
  { {0xe2f90088, 0x02cc0061, 0x00000000, 0x00000000}},  //   дені_, ासून,   ,
  { {0x257901aa, 0x00000000, 0x00000000, 0x00000000}},  //   bèl_,   ,   ,
  { {0xe298007e, 0xc68f00a1, 0x00000000, 0x00000000}},  //   хаў_, _دِن_,   ,
  { {0x2ec902fb, 0x628400d9, 0x63a30009, 0x00000000}},  //   रस्त, _ebio, _frnn,
  { {0x6d4404a5, 0x442e0335, 0x00000000, 0x00000000}},  //   epia, _igf_,   ,
  { {0xdce4014a, 0xceb4006b, 0x00000000, 0x00000000}},  //   ttiğ, smən_,   ,
  { {0xb8160044, 0xceb4013f, 0x00000000, 0x00000000}},  // [32b0] াশিত_, mməl_,   ,
  { {0x629d0637, 0x62840036, 0x00000000, 0x00000000}},  //   ldso, _zbio,   ,
  { {0x37e50044, 0x257901aa, 0xdce40095, 0x00000000}},  //   _পুনর, zèl_, stiğ,
  { {0x628f0bc0, 0x25790263, 0x7b2c014a, 0x00000000}},  //   neco, yèl_, _ağus,
  { {0x6f0d1887, 0x629d1888, 0x442e0146, 0x00000000}},  //   mlac, idso, _ogf_,
  { {0x6f0d0791, 0x25790263, 0x013800b3, 0x00000000}},  //   llac, vèl_, ערות_,
  { {0x628f0085, 0x6f0d0048, 0x00000000, 0x00000000}},  //   keco, olac,   ,
  { {0x25791889, 0x442e0030, 0xd055006b, 0x00000000}},  //   tèl_, _agf_, rizə,
  { {0x628f164f, 0x629d0016, 0x6f0d00d9, 0x00000000}},  //   deco, ddso, ilac,
  { {0x257901aa, 0x6f0d1274, 0x657b188a, 0x00000000}},  //   rèl_, hlac, rtuh,
  { {0x657b011c, 0x6f0d188b, 0x257901aa, 0x00000000}},  //   stuh, klac, sèl_,
  { {0x2d4f0046, 0x628f0141, 0x81dd0044, 0x00000000}},  //   kże_, geco, _তুই_,
  { {0x69d901a2, 0x6f0d188c, 0x00000000, 0x00000000}},  //   nzwe, dlac,   ,
  { {0x6143004c, 0x442e010f, 0x6f0d0048, 0x00000000}},  //   рера, _ggf_, elac,
  { {0x6d440016, 0x6d5d188d, 0xd0070140, 0x00000000}},  //   wpia, _avsa, вере_,
  { {0x628f1372, 0x4374025f, 0x7b2c006b, 0x00000000}},  //   ceco, _сушт, _oğur,
  { {0xed5701f9, 0xf65201ce, 0x7159007e, 0x00000000}},  // [32c0] кот_, יצן_, _прэс_,
  { {0x672b008d, 0x6f0d002a, 0x315701ce, 0x00000000}},  //   _ligj, alac, _שיין_,
  { {0x6f0d188e, 0x6d44188f, 0xd8380166, 0x00000000}},  //   blac, spia, _jače_,
  { {0x6d441015, 0xd8381890, 0x298a092b, 0x00000000}},  //   ppia, _mače_, дско_,
  { {0xd91000e9, 0x00000000, 0x00000000, 0x00000000}},  //   میر_,   ,   ,
  { {0x8c430088, 0x6569010f, 0x7b2c0035, 0x00000000}},  //   _вере, dreh, _eşua,
  { {0x20d4006c, 0xfce3007c, 0x629d1891, 0x00000000}},  //   _käib_, _торо, ydso,
  { {0x443c0203, 0x2ef20016, 0x25a90340, 0x00000000}},  //   _sfv_, nnyf_, _šala_,
  { {0x80d30055, 0x628f01c5, 0x65691892, 0x00000000}},  //   _সদস্, veco, greh,
  { {0x3946029d, 0x81b80044, 0x6f04077d, 0x00000000}},  //   mpos_, চনা_, hoic,
  { {0x628f0141, 0xd4970783, 0xdced0107, 0x00000000}},  //   teco, тры_, stać,
  { {0x290e0016, 0xdce40bf8, 0x20d4010e, 0x00000000}},  //   llfa_, drič, _näib_,
  { {0x6f0d037e, 0x629d11d1, 0x39460009, 0x00000000}},  //   vlac, rdso, npos_,
  { {0x39460211, 0x443c00fa, 0x27381893, 0x00000000}},  //   ipos_, _ufv_, _kén_,
  { {0x4fc40147, 0x6f0d0142, 0x6d5d012d, 0x00000000}},  //   аста, tlac, _svsa,
  { {0xb275007c, 0x3d9504b6, 0x25a60f5d, 0x00000000}},  //   _слиш, либр, _krol_,
  { {0xa2f800a0, 0x27381894, 0x1e34007e, 0x00000000}},  // [32d0] _שמחה_, _lén_, рнуў,
  { {0x6f0d049a, 0xdce4016c, 0x00000000, 0x00000000}},  //   slac, brič,   ,
  { {0x6f0d0549, 0x27380011, 0xde59013a, 0x00000000}},  //   plac, _nén_, _пані_,
  { {0x69d9010f, 0x6d5d00e5, 0xa904009e, 0x00000000}},  //   tzwe, _tvsa, یبون,
  { {0x998501d8, 0xda780764, 0x394600e0, 0x00000000}},  //   التو, тях_, gpos_,
  { {0xd914008b, 0x69d9010f, 0x27380082, 0x00000000}},  //   адчы, rzwe, _bén_,
  { {0x2738002a, 0x69d901a2, 0x660b0145, 0x00000000}},  //   _cén_, szwe, _sygk,
  { {0x65690010, 0x3869005d, 0xd8380d0a, 0x00000000}},  //   treh, şar_, _rače_,
  { {0x273800b5, 0x3a3f00f6, 0x672b1895, 0x00000000}},  //   _eén_, _ifup_, _vigj,
  { {0x7b2c027d, 0xb4cd0164, 0x25a61896, 0x00000000}},  //   _uğur, रसे_, _drol_,
  { {0x42ea005e, 0x65690d25, 0x25a6014a, 0x00000000}},  //   емно_, sreh, _erol_,
  { {0x6d41092f, 0x216a01fb, 0x65691897, 0x00000000}},  //   _član, ними_, preh,
  { {0x7d050023, 0x25a6012d, 0xca7a0049, 0x00000000}},  //   kohs, _grol_, ענשט,
  { {0x19b6009b, 0xb447007e, 0x00000000, 0x00000000}},  //   אפשר_, _рэдк,   ,
  { {0x2d991898, 0xf4560097, 0x2d8b0f75, 0x00000000}},  //   _asse_, _עיקר_, _apce_,
  { {0x944200a1, 0x00000000, 0x00000000, 0x00000000}},  //   _پھین,   ,   ,
  { {0x6f040bf5, 0xceb4006b, 0x3dc900e0, 0x00000000}},  // [32e0] roic, lmək_, gyaw_,
  { {0xdce40bf8, 0x00000000, 0x00000000, 0x00000000}},  //   prič,   ,   ,
  { {0xe7e3001c, 0x2d9902d5, 0xceb4006b, 0x00000000}},  //   _केला_, _esse_, nmək_,
  { {0x316000d0, 0x39461042, 0x2d860181, 0x00000000}},  //   _kviz_, tpos_, çoes_,
  { {0x9f0604e1, 0xaa570379, 0xb2770049, 0x00000000}},  //   _لوگو, الها_, רענג_,
  { {0x39460325, 0x307a0049, 0xceb4006b, 0x00000000}},  //   rpos_, גאַנ, kmək_,
  { {0x39461899, 0x2d80189a, 0xb8ec006e, 0x00000000}},  //   spos_, ltie_, _लव_,
  { {0x3ea0008d, 0x963400c0, 0x25a600c4, 0x00000000}},  //   ndit_, шниц, _prol_,
  { {0x2d8002ae, 0xb8ea0055, 0xe8fa003b, 0x00000000}},  //   ntie_, _লগ_, _зла_,
  { {0x3f9a012d, 0x3ea00e2c, 0x00000000, 0x00000000}},  //   _ospu_, hdit_,   ,
  { {0xa92301ca, 0x31600035, 0xd25103ec, 0x00000000}},  //   ížen, _aviz_, يند_,
  { {0x57fb009b, 0x2d80189b, 0x25a6005b, 0x00000000}},  //   _אלבו, ktie_, _trol_,
  { {0xf1ab0025, 0x2259007f, 0x3135189c, 0x00000000}},  //   راحه_, rask_, регр,
  { {0xe7b60044, 0x63bc1565, 0x31600173, 0x00000000}},  //   জনীয, ørns, _dviz_,
  { {0x2d800436, 0x443e00f6, 0x7c3e0009, 0x00000000}},  //   etie_, mct_, dcpr,
  { {0x645a030a, 0x2d800de1, 0x3dc900e0, 0x00000000}},  //   lati, ftie_, tyaw_,
  { {0xdc55098c, 0x645a002d, 0x00000000, 0x00000000}},  // [32f0] ивањ, oati,   ,
  { {0x443e189d, 0x7d1c0725, 0x00000000, 0x00000000}},  //   nct_, _chrs,   ,
  { {0x5a350265, 0x2d801541, 0xa2aa0061, 0x00000000}},  //   анет, atie_, टाच्,
  { {0x645a1166, 0x64a60061, 0x3dc900e0, 0x00000000}},  //   hati, _कोसळ, pyaw_,
  { {0x2d80189e, 0x50b800e9, 0xbebb0328, 0x00000000}},  //   ctie_, _شدید_, _diët,
  { {0x645a0027, 0xb4c30164, 0x20d4006c, 0x00000000}},  //   jati, _एके_, _käia_,
  { {0x645a066a, 0x443e00e5, 0x98540088, 0x00000000}},  //   dati, dct_, стіш,
  { {0x16a9007c, 0x0565189f, 0x443e18a0, 0x00000000}},  //   твии_, авин, ect_,
  { {0x6341001e, 0x05760054, 0xba190025, 0x00000000}},  //   _mēne, لمية_, _شيئا_,
  { {0xc4820eb1, 0x7aeb18a1, 0x3ea018a2, 0x00000000}},  //   ольк, ligt, zdit_,
  { {0x69cb18a3, 0x86c50014, 0x31600087, 0x00000000}},  //   lyge, _پيشن, _sviz_,
  { {0x290704bd, 0xceb4005f, 0xf77006dd, 0x00000000}},  //   lona_, rmək_, _رام_,
  { {0x443e01d6, 0xa91d0006, 0x00000000, 0x00000000}},  //   bct_, _apži,   ,
  { {0x645a030a, 0x03a501fb, 0x044500e2, 0x00000000}},  //   cati, _вико, _текн,
  { {0xb21b0030, 0xd8380166, 0x7e56007c, 0x00000000}},  //   lfæl, _jača_, итац,
  { {0xe519013d, 0xd83801c5, 0x290718a4, 0x00000000}},  //   _नीति_, _mača_, hona_,
  { {0x7aeb0343, 0x29070c30, 0x3ea011be, 0x00000000}},  // [3300] digt, kona_, rdit_,
  { {0x2d8018a5, 0x2907066e, 0x3865009d, 0x00000000}},  //   rtie_, jona_, _ndlr_,
  { {0xa7fc038c, 0x2d800027, 0xbebb01c3, 0x00000000}},  //   _adın, stie_, _piët,
  { {0x645a0038, 0x2d8018a6, 0x0a670401, 0x00000000}},  //   zati, ptie_, арши_,
  { {0x660f010f, 0x645a09e5, 0x3b060606, 0x00000000}},  //   ückl, yati, rooq_,
  { {0x290704bd, 0x645a062a, 0x6fba0061, 0x00000000}},  //   gona_, xati, _उपां,
  { {0x645a18a7, 0xe0b70049, 0x00000000, 0x00000000}},  //   vati, ילסט_,   ,
  { {0x645a18a8, 0x79b700a1, 0x69cb00ea, 0x00000000}},  //   wati, _چھوڑ_, byge,
  { {0x645a121e, 0x290718a9, 0x386518aa, 0x00000000}},  //   tati, bona_, _fdlr_,
  { {0x29070e68, 0x79820146, 0x6aa2074e, 0x00000000}},  //   cona_, mtow, ldof,
  { {0x645a1294, 0x443e13ba, 0x92590364, 0x00000000}},  //   rati, rct_, лант_,
  { {0x645a028c, 0x6aa201d6, 0x6d460091, 0x00000000}},  //   sati, ndof, _otka,
  { {0xc05b01fb, 0x79820046, 0x645a18ab, 0x00000000}},  //   ків_, ntow, pati,
  { {0x41e80401, 0x645a18ac, 0x92e70044, 0x00000000}},  //   рфюм_, qati, বকে_,
  { {0x6458001e, 0x251b0476, 0x6d461104, 0x00000000}},  //   _ievi, _שווא, _atka,
  { {0x79820046, 0x645818ad, 0x6d4601c3, 0x00000000}},  //   ktow, _hevi, _btka,
  { {0x290718ae, 0x040b0044, 0x7aeb0190, 0x00000000}},  // [3310] yona_, হেদী_, vigt,
  { {0x40950054, 0xd05c006b, 0x645818af, 0x00000000}},  //   _الدر, kirə, _jevi,
  { {0xd00801f9, 0x29070197, 0x7aeb010f, 0x00000000}},  //   _веќе_, vona_, tigt,
  { {0xd05c006b, 0x68e80016, 0x69cb18b0, 0x00000000}},  //   dirə, _amdd, tyge,
  { {0x29070209, 0x7aeb0007, 0x99d40014, 0x00000000}},  //   tona_, rigt, يتها,
  { {0x645809a9, 0x7aeb18b1, 0x69cb18b2, 0x00000000}},  //   _nevi, sigt, ryge,
  { {0x290718b3, 0x79820036, 0x69cb068f, 0x00000000}},  //   rona_, atow, syge,
  { {0x2907022b, 0x20d4021e, 0x98a500e5, 0x00000000}},  //   sona_, _näin_, _bilă_,
  { {0x7ae916dd, 0x2738001d, 0x799b0036, 0x00000000}},  //   _imet, _lĩnh_, _usuw,
  { {0xa91d0006, 0x6458014a, 0x6aa00035, 0x00000000}},  //   _apžv, _cevi, _zamf,
  { {0x7ae901d9, 0xd6db18b4, 0xd90c00a1, 0x00000000}},  //   _kmet, _итд_, _جیو_,
  { {0x6aa000f6, 0x98a500e5, 0x00000000, 0x00000000}},  //   _xamf, _filă_,   ,
  { {0x45450879, 0x64a5008b, 0x68e8018e, 0x00000000}},  //   _انتق, _гала, _ymdd,
  { {0x05b800a6, 0x64580007, 0x7afb0825, 0x00000000}},  //   _خدمت_, _gevi, _ljut,
  { {0x7ae9006c, 0x66d50428, 0x644118b5, 0x00000000}},  //   _omet, _záka, mcli,
  { {0x79820036, 0x7afb0039, 0x64580026, 0x00000000}},  //   ytow, _njut, _zevi,
  { {0x644100e5, 0x00000000, 0x00000000, 0x00000000}},  // [3320] ocli,   ,   ,
  { {0x7ae90004, 0x7afb18b6, 0x6441006b, 0x00000000}},  //   _amet, _ajut, ncli,
  { {0x7ae90026, 0x2fd00035, 0x00000000, 0x00000000}},  //   _bmet, ângă_,   ,
  { {0x76590bc4, 0xdbd001ca, 0x291e05fa, 0x00000000}},  //   _newy, _užív, _shta_,
  { {0xe3a7026c, 0x78a10089, 0x6d460056, 0x00000000}},  //   _کر_, _balv, _utka,
  { {0x79820046, 0x7ae90129, 0xd05c006b, 0x00000000}},  //   rtow, _emet, tirə,
  { {0x64580038, 0x79820036, 0x76590007, 0x00000000}},  //   _revi, stow, _bewy,
  { {0x6458011f, 0xd6d70a78, 0x3ea200d8, 0x00000000}},  //   _sevi, йты_, _jakt_,
  { {0x7ae300c1, 0x3ea201c9, 0xf772009e, 0x00000000}},  //   ënte, _makt_, زاں_,
  { {0x78a10ebc, 0xd49a0920, 0x644100f6, 0x00000000}},  //   _galv, ури_, gcli,
  { {0x387e0be3, 0xa68600aa, 0x60c50170, 0x00000000}},  //   _ictr_, _глед, _rohm,
  { {0x6443000c, 0x765918b7, 0x332000e5, 0x00000000}},  //   _efni, _gewy, _chix_,
  { {0x645801c1, 0x98ac01aa, 0xa6a9035b, 0x00000000}},  //   _tevi, _lidč_, _خالق_,
  { {0x64a30001, 0x273800ad, 0x673a18b8, 0x00000000}},  //   _нача, _cũng_, _kutj,
  { {0x27380011, 0x673a18b9, 0x3ea218ba, 0x00000000}},  //   _dũng_, _jutj, _bakt_,
  { {0xfbdf0055, 0x2738001d, 0x2bac007d, 0x00000000}},  //   _বুঝত, _vĩnh_, घटना,
  { {0x673a0065, 0xe1670076, 0x628d0058, 0x00000000}},  // [3330] _lutj, _ادبي, _ibao,
  { {0x27380011, 0x7ae90213, 0xbcfb00f4, 0x00000000}},  //   _tĩnh_, _smet, _evén,
  { {0x3ea20dc1, 0x79990487, 0x7afb002b, 0x00000000}},  //   _fakt_, wwww, _pjut,
  { {0x26c60253, 0x6441004a, 0x00000000, 0x00000000}},  //   _nooo_, zcli,   ,
  { {0x78a1021e, 0x1a6800a6, 0x5d790049, 0x00000000}},  //   _palv, صیلی_, _דאָק,
  { {0x6d4d003c, 0xd90f0123, 0xe8f801ff, 0x00000000}},  //   mpaa, ریا_, блі_,
  { {0x78a100b0, 0x6441001c, 0x9405006b, 0x00000000}},  //   _valv, vcli, belə_,
  { {0x7ae901d9, 0x7afb0091, 0x78a1040f, 0x00000000}},  //   _umet, _ujut, _walv,
  { {0x78a1044e, 0x212118bb, 0x6b850300, 0x00000000}},  //   _talv, _ohhh_, lthg,
  { {0x33650805, 0xaf010044, 0x98f70167, 0x00000000}},  //   овог, ্ষিণ_, _اثرا,
  { {0x2ca30047, 0x644101c5, 0x765901c3, 0x00000000}},  //   _majd_, rcli, _tewy,
  { {0x21210058, 0x644100d4, 0xc5d50245, 0x00000000}},  //   _ahhh_, scli, _міль,
  { {0x80b50044, 0x3ea20039, 0xe60e02ea, 0x00000000}},  //   ুসন্, _rakt_, _цд_,
  { {0xceb4006b, 0x27310087, 0x3ea218bc, 0x00000000}},  //   hmət_, _kšno_, _sakt_,
  { {0x3ea200bb, 0x7ce9006b, 0x27380011, 0x00000000}},  //   _pakt_, _görə, _vũng_,
  { {0x212103b0, 0x63ae0190, 0xee3f01e5, 0x00000000}},  //   _ehhh_, æbne, _snýr_,
  { {0xceb4006b, 0x3ea2030e, 0x6d4d011c, 0x00000000}},  // [3340] dmət_, _vakt_, gpaa,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xeb9a009a, 0x0b46007e, 0x00000000, 0x00000000}},  //   рие_, цнен,   ,
  { {0x094a0072, 0x673a18bd, 0x00000000, 0x00000000}},  //   ачки_, _rutj,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x765d000c, 0x6f1600ea, 0x26c601a2, 0x00000000}},  //   ðsyn, llyc, _sooo_,
  { {0xd6da0bbd, 0xf40700a1, 0x00000000, 0x00000000}},  //   ити_, _آؤ_,   ,
  { {0x83fc0091, 0x758a0256, 0xbddb00f6, 0x00000000}},  //   nađe, асов_, _ofèl,
  { {0xc6f7008b, 0x66d5000c, 0x7c390010, 0x00000000}},  //   ўных_, _tákn, _ábrá,
  { {0x673a0065, 0x26c60145, 0x00000000, 0x00000000}},  //   _tutj, _wooo_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x21210146, 0x00000000, 0x00000000, 0x00000000}},  //   _shhh_,   ,   ,
  { {0x66d5004f, 0xe298008b, 0x64a60256, 0x00000000}},  //   _záko, цаў_, _мада,
  { {0x7ce9006b, 0x00000000, 0x00000000, 0x00000000}},  //   _törə,   ,   ,
  { {0xceb4006b, 0x7ce0000c, 0x40340081, 0x00000000}},  //   ymət_, _körf, дерс,
  { {0x83fc037e, 0x66d50428, 0x2ca3002b, 0x00000000}},  //   gađe, _nákl, _sajd_,
  { {0x3f9e000c, 0x00000000, 0x00000000, 0x00000000}},  // [3350] ætur_,   ,   ,
  { {0x6d4d01b1, 0x00000000, 0x00000000, 0x00000000}},  //   rpaa,   ,   ,
  { {0x6d4d095c, 0x6d40009d, 0x2b4a00c4, 0x00000000}},  //   spaa, _éman, _ctbc_,
  { {0xb5fd01d9, 0x6d4d00b0, 0x6b850016, 0x00000000}},  //   laše, ppaa, rthg,
  { {0xdce70279, 0xceb4006b, 0x3179108d, 0x00000000}},  //   şlıc, rmət_, nusz_,
  { {0x9d18005e, 0xb5fd013e, 0x08c401e1, 0x00000000}},  //   _моят_, naše, мбін,
  { {0x7b640242, 0xd37811af, 0x00000000, 0x00000000}},  //   _отте, juć_,   ,
  { {0x6f0d0617, 0x31790f88, 0x672200b4, 0x00000000}},  //   noac, kusz_, _choj,
  { {0xe5710025, 0x7ce001a2, 0x00000000, 0x00000000}},  //   رطة_, _dörf,   ,
  { {0x66d50428, 0xdced0161, 0x83fc012d, 0x00000000}},  //   _zákl, krač, zađe,
  { {0x7ce00073, 0xb5fd003b, 0x130a0783, 0x00000000}},  //   _förf, daše, йной_,
  { {0xf8bd0055, 0xdced00ca, 0xf5560014, 0x00000000}},  //   _অতিথ, drač, _کلوب_,
  { {0x171a007b, 0xe2970783, 0x14a60061, 0x00000000}},  //   _פונע, чая_, _कोकण,
  { {0x7528001c, 0x00000000, 0x00000000, 0x00000000}},  //   cmdz,   ,   ,
  { {0x24670010, 0x6023003b, 0xdced047c, 0x00000000}},  //   _című_, едра, grač,
  { {0x660f01a2, 0x00000000, 0x00000000, 0x00000000}},  //   ückw,   ,   ,
  { {0x83fc0166, 0x7ce000f8, 0x6f1618be, 0x00000000}},  // [3360] rađe, _jörg, rlyc,
  { {0x7ce0000c, 0x200c010e, 0xdced0471, 0x00000000}},  //   _mörg, üdis_, brač,
  { {0x6f0d027b, 0x205700a0, 0xdce4012d, 0x00000000}},  //   boac, _מייל_, hrić,
  { {0xdce40091, 0x672900ca, 0x00000000, 0x00000000}},  //   krić, jmej,   ,
  { {0x7ae30112, 0xd37800b4, 0x00000000, 0x00000000}},  //   ënta, zuć_,   ,
  { {0x2b58009d, 0xdce404eb, 0x00000000, 0x00000000}},  //   _twrc_, drić,   ,
  { {0xb8f4013d, 0x00000000, 0x00000000, 0x00000000}},  //   _हक_,   ,   ,
  { {0xb8d302d2, 0xfaa318bf, 0xd6d00025, 0x00000000}},  //   _जो_, _пасо, ئقة_,
  { {0xdced1470, 0x186a00e2, 0x00000000, 0x00000000}},  //   zrač, _гази_,   ,
  { {0x656f18c0, 0x07a6007c, 0xb4d6013d, 0x00000000}},  //   ácha, _назн, ससे_,
  { {0x67220065, 0x7b370107, 0x6f0d18c1, 0x00000000}},  //   _thoj, _ućut, yoac,
  { {0x6602002d, 0xdced0059, 0xd7ef0025, 0x00000000}},  //   _txok, vrač, _حكم_,
  { {0x7ce018c2, 0xb5fd00ca, 0xdb0e0065, 0x00000000}},  //   _körd, taše, _arbë,
  { {0xdced016e, 0x63bc00f8, 0x00000000, 0x00000000}},  //   trač, ärns,   ,
  { {0xbebb008d, 0xb5fd0059, 0x7ce00a5d, 0x00000000}},  //   _dhën, raše, _mörd,
  { {0x7ce00039, 0x290e0022, 0x00000000, 0x00000000}},  //   _lörd, hofa_,   ,
  { {0x6f0d18c3, 0xdd9407d0, 0x00000000, 0x00000000}},  // [3370] roac, наты,   ,
  { {0xa1150025, 0x81e60044, 0x7ce001a2, 0x00000000}},  //   _زوجت, _বুক_, _nörd,
  { {0x6ce40088, 0x6f0d00e7, 0x00000000, 0x00000000}},  //   хіте, poac,   ,
  { {0x386c0541, 0x2ee00016, 0xdb230014, 0x00000000}},  //   _addr_, chif_, روشی,
  { {0x7ce004ce, 0x3ea90045, 0x00000000, 0x00000000}},  //   _börd, mdat_,   ,
  { {0x3ea90030, 0x008a0049, 0x7ff400a2, 0x00000000}},  //   ldat_, ַרפֿ, _آسیا,
  { {0x7ce00279, 0x917a0082, 0xfaf30025, 0x00000000}},  //   _dörd, _mất_, _كثر_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ce0127c, 0x2d8918c4, 0x2a6d12dd, 0x00000000}},  //   _förd, ntae_, _ideb_,
  { {0x7ce0005d, 0x67290229, 0x3ea900b0, 0x00000000}},  //   _görd, smej, hdat_,
  { {0xf77006b4, 0xb7d5083e, 0x00000000, 0x00000000}},  //   _مان_, _تقاب,   ,
  { {0xbebb008d, 0x25a904eb, 0x00000000, 0x00000000}},  //   _shën, _šalu_,   ,
  { {0x7ce0010f, 0x3ea900f8, 0x823602fd, 0x00000000}},  //   _höre, ddat_, بردا,
  { {0xbddb000a, 0x25ad00ea, 0xd8380087, 0x00000000}},  //   _efèk, mvel_, _račk_,
  { {0x25ad006c, 0x6b9e0009, 0x00000000, 0x00000000}},  //   lvel_, xwpg,   ,
  { {0x3f68006b, 0xf412009b, 0xef1a0245, 0x00000000}},  //   rğu_, _שפה_, іма_,
  { {0xbebb008d, 0x25ad0691, 0x00000000, 0x00000000}},  // [3380] _thën, nvel_,   ,
  { {0x3ea618c5, 0x2ee000e7, 0x6284000a, 0x00000000}},  //   žot_, shif_, _hcio,
  { {0x4f2600c0, 0x66dc0224, 0x26dd0009, 0x00000000}},  //   _одоб, _léka, _olwo_,
  { {0x657b00b0, 0xd8380087, 0x00000000, 0x00000000}},  //   kuuh, _tačk_,   ,
  { {0xd00f01ef, 0x290e1530, 0xe894041f, 0x00000000}},  //   _ملی_, tofa_, еаль,
  { {0xd838016c, 0x394d00f6, 0x7e64007f, 0x00000000}},  //   _kači_, _dtes_, laip,
  { {0x290e18c6, 0x394d18c7, 0x778a006b, 0x00000000}},  //   rofa_, _etes_, _təxm,
  { {0x290e18c8, 0x7e6418c9, 0x356a0194, 0x00000000}},  //   sofa_, naip, орон_,
  { {0xa534004c, 0x38cb00a1, 0xd49a0256, 0x00000000}},  //   ннич, _ڈالی_, орн_,
  { {0x7ce003a2, 0x38cb026c, 0xe0df0263, 0x00000000}},  //   _före, _والی_, npòt_,
  { {0x7ce018ca, 0x3c770104, 0x7e640058, 0x00000000}},  //   _göre, ותים_, kaip,
  { {0x83fc0119, 0xeb91007b, 0x7ae202a3, 0x00000000}},  //   gađa, אָך_, nhot,
  { {0x660f01a2, 0x3ea9035f, 0x518418cb, 0x00000000}},  //   ückt, vdat_, кура,
  { {0x7ce0014a, 0x0ef9013d, 0x30150849, 0x00000000}},  //   _yöre, ्क्स_, едгр,
  { {0x7e7f001c, 0x3ea900c7, 0x644a002b, 0x00000000}},  //   tgqp, tdat_, _iffi,
  { {0x62840051, 0xb5fd0e3b, 0x2249014a, 0x00000000}},  //   _gcio, laša, _ufak_,
  { {0x629d12fe, 0x78ba049b, 0x3ea9046a, 0x00000000}},  // [3390] meso, _ontv, rdat_,
  { {0xb5fd0340, 0x628f01f3, 0x78a80142, 0x00000000}},  //   naša, lfco, _nadv,
  { {0x394d00f6, 0x443c00dd, 0x630400a1, 0x00000000}},  //   _stes_, _mgv_, _سویل,
  { {0x7ce00039, 0x628f0197, 0xdb07000c, 0x00000000}},  //   _röre, nfco, _brjá,
  { {0x644a0038, 0x7ce000f8, 0x2721000c, 0x00000000}},  //   _offi, _söre, jóna_,
  { {0x8d5a0104, 0xf7710379, 0x629d18cc, 0x00000000}},  //   _מכשי, هاب_, heso,
  { {0x7ce00073, 0x629d0065, 0x7ae218cd, 0x00000000}},  //   _förb, keso, bhot,
  { {0x644a0e8d, 0x7ae2000b, 0xdb07000c, 0x00000000}},  //   _affi, chot, _frjá,
  { {0x25ad00d9, 0x443c18ce, 0x00000000, 0x00000000}},  //   uvel_, _bgv_,   ,
  { {0x25ad0030, 0x62840207, 0x7ce018cf, 0x00000000}},  //   rvel_, _scio, _töre,
  { {0x629d050a, 0x39890584, 0x6abb18d0, 0x00000000}},  //   feso, lús_, _knuf,
  { {0x629d0030, 0x660f010f, 0x00000000, 0x00000000}},  //   geso, ücks,   ,
  { {0xa4d501fb, 0x398918d1, 0x443c00c4, 0x00000000}},  //   _поді, nús_, _fgv_,
  { {0x628b0039, 0x83fc016c, 0xbebb0065, 0x00000000}},  //   _ögon, sađa, _dhëm,
  { {0x629d01d6, 0x6569032e, 0x398911ea, 0x00000000}},  //   beso, lseh, hús_,
  { {0xbea3003b, 0x7649014a, 0x00000000, 0x00000000}},  //   ласк, ncey,   ,
  { {0x7e6418d2, 0x656910a4, 0x00000000, 0x00000000}},  // [33a0] raip, nseh,   ,
  { {0x315701ce, 0x67390066, 0x00000000, 0x00000000}},  //   _ריין_, _liwj,   ,
  { {0x7ae2098e, 0x78a80006, 0x7e6400d4, 0x00000000}},  //   thot, _radv, paip,
  { {0xca2608d6, 0x255d01aa, 0x69c2002d, 0x00000000}},  //   нфли, kňl_, txoe,
  { {0x7ae20020, 0xb21b0f4b, 0x78a818d3, 0x00000000}},  //   rhot, lfær, _padv,
  { {0x7ae20020, 0x97a6017f, 0x6abb0943, 0x00000000}},  //   shot, ерил, _enuf,
  { {0x7a36038c, 0x629d008d, 0x5a96008b, 0x00000000}},  //   _bütü, yeso, _праф,
  { {0x398906c2, 0xdb0701e5, 0x00000000, 0x00000000}},  //   bús_, _trjá,   ,
  { {0xb5fd0e00, 0x1a9b0049, 0x78ba0912, 0x00000000}},  //   taša, _צימע, _tntv,
  { {0xdce410ec, 0x00000000, 0x00000000, 0x00000000}},  //   ksič,   ,   ,
  { {0xb5fd18d4, 0x629d0065, 0xbebb0065, 0x00000000}},  //   raša, teso, _shëm,
  { {0xb5fd0ce4, 0x9258007c, 0x2a6600e0, 0x00000000}},  //   mašn, нают_, naob_,
  { {0x629d18d5, 0x443c0666, 0x628f00d9, 0x00000000}},  //   reso, _tgv_, rfco,
  { {0x644a13f0, 0x629d0169, 0x7e6f0009, 0x00000000}},  //   _uffi, seso, _sdcp,
  { {0xb5fd0f3a, 0x629d18d6, 0x2f2700e2, 0x00000000}},  //   našn, peso, еќав,
  { {0x629d0065, 0x612000b0, 0x539b009b, 0x00000000}},  //   qeso, löll, _זיהו,
  { {0xb274007c, 0x00000000, 0x00000000, 0x00000000}},  // [33b0] _слыш,   ,   ,
  { {0x6abb0116, 0x6aa90093, 0x612000b0, 0x00000000}},  //   _snuf, _saef, nöll,
  { {0xb5fd0091, 0xf092009b, 0x00000000, 0x00000000}},  //   jašn, _דני_,   ,
  { {0xb5fd0119, 0xf4130049, 0x255d01aa, 0x00000000}},  //   dašn, אפע_, yňl_,
  { {0x612018d7, 0x6d4f0010, 0x00000000, 0x00000000}},  //   köll, _utca,   ,
  { {0x66d5000c, 0x2d990026, 0xb4bf0061, 0x00000000}},  //   _jákv, _ipse_, _ंचे_,
  { {0x398918d8, 0x255d01aa, 0x66e5004d, 0x00000000}},  //   sús_, wňl_, кока,
  { {0x6569006c, 0x291c00fa, 0x00000000, 0x00000000}},  //   tseh, alva_,   ,
  { {0xd3780036, 0xd6ce0025, 0x7ce000f8, 0x00000000}},  //   erć_, تقي_, _höra,
  { {0x66d5000c, 0x6569010f, 0x7b2c0035, 0x00000000}},  //   _nákv, rseh, _uşur,
  { {0x25a618d9, 0x6569010f, 0x3f47006c, 0x00000000}},  //   _esol_, sseh, _nõu_,
  { {0x05210044, 0x216a02d3, 0x7c3a000c, 0x00000000}},  //   নদের_, мими_, _útre,
  { {0xe7300151, 0x00000000, 0x00000000, 0x00000000}},  //   _اصل_,   ,   ,
  { {0xfd660011, 0xb21b101b, 0x6d40009d, 0x00000000}},  //   _thuầ, tfær, _émai,
  { {0x2d990173, 0x26cf0036, 0x6f6300e2, 0x00000000}},  //   _apse_, _kogo_, иврз,
  { {0xf772061e, 0x26cf02d5, 0x3329002b, 0x00000000}},  //   יקל_, _jogo_, _ghax_,
  { {0xb21b043e, 0x8c460088, 0x62960009, 0x00000000}},  // [33c0] lgæn, везе, _ibyo,
  { {0x811600a1, 0xb21b000c, 0xe058025a, 0x00000000}},  //   _جذبا, pfær, _سیرت_,
  { {0x3eab00ab, 0x5f06007e, 0x6ee3006c, 0x00000000}},  //   _fact_, _азна, _sõbe,
  { {0x68e10039, 0x26cf00ca, 0x00000000, 0x00000000}},  //   _alld, _nogo_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ce00039, 0x3ea00daf, 0x3f9a0093, 0x00000000}},  //   _föra, leit_, _kppu_,
  { {0xf093012f, 0x7ce00039, 0xa3c301ca, 0x00000000}},  //   ינג_, _göra, yšší_,
  { {0x81e80055, 0xb5fd0091, 0x3ea0060d, 0x00000000}},  //   _যখন_, rašn, neit_,
  { {0xe4e6008b, 0x66d50428, 0x26cf0020, 0x00000000}},  //   вінн, _náku, _dogo_,
  { {0x3ea0001f, 0x70d10061, 0xd49a0d15, 0x00000000}},  //   heit_, _सकेल, фри_,
  { {0x3ea0001f, 0x26cf0181, 0x83fc0521, 0x00000000}},  //   keit_, _fogo_, rađo,
  { {0x26cf002d, 0xc2b80088, 0x61200052, 0x00000000}},  //   _gogo_, влює_, söll,
  { {0x39440ebc, 0xdb210047, 0x316d00f4, 0x00000000}},  //   _jums_, ítés, éez_,
  { {0x39441104, 0xab6518da, 0x2a640093, 0x00000000}},  //   _mums_, ngüí, _lemb_,
  { {0xd838001e, 0x3eab0675, 0x60180242, 0x00000000}},  //   _taču_, _pact_, воря_,
  { {0x7ce000f8, 0x3ea00010, 0x00000000, 0x00000000}},  //   _röra, geit_,   ,
  { {0x1df81036, 0x3944003b, 0x2d80004a, 0x00000000}},  // [33d0] веты_, _nums_, guie_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3ea0010f, 0x644f0036, 0x645a01a2, 0x00000000}},  //   beit_, ścig, ibti,
  { {0x2d80000d, 0xeb0d0061, 0x39440089, 0x00000000}},  //   buie_, िकेत_, _bums_,
  { {0xadf0001c, 0x26cf0026, 0xeab003ab, 0x00000000}},  //   _घेऊन_, _rogo_, تعل_,
  { {0x7ce00a5d, 0x9b450188, 0x26cf05cd, 0x00000000}},  //   _hörn, _منسو, _sogo_,
  { {0x7ce009e9, 0x61200039, 0x0b8800ed, 0x00000000}},  //   _körn, följ, _исти_,
  { {0xbb840025, 0x394400d4, 0x05a90088, 0x00000000}},  //   _خلفي, _fums_, евий_,
  { {0x888300a1, 0xeb1f0061, 0xb5fd18db, 0x00000000}},  //   _نیشن, बतीत_, rašo,
  { {0x3ea0010f, 0x645e006c, 0x68e100d4, 0x00000000}},  //   zeit_, _õpil, _ulld,
  { {0x26cf18dc, 0xe784007e, 0x69d90b04, 0x00000000}},  //   _togo_, _вучо, lywe,
  { {0xe1ff004a, 0x73e20900, 0x00000000, 0x00000000}},  //   raón_, союз,   ,
  { {0x765b10e0, 0x3ea018dd, 0x69d900e7, 0x00000000}},  //   mbuy, veit_, nywe,
  { {0x3ea0010f, 0x657b00e7, 0x00000000, 0x00000000}},  //   weit_, mruh,   ,
  { {0x3ea0049b, 0xdee603f3, 0x7ce0009f, 0x00000000}},  //   teit_, гови, _börn,
  { {0x7e550216, 0xeabe0055, 0xceb4006b, 0x00000000}},  //   итуц, _আত্ম, lməz_,
  { {0x3ea018de, 0xb21b0030, 0x518500ed, 0x00000000}},  // [33e0] reit_, ngæl, _куќа,
  { {0x69d918df, 0x442701d6, 0x3ea018e0, 0x00000000}},  //   dywe, _kzn_, seit_,
  { {0x7ce00039, 0x78ae00c4, 0x2d801387, 0x00000000}},  //   _förn, _óbvi, suie_,
  { {0x6286006a, 0x20d4006c, 0x298a005e, 0x00000000}},  //   ngko, _täis_, еско_,
  { {0xf548001d, 0xceb300a3, 0x2d80117e, 0x00000000}},  //   _mục_, _פיש_, quie_,
  { {0x6f0418e1, 0xf5480011, 0xb5fd18e2, 0x00000000}},  //   lnic, _lục_, rašl,
  { {0x6f040166, 0xebe616c4, 0x44270006, 0x00000000}},  //   onic, _совп, _nzn_,
  { {0x6d460258, 0x6f040036, 0x394400f8, 0x00000000}},  //   _kuka, nnic, _tums_,
  { {0x4427006b, 0x1a060888, 0x6aa218e3, 0x00000000}},  //   _azn_, _спам, meof,
  { {0x6d46021e, 0x6f04001a, 0x6aa21270, 0x00000000}},  //   _muka, hnic, leof,
  { {0xd4970147, 0x44380039, 0x634800b9, 0x00000000}},  //   уры_, är_, _věno,
  { {0xf5480011, 0x518701e0, 0x6aa218e4, 0x00000000}},  //   _cục_, луга, neof,
  { {0xf548001d, 0x41e4007e, 0xa2f4007e, 0x00000000}},  //   _dục_, біра, спяч,
  { {0x6f040197, 0x00000000, 0x00000000, 0x00000000}},  //   enic,   ,   ,
  { {0x6d46021a, 0x6f0401ee, 0x403500ed, 0x00000000}},  //   _auka, fnic, ревс,
  { {0x6d460127, 0xf5480082, 0x6f040036, 0x00000000}},  //   _buka, _gục_, gnic,
  { {0x705504e1, 0x644f0046, 0x8cf5007e, 0x00000000}},  // [33f0] _پنجا, ście, азац,
  { {0x63b80b4a, 0x6d460d00, 0xeb0d007d, 0x00000000}},  //   _krvn, _duka, िक्त_,
  { {0x6d4601aa, 0x6f0401ca, 0xfff90167, 0x00000000}},  //   _euka, bnic, _شکست_,
  { {0x7ce018e5, 0x6d4618e6, 0x6aa201d6, 0x00000000}},  //   _föro, _fuka, geof,
  { {0x6d4618e7, 0x3f830091, 0x09d80044, 0x00000000}},  //   _guka, luju_, _দেবা,
  { {0xe9b8026c, 0x69d90343, 0x02e2007d, 0x00000000}},  //   انوں_, rywe, _पत्न,
  { {0x3f830169, 0x69d90197, 0x3f91002d, 0x00000000}},  //   nuju_, sywe, ntzu_,
  { {0x6d46011f, 0x2b4d0802, 0x657b0387, 0x00000000}},  //   _yuka, _čech_, truh,
  { {0xc987098c, 0xb5fd050f, 0x3f8309fc, 0x00000000}},  //   _љуби, mašk, huju_,
  { {0xb4650816, 0x81cb0044, 0x63b818e8, 0x00000000}},  //   школ, লনা_, _brvn,
  { {0x78a300b5, 0x02c60264, 0x765b0009, 0x00000000}},  //   menv, айно, pbuy,
  { {0xdced05fa, 0xb5fd0e00, 0x3f830091, 0x00000000}},  //   brać, našk, duju_,
  { {0x6f040340, 0x628617c6, 0x6146007c, 0x00000000}},  //   vnic, rgko, рега,
  { {0x6f040046, 0x412a004c, 0x6d460091, 0x00000000}},  //   wnic, того_, _ruka,
  { {0xf548001d, 0x52760200, 0x3f830107, 0x00000000}},  //   _tục_, _купу, guju_,
  { {0xb5fd0059, 0xdb0e0344, 0x539a009b, 0x00000000}},  //   jašk, _orbá, _ייצו,

  { {0xee3a00d7, 0x7ce00073, 0x78a300bb, 0x00000000}},  // [3400] тна_, _förl, kenv,
  { {0x6d46037e, 0x3f830062, 0xccc3007c, 0x00000000}},  //   _vuka, buju_, обуй,
  { {0x6f0418e1, 0x3f83016c, 0x307b00b6, 0x00000000}},  //   pnic, cuju_, _באינ,
  { {0x6d46161a, 0xb5fd0c0a, 0x41b302fd, 0x00000000}},  //   _tuka, gašk, _امیر,
  { {0x7ce018e9, 0x64430036, 0x6aa20051, 0x00000000}},  //   _hörm, _ogni, reof,
  { {0x78a3054e, 0x1d0a18ea, 0x307a0049, 0x00000000}},  //   genv, _реги_, דאַנ,
  { {0xe3a70063, 0x96f80256, 0xf6e61867, 0x00000000}},  //   _بر_, лект_, ицин,
  { {0x64430036, 0xd6d7007c, 0xdced016c, 0x00000000}},  //   _agni, иты_, trać,
  { {0x3f830091, 0x2d920173, 0x645e010e, 0x00000000}},  //   zuju_, ntye_, _õpik,
  { {0x63b80224, 0x30c10044, 0x0d97009b, 0x00000000}},  //   _prvn, _উত্স, סכים_,
  { {0x66e60595, 0x7ce000f8, 0x00000000, 0x00000000}},  //   _кожа, _rörl,   ,
  { {0x32670fbb, 0x3f8301ee, 0x96ba00f3, 0x00000000}},  //   штов, vuju_, _جائز_,
  { {0xbddb0129, 0xe4e60088, 0x00000000, 0x00000000}},  //   _agèn, _війн,   ,
  { {0x3f8304cb, 0x3d10013d, 0x64a3003b, 0x00000000}},  //   tuju_, ़कों_, _мача,
  { {0x43840025, 0x2ee9018e, 0x644f0036, 0x00000000}},  //   _العق, thaf_, ścic,
  { {0x2fcd0091, 0x3f830091, 0x78a30e24, 0x00000000}},  //   ćeg_, ruju_, zenv,
  { {0xb5fd01d9, 0x7ce00010, 0x3f830091, 0x00000000}},  // [3410] vašk, _törl, suju_,
  { {0x7ce00073, 0xfd1003ab, 0x3f8304eb, 0x00000000}},  //   _förm, وجل_, puju_,
  { {0x7ce001f6, 0x78a3007f, 0xb5fd0091, 0x00000000}},  //   _görm, venv, tašk,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26cd016c, 0x78a30c4c, 0xb5fd01ed, 0x00000000}},  //   vjeo_, tenv, rašk,
  { {0xac19012b, 0xf745012b, 0x3158009b, 0x00000000}},  //   _богу_, беко, סיון_,
  { {0x3a870147, 0x48780245, 0x78a318eb, 0x00000000}},  //   _вызв, рсія_, renv,
  { {0x78a31596, 0xfc4a0051, 0xb5fd0166, 0x00000000}},  //   senv, _tríú_, laši,
  { {0x78a30a5e, 0x00000000, 0x00000000, 0x00000000}},  //   penv,   ,   ,
  { {0x6444011f, 0xb5fd1472, 0x00000000, 0x00000000}},  //   _şiir, naši,   ,
  { {0x7ce00073, 0xc2c60025, 0x7e6d18ec, 0x00000000}},  //   _börj, ميدي, kaap,
  { {0x4735003b, 0xc0490097, 0x778a006b, 0x00000000}},  //   _унес, _טז_, _təxr,
  { {0xb5fd0107, 0x29070bfd, 0x7ce000f8, 0x00000000}},  //   kaši, onna_, _sörm,
  { {0x644318ed, 0x270c00b9, 0x00000000, 0x00000000}},  //   _ugni, měna_,   ,
  { {0xa355023c, 0x1fb5007c, 0x63530035, 0x00000000}},  //   _اختص, остр, _băne,
  { {0xe9ff0011, 0xf5480011, 0x628d0051, 0x00000000}},  //   _ngắn_, _mụn_, _gcao,
  { {0xb5fd0091, 0x270c00b9, 0x635300e5, 0x00000000}},  // [3420] faši, něna_, _dăne,
  { {0xee370407, 0x2d920007, 0xbc6a01fa, 0x00000000}},  //   сну_, rtye_, امان_,
  { {0xaf0a06b4, 0xbea6030d, 0x7ce001e5, 0x00000000}},  //   _مقدم_, _ланк, _hörk,
  { {0x26180061, 0x7ce018ee, 0x0c370025, 0x00000000}},  //   _पडली_, _körk, حكمة_,
  { {0xceb4006b, 0x83fc0091, 0xdce40036, 0x00000000}},  //   mdə_, rađi, esią,
  { {0xceb4005f, 0x7ce003ed, 0x7d1c0107, 0x00000000}},  //   ldə_, _mörk, _ukrs,
  { {0x6ecc0204, 0xd8380087, 0x00000000, 0x00000000}},  //   हापु, _obče_,   ,
  { {0xceb40163, 0x2907002a, 0xf1050164, 0x00000000}},  //   ndə_, anna_, _रद्द_,
  { {0xceb3012e, 0x2d80004a, 0x7bde18ef, 0x00000000}},  //   ליה_, nrie_, lypu,
  { {0x2d8018f0, 0x337402e9, 0x92c50044, 0x00000000}},  //   irie_, огор, _এতে_,
  { {0xceb4005f, 0xd6cf005e, 0x3cf0013d, 0x00000000}},  //   kdə_, _ет_, _इतने_,
  { {0x7ae2007f, 0x2d800093, 0x00000000, 0x00000000}},  //   nkot, krie_,   ,
  { {0x7e6d001c, 0x656f002a, 0xceb4006b, 0x00000000}},  //   vaap, ácht, ddə_,
  { {0x7ae21092, 0x2cb30555, 0x7e6d1519, 0x00000000}},  //   hkot, xdxd_, waap,
  { {0x7ae200b0, 0x4fc402ea, 0xceb4013f, 0x00000000}},  //   kkot, пста, fdə_,
  { {0x7ce00039, 0x2d8006ec, 0x3f7304eb, 0x00000000}},  //   _förk, frie_, rću_,
  { {0x2907000c, 0x7ce00180, 0x7e6d010e, 0x00000000}},  // [3430] ynna_, _görk, raap,
  { {0x2b580022, 0x26090061, 0x291e00e0, 0x00000000}},  //   _btrc_, ापती_, _nkta_,
  { {0xb5fd0006, 0x2d8018f1, 0xfb8407d0, 0x00000000}},  //   raši, arie_, зычн,
  { {0x2d80001a, 0x291e01a3, 0xceb4006b, 0x00000000}},  //   brie_, _akta_, cdə_,
  { {0x2d800035, 0xcec0013e, 0x60d70288, 0x00000000}},  //   crie_, ářet_, _koxm,
  { {0xfe73026c, 0x92c50044, 0x83fc0107, 0x00000000}},  //   _بدھ_, _এতো_, lađu,
  { {0xa6c90920, 0xddc40006, 0x2aa0000a, 0x00000000}},  //   илка_, maiš, _bčbč_,
  { {0xba7701ef, 0xe579003b, 0x96b9012b, 0x00000000}},  //   _داست, ази_, руку_,
  { {0x7ae9011f, 0x4ae4008b, 0x7afb0943, 0x00000000}},  //   _ilet, _эўра, _imut,
  { {0xceb4005f, 0x039502dc, 0x395d005b, 0x00000000}},  //   zdə_, ормя, mpws_,
  { {0x7ae90343, 0x130a007c, 0xceb4006b, 0x00000000}},  //   _klet, иной_, ydə_,
  { {0xdb1c00f4, 0x92f603e8, 0xceb4006b, 0x00000000}},  //   _arrê, ічні, xdə_,
  { {0x7ce00073, 0x6353001a, 0x60d700bb, 0x00000000}},  //   _förh, _bănc, _boxm,
  { {0x7ae918f2, 0x7ae2002d, 0xa067013b, 0x00000000}},  //   _llet, zkot, жара_,
  { {0x7ae9003c, 0xceb4005f, 0x48e10061, 0x00000000}},  //   _olet, tdə_, _कवनो_,
  { {0xbebb008d, 0x83fc0107, 0xc7b200a0, 0x00000000}},  //   _shër, gađu, ובל_,
  { {0xceb4005f, 0x16360049, 0x2c260044, 0x00000000}},  // [3440] rdə_, ַנער_, _বলেই_,
  { {0x2d800007, 0x7ae91198, 0x69b0013d, 0x00000000}},  //   rrie_, _alet, _आईबी,
  { {0xa09b0476, 0x7ae20e88, 0x7ae918f3, 0x00000000}},  //   _דייט, tkot, _blet,
  { {0x2d8004b4, 0x639a0049, 0xb5fd0059, 0x00000000}},  //   prie_, יסענ, lašu,
  { {0xdb210047, 0xbebb0065, 0x6120000c, 0x00000000}},  //   ítás, _thër, sölu,
  { {0x7ae918f4, 0x3a2d0107, 0xb5fd0006, 0x00000000}},  //   _elet, _dzep_, našu,
  { {0x7ae90028, 0xd90d06c6, 0xf76f023c, 0x00000000}},  //   _flet, دیل_, ناي_,
  { {0x7c2e11e6, 0x00000000, 0x00000000, 0x00000000}},  //   _izbr,   ,   ,
  { {0x29000181, 0xe4a6007c, 0xf77200a1, 0x00000000}},  //   éias_, орно, ساں_,
  { {0x07a6005e, 0x798218f5, 0x449701ab, 0x00000000}},  //   _мазн, mrow, овью_,
  { {0xd6da0014, 0xb6cc0180, 0x94710241, 0x00000000}},  //   _پوشش_, çüsü, رگوا,
  { {0x291c18f6, 0xfc4600b9, 0x79820036, 0x00000000}},  //   lova_, šího_, orow,
  { {0xc6490a4f, 0x00000000, 0x00000000, 0x00000000}},  //   _اجمل_,   ,   ,
  { {0x7ce018f7, 0x00000000, 0x00000000, 0x00000000}},  //   _föri,   ,   ,
  { {0x291c001a, 0x270c00b9, 0x3e6b00ed, 0x00000000}},  //   iova_, něno_, ишан_,
  { {0x291c0091, 0x798218f8, 0xa3c9007d, 0x00000000}},  //   hova_, krow, ोहर_,
  { {0x61200047, 0x291c0209, 0x3d941281, 0x00000000}},  // [3450] tölt, kova_, митр,
  { {0x7ae90292, 0x79820036, 0x613218f9, 0x00000000}},  //   _slet, drow, gæld,
  { {0xf09200b6, 0xb5fd037e, 0x7ae9040d, 0x00000000}},  //   _אני_, lašt, _plet,
  { {0x79820036, 0xd90f00a1, 0x53380049, 0x00000000}},  //   frow, ھیا_, ַנגן_,
  { {0x79820036, 0x3ea918fa, 0x21210022, 0x00000000}},  //   grow, meat_, _kkhh_,
  { {0xe8f801ff, 0x3ea918fb, 0xf5480011, 0x00000000}},  //   олі_, leat_, _cụm_,
  { {0xf7710025, 0x98a20152, 0x7ae9002b, 0x00000000}},  //   ءات_, хище, _tlet,
  { {0x7afb0c2b, 0xdce40036, 0x224918fc, 0x00000000}},  //   _umut, dsię, _ngak_,
  { {0x291c0091, 0xdce40036, 0x79820133, 0x00000000}},  //   bova_, esię, crow,
  { {0x2249027e, 0xceb4006b, 0x291c0142, 0x00000000}},  //   _agak_, llət_, cova_,
  { {0x644f0046, 0x1425007e, 0x3ea90052, 0x00000000}},  //   ścio, ядом, keat_,
  { {0xe29a0ae0, 0x39450190, 0x00000000, 0x00000000}},  //   щам_, _hils_,   ,
  { {0x21330082, 0x3ea90052, 0x00000000, 0x00000000}},  //   _bhxh_, deat_,   ,
  { {0xd479007b, 0x55ba009b, 0xa7fc01df, 0x00000000}},  //   _האַל, _למנו, _adıy,
  { {0xb5fd00d0, 0x442005b8, 0x394501b8, 0x00000000}},  //   rašu, _цi_, _mils_,
  { {0xc7b2007b, 0x200518fd, 0x394d01d6, 0x00000000}},  //   עבן_, úlia_, _oues_,
  { {0x394d009d, 0x25ad18fe, 0xada30143, 0x00000000}},  // [3460] _nues_, nwel_, натл,
  { {0x394500f8, 0x6d23012b, 0xdb1c00f4, 0x00000000}},  //   _nils_, едуз, _irré,
  { {0x291c11e4, 0x61320018, 0x7ac6005e, 0x00000000}},  //   vova_, ræld, зсле,
  { {0x79820036, 0x291c01aa, 0xec130014, 0x00000000}},  //   trow, wova_, روند,
  { {0x394d18ff, 0x291c0091, 0x3f981900, 0x00000000}},  //   _cues_, tova_, ltru_,
  { {0x394d04bd, 0xdb07000c, 0xd90d0167, 0x00000000}},  //   _dues_, _brjó, لیق_,
  { {0x3f981305, 0x291c1901, 0x7c2e0089, 0x00000000}},  //   ntru_, rova_, _uzbr,
  { {0x291c008d, 0x79820036, 0x7d1e0039, 0x00000000}},  //   sova_, prow, lops,
  { {0x394500f4, 0x291c0091, 0x394d0ec1, 0x00000000}},  //   _fils_, pova_, _gues_,
  { {0x7d1e1902, 0x39451903, 0x937800e2, 0x00000000}},  //   nops, _gils_, обот_,
  { {0x7ce00073, 0xdced01d5, 0xdb1c01e6, 0x00000000}},  //   _förv, ntaġ, _arré,
  { {0x69c01282, 0xdb0e00d4, 0x52a70025, 0x00000000}},  //   _krme, _arbú, أصدق,
  { {0xe298008b, 0x3ea91904, 0x37ae0044, 0x00000000}},  //   чаў_, veat_, _কপির,
  { {0xb5fd04a5, 0xa63b00b6, 0x00000000, 0x00000000}},  //   rašt, _הגדר,   ,
  { {0x7d1e1043, 0x37de0044, 0x63530035, 0x00000000}},  //   dops, _ভেতর, _tăna,
  { {0xb5fd04eb, 0x00000000, 0x00000000, 0x00000000}},  //   pašt,   ,   ,
  { {0xceb4005f, 0x634800b9, 0x3ea90585, 0x00000000}},  // [3470] vlət_, _věnu, reat_,
  { {0x394d009d, 0x61ef005a, 0xe9ff0082, 0x00000000}},  //   _rues_, ınlı, _ngạn_,
  { {0x3ea90498, 0x9be4007e, 0xcf9b00e2, 0x00000000}},  //   peat_, ніцк, _ујп_,
  { {0x394d0219, 0x39450129, 0x628f1905, 0x00000000}},  //   _pues_, _sils_, ngco,
  { {0x27211906, 0x394d0f57, 0x39450089, 0x00000000}},  //   zóns_, _ques_, _pils_,
  { {0x475901e0, 0x394d00f4, 0x6d5d022b, 0x00000000}},  //   ория_, _vues_, _itsa,
  { {0xceb4005f, 0x2a6d0004, 0x69c01907, 0x00000000}},  //   mlər_, _teeb_, _erme,
  { {0xceb4005f, 0x6d4704cb, 0x64580030, 0x00000000}},  //   llər_, _hija, _afvi,
  { {0x6d470f59, 0x6d4f000d, 0x69c001ee, 0x00000000}},  //   _kija, _juca, _grme,
  { {0x7ce01908, 0xceb4005f, 0x6f0d010f, 0x00000000}},  //   _föru, nlər_, hnac,
  { {0x7ce00047, 0x6d470a6e, 0x3f98002b, 0x00000000}},  //   _törv, _mija, xtru_,
  { {0x6d5d1909, 0xdced0279, 0x672201ee, 0x00000000}},  //   _otsa, yrağ, _gkoj,
  { {0xceb4005f, 0x6f0d09c6, 0x6d4f00f6, 0x00000000}},  //   klər_, dnac, _nuca,
  { {0x6d47190a, 0x6729190b, 0x7e7d1621, 0x00000000}},  //   _nija, llej, _adsp,
  { {0x6d5d0a5c, 0xe29a0256, 0xceb4006b, 0x00000000}},  //   _atsa, _дай_, dlər_,
  { {0x6d4f001a, 0x6f0d120c, 0x6d47190c, 0x00000000}},  //   _buca, gnac, _aija,
  { {0x44270bc4, 0x6d4701a3, 0xceb4006b, 0x00000000}},  // [3480] _hyn_, _bija, flər_,
  { {0x3e6c001d, 0x6e2b001f, 0x6d4f0207, 0x00000000}},  //   ết_, ügba, _duca,
  { {0x7d1e0514, 0x6d47020c, 0x6d4f00d6, 0x00000000}},  //   rops, _dija, _euca,
  { {0x673b0046, 0x7d1e0190, 0xdced014a, 0x00000000}},  //   jmuj, sops, prağ,
  { {0xceb4005f, 0x44270007, 0x6d470211, 0x00000000}},  //   blər_, _lyn_, _fija,
  { {0x69c0016c, 0x765901d6, 0x644f0036, 0x00000000}},  //   _vrme, _afwy, ścij,
  { {0x67290211, 0x62880006, 0x7ce0014a, 0x00000000}},  //   flej, ėdoj, _dört,
  { {0xd6d00054, 0x7ce0000c, 0x6d4f008e, 0x00000000}},  //   اقة_, _vöru, _yuca,
  { {0x7ce00039, 0x69c0001a, 0x2cb80313, 0x00000000}},  //   _fört, _urme, _kard_,
  { {0x6f0d0046, 0x442700f8, 0x764b190d, 0x00000000}},  //   znac, _byn_, _eggy,
  { {0x4427018e, 0x7ce00210, 0x6ef10030, 0x00000000}},  //   _cyn_, _hörs, _håbe,
  { {0x44270016, 0xceb4006b, 0x7cf20030, 0x00000000}},  //   _dyn_, zlər_, _færg,
  { {0xceb4006b, 0x7e6f00f6, 0x290e0026, 0x00000000}},  //   ylər_, _recp, onfa_,
  { {0x4427190e, 0x7ce006d3, 0x6d4f0213, 0x00000000}},  //   _fyn_, _mörs, _ruca,
  { {0x44270016, 0xe8df0011, 0xceb4006b, 0x00000000}},  //   _gyn_, _cuộn_, vlər_,
  { {0x6d47021e, 0x6720022e, 0x2cb800c7, 0x00000000}},  //   _sija, nomj, _aard_,
  { {0x6f0d0919, 0xceb4005f, 0x6d470213, 0x00000000}},  // [3490] rnac, tlər_, _pija,
  { {0x6f0d018e, 0x2cb8190f, 0x798b0061, 0x00000000}},  //   snac, _card_, vugw,
  { {0xceb40163, 0x6d47000b, 0x673b0036, 0x00000000}},  //   rlər_, _vija, ymuj,
  { {0x7ce01910, 0x6d470093, 0xceb4006b, 0x00000000}},  //   _börs, _wija, slər_,
  { {0x672012d5, 0x6d47003b, 0x2cb80066, 0x00000000}},  //   domj, _tija, _fard_,
  { {0x2cb81911, 0x798b1912, 0xa7b501fc, 0x00000000}},  //   _gard_, rugw, есиј,
  { {0x6729006c, 0xddc60089, 0x3eb900b5, 0x00000000}},  //   tlej, _iekš, _kast_,
  { {0x7ce01913, 0xe9ff0082, 0x2cb80087, 0x00000000}},  //   _förs, _ngần_, _zard_,
  { {0x7ce01914, 0x44270292, 0x7cf20030, 0x00000000}},  //   _tört, _syn_, _færd,
  { {0x3eb90038, 0x67bb01d8, 0x44270007, 0x00000000}},  //   _last_, _واضح_, _pyn_,
  { {0xc20900b6, 0x67290030, 0x232a0216, 0x00000000}},  //   _פה_, plej, зони_,
  { {0x7af90279, 0xbebb0065, 0x3eb915c7, 0x00000000}},  //   _çatı, _skën, _nast_,
  { {0x44271915, 0x35a508f3, 0x7cf2043e, 0x00000000}},  //   _wyn_, _чалг, _hære,
  { {0x7cf20698, 0x44271916, 0x3eb900d9, 0x00000000}},  //   _kære, _tyn_, _aast_,
  { {0x6ee3006c, 0x8fa3189f, 0x7cf200ea, 0x00000000}},  //   _lõbu, ларе, _jære,
  { {0xe1ff027b, 0x6eea0161, 0x3eb900ab, 0x00000000}},  //   mbón_, _výbo, _cast_,
  { {0x7cf20637, 0x62960009, 0x72060014, 0x00000000}},  // [34a0] _lære, _icyo, _سودم,
  { {0x3eb900ab, 0xdd8f0188, 0xb19b0049, 0x00000000}},  //   _east_, صوم_, _צייכ,
  { {0xe29f000c, 0x61e61917, 0x12d20044, 0x00000000}},  //   liða_, lykl, াসীদ,
  { {0x3eb905c6, 0x395f1824, 0xd00f00a1, 0x00000000}},  //   _gast_, _btus_, _چلی_,
  { {0x2cb81918, 0xe89417fa, 0x7ce00039, 0x00000000}},  //   _tard_, валь, _dörr,
  { {0x7cf20737, 0x6ef10030, 0x7e761919, 0x00000000}},  //   _bære, _våbe, layp,
  { {0x09d80055, 0x7ce00073, 0x7cf20030, 0x00000000}},  //   _দেখা, _förr, _værd,
  { {0x8f9b061e, 0x61e6010a, 0x26dd023a, 0x00000000}},  //   ליצי, kykl, _cowo_,
  { {0x60de0007, 0xd2510014, 0x550603e0, 0x00000000}},  //   _oopm, یند_, ечна,
  { {0xdb15010f, 0x644d0279, 0x61e60006, 0x00000000}},  //   _erzä, _şair, dykl,
  { {0xccf300b6, 0x6720191a, 0x7cf20146, 0x00000000}},  //   רכת_, pomj, _gære,
  { {0xf1bf0f6c, 0x78ba0010, 0x00000000, 0x00000000}},  //   tvá_, _hatv,   ,
  { {0x3eb9008d, 0x250b00a1, 0x78ba01d6, 0x00000000}},  //   _rast_, _کرنی_, _katv,
  { {0x31350603, 0x3eb90007, 0x75210129, 0x00000000}},  //   тегр, _sast_, colz,
  { {0x3eb905d0, 0x3ea0191b, 0x78ba03fa, 0x00000000}},  //   _past_, ffit_, _matv,
  { {0x78ba191c, 0x7cf2191d, 0x00000000, 0x00000000}},  //   _latv, _nærb,   ,
  { {0x3eb900b5, 0x7d25026c, 0x61e60387, 0x00000000}},  // [34b0] _vast_, نفرن, cykl,
  { {0x3eb900d9, 0x2ee9191e, 0xdbd1010e, 0x00000000}},  //   _wast_, skaf_, püüg,
  { {0x7cf20637, 0x3eb905d5, 0x00000000, 0x00000000}},  //   _bærb, _tast_,   ,
  { {0xc01c0011, 0x9980014a, 0x0f7a01ce, 0x00000000}},  //   _lược_, çiş_, _קארב,
  { {0x442b0011, 0x7cf2068f, 0x00000000, 0x00000000}},  //   ́c_, _sære,   ,
  { {0x78ba00e5, 0x3158009b, 0x09e2030d, 0x00000000}},  //   _catv, עיון_, рошн,
  { {0x8aa7008b, 0x61e603de, 0xac180088, 0x00000000}},  //   _прад, zykl, _зору_,
  { {0x7cf2068f, 0x78a40091, 0x645a001a, 0x00000000}},  //   _være, điva, ecti,
  { {0x7ce0191f, 0x940b006b, 0x23600091, 0x00000000}},  //   _körp, əcə_, _čija_,
  { {0x78ba0ff2, 0x61e61920, 0x25bf0007, 0x00000000}},  //   _gatv, vykl, rvul_,
  { {0xc6e701fb, 0x6abb001f, 0xc01c0011, 0x00000000}},  //   _підп, _kauf, _dược_,
  { {0x29070027, 0x78ba1434, 0xe1ff12e1, 0x00000000}},  //   lina_, _zatv, rbón_,
  { {0x95e900a1, 0x399b0181, 0x98be0035, 0x00000000}},  //   _تباہ_, nês_, _uită_,
  { {0x6abb001f, 0x2d890007, 0xe1ff0010, 0x00000000}},  //   _lauf, drae_, mból_,
  { {0x61e6010a, 0x657b000c, 0x00000000, 0x00000000}},  //   sykl, lsuh,   ,
  { {0x29071921, 0x2416009b, 0xe1f20355, 0x00000000}},  //   hina_, _שחקן_, _نسخ_,
  { {0x2907002d, 0x60de0061, 0x7e760146, 0x00000000}},  // [34c0] kina_, _topm, rayp,
  { {0x29070a13, 0xee370407, 0x98be0006, 0x00000000}},  //   jina_, тну_, _kitą_,
  { {0x29070119, 0x644f0036, 0x7e760058, 0x00000000}},  //   dina_, ściw, payp,
  { {0x2d890181, 0xe1ff0010, 0xbad5007e, 0x00000000}},  //   brae_, kból_, лічы,
  { {0x78ba030b, 0x7ce00039, 0xc333034e, 0x00000000}},  //   _patv, _förp, בוא_,
  { {0x290702ae, 0x97a6003b, 0xc8780095, 0x00000000}},  //   gina_, врил, _boğa_,
  { {0x8b26007e, 0x27e700ea, 0x00000000, 0x00000000}},  //   _адве, gynn_,   ,
  { {0x399b0181, 0x8c1b0104, 0xf5480082, 0x00000000}},  //   bês_, _חולי, _lụt_,
  { {0x81e70055, 0x399b0181, 0x78ba0f22, 0x00000000}},  //   _যেন_, cês_, _tatv,
  { {0x645a0050, 0x6abb0036, 0x00000000, 0x00000000}},  //   ucti, _zauf,   ,
  { {0xd25100a2, 0x69c20007, 0x645a0133, 0x00000000}},  //   ینگ_, lvoe, rcti,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x394c00ab, 0x69c20250, 0x7ae300c4, 0x00000000}},  //   _kids_, nvoe, ênti,
  { {0x5577007b, 0x2d890007, 0x03c601ee, 0x00000000}},  //   _יעדן_, vrae_, _асим,
  { {0xcebb003b, 0x13b30379, 0x00000000, 0x00000000}},  //   мља_, _نصيح,   ,
  { {0x29071922, 0x2d890e32, 0x00000000, 0x00000000}},  //   zina_, trae_,   ,
  { {0x6abb1642, 0x69c200bb, 0x00000000, 0x00000000}},  // [34d0] _rauf, jvoe,   ,
  { {0x2907081d, 0xcc0b03ec, 0xb5df0044, 0x00000000}},  //   xina_, وزان_, _বেঁচ,
  { {0x290700ee, 0x99d40014, 0xfd44007e, 0x00000000}},  //   vina_, یتها, рэтн,
  { {0x7ae01923, 0x29071156, 0xbcfb0051, 0x00000000}},  //   _comt, wina_, _dtéa,
  { {0xdcef005f, 0x29070490, 0x69c207a5, 0x00000000}},  //   şdır, tina_, gvoe,
  { {0xdb1c00f6, 0x61320190, 0x00000000, 0x00000000}},  //   _errà, jæll,   ,
  { {0x6abb0475, 0x3f91005a, 0x273a0023, 0x00000000}},  //   _tauf, nuzu_, kënd_,
  { {0x657b0058, 0x7bc70066, 0xe1ff0010, 0x00000000}},  //   tsuh, _irju, tból_,
  { {0x29070b41, 0xfec50044, 0x61320030, 0x00000000}},  //   pina_, _একাধ, fæll,
  { {0x394c01b5, 0x7cf2000c, 0x657b1924, 0x00000000}},  //   _gids_, _kæra, rsuh,
  { {0x657b00b0, 0xe1ff0010, 0x3f9100e7, 0x00000000}},  //   ssuh, sból_, juzu_,
  { {0x68e10018, 0x65620065, 0x3f911925, 0x00000000}},  //   _hold, _ftoh, duzu_,
  { {0x68e10d44, 0x26cf01a2, 0x7cf20056, 0x00000000}},  //   _kold, _ingo_, _læra,
  { {0x29350049, 0xd5ac00a1, 0x3f911926, 0x00000000}},  //   טאָן_, _کہی_, fuzu_,
  { {0x68e1000d, 0x442400e9, 0x3f91002d, 0x00000000}},  //   _mold, _پروف, guzu_,
  { {0x6ee30004, 0x2b9c0802, 0x52761927, 0x00000000}},  //   _sõbr, víc_, _суку,
  { {0x62840211, 0x7bc7008a, 0x7ae00035, 0x00000000}},  // [34e0] _idio, _arju, _romt,
  { {0x7ae01928, 0x00000000, 0x00000000, 0x00000000}},  //   _somt,   ,   ,
  { {0xb09b0476, 0x409b0049, 0xa2d80164, 0x00000000}},  //   _אייר, _אביס, याप्,
  { {0x69c20250, 0x3cf00061, 0xdb0e00f6, 0x00000000}},  //   tvoe, _इतके_, _arbò,
  { {0x68e10e8f, 0x2b9c01ca, 0x187405b8, 0x00000000}},  //   _bold, síc_, агля,
  { {0x69c20250, 0x2d920dfc, 0x68e1051b, 0x00000000}},  //   rvoe, muye_, _cold,
  { {0x7ae0004f, 0x68e1049d, 0x62840555, 0x00000000}},  //   _tomt, _dold, _odio,
  { {0x6d4e1929, 0x473400e2, 0x00000000, 0x00000000}},  //   _hiba, јнис,   ,
  { {0x6d4e000b, 0x2905192a, 0x58960014, 0x00000000}},  //   _kiba, _fmla_, _مجاز,
  { {0x68e1192b, 0x6284008e, 0x6d4e0066, 0x00000000}},  //   _gold, _adio, _jiba,
  { {0x2d920009, 0xc6250044, 0x998d012d, 0x00000000}},  //   huye_, মেলা_, _izeš_,
  { {0x6d4e011c, 0x973c016e, 0x68e1192c, 0x00000000}},  //   _liba, _opći, _zold,
  { {0x68e10279, 0x6284018e, 0x870600a1, 0x00000000}},  //   _yold, _ddio, _لڑکے_,
  { {0x6d4e0f36, 0x3f91002d, 0xe104007e, 0x00000000}},  //   _niba, tuzu_, бясп,
  { {0xe44f0380, 0x7c2e192d, 0x00000000, 0x00000000}},  //   _عضو_, _nybr,   ,
  { {0x2d920045, 0xaf3704b1, 0x6d4e192e, 0x00000000}},  //   fuye_, ارست, _aiba,
  { {0x6d4e192f, 0x2d9201dd, 0x5c7500e3, 0x00000000}},  // [34f0] _biba, guye_, илат,
  { {0x2d8705e8, 0x7c2e1930, 0x2b4d07c0, 0x00000000}},  //   čne_, _bybr, _siec_,
  { {0x6d4e0149, 0xaa55003b, 0x8f351867, 0x00000000}},  //   _diba, авеш, _венц,
  { {0x6d4e002d, 0x2d921931, 0x00000000, 0x00000000}},  //   _eiba, buye_,   ,
  { {0x68e1023a, 0x442e037d, 0x2b4d0011, 0x00000000}},  //   _pold, _lyf_, _viec_,
  { {0x6d4e0059, 0x2b4d0036, 0x7c2e00d9, 0x00000000}},  //   _giba, _wiec_, _fybr,
  { {0x68e11932, 0x46f50aed, 0xf6510025, 0x00000000}},  //   _vold, ичит, يئة_,
  { {0x6d4e01c5, 0x68e100d9, 0xe1ff000c, 0x00000000}},  //   _ziba, _wold, gbók_,
  { {0x6d4e0009, 0xe5760783, 0x195900a5, 0x00000000}},  //   _yiba, азы_, _разы_,
  { {0xb3a9011f, 0x6d4e004a, 0x00000000, 0x00000000}},  //   _çıkı, _xiba,   ,
  { {0xb4e5001c, 0x03a50a27, 0x2d920009, 0x00000000}},  //   _नवी_, шино, zuye_,
  { {0xb6c9026c, 0x69c917c6, 0x2d920045, 0x00000000}},  //   _جائے_, _kree, yuye_,
  { {0x95670ae0, 0x7f57009d, 0x00000000, 0x00000000}},  //   _съед, _auxq,   ,
  { {0x2d920009, 0x65690190, 0x672404eb, 0x00000000}},  //   vuye_, mpeh, čije,
  { {0x6d4e1933, 0x6ef800fa, 0x65691934, 0x00000000}},  //   _riba, _líbe, lpeh,
  { {0xe8df001d, 0x539a00b6, 0x6d4e0058, 0x00000000}},  //   _muốn_, _סיפו, _siba,
  { {0xed5701b3, 0xd1320025, 0x98a5000a, 0x00000000}},  // [3500] иот_, _ومع_, _aklč_,
  { {0x2d921935, 0x6aa904b3, 0x6ef10146, 0x00000000}},  //   ruye_, _abef, _fåbo,
  { {0x1d1901fb, 0xeb9a10a9, 0x6d4e0020, 0x00000000}},  //   ують_, тие_, _viba,
  { {0x7c2e004f, 0xfaa606b6, 0x69c91936, 0x00000000}},  //   _vybr, радо, _bree,
  { {0x7c2e0046, 0x6d4e0487, 0x69c91937, 0x00000000}},  //   _wybr, _tiba, _cree,
  { {0x6f161191, 0x2d82016c, 0x2d801938, 0x00000000}},  //   lnyc, _ivke_, msie_,
  { {0xe8df0011, 0x6f160036, 0x1d071939, 0x00000000}},  //   _cuốn_, onyc, _тери_,
  { {0x6f16193a, 0x2d800022, 0x6b830035, 0x00000000}},  //   nnyc, osie_, ânge,
  { {0x2d800343, 0x69c90038, 0x3f5c0082, 0x00000000}},  //   nsie_, _gree, _líu_,
  { {0x44f40072, 0x2d80193b, 0x2b580087, 0x00000000}},  //   спос, isie_, _kurc_,
  { {0x3f5c193c, 0x443801c4, 0x00000000, 0x00000000}},  //   _níu_, år_,   ,
  { {0xe5a6017f, 0x2d80193d, 0x6f160046, 0x00000000}},  //   _види, ksie_, jnyc,
  { {0x6f160871, 0x442e0016, 0xfe7f009d, 0x00000000}},  //   dnyc, _wyf_, _loïc_,
  { {0x09c30044, 0x969200a1, 0xddcf0035, 0x00000000}},  //   ্নচা, _ایکش, _lecţ,
  { {0x75280036, 0x403515c4, 0x63530035, 0x00000000}},  //   modz, севс, _bănu,
  { {0x27210027, 0x7528193e, 0x00000000, 0x00000000}},  //   fóny_, lodz,   ,
  { {0x7cf20190, 0x7f4f01c3, 0x635300e5, 0x00000000}},  // [3510] _værn, _vicq, _dănu,
  { {0xeb1f0201, 0x6d8a00a1, 0x6aa90026, 0x00000000}},  //   यक्त_, املہ_, _sbef,
  { {0x6f160832, 0x2d80193f, 0x00000000, 0x00000000}},  //   bnyc, asie_,   ,
  { {0x69c90663, 0x75280036, 0x2b580026, 0x00000000}},  //   _pree, hodz, _durc_,
  { {0x7cf2158f, 0xe1ff076b, 0x7f3a009b, 0x00000000}},  //   _kærl, nzó_, _תערו,
  { {0x6f0d0dc6, 0x69c906b2, 0xb4e50061, 0x00000000}},  //   liac, _vree, _नवे_,
  { {0x69c901bb, 0x3f5c0082, 0x00000000, 0x00000000}},  //   _wree, _xíu_,   ,
  { {0x6f0d0871, 0x6d45002a, 0x660d000c, 0x00000000}},  //   niac, lmha, _þakk,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d45002a, 0x6f1605fd, 0x6f0d0197, 0x00000000}},  //   nmha, znyc, hiac,
  { {0x65690de5, 0x6f0d1940, 0x272104bb, 0x00000000}},  //   speh, kiac, zóny_,
  { {0x8a14026c, 0x6132000c, 0x63a10009, 0x00000000}},  //   _اظہا, mæli, rtln,
  { {0x6f0d0142, 0xe297007c, 0x6f160142, 0x00000000}},  //   diac, щая_, vnyc,
  { {0xd46601fb, 0x6f160036, 0x61460893, 0x00000000}},  //   _лише_, wnyc, сега,
  { {0x33951941, 0x6f160871, 0x438501b7, 0x00000000}},  //   _العز, tnyc, _البق,
  { {0x09bd08b7, 0x2d800007, 0x83640b03, 0x00000000}},  //   _আপনা, tsie_, _بدول,
  { {0x8297009b, 0x6f1605fd, 0x7f440005, 0x00000000}},  // [3520] _הדפס_, rnyc, rmiq,
  { {0x2d8002ae, 0xa25b0181, 0xddcf001a, 0x00000000}},  //   rsie_, ndôn, _secţ,
  { {0x2d80049b, 0xb5fd010a, 0xf53601ce, 0x00000000}},  //   ssie_, rašy, צטער_,
  { {0x2d801942, 0x6d450051, 0xaf3602fd, 0x00000000}},  //   psie_, amha, _درخت,
  { {0x08540088, 0x98a5002b, 0x00000000, 0x00000000}},  //   овлю, _silġ_,   ,
  { {0x6d450051, 0x2b580bdb, 0x00000000, 0x00000000}},  //   cmha, _turc_,   ,
  { {0x37060242, 0x00000000, 0x00000000, 0x00000000}},  //   йчив,   ,   ,
  { {0xfaa3026b, 0xe8df001d, 0x75280036, 0x00000000}},  //   _насо, _buồn_, wodz,
  { {0x186a0088, 0x00000000, 0x00000000, 0x00000000}},  //   _бази_,   ,   ,
  { {0x6f0d1943, 0xe29f000c, 0x00000000, 0x00000000}},  //   ziac, miði_,   ,
  { {0x63a5001f, 0x75280871, 0x7cf201e3, 0x00000000}},  //   _ähnl, rodz, _nærm,
  { {0x083b0049, 0x7cf202cc, 0x290e00e7, 0x00000000}},  //   _געבל, _særl, lifa_,
  { {0x79820046, 0x26c30089, 0x6f0d1944, 0x00000000}},  //   nsow, ējot_, viac,
  { {0x290e0032, 0xe3b20025, 0xe1ff1819, 0x00000000}},  //   nifa_, _فرع_, rzó_,
  { {0x436700ed, 0x6f0d0142, 0x00000000, 0x00000000}},  //   _лајн_, tiac,   ,
  { {0x877b00a3, 0x79820036, 0x8c000044, 0x00000000}},  //   טאלי, ksow, ্থান_,
  { {0x6f0d05e1, 0x28b903d7, 0x00000000, 0x00000000}},  // [3530] riac, _इसलि,   ,
  { {0x6f0d0027, 0x6d451945, 0x463b0049, 0x00000000}},  //   siac, umha, רעמע,
  { {0x6d451946, 0x25a40020, 0x290e0066, 0x00000000}},  //   rmha, html_, difa_,
  { {0xf2d40049, 0x539b009b, 0x5a350216, 0x00000000}},  //   ּעס_, ריאו, онет,
  { {0xb2bc0049, 0x290e0066, 0x6f1d00d9, 0x00000000}},  //   טמאר, fifa_, _ijsc,
  { {0x0b7b083e, 0x00000000, 0x00000000, 0x00000000}},  //   _مصرع_,   ,   ,
  { {0x0a6b06e3, 0xf7451947, 0xf772009e, 0x00000000}},  //   _брзи_, оеко, واٹ_,
  { {0x0565012b, 0x3b6402dc, 0x3ea902d4, 0x00000000}},  //   овин, _хърв, nfat_,
  { {0xceb400a0, 0x3ea90016, 0xa8a7004c, 0x00000000}},  //   ליק_, ifat_, _грек,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x28150054, 0x00000000, 0x00000000, 0x00000000}},  //   _بواس,   ,   ,
  { {0x4acf02fb, 0xe29a1948, 0x26c30089, 0x00000000}},  //   _सोमव, шам_, ējos_,
  { {0x9f4c00b9, 0x7cf200ea, 0x00000000, 0x00000000}},  //   ádí_, _særm,   ,
  { {0x2d4d0521, 0x6eea1949, 0x443c0087, 0x00000000}},  //   _džek_, _nýbr, _fzv_,
  { {0x3ea90c43, 0xc4470014, 0x7ce00010, 0x00000000}},  //   ffat_, _دیدن_, _törz,
  { {0x7cf200ea, 0x9f590010, 0x00000000, 0x00000000}},  //   _værm, ázás_,   ,
  { {0x82fa01ef, 0xec7a00e3, 0x61ef028a, 0x00000000}},  // [3540] _مرکز_, ипа_, cycl,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdee601fc, 0x60d70049, 0x00000000, 0x00000000}},  //   _дони, _וויא_,   ,
  { {0x3f98194a, 0x49ca05b5, 0x261a0082, 0x00000000}},  //   muru_, илен_, ừoi_,
  { {0x3f98008a, 0x290e014a, 0x3a200095, 0x00000000}},  //   luru_, tifa_, çip_,
  { {0xf77200b8, 0x7cf20018, 0xe29f000c, 0x00000000}},  //   واع_, _mærk, riði_,
  { {0x290e194b, 0x31a40010, 0x7cf20190, 0x00000000}},  //   rifa_, höz_, _lærk,
  { {0x7e640682, 0x27e00091, 0x290e00e7, 0x00000000}},  //   ncip, ćin_, sifa_,
  { {0x3f980020, 0x26c20027, 0x2369183b, 0x00000000}},  //   huru_, ľko_, _čaja_,
  { {0x69c00047, 0x3f98194c, 0x26c207ac, 0x00000000}},  //   _isme, kuru_, žko_,
  { {0x3f9816b1, 0x4acf0061, 0x316901ee, 0x00000000}},  //   juru_, _सोडव, _staz_,
  { {0x46d1013d, 0x68e8005b, 0x290c016c, 0x00000000}},  //   _दोपह, _hodd, _hmda_,
  { {0x68e801e5, 0x00000000, 0x00000000, 0x00000000}},  //   _kodd,   ,   ,
  { {0x443c01ca, 0x3f9816fa, 0xf99300b3, 0x00000000}},  //   _tzv_, furu_, ורש_,
  { {0x3f98002d, 0x290c0058, 0x6f1d0022, 0x00000000}},  //   guru_, _mmda_, _pjsc,
  { {0x69c0003b, 0x68e8101b, 0x37bc0044, 0x00000000}},  //   _osme, _lodd, _অপার,
  { {0xa2d80201, 0x7cf2000c, 0x3ea9194d, 0x00000000}},  // [3550] यार्, _gærk, rfat_,
  { {0x3f98022b, 0x68e80016, 0x3ea90145, 0x00000000}},  //   buru_, _nodd, sfat_,
  { {0x69c0010a, 0xa3cd007d, 0x3f98194e, 0x00000000}},  //   _asme, रिय_, curu_,
  { {0xd7b40061, 0x60c500b0, 0x68fa194f, 0x00000000}},  //   ंबईच, _hahm, _altd,
  { {0x7e7d001e, 0x68e81950, 0x09e10044, 0x00000000}},  //   _iesp, _bodd, _মেজা,
  { {0x7e7d00d4, 0x2c4600a1, 0x7cf2068f, 0x00000000}},  //   _hesp, _کیمپ_, _nærh,
  { {0x69c00129, 0x60c503fe, 0x4758008b, 0x00000000}},  //   _esme, _mahm, орыя_,
  { {0x6d5d000b, 0x7e7d1951, 0x1ab40088, 0x00000000}},  //   _kusa, _jesp, _обся,
  { {0x6d550020, 0x68e8005b, 0x7e7d0032, 0x00000000}},  //   _kiza, _fodd, _mesp,
  { {0x7afb009f, 0x7e7d0263, 0x3f98014a, 0x00000000}},  //   _hlut, _lesp, yuru_,
  { {0x6d55014a, 0x7afb0a74, 0x7ae900b0, 0x00000000}},  //   _miza, _klut, _koet,
  { {0xf7700123, 0x7ae90066, 0x6d5d00c4, 0x00000000}},  //   _شام_, _joet, _ousa,
  { {0x7ae902ae, 0x6d5d023a, 0x7cf3014a, 0x00000000}},  //   _moet, _nusa, _kırı,
  { {0x3f980089, 0x6d55006b, 0x7cf20018, 0x00000000}},  //   turu_, _niza, _værk,
  { {0x6d5d1952, 0x7afb0052, 0x32021953, 0x00000000}},  //   _ausa, _olut, szky_,
  { {0x6d5d0390, 0xdee30679, 0x7e7d0851, 0x00000000}},  //   _busa, носи, _cesp,
  { {0x7e7d1954, 0x60c504be, 0x6d5d03c5, 0x00000000}},  // [3560] _desp, _fahm, _cusa,
  { {0xdd8f0647, 0x6d5d0b30, 0x7afb0093, 0x00000000}},  //   اول_, _dusa, _alut,
  { {0x46bd0183, 0x68e80016, 0x7ae912ed, 0x00000000}},  //   ्याह, _rodd, _boet,
  { {0x7e7d1955, 0x7ae90007, 0x68e80282, 0x00000000}},  //   _gesp, _coet, _sodd,
  { {0x6d5d011c, 0x13b40044, 0x7cf21956, 0x00000000}},  //   _gusa, টিয়, _læri,
  { {0x6d55022b, 0x7e7d0046, 0x7afb1957, 0x00000000}},  //   _giza, _zesp, _elut,
  { {0x7afb000c, 0x6d5d001f, 0xf76f007a, 0x00000000}},  //   _flut, _zusa, هاي_,
  { {0x7ae901b6, 0x256001aa, 0x6d550a65, 0x00000000}},  //   _goet, _pòl_, _ziza,
  { {0x69c01958, 0x7cf3005d, 0x68e81959, 0x00000000}},  //   _usme, _fırı, _todd,
  { {0x7ae900b5, 0x76590016, 0x25600173, 0x00000000}},  //   _zoet, _egwy, _vòl_,
  { {0x60c5127d, 0x256001aa, 0xa29501e1, 0x00000000}},  //   _rahm, _wòl_, мані,
  { {0x883b009b, 0x6b650006, 0x00000000, 0x00000000}},  //   _פתאו, _jėga,   ,
  { {0x629d13ea, 0x60c50022, 0x236004eb, 0x00000000}},  //   rgso, _pahm, _čiju_,
  { {0x0cc70055, 0x7cf207a8, 0xdb0e0146, 0x00000000}},  //   _শক্ত, _færi, _esbø,
  { {0x6d5d0127, 0x443a001d, 0x22400a69, 0x00000000}},  //   _susa, _áp_, _ezik_,
  { {0x6d5d020c, 0x6d5501aa, 0x539b009b, 0x00000000}},  //   _pusa, _siza, _היהו,
  { {0x7e7d0129, 0x7ae90007, 0x6d55008e, 0x00000000}},  // [3570] _vesp, _roet, _piza,
  { {0x7afb05ad, 0x7ae9195a, 0x81fc009b, 0x00000000}},  //   _slut, _soet, _להחז,
  { {0xf09201f8, 0x7afb00f4, 0xfe7000a1, 0x00000000}},  //   _בני_, _plut, ئدہ_,
  { {0x6d55195b, 0xa3cd02fb, 0x6d5d154f, 0x00000000}},  //   _wiza, रित_, _tusa,
  { {0x7ae901b5, 0x6d5d195c, 0xdb05009d, 0x00000000}},  //   _voet, _uusa, nthé,
  { {0x78ad016c, 0x7cf3006b, 0xbcfb004a, 0x00000000}},  //   đavo, _qırı, _quéd,
  { {0x7ae9195d, 0x00000000, 0x00000000, 0x00000000}},  //   _toet,   ,   ,
  { {0x628d0051, 0x7afb0058, 0x8cdb013d, 0x00000000}},  //   _ndao, _ulut, नावो,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8389041f, 0x628d0035, 0x00000000, 0x00000000}},  //   обов_, _adao,   ,
  { {0xccf20097, 0x6ef804f6, 0x673a000c, 0x00000000}},  //   דכי_, _bíbl, ðbjö,
  { {0x395f006c, 0xe29f000c, 0xc878014a, 0x00000000}},  //   _kuus_, ggð_, _doğu_,
  { {0x64a5195e, 0xf5480082, 0xdb240068, 0x00000000}},  //   _жала, _lụy_, ésél,
  { {0x7cf20190, 0x395f195f, 0x00000000, 0x00000000}},  //   _hærv, _muus_,   ,
  { {0x2d8f008e, 0x8fa30088, 0x395f00d9, 0x00000000}},  //   ágen_, каре, _luus_,
  { {0x98bf002b, 0x6ef8004a, 0x00000000, 0x00000000}},  //   _ftuħ_, _víbo,   ,
  { {0x395f0343, 0x312601fc, 0xe1ff008e, 0x00000000}},  // [3580] _nuus_, _одиг, lcón_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe1ff0211, 0x00000000, 0x00000000, 0x00000000}},  //   ncón_,   ,   ,
  { {0x7cf2101b, 0x395f1960, 0x9411013f, 0x00000000}},  //   _nærv, _buus_, üzə_,
  { {0x387e01dc, 0x31600181, 0x7bda0cce, 0x00000000}},  //   _petr_, _juiz_, _štud,
  { {0x395f0146, 0x00000000, 0x00000000, 0x00000000}},  //   _duus_,   ,   ,
  { {0x31600181, 0xdca30404, 0xb906013d, 0x00000000}},  //   _luiz_, _шари, _बच_,
  { {0x3ea01961, 0x44200107, 0x8c4300ed, 0x00000000}},  //   ngit_, _ći_, _ресе,
  { {0xb8f40055, 0x395f00bb, 0xd5ba0088, 0x00000000}},  //   _হক_, _guus_, іси_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x38cb089d, 0x00000000, 0x00000000, 0x00000000}},  //   _باقی_,   ,   ,
  { {0x395f000a, 0x0cbb0164, 0x00000000, 0x00000000}},  //   _yuus_, _उस्म,   ,
  { {0xe7070167, 0x3ea00173, 0xbebb0023, 0x00000000}},  //   _تسلی, dgit_, _njëa,
  { {0x672d0825, 0xdb0507cb, 0x7cf2000c, 0x00000000}},  //   čaje, rthé, _kæru,
  { {0xd5c80011, 0xe1f90006, 0xdb05009d, 0x00000000}},  //   _hề_, šų_, sthé,
  { {0xd5c80011, 0x3ea0011c, 0xceb8003b, 0x00000000}},  //   _kề_, ggit_, мљу_,
  { {0xc05b01e1, 0x917a0082, 0xfe7f00f6, 0x00000000}},  // [3590] _мін_, _vật_, _veï_,
  { {0x2d9b004a, 0x3d940256, 0x00000000, 0x00000000}},  //   ruqe_, тифр,   ,
  { {0xd5c80011, 0x7e761962, 0x98a70089, 0x00000000}},  //   _lề_, bbyp, jonā_,
  { {0xbcfb12a3, 0x6ef101c4, 0x00000000, 0x00000000}},  //   _québ, _påbu,   ,
  { {0x18690175, 0xd5c80011, 0x38c40006, 0x00000000}},  //   пали_, _nề_, kūrė_,
  { {0x7f4d006b, 0x270c00b9, 0xf5480082, 0x00000000}},  //   lmaq, měny_, _tụy_,
  { {0x2d4d0521, 0x6c54007e, 0x38c4007f, 0x00000000}},  //   _džet_, _акру, dūrė_,
  { {0x7c22006b, 0xd5c80011, 0xa3cd007d, 0x00000000}},  //   ğort, _bề_, रिस_,
  { {0xc8ab005e, 0xe6190aef, 0x9419006b, 0x00000000}},  //   _мъже_, яди_, əsə_,
  { {0x31600919, 0x61320190, 0x6b650006, 0x00000000}},  //   _ruiz_, jælp, _jėgo,
  { {0x260f03d7, 0x00000000, 0x00000000, 0x00000000}},  //   _तेरी_,   ,   ,
  { {0xe1ff008e, 0x67220065, 0x2d8b0466, 0x00000000}},  //   rcón_, _gjoj, _ovce_,
  { {0x6d47021e, 0xe1ff06c2, 0x3afa0049, 0x00000000}},  //   _ohja, scón_, פּטע,
  { {0x64a51963, 0x673b0052, 0xdbd701b1, 0x00000000}},  //   _чака, lluj, _käär,
  { {0x6d4b0006, 0xdbd70961, 0x00000000, 0x00000000}},  //   įgal, _jäär,   ,
  { {0xdbd70368, 0x6443016e, 0x6d470310, 0x00000000}},  //   _määr, _izni, _ahja,
  { {0x62860ac2, 0xdce60089, 0x7e7601c3, 0x00000000}},  // [35a0] mako, _atkā, rbyp,
  { {0x62861964, 0x3e7e0082, 0x00000000, 0x00000000}},  //   lako, ắt_,   ,
  { {0xbcfb00c4, 0x6d470023, 0x00000000, 0x00000000}},  //   _suéc, _dhja,   ,
  { {0x44271965, 0xbcfb000c, 0x673b15ad, 0x00000000}},  //   _mxn_, _stét, jluj,
  { {0xddcd001a, 0x82770049, 0xceb4013f, 0x00000000}},  //   rbaţ, גענע_, nnəm_,
  { {0x6286006c, 0xb86603ec, 0x6f0400c4, 0x00000000}},  //   hako, راتو, lhic,
  { {0x8c430373, 0x62860059, 0xa09b00a0, 0x00000000}},  //   _бере, kako, ליסט,
  { {0xa6aa0025, 0xcc3b0049, 0xcf93009b, 0x00000000}},  //   سابق_, _זעלט, אטה_,
  { {0x62861957, 0xe56f0014, 0x7cf20146, 0x00000000}},  //   dako, یطی_, _fært,
  { {0xd5c800ad, 0xc42a109f, 0x81e60044, 0x00000000}},  //   _về_, зюме_, পনা_,
  { {0x5c970049, 0x44380374, 0x00000000, 0x00000000}},  //   עכטע_, ær_,   ,
  { {0x6aa20012, 0xd5c80082, 0xadc30082, 0x00000000}},  //   ngof, _tề_, _nhếc,
  { {0x6f040146, 0x7cfb00e5, 0x00000000, 0x00000000}},  //   dhic, _bîrl,   ,
  { {0xa3cd03d7, 0x248500d4, 0x7cf20030, 0x00000000}},  //   रिश_, calm_, _mærs,
  { {0x628615f9, 0x656207a4, 0x7761002b, 0x00000000}},  //   bako, _huoh, _xulx,
  { {0x643b009b, 0x9f60134d, 0x63b80082, 0x00000000}},  //   _מעונ, árás_, _ipvn,
  { {0x7f4d006b, 0x6ef80048, 0xdced12db, 0x00000000}},  // [35b0] rmaq, _míbh, spač,
  { {0xac2700d7, 0xbebb0023, 0x69c201c3, 0x00000000}},  //   нфек, _gjën, dwoe,
  { {0x2d8900f6, 0x69c201d6, 0x00000000, 0x00000000}},  //   ssae_, ewoe,   ,
  { {0x6f041966, 0x9e150099, 0x7cf206ec, 0x00000000}},  //   chic, _адмі, _sært,
  { {0xdb1c0010, 0x2d8b016c, 0xab640036, 0x00000000}},  //   _arró, _uvce_, ężar,
  { {0x62861204, 0xbcfb00d6, 0xdbd70933, 0x00000000}},  //   zako, _etér, _päär,
  { {0x62860232, 0x7cf20030, 0xdce40036, 0x00000000}},  //   yako, _vært, jpię,
  { {0x7cf2009f, 0xdbd708b2, 0x98b60089, 0x00000000}},  //   _færs, _väär, īgās_,
  { {0xe7f30201, 0x62861553, 0xdb1c008e, 0x00000000}},  //   _अथवा_, vako, _erró,
  { {0xd95500a6, 0xd90f00a1, 0x673b0059, 0x00000000}},  //   _شناخ, _ھیں_, sluj,
  { {0x6286022b, 0xdce40fcd, 0x00000000, 0x00000000}},  //   tako, spić,   ,
  { {0x64430428, 0x461200a2, 0x069b00a1, 0x00000000}},  //   _vzni, اویر, _رخصت_,
  { {0x6286022b, 0x248501d6, 0x9f45013e, 0x00000000}},  //   rako, palm_, álý_,
  { {0x6286010a, 0xf4870072, 0x25ad1967, 0x00000000}},  //   sako, _чудн, mtel_,
  { {0x6f040051, 0x25ad1968, 0x4cca0044, 0x00000000}},  //   thic, ltel_, রামু,
  { {0x7cf2000c, 0x0b130044, 0x8fa30143, 0x00000000}},  //   _nærr, িকুল_, јате,
  { {0x25ad014a, 0x7bd50180, 0xed5a00ed, 0x00000000}},  // [35c0] ntel_, _arzu, доа_,
  { {0xbcfb00f4, 0x5eaa0044, 0x7bd50036, 0x00000000}},  //   _stér, _চোখে, _brzu,
  { {0x6f0400ab, 0xe0fb0097, 0x6ef800b9, 0x00000000}},  //   phic, _חליל, _líbi,
  { {0x25ad0107, 0xe6bd0061, 0xdb1c00d4, 0x00000000}},  //   ktel_, ्योज, _arrò,
  { {0xe8941969, 0x62840181, 0xa967004c, 0x00000000}},  //   галь, _meio, вича_,
  { {0x6609001e, 0x26dd01aa, 0x69c201bb, 0x00000000}},  //   dzek, _anwo_, rwoe,
  { {0x38cb01ef, 0x7cf21956, 0x6d5c0058, 0x00000000}},  //   بانی_, _færr, _iira,
  { {0x6d5c011c, 0x3e860006, 0xdb1c00d4, 0x00000000}},  //   _hira, būtų_, _errò,
  { {0x6d5c011f, 0x6f03000d, 0x28e2006e, 0x00000000}},  //   _kira, _înce, पादि,
  { {0x6d5c0518, 0x628400c4, 0x7c3c0fdc, 0x00000000}},  //   _jira, _aeio, _kyrr,
  { {0x4c9b009b, 0xdc9b0097, 0x63aa0045, 0x00000000}},  //   וביו, וייל, _qqfn,
  { {0x6d5c04a0, 0x25ad0638, 0x656200b0, 0x00000000}},  //   _lira, btel_, _tuoh,
  { {0x62840032, 0x66090036, 0x25ad008e, 0x00000000}},  //   _deio, czek, ctel_,
  { {0xa2a50309, 0xe9ce007e, 0x00000000, 0x00000000}},  //   _काव्, скi_,   ,
  { {0x543301ef, 0xa43801fb, 0x6e950517, 0x00000000}},  //   _پرور, _язку_, ливу,
  { {0x2167007c, 0x6d5c0145, 0xbcfb008e, 0x00000000}},  //   _итог, _aira, _cuén,
  { {0x6d5c0284, 0x00000000, 0x00000000, 0x00000000}},  // [35d0] _bira,   ,   ,
  { {0x6d5c196a, 0x26cd196b, 0x00000000, 0x00000000}},  //   _cira, zdeo_,   ,
  { {0xa2d8001c, 0x6d5c020c, 0x7c3c0016, 0x00000000}},  //   याच्, _dira, _cyrr,
  { {0x443c196c, 0x6d5c010e, 0xd2590089, 0x00000000}},  //   _myv_, _eira, žņu_,
  { {0x78a3001c, 0x6d5c0039, 0x99150106, 0x00000000}},  //   tgnv, _fira, лькі,
  { {0x7c3c009f, 0x6d5c0207, 0x7e6d06b1, 0x00000000}},  //   _fyrr, _gira, lcap,
  { {0x6e3d018e, 0x7c3c018e, 0x98a70a55, 0x00000000}},  //   _hysb, _gyrr, joną_,
  { {0x66090756, 0x27e9037e, 0x25ad196d, 0x00000000}},  //   tzek, ćan_, ttel_,
  { {0x25ad0fe2, 0x26cd008e, 0xbebb0023, 0x00000000}},  //   utel_, rdeo_, _njëm,
  { {0x25ad0944, 0x6609196e, 0x69c9006c, 0x00000000}},  //   rtel_, rzek, _isee,
  { {0x25ad196f, 0xa2a501f5, 0x66090010, 0x00000000}},  //   stel_, _काश्, szek,
  { {0x91e60140, 0x1614013d, 0x00000000, 0x00000000}},  //   гоме, _तेवर_,   ,
  { {0xa2a502fb, 0xe4c80014, 0x00000000, 0x00000000}},  //   _कार्, ربین_,   ,
  { {0x361a007b, 0xa2d4007d, 0xf5920025, 0x00000000}},  //   _אונד, _बोर्, _الوج,
  { {0x6d5c1970, 0x6026005e, 0xaf220044, 0x00000000}},  //   _rira, удва, _ভীষণ_,
  { {0xbcfb00f4, 0x69c900f6, 0x7e6d192c, 0x00000000}},  //   _stép, _osee, gcap,
  { {0x7f5d00f4, 0x25691971, 0xd7f80011, 0x00000000}},  // [35e0] _disq, _júl_, _ngăn_,
  { {0x6d5c1972, 0x29070059, 0xee37003b, 0x00000000}},  //   _qira, jhna_, уну_,
  { {0x6d5c1973, 0x9f58008d, 0x69c90103, 0x00000000}},  //   _vira, nyrë_, _asee,
  { {0x6d5c10ed, 0x7e6d0197, 0x00000000, 0x00000000}},  //   _wira, ccap,   ,
  { {0x6d5c008d, 0x427b0049, 0x98a70a62, 0x00000000}},  //   _tira, גאנג, zoną_,
  { {0xbebb0065, 0x2907002b, 0x7c3c00ea, 0x00000000}},  //   _njëj, ghna_, _tyrr,
  { {0x672d0213, 0xc5f10055, 0xa2a50164, 0x00000000}},  //   čajn, _জেলা_, _काल्,
  { {0xb6f400ec, 0xdbd2006c, 0x63a11974, 0x00000000}},  //   рзиј, _müür, duln,
  { {0xe9da01fb, 0xfaf7009b, 0x3b0700ed, 0x00000000}},  //   _яка_, _עצמי_, _сето_,
  { {0x38c800e9, 0x290700b9, 0x63a10133, 0x00000000}},  //   _جاری_, chna_, fuln,
  { {0x4c9b0049, 0x499000a1, 0x00000000, 0x00000000}},  //   עשטע, _ایڈر,   ,
  { {0x395e04c7, 0xa2a50061, 0x00000000, 0x00000000}},  //   _hits_, _काळ्,   ,
  { {0x395e0c0d, 0x7f5d00f4, 0x9258007c, 0x00000000}},  //   _kits_, _risq, лают_,
  { {0x7f5d00f6, 0xbebb0023, 0xbcfb0919, 0x00000000}},  //   _sisq, _gjëj, _cuél,
  { {0x395e1975, 0x00000000, 0x00000000, 0x00000000}},  //   _mits_,   ,   ,
  { {0x395e1976, 0x7cf206ec, 0x2907012d, 0x00000000}},  //   _lits_, _særp, zhna_,
  { {0x2d8f0010, 0x7e6d003f, 0x7f5d0115, 0x00000000}},  // [35f0] ége_, rcap, _visq,
  { {0x7e6d049a, 0x395e0129, 0x22491977, 0x00000000}},  //   scap, _nits_, _izak_,
  { {0x1cb80025, 0x7f5d01f3, 0x00000000, 0x00000000}},  //   طالب_, _tisq,   ,
  { {0x2cb80a3b, 0x00000000, 0x00000000, 0x00000000}},  //   _ebrd_,   ,   ,
  { {0xdd01011f, 0x7cdb001e, 0xddc4001a, 0x00000000}},  //   ştır, _pārē, rciţ,
  { {0x395e0089, 0x69c90059, 0x6ce70088, 0x00000000}},  //   _cits_, _vsee, _сіме,
  { {0x395e0f57, 0x80ad0309, 0xbebb0065, 0x00000000}},  //   _dits_, _जाने, _njëk,
  { {0xb8fc02fb, 0x497501fb, 0x29070908, 0x00000000}},  //   _तो_, _влас, shna_,
  { {0x09b806b4, 0x69c91978, 0x395e0133, 0x00000000}},  //   _مطلع_, _usee, _fits_,
  { {0x332900b5, 0x63a101ca, 0x9f580065, 0x00000000}},  //   _ajax_, tuln, tyrë_,
  { {0x04450373, 0xd8740d0b, 0x29050fd1, 0x00000000}},  //   ренн, _طالب, _illa_,
  { {0x216a041f, 0x25690010, 0x395e021b, 0x00000000}},  //   кими_, _túl_, _zits_,
  { {0xe2970783, 0x614608f3, 0x26cf1014, 0x00000000}},  //   шая_, иема, _iago_,
  { {0x81b80055, 0x26cf0211, 0x8467005e, 0x00000000}},  //   ছিল_, _hago_, _съде,
  { {0x26cf000a, 0x3f1600ed, 0x22490032, 0x00000000}},  //   _kago_, аќат, _ezak_,
  { {0x26cf0093, 0x3eab0009, 0x2caa0022, 0x00000000}},  //   _jago_, _ccct_, _scbd_,
  { {0x29050368, 0xa3cd02fb, 0x433b009b, 0x00000000}},  // [3600] _olla_, रिक_, _בעקב,
  { {0x26cf0555, 0x80ad013d, 0x409600e3, 0x00000000}},  //   _lago_, _जाये, _трит,
  { {0x24870607, 0x6cd301fa, 0xa09b01ce, 0x00000000}},  //   _menm_, تقلا, _בייט,
  { {0x29050624, 0x26cf002d, 0xbebb0065, 0x00000000}},  //   _alla_, _nago_, _njëh,
  { {0x395e041d, 0x6f03001a, 0x28e20963, 0x00000000}},  //   _pits_, _înca, पालि,
  { {0x89da0123, 0xdb050a87, 0x39130088, 0x00000000}},  //   _یوزر_, rthá, омір,
  { {0xb8ce02d2, 0x26cf006a, 0x2fda0022, 0x00000000}},  //   _का_, _bago_, _jrpg_,
  { {0xd6d7007c, 0x29050219, 0xfaa30088, 0x00000000}},  //   ать_, _ella_, _масо,
  { {0x26cf022b, 0x6b9e001c, 0x395e0061, 0x00000000}},  //   _dago_, lrpg, _tits_,
  { {0x04660098, 0x395e00d9, 0x00000000, 0x00000000}},  //   штим, _uits_,   ,
  { {0x291c1979, 0x9cd90049, 0x6cd90049, 0x00000000}},  //   miva_, אַרז, אַרצ,
  { {0x291c07ac, 0x26cf011c, 0xe61a0745, 0x00000000}},  //   liva_, _gago_, _иде_,
  { {0x26c412ac, 0x5067005e, 0xe73716e3, 0x00000000}},  //   memo_, итва, _тец_,
  { {0x291c0638, 0x26cf197a, 0x2487000a, 0x00000000}},  //   niva_, _zago_, _genm_,
  { {0x26cf0203, 0x00000000, 0x00000000, 0x00000000}},  //   _yago_,   ,   ,
  { {0x291c001a, 0x2fcd0036, 0x6d4e002b, 0x00000000}},  //   hiva_, łego_, _ahba,
  { {0x291c197b, 0x2249014a, 0x22400010, 0x00000000}},  // [3610] kiva_, _uzak_, _gyik_,
  { {0x291c0c1e, 0x61fd197c, 0xe1ff0036, 0x00000000}},  //   jiva_, mysl, wców_,
  { {0x291c0627, 0x70550014, 0x41d50164, 0x00000000}},  //   diva_, _دندا, दिवस,
  { {0x26c40295, 0x6e3200b9, 0xf21c013d, 0x00000000}},  //   jemo_, _žebř, _पेड़_,
  { {0x26c40e00, 0xe1ff0036, 0x26cf04a5, 0x00000000}},  //   demo_, rców_, _rago_,
  { {0x291c197d, 0x26cf0483, 0x3ea90725, 0x00000000}},  //   giva_, _sago_, lgat_,
  { {0x26cf0b76, 0xb3a9005f, 0x260f006e, 0x00000000}},  //   _pago_, _çıxı, _तेजी_,
  { {0x3ea9020c, 0x656f01ca, 0x6ef806f4, 0x00000000}},  //   ngat_, ícho, _híbr,
  { {0x291c0074, 0x98c70081, 0xa3a901f5, 0x00000000}},  //   biva_, _всел, गून_,
  { {0xdb1c00f4, 0x290500eb, 0x61fd00ea, 0x00000000}},  //   _aprè, _ulla_, dysl,
  { {0x26cf0058, 0x2bda013d, 0x00000000, 0x00000000}},  //   _tago_, णिया,   ,
  { {0x26c4037e, 0x05170044, 0x6ef8004a, 0x00000000}},  //   cemo_, ঠকের_, _líbr,
  { {0x61fd007f, 0x7d070087, 0x00000000, 0x00000000}},  //   gysl, _oljs,   ,
  { {0x463a0049, 0x657b027c, 0xdb1c0173, 0x00000000}},  //   _גענע, mpuh, _eprè,
  { {0xd007026b, 0xdee6197e, 0x442e00f6, 0x00000000}},  //   бере_, бови, _gxf_,
  { {0x98a70046, 0x0e660c4e, 0x291c0091, 0x00000000}},  //   ronę_, скан, ziva_,
  { {0x10a601fb, 0xc27b009b, 0x00000000, 0x00000000}},  // [3620] _липн, _גרפי,   ,
  { {0x26c4037e, 0x291c10af, 0x6abb0022, 0x00000000}},  //   zemo_, xiva_, _abuf,
  { {0xcfea0014, 0x26c40061, 0x1c39007e, 0x00000000}},  //   _صفحه_, yemo_, аяць_,
  { {0xfaa60d68, 0x69db101a, 0x00000000, 0x00000000}},  //   садо, _brue,   ,
  { {0x315702fd, 0x26c40c1e, 0x00000000, 0x00000000}},  //   _خلیج_, vemo_,   ,
  { {0x26c40020, 0x69db00b7, 0x7f44197f, 0x00000000}},  //   wemo_, _drue, lliq,
  { {0x291c1980, 0x26c40042, 0x00000000, 0x00000000}},  //   riva_, temo_,   ,
  { {0x291c08d3, 0xc6f8019d, 0x69db1981, 0x00000000}},  //   siva_, рних_, _frue,
  { {0x26c41982, 0x69db0252, 0x291c00b0, 0x00000000}},  //   remo_, _grue, piva_,
  { {0x26c40107, 0x7d1e0058, 0x3ea9014a, 0x00000000}},  //   semo_, nips, zgat_,
  { {0xdb1c009d, 0x1877009b, 0x201e0253, 0x00000000}},  //   _apré, _העבר_, útil_,
  { {0xa3cd006e, 0x61fd00b0, 0x7d1e0095, 0x00000000}},  //   रिज_, tysl, hips,
  { {0x66e50164, 0x02aa0061, 0xf204007e, 0x00000000}},  //   कारक_, _कारभ, пяро,
  { {0x2d920007, 0xf1270500, 0x61fd0472, 0x00000000}},  //   dsye_, сьмо, rysl,
  { {0x24b7009b, 0xf04300a1, 0x753a0b7c, 0x00000000}},  //   _ההון_, سٹری, motz,
  { {0x69c0017c, 0x3ea9001a, 0x753a0032, 0x00000000}},  //   _opme, ugat_, lotz,
  { {0x7bdc1983, 0xd0d50265, 0x3ea900d4, 0x00000000}},  // [3630] _arru, _допъ, rgat_,
  { {0x8c671984, 0x6abb0026, 0x753a0032, 0x00000000}},  //   стад, _sbuf, notz,
  { {0x7f441923, 0xbc4b0057, 0x69c0001e, 0x00000000}},  //   bliq, учае_, _apme,
  { {0x69db0211, 0x753a002d, 0x60c70023, 0x00000000}},  //   _prue, hotz, lejm,
  { {0x6f0d002a, 0x7bdc002d, 0x753a002d, 0x00000000}},  //   mhac, _erru, kotz,
  { {0xd366023c, 0xf77101af, 0x20110026, 0x00000000}},  //   _يه_, واب_, ozzi_,
  { {0x3786005e, 0x776200e5, 0xda7b007e, 0x00000000}},  //   общо_, _biox, _бяз_,
  { {0x69db068f, 0x6d450c49, 0x6abb0009, 0x00000000}},  //   _true, llha, _ubuf,
  { {0xd6290147, 0x628f0020, 0x9f4a0068, 0x00000000}},  //   ропе_, daco, ômée_,
  { {0x753a002d, 0x1425007c, 0x3871006b, 0x00000000}},  //   gotz, ждом, _üzr_,
  { {0x02c601e0, 0xd6ce0123, 0x60c70036, 0x00000000}},  //   ойно, رقی_, dejm,
  { {0x77620026, 0x6d4501a2, 0x628f00b4, 0x00000000}},  //   _giox, hlha, gaco,
  { {0x51ba007e, 0x2d4d1985, 0x6f0d0048, 0x00000000}},  //   шыня_, _džez_, dhac,
  { {0x320c0036, 0x627e0036, 0x67290134, 0x00000000}},  //   ądy_, dłoż, lnej,
  { {0x656b0016, 0x6143004c, 0x6b650006, 0x00000000}},  //   _hugh, фера, _mėgs,
  { {0x65631986, 0x628f00c4, 0x656b0020, 0x00000000}},  //   _hinh, caco, _kugh,
  { {0x7d1e035f, 0x80a500a1, 0x65630082, 0x00000000}},  // [3640] tips, _کمپن, _kinh,
  { {0x65630066, 0x656b1575, 0x644303b4, 0x00000000}},  //   _jinh, _mugh, _kyni,
  { {0x656302d5, 0x7d1e1987, 0x656b000b, 0x00000000}},  //   _minh, rips, _lugh,
  { {0xe9da0f09, 0x65631988, 0x6f0d0020, 0x00000000}},  //   ике_, _linh, chac,
  { {0x6d450016, 0x67290465, 0x656b0026, 0x00000000}},  //   blha, dnej, _nugh,
  { {0xf806007c, 0x1d0a0077, 0x6f0413fb, 0x00000000}},  //   жчин, _теги_, lkic,
  { {0xe3a702fd, 0xeb97007c, 0x7bdc002d, 0x00000000}},  //   _تر_, _мир_, _urru,
  { {0x656b0058, 0x6563002d, 0x6f040166, 0x00000000}},  //   _bugh, _ainh, nkic,
  { {0x65630d39, 0x3cf8150e, 0x628f0142, 0x00000000}},  //   _binh, _korv_, vaco,
  { {0x2b460129, 0x32d70011, 0xa3d6013d, 0x00000000}},  //   lloc_, _ủy_, सिल_,
  { {0x65630181, 0x64430016, 0x628f0207, 0x00000000}},  //   _dinh, _cyni, taco,
  { {0x65630fde, 0x753a022b, 0x61e20059, 0x00000000}},  //   _einh, sotz, _šola,
  { {0x628f0387, 0x753a004a, 0x7d1c016c, 0x00000000}},  //   raco, potz, _omrs,
  { {0x628f03d1, 0x65630058, 0x3cf800ea, 0x00000000}},  //   saco, _ginh, _norv_,
  { {0x6f0d0051, 0x628f1989, 0x60c70087, 0x00000000}},  //   thac, paco, rejm,
  { {0xe7f202d2, 0x3eaf010f, 0x2b46001a, 0x00000000}},  //   _अपना_, ügt_, jloc_,
  { {0x2005154d, 0x63a80142, 0xe1ff0129, 0x00000000}},  // [3650] šli_, ludn, rcós_,
  { {0x656301da, 0x6729198a, 0x6f0d016e, 0x00000000}},  //   _xinh, znej, shac,
  { {0x63a80059, 0x6d450203, 0xdbd6010e, 0x00000000}},  //   nudn, rlha, jääg,
  { {0x6f04198b, 0xddcd198c, 0xfbde00c4, 0x00000000}},  //   ckic, mbaž, _drª_,
  { {0xed5b02fd, 0x6f1d0051, 0xda7801e1, 0x00000000}},  //   _نشست_, _imsc, цях_,
  { {0xb17c00b3, 0x656b0197, 0x00000000, 0x00000000}},  //   סטור, _rugh,   ,
  { {0xa2ac001c, 0x07a50500, 0x2b460115, 0x00000000}},  //   _झाल्, чайн, bloc_,
  { {0x65630082, 0x2b46198d, 0x6ef1198e, 0x00000000}},  //   _sinh, cloc_, _påby,
  { {0x67290b4a, 0x644307b5, 0x65630181, 0x00000000}},  //   rnej, _syni, _pinh,
  { {0x67290235, 0xe61600a5, 0x656b00bb, 0x00000000}},  //   snej, яды_, _vugh,
  { {0x65630181, 0x6f1d00b5, 0x00000000, 0x00000000}},  //   _vinh, _omsc,   ,
  { {0x64430161, 0xd7ba009b, 0x656b0258, 0x00000000}},  //   _vyni, _לצער, _tugh,
  { {0x64430046, 0x65630701, 0x9f5e01dc, 0x00000000}},  //   _wyni, _tinh, átí_,
  { {0x63a80027, 0x6f1d0d28, 0x00000000, 0x00000000}},  //   budn, _amsc,   ,
  { {0xdee6198f, 0xbebb0065, 0x9f5e01dc, 0x00000000}},  //   пови, _njës, ští_,
  { {0x1b010044, 0x00000000, 0x00000000, 0x00000000}},  //   লোতে_,   ,   ,
  { {0x6f0404eb, 0xfbde00fa, 0x00000000, 0x00000000}},  // [3660] rkic, _srª_,   ,
  { {0x6f040b23, 0x00000000, 0x00000000, 0x00000000}},  //   skic,   ,   ,
  { {0xe0fb00b3, 0x7f46007c, 0x6f040b4a, 0x00000000}},  //   _הליל, _неож, pkic,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd9460256, 0x2ea80061, 0x3cf807c4, 0x00000000}},  //   педи, गलीत, _torv_,
  { {0x2d800007, 0xfe6f00a1, 0xed57007c, 0x00000000}},  //   mpie_, _لگے_, _ноя_,
  { {0xab64010f, 0x2d8001c3, 0x2ca7004a, 0x00000000}},  //   grüß, lpie_, ónde_,
  { {0x290e0020, 0x2d8000d2, 0x63a802e1, 0x00000000}},  //   shfa_, opie_, vudn,
  { {0xb6c8026c, 0x9634004c, 0xceb301ce, 0x00000000}},  //   ماکے_, ьниц, גיח_,
  { {0x63a8002b, 0x00000000, 0x00000000, 0x00000000}},  //   tudn,   ,   ,
  { {0x533501bd, 0x68e80030, 0xa84a0025, 0x00000000}},  //   дент, _indd, _الام_,
  { {0x68fa0010, 0x63a80036, 0x00000000, 0x00000000}},  //   _hotd, rudn,   ,
  { {0x63a81990, 0x75210032, 0xc56a0025, 0x00000000}},  //   sudn, bilz, _احصل_,
  { {0xbebb008d, 0xd6250774, 0xe9ce007e, 0x00000000}},  //   _njër, _تعمي, ткi_,
  { {0x4fc4003b, 0xdb1c1991, 0x2d800007, 0x00000000}},  //   нста, _aprí, epie_,
  { {0xdb1c0051, 0x290c00e0, 0x00000000, 0x00000000}},  //   _bprí, _llda_,   ,
  { {0xf1b10061, 0xe3b8005d, 0x2d801992, 0x00000000}},  // [3670] _जमिन, ltı_, gpie_,
  { {0x68fa01a2, 0x39470045, 0x4d980930, 0x00000000}},  //   _notd, xlns_, якую_,
  { {0xe3b8005a, 0x798901c3, 0x9f550152, 0x00000000}},  //   ntı_, _swew, _овоч,
  { {0xf1b1006e, 0x290c121f, 0x6f1d010f, 0x00000000}},  //   _जमान, _alda_, _umsc,
  { {0xeab00025, 0x68fa00d9, 0x60d70288, 0x00000000}},  //   اعم_, _botd, _kaxm,
  { {0xd045005f, 0xbebb0065, 0xe3b8005a, 0x00000000}},  //   _sahə, _gjër, ktı_,
  { {0xb09c0049, 0x7b080010, 0xbebb0023, 0x00000000}},  //   מיגר, ártó, _ujës,
  { {0x06090256, 0xfbd2009b, 0x68e80030, 0x00000000}},  //   жник_, _בתל_, _endd,
  { {0x7ae9006c, 0xeaf80025, 0x00000000, 0x00000000}},  //   _inet, _عرفت_,   ,
  { {0x7afb01b5, 0x61e200d0, 0x25720016, 0x00000000}},  //   _hout, _šolo, _dâl_,
  { {0x7afb1993, 0xbcfb008e, 0x7ae901a2, 0x00000000}},  //   _kout, _hués, _knet,
  { {0x6f03001a, 0x7afb021e, 0x2d9900ca, 0x00000000}},  //   _înch, _jout, _ovse_,
  { {0x60d7005f, 0x68e80016, 0x7afb060b, 0x00000000}},  //   _baxm, _yndd, _mout,
  { {0x7afb10f0, 0x7dd80048, 0xbcfb004a, 0x00000000}},  //   _lout, húsá, _mués,
  { {0x7ae9114c, 0xa067003b, 0x504300ed, 0x00000000}},  //   _onet, дара_, верб,
  { {0x7afb001a, 0x7dd80010, 0x00000000, 0x00000000}},  //   _nout, júsá,   ,
  { {0x2d800e6d, 0xddc60036, 0x4d66007e, 0x00000000}},  // [3680] upie_, _szkł, дкав,
  { {0x7ae90065, 0x2d800a77, 0x51f700a1, 0x00000000}},  //   _anet, rpie_, _آسٹر,
  { {0x7afb028c, 0x2d8000b4, 0x8e8608d6, 0x00000000}},  //   _bout, spie_, _огне,
  { {0x7afb1994, 0x291e0022, 0x7ae91995, 0x00000000}},  //   _cout, _smta_, _cnet,
  { {0xfe42026c, 0x7afb1994, 0xb17b0030, 0x00000000}},  //   _شکری, _dout, rvåg,
  { {0xe3b80477, 0x7ae91996, 0xbebb0023, 0x00000000}},  //   ytı_, _enet, _ujër,
  { {0x7afb046a, 0xe3b8006b, 0x25720016, 0x00000000}},  //   _fout, xtı_, _sâl_,
  { {0x7afb023f, 0xd7570025, 0x7ae91997, 0x00000000}},  //   _gout, وجيا_, _gnet,
  { {0xa3b00164, 0x68fa1998, 0xf77200a1, 0x00000000}},  //   टून_, _totd, راں_,
  { {0x7afb1999, 0xe3b8014a, 0xbcfb008e, 0x00000000}},  //   _zout, ttı_, _huér,
  { {0x7afb00ab, 0x798200d2, 0x00000000, 0x00000000}},  //   _yout, lpow,   ,
  { {0xe3af00d3, 0x38630010, 0xe3b801df, 0x00000000}},  //   گری_, _újra_, rtı_,
  { {0x672d199a, 0xe3b8026d, 0x00000000, 0x00000000}},  //   čajt, stı_,   ,
  { {0xe3af0167, 0xe3b8014a, 0x00000000, 0x00000000}},  //   دری_, ptı_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdcc70183, 0x7d0e199b, 0x798200e0, 0x00000000}},  //   रज्ञ, _albs, kpow,
  { {0xa3d60316, 0x5d55003b, 0x98be0173, 0x00000000}},  // [3690] सिक_, екат, _aktč_,
  { {0x7afb0c6a, 0x7059007e, 0x2249011c, 0x00000000}},  //   _sout, _напр_, _iyak_,
  { {0xfe70026c, 0x7afb0263, 0x3b0d0023, 0x00000000}},  //   ادہ_, _pout, _pleq_,
  { {0xd6d90036, 0x3f83002b, 0x80bb006e, 0x00000000}},  //   koła_, mpju_, श्रे,
  { {0x7ae90059, 0x7afb0dd9, 0x013401b2, 0x00000000}},  //   _vnet, _vout, _سعید,
  { {0xe9d80099, 0xe8f80245, 0x7afb00bb, 0x00000000}},  //   ькі_, млі_, _wout,
  { {0x7afb028c, 0xe77800a1, 0x5ed20044, 0x00000000}},  //   _tout, ولوں_, হারে,
  { {0xbcfb00f4, 0x29070203, 0x00000000, 0x00000000}},  //   _guér, skna_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf8070057, 0x00000000, 0x00000000, 0x00000000}},  //   _очен,   ,   ,
  { {0x2249014a, 0x8cc1006e, 0x644f0036, 0x00000000}},  //   _ayak_, र्यो, ęcio,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe60e004d, 0x3d000061, 0x00000000, 0x00000000}},  //   _сд_, _शकले_,   ,
  { {0x656f199c, 0x2618006e, 0xe7c30044, 0x00000000}},  //   íchu, _बेटी_, ্মীয,
  { {0x79820036, 0x00000000, 0x00000000, 0x00000000}},  //   zpow,   ,   ,
  { {0xdb1c04bb, 0x3cea00d9, 0x00000000, 0x00000000}},  //   _oprá, _snbv_,   ,
  { {0x6da300c0, 0xd2660088, 0x7bc7199d, 0x00000000}},  // [36a0] лита, _який, _apju,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x1ee8026c, 0xbcfb009d, 0x25ad008e, 0x00000000}},  //   _ہوگی_, _puér, huel_,
  { {0x61e40ecc, 0x60dc0107, 0x25ad05cd, 0x00000000}},  //   _kril, ldrm, kuel_,
  { {0xdced01d5, 0x61e20107, 0x00000000, 0x00000000}},  //   ssaġ, _šolj,   ,
  { {0x6b510039, 0x25ad199e, 0x7b1300fa, 0x00000000}},  //   råga, duel_, _açud,
  { {0xfaa6008b, 0x00000000, 0x00000000, 0x00000000}},  //   _паво,   ,   ,
  { {0x61e4008e, 0xd90e0123, 0x00000000, 0x00000000}},  //   _oril, _گیت_,   ,
  { {0x25ad0489, 0x6d5e0048, 0x00000000, 0x00000000}},  //   guel_, ompa,   ,
  { {0xe9d70088, 0x3a23106d, 0x00000000, 0x00000000}},  //   _яку_, _смуг,   ,
  { {0x66e60057, 0xdb1c0224, 0x61e4199f, 0x00000000}},  //   _пожа, _zprá, _aril,
  { {0x6b9c00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _mvrg,   ,   ,
  { {0x6906009f, 0x61e400f8, 0x3f57009d, 0x00000000}},  //   _aðei, _cril, nçue_,
  { {0x2eeb009d, 0x61e400ab, 0x6b9c0087, 0x00000000}},  //   _sncf_, _dril, _ovrg,
  { {0xb4ac0201, 0x61e40368, 0xe9ff001d, 0x00000000}},  //   गली_, _eril, _khảo_,
  { {0x61e405ad, 0x22490058, 0x00000000, 0x00000000}},  //   _fril, _tyak_,   ,
  { {0x6722000b, 0x6ca70088, 0x2f07006c, 0x00000000}},  // [36b0] _mmoj, ереж, _jõgi_,
  { {0x63a80287, 0x656a002b, 0x00000000, 0x00000000}},  //   ordn, _jifh,   ,
  { {0xdb1c06b8, 0x6e2a006b, 0x9be4007e, 0x00000000}},  //   _sprá, _əlbə, ліцк,
  { {0x6d5e00b0, 0xa5a1013d, 0x00000000, 0x00000000}},  //   ampa, _खिलौ,   ,
  { {0x25ad19a0, 0x644a19a1, 0x00000000, 0x00000000}},  //   xuel_, _lyfi,   ,
  { {0x7f4d001c, 0xbb850025, 0x7bcb0035, 0x00000000}},  //   llaq, _للسي, ăgub,
  { {0x644a0039, 0xe73919a2, 0x58940025, 0x00000000}},  //   _nyfi, мек_, اجهز,
  { {0x25ad19a3, 0xe9ff0082, 0xb21b000c, 0x00000000}},  //   tuel_, _chảo_, rbæj,
  { {0x6f03001a, 0xaefb0045, 0x6b6c014a, 0x00000000}},  //   _încu, _ciùi, _işga,
  { {0x67220009, 0x25ad008e, 0x80ad0204, 0x00000000}},  //   _emoj, ruel_, _जागे,
  { {0x63a80107, 0x644a018e, 0x25ad009d, 0x00000000}},  //   grdn, _cyfi, suel_,
  { {0x61e40213, 0x60ce00d4, 0x644a132f, 0x00000000}},  //   _pril, webm, _dyfi,
  { {0x25ad0fdb, 0x1c1e001c, 0x6d5e0016, 0x00000000}},  //   quel_, _येईल_, ympa,
  { {0x7e7d19a4, 0xe5a2003b, 0x64a50fc0, 0x00000000}},  //   _afsp, _тиши, _рака,
  { {0x21670517, 0x764b018e, 0x644a0016, 0x00000000}},  //   тири_, _hygy, _gyfi,
  { {0x61e40d52, 0x69c90328, 0x8464005e, 0x00000000}},  //   _tril, _opee, _съче,
  { {0x61e4001a, 0xc69200a0, 0x00000000, 0x00000000}},  // [36c0] _uril, יאן_,   ,
  { {0xdced006b, 0x4c8300e2, 0x00000000, 0x00000000}},  //   rpağ, илув,   ,
  { {0xeb97019d, 0x6d5e00ea, 0x7d030510, 0x00000000}},  //   вих_, rmpa, önsa,
  { {0xfaa6025f, 0x6207000c, 0x00000000, 0x00000000}},  //   тадо, _örlí,   ,
  { {0xceb3007b, 0x82770049, 0x00000000, 0x00000000}},  //   _דיר_, דענע_,   ,
  { {0x6b580df3, 0x92ce0044, 0xceb4006b, 0x00000000}},  //   díge, রায়_, lgə_,
  { {0xdbcc000c, 0xc0100011, 0x69c9118e, 0x00000000}},  //   _góða, _đuổi_, _epee,
  { {0x95d80264, 0xceb4005f, 0xc6230044, 0x00000000}},  //   едит_, ciət_, _পড়া_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb4ac0183, 0x44f4005e, 0x03f8003b, 0x00000000}},  //   गले_, упос, еној_,
  { {0xe9ff001d, 0xd6cf19a5, 0x929506f3, 0x00000000}},  //   _thảo_, _кт_, ланц,
  { {0x6722000b, 0xf626003b, 0xdb9b0097, 0x00000000}},  //   _umoj, _идео, וסטר,
  { {0x63a80091, 0x644a01d6, 0x656a002b, 0x00000000}},  //   srdn, _wyfi, _tifh,
  { {0x3494132e, 0xdb05009d, 0x00000000, 0x00000000}},  //   _сакр, rrhé,   ,
  { {0x403501f9, 0xe7e5013d, 0x2f1506ec, 0x00000000}},  //   уевс, किया_, _låge_,
  { {0x75280089, 0xfcd900a1, 0xb7db00a3, 0x00000000}},  //   lidz, کارڈ_, וקלי,
  { {0x2d8f00f4, 0x7e550088, 0x26c600e7, 0x00000000}},  // [36d0] ège_, уває, _mboo_,
  { {0x48bd0044, 0x00000000, 0x00000000, 0x00000000}},  //   _আফ্র,   ,   ,
  { {0x69c91936, 0x7a0a0089, 0xf1bf0325, 0x00000000}},  //   _spee, _lētā, ltá_,
  { {0x6f16013e, 0x6b510039, 0xee840a78, 0x00000000}},  //   chyc, rågo, _выро,
  { {0xf1bf19a6, 0x7b1300c4, 0x2d5400b0, 0x00000000}},  //   ntá_, _açuc, mäen_,
  { {0xb4ac01f5, 0x6f0d00b4, 0x00000000, 0x00000000}},  //   गलो_, lkac,   ,
  { {0xf7710d3a, 0x6d45008e, 0x31580049, 0x00000000}},  //   حات_, moha, דיגן_,
  { {0xdb05002a, 0x6f0d0871, 0x6b58004a, 0x00000000}},  //   rthó, nkac, tíge,
  { {0x645c000c, 0x00000000, 0x00000000, 0x00000000}},  //   ýrin,   ,   ,
  { {0x6d4519a7, 0x6b580446, 0xe616007c, 0x00000000}},  //   noha, ríge, удь_,
  { {0xc2090104, 0xf1bf00c4, 0x00000000, 0x00000000}},  //   _צה_, etá_,   ,
  { {0xa77a007b, 0x82f600e2, 0x00000000, 0x00000000}},  //   _טרעפ, учоц,   ,
  { {0x6d450004, 0xe5a500d7, 0x67290a67, 0x00000000}},  //   koha, _сили, miej,
  { {0x67290006, 0xf48700ed, 0x6d4501a3, 0x00000000}},  //   liej, _рудн, joha,
  { {0x66090010, 0x37c30044, 0x232a0088, 0x00000000}},  //   lyek, ্মকর, _поки_,
  { {0x67290fed, 0x26df0006, 0x25bf0035, 0x00000000}},  //   niej, nduo_, otul_,
  { {0x25bf000d, 0x660919a8, 0xceb4006b, 0x00000000}},  // [36e0] ntul_, nyek, rgə_,
  { {0x98a70006, 0x25bf001a, 0x629600e0, 0x00000000}},  //   monė_, itul_, _heyo,
  { {0x67290036, 0xa25b00c4, 0x00000000, 0x00000000}},  //   kiej, nfôn,   ,
  { {0x6f0d0253, 0x26dd0045, 0x62960173, 0x00000000}},  //   ckac, _nawo_, _jeyo,
  { {0xe81c013d, 0xceb4006b, 0x672919a9, 0x00000000}},  //   _भेजा_, rhəd_, diej,
  { {0x6f03001a, 0xdb1c0039, 0xdb050344, 0x00000000}},  //   _încr, _sprä, ruhá,
  { {0x6d5c014a, 0x60de0023, 0x26dd0173, 0x00000000}},  //   _ihra, _mapm, _bawo_,
  { {0x2ee0002b, 0x629601aa, 0x75280036, 0x00000000}},  //   ndif_, _neyo, widz,
  { {0x16340ae0, 0xe9ff0082, 0x6d5c0203, 0x00000000}},  //   репя, _thạo_, _khra,
  { {0x88bc0224, 0x00000000, 0x00000000, 0x00000000}},  //   _změn,   ,   ,
  { {0x629619aa, 0xdb1e0065, 0x25bf001a, 0x00000000}},  //   _beyo, jtpë, atul_,
  { {0x66760054, 0x660919ab, 0x26dd000a, 0x00000000}},  //   _إدار, byek, _gawo_,
  { {0x6d5c0059, 0x25bf000d, 0x62960173, 0x00000000}},  //   _ohra, ctul_, _deyo,
  { {0x60de19ac, 0xf1bf00fa, 0x6f0d0036, 0x00000000}},  //   _capm, rtá_, wkac,
  { {0xe47b009b, 0xf1bf04bb, 0x2d5400b0, 0x00000000}},  //   _ארוכ, stá_, täen_,
  { {0xfe730a4f, 0x62960022, 0x6d450058, 0x00000000}},  //   صدر_, _geyo, woha,
  { {0x6d45006a, 0x6d5c0051, 0x6f0d0036, 0x00000000}},  // [36f0] toha, _bhra, rkac,
  { {0xb0b203d7, 0x6d5c19ad, 0x67290006, 0x00000000}},  //   _जाएग, _chra, ziej,
  { {0x6296000b, 0x3a7500ed, 0x6d4519ae, 0x00000000}},  //   _yeyo, алер, roha,
  { {0x645d006b, 0x6d450058, 0x8d7703ec, 0x00000000}},  //   əsid, soha, _ماسا,
  { {0x60de011f, 0x39a7025f, 0x67290d94, 0x00000000}},  //   _yapm, ушев, viej,
  { {0x26dd19af, 0x6d5c0048, 0xbebb0023, 0x00000000}},  //   _sawo_, _ghra, _njëz,
  { {0xdb1c01d2, 0x672919b0, 0xa8020180, 0x00000000}},  //   _språ, tiej, şınl,
  { {0x88bc00b9, 0x661b002d, 0xbddb0173, 0x00000000}},  //   _uměn, tzuk, _fyèt,
  { {0x2d890061, 0x629606af, 0x45350242, 0x00000000}},  //   npae_, _reyo, ихот,
  { {0x25bf000d, 0x6729093c, 0x62960093, 0x00000000}},  //   rtul_, siej, _seyo,
  { {0x661b0046, 0x25bf000d, 0x394706fa, 0x00000000}},  //   szuk, stul_, mons_,
  { {0x394700f4, 0x25bf000d, 0xb17b0039, 0x00000000}},  //   lons_, ptul_, rvån,
  { {0x80df0044, 0x00000000, 0x00000000, 0x00000000}},  //   মান্,   ,   ,
  { {0x394719b1, 0x660600b0, 0x73e50131, 0x00000000}},  //   nons_, äkke, _вокз,
  { {0x5f0619b2, 0xdfd2067a, 0x629601aa, 0x00000000}},  //   азва, غير_, _teyo,
  { {0x1e8601f9, 0x6d5c0059, 0x3947009d, 0x00000000}},  //   рлам, _shra, hons_,
  { {0xa156005e, 0x60de19b3, 0x6d5c19b4, 0x00000000}},  // [3700] _външ, _tapm, _phra,
  { {0x39470089, 0xdca6013b, 0x6abb0026, 0x00000000}},  //   jons_, ражи, _acuf,
  { {0x60c30010, 0x00000000, 0x00000000, 0x00000000}},  //   _önma,   ,   ,
  { {0xdee6003b, 0x00000000, 0x00000000, 0x00000000}},  //   _томи,   ,   ,
  { {0x6d5c0016, 0x394719b5, 0xd90d00a6, 0x00000000}},  //   _thra, fons_, کیل_,
  { {0x97a60679, 0x394701cb, 0xb21b000c, 0x00000000}},  //   арил, gons_, mbæt,
  { {0xf09300b6, 0x81cc0044, 0xf803007e, 0x00000000}},  //   חנו_, রটি_, жчын,
  { {0xa3e40316, 0xab690070, 0x7bdb009b, 0x00000000}},  //   निस_, _محقق_, _בקלו,
  { {0x25ad00d4, 0xc6f70783, 0x394700f6, 0x00000000}},  //   grel_, рных_, bons_,
  { {0x81cc0044, 0x7ae207ef, 0x7ae000e7, 0x00000000}},  //   রটা_, ldot, _hamt,
  { {0x69c20168, 0x7ae000ea, 0x3c7700b3, 0x00000000}},  //   ltoe, _kamt, יתים_,
  { {0x7ae2001b, 0x268a023c, 0x86461020, 0x00000000}},  //   ndot, _شخصي_, _кнеж,
  { {0x69c20292, 0x273a0089, 0x7ae201c5, 0x00000000}},  //   ntoe, cīna_, idot,
  { {0x29c2001d, 0x2d050061, 0x7ae00cb8, 0x00000000}},  //   _mưa_, _शकेल_, _lamt,
  { {0x753d0047, 0x7ae20d90, 0x69c200b0, 0x00000000}},  //   észe, kdot, htoe,
  { {0x3947062a, 0x69c219b6, 0x7ae019b7, 0x00000000}},  //   zons_, ktoe, _namt,
  { {0x629d0013, 0x394700f4, 0x7ae219b8, 0x00000000}},  // [3710] maso, yons_, ddot,
  { {0x394702d0, 0x629d07ac, 0x30a70088, 0x00000000}},  //   xons_, laso, _трив,
  { {0x394700f4, 0xbddb000a, 0x00000000, 0x00000000}},  //   vons_, _pyès,   ,
  { {0x06ac0055, 0x7ae001a3, 0x3b040026, 0x00000000}},  //   ক্তি, _camt, _comq_,
  { {0xa2bc02f4, 0x39471120, 0x29c20082, 0x00000000}},  //   ष्ट्, tons_, _cưa_,
  { {0x629d19b9, 0x88bc00b9, 0x29c20011, 0x00000000}},  //   haso, _uměl, _dưa_,
  { {0x394700f4, 0xfb84007e, 0x7ae00087, 0x00000000}},  //   rons_, _мытн, _famt,
  { {0x497505a5, 0x3947028a, 0x7ae00006, 0x00000000}},  //   _глас, sons_, _gamt,
  { {0x629d065c, 0x394719ba, 0x69db164e, 0x00000000}},  //   daso, pons_, _usue,
  { {0x25ad0e69, 0x00000000, 0x00000000, 0x00000000}},  //   rrel_,   ,   ,
  { {0xe29a017a, 0x9407006b, 0x0445060e, 0x00000000}},  //   лан_, _yenə_, сенн,
  { {0x290519bb, 0x68e10635, 0x2d850e3c, 0x00000000}},  //   _hola_, _hald, _člen_,
  { {0x68e119bc, 0x29050802, 0x29c20011, 0x00000000}},  //   _kald, _kola_, _xưa_,
  { {0x68e30065, 0xa3e40316, 0x61e20059, 0x00000000}},  //   ndnd, निश_, _šols,
  { {0x290519bd, 0x09d4007d, 0xb4b30164, 0x00000000}},  //   _mola_, _धन्य, टली_,
  { {0x2905011c, 0x629d008e, 0x69c201d6, 0x00000000}},  //   _lola_, caso, ytoe,
  { {0x7ae00190, 0x00000000, 0x00000000, 0x00000000}},  // [3720] _ramt,   ,   ,
  { {0x2905022b, 0x2f150039, 0xe0da01ee, 0x00000000}},  //   _nola_, _våga_, _сво_,
  { {0x940c005f, 0x7ae00091, 0x7ae211b2, 0x00000000}},  //   fadə_, _pamt, tdot,
  { {0x9b2501e1, 0x69c20b38, 0x7ae2013e, 0x00000000}},  //   офіл, ttoe, udot,
  { {0x68e119be, 0x29051238, 0xd91006c6, 0x00000000}},  //   _bald, _bola_, ویر_,
  { {0xdd8f0025, 0x69c200c7, 0xd94317bc, 0x00000000}},  //   _سوف_, rtoe, печи,
  { {0x29050509, 0x69c20168, 0x6d4e14fe, 0x00000000}},  //   _dola_, stoe, _ikba,
  { {0xdc37007b, 0x69c201d6, 0x98bc007f, 0x00000000}},  //   _האלט_, ptoe, dovą_,
  { {0x68e10030, 0x629d0010, 0x6b5819bf, 0x00000000}},  //   _fald, vaso, lígo,
  { {0x68e119c0, 0x29050091, 0x18a300ed, 0x00000000}},  //   _gald, _gola_, _наум,
  { {0x629d00b0, 0x8cca013d, 0x06e00044, 0x00000000}},  //   taso, स्यो, ভাবি,
  { {0x68e1002d, 0x23a9006e, 0x00000000, 0x00000000}},  //   _zald, _किरद,   ,
  { {0x629d002d, 0x29050279, 0xdcef001a, 0x00000000}},  //   raso, _yola_, _jucă,
  { {0x463b007b, 0x629d002d, 0x777a002d, 0x00000000}},  //   _געדע, saso, _kutx,
  { {0x629d1163, 0x4ac802fb, 0x60d501aa, 0x00000000}},  //   paso, रभाव, rezm,
  { {0x6d4e01d5, 0x777a05aa, 0x332905d2, 0x00000000}},  //   _akba, _mutx, _umax_,
  { {0x246e006b, 0x777a0032, 0x3f9e01e5, 0x00000000}},  // [3730] ləm_, _lutx, átur_,
  { {0xe29f009f, 0x2b4d016c, 0x61ed0032, 0x00000000}},  //   lað_, _skec_, _iral,
  { {0x290519c1, 0xf2dc0044, 0x2b5f0011, 0x00000000}},  //   _rola_, ধারণ, _phuc_,
  { {0x68e119c2, 0xe29f009f, 0x61ed0119, 0x00000000}},  //   _sald, nað_, _kral,
  { {0x290519c3, 0x68e10089, 0x210d001c, 0x00000000}},  //   _pola_, _pald, _सकाळ_,
  { {0xa969013b, 0x68e1005f, 0xdb2300a1, 0x00000000}},  //   шила_, _qald, _کوری,
  { {0x68e10394, 0xe29f000c, 0x2b5f0011, 0x00000000}},  //   _vald, kað_, _thuc_,
  { {0x68e10dcc, 0x777a0c2f, 0xe29f000c, 0x00000000}},  //   _wald, _dutx, jað_,
  { {0x68e119c4, 0x290519c5, 0xe5760147, 0x00000000}},  //   _tald, _tola_, озы_,
  { {0xb4b30061, 0x628407ae, 0x893706dd, 0x00000000}},  //   टले_, _sfio, _اعرا,
  { {0x61ed19c6, 0x777a022b, 0x7d070059, 0x00000000}},  //   _aral, _gutx, _mojs,
  { {0x61ed0235, 0xe29f000c, 0x7bc519c7, 0x00000000}},  //   _bral, gað_, ithu,
  { {0x64a50745, 0x6f060087, 0x00000000, 0x00000000}},  //   _дала, _rokc,   ,
  { {0xe3b10647, 0x7bc500f8, 0x6f060085, 0x00000000}},  //   _قرب_, kthu, _sokc,
  { {0xa06a008b, 0x61ed066f, 0x246e006b, 0x00000000}},  //   рава_, _eral, cəm_,
  { {0x6aa90020, 0x61ed00c4, 0x7bc50146, 0x00000000}},  //   _ndef, _fral, dthu,
  { {0x7d0702c0, 0xcd2a007e, 0x7bc5005b, 0x00000000}},  // [3740] _bojs, ажае_, ethu,
  { {0x6aa900f6, 0x6b5800f6, 0x7d07012d, 0x00000000}},  //   _adef, tígo, _cojs,
  { {0x8b2601fb, 0x7bc519c8, 0x1c39007e, 0x00000000}},  //   одже, gthu, бяць_,
  { {0xa802014a, 0x39ea0cb3, 0x00000000, 0x00000000}},  //   şıkl, идео_,   ,
  { {0x6aa9018e, 0x2d4f0129, 0xd94619c9, 0x00000000}},  //   _ddef, gües_, оеди,
  { {0xed57053f, 0x3ea000f4, 0xf1bf0010, 0x00000000}},  //   _моя_, lait_, szág_,
  { {0xfbc30088, 0x6aa90009, 0x7bc50082, 0x00000000}},  //   _обро, _fdef, cthu,
  { {0x3ea000f4, 0xc6f80793, 0xd83801ed, 0x00000000}},  //   nait_, сних_, _neče_,
  { {0xe29f000c, 0xdcee19ca, 0xb17b0056, 0x00000000}},  //   vað_, _libč, rvåk,
  { {0x38c80167, 0x61ed0065, 0xdb210010, 0x00000000}},  //   _داری_, _rral, ütör,
  { {0xe29f009f, 0x06ac0055, 0x3ea00504, 0x00000000}},  //   tað_, ক্ষি, kait_,
  { {0x246e005f, 0x0665007a, 0x61ed0006, 0x00000000}},  //   rəm_, _کامپ, _pral,
  { {0xe29f000c, 0x363601fa, 0x41e40451, 0x00000000}},  //   rað_, _براس, міра,
  { {0x7bc50016, 0xe29f000c, 0x00000000, 0x00000000}},  //   ythu, sað_,   ,
  { {0x7d070059, 0xe29f000c, 0x3ea0009d, 0x00000000}},  //   _rojs, pað_, fait_,
  { {0x06ac0044, 0x2328003b, 0x00000000, 0x00000000}},  //   ক্রি, _моји_,   ,
  { {0x61ed0010, 0x753a0032, 0x3f57014a, 0x00000000}},  // [3750] _ural, ontz, lçuk_,
  { {0x7bc519cb, 0x00000000, 0x00000000, 0x00000000}},  //   tthu,   ,   ,
  { {0x7d070b54, 0x3ea003b0, 0x753a002d, 0x00000000}},  //   _vojs, bait_, intz,
  { {0x7bc50016, 0x7d070036, 0x77620082, 0x00000000}},  //   rthu, _wojs, _nhox,
  { {0x7bc50007, 0x00000000, 0x00000000, 0x00000000}},  //   sthu,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4809005e, 0x00000000, 0x00000000, 0x00000000}},  //   сейн_,   ,   ,
  { {0x753a002d, 0x6aa90190, 0x656801c3, 0x00000000}},  //   entz, _udef, emdh,
  { {0xd8381279, 0x6446027d, 0xc8f90044, 0x00000000}},  //   _reče_, şkil, _অতীত_,
  { {0x58bb0318, 0x6e200004, 0xe5761280, 0x00000000}},  //   _خارج_, _ümbe, язь_,
  { {0x6d890027, 0x3ea001e6, 0xa2e619cc, 0x00000000}},  //   _hľad, yait_, понд,
  { {0x96b8003b, 0x62810036, 0x753a002d, 0x00000000}},  //   _душу_, ślon, antz,
  { {0xd838037e, 0x2bd201f5, 0x3ea000f4, 0x00000000}},  //   _veče_, _सहभा, vait_,
  { {0x645d0163, 0xdd92026c, 0xeb08013d, 0x00000000}},  //   əsin, ہور_, _वक्त_,
  { {0x3ea019cd, 0xd2590089, 0x442102e7, 0x00000000}},  //   tait_, ļņa_, _åh_,
  { {0x673b0934, 0xdd920644, 0x04560025, 0x00000000}},  //   nnuj, فور_, _علية_,
  { {0x3ea0028c, 0xfe4308d6, 0x00e400a1, 0x00000000}},  // [3760] rait_, енто, _ہتھی,
  { {0x3ea019ce, 0x00000000, 0x00000000, 0x00000000}},  //   sait_,   ,   ,
  { {0x3ea00f91, 0xc0470011, 0x0c26025f, 0x00000000}},  //   pait_, _mượn_, џмен,
  { {0xc0470082, 0x70760014, 0x63be0056, 0x00000000}},  //   _lượn_, _واگذ, _åpne,
  { {0xceb300bd, 0xd6c30055, 0x0d83007e, 0x00000000}},  //   _איר_, ্যায, _плян,
  { {0x6f0411cc, 0xf8060088, 0x00000000, 0x00000000}},  //   ljic, зчин,   ,
  { {0x776200d9, 0x00000000, 0x00000000, 0x00000000}},  //   _phox,   ,   ,
  { {0x1ae30057, 0x6f0410c1, 0x6f1619cf, 0x00000000}},  //   _посм, njic, nkyc,
  { {0x6e24000b, 0xbb430242, 0x00000000, 0x00000000}},  //   nzib, _четк,   ,
  { {0x47d40055, 0x00000000, 0x00000000, 0x00000000}},  //   থিবী,   ,   ,
  { {0x4ae00061, 0x00000000, 0x00000000, 0x00000000}},  //   _नसाव,   ,   ,
  { {0xf6e501fb, 0x1dac007d, 0x6aa20020, 0x00000000}},  //   _оцін, _चिंत, naof,
  { {0x6f0408de, 0x87250025, 0x00000000, 0x00000000}},  //   djic, _تعلم,   ,
  { {0x6e2419d0, 0x98a7001a, 0xe3af00a1, 0x00000000}},  //   dzib, mină_, خری_,
  { {0x3d00007d, 0x6aa200e7, 0x98a70035, 0x00000000}},  //   राने_, kaof, lină_,
  { {0x6d4300ca, 0x394e01a2, 0x00000000, 0x00000000}},  //   čnam, hofs_,   ,
  { {0x63ba016c, 0xa3e402fb, 0x7b3c0eae, 0x00000000}},  // [3770] lutn, निक_, rčul,
  { {0xf1b2013d, 0xdb1c0036, 0x673b0059, 0x00000000}},  //   _जितन, _opró, znuj,
  { {0x63ba089f, 0x00000000, 0x00000000, 0x00000000}},  //   nutn,   ,   ,
  { {0xdb050065, 0xadbd007e, 0x6f04012d, 0x00000000}},  //   mshë, _камi, cjic,
  { {0xdb1c0010, 0x67200023, 0xdb050023, 0x00000000}},  //   _apró, dhmj, lshë,
  { {0x63ba19d1, 0xe9d801ff, 0xdb1c0051, 0x00000000}},  //   kutn, які_, _bpró,
  { {0x1bd4004c, 0x67d200ed, 0xdb050065, 0x00000000}},  //   _поря, воју, nshë,
  { {0xe619005e, 0x629f0023, 0x63ba19d2, 0x00000000}},  //   жди_, _neqo, dutn,
  { {0x98a7001a, 0x3dc919d3, 0xe9d000a1, 0x00000000}},  //   gină_, ntaw_, _مغل_,
  { {0x65630061, 0xe6c40107, 0xdb050065, 0x00000000}},  //   _qhnh, češć, kshë,
  { {0x2d540004, 0xdb050065, 0x78a30052, 0x00000000}},  //   päev_, jshë, manv,
  { {0x572701f7, 0x47350364, 0x98bc013e, 0x00000000}},  //   _عراق, _юнес, kově_,
  { {0xdb050065, 0xaefb0011, 0x2ee9098d, 0x00000000}},  //   eshë, _phùn, ddaf_,
  { {0x63ba04be, 0xdb050065, 0xdb1c010f, 0x00000000}},  //   butn, fshë, _sprü,
  { {0x63ba012d, 0x6f04012d, 0x00000000, 0x00000000}},  //   cutn, tjic,   ,
  { {0xdbd90181, 0xd00f00a1, 0x6e240032, 0x00000000}},  //   nçõe, گلہ_, tzib,
  { {0xdbd90181, 0xee3a0fc0, 0xaefb0011, 0x00000000}},  // [3780] içõe, цна_, _thùn,
  { {0x61e4002d, 0x5d6719d4, 0xd8380087, 0x00000000}},  //   _isil, диум_, _leča_,
  { {0x6f6600ed, 0xb6a30082, 0xdbf200b9, 0x00000000}},  //   _овоз, _phầ, příp,
  { {0x60dc0207, 0x7c65002c, 0xdb1c000a, 0x00000000}},  //   lerm, رالل, _aprò,
  { {0xa2c1007d, 0xdb1c0036, 0xfaa3007e, 0x00000000}},  //   _वास्, _spró, тачо,
  { {0x60dc19d5, 0xeb9a00d7, 0x98a7001a, 0x00000000}},  //   nerm, _миг_, vină_,
  { {0x38cb00e9, 0x6f1d0009, 0x60dc01a2, 0x00000000}},  //   تانی_, _ylsc, ierm,
  { {0x60dc02ae, 0x394e19d6, 0x98a70035, 0x00000000}},  //   herm, sofs_, tină_,
  { {0xfaa30545, 0x557419a2, 0x00000000, 0x00000000}},  //   _шато, нгит,   ,
  { {0x2fdf0046, 0x78a300d4, 0xdbd900c4, 0x00000000}},  //   ługi_, canv, açõe,
  { {0x61e4000b, 0x291e00b0, 0x798000e7, 0x00000000}},  //   _asil, _ilta_, _humw,
  { {0x63ba0897, 0x68e80292, 0x798009df, 0x00000000}},  //   rutn, _hadd, _kumw,
  { {0x60dc08d3, 0x290c0059, 0x63ba0091, 0x00000000}},  //   ferm, _koda_, sutn,
  { {0x60dc0c53, 0xdb050065, 0x660f0a5d, 0x00000000}},  //   germ, tshë, äcke,
  { {0x68e801f6, 0x61e419d7, 0x57dc0309, 0x00000000}},  //   _madd, _esil, _मनोह,
  { {0xc3280054, 0xdb050065, 0x3dc9002b, 0x00000000}},  //   _يكون_, rshë, ttaw_,
  { {0x6458021e, 0x68fa01b5, 0x8d790025, 0x00000000}},  // [3790] _hyvi, _ontd, سماء_,
  { {0x68e80066, 0x60dc008e, 0x290c19d8, 0x00000000}},  //   _nadd, cerm, _noda_,
  { {0x3dc919d9, 0x5eab0044, 0x60c50c10, 0x00000000}},  //   staw_, ঙ্গে, _ichm,
  { {0xbebb0065, 0xdd95007e, 0xfbd00014, 0x00000000}},  //   _emër, _памы, شتم_,
  { {0x290c19da, 0x3f8101a3, 0x442500d9, 0x00000000}},  //   _boda_, _huhu_, zzl_,
  { {0x290c0197, 0x3f81006c, 0x41b2013d, 0x00000000}},  //   _coda_, _kuhu_, _जिसस,
  { {0xa9270089, 0x78a300f8, 0x68e80837, 0x00000000}},  //   _režī, ranv, _dadd,
  { {0x68fa010f, 0x6aa0041d, 0x06090088, 0x00000000}},  //   _entd, _gemf, зник_,
  { {0x7afb0207, 0xb9b503ab, 0x68e808c9, 0x00000000}},  //   _inut, _سماع, _fadd,
  { {0x290c0039, 0x68e800ea, 0x7ae900b0, 0x00000000}},  //   _goda_, _gadd, _haet,
  { {0x60dc0270, 0x7afb0039, 0xdbd900c4, 0x00000000}},  //   verm, _knut, pçõe,
  { {0x78a1001c, 0x60c50093, 0x29070295, 0x00000000}},  //   _helv, _achm, ljna_,
  { {0x60dc0b25, 0xa2c102fb, 0x78a119db, 0x00000000}},  //   term, _वार्, _kelv,
  { {0x7ae9002a, 0xafe6034b, 0x61e400ca, 0x00000000}},  //   _laet, ногл, _vsil,
  { {0xb4ab001c, 0x60dc0302, 0x69cb19dc, 0x00000000}},  //   गणी_, rerm, htge,
  { {0xe456007b, 0x60dc08ed, 0x61e419dd, 0x00000000}},  //   _איצט_, serm, _tsil,
  { {0xc6920476, 0x733b0049, 0x8cb600aa, 0x00000000}},  // [37a0] טאן_, _מעקס, есеч,
  { {0x79800b3a, 0xafe600e2, 0xf4bd0044, 0x00000000}},  //   _rumw, _зоол, _অসুব,
  { {0x68e819de, 0x7ae906c0, 0x309b009b, 0x00000000}},  //   _radd, _baet, _משימ,
  { {0x6d5519df, 0x7ae90767, 0x2d920007, 0x00000000}},  //   _ekza, _caet, ppye_,
  { {0x68e8001c, 0x78a10010, 0x7ae90016, 0x00000000}},  //   _padd, _belv, _daet,
  { {0x7afb00f6, 0x68e8002b, 0x612200c4, 0x00000000}},  //   _enut, _qadd, _fôle,
  { {0xb90802d2, 0x78a104d3, 0x9d43007c, 0x00000000}},  //   _बस_, _delv, _серд,
  { {0x8b66007a, 0x7659018e, 0x68e8014f, 0x00000000}},  //   _سازم, _bywy, _wadd,
  { {0x290c19e0, 0x78a10047, 0xa84a0167, 0x00000000}},  //   _toda_, _felv, _کلام_,
  { {0x7d0e01e7, 0xb17b0039, 0x2d820145, 0x00000000}},  //   _jobs, kvår, _muke_,
  { {0x332000eb, 0x9295005e, 0x2d820238, 0x00000000}},  //   _blix_, канц, _luke_,
  { {0x60c5001f, 0x76590016, 0x3f5700d4, 0x00000000}},  //   _schm, _fywy, nçut_,
  { {0x2d8219e1, 0x3f8104cb, 0x7d0e00e0, 0x00000000}},  //   _nuke_, _suhu_, _oobs,
  { {0x78a100d4, 0xd8380087, 0x6e3b19e2, 0x00000000}},  //   _xelv, _ječo_, _žubo,
  { {0x332019e3, 0xdfd8005e, 0xbf1c013d, 0x00000000}},  //   _flix_, нът_, नसून_,
  { {0x2d8219e4, 0x61180279, 0x6122009d, 0x00000000}},  //   _buke_, _ağlı, _rôle,
  { {0x7d0e01c5, 0xe7e2013d, 0x5d5500e3, 0x00000000}},  // [37b0] _bobs, _कैसा_, вкат,
  { {0x2d82071e, 0x7ae90016, 0x6122009d, 0x00000000}},  //   _duke_, _saet, _pôle,
  { {0x78a119e5, 0xe3b8005d, 0x7ae90ac2, 0x00000000}},  //   _relv, nrı_, _paet,
  { {0x78a119e6, 0x29c9008e, 0x612200c4, 0x00000000}},  //   _selv, túa_, _vôle,
  { {0x7d0e00f6, 0x09e50143, 0x78a10835, 0x00000000}},  //   _fobs, толн, _pelv,
  { {0x69cb0506, 0x88bc00b9, 0x7ae90016, 0x00000000}},  //   rtge, _směr, _waet,
  { {0x78a100b0, 0x69cb19e7, 0x2d82012d, 0x00000000}},  //   _velv, stge, _zuke_,
  { {0xf77101af, 0x26c619e8, 0x78a10116, 0x00000000}},  //   جات_, _ccoo_, _welv,
  { {0x9fb600b9, 0x645c0e4d, 0x99d403e6, 0x00000000}},  //   vřít_, ürin, _متلا,
  { {0xe9750380, 0x26c60026, 0x2ca301f3, 0x00000000}},  //   _شهاد, _ecoo_, _jejd_,
  { {0xa8020279, 0xa91d0091, 0x3f57009d, 0x00000000}},  //   şırl, _tužb, nçus_,
  { {0x7659018e, 0x6f0f0197, 0x236901aa, 0x00000000}},  //   _tywy, _nocc, _chaj_,
  { {0xf1bf0181, 0x3ea200d9, 0x00000000, 0x00000000}},  //   guá_, _rekt_,   ,
  { {0x2d821434, 0x3ea201e5, 0x2ca301f3, 0x00000000}},  //   _ruke_, _sekt_, _nejd_,
  { {0x10a319e9, 0x6f0f0207, 0x7d0e00c4, 0x00000000}},  //   рисн, _bocc, _robs,
  { {0x6f0f0207, 0x2d82011c, 0x22160269, 0x00000000}},  //   _cocc, _puke_, _афор,
  { {0x6f0f0207, 0xe7bd0044, 0xb17b0039, 0x00000000}},  // [37c0] _docc, _আনোয, rvår,
  { {0xa3b80061, 0x00000000, 0x00000000, 0x00000000}},  //   _चिम_,   ,   ,
  { {0xa7fc005a, 0xb17b00ea, 0x00000000, 0x00000000}},  //   _azın, mvåp,   ,
  { {0x6f0f0197, 0x98a70a67, 0x2d820253, 0x00000000}},  //   _gocc, minę_, _tuke_,
  { {0x98a70a67, 0x3f5702d0, 0x00000000, 0x00000000}},  //   linę_, rçut_,   ,
  { {0xa2d90061, 0x6f0f0197, 0x7b3c0107, 0x00000000}},  //   _फॉन्, _zocc, jčuv,
  { {0x6a8601f9, 0xec7709da, 0xb8da03d7, 0x00000000}},  //   _алба, _апр_, _आए_,
  { {0x6d5e0472, 0x3d000061, 0x8c4302dc, 0x00000000}},  //   llpa, रावे_, _тесе,
  { {0xd838012d, 0xdb110048, 0x00000000, 0x00000000}},  //   _tečo_, _ógán,   ,
  { {0xe29a001d, 0xa802005f, 0x660f0039, 0x00000000}},  //   _đưa_, şıql, äcka,
  { {0x33750081, 0x91820082, 0xd70619ea, 0x00000000}},  //   лгор, yện_, _изжи,
  { {0x61f60030, 0xe61a003b, 0xe3b8014a, 0x00000000}},  //   _bryl, _оде_, rrı_,
  { {0x6f0f0207, 0xd05d006b, 0x00000000, 0x00000000}},  //   _rocc, əyən,   ,
  { {0x6f0f19eb, 0x2f1501c9, 0x61f60016, 0x00000000}},  //   _socc, _lågt_, _dryl,
  { {0x443a006c, 0x6f0f0026, 0xb227000c, 0x00000000}},  //   _äp_, _pocc, _bræð,
  { {0x5eb401e0, 0x63ba02aa, 0x6d5e054e, 0x00000000}},  //   ийст, mrtn, elpa,
  { {0x6f0f0026, 0x6ca70a1e, 0x61f604e7, 0x00000000}},  // [37d0] _vocc, вреж, _gryl,
  { {0x67220065, 0x98a70a62, 0x01fa0097, 0x00000000}},  //   _lloj, binę_, _נפתל,
  { {0xb227009f, 0x6f0f0207, 0x30a4007e, 0x00000000}},  //   _fræð, _tocc, _трыв,
  { {0x27f901dc, 0x3f57009d, 0xb227000c, 0x00000000}},  //   _čsn_, rçus_, _græð,
  { {0x3ea901a3, 0x6eba009b, 0x2ca30066, 0x00000000}},  //   maat_, _אזרח, _tejd_,
  { {0xeb9304e8, 0x18690265, 0x3ea90007, 0x00000000}},  //   _نظر_, нали_, laat_,
  { {0x98a2007c, 0x00000000, 0x00000000, 0x00000000}},  //   щище,   ,   ,
  { {0xa6e5012d, 0xdb1c0210, 0x307c0049, 0x00000000}},  //   ужил, _sprö, ואונ,
  { {0xe579017a, 0xaefb0045, 0x00000000, 0x00000000}},  //   нзи_, _chùi,   ,
  { {0x499000a1, 0x3ea901d6, 0x00000000, 0x00000000}},  //   _بیور, haat_,   ,
  { {0x6722008e, 0x656f013e, 0x80df0044, 0x00000000}},  //   _floj, ůcho, মাঞ্,
  { {0x15f501f7, 0x61f60039, 0x6b58004a, 0x00000000}},  //   _مستح, _pryl, lígr,
  { {0x3ea90277, 0x63ba00bb, 0xba3d013e, 0x00000000}},  //   daat_, artn, _zdůr,
  { {0x64a519ec, 0x25ad08a9, 0x98a70006, 0x00000000}},  //   _сака, msel_, tinę_,
  { {0x25ad19ed, 0x3ea90145, 0x7a2a0010, 0x00000000}},  //   lsel_, faat_, _köté,
  { {0x14cf01f5, 0x6d4719ee, 0x543a0049, 0x00000000}},  //   त्रण, _ajja, _רעקא,
  { {0x201e0209, 0x25ad114e, 0x0e660887, 0x00000000}},  // [37e0] šti_, nsel_, укан,
  { {0x3ea9001c, 0x319b00a3, 0x25ad01d6, 0x00000000}},  //   aaat_, _רבינ, isel_,
  { {0xf536007b, 0x69db0211, 0x25e5013d, 0x00000000}},  //   נטער_, _apue, _जैसी_,
  { {0x3ea919ef, 0x25ad014a, 0x0b46007e, 0x00000000}},  //   caat_, ksel_, ынен,
  { {0x99d30054, 0xa91d19f0, 0x69db0146, 0x00000000}},  //   متوا, _suža, _cpue,
  { {0x25ad05a6, 0x5f260044, 0xe9730025, 0x00000000}},  //   dsel_, _যদিও_, مهند,
  { {0x25ad021f, 0xd90d0063, 0xdce60006, 0x00000000}},  //   esel_, بیل_, _sukė,
  { {0xc6f819f1, 0x291c19f2, 0x7f4419f3, 0x00000000}},  //   тних_, skva_, nniq,
  { {0x25ad02e7, 0x7ae2087c, 0x00000000, 0x00000000}},  //   gsel_, meot,   ,
  { {0x7ae219f4, 0x2956005e, 0x80d600e8, 0x00000000}},  //   leot, _събр, म्मे,
  { {0x6134006b, 0x69c20016, 0xa91d050f, 0x00000000}},  //   _gülə, luoe, _kužn,
  { {0xa91d16d0, 0x78aa001c, 0xf1bf0010, 0x00000000}},  //   _južn, lafv, szám_,
  { {0xa5960265, 0x3ea90007, 0xd5ae00a1, 0x00000000}},  //   _срещ, vaat_, _عہد_,
  { {0xa2c10164, 0x7bdc00bb, 0x98a700b9, 0x00000000}},  //   _वाक्, _opru, dině_,
  { {0x3ea9046a, 0x753a0ec8, 0xceb4006b, 0x00000000}},  //   taat_, mitz, rkən_,
  { {0x753a120d, 0xa91d0091, 0x3e07005e, 0x00000000}},  //   litz, _nužn, лязв,
  { {0x7ae2128e, 0x3ea9049b, 0xdb1e00f4, 0x00000000}},  // [37f0] deot, raat_, cupé,
  { {0x753a04bd, 0x3ea904be, 0xd7f8001a, 0x00000000}},  //   nitz, saat_, _oră_,
  { {0x3ea900b0, 0x00000000, 0x00000000, 0x00000000}},  //   paat_,   ,   ,
  { {0x753a19f5, 0x8f9a009b, 0x7f440129, 0x00000000}},  //   hitz, _שירי, cniq,
  { {0x753a022b, 0xa91d0091, 0x00000000, 0x00000000}},  //   kitz, _dužn,   ,
  { {0x25ad0190, 0x6f0d0091, 0x7a2a0010, 0x00000000}},  //   vsel_, ljac, _söté,
  { {0x753a002d, 0x6e2d06b9, 0x6d450011, 0x00000000}},  //   ditz, lzab, mnha,
  { {0x6f0d0091, 0x475902dc, 0x00000000, 0x00000000}},  //   njac, ърля_,   ,
  { {0xd706007c, 0x6e2d04de, 0x88c7023c, 0x00000000}},  //   рные_, nzab, _متال,
  { {0x25ad19f6, 0x2bc90061, 0x753a002d, 0x00000000}},  //   rsel_, ांपा, gitz,
  { {0x68e3022b, 0x25ad0010, 0x612b0010, 0x00000000}},  //   mend, ssel_, _külf,
  { {0x2498005d, 0x6f0d0107, 0x45d500ed, 0x00000000}},  //   ırma_, jjac, _водс,
  { {0x6f0d0107, 0x753a15ed, 0x442c0036, 0x00000000}},  //   djac, bitz, azd_,
  { {0xf48701a4, 0x628f000a, 0x98a700b9, 0x00000000}},  //   _судн, acco, vině_,
  { {0x2bb10046, 0x6d570a86, 0x68fc008e, 0x00000000}},  //   jąc_, doxa, _órde,
  { {0x68e30004, 0x6f0d0093, 0x6d450052, 0x00000000}},  //   hend, gjac, enha,

  { {0x63a3018e, 0x661b04cb, 0xa91d0091, 0x00000000}},  // [3800] _hwnn, nyuk, _ružn,
  { {0x68e3004e, 0x4103007e, 0xa91d0fd0, 0x00000000}},  //   jend, _дзьв, _sužn,
  { {0x68e3068f, 0x7ae2002d, 0x6e2d0032, 0x00000000}},  //   dend, teot, azab,
  { {0x753a022b, 0x6f0d0036, 0x98a700b9, 0x00000000}},  //   zitz, cjac, pině_,
  { {0x2bd2024c, 0x272a001d, 0xdcfc002b, 0x00000000}},  //   _सहका, _hùng_, _jirċ,
  { {0x68e303a1, 0x8b96007c, 0x7c660439, 0x00000000}},  //   gend, _врач, _نازل,
  { {0x8c43041f, 0xa91d0091, 0x753a0fc3, 0x00000000}},  //   _дере, _tužn, vitz,
  { {0x6d5c0059, 0x272a0082, 0x753a01a2, 0x00000000}},  //   _hkra, _mùng_, witz,
  { {0x753a0ec8, 0x5506007e, 0x272a0011, 0x00000000}},  //   titz, ачна, _lùng_,
  { {0x68e30198, 0xd8380521, 0x612b0276, 0x00000000}},  //   cend, _leči_, _zülf,
  { {0x753a19f7, 0x6e2d0207, 0x612b010e, 0x00000000}},  //   ritz, zzab, _hülg,
  { {0x753a0fa5, 0xd6d90036, 0x612b006c, 0x00000000}},  //   sitz, koły_, _külg,
  { {0x78a80047, 0xf5940054, 0x6d45018e, 0x00000000}},  //   _kedv, _التج, ynha,
  { {0x78a80091, 0x442c0009, 0x272a0011, 0x00000000}},  //   _jedv, pzd_, _bùng_,
  { {0x272a001d, 0x4ea701f9, 0x7467005e, 0x00000000}},  //   _cùng_, ираа, _кръв_,
  { {0x68e319f8, 0x272a001d, 0x6d5c19f9, 0x00000000}},  //   zend, _dùng_, _akra,
  { {0x68e30211, 0x8cc2006e, 0x6d5700e5, 0x00000000}},  // [3810] yend, _लाखो, toxa,
  { {0x61ed011c, 0x68e31824, 0xa91d0142, 0x00000000}},  //   _isal, xend, _ružo,
  { {0x68e319fa, 0x6d450abe, 0xee870a78, 0x00000000}},  //   vend, rnha, _выго,
  { {0x6d5c011f, 0x28c9001c, 0x68e30dcc, 0x00000000}},  //   _ekra, _राहि, wend,
  { {0xe9190088, 0x61ed0066, 0x3df4007e, 0x00000000}},  //   лоді_, _jsal, _дзяс,
  { {0x98a2005e, 0x61ed0020, 0xf1bf0b33, 0x00000000}},  //   пише, _msal, irá_,
  { {0xe73901ab, 0x60da010e, 0x67290023, 0x00000000}},  //   лек_, õtmi, thej,
  { {0x61ed08b2, 0x7bc511b3, 0xf1bf19fb, 0x00000000}},  //   _osal, muhu, krá_,
  { {0x68e319fc, 0x612b0047, 0x7bc50022, 0x00000000}},  //   pend, _küld, luhu,
  { {0xb8fc0055, 0x6aa90662, 0xf1bf19fd, 0x00000000}},  //   _তো_, _heef, drá_,
  { {0x61ed01a3, 0xd8860014, 0x7bc50058, 0x00000000}},  //   _asal, _اهمی, nuhu,
  { {0x272a0082, 0x00000000, 0x00000000, 0x00000000}},  //   _rùng_,   ,   ,
  { {0x7bc503b0, 0x61ed0047, 0x753d0047, 0x00000000}},  //   huhu, _csal, észs,
  { {0x6aa9015c, 0x7bc519fe, 0x00000000, 0x00000000}},  //   _leef, kuhu,   ,
  { {0x798119ff, 0x61ed1a00, 0xf1bf0b33, 0x00000000}},  //   _milw, _esal, ará_,
  { {0xf1bf1a01, 0x272a001d, 0x84070010, 0x00000000}},  //   brá_, _vùng_, _előí,
  { {0x2fdf0035, 0x1d8a0025, 0xc5880082, 0x00000000}},  // [3820] ăuga_, ائري_, _lồn_,
  { {0x272a0011, 0xdca61a02, 0x6b80014a, 0x00000000}},  //   _tùng_, сажи, _simg,
  { {0xb53a0049, 0xa6ad0044, 0x25bf008a, 0x00000000}},  //   נגעש, _গানট, hrul_,
  { {0x7981005b, 0x00000000, 0x00000000, 0x00000000}},  //   _ailw,   ,   ,
  { {0x3ea01a03, 0x28c9006e, 0x213a0085, 0x00000000}},  //   mbit_, _राशि, _kmph_,
  { {0x25bf1a04, 0xc5880011, 0x612b005d, 0x00000000}},  //   drul_, _bồn_, _güld,
  { {0x93bc001a, 0x79811a05, 0x6ab70044, 0x00000000}},  //   nzăt, _dilw, _ইউরো,
  { {0xbc1b00b6, 0x6aa902ae, 0xa3ab013d, 0x00000000}},  //   _גולש, _geef, गठन_,
  { {0xe9a30080, 0xc6f70147, 0x79811a06, 0x00000000}},  //   _натп, сных_, _filw,
  { {0xd90e02fd, 0x3f8210c6, 0x73d80745, 0x00000000}},  //   _سیب_, _liku_, адор_,
  { {0x61ed1a07, 0x25bf0035, 0x3ea00058, 0x00000000}},  //   _ssal, arul_, kbit_,
  { {0x25bf0035, 0x3f8216aa, 0x61ed1a08, 0x00000000}},  //   brul_, _niku_, _psal,
  { {0xd7570025, 0x3ea00203, 0x25bf001a, 0x00000000}},  //   _النت_, dbit_, crul_,
  { {0xecc7013d, 0xdcfc15ad, 0xf1bf1a09, 0x00000000}},  //   _लाइफ, _birč, rrá_,
  { {0x7d150387, 0x653b009b, 0x3f821a0a, 0x00000000}},  //   _rozs, _תעוד, _biku_,
  { {0x61ed1a0b, 0xdcfc0173, 0xa91d01ed, 0x00000000}},  //   _tsal, _dirč, _ružm,
  { {0x9c870054, 0x61ed1a0c, 0x3f820065, 0x00000000}},  // [3830] مشاه, _usal, _diku_,
  { {0x7bc5000b, 0xd13100a6, 0x30a7072b, 0x00000000}},  //   tuhu, _آمد_, _урив,
  { {0x3ea00838, 0x00000000, 0x00000000, 0x00000000}},  //   bbit_,   ,   ,
  { {0x7bc5000b, 0x79810007, 0xd9f90d51, 0x00000000}},  //   ruhu, _silw, инец_,
  { {0x7bc50020, 0xdaa80088, 0xbddb0129, 0x00000000}},  //   suhu, свід_, _exèr,
  { {0x2d99021e, 0x27951a0d, 0x7bc51a0e, 0x00000000}},  //   _itse_, ошир, puhu,
  { {0x25a6041d, 0x612b014a, 0x6aa900bb, 0x00000000}},  //   _awol_, _güle, _teef,
  { {0xf38900ad, 0x2d8b037e, 0x25bf001a, 0x00000000}},  //   _bản_, _kuce_, trul_,
  { {0x2d8b05fa, 0xf3890011, 0xe616007c, 0x00000000}},  //   _juce_, _cản_, жды_,
  { {0x45190401, 0x2d8301aa, 0xc5880011, 0x00000000}},  //   рция_, _jije_, _tồn_,
  { {0x2d8b0207, 0x3eb900b9, 0x2d830065, 0x00000000}},  //   _luce_, _odst_, _mije_,
  { {0x2d99006c, 0x00000000, 0x00000000, 0x00000000}},  //   _otse_,   ,   ,
  { {0x3f8201b1, 0xfe7f1a0f, 0x10f6005e, 0x00000000}},  //   _riku_, _maïs_, оявя,
  { {0x3f82000b, 0xe7dd0201, 0xf992019b, 0x00000000}},  //   _siku_, _महाप, ורך_,
  { {0x3ea01a10, 0x612b0279, 0x3f820288, 0x00000000}},  //   tbit_, _bülb, _piku_,
  { {0xf3890011, 0x6d4b009d, 0x1f6605b8, 0x00000000}},  //   _hảo_, égan, ікам,
  { {0x3f82009f, 0x3ea0033b, 0x612b1a11, 0x00000000}},  // [3840] _viku_, rbit_, _süle,
  { {0x2d830107, 0x2d8b001a, 0x3ea00276, 0x00000000}},  //   _cije_, _duce_, sbit_,
  { {0x2d8307ed, 0x3f6a00aa, 0x3f8201c5, 0x00000000}},  //   _dije_, _вино_, _tiku_,
  { {0x2d990197, 0x27f8000c, 0xbddb00d4, 0x00000000}},  //   _ftse_, _árni_, _exèq,
  { {0xe8940b21, 0x93bc001a, 0x2d831a12, 0x00000000}},  //   паль, nzăr, _fije_,
  { {0x6d89012d, 0x2d83000a, 0x25a6002b, 0x00000000}},  //   _džad, _gije_, _rwol_,
  { {0xf38900ad, 0xb8f20164, 0xf72a0a1e, 0x00000000}},  //   _sản_, _वा_, иций_,
  { {0x4b3400a2, 0xdb050210, 0xaad10061, 0x00000000}},  //   _عکاس, gshä, _हायक,
  { {0xf389001d, 0x6aa20035, 0x7afd1a13, 0x00000000}},  //   _bảo_, mbof, _ósta,
  { {0x61300002, 0x37e6007c, 0x01d00044, 0x00000000}},  //   _hälf, _мозг, িবাদ,
  { {0xd7ef0054, 0x2cfb01ce, 0x00000000, 0x00000000}},  //   _لكل_, בליא,   ,
  { {0x51870a30, 0xf3890011, 0x98bc0006, 0x00000000}},  //   жува, _tản_, tovė_,
  { {0x3eab0061, 0x69c2040f, 0x00000000, 0x00000000}},  //   _rect_, nroe,   ,
  { {0x3eab1290, 0x2d8b00b9, 0x98bc0006, 0x00000000}},  //   _sect_, _ruce_, rovė_,
  { {0x69c200b5, 0x2d8b1a14, 0x656f009d, 0x00000000}},  //   hroe, _suce_, îche,
  { {0x2d8301aa, 0x2bc90061, 0x2d8b009d, 0x00000000}},  //   _sije_, ांसा, _puce_,
  { {0x2d830091, 0x395c0089, 0xa80201df, 0x00000000}},  // [3850] _pije_, kovs_, ğıyl,
  { {0x2d8b0107, 0x459b0049, 0xf3890082, 0x00000000}},  //   _vuce_, יסמע, _xảo_,
  { {0xd2510014, 0x2d830065, 0x69c2046a, 0x00000000}},  //   _زنگ_, _vije_, eroe,
  { {0xf4130097, 0x69c20016, 0xa91d07e4, 0x00000000}},  //   ופע_, froe, _tužk,
  { {0x69c20100, 0x2b4d0065, 0x2d831a15, 0x00000000}},  //   groe, _vjec_, _tije_,
  { {0xa91d016e, 0x00000000, 0x00000000, 0x00000000}},  //   _kuži,   ,   ,
  { {0xdb050210, 0xb886000c, 0x00000000, 0x00000000}},  //   tshä, _svíþ,   ,
  { {0x69c20168, 0xa3bb013d, 0xf9890076, 0x00000000}},  //   broe, ेंस_, _هنري_,
  { {0x3d000061, 0xa91d0062, 0x00000000, 0x00000000}},  //   राचे_, _luži,   ,
  { {0xc588001d, 0xa8a70088, 0x799b0058, 0x00000000}},  //   _gồm_, _фрак, _ituw,
  { {0x7bd70032, 0x00000000, 0x00000000, 0x00000000}},  //   ntxu,   ,   ,
  { {0x26dd0061, 0x91e60098, 0xd6d90036, 0x00000000}},  //   _ubwo_, поме, biła_,
  { {0x6130006c, 0x6d890027, 0xf3890082, 0x00000000}},  //   _jälg, _zľav, _tảo_,
  { {0x867a00b6, 0x92ac0044, 0x6d4b009d, 0x00000000}},  //   _פרסו, খলে_, égal,
  { {0x645c006c, 0xa06a16b6, 0x00000000, 0x00000000}},  //   ürit, сава_,   ,
  { {0xa91d1434, 0x00000000, 0x00000000, 0x00000000}},  //   _duži,   ,   ,
  { {0x6130010e, 0x00000000, 0x00000000, 0x00000000}},  // [3860] _nälg,   ,   ,
  { {0x4d6301f9, 0xd00f00a1, 0xa91d050f, 0x00000000}},  //   екув, خلہ_, _fuži,
  { {0x711b007b, 0xa7fc038c, 0x28d2013d, 0x00000000}},  //   _הויפ, _ayın, _साबि,
  { {0x69c20129, 0x6d890107, 0x7d070087, 0x00000000}},  //   troe, _džab, _enjs,
  { {0x61300039, 0xc333009b, 0x395c01c5, 0x00000000}},  //   _välf, עוד_, tovs_,
  { {0x612b0004, 0x69c20129, 0x672b000c, 0x00000000}},  //   _küla, rroe, _algj,
  { {0xfaa6012b, 0x8b66025a, 0xd6d90036, 0x00000000}},  //   _наво, _فارم, wiła_,
  { {0xf389001d, 0x96ea0088, 0x499400a1, 0x00000000}},  //   _cảm_, ська_, _قیصر,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x79b700a0, 0x672b0146, 0x00000000, 0x00000000}},  //   _מלמד_, _elgj,   ,
  { {0x61e41a16, 0x7ae000fa, 0xd6d900b4, 0x00000000}},  //   _apil, _kbmt, siła_,
  { {0x6d5e0107, 0xa91d0aab, 0xd16d00e5, 0x00000000}},  //   hopa, _ruži, _fraț,
  { {0x637f001e, 0xa91d19f0, 0xf67a0014, 0x00000000}},  //   _jūni, _suži, _امشب_,
  { {0xf67b0104, 0x6d5e04eb, 0x661d1a17, 0x00000000}},  //   _האדמ, jopa, äske,
  { {0x6d5e0211, 0x04db009b, 0x00000000, 0x00000000}},  //   dopa, _הקול,   ,
  { {0x65680039, 0x657a0270, 0x7ae4010e, 0x00000000}},  //   lldh, lmth, õitl,
  { {0xbf1d024c, 0x78830010, 0x3200000a, 0x00000000}},  // [3870] _नवीन_, _kívü, _griy_,
  { {0xa91d037e, 0x6d5e01d6, 0xfd47007e, 0x00000000}},  //   _tuži, gopa, чэбн,
  { {0xa022006c, 0x799b00bb, 0x00000000, 0x00000000}},  //   ööta, _stuw,   ,
  { {0x7bd7002d, 0xceeb0123, 0x1b19007e, 0x00000000}},  //   rtxu, _اردن_, ўжды_,
  { {0x6b9c00ca, 0xa2c0006e, 0x27310082, 0x00000000}},  //   _etrg, _वयस्, _háng_,
  { {0x5d850167, 0x61300894, 0x00000000, 0x00000000}},  //   _زلزل, _välg,   ,
  { {0x81e30044, 0x6e20006c, 0x612b006b, 0x00000000}},  //   নটি_, _ümbr, _xüla,
  { {0x6604040d, 0x65680f7a, 0x27310082, 0x00000000}},  //   _šika, eldh, _máng_,
  { {0x27311877, 0x06090088, 0x26cd00b4, 0x00000000}},  //   _láng_, інок_, rgeo_,
  { {0x81e30044, 0x7aeb010f, 0xe91a00a1, 0x00000000}},  //   নটা_, legt, _ورلڈ_,
  { {0x61e41a18, 0xa3a80061, 0x69d9010f, 0x00000000}},  //   _spil, खील_, ltwe,
  { {0xe2970454, 0x6130006c, 0x59d1007d, 0x00000000}},  //   маю_, _mäle, _समार,
  { {0x69d909d0, 0x6d5e0020, 0x7bc5010f, 0x00000000}},  //   ntwe, yopa, hrhu,
  { {0x69d9054e, 0xafe6041f, 0x212c0051, 0x00000000}},  //   itwe, могл, ódh_,
  { {0xe0d20014, 0x6d5e00b0, 0x00000000, 0x00000000}},  //   _یزد_, vopa,   ,
  { {0xf412009b, 0x27310011, 0xdbc6006c, 0x00000000}},  //   _יפו_, _dáng_, _köög,
  { {0x6d5e00b0, 0x6b8e086a, 0x3eb200e0, 0x00000000}},  // [3880] topa, _subg, rayt_,
  { {0xa06a072b, 0x41760014, 0x28c9013d, 0x00000000}},  //   _мапа_, _تابس, _रागि,
  { {0x6d5e1a19, 0x5fe2001c, 0x61300073, 0x00000000}},  //   ropa, _पहिल, _väld,
  { {0x69d91515, 0x4a461a1a, 0x6d5e1a1b, 0x00000000}},  //   ftwe, мнев, sopa,
  { {0xceb300b6, 0x6d5e0020, 0x637612c5, 0x00000000}},  //   _שיש_, popa, mánd,
  { {0xfbc60152, 0x63761a1c, 0xf8061523, 0x00000000}},  //   _обго, lánd, дчин,
  { {0xa91d0006, 0x6376004a, 0x99920036, 0x00000000}},  //   _nužu, cáng, ódła_,
  { {0xc588001d, 0x6376008e, 0x69cb00e5, 0x00000000}},  //   _hồi_, nánd, buge,
  { {0xbb4301fc, 0x69d90036, 0x6e241a1d, 0x00000000}},  //   _ретк, ctwe, nyib,
  { {0x7d1c0085, 0x6376004a, 0x00000000, 0x00000000}},  //   _jors, hánd,   ,
  { {0x7d1c016e, 0xd6cf00e3, 0xc5880082, 0x00000000}},  //   _mors, _ит_, _mồi_,
  { {0x3d0503d7, 0x7d1c028c, 0x63761a1e, 0x00000000}},  //   _होने_, _lors, jánd,
  { {0x2731001d, 0x7d1c0100, 0x660f0039, 0x00000000}},  //   _sáng_, _oors, äckt,
  { {0x63880263, 0x7d1c0292, 0x61fd0030, 0x00000000}},  //   tènè, _nors, rvsl,
  { {0x69cb010f, 0xc5880011, 0xdfd8005e, 0x00000000}},  //   zuge, _nồi_, мът_,
  { {0x66020387, 0x6376008e, 0x33180025, 0x00000000}},  //   _krok, gánd, _يزيد_,
  { {0x171b007b, 0x93780151, 0x6d58016c, 0x00000000}},  // [3890] קומע, _تصور_, čvan,
  { {0x7d1c0198, 0xc5880011, 0x2d871a1f, 0x00000000}},  //   _cors, _bồi_, öne_,
  { {0xe3b8027d, 0xd0110070, 0xe1ff12c5, 0x00000000}},  //   nsı_, _صلح_, lvó_,
  { {0x0f2701fb, 0x6602022b, 0x6376008e, 0x00000000}},  //   _цьом, _orok, cánd,
  { {0x7d1c004e, 0xdddd0046, 0x7aeb0007, 0x00000000}},  //   _fors, _wysł, regt,
  { {0x69cb1a20, 0x7d1c1156, 0x69d90270, 0x00000000}},  //   ruge, _gors, rtwe,
  { {0x69d90007, 0x6d45006a, 0x63761a21, 0x00000000}},  //   stwe, miha, láne,
  { {0x6d450149, 0xf7710426, 0x660200ab, 0x00000000}},  //   liha, دات_, _brok,
  { {0x2cb10010, 0x00000000, 0x00000000, 0x00000000}},  //   _kezd_,   ,   ,
  { {0xf389001d, 0x6d45000c, 0xf9920104, 0x00000000}},  //   _hải_, niha, _ערב_,
  { {0x776905d2, 0x6b890010, 0x93460147, 0x00000000}},  //   plex, _kieg, енне,
  { {0x6f1d001c, 0x6d4506ba, 0x6602068f, 0x00000000}},  //   _nosc, hiha, _frok,
  { {0x6b891a22, 0x6d45011c, 0xe5b4007e, 0x00000000}},  //   _mieg, kiha, _айчы,
  { {0x6b89001f, 0x412a01fb, 0x6d4500e7, 0x00000000}},  //   _lieg, чого_, jiha,
  { {0x63760211, 0xd4660e85, 0x6d4501a3, 0x00000000}},  //   tánd, _пише_, diha,
  { {0xc588001d, 0x6b891a23, 0x6f1d0207, 0x00000000}},  //   _rồi_, _nieg, _cosc,
  { {0x63761a24, 0x612b006c, 0x6f1d16b8, 0x00000000}},  // [38a0] ránd, _küll, _dosc,
  { {0x1016007e, 0x98a70006, 0x6376008e, 0x00000000}},  //   _зьмя, minė_, sánd,
  { {0x7d1c001f, 0x6f1d0c42, 0x6b891a25, 0x00000000}},  //   _vors, _fosc, _bieg,
  { {0x28d20201, 0x6b89008e, 0xb6050087, 0x00000000}},  //   _साहि, _cieg, _košč,
  { {0x6b891a26, 0x7d1c0239, 0xf38a0011, 0x00000000}},  //   _dieg, _tors, _cải_,
  { {0x442511d1, 0xf38a0082, 0xc5880082, 0x00000000}},  //   kyl_, _dải_, _tồi_,
  { {0xb6050087, 0x00000000, 0x00000000, 0x00000000}},  //   _lošč,   ,   ,
  { {0x442515d6, 0xf38a0082, 0x6b8901f3, 0x00000000}},  //   dyl_, _fải_, _gieg,
  { {0x79880066, 0x656100c4, 0x2d8a1a27, 0x00000000}},  //   _tidw, folh, _kibe_,
  { {0x645d005f, 0x6b891a28, 0xef210089, 0x00000000}},  //   əsiz, _zieg, _zaļā_,
  { {0x5335072b, 0x290c0145, 0x44250544, 0x00000000}},  //   вент, _inda_, gyl_,
  { {0x6602016e, 0x291e18be, 0x6d4500e7, 0x00000000}},  //   _trok, _hota_, ziha,
  { {0x291e04fa, 0x8c240055, 0x612b0fb5, 0x00000000}},  //   _kota_, _যেমন_, _füll,
  { {0x656102d5, 0x442500b9, 0x291e00b0, 0x00000000}},  //   colh, byl_, _jota_,
  { {0xb4be0201, 0xf2b00055, 0x291e002d, 0x00000000}},  //   ेली_, _কারণ, _mota_,
  { {0x6d450009, 0x628d1a29, 0x63761a2a, 0x00000000}},  //   wiha, _ugao, táne,
  { {0x6d450475, 0x290c006b, 0x6b8900dd, 0x00000000}},  // [38b0] tiha, _onda_, _rieg,
  { {0x6b891a2b, 0x63761a2c, 0x612b006c, 0x00000000}},  //   _sieg, ráne, _külm,
  { {0x6b89001e, 0x63ba129a, 0x6f1d0207, 0x00000000}},  //   _pieg, nstn, _tosc,
  { {0x290c020c, 0x6d450127, 0x6b8901d5, 0x00000000}},  //   _anda_, siha, _qieg,
  { {0x291e0307, 0x6b89001e, 0x6d45011c, 0x00000000}},  //   _bota_, _vieg, piha,
  { {0x291e0bc0, 0xf38a0011, 0x6b8901de, 0x00000000}},  //   _cota_, _vải_, _wieg,
  { {0x6b890f68, 0x291e07e8, 0x63ba1a2d, 0x00000000}},  //   _tieg, _dota_, jstn,
  { {0x3d050201, 0x290c00cd, 0x0609012b, 0x00000000}},  //   _होते_, _enda_, дник_,
  { {0x4425018e, 0xceb400a3, 0x3f8b0035, 0x00000000}},  //   wyl_, ניץ_, _micu_,
  { {0x7afb1a2e, 0x69db001c, 0x44250007, 0x00000000}},  //   _haut, _ique, tyl_,
  { {0x394702d0, 0x7afb021e, 0x645800f6, 0x00000000}},  //   mins_, _kaut, _cxvi,
  { {0x7afb1a2f, 0x98a7010a, 0x39471a30, 0x00000000}},  //   _jaut, tinė_, lins_,
  { {0x7afb0020, 0x44250403, 0x291e000a, 0x00000000}},  //   _maut, syl_, _yota_,
  { {0x3dc9002b, 0x3947153c, 0x66060018, 0x00000000}},  //   draw_, nins_, ække,
  { {0xa0670216, 0x2d8a0091, 0x612b1a31, 0x00000000}},  //   вара_, _ribe_, _gülm,
  { {0x7afb00b0, 0x69db00f6, 0xe4560049, 0x00000000}},  //   _naut, _oque, _שיקט_,
  { {0x3dc90719, 0x2d8a18c8, 0xf1bf0010, 0x00000000}},  // [38c0] graw_, _pibe_, lyán_,
  { {0xad9b1a32, 0x39471a33, 0x7afb00e0, 0x00000000}},  //   _trún, jins_, _aaut,
  { {0x69db1a34, 0x3ea90039, 0x39471a35, 0x00000000}},  //   _aque, bbat_, dins_,
  { {0x291e1a36, 0x3dc91a37, 0x7afb0585, 0x00000000}},  //   _sota_, braw_, _caut,
  { {0x7fe2006e, 0x2b460051, 0x39470def, 0x00000000}},  //   _पहुँ, rioc_, fins_,
  { {0xdca30242, 0x394700ab, 0x3f8b0ce0, 0x00000000}},  //   _вари, gins_, _zicu_,
  { {0x6b660256, 0x7afb00f4, 0x69db03e2, 0x00000000}},  //   _аква, _faut, _eque,
  { {0x8a0600aa, 0x7afb010a, 0xb6f401fc, 0x00000000}},  //   _избе, _gaut, узиј,
  { {0x291e1a38, 0xc6f70783, 0x7ae20203, 0x00000000}},  //   _tota_, тных_, mfot,
  { {0xb4be0201, 0x394700f4, 0x3ea9093e, 0x00000000}},  //   ेले_, cins_, zbat_,
  { {0x3cfa03d7, 0x332000d4, 0x7afb00d2, 0x00000000}},  //   _उसने_, _boix_, _yaut,
  { {0x7ae2054e, 0x46a6005e, 0x63760010, 0x00000000}},  //   nfot, _радв, vánc,
  { {0x6d58016c, 0x201e1a39, 0x63ba00ea, 0x00000000}},  //   čvaj, ätin_, sstn,
  { {0x3f8b016c, 0x7bde1a3a, 0x7ae20035, 0x00000000}},  //   _sicu_, ktpu, hfot,
  { {0x5ea40055, 0x332000d4, 0xc5790049, 0x00000000}},  //   _ওয়ে, _foix_, _אָקט,
  { {0x394700b5, 0x637600b9, 0x332000f6, 0x00000000}},  //   zins_, ránc, _goix_,
  { {0x3ea9001a, 0x7afb00b0, 0x7db40025, 0x00000000}},  // [38d0] rbat_, _raut, لصلا,
  { {0x7afb1a3b, 0x612b0180, 0x63761a3c, 0x00000000}},  //   _saut, _mülk, mána,
  { {0x7afb0127, 0x39471a3d, 0x63761a3e, 0x00000000}},  //   _paut, vins_, lána,
  { {0x5a35026b, 0x39470462, 0x629d0010, 0x00000000}},  //   лнет, wins_, ncso,
  { {0x39470129, 0xa2d6006e, 0x7afb009d, 0x00000000}},  //   tins_, _भास्, _vaut,
  { {0x4cad0044, 0xe8f80451, 0x00000000, 0x00000000}},  //   _চাকু, клі_,   ,
  { {0x7afb0ebc, 0x3947000c, 0xf74500ed, 0x00000000}},  //   _taut, rins_, леко,
  { {0x3947009f, 0x98bc001a, 0x212108a8, 0x00000000}},  //   sins_, tivă_, _lohh_,
  { {0xd4d9008b, 0x4a5501e1, 0x3947009d, 0x00000000}},  //   ньні_, _скас, pins_,
  { {0x27310399, 0xdb1c000a, 0x63761a3f, 0x00000000}},  //   _dána_, _avrè, dána,
  { {0x6b950ea1, 0x98bc0035, 0xa34a01ee, 0x00000000}},  //   _juzg, sivă_, езна_,
  { {0x257900f4, 0x69cb00d9, 0x11d601e1, 0x00000000}},  //   dèle_, orge, лігр,
  { {0x332000f4, 0x63760d6a, 0x39990173, 0x00000000}},  //   _voix_, gána, _jès_,
  { {0xb60200b9, 0x39991a40, 0x69cb0048, 0x00000000}},  //   čátk, _mès_, irge,
  { {0x39991a41, 0x3d170164, 0x7ae20240, 0x00000000}},  //   _lès_, नाने_, yfot,
  { {0x6d890107, 0x69c4006e, 0xad9b000c, 0x00000000}},  //   _džam, _रिली, _trúl,
  { {0xc69201ce, 0x80b30044, 0x7ae20190, 0x00000000}},  // [38e0] מאן_, _জার্, vfot,
  { {0xc8d2006e, 0x23b7013d, 0xfca91a42, 0x00000000}},  //   _साइट, _आबाद, نامو_,
  { {0x80aa01f5, 0xa3bb006e, 0x7ae216ec, 0x00000000}},  //   _ज्ये, ेंट_, tfot,
  { {0x2ca7038c, 0xeafa00a1, 0xda7a007c, 0x00000000}},  //   ında_, عرات_, нял_,
  { {0x82d7007b, 0x59f80741, 0xb17b1861, 0x00000000}},  //   רונג_, теля_, ståe,
  { {0x399900f4, 0x7ae200bb, 0x7bde016c, 0x00000000}},  //   _dès_, sfot, ptpu,
  { {0xe3a70014, 0xd90d0167, 0x69cb046a, 0x00000000}},  //   _در_, ظیم_, arge,
  { {0xb8cb007d, 0x3999147f, 0x78b80095, 0x00000000}},  //   _क्_, _fès_, savv,
  { {0xa5340256, 0x290f0051, 0x39990173, 0x00000000}},  //   инич, álaí_, _gès_,
  { {0x6b8200bb, 0x5983007c, 0x46a40309, 0x00000000}},  //   lmog, _глуб, _ग्रह,
  { {0xb8930025, 0xd6c400d3, 0x245801fb, 0x00000000}},  //   _المع, _نمای, тань_,
  { {0x80d7024c, 0x84330088, 0x63760d6a, 0x00000000}},  //   _बाहे, снює, tána,
  { {0x96b90245, 0x6d890107, 0x80de0044, 0x00000000}},  //   _руху_, _džaj, য়ন্,
  { {0xe3af00a1, 0x63761a43, 0x257900f4, 0x00000000}},  //   _کرو_, rána, tèle_,
  { {0x629d0047, 0x63760047, 0xc8d201f5, 0x00000000}},  //   pcso, sána, _साईट,
  { {0x61300039, 0x00000000, 0x00000000, 0x00000000}},  //   _häll,   ,   ,
  { {0x61300039, 0x612b006c, 0x672200fa, 0x00000000}},  // [38f0] _käll, _lüli, _mooj,
  { {0x627c00b6, 0x613003b6, 0x399901aa, 0x00000000}},  //   _אנחנ, _jäll, _rès_,
  { {0xbc070642, 0x768b014a, 0x69c000ea, 0x00000000}},  //   ычай, _köyü, _avme,
  { {0x612b006b, 0x32090be1, 0x39990173, 0x00000000}},  //   _sülh, _kray_, _pès_,
  { {0x99d70054, 0xf9c716a9, 0x69cb0602, 0x00000000}},  //   اتصا, ущен, urge,
  { {0xa4f30061, 0xf990067a, 0x6b820026, 0x00000000}},  //   _असेच_, سبه_, amog,
  { {0xd8b80076, 0x00000000, 0x00000000, 0x00000000}},  //   ادها_,   ,   ,
  { {0x399901aa, 0x61ed1a44, 0x637d1a45, 0x00000000}},  //   _tès_, _opal, nénd,
  { {0x857900ed, 0x7d120010, 0x00000000, 0x00000000}},  //   ксот_, _újsá,   ,
  { {0x63520089, 0x6606000c, 0x00000000, 0x00000000}},  //   māni, ækka,   ,
  { {0x768b005f, 0x61ed1a46, 0x99840025, 0x00000000}},  //   _böyü, _apal, _اللو,
  { {0xe28609ae, 0x60c50051, 0xb60200b9, 0x00000000}},  //   илни, _adhm, čárk,
  { {0x7ae9008d, 0x61300a35, 0x768b006b, 0x00000000}},  //   _mbet, _fäll, _döyü,
  { {0x61300073, 0x6d891a47, 0xdb05009d, 0x00000000}},  //   _gäll, _džak, sphè,
  { {0xa06a01c0, 0x602301ee, 0x63520089, 0x00000000}},  //   тава_, одра, hāni,
  { {0x75230802, 0x6d470258, 0x7ae90288, 0x00000000}},  //   _honz, _amja, _nbet,
  { {0x25bf001a, 0x63760010, 0x7dc6007a, 0x00000000}},  // [3900] nsul_, láno, شقان,
  { {0x7ae91a48, 0x127b0049, 0x91bb0097, 0x00000000}},  //   _abet, _באפע, _שמיי,
  { {0xc5f202d2, 0xf536007b, 0x75230207, 0x00000000}},  //   _अन्य_, סטער_, _monz,
  { {0x25bf0004, 0x79a6005e, 0x305b0104, 0x00000000}},  //   ksul_, арке, _ידיד,
  { {0x6b8200b5, 0x68000010, 0x00000000, 0x00000000}},  //   rmog, kájá,   ,
  { {0x6722006c, 0x6b8200bb, 0x637d0919, 0x00000000}},  //   _sooj, smog, méne,
  { {0x02b60061, 0xc6230044, 0xd7fa0888, 0x00000000}},  //   _अजून, _বেলা_, тул_,
  { {0x61301a49, 0xab2704cf, 0x3ea001a3, 0x00000000}},  //   _säll, _коса_, ncit_,
  { {0x66e20309, 0x38c800a1, 0x94aa0478, 0x00000000}},  //   क्षक_, _ماضی_, ктна_,
  { {0xdb0e00ea, 0x612b1a4a, 0x96a6007d, 0x00000000}},  //   _avbø, _tüli, _ट्रॉ,
  { {0x61ed010a, 0xa4140055, 0x7523059a, 0x00000000}},  //   _spal, ান্য_, _donz,
  { {0x32090133, 0x3dc00058, 0x00000000, 0x00000000}},  //   _pray_, ksiw_,   ,
  { {0x6130021e, 0x15a7005e, 0x75230638, 0x00000000}},  //   _täll, _къщи_, _fonz,
  { {0x75230211, 0xf1bf0051, 0xf6690014, 0x00000000}},  //   _gonz, rsá_, _صحنه_,
  { {0xf1bf0010, 0xdb05009d, 0x415400e2, 0x00000000}},  //   ssá_, sphé, цврс,
  { {0x32090e9e, 0x61300103, 0x3f8f000c, 0x00000000}},  //   _tray_, _jälj, ögu_,
  { {0x61ed1a4b, 0x442c018e, 0x637d076d, 0x00000000}},  // [3910] _upal, lyd_, géne,
  { {0xeca7025f, 0xdca7007e, 0x00000000, 0x00000000}},  //   рјан, ршап,   ,
  { {0x443e1582, 0x656f009d, 0x442c005b, 0x00000000}},  //   nzt_, îchi, nyd_,
  { {0x63760010, 0x63520089, 0x65680020, 0x00000000}},  //   jánl, tāni, hodh,
  { {0x98a50081, 0x442c0016, 0x2cb80056, 0x00000000}},  //   биле, hyd_, _ferd_,
  { {0x63a40428, 0x3eb91a4c, 0x9f5a01aa, 0x00000000}},  //   _činn, _hest_, _aspè_,
  { {0x013800b6, 0x2d990030, 0x75230197, 0x00000000}},  //   שרות_, _huse_, _ronz,
  { {0x3eb90df0, 0x442c018e, 0x0058034e, 0x00000000}},  //   _jest_, dyd_, ישות_,
  { {0x6d570061, 0x6e2d016a, 0x75230197, 0x00000000}},  //   onxa, nyab, _ponz,
  { {0xf9900137, 0x442c018e, 0xd7e701fb, 0x00000000}},  //   _قبل_, fyd_, _відо,
  { {0x2d910381, 0x3cfa013d, 0x3eb90129, 0x00000000}},  //   _mize_, _उससे_, _oest_,
  { {0xe6950054, 0x63760027, 0x25bf008a, 0x00000000}},  //   _الإد, ráno, psul_,
  { {0x7f4d009d, 0xa69600b3, 0x2d990023, 0x00000000}},  //   diaq, _הכנה_, _nuse_,
  { {0xa0a3005e, 0x753a05c6, 0x2eeb0009, 0x00000000}},  //   зард, chtz, _abcf_,
  { {0x3eb90038, 0x251a00b6, 0x61431a4d, 0x00000000}},  //   _best_, _תוצא, чера,
  { {0xdd920054, 0x637d0010, 0x2d910288, 0x00000000}},  //   كور_, téne, _aize_,
  { {0x6130021e, 0x2d91011f, 0x2cb81a4e, 0x00000000}},  // [3920] _jälk, _bize_, _perd_,
  { {0x3eb90004, 0x2d99037e, 0x98a70006, 0x00000000}},  //   _eest_, _duse_, dinį_,
  { {0x4176026c, 0x3eb904fb, 0x2cb81a4f, 0x00000000}},  //   _پاکس, _fest_, _verd_,
  { {0x2cb817cc, 0x2ca1157d, 0x3eb91a50, 0x00000000}},  //   _werd_, achd_, _gest_,
  { {0x7c3e0010, 0x7769008e, 0x2d910173, 0x00000000}},  //   szpr, doex, _fize_,
  { {0x61300073, 0x3eb91a51, 0x3f9a04be, 0x00000000}},  //   _sälj, _zest_, _kupu_,
  { {0xb9000754, 0xa7fc005d, 0x63a40142, 0x00000000}},  //   _था_, _ayır, _čino,
  { {0xcb6a008b, 0x9634003b, 0x3f9a012d, 0x00000000}},  //   _сабе_, жниц, _mupu_,
  { {0x61300dac, 0x442c018e, 0x612b014a, 0x00000000}},  //   _välj, wyd_, _kült,
  { {0x443e001f, 0x442c0343, 0x69c20022, 0x00000000}},  //   tzt_, tyd_, msoe,
  { {0x78ba0089, 0x65681a52, 0x00000000, 0x00000000}},  //   _ietv, rodh,   ,
  { {0x442c1194, 0x443e010f, 0x6aa20197, 0x00000000}},  //   ryd_, rzt_, ncof,
  { {0x66760151, 0x443e1a53, 0x69c20007, 0x00000000}},  //   _ادار, szt_, nsoe,
  { {0x3eb90004, 0x70d30061, 0x2d991717, 0x00000000}},  //   _sest_, तलेल, _ruse_,
  { {0x3eb90010, 0xdbf10224, 0x889b0049, 0x00000000}},  //   _pest_, _příj, רבלי,
  { {0x2d910541, 0x6e2d005f, 0xbebb01c3, 0x00000000}},  //   _size_, tyab, _goël,
  { {0x3eb90056, 0x612b014a, 0x7f4d0068, 0x00000000}},  // [3930] _vest_, _bült, riaq,
  { {0x78ba0030, 0x3eb900ab, 0x6f04004a, 0x00000000}},  //   _netv, _west_, adic,
  { {0x2d9109e5, 0x7bf900e2, 0x28d200e8, 0x00000000}},  //   _vize_, рнер_, _साजि,
  { {0x98a70006, 0x2d991a54, 0x69c201c3, 0x00000000}},  //   tinį_, _tuse_, fsoe,
  { {0x7ccb0089, 0x78ba1992, 0x660d0066, 0x00000000}},  //   tērē, _betv, _ġako,
  { {0x527c007b, 0x660d0b4d, 0x612b1a55, 0x00000000}},  //   אנדא, _šako, _gült,
  { {0xb8f10061, 0xe8090309, 0x98bc013e, 0x00000000}},  //   _वय_, विधा_, livě_,
  { {0x612b0010, 0x661b002d, 0xdb230c43, 0x00000000}},  //   _küls, txuk, öräl,
  { {0x673b1a56, 0x7769004a, 0x78ba1a57, 0x00000000}},  //   rhuj, roex, _fetv,
  { {0x61300039, 0x6f0402db, 0x673b00e7, 0x00000000}},  //   _välk, zdic, shuj,
  { {0x09be0044, 0xe85501f7, 0xd77400a1, 0x00000000}},  //   _উৎপা, _بناد, _کالع,
  { {0x3f9a0182, 0x799b00e7, 0x65950f4e, 0x00000000}},  //   _rupu_, _kuuw, _даду,
  { {0x4ade006e, 0xbebb0007, 0x3f9a1a58, 0x00000000}},  //   फ्टव, _voël, _supu_,
  { {0x25ad0292, 0xb17b0073, 0x3f9a02c8, 0x00000000}},  //   mpel_, stån, _pupu_,
  { {0xa2e61a59, 0x66090056, 0x6abb009d, 0x00000000}},  //   _дойд, lvek, _oeuf,
  { {0x6abb1119, 0x6f0406c2, 0x69c20016, 0x00000000}},  //   _neuf, udic, ysoe,
  { {0xfd4a003b, 0x25ad0022, 0x00000000, 0x00000000}},  // [3940] азак_, npel_,   ,
  { {0x637d1a5a, 0xbd8301e1, 0x3f9a0020, 0x00000000}},  //   ména, дгук, _tupu_,
  { {0x61e605d5, 0x78ba0146, 0xb53a0049, 0x00000000}},  //   ltkl, _retv, סגעש,
  { {0xfa250044, 0x78ba1a5b, 0x69c20f12, 0x00000000}},  //   _মেইল_, _setv, tsoe,
  { {0x394e028c, 0x2a60006b, 0x2fd81332, 0x00000000}},  //   tifs_, çib_, lurg_,
  { {0x69c20343, 0x27fe0022, 0x6d5c1a5c, 0x00000000}},  //   rsoe, _pstn_, _ujra,
  { {0x394e00f4, 0x78ba1a5d, 0x25ad071b, 0x00000000}},  //   rifs_, _vetv, epel_,
  { {0x64410061, 0x61e60039, 0xf0930104, 0x00000000}},  //   dzli, ktkl, ונו_,
  { {0x99890bf8, 0x5b2100a1, 0x6b9c0c06, 0x00000000}},  //   šaš_, _سہول, _hurg,
  { {0x2bd1007d, 0x27310082, 0x6b9c0560, 0x00000000}},  //   _हिमा, _lánh_, _kurg,
  { {0x66e619ec, 0x6b9c0006, 0x7d7b0049, 0x00000000}},  //   _можа, _jurg, שריג,
  { {0x6b9c002d, 0xe3af0167, 0xad9b0b22, 0x00000000}},  //   _murg, کری_, _krút,
  { {0xe4da0014, 0x6b9c0288, 0x637d0068, 0x00000000}},  //   _نوشت_, _lurg, géna,
  { {0x3cf6013d, 0xa3b5007d, 0x00000000, 0x00000000}},  //   ीयों_, _चौक_,   ,
  { {0x27310011, 0x2f19007c, 0x6b9c006c, 0x00000000}},  //   _bánh_, бовь_, _nurg,
  { {0x27310011, 0x2fcd0091, 0x394c00f6, 0x00000000}},  //   _cánh_, čeg_, _lmds_,
  { {0xd251004b, 0x3dd20016, 0xdddd0089, 0x00000000}},  // [3950] _سند_, gryw_, _izsū,
  { {0x6b9c07af, 0xdfdb0265, 0x2fd8010f, 0x00000000}},  //   _burg, _към_, burg_,
  { {0x92dd0055, 0x6b9c1a5e, 0xdc980088, 0x00000000}},  //   ড়ী_, _curg, івці_,
  { {0x27310011, 0xad9b0010, 0x6b9c0095, 0x00000000}},  //   _gánh_, _csúc, _durg,
  { {0x6d5811af, 0x7e7d0089, 0xe9d80451, 0x00000000}},  //   čvar, _uzsp, жкі_,
  { {0x3f8900d4, 0x68f8006c, 0x66090056, 0x00000000}},  //   lmau_, gevd, vvek,
  { {0x6b9c00c4, 0x6abb01a2, 0x00000000, 0x00000000}},  //   _gurg, _teuf,   ,
  { {0x6130003c, 0x63760428, 0x96230055, 0x00000000}},  //   _väli, ránk, _বেগম_,
  { {0x7bc51864, 0x6b9c1424, 0x00000000, 0x00000000}},  //   lshu, _zurg,   ,
  { {0x6441001f, 0x637610fa, 0x69d90eb0, 0x00000000}},  //   tzli, máni, muwe,
  { {0x69d906f6, 0x25ad0aa4, 0x660900ea, 0x00000000}},  //   luwe, spel_, svek,
  { {0x2905022b, 0x64410d9a, 0x332900bb, 0x00000000}},  //   _hala_, rzli, _coax_,
  { {0x29050643, 0x7bc501d6, 0x2d8300b0, 0x00000000}},  //   _kala_, hshu, _ohje_,
  { {0x29071a5f, 0x27310011, 0x61e601d6, 0x00000000}},  //   ndna_, _sánh_, rtkl,
  { {0x29050027, 0xb4d701f5, 0x3eb201d6, 0x00000000}},  //   _mala_, िली_, tbyt_,
  { {0x2fd80209, 0x69d91a60, 0x7bc501bf, 0x00000000}},  //   rurg_, kuwe, dshu,
  { {0x0e6301e0, 0x6b9c0053, 0x68f8006b, 0x00000000}},  // [3960] ектн, _surg, yevd,
  { {0xee37019d, 0x69d907a5, 0x6b9c016e, 0x00000000}},  //   чну_, duwe, _purg,
  { {0x309b009b, 0x69d900b5, 0x27310082, 0x00000000}},  //   _לשימ, euwe, _tánh_,
  { {0x23a10036, 0x29071a61, 0x290500e0, 0x00000000}},  //   _mój_, edna_, _aala_,
  { {0x63761526, 0x29051a62, 0x7bc51a63, 0x00000000}},  //   gáni, _bala_, ashu,
  { {0x6b9c14cc, 0x29fd0027, 0x6f0601a3, 0x00000000}},  //   _turg, _dňa_, _hakc,
  { {0x6d4e1a64, 0x7c650d0b, 0x6b9c01d6, 0x00000000}},  //   _imba, _قافل, _uurg,
  { {0x290700d4, 0xceb4006b, 0xa614005e, 0x00000000}},  //   adna_, nbə_, дмич,
  { {0x20dc024c, 0x69d9128d, 0x29050181, 0x00000000}},  //   _बांध, cuwe, _fala_,
  { {0x29070045, 0xaa3b009b, 0x00000000, 0x00000000}},  //   cdna_, _התמח,   ,
  { {0xd6cf0121, 0x14dd0204, 0xa4380245, 0x00000000}},  //   _пт_, _मारण, ізму_,
  { {0x29050968, 0x66e6003b, 0x6f061a65, 0x00000000}},  //   _zala_, _хода, _nakc,
  { {0x51871a66, 0x6d4e01a3, 0xdb1e013e, 0x00000000}},  //   зува, _omba, jspí,
  { {0x92dd0055, 0x66021a67, 0xf617034e, 0x00000000}},  //   ড়ে_, _isok, _מחדש_,
  { {0x6f06013f, 0x69d901a2, 0x00000000, 0x00000000}},  //   _bakc, zuwe,   ,
  { {0x6d4e0be3, 0x5f94003b, 0x637d1a68, 0x00000000}},  //   _amba, еист, méno,
  { {0x3f890016, 0x7bc501c3, 0x6f0600d9, 0x00000000}},  // [3970] rmau_, wshu, _dakc,
  { {0x7bc500bb, 0x00000000, 0x00000000, 0x00000000}},  //   tshu,   ,   ,
  { {0xd25102fd, 0x629a00b9, 0x3d0c0061, 0x00000000}},  //   _سنگ_, ětov, _डोळे_,
  { {0x63761a69, 0x6d4e0781, 0x6602002d, 0x00000000}},  //   táni, _emba, _osok,
  { {0x2905006a, 0x7bc503f1, 0xdd910879, 0x00000000}},  //   _pala_, sshu, _لوح_,
  { {0x63761a6a, 0x69d91a6b, 0x29050312, 0x00000000}},  //   ráni, ruwe, _qala_,
  { {0xccf20104, 0x66020023, 0x69d90058, 0x00000000}},  //   _שכל_, _asok, suwe,
  { {0x290511ad, 0x05a901fb, 0xeab30025, 0x00000000}},  //   _wala_, овий_, _سعر_,
  { {0x29050635, 0xa3df0061, 0x7d071a6c, 0x00000000}},  //   _tala_, धून_, _kajs,
  { {0xb4d70201, 0x53c902b8, 0x629b0006, 0x00000000}},  //   िले_, огом_, žuol,
  { {0x7d0704a9, 0xa3d402fb, 0x66020281, 0x00000000}},  //   _majs, िंग_, _esok,
  { {0x4cc70044, 0x7d071a6d, 0x00000000, 0x00000000}},  //   র্চু, _lajs,   ,
  { {0xe56e0265, 0xceb4006b, 0x6f060087, 0x00000000}},  //   _аз_, vbə_, _rakc,
  { {0x659401fc, 0x00000000, 0x00000000, 0x00000000}},  //   _зачу,   ,   ,
  { {0xdee60a27, 0x10a31662, 0xd0070175, 0x00000000}},  //   мови, тисн, мере_,
  { {0x672b0762, 0x26df0020, 0x6aad004a, 0x00000000}},  //   _jogj, nguo_, ñafl,
  { {0x6f06145e, 0x63a40091, 0x7d0700f8, 0x00000000}},  // [3980] _vakc, _čini, _bajs,
  { {0x672b1a6e, 0x1e83007e, 0x00000000, 0x00000000}},  //   _logj, тлум,   ,
  { {0x711b0049, 0xa7fc013f, 0xfce30256, 0x00000000}},  //   _וויפ, _axın, тохо,
  { {0x3cfa03d7, 0x28e00061, 0xdbc7000c, 0x00000000}},  //   _उसके_, _नाहि, _vöðv,
  { {0x6368005d, 0xd946007c, 0x61300039, 0x00000000}},  //   mınd, меди, _fält,
  { {0x6368047f, 0x6aa90061, 0x6d4e0d65, 0x00000000}},  //   lınd, _efef, _umba,
  { {0x61300073, 0x31570049, 0x6aa90016, 0x00000000}},  //   _häls, ויסן_, _ffef,
  { {0x636801f6, 0x85a600ed, 0x2d9800ab, 0x00000000}},  //   nınd, мјод, _hire_,
  { {0x63ad016c, 0x672b0023, 0x2d980145, 0x00000000}},  //   _čana, _dogj, _kire_,
  { {0x63681a6f, 0x2d980173, 0x00000000, 0x00000000}},  //   hınd, _jire_,   ,
  { {0x2d981a70, 0x443803b5, 0x99800006, 0x00000000}},  //   _mire_, ár_, šių_,
  { {0x2d98028c, 0x2bd1006e, 0x66020058, 0x00000000}},  //   _lire_, _हिसा, _tsok,
  { {0x26c41a71, 0x6368005a, 0xd3790091, 0x00000000}},  //   mamo_, dınd, juće_,
  { {0x2d98022b, 0x26c40af3, 0xe44f02fd, 0x00000000}},  //   _nire_, lamo_, اضی_,
  { {0xa3cb0754, 0x6368047f, 0x4fc4007e, 0x00000000}},  //   _लिए_, fınd, кста,
  { {0x26c409e3, 0x2d9810c9, 0x660d1a72, 0x00000000}},  //   namo_, _aire_, _šaki,
  { {0x8af7005f, 0xd3790119, 0x7d070d6b, 0x00000000}},  // [3990] şəkk, guće_, _pajs,
  { {0x26c4050f, 0x2d98009d, 0x6d5e0146, 0x00000000}},  //   hamo_, _cire_, gnpa,
  { {0x2d980e8d, 0x8af90256, 0x61300d20, 0x00000000}},  //   _dire_, знес_, _vält,
  { {0x26c40059, 0xf38a0011, 0x2d981a73, 0x00000000}},  //   jamo_, _bảy_, _eire_,
  { {0x28e0001c, 0xad9b002a, 0x3ea900ea, 0x00000000}},  //   _नाशि, _grúp, mcat_,
  { {0xde16007b, 0x63761a74, 0x3ea91a75, 0x00000000}},  //   _אַלץ_, lánt, lcat_,
  { {0xe73901e1, 0xb90701f5, 0x3f9900e7, 0x00000000}},  //   зей_, _भा_, _kisu_,
  { {0x3ea9145d, 0x26c40059, 0x9ac700a1, 0x00000000}},  //   ncat_, gamo_, _آگاہ_,
  { {0x29d5031d, 0x3f99016e, 0x00000000, 0x00000000}},  //   _سياس, _misu_,   ,
  { {0x142501e0, 0x9a84004c, 0x6368005d, 0x00000000}},  //   едом, _русл, zınd,
  { {0x63680279, 0x61f61a76, 0x26c40247, 0x00000000}},  //   yınd, _spyl, bamo_,
  { {0x3f990119, 0x26c4037e, 0x6368006b, 0x00000000}},  //   _nisu_, camo_, xınd,
  { {0xf38a0011, 0xb606000c, 0x00000000, 0x00000000}},  //   _xảy_, rráð,   ,
  { {0x25d60049, 0x6e2004bd, 0xb606000c, 0x00000000}},  //   _נוצן_, _àmbi, sráð,
  { {0x6368038c, 0x2d9800f4, 0xe465010e, 0x00000000}},  //   tınd, _rire_, ööde_,
  { {0x2d980107, 0x539a009b, 0x6d5e1a77, 0x00000000}},  //   _sire_, _ציפו, wnpa,
  { {0x636801f6, 0x2d9800f4, 0x0d86007c, 0x00000000}},  // [39a0] rınd, _pire_, елан,
  { {0x6368038c, 0x26c40020, 0x61300510, 0x00000000}},  //   sınd, zamo_, _väls,
  { {0xf536007b, 0x2d9801aa, 0xeb9a022a, 0x00000000}},  //   עטער_, _vire_, чие_,
  { {0x3ea9001c, 0x2057007b, 0x2d9800ab, 0x00000000}},  //   ccat_, _טייל_, _wire_,
  { {0x26c40091, 0x2d98060b, 0x00000000, 0x00000000}},  //   vamo_, _tire_,   ,
  { {0x26c40020, 0xdbc7006c, 0x26cf01c3, 0x00000000}},  //   wamo_, _rööv, _adgo_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bde0085, 0x62840026, 0xf4150044, 0x00000000}},  //   mupu, _ozio, াহার_,
  { {0x26c40340, 0xbb4300a5, 0x7bde19ae, 0x00000000}},  //   ramo_, _сетк, lupu,
  { {0x26c4016c, 0x7ae20450, 0xa3cb006e, 0x00000000}},  //   samo_, lgot, _लिख_,
  { {0x62840207, 0x7bde011c, 0x3ea90253, 0x00000000}},  //   _azio, nupu, ycat_,
  { {0x7ae2002d, 0xdbc7006c, 0x5c5b0049, 0x00000000}},  //   ngot, _tööv, לדיק,
  { {0x7bde01a3, 0x799a047b, 0x628400d9, 0x00000000}},  //   hupu, _kitw, _czio,
  { {0xa4d401fb, 0x7bde0f6b, 0x3f99006c, 0x00000000}},  //   _рокі, kupu, _sisu_,
  { {0x3ea91a78, 0x3f991293, 0x62840026, 0x00000000}},  //   tcat_, _pisu_, _ezio,
  { {0x799a1a79, 0x3f99002b, 0x7d1c00e5, 0x00000000}},  //   _litw, _qisu_, _anrs,
  { {0x3ea91a7a, 0x3f991a2f, 0x63761a43, 0x00000000}},  // [39b0] rcat_, _visu_, ránt,
  { {0xceeb007a, 0x3ea91a7b, 0x3dc91156, 0x00000000}},  //   _کردن_, scat_, rsaw_,
  { {0x3ea9003b, 0x60c71a7c, 0x9c190025, 0x00000000}},  //   pcat_, majm, بياء_,
  { {0x7ae20149, 0x60c70065, 0x799a0020, 0x00000000}},  //   ggot, lajm, _aitw,
  { {0x6f1d032c, 0xd7f8001a, 0xf77102fd, 0x00000000}},  //   _insc, _apă_, یاب_,
  { {0x60c70036, 0x7ae2002d, 0xfd610082, 0x00000000}},  //   najm, agot, _luyế,
  { {0xd942073b, 0xdb1e101b, 0x00000000, 0x00000000}},  //   рещи, dspæ,   ,
  { {0x60c71a7d, 0x00000000, 0x00000000, 0x00000000}},  //   hajm,   ,   ,
  { {0xd7060057, 0x3b64005e, 0x91820082, 0x00000000}},  //   тные_, _сърв, yền_,
  { {0x60c7050f, 0xdb05010f, 0xb8860802, 0x00000000}},  //   jajm, sphä, _stíž,
  { {0x6f1d00bb, 0x1422007e, 0x60c7016e, 0x00000000}},  //   _onsc, адэм, dajm,
  { {0x6d451a7e, 0x6368005d, 0x69d90112, 0x00000000}},  //   hhha, dınc, orwe,
  { {0x799a0009, 0x69cb1a7f, 0x6f0d005b, 0x00000000}},  //   _yitw, nsge, ddac,
  { {0x6f1d001f, 0x60c71a80, 0x67291727, 0x00000000}},  //   _ansc, gajm, ljej,
  { {0x69d9010f, 0x7f4400f4, 0x6d570288, 0x00000000}},  //   hrwe, thiq, dixa,
  { {0xd36f0054, 0x6e24002d, 0x69cb01d6, 0x00000000}},  //   _وهو_, txib, ksge,
  { {0x63a302e1, 0x7f440065, 0x6d5700f8, 0x00000000}},  // [39c0] _hunn, rhiq, fixa,
  { {0x63a302ae, 0x6f1d00bb, 0x69cb0112, 0x00000000}},  //   _kunn, _ensc, dsge,
  { {0x7c9601fb, 0x40d9007b, 0x823600e9, 0x00000000}},  //   трац, _אַרײ, _سرکا,
  { {0x6b8902d5, 0x799a1a81, 0x63a305ed, 0x00000000}},  //   _cheg, _sitw, _munn,
  { {0x7bde1632, 0x7ae21a82, 0x6b9b0254, 0x00000000}},  //   supu, rgot, _diug,
  { {0x49730822, 0x14dd001c, 0x6d45010f, 0x00000000}},  //   аліс, _मागण, chha,
  { {0x69cb0007, 0x6b9b0197, 0x63a3006c, 0x00000000}},  //   asge, _fiug, _nunn,
  { {0x6b9b0198, 0xe3af0055, 0x60c705fa, 0x00000000}},  //   _giug, _কিংব, zajm,
  { {0xe9a60265, 0x3d170061, 0xd3790091, 0x00000000}},  //   _разп, नाचे_, juća_,
  { {0x799a1a83, 0x973c1a84, 0x636801df, 0x00000000}},  //   _uitw, _duća, yınc,
  { {0x291e1a85, 0x290c0032, 0x00000000, 0x00000000}},  //   _inta_, _iada_,   ,
  { {0xfd61001d, 0x63a3020f, 0x5453005e, 0x00000000}},  //   _quyế, _dunn, рвют,
  { {0x290c0006, 0x60c70142, 0xd3790091, 0x00000000}},  //   _kada_, tajm, guća_,
  { {0x63a30292, 0x290c002d, 0xf8b401f5, 0x00000000}},  //   _funn, _jada_, ुरिय,
  { {0x63a3009f, 0xfd61001d, 0x290c000b, 0x00000000}},  //   _gunn, _tuyế, _mada_,
  { {0xe0e30044, 0x290c01a3, 0xe3af03ec, 0x00000000}},  //   য়েন, _lada_, _برو_,
  { {0x6f0d002a, 0xc29901fb, 0x5f940088, 0x00000000}},  // [39d0] rdac, _яких_, ритт,
  { {0x290c0977, 0xbebb0007, 0x50b7007d, 0x00000000}},  //   _nada_, _poës, _अभिष,
  { {0x290e018e, 0x4035004c, 0xd0110025, 0x00000000}},  //   ddfa_, _сенс, _الج_,
  { {0x41c4089d, 0x69cb010f, 0x6f1d0043, 0x00000000}},  //   _حقیق, tsge, _unsc,
  { {0x290c022b, 0x61ef1a86, 0x637d00f4, 0x00000000}},  //   _bada_, ntcl, géni,
  { {0x69cb0168, 0x2a6901d5, 0xc4bd0044, 0x00000000}},  //   rsge, ħab_, _ইঞ্জ,
  { {0x6d55038c, 0x60c5014a, 0x290c00f0, 0x00000000}},  //   _imza, _mehm, _dada_,
  { {0x0609026b, 0x80dc0055, 0x60c50ac2, 0x00000000}},  //   еник_, ম্প্, _lehm,
  { {0x63a30635, 0x290c002a, 0x673b0065, 0x00000000}},  //   _sunn, _fada_, rkuj,
  { {0x290c001e, 0x60c5010f, 0x7e7d00ab, 0x00000000}},  //   _gada_, _nehm, _mysp,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63a302e1, 0xc6540014, 0x3f47010e, 0x00000000}},  //   _vunn, افیک, _jõud_,
  { {0xf77005d4, 0x290c01df, 0x973c0091, 0x00000000}},  //   _بال_, _yada_, _kućn,
  { {0xa11600e9, 0x06e30309, 0x63a31a87, 0x00000000}},  //   دوست, _गाँव_, _tunn,
  { {0xd379016e, 0xa06701c0, 0x973c016c, 0x00000000}},  //   suća_, гара_, _mućn,
  { {0x332b0061, 0x2eb500ec, 0x7e7d01c3, 0x00000000}},  //   cjcx_, исус, _bysp,
  { {0x60c5002b, 0xcb1d013d, 0xdb1e00f8, 0x00000000}},  // [39e0] _fehm, फाईड_, nspå,
  { {0x7e7d0036, 0x637d1a88, 0x64640006, 0x00000000}},  //   _dysp, véni, štiš,
  { {0x06e303d7, 0xdd8f0054, 0x9f5e0010, 0x00000000}},  //   _गांव_, أول_, ító_,
  { {0x290c01cd, 0xbda6035b, 0xbae50088, 0x00000000}},  //   _sada_, _محسو, ицій,
  { {0x290c0149, 0x00000000, 0x00000000, 0x00000000}},  //   _pada_,   ,   ,
  { {0x3f801460, 0x637d1a89, 0xbebb01d6, 0x00000000}},  //   lliu_, réni, _hoëp,
  { {0x8c460517, 0x290c1a8a, 0x3320106f, 0x00000000}},  //   _севе, _vada_, _onix_,
  { {0x7d0e0145, 0xbb43003b, 0xa81703ec, 0x00000000}},  //   _habs, _леск, اتور_,
  { {0x290c010a, 0xe4c6007c, 0xdb1e053d, 0x00000000}},  //   _tada_, лённ, rspä,
  { {0x291e1a8b, 0xa97601fc, 0x35f70439, 0x00000000}},  //   _unta_, _субј, اريد_,
  { {0xb9930025, 0x249803a2, 0x3f801a8c, 0x00000000}},  //   _اللب, ärm_, kliu_,
  { {0xdc3b0049, 0x7d0e1478, 0x41e701e1, 0x00000000}},  //   געטר, _labs, ліга,
  { {0x36360084, 0x60c503b6, 0x61ed0009, 0x00000000}},  //   _حراس, _pehm, _qqal,
  { {0x61ef0270, 0x973c11af, 0x00000000, 0x00000000}},  //   rtcl, _kućo,   ,
  { {0x61ef1a8d, 0xdfd8005e, 0x855600a1, 0x00000000}},  //   stcl, лът_, _لیکر_,
  { {0x7d0e00e0, 0x636801df, 0x61ed0066, 0x00000000}},  //   _aabs, pına, _tqal,
  { {0x5d5500c0, 0x60c501f3, 0x320900e0, 0x00000000}},  // [39f0] акат, _tehm, _usay_,
  { {0x7ae90197, 0x00000000, 0x00000000, 0x00000000}},  //   _scet,   ,   ,
  { {0x7e7d0036, 0x63ad016c, 0x3ea61a8e, 0x00000000}},  //   _wysp, _čank, žota_,
  { {0x681c001a, 0xb17b0039, 0x00000000, 0x00000000}},  //   _mădă, fråg,   ,
  { {0x6f0f0026, 0x2b440087, 0x00000000, 0x00000000}},  //   _iacc, _dlmc_,   ,
  { {0x26c90091, 0x00000000, 0x00000000, 0x00000000}},  //   _žao_,   ,   ,
  { {0xb17b063b, 0xe7310025, 0x6f0f0066, 0x00000000}},  //   mråd, قصة_, _kacc,
  { {0x6f0f1a8f, 0xb17b0748, 0xdb070190, 0x00000000}},  //   _jacc, lråd, _stjæ,
  { {0x6f0f0207, 0x00000000, 0x00000000, 0x00000000}},  //   _macc,   ,   ,
  { {0x5a340c27, 0x6f0f0197, 0x25a60058, 0x00000000}},  //   _унут, _lacc, _duol_,
  { {0xd4690aed, 0x3366004c, 0x39451a90, 0x00000000}},  //   тине_, ивог, _ills_,
  { {0x6f0f0afb, 0x17f80025, 0x681c00e5, 0x00000000}},  //   _nacc, _حركة_, _dădă,
  { {0xf7700644, 0xb17b03b1, 0x00000000, 0x00000000}},  //   _عام_, kråd,   ,
  { {0xa06a008b, 0xd3790091, 0x00000000, 0x00000000}},  //   вага_, vrće_,   ,
  { {0xd479007b, 0x6f0f1003, 0x1fb501e1, 0x00000000}},  //   _באַל, _bacc, йстр,
  { {0x6f0f0207, 0x7d0e146c, 0x2eeb00e5, 0x00000000}},  //   _cacc, _sabs, _cccf_,
  { {0x6f0f0197, 0xdcf50173, 0xb17b0ccc, 0x00000000}},  // [3a00] _dacc, _ekzč, rtår,
  { {0x8cb6005e, 0x6f0f00e5, 0x00000000, 0x00000000}},  //   рсач, _eacc,   ,
  { {0x6f0f0198, 0x6c4a0084, 0x2a7f0145, 0x00000000}},  //   _facc, خلاف_, _ayub_,
  { {0xa3e604da, 0x394505ce, 0x317803b2, 0x00000000}},  //   यंत_, _alls_, lorz_,
  { {0x7d0e152f, 0x637d004a, 0x6f041a91, 0x00000000}},  //   _tabs, mént, meic,
  { {0x6f04001f, 0x6f0f0197, 0x201a016c, 0x00000000}},  //   leic, _zacc, _krpi_,
  { {0x25a60026, 0xe7580088, 0xed57004d, 0x00000000}},  //   _suol_, ликі_, _тор_,
  { {0x39450129, 0x681c0035, 0x00000000, 0x00000000}},  //   _ells_, _rădă,   ,
  { {0x48e616c4, 0x758a007c, 0x00000000, 0x00000000}},  //   _возв, ксов_,   ,
  { {0x6b821a92, 0x25a60207, 0x69db01f5, 0x00000000}},  //   llog, _vuol_, _निती,
  { {0xd6c40014, 0x6f04007f, 0x637d0010, 0x00000000}},  //   _همای, keic, ként,
  { {0x6b82010f, 0x27fe0022, 0x00000000, 0x00000000}},  //   nlog, _iptn_,   ,
  { {0x6f0f1a93, 0x05b40879, 0x6445006c, 0x00000000}},  //   _racc, _امتح, _ühin,
  { {0xd5fb00b6, 0x6f0f0207, 0x5067005e, 0x00000000}},  //   _ספור, _sacc, атба,
  { {0x6f0f0207, 0x6f0407a7, 0xb17b0c73, 0x00000000}},  //   _pacc, feic, vråd,
  { {0xddc40036, 0x637d009d, 0x63ba16d0, 0x00000000}},  //   dził, ténu, mptn,
  { {0x6b820627, 0x2121001d, 0xb17b0d2b, 0x00000000}},  // [3a10] dlog, _tnhh_, tråd,
  { {0xacf400a1, 0x00000000, 0x00000000, 0x00000000}},  //   قسمت,   ,   ,
  { {0x6f0f1a94, 0x6b82018e, 0xb17b1a95, 0x00000000}},  //   _tacc, flog, rråd,
  { {0xb17b1a96, 0x637d008e, 0x6f0f0190, 0x00000000}},  //   sråd, cént, _uacc,
  { {0x636801f6, 0x00000000, 0x00000000, 0x00000000}},  //   dınl,   ,   ,
  { {0xdb070039, 0xe77800a1, 0xe9b800a1, 0x00000000}},  //   _stjä, یلوں_, جنوں_,
  { {0x6b821a97, 0x98f4023c, 0xdb0901a2, 0x00000000}},  //   blog, تثنا, _gieß,
  { {0x6b8200d4, 0x2ee91a98, 0x00000000, 0x00000000}},  //   clog, ngaf_,   ,
  { {0xe579026b, 0x7afb0058, 0x00000000, 0x00000000}},  //   лзи_, _ibut,   ,
  { {0x6f04001f, 0x99850025, 0x39450129, 0x00000000}},  //   zeic, _الطو, _ulls_,
  { {0x6d470ecc, 0x00000000, 0x00000000, 0x00000000}},  //   _mlja,   ,   ,
  { {0x6722073a, 0x00000000, 0x00000000, 0x00000000}},  //   _gnoj,   ,   ,
  { {0xd7740025, 0x6f041a99, 0xb5a71523, 0x00000000}},  //   _بالع, veic, _трей,
  { {0x6b820295, 0x6f04010f, 0x67220e25, 0x00000000}},  //   zlog, weic, _znoj,
  { {0x6f04001e, 0x7afb0059, 0x637d0842, 0x00000000}},  //   teic, _obut, tént,
  { {0x27ea0030, 0x660900e7, 0x00000000, 0x00000000}},  //   _åbne_, owek,   ,
  { {0x6f04001f, 0x6d470107, 0x63680180, 0x00000000}},  // [3a20] reic, _blja, nınm,
  { {0x7afb07b1, 0x6f041a9a, 0x637d008e, 0x00000000}},  //   _abut, seic, sént,
  { {0x6b820059, 0x6368011f, 0x61e6014a, 0x00000000}},  //   tlog, yınl, lukl,
  { {0xf09300b6, 0x6368006b, 0x66090116, 0x00000000}},  //   _מנת_, xınl, kwek,
  { {0xceb300bd, 0xb3470181, 0x61e60089, 0x00000000}},  //   _מיר_, luçõ, nukl,
  { {0x6b820056, 0xa7b800ed, 0x00000000, 0x00000000}},  //   slog, алку_,   ,
  { {0x6c36007a, 0x6d5e17ce, 0x6b821a9b, 0x00000000}},  //   _افزا, mipa, plog,
  { {0x6d5e006a, 0xa3e6013d, 0xcc3b0049, 0x00000000}},  //   lipa, यंस_, _געלט,
  { {0x3f47006c, 0x6368026d, 0x00000000, 0x00000000}},  //   _jõua_, rınl,   ,
  { {0x61e6014a, 0x7afb0023, 0x63680276, 0x00000000}},  //   dukl, _zbut, sınl,
  { {0x4395003b, 0x7c3e1a9c, 0x00000000, 0x00000000}},  //   жанс, nypr,   ,
  { {0xdc9b0476, 0x6d5e001a, 0xb3470181, 0x00000000}},  //   טייל, hipa, duçõ,
  { {0x6d5e006a, 0x66e3007e, 0xe6960025, 0x00000000}},  //   kipa, _хоча, _الشد,
  { {0x067b007b, 0xe3af02fd, 0x6d5e00f0, 0x00000000}},  //   _ענגל, بری_, jipa,
  { {0xd48f004d, 0x2099007e, 0x657a00ab, 0x00000000}},  //   _хр_, рквы_, moth,
  { {0x7eb90265, 0x6d470107, 0x61e61a9d, 0x00000000}},  //   ргас_, _slja, bukl,
  { {0x171b007b, 0x7d05005f, 0x61e6011f, 0x00000000}},  // [3a30] נומע, tehs, cukl,
  { {0x6d5e0695, 0x4c4b0641, 0x657a032c, 0x00000000}},  //   gipa, ляем_, noth,
  { {0x443e1a9e, 0xfbd00014, 0xb34700c4, 0x00000000}},  //   nyt_, فتن_, cuçõ,
  { {0x657a01a2, 0x20010022, 0xdb00000a, 0x00000000}},  //   hoth, _iphi_, _jimè,
  { {0x6d5e1a9f, 0x443e00b0, 0xdb0000f6, 0x00000000}},  //   bipa, hyt_, _mimè,
  { {0x6d5e06c0, 0x7ff4007a, 0xa3d80061, 0x00000000}},  //   cipa, _بسیا, ाळा_,
  { {0x7c3e0ace, 0x61e6014a, 0x657a0133, 0x00000000}},  //   cypr, zukl, doth,
  { {0x7afb0061, 0x443e0fed, 0x4cde0044, 0x00000000}},  //   _ubut, dyt_, ন্দু,
  { {0xdb1c009f, 0x63aa010f, 0x05a6007c, 0x00000000}},  //   _evró, _aufn, овый_,
  { {0x61e61353, 0x05760025, 0x58d40077, 0x00000000}},  //   vukl, يمية_, _ноут,
  { {0x29070119, 0xf6d50088, 0xe29f000c, 0x00000000}},  //   mena_, _діля, veða_,
  { {0xf7700054, 0x29070119, 0x61e61aa0, 0x00000000}},  //   _كان_, lena_, tukl,
  { {0x07080439, 0xdb0000f6, 0x15390014, 0x00000000}},  //   _ديني_, _dimè, _پزشک_,
  { {0x2907002d, 0x31af0279, 0x443e0142, 0x00000000}},  //   nena_, _düz_, byt_,
  { {0xa0a3025f, 0x628d01aa, 0x61e61aa1, 0x00000000}},  //   дард, _ezao, sukl,
  { {0x77690293, 0x2907002d, 0xb3470181, 0x00000000}},  //   nnex, hena_, ruçõ,
  { {0x6d5e0ed1, 0x29071640, 0x98a500b4, 0x00000000}},  // [3a40] tipa, kena_, _wolę_,
  { {0x29071032, 0x63a4006c, 0xf1b90802, 0x00000000}},  //   jena_, _hiin, íše_,
  { {0x63a41aa2, 0x6d5e0127, 0xbc6a00a1, 0x00000000}},  //   _kiin, ripa, جمان_,
  { {0x31af005d, 0x657a0258, 0x00000000, 0x00000000}},  //   _yüz_, zoth,   ,
  { {0xdb000efe, 0xcb070076, 0x63a40ac2, 0x00000000}},  //   _jimé, زيون_, _miin,
  { {0x29071aa3, 0x63a401c2, 0x69db007d, 0x00000000}},  //   gena_, _liin, _निरी,
  { {0x6d5c01a3, 0x98be001a, 0xa7fc006b, 0x00000000}},  //   _imra, _altă_, _axır,
  { {0xceb4005f, 0x44200428, 0x63a418ec, 0x00000000}},  //   ncə_, _či_, _niin,
  { {0x55060147, 0x657a009d, 0xcf93034e, 0x00000000}},  //   очна, toth, וטה_,
  { {0x63760047, 0x443e042c, 0x63aa01ee, 0x00000000}},  //   mány, tyt_, _pufn,
  { {0xd6cf046c, 0xad1b007b, 0xceb4006b, 0x00000000}},  //   _от_, בויר, kcə_,
  { {0x657a1784, 0x443e0006, 0x74ba013d, 0x00000000}},  //   soth, ryt_, _श्रृ,
  { {0x657a00b5, 0x6d5c0107, 0x63a404cb, 0x00000000}},  //   poth, _omra, _diin,
  { {0x660201aa, 0x63aa0521, 0x443e0027, 0x00000000}},  //   _ipok, _tufn, pyt_,
  { {0x63a4000d, 0x403500ed, 0x3cfd0061, 0x00000000}},  //   _fiin, чевс, र्फे_,
  { {0x29070f53, 0xa3b70070, 0x234902fd, 0x00000000}},  //   zena_, _باور_, _دستی_,
  { {0xd3790119, 0xdb000919, 0x00000000, 0x00000000}},  // [3a50] jući_, _gimé,   ,
  { {0xd3790166, 0x8d7405f3, 0x66020020, 0x00000000}},  //   dući_, والا, _mpok,
  { {0x29070091, 0x76400016, 0x823402fd, 0x00000000}},  //   vena_, hymy, _فریا,
  { {0x6d5c1aa4, 0x29070058, 0xddc40089, 0x00000000}},  //   _emra, wena_, dziņ,
  { {0xd3790091, 0x63760010, 0x00000000, 0x00000000}},  //   gući_, gány,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x29070390, 0x6d451aa5, 0x09d70061, 0x00000000}},  //   rena_, mkha, _ठिकठ,
  { {0x290703b6, 0x3f5701d5, 0x27e70bdc, 0x00000000}},  //   sena_, għux_, runn_,
  { {0x2907062b, 0x7769002b, 0x63a4006c, 0x00000000}},  //   pena_, rnex, _riin,
  { {0x63a40b3e, 0x6d4518ce, 0x34390025, 0x00000000}},  //   _siin, nkha, مسجد_,
  { {0xdb000173, 0x66020c01, 0x63a4006c, 0x00000000}},  //   _simé, _epok, _piin,
  { {0x69c900c7, 0xd7fa009b, 0xd76300a1, 0x00000000}},  //   _kwee, _להעל, _تنصی,
  { {0x63a4003c, 0x00000000, 0x00000000, 0x00000000}},  //   _viin,   ,   ,
  { {0x25bf1aa6, 0xd13200f3, 0x55ba009b, 0x00000000}},  //   mpul_, رمز_, _המסו,
  { {0x65611aa7, 0x34e8007b, 0x3d0f013d, 0x00000000}},  //   milh, _וווּ_, ड़ने_,
  { {0x0eaa008b, 0x64410061, 0x6561002b, 0x00000000}},  //   скай_, myli, lilh,
  { {0x6f1605d2, 0x9f5a000c, 0xee3a005e, 0x00000000}},  // [3a60] rdyc, _uppí_, щна_,
  { {0x656100c4, 0xd3790166, 0x98ac0006, 0x00000000}},  //   nilh, vući_, _kodą_,
  { {0x315700bd, 0x6441018e, 0x913b009b, 0x00000000}},  //   _זיין_, nyli, _העיק,
  { {0x2f5601e1, 0xeb970f93, 0x6da6003b, 0x00000000}},  //   _хтос, пих_, _нима,
  { {0xf38d0049, 0x00000000, 0x00000000, 0x00000000}},  //   בראָ,   ,   ,
  { {0x661b1aa8, 0x6d5c01a3, 0x63760010, 0x00000000}},  //   dvuk, _umra, rány,
  { {0x66021aa9, 0x65611aaa, 0x69c90019, 0x00000000}},  //   _spok, dilh, _ewee,
  { {0xddc40089, 0x85b80745, 0x45b801ab, 0x00000000}},  //   rziņ, олис_, огию_,
  { {0x75381aab, 0xeb9700d7, 0x65611824, 0x00000000}},  //   _povz, _хит_, filh,
  { {0xddc401c5, 0x00000000, 0x00000000, 0x00000000}},  //   pziņ,   ,   ,
  { {0x7640021e, 0x69c900bb, 0x656f009d, 0x00000000}},  //   symy, _zwee, écha,
  { {0xc7b300b3, 0x6d4b0089, 0x394c0048, 0x00000000}},  //   _טבע_, īgai, _hlds_,
  { {0x7afd051d, 0x66020235, 0x394c00f6, 0x00000000}},  //   _öste, _upok, _klds_,
  { {0x3f821744, 0xad9b008e, 0x656100fa, 0x00000000}},  //   _akku_, _apún, cilh,
  { {0x34fb1aac, 0x7d150059, 0x4acc01f5, 0x00000000}},  //   _ההוד, _razs, ाराव,
  { {0x35d1013d, 0x00000000, 0x00000000, 0x00000000}},  //   _दौड़,   ,   ,
  { {0xc434026c, 0x6d451aad, 0x394c0133, 0x00000000}},  // [3a70] _رکھت, tkha, _olds_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d4501a3, 0x69c900fe, 0x661b0253, 0x00000000}},  //   rkha, _swee, zvuk,
  { {0x395e0296, 0x7fd600b3, 0x6d451aae, 0x00000000}},  //   _amts_, _קורס_, skha,
  { {0xe9d8007e, 0x64410036, 0x9f4300b9, 0x00000000}},  //   зкі_, zyli, nují_,
  { {0x3f89018e, 0xada4007e, 0x3eb90007, 0x00000000}},  //   llau_, _паўл, _hfst_,
  { {0x65610181, 0x3f890016, 0x9f4300b9, 0x00000000}},  //   vilh, olau_, hují_,
  { {0x69c91aaf, 0xeab00025, 0xf0940097, 0x00000000}},  //   _twee, _معك_, ענק_,
  { {0x2bcb0204, 0x656100fa, 0x64410016, 0x00000000}},  //   ाठवा, tilh, wyli,
  { {0x33290061, 0x64410056, 0x25bf1ab0, 0x00000000}},  //   _anax_, tyli, rpul_,
  { {0x65611824, 0x661b1ab1, 0x00000000, 0x00000000}},  //   rilh, svuk,   ,
  { {0x8c1a009b, 0x3cfd0164, 0x656100c4, 0x00000000}},  //   קורי, र्ते_, silh,
  { {0x3f890016, 0x656100c4, 0xdcfc1ab2, 0x00000000}},  //   dlau_, pilh, _skrč,
  { {0x59e00061, 0x26cf002d, 0xdb1e01aa, 0x00000000}},  //   _निसर, _hego_, nspò,
  { {0x6d8b00f6, 0x00000000, 0x00000000, 0x00000000}},  //   güam,   ,   ,
  { {0x26cf0046, 0x60c1038c, 0x9f4300b9, 0x00000000}},  //   _jego_, ılma, bují_,
  { {0xd1ba004b, 0x2013098e, 0x88bc00b9, 0x00000000}},  // [3a80] _بابا_, _esxi_, _sněm,
  { {0x3eb9000c, 0x00000000, 0x00000000, 0x00000000}},  //   _efst_,   ,   ,
  { {0xfb8200a1, 0x3f89068a, 0x201c0010, 0x00000000}},  //   نگری, blau_, _évi_,
  { {0x26cf0119, 0x0b461969, 0x9f5a01aa, 0x00000000}},  //   _nego_, ьнен, _espò_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe89409c0, 0x2b4d009d, 0xc983080c, 0x00000000}},  //   наль, _elec_, кущи,
  { {0x9f4300b9, 0x6d4e0056, 0x26cf0032, 0x00000000}},  //   zují_, _ilba, _bego_,
  { {0x27e001d9, 0x26cf00c4, 0xa614004d, 0x00000000}},  //   čin_, _cego_, емич,
  { {0xe9d700c0, 0xe4e60088, 0x6a830641, 0x00000000}},  //   _окт_, мінн, _алта,
  { {0x4a57009b, 0x69c2018f, 0x9f4300b9, 0x00000000}},  //   _חשמל_, mpoe, vují_,
  { {0x61e60109, 0x3f890016, 0xdb001ab3, 0x00000000}},  //   erkl, ylau_, _limí,
  { {0xf6d6089d, 0x25af1ab4, 0xe6660a85, 0x00000000}},  //   _آزاد, _fugl_, _отло,
  { {0x51870a30, 0x9294007e, 0x69c200bb, 0x00000000}},  //   дува, каюц, npoe,
  { {0x9f4300b9, 0x3f89005b, 0x00000000, 0x00000000}},  //   rují_, wlau_,   ,
  { {0x3f890016, 0x33290066, 0x00000000, 0x00000000}},  //   tlau_, _tnax_,   ,
  { {0x9f580263, 0x5f9402b0, 0x2bd8013d, 0x00000000}},  //   ntrè_, вист, _डिजा,
  { {0x200500b9, 0xd25200a1, 0x88bc00b9, 0x00000000}},  // [3a90] ůli_, _منٹ_, _vněj,
  { {0x30150373, 0x3f8903d1, 0x69c2005b, 0x00000000}},  //   _здор, slau_, dpoe,
  { {0x2b4d1ab5, 0xd379016e, 0x99490142, 0x00000000}},  //   _plec_, suću_, núť_,
  { {0x309a00b6, 0x6d4e0065, 0xceeb0014, 0x00000000}},  //   _משתמ, _elba, _بردن_,
  { {0x6f0d1ab6, 0x6eba0104, 0x9f5a000c, 0x00000000}},  //   meac, _מזרח, _uppá_,
  { {0x6f0d002a, 0x6813006b, 0x26cf0022, 0x00000000}},  //   leac, _hədə, _sego_,
  { {0x26cf0285, 0x7c841ab7, 0x6813006b, 0x00000000}},  //   _pego_, _ауте, _kədə,
  { {0x6f0d002a, 0xac941001, 0x5bcb0061, 0x00000000}},  //   neac, _расш, ाठीव,
  { {0x6813005f, 0xb17b1ab8, 0x3989000c, 0x00000000}},  //   _mədə, trål, húsi_,
  { {0xe00f02d2, 0x6f0d0051, 0xb4e9007d, 0x00000000}},  //   ाबाद_, heac, यले_,
  { {0x26cf0046, 0x6368014a, 0x6f0d00eb, 0x00000000}},  //   _tego_, kınt, keac,
  { {0x81d70044, 0x59c60164, 0x6813006b, 0x00000000}},  //   _সহজ_, रीकर, _nədə,
  { {0x6f0d002a, 0x69d9010f, 0x15f3013d, 0x00000000}},  //   deac, nswe, _आमिर_,
  { {0x463a0049, 0x69d90c4c, 0x00000000, 0x00000000}},  //   _מענע, iswe,   ,
  { {0x6f0d002a, 0x6813006b, 0xf8b201ce, 0x00000000}},  //   feac, _bədə, רשל_,
  { {0x6f0d1ab9, 0xd2521095, 0x69d901d6, 0x00000000}},  //   geac, _منع_, kswe,
  { {0x9f5812a3, 0xdb0000c4, 0x20d6007e, 0x00000000}},  // [3aa0] ntré_, _limã, _пінс,
  { {0x69d90116, 0x60d5004a, 0x98a5000a, 0x00000000}},  //   dswe, cazm, _anlč_,
  { {0xdd8f039d, 0xd910007a, 0xc173009b, 0x00000000}},  //   حول_, ییر_, _תחת_,
  { {0x6f0d0051, 0x3ce61aba, 0x69c200d9, 0x00000000}},  //   ceac, şov_, tpoe,
  { {0xdcfc0089, 0x69d90d18, 0x00000000, 0x00000000}},  //   _ekrā, gswe,   ,
  { {0x69c20116, 0x672b1abb, 0x48fb0316, 0x00000000}},  //   rpoe, _angj, ल्लो_,
  { {0x2d98001f, 0x69c200c7, 0x69d901d6, 0x00000000}},  //   _ihre_, spoe, aswe,
  { {0xa8470025, 0x9f58000c, 0x3ea60089, 0x00000000}},  //   عليم_, ftré_, žotu_,
  { {0xdb0e00f6, 0x00000000, 0x00000000, 0x00000000}},  //   _rubè,   ,   ,
  { {0x6b820004, 0x672b1abc, 0xdb0000f6, 0x00000000}},  //   loog, _engj, _himà,
  { {0xd49801fb, 0x6b8201ee, 0xdb1c004a, 0x00000000}},  //   ької_, ooog, _atré,
  { {0xd25100a1, 0x88bc00b9, 0x00000000, 0x00000000}},  //   لنج_, _sněh,   ,
  { {0xd46a025a, 0xf2041abd, 0x6f0d0d28, 0x00000000}},  //   تحکم_, ляро, veac,
  { {0x6b8200bb, 0x291c1792, 0xdb1c0048, 0x00000000}},  //   hoog, ndva_, _dtré,
  { {0x6f0d002a, 0x7ae00009, 0x60d50c8a, 0x00000000}},  //   teac, _odmt, razm,
  { {0x6813005f, 0x69c00521, 0x69d91abe, 0x00000000}},  //   _qədə, _otme, yswe,
  { {0x6f0d0195, 0x623502b0, 0xf1a702a8, 0x00000000}},  // [3ab0] reac, _репу, _прон,
  { {0x6f0d002a, 0x32090022, 0x4ea40b7b, 0x00000000}},  //   seac, _ipay_, урса,
  { {0x2fd90054, 0x69c00995, 0xceb4006b, 0x00000000}},  //   _توجد_, _atme, mdən_,
  { {0xeab000b8, 0x6b82006c, 0x69d9010f, 0x00000000}},  //   معه_, goog, tswe,
  { {0xdb07009f, 0x61fd006c, 0xdb0000c4, 0x00000000}},  //   _stjó, ntsl, _simã,
  { {0xceb40163, 0xfbd3023c, 0x69d9046a, 0x00000000}},  //   ndən_, _متر_, rswe,
  { {0x69c01abf, 0xe7391ac0, 0x6b8201d6, 0x00000000}},  //   _etme, дей_, boog,
  { {0x7bc516d4, 0x6abb00e7, 0xdb0000f6, 0x00000000}},  //   mphu, _ufuf, _gimà,
  { {0xceb4005f, 0x57240025, 0x998d00e5, 0x00000000}},  //   kdən_, طريق, _greş_,
  { {0x637d0047, 0xdb0e008e, 0xdb0000c4, 0x00000000}},  //   mény, _rubé, _timã,
  { {0x9f5800f4, 0xa3cc0309, 0x79830058, 0x00000000}},  //   stré_, शील_, monw,
  { {0x3fc8026c, 0x06990025, 0x672b0065, 0x00000000}},  //   ہدری_, _قناة_, _ungj,
  { {0x20d60088, 0xceb4006b, 0xe29717fa, 0x00000000}},  //   ківс, fdən_, каю_,
  { {0x6e20064d, 0xdb0901c3, 0x00000000, 0x00000000}},  //   _ámbi, _bieë,   ,
  { {0x61fd0112, 0x998f0006, 0x00000000, 0x00000000}},  //   atsl, lygų_,   ,
  { {0xdb0e10cb, 0x9f5a00ea, 0x7983005b, 0x00000000}},  //   _tubé, _oppå_, honw,
  { {0xfe43007c, 0x29050f9e, 0x27380010, 0x00000000}},  // [3ac0] анто, _obla_, _pénz_,
  { {0x64450004, 0x63ae0051, 0x9f4300c4, 0x00000000}},  //   _ühis, _úiné, rujá_,
  { {0x6b8200b5, 0x69c01ac1, 0x7983005b, 0x00000000}},  //   toog, _stme, donw,
  { {0x27380a50, 0x29050095, 0x00000000, 0x00000000}},  //   _fény_, _abla_,   ,
  { {0x79830016, 0x2d980af2, 0x637d0010, 0x00000000}},  //   fonw, _thre_, gény,
  { {0xf8060088, 0x3ea60089, 0x00000000, 0x00000000}},  //   вчин, žots_,   ,
  { {0x9d1b0476, 0x7d1c1ac2, 0x290e1ac3, 0x00000000}},  //   _קולט, _iars, refa_,
  { {0xceb4006b, 0x290e013e, 0xd056006b, 0x00000000}},  //   zdən_, sefa_, übəs,
  { {0x7d1c0089, 0x68ed0010, 0xbb431a4d, 0x00000000}},  //   _kars, ándé, _тетк,
  { {0xf1dc013d, 0x7d1c1ac4, 0xdcfe01ed, 0x00000000}},  //   _बिजन, _jars, kopč,
  { {0x2955005e, 0xd6d203ec, 0xe2f90088, 0x00000000}},  //   _сътр, _نقض_, нені_,
  { {0x7d1c05fe, 0x61fd093b, 0xb17b01c9, 0x00000000}},  //   _lars, ttsl, pråk,
  { {0xceb4006b, 0xa3e6006e, 0x7d1c002d, 0x00000000}},  //   tdən_, यूज_, _oars,
  { {0x70bf02d2, 0x61fd0030, 0x7d1c0d8f, 0x00000000}},  //   ्रेल, rtsl, _nars,
  { {0xceb4005f, 0x224d05d2, 0xd37b0f97, 0x00000000}},  //   rdən_, šek_, _очи_,
  { {0x65681ac5, 0x3eaf0030, 0xd437009b, 0x00000000}},  //   lidh, øgt_, _ירוק_,
  { {0x7d1c0030, 0x6448007f, 0x680a006b, 0x00000000}},  // [3ad0] _bars, lydi, _hədd,
  { {0xbebb008d, 0x2d8700f4, 0x7d1c0091, 0x00000000}},  //   _anët, ône_, _cars,
  { {0x6ca702a8, 0xe1ff147e, 0x7d1c010f, 0x00000000}},  //   траж, ltó_, _dars,
  { {0x2b8e004f, 0x63ad1ac6, 0x9f3501e1, 0x00000000}},  //   ných_, _jian, _семі,
  { {0x7d1c1ac7, 0xe1ff1ac8, 0x0f360049, 0x00000000}},  //   _fars, ntó_, _ערשט_,
  { {0x65681ac9, 0x7d1c010a, 0x6f1d0210, 0x00000000}},  //   jidh, _gars, _hasc,
  { {0xccf200b6, 0x2b8e0428, 0xdb09009d, 0x00000000}},  //   _לכם_, kých_, _lieé,
  { {0xe6190265, 0x6f1d0270, 0x4429016e, 0x00000000}},  //   еди_, _jasc, _ča_,
  { {0x645a0089, 0x6b9b00ea, 0xe1ff0010, 0x00000000}},  //   ezti, _ihug, jtó_,
  { {0x6f1d0198, 0x63ad006c, 0xc9841aca, 0x00000000}},  //   _lasc, _aian, _кухи,
  { {0x63ad0198, 0x6f1d0009, 0xe1ff00f6, 0x00000000}},  //   _bian, _oasc, etó_,
  { {0xc7b2012e, 0x63ad1acb, 0x18a40088, 0x00000000}},  //   _הבא_, _cian, _таєм,
  { {0x63ad0149, 0x65680020, 0x7d070a26, 0x00000000}},  //   _dian, bidh, _objs,
  { {0x673b092f, 0x88e50044, 0xd6d900b4, 0x00000000}},  //   ljuj, প্রক, lał_,
  { {0xdee60001, 0x6f1d0a86, 0x63ad1acc, 0x00000000}},  //   лови, _basc, _fian,
  { {0x673b0825, 0x63ad0a60, 0xd6d90036, 0x00000000}},  //   njuj, _gian, nał_,
  { {0x7d1c0006, 0xdd9206b4, 0x6e930025, 0x00000000}},  // [3ae0] _pars, مور_, ملفا,
  { {0xdca60001, 0x442704cb, 0x6f1d0051, 0x00000000}},  //   гази, _krn_, _easc,
  { {0x6f1d0490, 0xd6d90036, 0x7c9601ab, 0x00000000}},  //   _fasc, kał_, урац,
  { {0x7d1c0046, 0x6b9b0051, 0x6f1d0a86, 0x00000000}},  //   _wars, _chug, _gasc,
  { {0x673b05fa, 0x298a017a, 0x7d1c0006, 0x00000000}},  //   djuj, нско_, _tars,
  { {0xc27b007b, 0xb6050059, 0x00000000, 0x00000000}},  //   ערסי, _mašč,   ,
  { {0x37aa017f, 0x8b960545, 0x6e240026, 0x00000000}},  //   нтин_, _брач, lvib,
  { {0x6f040181, 0x7bde1864, 0x7e690087, 0x00000000}},  //   nfic, mspu, _žepi,
  { {0x2b8e0428, 0x64481acd, 0x442700f8, 0x00000000}},  //   vých_, wydi, _arn_,
  { {0x201a00f6, 0x00000000, 0x00000000, 0x00000000}},  //   _ospi_,   ,   ,
  { {0x65680020, 0x33750088, 0x291e001a, 0x00000000}},  //   ridh, игор, _iata_,
  { {0x291e1ace, 0x63ad0719, 0x76490061, 0x00000000}},  //   _hata_, _qian, byey,
  { {0x291e0149, 0xe534008b, 0x645a0047, 0x00000000}},  //   _kata_, _вель, szti,
  { {0xe1ff1acf, 0xe6930025, 0x4427000a, 0x00000000}},  //   rtó_, _الهد, _frn_,
  { {0x291e0d56, 0x6f0411c5, 0xe1ff0211, 0x00000000}},  //   _mata_, ffic, stó_,
  { {0x2f1805c7, 0x291e0036, 0x7bde05b7, 0x00000000}},  //   лось_, _lata_, dspu,
  { {0x6b9b005b, 0xdb0e004a, 0x00000000, 0x00000000}},  // [3af0] _rhug, _cubí,   ,
  { {0x6b9b000b, 0x291e0747, 0x6f1d010f, 0x00000000}},  //   _shug, _nata_, _wasc,
  { {0xc17400b6, 0x6f1d11dc, 0xb60501d9, 0x00000000}},  //   _לחץ_, _tasc, _zašč,
  { {0xfbd0007a, 0x4c94007c, 0x00000000, 0x00000000}},  //   ستم_, щихс,   ,
  { {0x291e0b9a, 0x673b012d, 0x00000000, 0x00000000}},  //   _bata_, vjuj,   ,
  { {0xed51026c, 0xd6d90046, 0x291e0035, 0x00000000}},  //   _بھر_, wał_, _cata_,
  { {0x6b9b0051, 0xd6d90036, 0x9835007e, 0x00000000}},  //   _thug, tał_, рэлі,
  { {0x5ba40783, 0x680a006b, 0x6b9b00e0, 0x00000000}},  //   _груз, _bədb, _uhug,
  { {0x291e000d, 0x7afb0022, 0xd6d90036, 0x00000000}},  //   _fata_, _icut, rał_,
  { {0x056502be, 0xd6d90046, 0x291e001a, 0x00000000}},  //   рвон, sał_, _gata_,
  { {0x2815007a, 0x00000000, 0x00000000, 0x00000000}},  //   _خواس,   ,   ,
  { {0x25ee0061, 0xb6050ed9, 0x25ae1ad0, 0x00000000}},  //   _आमची_, _pašč, _eifl_,
  { {0x291e011c, 0xeb3a0049, 0xbb3a0049, 0x00000000}},  //   _yata_, דערש, דערי,
  { {0x64a50816, 0xdb150065, 0x00000000, 0x00000000}},  //   _кала, _buzë,   ,
  { {0x44271ad1, 0xdb1c000c, 0x3f47006c, 0x00000000}},  //   _urn_, _strí, _nõus_,
  { {0xcc36026c, 0x6d551ad2, 0x6e241ad3, 0x00000000}},  //   یراع, _alza, tvib,
  { {0x6f041ad2, 0xdc3c00ca, 0x4d66007e, 0x00000000}},  // [3b00] rfic, ršča, акав,
  { {0x6f0400d4, 0x7afb0835, 0x6e24004a, 0x00000000}},  //   sfic, _acut, rvib,
  { {0x291e04d4, 0x60dc19d5, 0x3dc90058, 0x00000000}},  //   _rata_, marm, apaw_,
  { {0x60dc0207, 0x291e0091, 0x7bde000c, 0x00000000}},  //   larm, _sata_, rspu,
  { {0x291e0f87, 0xda630954, 0x00000000, 0x00000000}},  //   _pata_, овци,   ,
  { {0x60dc000c, 0x07e6003b, 0x00000000, 0x00000000}},  //   narm, ацим,   ,
  { {0xa8a3005e, 0x8c460517, 0x25ae0087, 0x00000000}},  //   орък, _теве, _rifl_,
  { {0x60dc01a3, 0xab740014, 0xdb07000c, 0x00000000}},  //   harm, _انرژ, _stjö,
  { {0x291e023a, 0x60dc014a, 0x00000000, 0x00000000}},  //   _tata_, karm,   ,
  { {0x60dc1ad4, 0xe4a6007c, 0x00000000, 0x00000000}},  //   jarm, ирно,   ,
  { {0x332004bd, 0x60dc0027, 0xd49a005e, 0x00000000}},  //   _baix_, darm, ъри_,
  { {0x680a005f, 0x3d06006e, 0x60d71ad5, 0x00000000}},  //   _tədb, स्ते_, _sexm,
  { {0x60c20035, 0x98be000a, 0x00000000, 0x00000000}},  //   _şoma, _lotč_,   ,
  { {0xa187008b, 0x224b0039, 0x51870878, 0x00000000}},  //   рымл, ryck_, рума,
  { {0x656f009d, 0x657d0010, 0x00000000, 0x00000000}},  //   èche, éshe,   ,
  { {0xa857009b, 0x64470052, 0x00000000, 0x00000000}},  //   בילה_, äjie,   ,
  { {0x23690f5c, 0x60dc002d, 0x60d71ad6, 0x00000000}},  // [3b10] _imaj_, barm, _texm,
  { {0x60dc1ad7, 0x7afb001a, 0x6144003b, 0x00000000}},  //   carm, _scut, _мења,
  { {0x92d90044, 0x5ba7007e, 0x00000000, 0x00000000}},  //   ালী_, ардз,   ,
  { {0x3dc9002b, 0x98be000a, 0x00000000, 0x00000000}},  //   ppaw_, _dotč_,   ,
  { {0xbf3601f8, 0x00000000, 0x00000000, 0x00000000}},  //   _הארץ_,   ,   ,
  { {0x2bd900a6, 0xdcfc0036, 0x3f47006c, 0x00000000}},  //   _مارک_, _okrę, _tõus_,
  { {0x3158009b, 0x23690173, 0x00000000, 0x00000000}},  //   שיון_, _omaj_,   ,
  { {0x27e90119, 0x7afb0521, 0x32020062, 0x00000000}},  //   čan_, _ucut, ytky_,
  { {0xd4d90099, 0x80dd0044, 0x387e1ad8, 0x00000000}},  //   льні_, _বান্, _extr_,
  { {0x60dc006b, 0x4535034b, 0x69cb01c3, 0x00000000}},  //   xarm, схит, mpge,
  { {0xb8950025, 0x60dc0030, 0x2b9c0802, 0x00000000}},  //   _الاع, varm, síce_,
  { {0x60dc1ad9, 0x21211ada, 0x63b801ed, 0x00000000}},  //   warm, _aahh_, _duvn,
  { {0xa50906b6, 0xdb1c0036, 0x212100f6, 0x00000000}},  //   _бела_, _zwró, _bahh_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x03a6025f, 0x60dc0211, 0x32020161, 0x00000000}},  //   _лико, rarm, stky_,
  { {0x60dc008e, 0xd007012b, 0x39450058, 0x00000000}},  //   sarm, љете_, _lols_,
  { {0x60dc0095, 0xf1bf076d, 0x00000000, 0x00000000}},  // [3b20] parm, lván_,   ,
  { {0xc6920097, 0x61e40095, 0x51f700a1, 0x00000000}},  //   לאן_, _ivil, _اسٹر,
  { {0xdb1c029d, 0x61e402cc, 0xbc6a03ec, 0x00000000}},  //   _atrá, _hvil, دمان_,
  { {0x7bc300d4, 0x61e40635, 0x39450026, 0x00000000}},  //   ínua, _kvil, _aols_,
  { {0x21210022, 0x88cf0044, 0x00000000, 0x00000000}},  //   _yahh_, _রাজক,   ,
  { {0x39450f36, 0xdb1c0048, 0x636f0173, 0x00000000}},  //   _cols_, _dtrá, _kònè,
  { {0xa3f208b7, 0x3945000a, 0x2b440087, 0x00000000}},  //   _জন্য_, _dols_, _tomc_,
  { {0x61e40c43, 0xb8ef006e, 0x00000000, 0x00000000}},  //   _ovil, _व्_,   ,
  { {0xdcfc0036, 0x00000000, 0x00000000, 0x00000000}},  //   _skrę,   ,   ,
  { {0xb9960054, 0x394509f7, 0xc7b80521, 0x00000000}},  //   _الطب, _gols_, _tuđ_,
  { {0x61e41adb, 0xdb1c01dc, 0x290c0066, 0x00000000}},  //   _avil, _ztrá, _ibda_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc69600a1, 0x926b00ed, 0x61e41adc, 0x00000000}},  //   _اشاع, урна_, _cvil,
  { {0x92d90055, 0xd258007e, 0x602300b9, 0x00000000}},  //   ালে_, сцю_, jímá,
  { {0xf484007a, 0x00000000, 0x00000000, 0x00000000}},  //   _باشی,   ,   ,
  { {0xe7f00316, 0x61ef1add, 0x3d06006e, 0x00000000}},  //   _घटना_, prcl, स्से_,
  { {0x7bc70ade, 0x93bc0035, 0x20030925, 0x00000000}},  // [3b30] _stju, zvăl, stji_,
  { {0x6ca70745, 0xd04e013f, 0x00000000, 0x00000000}},  //   бреж, habə,   ,
  { {0xdb1c1ade, 0xd25101ef, 0x61e4045d, 0x00000000}},  //   _strá, _رنگ_, _zvil,
  { {0x3945153c, 0x33fb0049, 0x6bd40025, 0x00000000}},  //   _sols_, רהאנ, ستمر,
  { {0x39450129, 0xd9451adf, 0x00000000, 0x00000000}},  //   _pols_, жели,   ,
  { {0x680a006b, 0x00000000, 0x00000000, 0x00000000}},  //   _səda,   ,   ,
  { {0x39451ae0, 0xf99000b8, 0x68e80142, 0x00000000}},  //   _vols_, ربه_, _dddd,
  { {0x290c01d5, 0x9b58004c, 0x6d470211, 0x00000000}},  //   _ebda_, _лист_, _hoja,
  { {0x6d4700f5, 0x857900ed, 0x6b8b01f4, 0x00000000}},  //   _koja, исот_, mogg,
  { {0x6b8b0fcf, 0xe5690d03, 0xf1bf0010, 0x00000000}},  //   logg, риод_, tván_,
  { {0x61e40198, 0x6d470142, 0x03a60072, 0x00000000}},  //   _svil, _moja, жино,
  { {0x6d470181, 0x6b8b0007, 0x9655005e, 0x00000000}},  //   _loja, nogg, _мълч,
  { {0x84e51ae1, 0x057402fd, 0xf1bf1ae2, 0x00000000}},  //   _долж, _کاند, sván_,
  { {0x412a0805, 0x6d470778, 0x28cf0164, 0x00000000}},  //   шого_, _noja, _स्मि,
  { {0x7ae90107, 0x06ae0044, 0x752300e7, 0x00000000}},  //   _odet, ছুদি, _ianz,
  { {0x75231ae3, 0x7ae90061, 0x61e405fe, 0x00000000}},  //   _hanz, _ndet, _tvil,
  { {0x75231515, 0xee3a0113, 0x92e9057d, 0x00000000}},  // [3b40] _kanz, шна_, _طريق_,
  { {0x3d1403d7, 0x7c9600d7, 0x75230032, 0x00000000}},  //   ड़ें_, орец, _janz,
  { {0x752310ea, 0x6d470874, 0x3a2d0022, 0x00000000}},  //   _manz, _doja, _arep_,
  { {0x75230211, 0xeb970057, 0xddd60036, 0x00000000}},  //   _lanz, оих_, rzył,
  { {0x6a1605f3, 0xc9aa0e82, 0x49a6025f, 0x00000000}},  //   تبار, авде_, ојка,
  { {0xed5a012b, 0xe9180451, 0x7ae903b6, 0x00000000}},  //   _тог_, сокі_, _edet,
  { {0xd7f00025, 0xfc030679, 0x69c900b0, 0x00000000}},  //   ركة_, _опро, _etee,
  { {0x75231ae4, 0xdb1c0dba, 0x798a0022, 0x00000000}},  //   _aanz, _stræ, sofw,
  { {0x7523097e, 0x3a2d02e1, 0xd04e006b, 0x00000000}},  //   _banz, _grep_, rabə,
  { {0x70b9001c, 0x75230207, 0x98a600d7, 0x00000000}},  //   _आलेल, _canz, _дизе,
  { {0x75231ad2, 0x00000000, 0x00000000, 0x00000000}},  //   _danz,   ,   ,
  { {0x80dd0044, 0x7c2e0087, 0xd04e006b, 0x00000000}},  //   _বাধ্, _mrbr, qabə,
  { {0xa2bc013d, 0x00000000, 0x00000000, 0x00000000}},  //   _एलर्,   ,   ,
  { {0x7523001f, 0x3d14013d, 0x1a9b0049, 0x00000000}},  //   _ganz, ड़ों_, ייכע,
  { {0x6d470211, 0x20990783, 0x4f6b00e2, 0x00000000}},  //   _roja, сквы_, ашам_,
  { {0x7523000b, 0x6d470145, 0x1fa4007c, 0x00000000}},  //   _zanz, _soja, друг,
  { {0x7c2e0fdb, 0x3eaf010f, 0x5d5500e3, 0x00000000}},  // [3b50] _arbr, ägt_, пкат,
  { {0xdd9101b7, 0x442e00ea, 0x80f50783, 0x00000000}},  //   روا_, _krf_, _эпох,
  { {0x5b15005e, 0x6d4702b2, 0x69c91aaf, 0x00000000}},  //   змет, _voja, _stee,
  { {0x501a00b6, 0x442e0203, 0x3a2d0133, 0x00000000}},  //   _פורו, _mrf_, _prep_,
  { {0x7f3a00b3, 0x6b8b01d6, 0x7c2e010f, 0x00000000}},  //   _הערו, rogg, _erbr,
  { {0x6d5e010f, 0xf77102fd, 0x6b8b0197, 0x00000000}},  //   chpa, کات_, sogg,
  { {0x6b8b0207, 0x00000000, 0x00000000, 0x00000000}},  //   pogg,   ,   ,
  { {0x75230207, 0x3a2d016c, 0x657a1ae5, 0x00000000}},  //   _sanz, _trep_, enth,
  { {0x28cf02fb, 0x7523138a, 0x443e0061, 0x00000000}},  //   _स्थि, _panz, ext_,
  { {0x442e00f8, 0x00000000, 0x00000000, 0x00000000}},  //   _brf_,   ,   ,
  { {0x7523000d, 0xb97a007b, 0xccf20049, 0x00000000}},  //   _vanz, _פרעז, עכט_,
  { {0x889a009b, 0x63760059, 0x442e1408, 0x00000000}},  //   _הבעי, kšne, _drf_,
  { {0x7523000b, 0xd25200a1, 0x442e0d1a, 0x00000000}},  //   _tanz, رنس_, _erf_,
  { {0x442e175f, 0x752300e7, 0x3eb90022, 0x00000000}},  //   _frf_, _uanz, _agst_,
  { {0x8fa6005e, 0x00000000, 0x00000000, 0x00000000}},  //   заве,   ,   ,
  { {0x9f580023, 0x00000000, 0x00000000, 0x00000000}},  //   murë_,   ,   ,
  { {0x2ee0002a, 0x63a41ae6, 0x31710668, 0x00000000}},  // [3b60] raif_, _ihin, bizz_,
  { {0x6f0f0061, 0xceb4006b, 0x61e600eb, 0x00000000}},  //   _ebcc, ddət_, mskl,
  { {0xa3de0316, 0x63a40082, 0x61e600f8, 0x00000000}},  //   दीप_, _khin, lskl,
  { {0xeb9a0057, 0x6d5e07af, 0x0b4607d0, 0x00000000}},  //   щие_, shpa, янен,
  { {0x61e60039, 0xf8b000a1, 0x63a41ae7, 0x00000000}},  //   nskl, چکا_, _mhin,
  { {0xe894085f, 0xdb1c0a5d, 0x9f580023, 0x00000000}},  //   маль, _strä, kurë_,
  { {0x55f80055, 0xdca60072, 0xab2a142c, 0x00000000}},  //   _অনেক_, _хави, _лова_,
  { {0x963402a8, 0x442e0288, 0x61e60203, 0x00000000}},  //   дниц, _rrf_, kskl,
  { {0xbb3b00b6, 0x80dd0055, 0x442e00fa, 0x00000000}},  //   _פעמי, _বাস্, _srf_,
  { {0x443e1ae8, 0x442e00c4, 0x63a4107b, 0x00000000}},  //   txt_, _prf_, _ahin,
  { {0xb4bc006e, 0x63a41ae9, 0x9f580023, 0x00000000}},  //   _अली_, _bhin, gurë_,
  { {0x63a403ef, 0x7ae20020, 0x442e0a5e, 0x00000000}},  //   _chin, naot, _vrf_,
  { {0x46a31aea, 0x61e600f8, 0x442e0288, 0x00000000}},  //   _зацв, gskl, _wrf_,
  { {0x442e00c4, 0x64740140, 0x6d4a0abc, 0x00000000}},  //   _trf_, _оглу, öfal,
  { {0x403401bd, 0xd5a5007a, 0x3171002b, 0x00000000}},  //   нерс, _تلوی, rizz_,
  { {0x63a40fff, 0x6d5c16fa, 0xa2de0061, 0x00000000}},  //   _ghin, _alra, परण्,
  { {0xceb4006b, 0x442c06d3, 0x00000000, 0x00000000}},  // [3b70] ddəs_, lvd_,   ,
  { {0x6ca7005e, 0x00000000, 0x00000000, 0x00000000}},  //   преж,   ,   ,
  { {0x8c190426, 0xdb1c0023, 0x00000000, 0x00000000}},  //   تيار_, _gurë,   ,
  { {0x63a40023, 0x6d5c0232, 0x00000000, 0x00000000}},  //   _xhin, _elra,   ,
  { {0x539c009b, 0x81df0044, 0x6f0d03cd, 0x00000000}},  //   זיאו, দূর_, mfac,
  { {0x6f0d1aeb, 0xceb201ce, 0x34db006e, 0x00000000}},  //   lfac, _שיך_, _मजेद,
  { {0x29c20359, 0xdb1c1aec, 0xb8e5006e, 0x00000000}},  //   _eða_, _strå, _एल_,
  { {0x6f0d001f, 0x8038009b, 0x6d4502e1, 0x00000000}},  //   nfac, לנוע_, ljha,
  { {0x63a40675, 0x629a0036, 0x09d70044, 0x00000000}},  //   _rhin, ętok, _সমকা,
  { {0xe576008b, 0x63a403ef, 0x9f580065, 0x00000000}},  //   дзь_, _shin, turë_,
  { {0xceb4005f, 0x63a41aed, 0x60de0087, 0x00000000}},  //   ndər_, _phin, _repm,
  { {0xe29a0fc0, 0x68e31aee, 0x61e601a2, 0x00000000}},  //   жам_, land, tskl,
  { {0xa3b902fb, 0x27e00166, 0x6f0d1445, 0x00000000}},  //   _अंक_, ćine_, dfac,
  { {0x10a61123, 0x61e61aef, 0x66091af0, 0x00000000}},  //   дигн, rskl, mtek,
  { {0x63a40038, 0x6609000c, 0x6f0d0af2, 0x00000000}},  //   _thin, ltek, ffac,
  { {0x7e7b1af1, 0x67290211, 0x9f580129, 0x00000000}},  //   _župa, ndej, ltrú_,
  { {0x80dd0055, 0xe3a70167, 0xdd921095, 0x00000000}},  // [3b80] _বার্, _تشوی, نور_,
  { {0x68e30004, 0x6609156a, 0x67291af2, 0x00000000}},  //   jand, itek, hdej,
  { {0x68e30073, 0x7e641af3, 0x7ae2006c, 0x00000000}},  //   dand, szip, taot,
  { {0x672900ca, 0x25ee006e, 0xddc61af4, 0x00000000}},  //   jdej, _इटली_, _обми,
  { {0x68e3000c, 0x6729002b, 0x0eea0061, 0x00000000}},  //   fand, ddej, टणीस_,
  { {0x68e3006a, 0x6da600aa, 0x66090056, 0x00000000}},  //   gand, _цига, dtek,
  { {0xfbc3053f, 0x2bf5007e, 0xd794005e, 0x00000000}},  //   _абсо, _пятр, никъ,
  { {0xdca3025f, 0x1f5b0049, 0x61e91af5, 0x00000000}},  //   _раси, ַדיא, šeli,
  { {0x68e30f42, 0x66090047, 0xf8cf007d, 0x00000000}},  //   band, gtek, _स्वय,
  { {0x68e300d6, 0x7afd0039, 0x7ae000f8, 0x00000000}},  //   cand, _östr, _hemt,
  { {0x69c00142, 0x291c003b, 0xdb1c09af, 0x00000000}},  //   _hume, meva_, _auré,
  { {0x291c0ac2, 0x69c00020, 0x00000000, 0x00000000}},  //   leva_, _kume,   ,
  { {0x69c000f4, 0x394c0089, 0x7ae000d2, 0x00000000}},  //   _jume, _kods_, _memt,
  { {0x291c000d, 0x69c01ac6, 0xceb4005f, 0x00000000}},  //   neva_, _mume, ydər_,
  { {0x69c0000d, 0x6f0d09b0, 0x00000000, 0x00000000}},  //   _lume, tfac,   ,
  { {0x69c00a20, 0x291c0023, 0x394c0146, 0x00000000}},  //   _oume, heva_, _lods_,
  { {0x68e3006b, 0x6f0d030a, 0x7bce1af6, 0x00000000}},  // [3b90] yand, rfac, _atbu,
  { {0x291c0119, 0x61fd0ac2, 0x4fc700ed, 0x00000000}},  //   jeva_, musl, _осма,
  { {0x68e30073, 0x69c01af7, 0x291c0059, 0x00000000}},  //   vand, _aume, deva_,
  { {0x68e31af8, 0xe7f40061, 0x395e00d4, 0x00000000}},  //   wand, ींना_, _alts_,
  { {0xe9d8007e, 0x7ae00065, 0x395e000a, 0x00000000}},  //   дкі_, _demt, _blts_,
  { {0x69c00058, 0x291c1af9, 0x33290026, 0x00000000}},  //   _dume, geva_, _laax_,
  { {0x7ae01afa, 0x69c000ea, 0xa7b50184, 0x00000000}},  //   _femt, _eume, нсиј,
  { {0x68e30004, 0x69c003e2, 0x6609006c, 0x00000000}},  //   sand, _fume, ttek,
  { {0x68e30f59, 0xe6160a78, 0x67291afb, 0x00000000}},  //   pand, еды_, rdej,
  { {0x6609022b, 0x291c1028, 0x7bc800f4, 0x00000000}},  //   rtek, ceva_, _éduc,
  { {0x6609022b, 0x9f58009d, 0xdb1c009d, 0x00000000}},  //   stek, suré_, _suré,
  { {0x68e11afc, 0x660903e3, 0xdb1c009d, 0x00000000}},  //   _held, ptek, _puré,
  { {0x61fd006c, 0x7e7b1afd, 0x68e1006c, 0x00000000}},  //   gusl, _župn, _keld,
  { {0x2b5f00d4, 0x00000000, 0x00000000, 0x00000000}},  //   _lluc_,   ,   ,
  { {0x68e11afe, 0x03960ae0, 0x00000000, 0x00000000}},  //   _meld, _прия,   ,
  { {0x20050129, 0x61fd1a6f, 0x00000000, 0x00000000}},  //   àlia_, busl,   ,
  { {0xc7b200a3, 0x291c006b, 0xdee1007e, 0x00000000}},  // [3ba0] רבן_, yeva_, русi_,
  { {0x69c00059, 0x68e11aff, 0x8d7601b7, 0x00000000}},  //   _rume, _neld, راءا,
  { {0xdee60057, 0x69c01b00, 0x394c0857, 0x00000000}},  //   _пони, _sume, _rods_,
  { {0x6d430894, 0x394c01c5, 0x3f820023, 0x00000000}},  //   önar, _sods_, _ujku_,
  { {0x291c000d, 0x68e11b01, 0xdb00008e, 0x00000000}},  //   teva_, _beld, _simó,
  { {0x680a006b, 0x68e1008e, 0xdb0000f6, 0x00000000}},  //   _hədi, _celd, _cimò,
  { {0x291c0020, 0xdca3003b, 0x7bce0039, 0x00000000}},  //   reva_, _бари, _utbu,
  { {0x69c0000b, 0x6d4e1b02, 0x291c1b03, 0x00000000}},  //   _tume, _hoba, seva_,
  { {0x68e10461, 0x6d4e04eb, 0x394c1b04, 0x00000000}},  //   _feld, _koba, _tods_,
  { {0x68e108a5, 0x6d4e0c53, 0x25a70009, 0x00000000}},  //   _geld, _joba, _chnl_,
  { {0x6d4e025e, 0x236000b5, 0x24980030, 0x00000000}},  //   _moba, _blij_, ærm_,
  { {0x68e100b5, 0x61fd03b6, 0x680a006b, 0x00000000}},  //   _zeld, tusl, _nədi,
  { {0x3f800036, 0x00000000, 0x00000000, 0x00000000}},  //   dniu_,   ,   ,
  { {0x3f800036, 0x6d4e1b05, 0x61fd01a3, 0x00000000}},  //   eniu_, _noba, rusl,
  { {0x7d1e1b06, 0x680a006b, 0x61fd1b07, 0x00000000}},  //   deps, _bədi, susl,
  { {0x5f940069, 0x2d870059, 0xc49b009b, 0x00000000}},  //   гист, čnem_, _משות,
  { {0x6d4e0091, 0x2b9c00b9, 0x00000000, 0x00000000}},  // [3bb0] _boba, mích_,   ,
  { {0x6d4e1b08, 0x2b9c0802, 0x61ed0052, 0x00000000}},  //   _coba, lích_, _ival,
  { {0x61ed016c, 0x6d4e0119, 0x614400ed, 0x00000000}},  //   _hval, _doba, _сеќа,
  { {0x68e1000c, 0x2b9c0224, 0x00000000, 0x00000000}},  //   _seld, ních_,   ,
  { {0xaa580175, 0x68e10089, 0xe1ff008e, 0x00000000}},  //   ницу_, _peld, nuó_,
  { {0x6d4e0016, 0x7d1e0b4a, 0x61ed00f6, 0x00000000}},  //   _goba, ceps, _mval,
  { {0x61ed001c, 0x7c8400e2, 0x0138009b, 0x00000000}},  //   _lval, _буте, תרות_,
  { {0x6d4e0046, 0x2b9c0802, 0x68e100fe, 0x00000000}},  //   _zoba, jích_, _weld,
  { {0x27e00091, 0x68e103fb, 0x59f8073b, 0x00000000}},  //   ćina_, _teld, _петя_,
  { {0xdb1c01e3, 0x38cb0478, 0xe1ff004a, 0x00000000}},  //   _strø, _хуан_, duó_,
  { {0x61ed1b09, 0x3f800a62, 0x00000000, 0x00000000}},  //   _aval, yniu_,   ,
  { {0x2cb0006b, 0xe1ff0efe, 0x7d1e013e, 0x00000000}},  //   ündə_, rzón_, zeps,
  { {0x2d870027, 0x98a50173, 0x00000000, 0x00000000}},  //   čnej_, _malč_,   ,
  { {0x61ed000c, 0x00000000, 0x00000000, 0x00000000}},  //   _dval,   ,   ,
  { {0xdee60bbd, 0x6d4e0919, 0x2d931b0a, 0x00000000}},  //   кови, _roba, doxe_,
  { {0x2b9c01c8, 0x6d4e010f, 0x680a006b, 0x00000000}},  //   cích_, _soba, _qədi,
  { {0x6d4e002a, 0x672b0065, 0x44271624, 0x00000000}},  // [3bc0] _poba, _magj, _hsn_,
  { {0x672b0065, 0x3f800006, 0x4d631b0b, 0x00000000}},  //   _lagj, sniu_, акув,
  { {0x6faa012b, 0xfbc3008b, 0x61ed0091, 0x00000000}},  //   _овог_, абхо, _zval,
  { {0x7d1e1b0c, 0x4427114e, 0x00000000, 0x00000000}},  //   seps, _msn_,   ,
  { {0x44270022, 0x6d4e0122, 0xa96a00d7, 0x00000000}},  //   _lsn_, _toba, мида_,
  { {0x6f040142, 0x38c800a6, 0x2b9c00b9, 0x00000000}},  //   lgic, راتی_, zích_,
  { {0xebe31ae1, 0x317b009b, 0x44270943, 0x00000000}},  //   _восп, ורסמ, _nsn_,
  { {0x59dd013d, 0x6f0401ed, 0x00000000, 0x00000000}},  //   _नौकर, ngic,   ,
  { {0x692601f9, 0xdb1c04f6, 0x44270145, 0x00000000}},  //   _имаа, _jurí, _asn_,
  { {0x4427008a, 0x80b30061, 0x201a0052, 0x00000000}},  //   _bsn_, _आणले, _oppi_,
  { {0x44271b0d, 0x31780009, 0x2b9c0062, 0x00000000}},  //   _csn_, dirz_, tích_,
  { {0x1877009b, 0x6e240009, 0xe1ff008e, 0x00000000}},  //   _בעבר_, kwib, tuó_,
  { {0x2b9c0af6, 0x201a006c, 0x680a006b, 0x00000000}},  //   rích_, _appi_, _cədv,
  { {0x6b821b0e, 0x44270035, 0x660004cb, 0x00000000}},  //   hnog, _fsn_, mumk,
  { {0xa184008b, 0x4427012d, 0x6366000c, 0x00000000}},  //   рыял, _gsn_, _bónd,
  { {0x6f040026, 0x6366004a, 0x00000000, 0x00000000}},  //   ggic, _cónd,   ,
  { {0x63660211, 0x6b820091, 0xdbca006c, 0x00000000}},  // [3bd0] _dónd, dnog, _mõõt,
  { {0x7c3a09fc, 0x80dd0044, 0x6366008e, 0x00000000}},  //   _štra, _বাক্, _póng,
  { {0x6b82018e, 0xdb1c1b0f, 0x44270026, 0x00000000}},  //   fnog, _eurí, _xsn_,
  { {0x4ea7008b, 0xfe70026c, 0x636606c2, 0x00000000}},  //   _арга, حدہ_, _gónd,
  { {0x4efa00a0, 0x00000000, 0x00000000, 0x00000000}},  //   _אהרו,   ,   ,
  { {0x7762027b, 0xdb1c0035, 0x2ee9054c, 0x00000000}},  //   _alox, _curâ, laaf_,
  { {0x77620288, 0x672b0023, 0x17b900e2, 0x00000000}},  //   _blox, _pagj, нѓиќ_,
  { {0x6c3100a1, 0x07090076, 0x56290140, 0x00000000}},  //   _پہچا, ريخي_, ежим_,
  { {0x25600026, 0x22590190, 0x66001b10, 0x00000000}},  //   _sòla_, jysk_, gumk,
  { {0x2ee90007, 0x4e360049, 0x00000000, 0x00000000}},  //   haaf_, אָטן_,   ,
  { {0x672b0010, 0xa3e9007e, 0x00000000, 0x00000000}},  //   _tagj, эдна_,   ,
  { {0xe6110014, 0x77620026, 0x67200243, 0x00000000}},  //   _هشت_, _glox, cemj,
  { {0x26cd0026, 0x06b10044, 0x36341125, 0x00000000}},  //   mceo_, _ট্রি, _پرنس,
  { {0x6e200181, 0xa50900ed, 0x442700e7, 0x00000000}},  //   _âmbi, _чека_, _tsn_,
  { {0xb4df0201, 0x44270c6a, 0x2b9c01dc, 0x00000000}},  //   तरी_, _usn_, síci_,
  { {0x80d4007d, 0x26cd0249, 0x6e240045, 0x00000000}},  //   _ब्रे, nceo_, twib,
  { {0x22461355, 0x8fa30769, 0xe1f203ec, 0x00000000}},  // [3be0] _çok_, сате, _اسب_,
  { {0x8c4605a7, 0x636600f6, 0x67200089, 0x00000000}},  //   лезе, _dóne, zemj,
  { {0x201a000c, 0x44250016, 0xc3270044, 0x00000000}},  //   _uppi_, nwl_, যারি_,
  { {0xdb1c1b11, 0xe513006e, 0x67d10089, 0x00000000}},  //   _turí, त्ति_, _mājd,
  { {0x6b8205bd, 0x32020027, 0xf1bf0d81, 0x00000000}},  //   rnog, nuky_, lvár_,
  { {0x75210010, 0x6b82016e, 0x082a01ab, 0x00000000}},  //   jelz, snog, еции_,
  { {0x8d6301c0, 0x75210270, 0xcb6a004d, 0x00000000}},  //   _увре, delz, _заве_,
  { {0x998d001a, 0x66000089, 0x1754005e, 0x00000000}},  //   _preţ_, tumk, рвия,
  { {0xfaa3007e, 0xe4e603e8, 0x672015d3, 0x00000000}},  //   _гато, лінн, remj,
  { {0x80d40316, 0x7521054e, 0x67201b12, 0x00000000}},  //   _ब्ले, gelz, semj,
  { {0x0d97009b, 0x9f58008e, 0xcd9700a0, 0x00000000}},  //   רכים_, ntró_, רדית_,
  { {0x78a80091, 0x5c370049, 0x439502ea, 0x00000000}},  //   _izdv, ארטן_, рамс,
  { {0xa77b007b, 0x75211b13, 0xc7b80082, 0x00000000}},  //   _אראפ, belz, _vpđd_,
  { {0x047500a1, 0x44250016, 0x998d0087, 0x00000000}},  //   ائیگ, bwl_, _kreš_,
  { {0xe3b001ef, 0x6568002a, 0x657a0051, 0x00000000}},  //   تری_, mhdh, mith,
  { {0x657a0051, 0xaf371b14, 0x82391b15, 0x00000000}},  //   lith, درست, _азис_,
  { {0x645a0056, 0xccfb012b, 0x63ad1b16, 0x00000000}},  // [3bf0] lyti, еће_, _ihan,
  { {0x657a002a, 0x637601d9, 0x81e80044, 0x00000000}},  //   nith, jšnj, মূহ_,
  { {0x63ad1b17, 0x2ca70945, 0x645a1b18, 0x00000000}},  //   _khan, ånd_, nyti,
  { {0xbe05026c, 0x657a0051, 0x5a3500ed, 0x00000000}},  //   _پوسٹ, hith, инет,
  { {0x20031b19, 0x63ad096a, 0x61ef1b1a, 0x00000000}},  //   luji_, _mhan, nscl,
  { {0x657a008d, 0x645a1b1b, 0xdb1c00d4, 0x00000000}},  //   jith, kyti, _eurà,
  { {0x3158019b, 0x657a1b1c, 0x2011002d, 0x00000000}},  //   ריון_, dith, ntzi_,
  { {0x63ad001d, 0x7bd5022b, 0x645a0006, 0x00000000}},  //   _nhan, _itzu, dyti,
  { {0x7bc71b1d, 0x7aeb1b1e, 0x7b640081, 0x00000000}},  //   _huju, magt, _утре,
  { {0x7bc71448, 0x63ad1786, 0x200300b9, 0x00000000}},  //   _kuju, _ahan, kuji_,
  { {0x64a51963, 0x7bc7033b, 0x63ad0051, 0x00000000}},  //   рана, _juju, _bhan,
  { {0x63ad15a4, 0x7aeb011c, 0x7bc71b1f, 0x00000000}},  //   _chan, nagt, _muju,
  { {0x63ad1b20, 0x69d901aa, 0x7bc70621, 0x00000000}},  //   _dhan, npwe, _luju,
  { {0x63ad1b21, 0x29070332, 0xbdfd0044, 0x00000000}},  //   _ehan, ngna_, ুবাদ_,
  { {0x6b9b0009, 0xafe60088, 0xd4660088, 0x00000000}},  //   _okug, робл, _вище_,
  { {0x6b890295, 0x63ad1659, 0x7c3a050f, 0x00000000}},  //   _njeg, _ghan, _štro,

  { {0x539b1aac, 0x7aeb0343, 0xf1bf0344, 0x00000000}},  // [3c00] _ביקו, dagt, rvár_,
  { {0x7bc71b22, 0x200300b9, 0x61e40026, 0x00000000}},  //   _buju, buji_, _iwil,
  { {0x80dd0044, 0x1c39007e, 0x6d5e006c, 0x00000000}},  //   _বাচ্, ляць_, rkpa,
  { {0x6d5e006c, 0x63ad0023, 0x61e401c3, 0x00000000}},  //   skpa, _xhan, _kwil,
  { {0x9f580211, 0x6b890065, 0xdb1c1b23, 0x00000000}},  //   stró_, _djeg, _stró,
  { {0x61e40020, 0x28f7007c, 0xdb1c0b33, 0x00000000}},  //   _mwil, аешь_, _durá,
  { {0x637608de, 0xdb0000c4, 0x478a005c, 0x00000000}},  //   ršnj, _simõ, ксим_,
  { {0x7aeb001c, 0x2ca7085e, 0x657a005b, 0x00000000}},  //   cagt, ünde_, with,
  { {0x63ad018e, 0x657a0051, 0xb90e0011, 0x00000000}},  //   _rhan, tith, _xalộ_,
  { {0xa906007a, 0x7bc01b24, 0x63bf006b, 0x00000000}},  //   _خبرن, _himu, _siqn,
  { {0x657a002a, 0x4438049a, 0x7bc01b25, 0x00000000}},  //   rith, ír_, _kimu,
  { {0x68e81b26, 0x645a1b27, 0x657a0051, 0x00000000}},  //   _hedd, ryti, sith,
  { {0x657a03b0, 0x7c3a050f, 0x61fd0112, 0x00000000}},  //   pith, _štrl, ursl,
  { {0x68e81b28, 0x7bc0016e, 0x7e6d0059, 0x00000000}},  //   _jedd, _limu, vzap,
  { {0x68e81b29, 0x63ad1b2a, 0xdb1e00b9, 0x00000000}},  //   _medd, _than, _švýc,
  { {0x7bc00009, 0x2011002d, 0x68e80039, 0x00000000}},  //   _nimu, rtzi_, _ledd,
  { {0x7bc70ecb, 0x7a1a0089, 0x68e80016, 0x00000000}},  // [3c10] _suju, nātā, _oedd,
  { {0x7aeb1b2b, 0x6b9b141a, 0xab5d002b, 0x00000000}},  //   wagt, _skug, _miże,
  { {0x63660047, 0x7bc00009, 0x6aa90036, 0x00000000}},  //   _hóna, _bimu, _szef,
  { {0x41c4007a, 0x9f580197, 0x7e990014, 0x00000000}},  //   _دقیق, strò_, _منجر_,
  { {0x7aeb018d, 0x7bc00169, 0x3d140164, 0x00000000}},  //   ragt, _dimu, न्हे_,
  { {0x7bc70149, 0x98ac005a, 0x290c0022, 0x00000000}},  //   _tuju, _aldı_, _ccda_,
  { {0x680a005f, 0x68e8018e, 0x7aeb011c, 0x00000000}},  //   _sədr, _dedd, pagt,
  { {0xbb850054, 0x9b940088, 0x6b9b0009, 0x00000000}},  //   _الري, _дисц, _ukug,
  { {0x68e8018e, 0x16390025, 0xa762005e, 0x00000000}},  //   _fedd, اسبة_, якъд,
  { {0x68e81742, 0x7bc01b2c, 0x6d5501aa, 0x00000000}},  //   _gedd, _zimu, _joza,
  { {0x6d55049c, 0xc7d9013b, 0xd05c006b, 0x00000000}},  //   _moza, _смех_, barə,
  { {0x69c11b01, 0x6d41000c, 0xd05c006b, 0x00000000}},  //   _hile, _ólaf, carə,
  { {0x7ae9109b, 0x63660051, 0xe1ff076b, 0x00000000}},  //   _meet, _cóna, gró_,
  { {0x8636007b, 0x6d55001e, 0x7ae91487, 0x00000000}},  //   _לאנג_, _noza, _leet,
  { {0xa0671b2d, 0x05740084, 0x201e06f0, 0x00000000}},  //   бара_, _باند, ïti_,
  { {0x69c114fe, 0xa3e7007d, 0xe1ff008e, 0x00000000}},  //   _lile, मीण_, bró_,
  { {0xee3a008b, 0x69c10051, 0x7bc00207, 0x00000000}},  // [3c20] ына_, _oile, _rimu,
  { {0x7bc0006a, 0xd05c005f, 0x69c100ea, 0x00000000}},  //   _simu, zarə, _nile,
  { {0xd5c8001d, 0x116804e1, 0xd05c005f, 0x00000000}},  //   _nền_, _ملکی_, yarə,
  { {0x387a005f, 0x69c1014a, 0x68e81b2e, 0x00000000}},  //   _üzrə_, _aile, _sedd,
  { {0xa3e70164, 0x00000000, 0x00000000, 0x00000000}},  //   मीत_,   ,   ,
  { {0xdd9202fd, 0x69c1008d, 0x6d551b2f, 0x00000000}},  //   _روز_, _cile, _goza,
  { {0x7bc004fa, 0x7ae901d6, 0x68e802e1, 0x00000000}},  //   _timu, _feet, _vedd,
  { {0x2d9a1b30, 0x69c100b0, 0x68e81959, 0x00000000}},  //   lope_, _eile, _wedd,
  { {0x69c11b31, 0x00000000, 0x00000000, 0x00000000}},  //   _file,   ,   ,
  { {0x69c101a3, 0xd05c006b, 0x7ae9000a, 0x00000000}},  //   _gile, sarə, _zeet,
  { {0x680a006b, 0xe60f02fd, 0xb8960025, 0x00000000}},  //   _tədq, وشی_, _الضع,
  { {0x69c11b32, 0xf3670a85, 0x2d9a0253, 0x00000000}},  //   _zile, стон, hope_,
  { {0xc797026c, 0x36360379, 0x86c30025, 0x00000000}},  //   _اپنا_, _دراس, _عيون,
  { {0x69c100f6, 0x7c2e01c3, 0x00000000, 0x00000000}},  //   _xile, _osbr,   ,
  { {0x67d10089, 0xe3c90082, 0x00000000, 0x00000000}},  //   _kāja, _hằn_,   ,
  { {0x442e0946, 0x9ed9007c, 0x6d55012d, 0x00000000}},  //   _isf_, рмат_, _soza,
  { {0x6d5501d9, 0x67d1001e, 0xa2a0007d, 0x00000000}},  // [3c30] _poza, _māja, _गुप्,
  { {0x7ae9006c, 0x60c500e0, 0x2d9a00e7, 0x00000000}},  //   _seet, _ughm, gope_,
  { {0x6d550363, 0x69c10207, 0x7ae90004, 0x00000000}},  //   _voza, _rile, _peet,
  { {0xcf270014, 0x443c00fa, 0x80b50061, 0x00000000}},  //   _اردي, _mrv_, ंधीं,
  { {0x69c1006c, 0x78a100f4, 0x7ae9006c, 0x00000000}},  //   _pile, _sylv, _veet,
  { {0x7ae90328, 0xe1ff0036, 0x2d9a00e7, 0x00000000}},  //   _weet, szów_, cope_,
  { {0xa2a0001c, 0x442e00d5, 0x69c11b33, 0x00000000}},  //   _गुन्, _nsf_, _vile,
  { {0x3f89018e, 0xf77100f9, 0x09d80044, 0x00000000}},  //   nnau_, بات_, _সিরা,
  { {0x14da0365, 0x69c1000c, 0x443c006c, 0x00000000}},  //   _म्हण, _tile, _arv_,
  { {0x2bb90183, 0x442e0211, 0xe5791364, 0x00000000}},  //   ेदवा, _bsf_, рзо_,
  { {0x6f1d001a, 0xa34a0072, 0x443c0145, 0x00000000}},  //   _obsc, азна_, _crv_,
  { {0x443c1b34, 0x80a30061, 0x2bd0013d, 0x00000000}},  //   _drv_, _गरजे, _तूफा,
  { {0xe796025a, 0x442e1093, 0x443c00f6, 0x00000000}},  //   _بالک, _esf_, _erv_,
  { {0x6f1d001f, 0x3f890016, 0x443c000c, 0x00000000}},  //   _absc, enau_, _frv_,
  { {0x659a00a0, 0x3f890016, 0x443c0d9b, 0x00000000}},  //   _דיסק, fnau_, _grv_,
  { {0x6f0f0061, 0x20870088, 0x3f890544, 0x00000000}},  //   _cccc, ійти_, gnau_,
  { {0xbea31b35, 0x27e00166, 0xee37007e, 0x00000000}},  // [3c40] датк, ćini_, онт_,
  { {0x7c3c0145, 0x4c8602dc, 0x00000000, 0x00000000}},  //   _prrr, олзв,   ,
  { {0x2d9a0549, 0x6f0f00fa, 0x00000000, 0x00000000}},  //   rope_, _fccc,   ,
  { {0x6f0f001c, 0x8cda02d2, 0x3e7000f4, 0x00000000}},  //   _gccc, _प्रो, _côté_,
  { {0x094a0ad9, 0xee37085f, 0xbddb0129, 0x00000000}},  //   ички_, _дня_, _crèd,
  { {0x39450045, 0x9f4300ea, 0x00000000, 0x00000000}},  //   _cnls_, rsjå_,   ,
  { {0xd90d0014, 0xf66a000c, 0x2ef90022, 0x00000000}},  //   ایم_, kvæð_, _ydsf_,
  { {0x3b0709ae, 0x7bde00b0, 0x8b230184, 0x00000000}},  //   _месо_, mppu, _одсе,
  { {0x442e0093, 0x443c1414, 0x598600ed, 0x00000000}},  //   _ssf_, _srv_, _длаб,
  { {0xd6e20055, 0xece80044, 0x29180009, 0x00000000}},  //   _যাওয, _পাঁড, _ùra_,
  { {0x3f89018e, 0x23691b36, 0x00000000, 0x00000000}},  //   ynau_, _plaj_,   ,
  { {0x7ae20e9c, 0x443c0087, 0x00000000, 0x00000000}},  //   nbot, _vrv_,   ,
  { {0x81d30055, 0xb5fd013e, 0x00000000, 0x00000000}},  //   হীন_, uzšt,   ,
  { {0x443c00ca, 0x442e00c4, 0x386f0276, 0x00000000}},  //   _trv_, _tsf_, _ömrü_,
  { {0xd5c8001d, 0x443c1374, 0xd24e0167, 0x00000000}},  //   _mềm_, _urv_, نچی_,
  { {0xa85700b3, 0xd5b80089, 0x75281b37, 0x00000000}},  //   חילה_, lmā_, ledz,
  { {0x3f890016, 0x7ae20126, 0x00000000, 0x00000000}},  // [3c50] rnau_, dbot,   ,
  { {0x8c670025, 0x75280010, 0xeca7003b, 0x00000000}},  //   يطان, nedz, ојен,
  { {0x25690142, 0xd5b80089, 0xa3de0061, 0x00000000}},  //   _júla_, imā_, दीच_,
  { {0x7ae20b57, 0xab5d01f3, 0x291e0544, 0x00000000}},  //   gbot, _biża, _abta_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f0d027b, 0xab5d002b, 0x7ae20026, 0x00000000}},  //   lgac, _diża, abot,
  { {0x77a5049a, 0x6d47002b, 0x7ae20197, 0x00000000}},  //   lóxi, _inja, bbot,
  { {0xdb1c1b38, 0x6f0d1b39, 0x656a00ea, 0x00000000}},  //   _strö, ngac, _alfh,
  { {0x6d470107, 0x79a701fc, 0x497502dc, 0x00000000}},  //   _knja, _држе, _елас,
  { {0xa509003b, 0x3a3f0022, 0x69db0288, 0x00000000}},  //   љена_, _irup_, _itue,
  { {0x04450373, 0x03a60404, 0x6e2d01a2, 0x00000000}},  //   ченн, зино, hwab,
  { {0xb4ab0164, 0x25e80061, 0x2d810082, 0x00000000}},  //   _खरी_, चीही_, hihe_,
  { {0x6d47016c, 0x6b8b0058, 0x00000000, 0x00000000}},  //   _onja, ingg,   ,
  { {0xb227009f, 0xe20b000c, 0x763a0049, 0x00000000}},  //   _svæð, _stóð_, _לענג,
  { {0x67d10089, 0x66091b3a, 0x64a2007e, 0x00000000}},  //   _mājo, luek, _паша,
  { {0xdfcf0054, 0x6d470145, 0xf412009b, 0x00000000}},  //   طيك_, _anja, _נפח_,
  { {0x26c21b3b, 0x7ae200ea, 0xc3330049, 0x00000000}},  // [3c60] žkov_, vbot, _טוה_,
  { {0x2d810009, 0xdd9201b7, 0x6b8b00e0, 0x00000000}},  //   gihe_, روض_, engg,
  { {0xdd8f0025, 0x7ae20009, 0x3a3f00ea, 0x00000000}},  //   دول_, tbot, _arup_,
  { {0xe3c9001d, 0x7f4a0644, 0x6d471b3c, 0x00000000}},  //   _nằm_, _الحق_, _enja,
  { {0x7ae21543, 0x20180207, 0x442c0009, 0x00000000}},  //   rbot, ltri_, zwd_,
  { {0xdb151b3d, 0x7ae20061, 0x6b8b00e0, 0x00000000}},  //   _buzó, sbot, angg,
  { {0x20181b3e, 0x200a006b, 0xdb090009, 0x00000000}},  //   ntri_, nubi_, _fheà,
  { {0x95d80057, 0x22401b3f, 0xe3c90082, 0x00000000}},  //   одит_, _orik_, _cằm_,
  { {0x3a3f04bd, 0x7bce020c, 0x2018039a, 0x00000000}},  //   _grup_, _hubu, htri_,
  { {0x7bce01a3, 0x6b821126, 0x2018006c, 0x00000000}},  //   _kubu, liog, ktri_,
  { {0x7528001e, 0x6366009f, 0xd5b8001e, 0x00000000}},  //   redz, _tónl, rmā_,
  { {0x98ac001e, 0x7bce0dfc, 0xd5b80089, 0x00000000}},  //   _gadā_, _mubu, smā_,
  { {0x7bce1b40, 0x27e00091, 0x16340ecd, 0x00000000}},  //   _lubu, ćinu_, _целя,
  { {0x35b30245, 0xdb090051, 0x22400190, 0x00000000}},  //   _збір, _mheá, _drik_,
  { {0x22400193, 0x200a0bf8, 0x443a1877, 0x00000000}},  //   _erik_, gubi_, _ép_,
  { {0x22401b41, 0xee3f00b9, 0x77a50d7b, 0x00000000}},  //   _frik_, _prý_, tóxi,
  { {0x201800eb, 0x7bdc0089, 0x6f0d1b42, 0x00000000}},  // [3c70] atri_, _atru, rgac,
  { {0x7bce170b, 0x77a5004a, 0x6f0d0045, 0x00000000}},  //   _bubu, róxi, sgac,
  { {0x69db0030, 0x5b150545, 0x7bce0035, 0x00000000}},  //   _stue, дмет, _cubu,
  { {0x7bce0089, 0x23cf0309, 0xbddb009d, 0x00000000}},  //   _dubu, _संसद, _crèc,
  { {0x3a3f005f, 0xcf5600b6, 0xe3c90082, 0x00000000}},  //   _qrup_, _חברת_, _rằm_,
  { {0x98a5034b, 0xbddb1b43, 0x6d470145, 0x00000000}},  //   миле, _trèb, _unja,
  { {0xb4ab01f5, 0x7bce0093, 0x999f0010, 0x00000000}},  //   _खरे_, _gubu, éről_,
  { {0xeafb00a6, 0x3a3f1717, 0xbddb0666, 0x00000000}},  //   _درست_, _trup_, _grèc,
  { {0x98ad006b, 0x61fb0166, 0x7bd20089, 0x00000000}},  //   ınıb_, šulj, ējuš,
  { {0x7bce0197, 0x66091165, 0xdce700ca, 0x00000000}},  //   _yubu, ruek, _oljč,
  { {0x7983097e, 0x2018002b, 0xe3c90082, 0x00000000}},  //   minw, xtri_, _tằm_,
  { {0x798300e0, 0x889a009b, 0x2240177d, 0x00000000}},  //   linw, _ובעי, _prik_,
  { {0xf7700879, 0x0caa02fb, 0x00000000, 0x00000000}},  //   _حال_, _कर्म,   ,
  { {0xd5bb05b8, 0x20180c32, 0xe7f40061, 0x00000000}},  //   _усе_, ttri_, ींचा_,
  { {0x7f5a00ed, 0x8fa61b44, 0x853c0006, 0x00000000}},  //   ојат_, даве, klėj,
  { {0x2240023a, 0x0395007e, 0x7bce0253, 0x00000000}},  //   _trik_, _прыя, _rubu,
  { {0x7bdc1b45, 0x7bce0760, 0x63a401f6, 0x00000000}},  // [3c80] _stru, _subu, _ikin,
  { {0xdd8f01f7, 0x7bce1b46, 0x00000000, 0x00000000}},  //   لوق_, _pubu,   ,
  { {0x81d60044, 0xfe7100a1, 0x6b821b47, 0x00000000}},  //   _হিট_, ندے_, tiog,
  { {0x61e9001a, 0x20050802, 0xab5d002b, 0x00000000}},  //   ţele, álie_, _diżo,
  { {0x6b82005b, 0x63a400e7, 0x00000000, 0x00000000}},  //   riog, _mkin,   ,
  { {0x7bce0149, 0x7c3a0142, 0x6b820006, 0x00000000}},  //   _tubu, _štru, siog,
  { {0x7bdc0039, 0x63a41b48, 0xa3ae007d, 0x00000000}},  //   _utru, _okin, कता_,
  { {0x96340072, 0xc6f81b49, 0x96ea01e1, 0x00000000}},  //   ениц, чних_, цька_,
  { {0x9f4300ea, 0x00000000, 0x00000000, 0x00000000}},  //   rsjø_,   ,   ,
  { {0x63a4006a, 0xb4e8013d, 0x6d5c01a3, 0x00000000}},  //   _akin, बरे_, _jora,
  { {0x6d5c00ee, 0x7bda028c, 0xb4de013d, 0x00000000}},  //   _mora, _étud, _तभी_,
  { {0x63b6018e, 0x6d5c002d, 0x88e60044, 0x00000000}},  //   _chyn, _lora, _নাটক,
  { {0x69c81b4a, 0x5a9b0049, 0x6d5c040f, 0x00000000}},  //   _kide, ַשלא, _oora,
  { {0x6d5c15f8, 0x63a4022b, 0x69c80066, 0x00000000}},  //   _nora, _ekin, _jide,
  { {0x69c81b4b, 0x3ead016c, 0xb4ca0061, 0x00000000}},  //   _mide, _šet_, लखी_,
  { {0x69c80baf, 0xab5d002b, 0x23880010, 0x00000000}},  //   _lide, _riżo, tője_,
  { {0x6d5c1b4c, 0x69c8002a, 0x443e1a95, 0x00000000}},  // [3c90] _bora, _oide, lvt_,
  { {0x6d5c00d6, 0x69c81b4d, 0x23b20010, 0x00000000}},  //   _cora, _nide, mája_,
  { {0x67220091, 0x2ca70030, 0x09d80044, 0x00000000}},  //   _oboj, ænd_, _সিগা,
  { {0x61ed1661, 0x6d5c0051, 0x69c8032c, 0x00000000}},  //   _kwal, _eora, _aide,
  { {0x69c8022b, 0x6d5c02d5, 0x7e760036, 0x00000000}},  //   _bide, _fora, czyp,
  { {0x61ed000b, 0x75381b4e, 0x00000000, 0x00000000}},  //   _mwal, _navz,   ,
  { {0x69c80bc3, 0x31580049, 0x98a2030d, 0x00000000}},  //   _dide, ויגן_, лише,
  { {0x6d5c055a, 0x69c80f30, 0x76420957, 0x00000000}},  //   _zora, _eide, _broy,
  { {0x69c8119e, 0x63b6018e, 0x764200f4, 0x00000000}},  //   _fide, _rhyn, _croy,
  { {0x69c81b4f, 0x63a40091, 0x63b60319, 0x00000000}},  //   _gide, _skin, _shyn,
  { {0x61ed0a9a, 0x98141095, 0xc6250044, 0x00000000}},  //   _awal, _لبنا, বিধা_,
  { {0xe29a18bf, 0xd7c80025, 0x61ed0258, 0x00000000}},  //   зам_, _قوله_, _bwal,
  { {0x7bc9028c, 0x45240044, 0x69c800e0, 0x00000000}},  //   _mieu, বয়ক_, _yide,
  { {0x7bc900f4, 0x661b1b50, 0x636600f1, 0x00000000}},  //   _lieu, mtuk, _móni,
  { {0x6d5c08da, 0x7f5d0211, 0xdfd2006d, 0x00000000}},  //   _rora, _bosq, اير_,
  { {0x7bc90662, 0xe29a0017, 0x6d5c0996, 0x00000000}},  //   _nieu, _най_, _sora,
  { {0x6d5c0410, 0xdd920076, 0x661b020c, 0x00000000}},  // [3ca0] _pora, هور_, ntuk,
  { {0x661b1b51, 0xa3b403d7, 0xd29b034e, 0x00000000}},  //   ituk, _जीत_, _משפט,
  { {0x6d5c010f, 0x26190011, 0x442701a3, 0x00000000}},  //   _vora, hèo_, _jpn_,
  { {0xeb9719f1, 0x69c802cc, 0x673b0046, 0x00000000}},  //   них_, _side, jduj,
  { {0x69c81b52, 0x6d5c1b53, 0x7bc9009d, 0x00000000}},  //   _pide, _tora, _dieu,
  { {0x61fb0285, 0x442700ca, 0x00000000, 0x00000000}},  //   áuli, _opn_,   ,
  { {0x7dc90006, 0xab5d01d5, 0x6aa90146, 0x00000000}},  //   _užsa, _miżj, _eyef,
  { {0x76421b54, 0x69c81b55, 0x2572009d, 0x00000000}},  //   _proy, _wide, _mâle_,
  { {0xf65216bb, 0x69c805cb, 0xadc3001d, 0x00000000}},  //   ائع_, _tide, _hoạc,
  { {0x64431b56, 0x44271b57, 0x78a801d6, 0x00000000}},  //   _brni, _bpn_, _tydv,
  { {0x661b002d, 0x64430091, 0x61ed03ef, 0x00000000}},  //   atuk, _crni, _swal,
  { {0x6722016e, 0x76420299, 0x395e002d, 0x00000000}},  //   _uboj, _troy, _hots_,
  { {0x64430058, 0x61f8008b, 0x44270030, 0x00000000}},  //   _erni, нняў_, _epn_,
  { {0x44270190, 0xe8ee05b8, 0x61ed0173, 0x00000000}},  //   _fpn_, алi_, _vwal,
  { {0xd3a7012b, 0x395e028c, 0x213a0173, 0x00000000}},  //   _прип, _mots_, _daph_,
  { {0x61ed01aa, 0x395e00ab, 0xa2aa0061, 0x00000000}},  //   _twal, _lots_, _घरच्,
  { {0xab5d0066, 0x7bc9009d, 0x64431b58, 0x00000000}},  // [3cb0] _fiżj, _rieu, _zrni,
  { {0x7bc91b59, 0x395e06ed, 0x44270145, 0x00000000}},  //   _sieu, _nots_, _ypn_,
  { {0x661b002d, 0x7bc9009d, 0x63660325, 0x00000000}},  //   ztuk, _pieu, _sóni,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x395e01a3, 0x7bc900f4, 0x2396001e, 0x00000000}},  //   _bots_, _vieu, nāja_,
  { {0x2d850808, 0x333b01f3, 0x2ee900f6, 0x00000000}},  //   _öle_, _laqx_, lbaf_,
  { {0x395e1b5a, 0x7bc90082, 0x013800b3, 0x00000000}},  //   _dots_, _tieu, גרות_,
  { {0x6366027b, 0x394c00ab, 0x661b0836, 0x00000000}},  //   _tóni, _ends_, ttuk,
  { {0x673b1b5b, 0x1a5b0025, 0x645c16bc, 0x00000000}},  //   rduj, _عشرة_, ärin,
  { {0x661b1b5c, 0x893403ec, 0x44271b5d, 0x00000000}},  //   rtuk, _معما, _ppn_,
  { {0x661b021e, 0x3d190316, 0x636600f6, 0x00000000}},  //   stuk, _पाने_, _mónv,
  { {0x64430059, 0x00000000, 0x00000000, 0x00000000}},  //   _vrni,   ,   ,
  { {0xd2f2013d, 0x23790023, 0x239601c5, 0x00000000}},  //   _अजीब_, ërja_, gāja_,
  { {0x44271b5e, 0x3ceb013d, 0x66091b5f, 0x00000000}},  //   _tpn_, टरों_, mrek,
  { {0x10a601fb, 0x64431b60, 0x44271b61, 0x00000000}},  //   тивн, _urni, _upn_,
  { {0xd00f004b, 0x20051b62, 0x20041b63, 0x00000000}},  //   تلف_, ália_, čmi_,
  { {0x0e63004c, 0xab5d0066, 0x9f580048, 0x00000000}},  // [3cc0] актн, _tiżj, orrú_,
  { {0x6d8b001e, 0x5bca006e, 0x00000000, 0x00000000}},  //   kļau, िद्व,   ,
  { {0x5f06003b, 0x395e1b64, 0xceea0088, 0x00000000}},  //   _изна, _rots_, _одне_,
  { {0x09e6025f, 0x395e1b65, 0x660902ab, 0x00000000}},  //   водн, _sots_, krek,
  { {0x395e04bd, 0x82d70049, 0x66091b66, 0x00000000}},  //   _pots_, דונג_, jrek,
  { {0xfce3041f, 0x2fc00146, 0x660900cd, 0x00000000}},  //   _воро, lmig_, drek,
  { {0x395e0129, 0x6d4e0032, 0x88840752, 0x00000000}},  //   _vots_, _inba, دیان,
  { {0xf09301f8, 0x466a00ed, 0x66090056, 0x00000000}},  //   ינו_, дром_, frek,
  { {0x395e04bd, 0x66090b5a, 0x00000000, 0x00000000}},  //   _tots_, grek,   ,
  { {0x26cf01d6, 0xb5fd01dc, 0x00000000, 0x00000000}},  //   _eggo_, myšl,   ,
  { {0x6609022b, 0x5975007e, 0x6ab20309, 0x00000000}},  //   arek, _сыту, _जरुर,
  { {0x2396001e, 0x66e60930, 0x00000000, 0x00000000}},  //   tāja_, _рода,   ,
  { {0x51871b67, 0x2d8f0010, 0x6d8b00b4, 0x00000000}},  //   вува, égek_, nżac,
  { {0x60de0146, 0x00000000, 0x00000000, 0x00000000}},  //   _cfpm,   ,   ,
  { {0xa3b40164, 0x84380025, 0x61e60168, 0x00000000}},  //   _जीव_, _أكبر_, apkl,
  { {0x6d4e1b68, 0x6ab203d7, 0x23960089, 0x00000000}},  //   _anba, _जरूर, pāja_,
  { {0x1df80783, 0x27e90166, 0x30c50044, 0x00000000}},  // [3cd0] кеты_, ćani_, ্রেস,
  { {0x9be70088, 0xdcb10082, 0x00000000, 0x00000000}},  //   відк, _ở_,   ,
  { {0x9f580211, 0x61fd0af1, 0x66090a10, 0x00000000}},  //   guró_, lssl, zrek,
  { {0xc47700b6, 0x09cb001c, 0x2011000b, 0x00000000}},  //   כתבו_, ाद्य, muzi_,
  { {0x3f890fdd, 0xd838000a, 0xfe7f00f6, 0x00000000}},  //   miau_, _asč_, _veïs_,
  { {0xdb1c1b69, 0x3f891b6a, 0x0d64005e, 0x00000000}},  //   _zurü, liau_, _късм,
  { {0xb8db02fb, 0x20110020, 0x645c1b6b, 0x00000000}},  //   _घर_, nuzi_, äril,
  { {0x3f891b6c, 0x66090cc0, 0x00000000, 0x00000000}},  //   niau_, trek,   ,
  { {0x09dd0055, 0xdb1c1b6d, 0x7bd5055b, 0x00000000}},  //   _ঠিকা, _euró, _huzu,
  { {0x66091b6e, 0x7bd5000b, 0x3f890016, 0x00000000}},  //   rrek, _kuzu, hiau_,
  { {0x78540167, 0x3f890006, 0x20111b6f, 0x00000000}},  //   _نیوز_, kiau_, juzi_,
  { {0x36d51b70, 0x66090466, 0x644101b6, 0x00000000}},  //   _содр, prek, rvli,
  { {0x66050088, 0x2ed90044, 0x3f890016, 0x00000000}},  //   _спла, তরাষ, diau_,
  { {0xbddb00f4, 0xe4e70088, 0x201100e7, 0x00000000}},  //   _crèm, _рідн, fuzi_,
  { {0x2011000b, 0x5f060265, 0x25a502ac, 0x00000000}},  //   guzi_, лзва, moll_,
  { {0x3f890e44, 0xab5d002b, 0x61e61b71, 0x00000000}},  //   giau_, _fiżi, ppkl,
  { {0x200a016c, 0x7bd515ed, 0x00000000, 0x00000000}},  // [3ce0] srbi_, _auzu,   ,
  { {0x61e40263, 0x20110066, 0x7bd5001a, 0x00000000}},  //   _itil, buzi_, _buzu,
  { {0x711b00bd, 0x3f891b72, 0xbb46005e, 0x00000000}},  //   _אויפ, biau_, лежк,
  { {0x3f891b73, 0x7bd5022b, 0x25a51b74, 0x00000000}},  //   ciau_, _duzu, holl_,
  { {0x25a50039, 0xe9180451, 0xc98600e2, 0x00000000}},  //   koll_, волі_, луки,
  { {0x6d4e0048, 0xd83801ca, 0x9f580026, 0x00000000}},  //   _unba, _psč_, curò_,
  { {0xebe30bbd, 0x68f8037b, 0x6366000c, 0x00000000}},  //   _госп, ravd, _jóns,
  { {0x7c930025, 0x61e400f8, 0x68f815c5, 0x00000000}},  //   _الفص, _otil, savd,
  { {0x7bd50342, 0x557405b5, 0x63a60091, 0x00000000}},  //   _zuzu, игит, dokn,
  { {0x7bc200ea, 0x3f890006, 0x7bd51b75, 0x00000000}},  //   lmou, ziau_, _yuzu,
  { {0x7c2905fa, 0x61e40095, 0x63550077, 0x00000000}},  //   _ćerk, _atil, авну,
  { {0x7bc20263, 0x20110009, 0xab5d0066, 0x00000000}},  //   nmou, vuzi_, _piżi,
  { {0x388e005f, 0x3f890006, 0x25a500f8, 0x00000000}},  //   _hər_, viau_, boll_,
  { {0x7bc21b76, 0x3f89018e, 0xab5d002b, 0x00000000}},  //   hmou, wiau_, _viżi,
  { {0x3f89018e, 0xbddb01aa, 0x403500ed, 0x00000000}},  //   tiau_, _vrèm, шевс,
  { {0x7bd50020, 0x20111b77, 0x7bc200b9, 0x00000000}},  //   _ruzu, ruzi_, jmou,
  { {0x3f891b78, 0x7bc20203, 0x518701fc, 0x00000000}},  // [3cf0] riau_, dmou, _буна,
  { {0x3f891b79, 0xab5d002b, 0x127c0049, 0x00000000}},  //   siau_, _jiżv, _ראזע,
  { {0xe1ff0047, 0x3f8904a2, 0x66cb0276, 0x00000000}},  //   lsó_, piau_, _kökü,
  { {0x22490190, 0x6d581b7a, 0x00000000, 0x00000000}},  //   _krak_, övar,   ,
  { {0xe9ff001d, 0xfaa501fc, 0xe1ff008e, 0x00000000}},  //   _trận_, јало, nsó_,
  { {0x22490091, 0xab5d0066, 0x0cd40131, 0x00000000}},  //   _mrak_, _niżv, _горю,
  { {0xe73908fc, 0x25a51b7b, 0x7bc20146, 0x00000000}},  //   вей_, voll_, bmou,
  { {0x16390025, 0x00000000, 0x00000000, 0x00000000}},  //   نسخة_,   ,   ,
  { {0x6b8b0026, 0x00000000, 0x00000000, 0x00000000}},  //   migg,   ,   ,
  { {0x4585107f, 0x2705001d, 0x6b8b05b7, 0x00000000}},  //   ргов, ồn_, ligg,
  { {0x25a512bc, 0x473501fb, 0xf1c80224, 0x00000000}},  //   roll_, _внес, ntář_,
  { {0x22490046, 0x53a601ee, 0x69c30232, 0x00000000}},  //   _brak_, рамб, lmne,
  { {0x25a50129, 0x63a61b7c, 0x66cb014a, 0x00000000}},  //   poll_, rokn, _dökü,
  { {0x69c30051, 0xa2c2007d, 0xa50918ea, 0x00000000}},  //   nmne, रेष्, _река_,
  { {0x7bc20133, 0x22490032, 0x00000000, 0x00000000}},  //   ymou, _erak_,   ,
  { {0x68400884, 0x22490846, 0x3a2d00d6, 0x00000000}},  //   ládá, _frak_, _opep_,
  { {0x7de501b7, 0x6b8b123c, 0x433b01ce, 0x00000000}},  // [3d00] مسلم, digg, _יעקב,
  { {0x01fb01ce, 0xab5d002b, 0x5fb80061, 0x00000000}},  //   _שפיל, _miżu, _आठवल,
  { {0x7bc21339, 0x22490733, 0x6b8b0197, 0x00000000}},  //   tmou, _zrak_, figg,
  { {0x69c31b7d, 0x656301f3, 0xdbdf01e5, 0x00000000}},  //   emne, _lonh, _víðt,
  { {0x7bc20133, 0x79c6007e, 0x00000000, 0x00000000}},  //   rmou, айдз,   ,
  { {0xf806025f, 0x99f50088, 0x645c03b6, 0x00000000}},  //   ачин, сяці, ärik,
  { {0xa96703f3, 0x31570049, 0xdb1c000c, 0x00000000}},  //   рија_, ייסן_, _furð,
  { {0x6d5e003b, 0x2ee00009, 0xab5d0036, 0x00000000}},  //   ljpa, ncif_, _biżu,
  { {0xba290447, 0x656300f4, 0x49ca034b, 0x00000000}},  //   _مسلم_, _bonh, _алан_,
  { {0x656302d5, 0x66cb0279, 0x00000000, 0x00000000}},  //   _conh, _sökü,   ,
  { {0xe2f90c50, 0x5fd20061, 0x00000000, 0x00000000}},  //   лені_, _दंगल,   ,
  { {0xe3b90477, 0xe1ff0010, 0x636b01ee, 0x00000000}},  //   atın_, tsó_, трог_,
  { {0x521402d3, 0x3636007a, 0xe57a0081, 0x00000000}},  //   одят, _خراس, _изд_,
  { {0xdd1a01d5, 0x7c2e1b7e, 0xd5af0088, 0x00000000}},  //   għżu, _opbr, _єс_,
  { {0xb4d2001c, 0x657a0051, 0x3f8700ed, 0x00000000}},  //   वशी_, mhth, аѓаа,
  { {0x224916e7, 0x853c0006, 0x644a002b, 0x00000000}},  //   _trak_, plės, _irfi,
  { {0x63ad0058, 0x3eaf0dba, 0x443c01a2, 0x00000000}},  // [3d10] _ikan, ægt_, _hsv_,
  { {0xdcf91095, 0x201e0129, 0x657a0011, 0x00000000}},  //   افات_, àtic_, nhth,
  { {0x63ad0066, 0x9f350245, 0x0dc81b7f, 0x00000000}},  //   _kkan, _лені, рути_,
  { {0xe457007b, 0x442e00c4, 0x63ad01f3, 0x00000000}},  //   ייבט_, _mpf_, _jkan,
  { {0x6b8b0207, 0xe3b9006b, 0xf2d40049, 0x00000000}},  //   rigg, ytın_, קעס_,
  { {0x443c0d2b, 0xab5d01d5, 0x6b8b1b80, 0x00000000}},  //   _osv_, _riżu, sigg,
  { {0x66021089, 0x63ad01ee, 0x7e6d0058, 0x00000000}},  //   _avok, _okan, lyap,
  { {0x65630181, 0x09e60044, 0x63ad0dfc, 0x00000000}},  //   _sonh, _নিরা, _nkan,
  { {0x9f5e028c, 0x443c001e, 0x7e6d1b81, 0x00000000}},  //   été_, _asv_, nyap,
  { {0x657a1b82, 0x63ad00f0, 0x66e7006e, 0x00000000}},  //   ghth, _akan, _ट्रक_,
  { {0x66020403, 0x442e0181, 0xe3b90279, 0x00000000}},  //   _evok, _cpf_, rtın_,
  { {0x443c0190, 0xc169009b, 0xa5f90140, 0x00000000}},  //   _dsv_, _אח_, _беду_,
  { {0x644a0708, 0x442e1b83, 0xc6a7003b, 0x00000000}},  //   _erfi, _epf_, _тржи,
  { {0x657a07eb, 0xf6520104, 0x1ddb013d, 0x00000000}},  //   chth, _מצד_, _बढ़त,
  { {0xe1f20014, 0xdee60088, 0x66020059, 0x00000000}},  //   _کسب_, йови, _zvok,
  { {0x439301fc, 0x6b9b00e7, 0x00000000, 0x00000000}},  //   _најс, _njug,   ,
  { {0x0ef9007e, 0xa3dd0061, 0x6f1d004a, 0x00000000}},  // [3d20] рэсы_, _थंड_, _dcsc,
  { {0x32020142, 0x442e0d48, 0x6b8900e7, 0x00000000}},  //   msky_, _ypf_, _ameg,
  { {0xfbd201fa, 0x0c2600c0, 0x61f60016, 0x00000000}},  //   ستا_, смен, _hwyl,
  { {0xeafa01af, 0x8afd00b9, 0xef210089, 0x00000000}},  //   ارات_, _pořa, _ceļā_,
  { {0x32020027, 0x298a064b, 0x3cf8075b, 0x00000000}},  //   nsky_, лско_, _terv_,
  { {0x2d8f0047, 0x6e240697, 0x2b401b84, 0x00000000}},  //   éget_, mtib, žic_,
  { {0x764b018e, 0x66020b22, 0x00000000, 0x00000000}},  //   _argy, _svok,   ,
  { {0x442e0020, 0x6e2400f6, 0xab960025, 0x00000000}},  //   _rpf_, otib, _الرغ,
  { {0x442e0062, 0xda6305f6, 0xba56005e, 0x00000000}},  //   _spf_, _евти, _утвъ,
  { {0x443c00b5, 0x2c0d0061, 0x644a0022, 0x00000000}},  //   _psv_, ांचं_, _prfi,
  { {0xd7ea0893, 0x32021293, 0x78ba0089, 0x00000000}},  //   _смее_, esky_, _uztv,
  { {0x6e241b85, 0x4c9b0049, 0x61f60016, 0x00000000}},  //   ktib, רשטע, _bwyl,
  { {0x442e0190, 0x2d8a0d16, 0x7f441352, 0x00000000}},  //   _wpf_, _ombe_, ddiq,
  { {0x442e0022, 0x68fa0606, 0x61f60016, 0x00000000}},  //   _tpf_, _jetd, _dwyl,
  { {0x7dc9010a, 0x63ad0021, 0x442e00d4, 0x00000000}},  //   _užsi, _tkan, _upf_,
  { {0x44ce006b, 0x63ad0020, 0x68fa0022, 0x00000000}},  //   mə_, _ukan, _letd,
  { {0x320f0047, 0x44ce005f, 0x61f6018e, 0x00000000}},  // [3d30] _így_, lə_, _gwyl,
  { {0x68fa0030, 0x6b890006, 0x7e6d0c2c, 0x00000000}},  //   _netd, _smeg, ryap,
  { {0x44ce0163, 0x29f60036, 0x6e241b86, 0x00000000}},  //   nə_, eła_, atib,
  { {0xe3b9014a, 0x291e0dcb, 0x7bc000b4, 0x00000000}},  //   ktım_, _acta_, _chmu,
  { {0x2bb80054, 0x2d8f0047, 0x29f60036, 0x00000000}},  //   حالة_, éges_, gła_,
  { {0x6ea20183, 0x98be005d, 0xbddb009d, 0x00000000}},  //   _कुटु, _altı_, _brèv,
  { {0x6d5500b5, 0x29f60036, 0x6d451b87, 0x00000000}},  //   _inza, ała_, mdha,
  { {0x44ce005f, 0x6d4502fa, 0x0609003b, 0x00000000}},  //   də_, ldha, аник_,
  { {0x96b901e1, 0x7c2501a2, 0x200511af, 0x00000000}},  //   шуку_, lthr, šlih_,
  { {0x7afb001f, 0x68fa006b, 0x32020142, 0x00000000}},  //   _heut, _getd, vsky_,
  { {0xbddb00f4, 0x7afb003f, 0x7c2514f9, 0x00000000}},  //   _grèv, _keut, nthr,
  { {0x7c251b88, 0x2011041a, 0x61f6018e, 0x00000000}},  //   ithr, drzi_, _pwyl,
  { {0x32040428, 0xbb3a0049, 0xeb3a0049, 0x00000000}},  //   émy_, בערי, בערש,
  { {0x7afb010f, 0x32020142, 0x6729002b, 0x00000000}},  //   _leut, rsky_, lfej,
  { {0x6d450016, 0xafe3017f, 0x7ae206fa, 0x00000000}},  //   ddha, досл, ycot,
  { {0x6d55010f, 0x6e2417f4, 0x29f60036, 0x00000000}},  //   _anza, ttib, yła_,
  { {0x20d6008b, 0x61461b89, 0x69c100b9, 0x00000000}},  // [3d40] _мінс, _депа, _ohle,
  { {0x6e24023a, 0x7f44006b, 0x8cb601fc, 0x00000000}},  //   rtib, sdiq, осеч,
  { {0x6e2400d6, 0x0b460242, 0x7afb1b8a, 0x00000000}},  //   stib, жнен, _beut,
  { {0xab2a102a, 0x20181b8b, 0x6e2400f4, 0x00000000}},  //   рода_, muri_, ptib,
  { {0x7afb03a1, 0x20180571, 0x7ae21965, 0x00000000}},  //   _deut, luri_, rcot,
  { {0x44ce005f, 0x7ae20211, 0x69c1171e, 0x00000000}},  //   yə_, scot, _chle,
  { {0x2018001a, 0x29f60036, 0x7afb009d, 0x00000000}},  //   nuri_, sła_, _feut,
  { {0x44ce005f, 0x20180035, 0x29f60036, 0x00000000}},  //   və_, iuri_, pła_,
  { {0x7bdc0475, 0x20181b1c, 0x44250036, 0x00000000}},  //   _huru, huri_, etl_,
  { {0x7bdc011f, 0x637f0065, 0x7c45000c, 0x00000000}},  //   _kuru, _këng, _ótrú,
  { {0x9cdb007b, 0x7bdc0281, 0x3a261b8c, 0x00000000}},  //   יקיפ, _juru, ltop_,
  { {0xc5f90055, 0x883b00b6, 0x44ce005f, 0x00000000}},  //   _আমরা_, _כתבו, rə_,
  { {0x3a2612d9, 0xe298007e, 0x44ce006b, 0x00000000}},  //   ntop_, жаў_, sə_,
  { {0x7c250675, 0x2018001a, 0x291c0006, 0x00000000}},  //   ythr, furi_, ngva_,
  { {0x2018001a, 0xe9ff001d, 0x44ce005f, 0x00000000}},  //   guri_, _trần_, qə_,
  { {0x20030036, 0x3a2600ea, 0x00000000, 0x00000000}},  //   rsji_, ktop_,   ,
  { {0x7afb006c, 0x7c250011, 0x7e600129, 0x00000000}},  // [3d50] _reut, wthr, _àmpl,
  { {0x7bdc022b, 0x20181b8d, 0x2b4600f4, 0x00000000}},  //   _buru, buri_, edoc_,
  { {0x2018000d, 0x6d4511d4, 0x7afb00d9, 0x00000000}},  //   curi_, rdha, _peut,
  { {0x7bdc011f, 0x2396001e, 0x7c2519dd, 0x00000000}},  //   _duru, tāji_, rthr,
  { {0x69c11625, 0x7bdc1b8e, 0xdb0b0023, 0x00000000}},  //   _phle, _euru, logë,
  { {0x7bdc00f8, 0x4dda009b, 0x2fc901d6, 0x00000000}},  //   _furu, _לחשו, lmag_,
  { {0x7bdc04a0, 0x637f0065, 0x7afb0023, 0x00000000}},  //   _guru, _kënd, _teut,
  { {0x3a3f00e0, 0x1606006e, 0x3a2610f0, 0x00000000}},  //   _tsup_, _शिखर_, btop_,
  { {0x20181b8f, 0x69c10009, 0x637f0023, 0x00000000}},  //   zuri_, _thle, _mënd,
  { {0x7649021e, 0x637f0065, 0x442501a2, 0x00000000}},  //   rvey, _lënd, ttl_,
  { {0x20181b90, 0xc5680025, 0x7dc9007f, 0x00000000}},  //   xuri_, تحيل_, _užsu,
  { {0x201801eb, 0x442501a2, 0x637f0023, 0x00000000}},  //   vuri_, rtl_, _nënd,
  { {0xbebb008d, 0x44251b91, 0x059600a1, 0x00000000}},  //   _mbës, stl_, _کانگ,
  { {0x20181b92, 0x270c0006, 0x00000000, 0x00000000}},  //   turi_, rėnų_,   ,
  { {0x394500d4, 0x645c0bac, 0x90c30517, 0x00000000}},  //   _mals_, ärit, ебре,
  { {0x20181aba, 0x7bdc00e0, 0xdb1b0051, 0x00000000}},  //   ruri_, _ruru, _bhuí,
  { {0x2018148e, 0x7bdc01a3, 0xd24f0025, 0x00000000}},  // [3d60] suri_, _suru, _مني_,
  { {0xf1bf1b93, 0x2018001a, 0x7bdc006c, 0x00000000}},  //   ltán_, puri_, _puru,
  { {0x7bdc005f, 0x6bd60774, 0xf1bf0048, 0x00000000}},  //   _quru, ستار, otán_,
  { {0x7bdc1b94, 0x3a261b95, 0x3947012d, 0x00000000}},  //   _vuru, ttop_, edns_,
  { {0x2b460203, 0x39450b50, 0x7bdc0022, 0x00000000}},  //   rdoc_, _bals_, _wuru,
  { {0x7bdc0127, 0x3a260bd3, 0x23960089, 0x00000000}},  //   _turu, rtop_, māju_,
  { {0x3a260059, 0x0720007d, 0xdca31867, 0x00000000}},  //   stop_, _यादव_, _зари,
  { {0x4c9b009b, 0x3a260a60, 0xab27004d, 0x00000000}},  //   _הבלו, ptop_, _носа_,
  { {0xc6f704af, 0x39451b96, 0x23960089, 0x00000000}},  //   чных_, _fals_, nāju_,
  { {0x9986035b, 0x394501c5, 0x6914012d, 0x00000000}},  //   _علاو, _gals_, _bžež,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x187700b6, 0xa295008b, 0xbebb0065, 0x00000000}},  //   _מעבר_, дамі, _mbër,
  { {0x637f008d, 0x95ca003b, 0xe9ff0011, 0x00000000}},  //   _rënd, _лука_, _trấn_,
  { {0x645c1b97, 0x32191b98, 0x239601c5, 0x00000000}},  //   äris, rusy_, dāju_,
  { {0xdb1b0051, 0x753a0f30, 0x2fc900d2, 0x00000000}},  //   _shuí, metz, tmag_,
  { {0x637f008d, 0xa857019b, 0x753a010f, 0x00000000}},  //   _qënd, הילה_, letz,
  { {0x63af0387, 0x9d5500e9, 0x2fc91058, 0x00000000}},  // [3d70] mocn, وچست, rmag_,
  { {0x61ed0198, 0x2fc9123c, 0x753a1b99, 0x00000000}},  //   _ital, smag_, netz,
  { {0xbddb01aa, 0x637f0065, 0x3f92011c, 0x00000000}},  //   _près, _tënd, biyu_,
  { {0x290c1b9a, 0xdecb0072, 0x39451b9b, 0x00000000}},  //   _adda_, _гугл_, _sals_,
  { {0xd9450069, 0x394500d4, 0x657d0065, 0x00000000}},  //   дели, _pals_, ëshk,
  { {0x99670057, 0xbddb00f4, 0xeab00025, 0x00000000}},  //   ятел, _frèr, دعم_,
  { {0x753a022b, 0x394501d6, 0xa90404b1, 0x00000000}},  //   detz, _vals_, ربون,
  { {0x6d4700f0, 0x290c01e5, 0x61ed02e1, 0x00000000}},  //   _haja, _edda_, _otal,
  { {0x61ed02c0, 0x394501b8, 0x66150036, 0x00000000}},  //   _ntal, _tals_, ązko,
  { {0x6d471b9c, 0x7bcb1b9d, 0x753a0032, 0x00000000}},  //   _jaja, lmgu, getz,
  { {0x6d470004, 0x6fbf0183, 0x61ed022b, 0x00000000}},  //   _maja, ्षां, _atal,
  { {0x6d470263, 0x61ed0066, 0x3209000a, 0x00000000}},  //   _laja, _btal, _bvay_,
  { {0x753a022b, 0xa50908d6, 0x61ed12fe, 0x00000000}},  //   betz, _дела_, _ctal,
  { {0x6d470466, 0xdb0b0039, 0xc7b90010, 0x00000000}},  //   _naja, llgä, llő_,
  { {0x61ed00b5, 0x2bd9007d, 0xdee60679, 0x00000000}},  //   _etal, _बंगा, доби,
  { {0xe29a046c, 0x2396001e, 0xe3b7005e, 0x00000000}},  //   _май_, tāju_, _общ_,
  { {0x6d470211, 0x2d930a86, 0x00000000, 0x00000000}},  // [3d80] _baja, fixe_,   ,
  { {0x6d470211, 0x7ae91b9e, 0xf1bf1b9f, 0x00000000}},  //   _caja, _afet, ntál_,
  { {0x6d470059, 0x7c3e00bb, 0x3f6a17a4, 0x00000000}},  //   _daja, uwpr, _дино_,
  { {0xeb9702d3, 0x661b0052, 0x6d470288, 0x00000000}},  //   мих_, kuuk, _eaja,
  { {0x09e314d1, 0x6d470169, 0x62861ba0, 0x00000000}},  //   вочн, _faja, nzko,
  { {0x7ae90181, 0x6f0401c5, 0x27380011, 0x00000000}},  //   _efet, laic, _ẩn_,
  { {0x753a1ba1, 0x4427004a, 0x00000000, 0x00000000}},  //   vetz, _nqn_,   ,
  { {0x6d470142, 0x6f041ba2, 0x8b9501e1, 0x00000000}},  //   _zaja, naic, _зруч,
  { {0x753a022b, 0x6443009d, 0x6d4700e7, 0x00000000}},  //   tetz, _asni, _yaja,
  { {0x62860027, 0x6f040035, 0x290c00f8, 0x00000000}},  //   dzko, haic, _udda_,
  { {0x753a002d, 0x63af0142, 0xc9530104, 0x00000000}},  //   retz, tocn, _שמע_,
  { {0x753a001f, 0x93bd001a, 0x6b820f5d, 0x00000000}},  //   setz, ptăm, nhog,
  { {0x63af0235, 0x6f0400c4, 0x16341ba3, 0x00000000}},  //   rocn, daic, _челя,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d4703b6, 0xdb0b0039, 0x63af057c, 0x00000000}},  //   _raja, llgå, pocn,
  { {0x6d470513, 0x6f041ba4, 0x00000000, 0x00000000}},  //   _saja, gaic,   ,
  { {0x61ed13df, 0x6d471ba5, 0x5d55026b, 0x00000000}},  // [3d90] _utal, _paja, нкат,
  { {0x20050047, 0xdcbb007c, 0x71750025, 0x00000000}},  //   ális_, още_, _أهدا,
  { {0x6d4706b0, 0x5b150200, 0xa739016c, 0x00000000}},  //   _vaja, емет, ščiš,
  { {0x6d47105a, 0x4fc7007e, 0x6f040555, 0x00000000}},  //   _waja, _існа, caic,
  { {0x6d4701a3, 0xa3c2007d, 0x6366008e, 0x00000000}},  //   _taja, ्गत_, _cóny,
  { {0x661b01b1, 0xda7801ab, 0x00000000, 0x00000000}},  //   vuuk, ьях_,   ,
  { {0x88bc00b9, 0xa3af0316, 0x7d050022, 0x00000000}},  //   _sběr, कवा_, mahs,
  { {0x661b157c, 0x8bc4007e, 0x3eb90190, 0x00000000}},  //   tuuk, _асуд, _kyst_,
  { {0xeab3031d, 0x9f510047, 0xf6510647, 0x00000000}},  //   _شعر_, lszó_, ائب_,
  { {0x44651ba6, 0xb46501ee, 0x661b0329, 0x00000000}},  //   евов, екол, ruuk,
  { {0x5fdb02d2, 0x7ae40161, 0x3eb91a4c, 0x00000000}},  //   _मंगल, žite, _lyst_,
  { {0x57ca0061, 0x8afd013e, 0x628601a2, 0x00000000}},  //   ागृह, _boři, tzko,
  { {0x6f041ba7, 0x55590581, 0x00000000, 0x00000000}},  //   vaic, _надя_,   ,
  { {0x64a5008b, 0x2396001e, 0x628601c5, 0x00000000}},  //   _пала, tājs_, rzko,
  { {0xa06a0999, 0x6286108d, 0xe4e40088, 0x00000000}},  //   чава_, szko, _річн,
  { {0x22520030, 0x42261ba8, 0xdce71ba9, 0x00000000}},  //   _tryk_, _здив, _dojč,
  { {0x539b00b6, 0x66090056, 0x6f04111b, 0x00000000}},  // [3da0] _מיקו, nsek, raic,
  { {0x6f040051, 0xbd460025, 0x660900b0, 0x00000000}},  //   saic, عناي, isek,
  { {0x6026008b, 0x6f040051, 0x6b82032c, 0x00000000}},  //   _ядна, paic, thog,
  { {0x637f0065, 0x6609014a, 0x8a0602dc, 0x00000000}},  //   _këna, ksek, езде,
  { {0x63a4000b, 0x66090a9d, 0x6b820250, 0x00000000}},  //   _mjin, jsek, rhog,
  { {0xe8940eec, 0xe29f000c, 0x6b821baa, 0x00000000}},  //   каль, naða_, shog,
  { {0xc30b0055, 0x6d5c062c, 0x6da302dc, 0x00000000}},  //   ষ্টি_, _inra, _сира,
  { {0x963401fb, 0x18970025, 0x17540a85, 0x00000000}},  //   вниц, عضوة_, твия,
  { {0x940a006b, 0xe72f023c, 0x660900f8, 0x00000000}},  //   əmək_, صصي_, gsek,
  { {0x63a41bab, 0x98be00e5, 0x00000000, 0x00000000}},  //   _ajin, _cată_,   ,
  { {0x98be001a, 0xbddb000a, 0x63a400c4, 0x00000000}},  //   _dată_, _asèl, _bjin,
  { {0x69da0047, 0x7d0501c5, 0x8afd00b9, 0x00000000}},  //   _hite, zahs, _poři,
  { {0x69da0924, 0x63a4003b, 0x2018002d, 0x00000000}},  //   _kite, _djin, erri_,
  { {0x69da1bac, 0x00000000, 0x00000000, 0x00000000}},  //   _jite,   ,   ,
  { {0x69da021e, 0xf1bf0010, 0x5f9500ed, 0x00000000}},  //   _mite, lták_, вивт,
  { {0x6d5c1bad, 0x63a40065, 0x657a0133, 0x00000000}},  //   _anra, _gjin, lkth,
  { {0x69da00c4, 0x442c02d4, 0xa3e4007d, 0x00000000}},  // [3db0] _oite, ltd_, _भूत_,
  { {0x69da1bae, 0x657a032e, 0x9f510010, 0x00000000}},  //   _nite, nkth, tszó_,
  { {0x6d5c0009, 0x7d050145, 0xf9910123, 0x00000000}},  //   _dnra, rahs, یبت_,
  { {0x3f670057, 0x3eb9144b, 0x3b64005e, 0x00000000}},  //   _чтоб, _tyst_, лъчв,
  { {0x69da1baf, 0xaa45007c, 0xd6e60044, 0x00000000}},  //   _bite, телл, নরায,
  { {0x69da000d, 0x7f4d178e, 0x6e2d1bb0, 0x00000000}},  //   _cite, ldaq, mtab,
  { {0xdb0b0219, 0x69da020c, 0x5ba70245, 0x00000000}},  //   logí, _dite, _зраз,
  { {0x69da018e, 0x6609006c, 0x06aa0044, 0x00000000}},  //   _eite, tsek, খেছি,
  { {0x69da00d4, 0x63bd0026, 0x00000000, 0x00000000}},  //   _fite, dlsn,   ,
  { {0x63b6000c, 0x66091bb1, 0x986500a1, 0x00000000}},  //   _skyn, rsek, _لیتے_,
  { {0x64a50113, 0x6609004e, 0xd6ab0014, 0x00000000}},  //   тана, ssek, _کدام_,
  { {0x29071bb2, 0xe29a06b6, 0x91e6005c, 0x00000000}},  //   lana_, дам_, коме,
  { {0x69c8021e, 0x6e2d01f3, 0xe29f000c, 0x00000000}},  //   _yhde, jtab, taða_,
  { {0x657a0056, 0x6e2d06d4, 0x29071bb3, 0x00000000}},  //   ckth, dtab, nana_,
  { {0x201801d6, 0x6e2d1bb4, 0x290700c4, 0x00000000}},  //   urri_, etab, iana_,
  { {0x29070020, 0x63a40020, 0x7e7600b0, 0x00000000}},  //   hana_, _ujin, tyyp,
  { {0x290704ff, 0xdb0b02a0, 0xfce61bb5, 0x00000000}},  // [3dc0] kana_, gogí, возо,
  { {0x290701d9, 0x00000000, 0x00000000, 0x00000000}},  //   jana_,   ,   ,
  { {0x69da1bb6, 0x61e400f4, 0xe6be007d, 0x00000000}},  //   _rite, _huil, _ऊर्ज,
  { {0x69da011f, 0x7981018e, 0x6e2d12b0, 0x00000000}},  //   _site, _allw, btab,
  { {0x61e4028c, 0x69da062c, 0xdb150047, 0x00000000}},  //   _juil, _pite, óbál,
  { {0x644f001e, 0x61e400b0, 0x6d5c0133, 0x00000000}},  //   ācij, _muil, _unra,
  { {0x69da008d, 0x26c00006, 0xeb9a00d7, 0x00000000}},  //   _vite, _šio_, _жив_,
  { {0x7aeb001c, 0x78ba0428, 0xf1bf0047, 0x00000000}},  //   ccgt, _vytv, tták_,
  { {0x69da037f, 0xcf9301f8, 0x09e607d0, 0x00000000}},  //   _tite, יטה_, _розн,
  { {0x29070211, 0x69da049b, 0x442c1bb7, 0x00000000}},  //   cana_, _uite, ttd_,
  { {0x9d1b00a3, 0x657a0065, 0xad1b0097, 0x00000000}},  //   וויט, rkth, וויר,
  { {0x61e40038, 0xc884005d, 0x442c0009, 0x00000000}},  //   _buil, ışı_, rtd_,
  { {0x81be0044, 0x61e41059, 0x98be0a67, 0x00000000}},  //   েদন_, _cuil, _datą_,
  { {0x657d008d, 0x61e41bb8, 0x6e2d0009, 0x00000000}},  //   ësht, _duil, vtab,
  { {0xb33b02d5, 0x394c0637, 0xf48400a2, 0x00000000}},  //   ança, _mads_, _حاشی,
  { {0x6e2d1bb9, 0xdce7013e, 0x61e40048, 0x00000000}},  //   ttab, _pojď, _fuil,
  { {0xdfd80265, 0x7bc90f10, 0x6e2d1a90, 0x00000000}},  // [3dd0] тър_, _rheu, utab,
  { {0x29071aba, 0x6e2d1bba, 0x224901d6, 0x00000000}},  //   xana_, rtab, _isak_,
  { {0x6e2d1bbb, 0x2907016c, 0x61e400bb, 0x00000000}},  //   stab, vana_, _zuil,
  { {0x6e2d1bbc, 0x29071bbd, 0x2613001c, 0x00000000}},  //   ptab, wana_, _दिली_,
  { {0x290716c3, 0xee87007c, 0xde6402dc, 0x00000000}},  //   tana_, _рыно, _кърп,
  { {0x9aa40025, 0x394c00d4, 0xaa560025, 0x00000000}},  //   جمهو, _cads_, الوا_,
  { {0x2907117c, 0x013800b6, 0x7bc91194, 0x00000000}},  //   rana_, דרות_, _theu,
  { {0x29071bbe, 0x394c01e5, 0x00000000, 0x00000000}},  //   sana_, _eads_,   ,
  { {0x29071bbf, 0x394c000a, 0x645c0479, 0x00000000}},  //   pana_, _fads_, årin,
  { {0x394c0089, 0x61e400b5, 0x61e2009d, 0x00000000}},  //   _gads_, _ruil, _éoli,
  { {0x2905001e, 0x9f600023, 0x22490085, 0x00000000}},  //   _iela_, ërës_, _asak_,
  { {0x29050073, 0x888c0049, 0x637f0065, 0x00000000}},  //   _hela_, _קראַ, _dëno,
  { {0x22491bc0, 0x61e409f7, 0x2d831bc1, 0x00000000}},  //   _csak_, _quil, _olje_,
  { {0x29051080, 0x61e40112, 0x869a0049, 0x00000000}},  //   _jela_, _vuil, _אינז,
  { {0x2905002b, 0xa5da0049, 0x34390049, 0x00000000}},  //   _mela_, _אַהי, _טײַע,
  { {0x61e4002a, 0x29050145, 0x128800a1, 0x00000000}},  //   _tuil, _lela_, _لمبی_,
  { {0x1fa71bc2, 0x733b0049, 0xdd2c0006, 0x00000000}},  // [3de0] укти_, _טעקס, _vėži,
  { {0x290511c8, 0x00000000, 0x00000000, 0x00000000}},  //   _nela_,   ,   ,
  { {0x661b0c0d, 0x2d830059, 0x82360123, 0x00000000}},  //   hruk, _dlje_, _شرکا,
  { {0xd9cc024c, 0x09e60057, 0xa09b007b, 0x00000000}},  //   ाष्ट, годн, _טייט,
  { {0x29051bc3, 0x2fc001c4, 0xf1a90014, 0x00000000}},  //   _bela_, mlig_, _سایه_,
  { {0xfce30194, 0x2905028c, 0x661b02ae, 0x00000000}},  //   _горо, _cela_, druk,
  { {0x29051bc4, 0xdcfe0089, 0x6f060087, 0x00000000}},  //   _dela_, sipē, _kekc,
  { {0x6d4e1bc5, 0x2d9a029d, 0x2fc005fe, 0x00000000}},  //   _haba, lipe_, nlig_,
  { {0x6d4e0b9a, 0x2905000c, 0x2fc0021f, 0x00000000}},  //   _kaba, _fela_, ilig_,
  { {0x6d4e0169, 0x16370054, 0x6f060036, 0x00000000}},  //   _jaba, اسية_, _lekc,
  { {0x6d4e1bc6, 0xa81a0647, 0xc4450014, 0x00000000}},  //   _maba, _ستار_, لیون_,
  { {0x6d4e1bc7, 0x2905002d, 0x661b1bc8, 0x00000000}},  //   _laba, _zela_, bruk,
  { {0x51870d68, 0x2fc005cb, 0x2d9a0a5f, 0x00000000}},  //   гува, dlig_, kipe_,
  { {0x6d4e1bc9, 0x22490b9f, 0xa4d401ff, 0x00000000}},  //   _naba, _vsak_, _колі,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x443c1702, 0xc27500ed, 0x644a002b, 0x00000000}},  //   _ipv_, _влиј, _isfi,
  { {0x6d4e006a, 0x2d83012d, 0x00000000, 0x00000000}},  // [3df0] _baba, _plje_,   ,
  { {0x31350373, 0x6d4e1bca, 0x8d7706dd, 0x00000000}},  //   _теор, _caba, دارا,
  { {0x6d4e030b, 0x2905003f, 0xa2d90309, 0x00000000}},  //   _daba, _rela_, _नृत्,
  { {0x8f470121, 0x29050213, 0x64580091, 0x00000000}},  //   _сход, _sela_, _mrvi,
  { {0x290502d5, 0x6d4e1bcb, 0x66020066, 0x00000000}},  //   _pela_, _faba, _nwok,
  { {0x2d9a0127, 0x6d4e006a, 0x64580724, 0x00000000}},  //   cipe_, _gaba, _orvi,
  { {0xa3e403d7, 0x29050142, 0xc984003b, 0x00000000}},  //   _भूल_, _vela_, ључи,
  { {0x6d4e1bcc, 0x291b005f, 0x7f4f00f4, 0x00000000}},  //   _zaba, şqa_, _jacq,
  { {0x6d4e011f, 0x64581bcd, 0x290512a1, 0x00000000}},  //   _yaba, _arvi, _tela_,
  { {0x661b002d, 0x80bb0061, 0xe576007c, 0x00000000}},  //   rruk, _शुभे, изы_,
  { {0x7d071bce, 0x443c0c06, 0x657d0023, 0x00000000}},  //   _mejs, _cpv_, ëshq,
  { {0xe72e01b3, 0x645816d0, 0x7f4f0197, 0x00000000}},  //   _ќе_, _drvi, _nacq,
  { {0x443c0061, 0x2fc01bcf, 0x64581bd0, 0x00000000}},  //   _epv_, vlig_, _ervi,
  { {0x6f06004f, 0x7d071bd1, 0x443c02c1, 0x00000000}},  //   _sekc, _nejs, _fpv_,
  { {0x2fc00cb2, 0x6fb6006d, 0x637f0023, 0x00000000}},  //   tlig_, لمسا, _mënj,
  { {0x6d4e1bd2, 0x4393025f, 0xb4d10061, 0x00000000}},  //   _saba, _мајс, वधी_,
  { {0x6d4e1bd3, 0x2fc00374, 0x0e6601e1, 0x00000000}},  // [3e00] _paba, rlig_, шкан,
  { {0x6d4e0312, 0x2fc000f8, 0x645e0285, 0x00000000}},  //   _qaba, slig_, _ápic,
  { {0x6d4e0004, 0x2d9a0051, 0x7d070059, 0x00000000}},  //   _vaba, ripe_, _dejs,
  { {0xfbc301be, 0x2d9a0263, 0x3f89010f, 0x00000000}},  //   обхо, sipe_, chau_,
  { {0x6d4e078f, 0x7d070107, 0x7ae40428, 0x00000000}},  //   _taba, _fejs, žito,
  { {0x2d9a0065, 0x93bd001a, 0x7d071bd4, 0x00000000}},  //   qipe_, ntăr, _gejs,
  { {0xdca3017f, 0x7659018e, 0x2d981bd5, 0x00000000}},  //   _дари, _arwy, _imre_,
  { {0x76590016, 0x66020173, 0x3f801bd6, 0x00000000}},  //   _brwy, _pwok, nkiu_,
  { {0xd0fb007d, 0x76590016, 0x7bc2013e, 0x00000000}},  //   ्रमण_, _crwy, mlou,
  { {0x645801ae, 0x76590016, 0x637f0065, 0x00000000}},  //   _prvi, _drwy, _gënj,
  { {0x2ec303d7, 0x764b0016, 0xc5730025, 0x00000000}},  //   _शर्त, _esgy, تطيع,
  { {0x64580e0d, 0x76590016, 0x7bc21684, 0x00000000}},  //   _vrvi, _frwy, nlou,
  { {0x7762008e, 0x7659005b, 0x00000000, 0x00000000}},  //   _inox, _grwy,   ,
  { {0x443c097c, 0xa63b009b, 0x7bc2013e, 0x00000000}},  //   _tpv_, _סגור, hlou,
  { {0x3f890bc4, 0x7d070018, 0x7414035b, 0x00000000}},  //   thau_, _rejs, _اوبا,
  { {0x93bd0035, 0x764b005b, 0x7659005b, 0x00000000}},  //   drăg, _ysgy, _yrwy,
  { {0x3f89018e, 0x7d0700b9, 0xea000011, 0x00000000}},  // [3e10] rhau_, _pejs, _đếm_,
  { {0x78ad0279, 0x93bd0035, 0x3f890bc1, 0x00000000}},  //   şavi, ctăr, shau_,
  { {0x705502fd, 0x637f0065, 0x2dd80025, 0x00000000}},  //   _انجا, _nënk, شبكة_,
  { {0x2d98014a, 0x6e24060c, 0x7bc2009d, 0x00000000}},  //   _emre_, buib, glou,
  { {0x7f3a007b, 0x2d8f00f4, 0xa2cb0061, 0x00000000}},  //   _גערו, èges_, सेच्,
  { {0x5d850647, 0x7bc200d9, 0xecf8007e, 0x00000000}},  //   _السل, alou, _верш_,
  { {0x7bc2113a, 0xf1bf0010, 0x00000000, 0x00000000}},  //   blou, ltás_,   ,
  { {0x7bc20129, 0x6d4501a3, 0x6f0d1bd7, 0x00000000}},  //   clou, leha, naac,
  { {0x6b830065, 0xf1bf0010, 0x00000000, 0x00000000}},  //   ëngu, ntás_,   ,
  { {0x2717001d, 0x6d4507f9, 0xc9740025, 0x00000000}},  //   ển_, neha, _والث,
  { {0x61f61bd8, 0x0445041f, 0x69c30009, 0x00000000}},  //   _styl, щенн, mlne,
  { {0x03a60242, 0x76590016, 0x69c31bd9, 0x00000000}},  //   симо, _trwy, llne,
  { {0xf6680014, 0x6d451341, 0xd29a0088, 0x00000000}},  //   _نحوه_, keha, утні_,
  { {0x9f58008e, 0xb227000c, 0xf7780066, 0x00000000}},  //   mpré_, _stæð, _ruħi_,
  { {0x64a203e0, 0x6d450030, 0x65631bda, 0x00000000}},  //   _наша, deha, _innh,
  { {0x4425000d, 0x672904cb, 0x6e241bdb, 0x00000000}},  //   mul_, ngej, tuib,
  { {0x4425000d, 0x93bd0035, 0x0d8601ee, 0x00000000}},  // [3e20] lul_, ptăr, блан,
  { {0x6f0d001c, 0x6d45046a, 0x44250068, 0x00000000}},  //   aaac, geha, oul_,
  { {0x4425000d, 0x98a70006, 0x7bc20062, 0x00000000}},  //   nul_, menė_, tlou,
  { {0x6f0d001c, 0xf1bf1bdc, 0x4425001a, 0x00000000}},  //   caac, stát_, iul_,
  { {0x44250004, 0x6d4513d2, 0x6e240df5, 0x00000000}},  //   hul_, beha, quib,
  { {0x44251bdd, 0x7bc200b9, 0x6d451bde, 0x00000000}},  //   kul_, slou, ceha,
  { {0x6c860054, 0xa96700e1, 0x442500e5, 0x00000000}},  //   _الأم, сија_, jul_,
  { {0x442504e3, 0xf1bf0027, 0x65630016, 0x00000000}},  //   dul_, ntár_, _annh,
  { {0x35f70014, 0x22400022, 0x00000000, 0x00000000}},  //   یرید_, _npik_,   ,
  { {0x44250038, 0x454a1bdf, 0x00000000, 0x00000000}},  //   ful_, учим_,   ,
  { {0x4425001a, 0x22400093, 0x6f0d00e7, 0x00000000}},  //   gul_, _apik_, yaac,
  { {0xe29f009f, 0x628f00f6, 0x29c9008e, 0x00000000}},  //   laði_, tzco, núan_,
  { {0x6d451be0, 0x00000000, 0x00000000, 0x00000000}},  //   yeha,   ,   ,
  { {0x4425038c, 0x3d22013d, 0xe29f000c, 0x00000000}},  //   bul_, मलों_, naði_,
  { {0x4425000d, 0x6f0d001c, 0x6d450190, 0x00000000}},  //   cul_, taac, veha,
  { {0x53a4098c, 0xaad90164, 0xc41700a1, 0x00000000}},  //   _најб, बेडक, _اغوا_,
  { {0x63ad0f5b, 0x6d451be1, 0xf1ab0014, 0x00000000}},  // [3e30] _ijan, teha, _ماده_,
  { {0xf1bf0010, 0x290e1be2, 0x61fd046a, 0x00000000}},  //   rtás_, jafa_, mpsl,
  { {0x6d45065c, 0xe29f000c, 0xf1bf00f1, 0x00000000}},  //   reha, daði_, stás_,
  { {0x6d450390, 0x53c9006e, 0x637f0065, 0x00000000}},  //   seha, रतिश, _bëni,
  { {0x2bb10046, 0x4425000d, 0xe29f009f, 0x00000000}},  //   jące_, zul_, faði_,
  { {0x637f0065, 0xb4e7007d, 0xe29f01e5, 0x00000000}},  //   _dëni, _भले_, gaði_,
  { {0x645e04c8, 0x4425001a, 0x69c30146, 0x00000000}},  //   _špin, xul_, rlne,
  { {0xe61901fb, 0x4425001a, 0x63ad003b, 0x00000000}},  //   ади_, vul_, _njan,
  { {0x67291be3, 0x1bd4007c, 0x44250022, 0x00000000}},  //   rgej, _хотя, wul_,
  { {0x44251305, 0x63ad1be4, 0x290e00e7, 0x00000000}},  //   tul_, _ajan, cafa_,
  { {0x39471be5, 0x63ad1be6, 0x61fd00bb, 0x00000000}},  //   mens_, _bjan, epsl,
  { {0x44251305, 0xc1690097, 0x22400022, 0x00000000}},  //   rul_, _בח_, _ppik_,
  { {0x4425000d, 0x63ad01aa, 0x515600ed, 0x00000000}},  //   sul_, _djan, отву,
  { {0x6b8916ca, 0x394700eb, 0x4425000d, 0x00000000}},  //   _lleg, nens_, pul_,
  { {0xaf9a085f, 0x6b9b1be7, 0x6b89010e, 0x00000000}},  //   атах_, _omug, _oleg,
  { {0x290e1be8, 0x82a60088, 0x3947192b, 0x00000000}},  //   zafa_, _майж, hens_,
  { {0x1dc50309, 0x8fa300ed, 0x7ae40161, 0x00000000}},  // [3e40] वतंत, фате, žitk,
  { {0x6b891be9, 0x39470190, 0x637f0065, 0x00000000}},  //   _aleg, jens_, _rëni,
  { {0x39471bea, 0x6b891beb, 0xdee60242, 0x00000000}},  //   dens_, _bleg, _мони,
  { {0x39470061, 0x6b890145, 0x00000000, 0x00000000}},  //   eens_, _cleg,   ,
  { {0x39471bec, 0xe29f000c, 0x6b8200f8, 0x00000000}},  //   fens_, taði_, rkog,
  { {0x394708da, 0x637f0023, 0x2d9e014a, 0x00000000}},  //   gens_, _vëni, _öte_,
  { {0x290e1bed, 0xe29f000c, 0x58d300e2, 0x00000000}},  //   rafa_, raði_, мошт,
  { {0x290e06fe, 0x00000000, 0x00000000, 0x00000000}},  //   safa_,   ,   ,
  { {0x3947119b, 0x056a01fc, 0xbddb009d, 0x00000000}},  //   bens_, ајни_, _isèr,
  { {0x39470f4a, 0x63ad0056, 0x2bb10036, 0x00000000}},  //   cens_, _sjan, rące_,
  { {0x63ad002b, 0x09e30044, 0xa3e4006e, 0x00000000}},  //   _pjan, _নৌকা, _भूख_,
  { {0xf746004c, 0x9f420023, 0x290c151d, 0x00000000}},  //   _федо, _dikë_, _heda_,
  { {0xe3b9006b, 0x290c1bee, 0x753d0010, 0x00000000}},  //   brın_, _keda_, ősza,
  { {0x290c0093, 0x637f0023, 0x00000000, 0x00000000}},  //   _jeda_, _nënv,   ,
  { {0xcf9b07d8, 0x290c0173, 0xdfd51001, 0x00000000}},  //   аја_, _meda_, зовы,
  { {0x290c0039, 0x2d8a001a, 0x61fd0479, 0x00000000}},  //   _leda_, _albe_, ppsl,
  { {0x394700f4, 0x645a0b16, 0x00000000, 0x00000000}},  // [3e50] yens_, lvti,   ,
  { {0x6b9b032e, 0x6b890343, 0x290c0738, 0x00000000}},  //   _smug, _sleg, _neda_,
  { {0x394702ae, 0x6b890129, 0xe1ff004a, 0x00000000}},  //   vens_, _pleg, lpó_,
  { {0x63bd0213, 0x61ed027e, 0x39470343, 0x00000000}},  //   nosn, _kual, wens_,
  { {0x290c1bef, 0x61ed04cb, 0x61e51bf0, 0x00000000}},  //   _beda_, _jual, _kihl,
  { {0x39470007, 0x290c1bf1, 0x61e501dc, 0x00000000}},  //   uens_, _ceda_, _jihl,
  { {0x76420211, 0x39471bea, 0x290c003b, 0x00000000}},  //   _apoy, rens_, _deda_,
  { {0x6d550010, 0x3947004e, 0x6b9b1bf2, 0x00000000}},  //   _haza, sens_, _umug,
  { {0x6d55011f, 0x39470168, 0xd706007c, 0x00000000}},  //   _kaza, pens_, чные_,
  { {0xb9980783, 0x6d550aa8, 0x9f420065, 0x00000000}},  //   _двух_, _jaza, _pikë_,
  { {0x1b0e0055, 0x320900ab, 0xf1bf004a, 0x00000000}},  //   _হাতে_, _away_, tuán_,
  { {0x6d55037e, 0x61ed1aed, 0x32090173, 0x00000000}},  //   _laza, _bual, _bway_,
  { {0x61ed0845, 0x290c00c4, 0x673b012d, 0x00000000}},  //   _cual, _yeda_, mfuj,
  { {0x6d5501d9, 0x61ed0b62, 0xa6e1000c, 0x00000000}},  //   _naza, _dual, öðug,
  { {0x32090082, 0x7ae90288, 0x98a70089, 0x00000000}},  //   _eway_, _oget, denī_,
  { {0x7ae909e4, 0x09a8013d, 0x7ae40027, 0x00000000}},  //   _nget, _औद्य, žiti,
  { {0x6d55005f, 0x3cde0061, 0x71a601ee, 0x00000000}},  // [3e60] _baza, केने_, _наиз,
  { {0x6d55172b, 0x6e360006, 0x637f0065, 0x00000000}},  //   _caza, rtyb, _dënu,
  { {0x290c12d8, 0x0b460069, 0xb33b09b1, 0x00000000}},  //   _reda_, знен, liça,
  { {0x290c0004, 0x261c062e, 0x7d010035, 0x00000000}},  //   _seda_, _मिली_, _pârâ,
  { {0x6f040169, 0x290c0052, 0xba73023c, 0x00000000}},  //   mbic, _peda_, فاوت,
  { {0x644300b5, 0x7ae916ec, 0x290c1bf3, 0x00000000}},  //   _opni, _eget, _qeda_,
  { {0x8c430373, 0xd90d00d3, 0xf7720447, 0x00000000}},  //   _пере, شین_, فاظ_,
  { {0x69c1011f, 0x7d0e1bf4, 0x6d551bf5, 0x00000000}},  //   _ekle, _hebs, _zaza,
  { {0x6d55047f, 0x290c1bf6, 0x6e2412aa, 0x00000000}},  //   _yaza, _teda_, nrib,
  { {0x61eb00f4, 0x1dbe0309, 0x6d55006b, 0x00000000}},  //   _égli, ्तित, _xaza,
  { {0x61ed0294, 0x6e240279, 0x63bd0e24, 0x00000000}},  //   _sual, hrib, tosn,
  { {0x637f0065, 0x60c5021e, 0x7d0e1bf7, 0x00000000}},  //   _nënt, _ryhm, _lebs,
  { {0x645a001c, 0x61ed051b, 0xe298008b, 0x00000000}},  //   svti, _qual, заў_,
  { {0xbddb00f6, 0x26db00a0, 0x00000000, 0x00000000}},  //   _apèn, _הקדמ,   ,
  { {0x6d55051a, 0xe53b00a0, 0x63bd00ca, 0x00000000}},  //   _raza, _התור, posn,
  { {0x4fc409f1, 0xb33b00fa, 0xdb0b074d, 0x00000000}},  //   есуа, biça, llgö,
  { {0x6d55011f, 0x2bb10036, 0x6e240dc5, 0x00000000}},  // [3e70] _paza, jąca_, grib,
  { {0x6d55005f, 0x27e6032c, 0x60c500b0, 0x00000000}},  //   _qaza, _lion_, _tyhm,
  { {0x6d5515f7, 0x6f040026, 0x6e2400e0, 0x00000000}},  //   _vaza, bbic, arib,
  { {0x69c10046, 0x6d55000b, 0x27e6002d, 0x00000000}},  //   _skle, _waza, _nion_,
  { {0x6e241bf8, 0x6d550020, 0x2fc91bf9, 0x00000000}},  //   crib, _taza, mlag_,
  { {0xd90f04e1, 0x27e60052, 0x2fc91bfa, 0x00000000}},  //   ایا_, _aion_, llag_,
  { {0x23690119, 0x27e60032, 0x26c60022, 0x00000000}},  //   _onaj_, _bion_, _ayoo_,
  { {0x27e60051, 0x69c10036, 0x7d1c1a7d, 0x00000000}},  //   _cion_, _wkle, _zdrs,
  { {0x6f0f0ef1, 0x27e6002d, 0x645c1bfb, 0x00000000}},  //   _mecc, _dion_, ærin,
  { {0x6f0f1bfc, 0x2fc9010f, 0x39150167, 0x00000000}},  //   _lecc, hlag_, _آواز,
  { {0x637f0065, 0xa34a00e3, 0x27e6009d, 0x00000000}},  //   _nëns, озна_, _fion_,
  { {0xf2a602ea, 0x27e60068, 0xb33b00fa, 0x00000000}},  //   димп, _gion_, tiça,
  { {0x7ae40059, 0xe2970783, 0x6e24013f, 0x00000000}},  //   žitv, дая_, xrib,
  { {0x6f1d0b32, 0x27e6002d, 0xb33b00fa, 0x00000000}},  //   _adsc, _zion_, riça,
  { {0x6f0f0197, 0x2fc90991, 0x91e30088, 0x00000000}},  //   _becc, flag_, торе,
  { {0x6f0f02c9, 0x442500d0, 0x2fc9011c, 0x00000000}},  //   _cecc, mrl_, glag_,
  { {0x6f0404cb, 0x0eaa008b, 0x6f0f1811, 0x00000000}},  // [3e80] rbic, цкай_, _decc,
  { {0x6f041862, 0x23690166, 0x6f1d0026, 0x00000000}},  //   sbic, _znaj_, _edsc,
  { {0x6c4a002c, 0x51f6025a, 0x926500a2, 0x00000000}},  //   تلاف_, _عسکر, _قدیم,
  { {0x6e24188a, 0x5aca00ed, 0x7d050051, 0x00000000}},  //   prib, олем_, abhs,
  { {0x6e24006b, 0x25be004a, 0x7d0e01c3, 0x00000000}},  //   qrib, yotl_, _tebs,
  { {0x2fc00051, 0x27e60de7, 0x6f0f0197, 0x00000000}},  //   loig_, _sion_, _zecc,
  { {0xa3c30309, 0xa2a5007d, 0x19b9007e, 0x00000000}},  //   ्तम_, _चेन्, чуць_,
  { {0x97a30783, 0xb6050087, 0x00000000, 0x00000000}},  //   крыл, _odšč,   ,
  { {0x993a007e, 0x00000000, 0x00000000, 0x00000000}},  //   _мяжу_,   ,   ,
  { {0x26c600e7, 0x44980088, 0x00000000, 0x00000000}},  //   _vyoo_, звою_,   ,
  { {0x201e0387, 0x27e60835, 0xe73a0131, 0x00000000}},  //   átil_, _tion_, _меж_,
  { {0x69ca1bfd, 0xc6a602dc, 0x00000000, 0x00000000}},  //   llfe, _орли,   ,
  { {0x6f0f197d, 0x44250082, 0x3a2600ea, 0x00000000}},  //   _recc, arl_, nrop_,
  { {0x6f0f1bfe, 0x00000000, 0x00000000, 0x00000000}},  //   _secc,   ,   ,
  { {0x656a002a, 0x6f0f1bff, 0x00000000, 0x00000000}},  //   _infh, _pecc,   ,
  { {0x442c1c00, 0x9df906e1, 0x93780025, 0x00000000}},  //   mud_, знат_, _يصير_,
  { {0x442c1c01, 0x6f0f0207, 0x291e00ea, 0x00000000}},  // [3e90] lud_, _vecc, _odta_,
  { {0x3a260436, 0xeca70184, 0x00000000, 0x00000000}},  //   drop_, мјен,   ,
  { {0x442c061f, 0x6f0f0232, 0x070e01f5, 0x00000000}},  //   nud_, _tecc, सराव_,
  { {0xad9b0daf, 0x61fb001a, 0x20031c02, 0x00000000}},  //   _stúd, ţulu, mpji_,
  { {0xa969025f, 0x442c010e, 0x00000000, 0x00000000}},  //   зила_, hud_,   ,
  { {0x442c1c03, 0xac190175, 0xdb0b0051, 0x00000000}},  //   kud_, _ногу_, ingé,
  { {0x442c04cb, 0xb8f70309, 0x6e2d00ab, 0x00000000}},  //   jud_, _सर_, luab,
  { {0x442c1c04, 0xd7f80082, 0x3f89007f, 0x00000000}},  //   dud_, _trăn_, nkau_,
  { {0x6e2d008e, 0x7afb00e7, 0x00000000, 0x00000000}},  //   nuab, _ifut,   ,
  { {0x7bcb0afd, 0x442500ea, 0xe5710025, 0x00000000}},  //   llgu, trl_, اطة_,
  { {0x44250061, 0x442c095a, 0xd469003b, 0x00000000}},  //   url_, gud_, чине_,
  { {0x7853006b, 0x00000000, 0x00000000, 0x00000000}},  //   _nəvə,   ,   ,
  { {0x44250026, 0x442c0068, 0x8883009e, 0x00000000}},  //   srl_, aud_, _سیکن,
  { {0x442c01bf, 0x201e0107, 0x442500ca, 0x00000000}},  //   bud_, štim_, prl_,
  { {0xa067012b, 0x1beb007d, 0x2bb10036, 0x00000000}},  //   нара_, _जंगल_, jąco_,
  { {0x3f89003f, 0x25a51c05, 0x00000000, 0x00000000}},  //   gkau_, lill_,   ,
  { {0x7853006b, 0x4d66007e, 0x63a60022, 0x00000000}},  // [3ea0] _dəvə, нкав, mikn,
  { {0x25a51c06, 0x63a6027e, 0x7dc601b2, 0x00000000}},  //   nill_, likn, رقان,
  { {0x10a60088, 0x98a70006, 0x00000000, 0x00000000}},  //   _чинн, denį_,   ,
  { {0x6e2d0b50, 0x63a604bb, 0x3a261c07, 0x00000000}},  //   buab, nikn, trop_,
  { {0x6f630057, 0x25a5000c, 0xf1bf004a, 0x00000000}},  //   _связ, kill_, irán_,
  { {0xdca61c08, 0xf1bf0051, 0x442c1c09, 0x00000000}},  //   _заги, hrán_, yud_,
  { {0x442c006b, 0xfdbe013d, 0x25a50fad, 0x00000000}},  //   xud_, ्तीफ, dill_,
  { {0x442c02e1, 0xca761c0a, 0x637f0023, 0x00000000}},  //   vud_, _пузы, _nënp,
  { {0xf1bf0211, 0x442c04be, 0x63a6008a, 0x00000000}},  //   drán_, wud_, dikn,
  { {0x442c1c0b, 0x25a501e5, 0x38c80123, 0x00000000}},  //   tud_, gill_, _قاضی_,
  { {0x46ea01f9, 0x3e5201aa, 0x4395142c, 0x00000000}},  //   _еден_, _lņt_, ванс,
  { {0x442c0030, 0xf1bf0051, 0x9f970023, 0x00000000}},  //   rud_, grán_, rçë_,
  { {0x32190061, 0x442c1c0c, 0x6f1606f2, 0x00000000}},  //   ussy_, sud_, dayc,
  { {0xf1bf1a1c, 0x442c006c, 0x66e3094b, 0x00000000}},  //   arán_, pud_, _соча,
  { {0xc4f7007b, 0xd48f013b, 0xf1bf02f9, 0x00000000}},  //   _אזוי_, _ср_, brán_,
  { {0x6e2d010e, 0x628600d9, 0x00000000, 0x00000000}},  //   tuab, byko,   ,
  { {0x3f890006, 0x8d87007c, 0xe3b01c0d, 0x00000000}},  // [3eb0] rkau_, нужд, _درو_,
  { {0x22490119, 0x3f891c0e, 0xfd100025, 0x00000000}},  //   _ipak_, skau_, مجم_,
  { {0x6f160163, 0x7853006b, 0x6e2d04a5, 0x00000000}},  //   bayc, _təvə, suab,
  { {0xa3c303d7, 0x501a009b, 0x2bb10036, 0x00000000}},  //   ्ति_, _קורו, rąco_,
  { {0x2fd90093, 0x5edf0044, 0x1a6800a1, 0x00000000}},  //   _ihsg_, _ফ্রে, ٹیلی_,
  { {0x7dcb006c, 0xf2d40049, 0xd9450745, 0x00000000}},  //   küsi, נעס_, теки,
  { {0xa3c302f4, 0x62860c8c, 0x2d910089, 0x00000000}},  //   ्ता_, zyko, _ilze_,
  { {0x25a50066, 0x9ff30044, 0xf7710a4f, 0x00000000}},  //   will_, _জবাব_, شاب_,
  { {0x25a50538, 0x9955004d, 0x63a60091, 0x00000000}},  //   till_, _икац, vikn,
  { {0xb4650088, 0x88e30044, 0x00000000, 0x00000000}},  //   вкол, নুষক,   ,
  { {0x69c30006, 0x63a604be, 0x22491c0f, 0x00000000}},  //   mone, tikn, _apak_,
  { {0x62861c10, 0x22490022, 0x03a6005c, 0x00000000}},  //   tyko, _bpak_, тимо,
  { {0x63a6008a, 0x25a51341, 0xf1bf0232, 0x00000000}},  //   rikn, pill_, rrán_,
  { {0x412a01fb, 0x69c300b0, 0x62861c11, 0x00000000}},  //   ього_, none, ryko,
  { {0xed520014, 0x69c30032, 0x2121004a, 0x00000000}},  //   یپر_, ione, _ddhh_,
  { {0xe4e40088, 0x6266022a, 0x3e52000a, 0x00000000}},  //   _січн, _авиа, _pņt_,
  { {0xee3a0425, 0x69c31c12, 0x63a40e6a, 0x00000000}},  // [3ec0] ьна_, kone, _imin,
  { {0x69c30292, 0xdb0000f4, 0x91e601ee, 0x00000000}},  //   jone, _immé, _шопе,
  { {0x69c31c13, 0x63a41c14, 0xa7fc01df, 0x00000000}},  //   done, _kmin, _arın,
  { {0x6a8600ed, 0x661b03b6, 0xf1bf00b9, 0x00000000}},  //   клеа, ksuk, hrál_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x661b1c15, 0x00000000, 0x00000000, 0x00000000}},  //   dsuk,   ,   ,
  { {0x63a400b0, 0xd7f80011, 0xa96701fc, 0x00000000}},  //   _omin, _trăm_, тија_,
  { {0x6d5e0bbc, 0x63a400e0, 0x7c3e01a2, 0x00000000}},  //   ldpa, _nmin, mtpr,
  { {0x6d5c1c16, 0x69c3002d, 0x201e0107, 0x00000000}},  //   _kara, bone, štih_,
  { {0x63a4006a, 0x69c304bd, 0x6d5c033b, 0x00000000}},  //   _amin, cone, _jara,
  { {0x92af08b7, 0x6d5c066d, 0x19b9007c, 0x00000000}},  //   _করে_, _mara, _чуть_,
  { {0x6d5c006a, 0x22490022, 0x63a40146, 0x00000000}},  //   _lara, _ppak_, _cmin,
  { {0x63a40056, 0x86c30014, 0x00000000, 0x00000000}},  //   _dmin, _پيون,   ,
  { {0x63a41c17, 0x7c3e02e1, 0xf4840123, 0x00000000}},  //   _emin, ktpr, _مابی,
  { {0x25ab00f4, 0xdb1b0011, 0xa5bd0006, 0x00000000}},  //   ècle_, _khuô, krųj,
  { {0x69c30885, 0x6d5c006a, 0x63a40036, 0x00000000}},  //   zone, _aara, _gmin,
  { {0x6d5c04d4, 0x6d5e00b5, 0x69c30095, 0x00000000}},  // [3ed0] _bara, fdpa, yone,
  { {0x69c30982, 0x7c3e068f, 0x5c070c4e, 0x00000000}},  //   xone, ftpr, вяда,
  { {0x443e008e, 0x69c300b0, 0x64580087, 0x00000000}},  //   ntt_, vone, _jsvi,
  { {0x66021c18, 0xff041c19, 0x69c301b5, 0x00000000}},  //   _otok, _вярн, wone,
  { {0x6b80037f, 0x443e0082, 0x66020045, 0x00000000}},  //   _domg, htt_, _ntok,
  { {0x6d5c0238, 0x64580626, 0x644a0030, 0x00000000}},  //   _gara, _osvi, _opfi,
  { {0x69c3029d, 0x7c3e0d4d, 0x92af0044, 0x00000000}},  //   rone, ctpr, _করো_,
  { {0x6d5c01d9, 0xdb1b0011, 0x69c30238, 0x00000000}},  //   _zara, _chuô, sone,
  { {0x6d5c038c, 0x7f5d00f4, 0x443e1c1a, 0x00000000}},  //   _yara, _masq, ett_,
  { {0x63a41c1b, 0x6d5c006b, 0x661b0145, 0x00000000}},  //   _smin, _xara, rsuk,
  { {0x443e001c, 0x661b0052, 0x63a40145, 0x00000000}},  //   gtt_, ssuk, _pmin,
  { {0x7981005b, 0x7f5d00f6, 0xdcfc0066, 0x00000000}},  //   _holw, _nasq, _porċ,
  { {0x6d470c06, 0x69da021e, 0x79811c1c, 0x00000000}},  //   _obja, _yhte, _kolw,
  { {0xf652009b, 0x00000000, 0x00000000, 0x00000000}},  //   _לצד_,   ,   ,
  { {0xb18401dc, 0x7c3e1c1d, 0x3fc8025a, 0x00000000}},  //   šťov, xtpr, ندری_,
  { {0x63a4011c, 0x7f5d00f4, 0x6d471c1e, 0x00000000}},  //   _umin, _casq, _abja,
  { {0xa3c302fb, 0x0e66008b, 0x7d150eef, 0x00000000}},  // [3ee0] ्तर_, ыкан, _bezs,
  { {0x6d5c005f, 0x3c3c1c1f, 0x7c3e1c20, 0x00000000}},  //   _qara, tív_, ttpr,
  { {0x3157007b, 0x0c26005e, 0x8fa60517, 0x00000000}},  //   _גיין_, умен, _бане,
  { {0x69da008d, 0xeb971c21, 0x207b0049, 0x00000000}},  //   _shte, лих_, _נאכא,
  { {0x6d5c0483, 0x79811c22, 0xab31006b, 0x00000000}},  //   _tara, _bolw, zıçı_,
  { {0x443e1c23, 0xdcfc0eae, 0x7981005b, 0x00000000}},  //   ytt_, _korč, _colw,
  { {0x3f8219c2, 0x764b0006, 0x6b8002e7, 0x00000000}},  //   _koku_, _apgy, _tomg,
  { {0x3f821c24, 0xf093009b, 0x7f441c25, 0x00000000}},  //   _joku_, מנו_, nfiq,
  { {0x0936023c, 0x853c0006, 0xa91c0142, 0x00000000}},  //   _مراج, siėm, _voľb,
  { {0xaa930025, 0x79811c26, 0x443e0785, 0x00000000}},  //   _الكث, _golw, ttt_,
  { {0x94d40245, 0xdcfc00ca, 0xa4d4013a, 0x00000000}},  //   ронц, _norč, роні,
  { {0xdb090065, 0x7dcb006b, 0x395e03a1, 0x00000000}},  //   _vjeç, lüst, _hats_,
  { {0x7f5d06c2, 0x443e0145, 0x66021c27, 0x00000000}},  //   _rasq, stt_, _utok,
  { {0xdcfc01ee, 0x365b009b, 0x443e0068, 0x00000000}},  //   _borč, _נכונ, ptt_,
  { {0x6ab00183, 0x395e0039, 0x7f5d1c28, 0x00000000}},  //   जपुर, _mats_, _pasq,
  { {0x29c9009f, 0x998600b9, 0xe1f000a6, 0x00000000}},  //   núar_, spoň_, _کسي_,
  { {0x6e3d0009, 0x61f60173, 0x7f5d038e, 0x00000000}},  // [3ef0] _qqsb, _guyl, _vasq,
  { {0x442c049b, 0x395e010e, 0x7bc901d6, 0x00000000}},  //   ord_, _nats_, _skeu,
  { {0x7f5d0129, 0x70fa009b, 0x7dcb014a, 0x00000000}},  //   _tasq, _בהתח, düst,
  { {0x907a00a0, 0x442c0051, 0x798100d2, 0x00000000}},  //   _סטרי, ird_, _solw,
  { {0x6f0d0149, 0xfe35007b, 0x79810093, 0x00000000}},  //   mbac, _דאָך_, _polw,
  { {0x6f0d01a2, 0x644e002b, 0x395e0133, 0x00000000}},  //   lbac, ħbij, _cats_,
  { {0x798101b5, 0x395e06ed, 0x00000000, 0x00000000}},  //   _volw, _dats_,   ,
  { {0x2d8302d5, 0xf6250072, 0x6f0d0dcc, 0x00000000}},  //   _hoje_, адио, nbac,
  { {0x2d830119, 0xe616045a, 0x442c015c, 0x00000000}},  //   _koje_, ады_, erd_,
  { {0x764b0061, 0x6f0d0471, 0x395e1c29, 0x00000000}},  //   _vpgy, hbac, _gats_,
  { {0x04450805, 0x7dcb010f, 0x645e14ba, 0x00000000}},  //   шенн, lüss, _špir,
  { {0x6e2d0232, 0x2d831c2a, 0x00000000, 0x00000000}},  //   krab, _loje_,   ,
  { {0x3f821712, 0x6f0d00ab, 0x442c0f12, 0x00000000}},  //   _roku_, dbac, ard_,
  { {0x66091c2b, 0xd62600ed, 0x6e2d0089, 0x00000000}},  //   mpek, _тоше_, drab,
  { {0x6f0d057e, 0x0cb00055, 0xc0e6007c, 0x00000000}},  //   fbac, _কর্ত, ровк,
  { {0x64411c2c, 0x7dcb0095, 0x0c760014, 0x00000000}},  //   mtli, züst, یداد,
  { {0x6e2d0c99, 0x6441010f, 0x2d83039b, 0x00000000}},  // [3f00] grab, ltli, _boje_,
  { {0xd24f00a2, 0x64410007, 0x27ef0030, 0x00000000}},  //   _کنی_, otli, _lign_,
  { {0x64410109, 0x26cf0009, 0xed57007e, 0x00000000}},  //   ntli, _lygo_, рох_,
  { {0x6441010f, 0xdb0b0181, 0x6e2d008e, 0x00000000}},  //   itli, ligê, brab,
  { {0x395e0a5c, 0x6441050d, 0x6e2d00e5, 0x00000000}},  //   _pats_, htli, crab,
  { {0xa3dd02fb, 0x64410039, 0x442c00ea, 0x00000000}},  //   _तीन_, ktli, yrd_,
  { {0x7dcb1c2d, 0x26cf0bc7, 0x2b5500a1, 0x00000000}},  //   rüst, _aygo_, _گیند_,
  { {0x7dcb006c, 0x395e01c3, 0xf1bf03b5, 0x00000000}},  //   süst, _wats_, nuár_,
  { {0xd6d70e09, 0x64411c2e, 0x00000000, 0x00000000}},  //   ить_, etli,   ,
  { {0x6441010f, 0x356a005e, 0x80f5006e, 0x00000000}},  //   ftli, трин_, _आलेख_,
  { {0x6f0d0075, 0x442c00b5, 0x98a50180, 0x00000000}},  //   ybac, urd_, _falı_,
  { {0x291c0059, 0x442c0022, 0x27ef1c2f, 0x00000000}},  //   lava_, rrd_, _gign_,
  { {0x9f42021e, 0x64410eaa, 0xf1bf0010, 0x00000000}},  //   _mikä_, atli, nság_,
  { {0x291c0027, 0x6e2d009d, 0x98a5006b, 0x00000000}},  //   nava_, vrab, _zalı_,
  { {0x64410045, 0xddcd0036, 0x2d830023, 0x00000000}},  //   ctli, ywał, _roje_,
  { {0xcf98045e, 0x6e2d011c, 0x291c1c30, 0x00000000}},  //   ају_, trab, hava_,
  { {0x291c1ab1, 0x2d8300ca, 0xfe700025, 0x00000000}},  // [3f10] kava_, _poje_, ودك_,
  { {0x291c0087, 0x6f0d0002, 0x6e2d13e4, 0x00000000}},  //   java_, sbac, rrab,
  { {0x291c014a, 0x2d830107, 0x201e00b9, 0x00000000}},  //   dava_, _voje_, átit_,
  { {0x6e2d00d4, 0xdea10014, 0x3a751c31, 0x00000000}},  //   prab, _فیزی, йлер,
  { {0xeab00379, 0x291c1c32, 0x2d830006, 0x00000000}},  //   وعه_, fava_, _toje_,
  { {0x27ef0038, 0x9f42021e, 0x98a5014a, 0x00000000}},  //   _sign_, _eikä_, _salı_,
  { {0x7c950054, 0x6c850647, 0x6441010f, 0x00000000}},  //   _الأص, _الزم, xtli,
  { {0x5ba40e09, 0x9f970129, 0x00000000, 0x00000000}},  //   _друз, nçà_,   ,
  { {0x291c0cce, 0x00000000, 0x00000000, 0x00000000}},  //   bava_,   ,   ,
  { {0x6609011c, 0x64411c33, 0x660d014a, 0x00000000}},  //   rpek, ttli, _çakm,
  { {0x6609151e, 0x84580401, 0x64411c34, 0x00000000}},  //   spek, арят_, utli,
  { {0x6441010f, 0xad9b000c, 0xdcfc0089, 0x00000000}},  //   rtli, _stúl, _morā,
  { {0x6605003b, 0x00000000, 0x00000000, 0x00000000}},  //   _упла,   ,   ,
  { {0x637f008d, 0x9103005e, 0x845902ea, 0x00000000}},  //   _mëny, зпре, _брит_,
  { {0xdcfc001e, 0xf1bf0010, 0x00000000, 0x00000000}},  //   _norā, zság_,   ,
  { {0xd00f002c, 0x291c01d9, 0x2d870706, 0x00000000}},  //   علق_, zava_, önen_,
  { {0xdee3004d, 0xdd8f0123, 0xea000011, 0x00000000}},  // [3f20] зоти, کول_, _đắm_,
  { {0x201e02d5, 0x291c1052, 0x627b00a3, 0x00000000}},  //   átis_, xava_, _ענינ,
  { {0xbddb0173, 0x0fda0014, 0xcb6a003b, 0x00000000}},  //   _apès, _مبحث_, лаже_,
  { {0xf3f90055, 0x201e010a, 0x00000000, 0x00000000}},  //   _আবার_, štis_,   ,
  { {0xe3b901df, 0xc6b20044, 0x00000000, 0x00000000}},  //   ksın_, _চর্চ,   ,
  { {0x7d960025, 0x5d860025, 0xfce60131, 0x00000000}},  //   _السؤ, _الآل, _гого,
  { {0xf1bf0010, 0xc866005e, 0x3ea00035, 0x00000000}},  //   sság_, стли, lzit_,
  { {0x291c037e, 0xbb430057, 0x7d1e006c, 0x00000000}},  //   sava_, _неск, laps,
  { {0xd6d00025, 0xf66a03ec, 0x3ea0013f, 0x00000000}},  //   بقة_, احبه_, nzit_,
  { {0x7d1e0232, 0x8afd00b9, 0x39990bf2, 0x00000000}},  //   naps, _vaře, _pèse_,
  { {0x07a6025f, 0x25ac0022, 0x00000000, 0x00000000}},  //   _лажн, ridl_,   ,
  { {0xc7f7009b, 0x69ca00bb, 0x7d1e1c35, 0x00000000}},  //   _הזאת_, lofe, haps,
  { {0x7d1e01c9, 0x00000000, 0x00000000, 0x00000000}},  //   kaps,   ,   ,
  { {0x645c1c36, 0x7d1e016c, 0x00000000, 0x00000000}},  //   æris, japs,   ,
  { {0xbddb009d, 0x251b00a3, 0x00000000, 0x00000000}},  //   _opèr, _גווא,   ,
  { {0xa3bd03d7, 0x69ca010f, 0x4034025f, 0x00000000}},  //   _आदि_, hofe, џетс,
  { {0x63af021c, 0x88bc00b9, 0x00000000, 0x00000000}},  // [3f30] micn, _sděl,   ,
  { {0x63af037e, 0x753a0203, 0x3209011c, 0x00000000}},  //   licn, ngtz, _itay_,
  { {0x69ca0066, 0xdb0b01e6, 0xa91c0142, 0x00000000}},  //   dofe, ligé, _poľn,
  { {0x63af012d, 0xeab100a1, 0x398b01e3, 0x00000000}},  //   nicn, وٹا_, _løst_,
  { {0x7f3a007b, 0xa91c0027, 0x784a006b, 0x00000000}},  //   _דערו, _voľn, _rəva,
  { {0xa96900ed, 0x69ca0203, 0x7d1e0133, 0x00000000}},  //   рика_, gofe, caps,
  { {0x88bc0224, 0xab950088, 0x00000000, 0x00000000}},  //   _uděl, _диві,   ,
  { {0x6d571c37, 0xd5b80089, 0x91f90164, 0x00000000}},  //   lexa, enā_, ंदाज_,
  { {0x7bcb10c6, 0x63af01ee, 0x00000000, 0x00000000}},  //   mogu, dicn,   ,
  { {0x7bcb1c38, 0x628f0b40, 0x05a9007c, 0x00000000}},  //   logu, dyco, рвой_,
  { {0xe3ba0057, 0x7dd00bf4, 0x32091c39, 0x00000000}},  //   ибо_, mäst, _atay_,
  { {0x3ce10754, 0x63af1c3a, 0x42ea0ae0, 0x00000000}},  //   _करने_, gicn, имно_,
  { {0x9293007e, 0x63bd004a, 0x00000000, 0x00000000}},  //   даўц, érna,   ,
  { {0x7dd01c3b, 0x00000000, 0x00000000, 0x00000000}},  //   näst,   ,   ,
  { {0x63af037e, 0x7bcb0004, 0x2b4d01ca, 0x00000000}},  //   bicn, kogu, _obec_,
  { {0x673b0161, 0x65630082, 0x7dd01c3c, 0x00000000}},  //   nguj, _hanh, häst,
  { {0x3f9912b5, 0x65630199, 0x7dd00cba, 0x00000000}},  // [3f40] _dlsu_, _kanh, käst,
  { {0x3ea01c3d, 0x2b4d0062, 0x69ca00fa, 0x00000000}},  //   rzit_, _abec_, xofe,
  { {0x7d1e0065, 0x65630335, 0x7bcb1c3e, 0x00000000}},  //   raps, _manh, fogu,
  { {0x29051c3f, 0xe800013d, 0x6563005b, 0x00000000}},  //   _afla_, _लंबा_, _lanh,
  { {0x79c6007e, 0x7dd000f8, 0xdcfc00e5, 0x00000000}},  //   ойдз, fäst, _coră,
  { {0x082a0769, 0xf806058f, 0x291a1c40, 0x00000000}},  //   ации_, очин, úpa_,
  { {0x23ca0183, 0x53ca0061, 0x6d4e002b, 0x00000000}},  //   रवाद, रवाश, _ibba,
  { {0x7d1c1440, 0x6f040107, 0x65631c41, 0x00000000}},  //   _hers, ncic, _aanh,
  { {0x7d1c00c7, 0x65630181, 0x63af01ee, 0x00000000}},  //   _kers, _banh, vicn,
  { {0x48e61c42, 0x7dd00bf4, 0x7d1c00ab, 0x00000000}},  //   _дозв, mäss, _jers,
  { {0x63af07d1, 0x2cfb061e, 0x320900ab, 0x00000000}},  //   ticn, יליא, _stay_,
  { {0x6f04037e, 0xf1bf00b9, 0x6b821c43, 0x00000000}},  //   jcic, hrát_, njog,
  { {0xf1bf01ca, 0x7d1c1c44, 0x3e4e0089, 0x00000000}},  //   krát_, _oers, nētā_,
  { {0x656302d5, 0x63af0107, 0xc87e006b, 0x00000000}},  //   _ganh, sicn, şğul_,
  { {0x3f8700ed, 0x6e240032, 0x7bcb00e7, 0x00000000}},  //   оѓаа, esib, yogu,
  { {0x6d4e001b, 0x628f0009, 0x2328003b, 0x00000000}},  //   _abba, pyco, _доћи_,
  { {0x7d1c020c, 0x63ad000b, 0x518701c0, 0x00000000}},  // [3f50] _bers, _iman, _дуна,
  { {0x7988018e, 0x93bd001a, 0xfd100025, 0x00000000}},  //   _nodw, crăr, نجم_,
  { {0x7d1c1c45, 0x7bcb0006, 0x63ad002b, 0x00000000}},  //   _ders, togu, _kman,
  { {0x7d1c049b, 0x799a0bed, 0x6f040197, 0x00000000}},  //   _eers, _altw, ccic,
  { {0x7d1c0016, 0xea00001d, 0x63ad0066, 0x00000000}},  //   _fers, _đảm_, _mman,
  { {0x7d1c000c, 0x8dfa00b6, 0x4e16009b, 0x00000000}},  //   _gers, _להשת, _מחשב_,
  { {0x63ad0004, 0x785702fd, 0x7dd000b0, 0x00000000}},  //   _oman, تیاز_, räst,
  { {0x6563011c, 0x7d1c010f, 0x63ad0058, 0x00000000}},  //   _sanh, _zers, _nman,
  { {0x65631214, 0x3964021e, 0x7d1c0276, 0x00000000}},  //   _panh, össä_, _yers,
  { {0x63ad16c3, 0x7988005b, 0x6b8901d6, 0x00000000}},  //   _aman, _godw, _hoeg,
  { {0x6563021e, 0x8afd00b9, 0x6b89016c, 0x00000000}},  //   _vanh, _zařa, _koeg,
  { {0x6f1d1a56, 0x6b8900d9, 0x8c49005a, 0x00000000}},  //   _nesc, _joeg, maşı,
  { {0x8c49005d, 0xc7b200b3, 0xa3bd0164, 0x00000000}},  //   laşı, _אבא_, _आदर_,
  { {0x63ad0c35, 0x64a5012b, 0xf1bf076a, 0x00000000}},  //   _eman, _нала, drás_,
  { {0x6f1d15a6, 0x251a00b3, 0x6b9b1c46, 0x00000000}},  //   _besc, _הוצא, _olug,
  { {0x6f1d0107, 0x63ad1b61, 0xb2261281, 0x00000000}},  //   _cesc, _gman, _емил,
  { {0x59cb0201, 0x88d10044, 0x539b00a0, 0x00000000}},  // [3f60] िवार, াধিক, _ליקו,
  { {0x6b9b1c47, 0x7d1c0065, 0x6f040197, 0x00000000}},  //   _alug, _qers, scic,
  { {0x7d1c0125, 0x1b0d0055, 0x3ce1001c, 0x00000000}},  //   _vers, _হয়ে_, _करणे_,
  { {0x6f1d04e5, 0x7d1c0046, 0x8c490676, 0x00000000}},  //   _gesc, _wers, daşı,
  { {0x7d1c0149, 0x79880036, 0x298a0ae0, 0x00000000}},  //   _ters, _podw, йско_,
  { {0x6f1d0107, 0x44270190, 0x3e4e0089, 0x00000000}},  //   _zesc, _ovn_, rētā_,
  { {0x6b9b14b4, 0x672001f3, 0x7dd01469, 0x00000000}},  //   _flug, tamj, säss,
  { {0x3ce1062e, 0x6b9b009f, 0x9cbb0104, 0x00000000}},  //   _करते_, _glug, _הצלח,
  { {0xfaa30113, 0x98b1001e, 0x7bc000bb, 0x00000000}},  //   _зато, ībām_, _ijmu,
  { {0xf64f0647, 0x63ad0091, 0x2d8a0203, 0x00000000}},  //   ائي_, _sman, _jobe_,
  { {0xdcfc0036, 0x67200065, 0xbebb01d6, 0x00000000}},  //   _gorą, pamj, _teëg,
  { {0x69d80073, 0x291e0039, 0x57fb009b, 0x00000000}},  //   llve, _heta_, _הלאו,
  { {0x291e0f7c, 0x27070011, 0x44270082, 0x00000000}},  //   _keta_, _ống_, _evn_,
  { {0x291e0065, 0x7521001a, 0x6f1d1052, 0x00000000}},  //   _jeta_, calz, _sesc,
  { {0x291e01d5, 0x6f1d0207, 0xdfd50147, 0x00000000}},  //   _meta_, _pesc, довы,
  { {0x291e1c48, 0xf1bf0211, 0xbfd90088, 0x00000000}},  //   _leta_, trás_, ідає_,
  { {0x7d050186, 0x6f1d0207, 0xddd000b9, 0x00000000}},  // [3f70] tchs, _vesc, _řeši,
  { {0x291e0107, 0xf1bf0010, 0x7d05010f, 0x00000000}},  //   _neta_, rrás_, uchs,
  { {0x7d05010f, 0x6f1d1c49, 0xceeb00a6, 0x00000000}},  //   rchs, _tesc, _گردن_,
  { {0xfc30031d, 0x69d80270, 0x7d0501a2, 0x00000000}},  //   احل_, elve, schs,
  { {0x6b8900b5, 0x6b9b07a5, 0x957c0006, 0x00000000}},  //   _voeg, _vlug, rmąj,
  { {0x3f8b037e, 0xac191c4a, 0x64481c4b, 0x00000000}},  //   _hocu_, _могу_, ktdi,
  { {0x6b89049b, 0x291e01aa, 0x246c00b9, 0x00000000}},  //   _toeg, _deta_, _něm_,
  { {0xefc80011, 0xa3dd0061, 0x442701f3, 0x00000000}},  //   _địch_, _तील_, _rvn_,
  { {0x291e0129, 0x3f8b0079, 0xbbc90316, 0x00000000}},  //   _feta_, _mocu_, िकीक,
  { {0x291e009f, 0x44270089, 0xbebb07a5, 0x00000000}},  //   _geta_, _pvn_, _geëe,
  { {0xb80806f1, 0x64a516b6, 0x00000000, 0x00000000}},  //   _فيلم_, фана,   ,
  { {0x3f8b0107, 0xb605021c, 0x442517fe, 0x00000000}},  //   _nocu_, _pešč, rsl_,
  { {0x4393007e, 0x21e401a2, 0x442501a2, 0x00000000}},  //   таўс, höhe_, ssl_,
  { {0x44270cd4, 0x77690039, 0xb6050059, 0x00000000}},  //   _tvn_, ldex, _vešč,
  { {0x64480066, 0xdb0000b0, 0x3f8b016e, 0x00000000}},  //   ctdi, _ymmä, _bocu_,
  { {0x77690141, 0x2d8a016e, 0xafe3005e, 0x00000000}},  //   ndex, _sobe_, восл,
  { {0xa1c601f9, 0x76491b36, 0x200c00c8, 0x00000000}},  // [3f80] _обид, ntey, ūdi_,
  { {0xee370088, 0x7afb00f6, 0x22570014, 0x00000000}},  //   ьну_, _agut, _کلید_,
  { {0x291e185b, 0x0b46007e, 0x01350049, 0x00000000}},  //   _reta_, днен, _אָרט_,
  { {0x291e002b, 0x3ebf0243, 0x3f8b016c, 0x00000000}},  //   _seta_, _žute_, _gocu_,
  { {0x291e027e, 0x65680016, 0x2d8a1c4c, 0x00000000}},  //   _peta_, yddh, _tobe_,
  { {0x7afb002d, 0x67c10089, 0x13bb0316, 0x00000000}},  //   _egut, vēja, _उद्भ,
  { {0x291e1c4d, 0xf54e0011, 0xfc03025f, 0x00000000}},  //   _veta_, _bụng_, _апсо,
  { {0x6f160016, 0x33200129, 0x88bc00b9, 0x00000000}},  //   nbyc, _neix_, _oděv,
  { {0xf54e00ad, 0x291e0091, 0x00000000, 0x00000000}},  //   _dụng_, _teta_,   ,
  { {0xdcfc0521, 0x67c10089, 0x2b440082, 0x00000000}},  //   _dorć, rēja, _hcmc_,
  { {0xe94700a1, 0x67c101c5, 0x2b4400e7, 0x00000000}},  //   _ترقی, sēja, _kcmc_,
  { {0x64480089, 0x67c10089, 0x6e361c4e, 0x00000000}},  //   rtdi, pēja, kryb,
  { {0xe298008b, 0x64480089, 0x332000f6, 0x00000000}},  //   даў_, stdi, _deix_,
  { {0x246c00b9, 0x00000000, 0x00000000, 0x00000000}},  //   _těm_,   ,   ,
  { {0x8557019b, 0x1048007c, 0x21230066, 0x00000000}},  //   _חשוב_, мяти_, rajh_,
  { {0x27e6008e, 0x7e6d00f8, 0x00000000, 0x00000000}},  //   _jhon_, tvap,   ,
  { {0x7f4d008d, 0x27e60022, 0x603e0035, 0x00000000}},  // [3f90] rfaq, _mhon_, _pămî,
  { {0xdb0b00dc, 0x7e6d01b1, 0x00000000, 0x00000000}},  //   rigí, rvap,   ,
  { {0x6f160270, 0x7e6d1c4f, 0x00000000, 0x00000000}},  //   bbyc, svap,   ,
  { {0x27e60082, 0x332000f6, 0x26d8013f, 0x00000000}},  //   _nhon_, _xeix_, ərov_,
  { {0xf54e0011, 0xdfd101b2, 0x00000000, 0x00000000}},  //   _rụng_, _ليگ_,   ,
  { {0x200100ca, 0xda620077, 0xfd1001b2, 0x00000000}},  //   _kuhi_, увши, _نجف_,
  { {0x20011009, 0x27e60009, 0x00000000, 0x00000000}},  //   _juhi_, _bhon_,   ,
  { {0xd0f8019b, 0x27e60082, 0x16650931, 0x00000000}},  //   ומות_, _chon_, евим,
  { {0xb8d6024c, 0xea000011, 0x77690288, 0x00000000}},  //   _चे_, _đầm_, rdex,
  { {0x21210022, 0xdb0b00f6, 0x00000000, 0x00000000}},  //   _nehh_, ligà,   ,
  { {0x7649115d, 0x33200129, 0xf54e0011, 0x00000000}},  //   stey, _peix_, _tụng_,
  { {0x6e360006, 0x00000000, 0x00000000, 0x00000000}},  //   yryb,   ,   ,
  { {0x27ed0109, 0xbb3a071c, 0x6595007e, 0x00000000}},  //   mmen_, הערי, _паду,
  { {0x200100e0, 0x00000000, 0x00000000, 0x00000000}},  //   _buhi_,   ,   ,
  { {0xddc41279, 0x27ed0270, 0x21210022, 0x00000000}},  //   jviš, omen_, _dehh_,
  { {0x27ed0263, 0xa2e60783, 0xbebb0065, 0x00000000}},  //   nmen_, _пойд, _ndës,
  { {0xee3a0265, 0x27ed00b0, 0x00000000, 0x00000000}},  // [3fa0] яна_, imen_,   ,
  { {0x27ed001f, 0x6e360145, 0x5d670fd8, 0x00000000}},  //   hmen_, rryb, ниум_,
  { {0x27ed1c50, 0x273a0276, 0x00000000, 0x00000000}},  //   kmen_, nünü_,   ,
  { {0x67c10089, 0x61ee07cc, 0x27ed00bb, 0x00000000}},  //   dējo, lmbl, jmen_,
  { {0xfeba0318, 0x27ed01a2, 0xc333009b, 0x00000000}},  //   _راحت_, dmen_, רוד_,
  { {0x27ed00b5, 0x7db60025, 0x27e60048, 0x00000000}},  //   emen_, _أصحا, _shon_,
  { {0xfce30264, 0x27e60026, 0x395c00f8, 0x00000000}},  //   _боро, _phon_, revs_,
  { {0x2fc01c51, 0x6d5e0127, 0x27ed1c52, 0x00000000}},  //   nnig_, lepa, gmen_,
  { {0x7c3e0428, 0xe60f00a6, 0x2fc00016, 0x00000000}},  //   lupr, یشی_, inig_,
  { {0x6d5e0ed1, 0x2fc0079d, 0x9f4000b0, 0x00000000}},  //   nepa, hnig_, lmiä_,
  { {0xd6da04e1, 0x27e61c53, 0x7c3e0089, 0x00000000}},  //   _کوشش_, _thon_, nupr,
  { {0x6d5e010e, 0x21210066, 0x20011c54, 0x00000000}},  //   hepa, _sehh_, _ruhi_,
  { {0x6d5e0023, 0x00000000, 0x00000000, 0x00000000}},  //   kepa,   ,   ,
  { {0x7c3e002b, 0x6d5e0166, 0x1a9b0049, 0x00000000}},  //   kupr, jepa, ליכע,
  { {0xbebb008d, 0x6d5e061d, 0x273a019a, 0x00000000}},  //   _ndër, depa, cünü_,
  { {0x987b007b, 0x66021c55, 0xc27501fc, 0x00000000}},  //   האלט, _kuok, _алиј,
  { {0x443e021e, 0x66020ecb, 0x9df9026b, 0x00000000}},  // [3fb0] lut_, _juok, днат_,
  { {0x6d5e00b5, 0x6602021e, 0x443e0061, 0x00000000}},  //   gepa, _muok, out_,
  { {0x443e098a, 0x6602021e, 0x27ed0023, 0x00000000}},  //   nut_, _luok, ymen_,
  { {0xc4d30049, 0xdab90025, 0x67c10089, 0x00000000}},  //   אגע_, وهات_, vējo,
  { {0xa969003b, 0x443e0065, 0xd9450a27, 0x00000000}},  //   дила_, hut_, вели,
  { {0x443e020c, 0x6d5e1c56, 0xbd45006d, 0x00000000}},  //   kut_, cepa, _جنسي,
  { {0x27ed1c57, 0x1866005e, 0x443e01a3, 0x00000000}},  //   tmen_, ващи_, jut_,
  { {0x443e0085, 0x3f890169, 0x27ed00ea, 0x00000000}},  //   dut_, njau_, umen_,
  { {0x64580e3f, 0x3ea91c58, 0x67c10089, 0x00000000}},  //   _apvi, nzat_, sējo,
  { {0xa8a702a8, 0x27ed0056, 0xd5a301b2, 0x00000000}},  //   _прек, smen_, الدی,
  { {0x443e04bd, 0x03a6013b, 0x27ed0145, 0x00000000}},  //   gut_, вино, pmen_,
  { {0x6d5e0036, 0x888a0049, 0x273a019a, 0x00000000}},  //   zepa, _קרײַ, rünü_,
  { {0xa2d5007d, 0x3ea90065, 0x6d5e1b1c, 0x00000000}},  //   _युद्, jzat_, yepa,
  { {0x443e0149, 0x784a005f, 0x6d5e0032, 0x00000000}},  //   but_, _səvi, xepa,
  { {0x443e000d, 0x61ee0065, 0x6d5e010f, 0x00000000}},  //   cut_, rmbl, vepa,
  { {0xa06700ed, 0x752309d0, 0x3ebf0166, 0x00000000}},  //   њата_, _henz, _žuta_,
  { {0x6d5e0515, 0x2fc0009f, 0xa7fc0180, 0x00000000}},  // [3fc0] tepa, rnig_, _asıl,
  { {0xdb0b1c59, 0x2fcd0f3a, 0x6d470066, 0x00000000}},  //   vigá, čega_, _ccja,
  { {0x75230207, 0xdd100027, 0x013700a0, 0x00000000}},  //   _menz, _týžd, _ברית_,
  { {0xeb9714dd, 0x6d5e14f0, 0x75231944, 0x00000000}},  //   ких_, sepa, _lenz,
  { {0x7c3e0006, 0x443e000d, 0xbb4310d6, 0x00000000}},  //   supr, zut_, речк,
  { {0x7f4400f4, 0x6602021e, 0x443e1c5a, 0x00000000}},  //   lgiq, _ruok, yut_,
  { {0x1c39007c, 0xa3c40164, 0x76590016, 0x00000000}},  //   _пять_, ्वा_, _apwy,
  { {0x443e021e, 0xf093009b, 0xf76f0426, 0x00000000}},  //   vut_, שנה_, قاً_,
  { {0x7523011f, 0x443e0433, 0x9f59000a, 0x00000000}},  //   _benz, wut_, _disè_,
  { {0x75230089, 0x6602021e, 0x00000000, 0x00000000}},  //   _cenz, _vuok,   ,
  { {0x3ea914fe, 0x43950088, 0x75230253, 0x00000000}},  //   zzat_, ганс, _denz,
  { {0x443e020c, 0x040d001d, 0x7bc20052, 0x00000000}},  //   rut_, _hưởn, nnou,
  { {0xe5c6025f, 0x443e1c5b, 0x3f8f000c, 0x00000000}},  //   _иско, sut_, ögum_,
  { {0x443e05bd, 0x7bc200b9, 0x75230724, 0x00000000}},  //   put_, hnou, _genz,
  { {0x9f350451, 0x75280036, 0x7bc21c5c, 0x00000000}},  //   леві, madz, knou,
  { {0x3ea90411, 0x442e00ca, 0x752304c6, 0x00000000}},  //   tzat_, _ivf_, _zenz,
  { {0x5d5505f6, 0x7bc200b9, 0x7c2e01c9, 0x00000000}},  // [3fd0] лкат, dnou, _avbr,
  { {0x752801ee, 0x3ea91c5d, 0x00000000, 0x00000000}},  //   nadz, rzat_,   ,
  { {0x442c0dda, 0x442e068f, 0x3ea90010, 0x00000000}},  //   nsd_, _jvf_, szat_,
  { {0xed51026c, 0x2013002d, 0x76400009, 0x00000000}},  //   _گھر_, _itxi_, kumy,
  { {0x75280036, 0x00000000, 0x00000000, 0x00000000}},  //   kadz,   ,   ,
  { {0x7528001e, 0xf2d40049, 0xca7602fd, 0x00000000}},  //   jadz, סעס_, اموش_,
  { {0x75231c5e, 0x6d451c5f, 0x6e2d01c5, 0x00000000}},  //   _renz, mgha, lsab,
  { {0x75230198, 0x6d450066, 0x399901aa, 0x00000000}},  //   _senz, lgha, _mèsi_,
  { {0xaab70164, 0x7523061b, 0x2d910263, 0x00000000}},  //   _अधिक, _penz, _koze_,
  { {0x6d45020c, 0x4585019d, 0x6e2d010f, 0x00000000}},  //   ngha, угов, isab,
  { {0x481500d7, 0x2d911c60, 0xfbb7007d, 0x00000000}},  //   _смес, _moze_, _आगाम,
  { {0xe72e045e, 0xdce71c61, 0x7523000b, 0x00000000}},  //   _ће_, _najč, _wenz,
  { {0x69c3028c, 0x752300b5, 0x2d91098e, 0x00000000}},  //   onne, _tenz, _ooze_,
  { {0xa06a008b, 0x957c0046, 0x69c30a2e, 0x00000000}},  //   нага_, gląd, nnne,
  { {0x69c3002a, 0x65610181, 0x442c0dea, 0x00000000}},  //   inne, melh, csd_,
  { {0x6f0d001c, 0xc31e0044, 0x6d4500ea, 0x00000000}},  //   gcac, _থাকি_, egha,
  { {0x2d91037e, 0x6e2d1c62, 0x64411080, 0x00000000}},  // [3fe0] _boze_, gsab, luli,
  { {0x5166053f, 0x7bc20a71, 0x63a40161, 0x00000000}},  //   _своб, wnou, _hlin,
  { {0x6441020c, 0x6f0f0b69, 0x7bc2013e, 0x00000000}},  //   nuli, _ffcc, tnou,
  { {0x69c31c63, 0x201815e1, 0x6f0d0197, 0x00000000}},  //   enne, mpri_, ccac,
  { {0xd00f00d3, 0x644114f7, 0x63a41c64, 0x00000000}},  //   _ولی_, huli, _mlin,
  { {0x6441000b, 0xe8940057, 0x63a41c65, 0x00000000}},  //   kuli, иаль, _llin,
  { {0x64410020, 0x201801aa, 0x63a41983, 0x00000000}},  //   juli, npri_, _olin,
  { {0x963402a8, 0x75280046, 0x63a41c66, 0x00000000}},  //   аниц, wadz, _nlin,
  { {0x2bb10046, 0x040d001d, 0x75281c67, 0x00000000}},  //   jący_, _tưởn, tadz,
  { {0x63a41c68, 0x65610203, 0x545400d7, 0x00000000}},  //   _alin, gelh, авот,
  { {0x64410ffc, 0x69da1c69, 0x75280036, 0x00000000}},  //   guli, _ikte, radz,
  { {0x63a400ab, 0x75280871, 0xdc9b009b, 0x00000000}},  //   _clin, sadz, גיטל,
  { {0x61fe00f6, 0x877b0049, 0xdce70db9, 0x00000000}},  //   _bipl, _ראדי, _rajč,
  { {0x64410006, 0x63a41198, 0x9f49002a, 0x00000000}},  //   buli, _elin, rmaí_,
  { {0x6441028c, 0xb97b007b, 0x6f0d001c, 0x00000000}},  //   culi, ענלי, tcac,
  { {0xa3dd0061, 0x6e2d01a2, 0xd3270088, 0x00000000}},  //   _तीच_, tsab, _ськи,
  { {0x2d911c6a, 0xa3c4006e, 0x6f0d18d1, 0x00000000}},  // [3ff0] _poze_, ्वर_, rcac,
  { {0x6e2d01a3, 0x6f0d0eb3, 0x63a40667, 0x00000000}},  //   rsab, scac, _zlin,
  { {0x6e2d1c6b, 0x6d451c6c, 0x2dd80025, 0x00000000}},  //   ssab, rgha, ابقة_,
  { {0x16040309, 0x6d450051, 0x501a0097, 0x00000000}},  //   रदार_, sgha, _שורו,
  { {0x3ce1013d, 0x6441182b, 0x00000000, 0x00000000}},  //   _करके_, zuli,   ,
  { {0x64410022, 0x67c10089, 0x00000000, 0x00000000}},  //   yuli, mēji,   ,
  { {0x65611748, 0x67c10089, 0x18a5007e, 0x00000000}},  //   velh, lēji, райм,
  { {0x64410006, 0x69da0056, 0x00000000, 0x00000000}},  //   vuli, _ekte,   ,
  { {0x64410009, 0x65610d95, 0x2d9c0010, 0x00000000}},  //   wuli, telh, öveg_,
  { {0xbebb07a5, 0x7ae91c6d, 0xe57607d0, 0x00000000}},  //   _reël, _izet, азь_,
  { {0x63a41c6e, 0x656103f0, 0x397a01ce, 0x00000000}},  //   _plin, relh, _שטענ,
  { {0xe29a0265, 0x6441006c, 0x61fe01aa, 0x00000000}},  //   вам_, ruli, _sipl,
  { {0x63a41c6f, 0x61fe0173, 0x212a0e9e, 0x00000000}},  //   _vlin, _pipl, tabh_,
  { {0x6441010a, 0x1a9a007b, 0x463a007b, 0x00000000}},  //   puli, דישע, _יענע,
  { {0x5f06007c, 0x39470133, 0x00000000, 0x00000000}},  //   изва, igns_,   ,
  { {0x63a40020, 0x7ae901aa, 0x20181c70, 0x00000000}},  //   _ulin, _ozet, rpri_,

  { {0x20180263, 0x61fe0279, 0x8fa30242, 0x00000000}},  // [4000] spri_, _tipl, цате,
  { {0x637b021e, 0x67f50006, 0xb33b014a, 0x00000000}},  //   _tänä, _išju, rkçe,
  { {0x3157061e, 0x913b01f8, 0xf536007b, 0x00000000}},  //   _דיין_, _בעיק, שטער_,
  { {0xf4560049, 0x3ce60061, 0x54560049, 0x00000000}},  //   ייער_, _करीं_, יסען_,
  { {0x7ae90026, 0x67c10089, 0x00000000, 0x00000000}},  //   _czet, cēji,   ,
  { {0xb33b0065, 0xd8760025, 0x2d8c010e, 0x00000000}},  //   thçk, لاعب, _õde_,
  { {0x7c8501f9, 0x7ae9002d, 0x97a60140, 0x00000000}},  //   _луѓе, _ezet, ирил,
  { {0xc7c60098, 0x25a0009d, 0x9f4200b0, 0x00000000}},  //   јски, _œil_, _eikö_,
  { {0xfaa3003b, 0xd6d00025, 0x00000000, 0x00000000}},  //   _дато, ثقة_,   ,
  { {0xd90e0bb6, 0x00000000, 0x00000000, 0x00000000}},  //   _غیب_,   ,   ,
  { {0x6d790049, 0x67c10089, 0x48b6007c, 0x00000000}},  //   אָרװ, zēji, _тщат,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69d80428, 0x14b70167, 0xddc40089, 0x00000000}},  //   nove, ادیث_, ltiņ,
  { {0x351b01ce, 0x044300ed, 0x69d80035, 0x00000000}},  //   _יוגנ, _дејн, iove,
  { {0xdcfc005f, 0x69d81c71, 0x34fb009b, 0x00000000}},  //   _sorğ, hove, _בהוד,
  { {0x69d81962, 0x63bd06a0, 0x59d60061, 0x00000000}},  // [4010] kove, misn, धवार,
  { {0x67c1001e, 0x443e0250, 0x63bd0743, 0x00000000}},  //   rēji, ort_, lisn,
  { {0x69d81c72, 0x629d0052, 0x443e00f6, 0x00000000}},  //   dove, lyso, nrt_,
  { {0x443e0195, 0x63bd04be, 0x67c800b9, 0x00000000}},  //   irt_, nisn, dějo,
  { {0x443e001f, 0x7c3e1c73, 0x394c00f6, 0x00000000}},  //   hrt_, arpr, _bcds_,
  { {0x69d80059, 0x32090c70, 0xe9d8007e, 0x00000000}},  //   gove, _muay_, акі_,
  { {0x013800b6, 0x315801ce, 0x3a240022, 0x00000000}},  //   ברות_, ייגן_, _ewmp_,
  { {0x1bd40088, 0x443e0925, 0x7ae4002b, 0x00000000}},  //   _дося, drt_, żita,
  { {0x443e1626, 0x63bd037e, 0x69d80142, 0x00000000}},  //   ert_, disn, bove,
  { {0x69d800ab, 0x629d05f0, 0x55890437, 0x00000000}},  //   cove, dyso, убом_,
  { {0xa78700a1, 0x232a01c0, 0x81bd0044, 0x00000000}},  //   _پشاو, лони_, ইকা_,
  { {0x06b80014, 0x63bd1c74, 0xdb0000f6, 0x00000000}},  //   انیک_, gisn, _immò,
  { {0x443e021b, 0x68e10030, 0xcfcd0044, 0x00000000}},  //   art_, _hyld, লতান,
  { {0x661b01a3, 0x3d21013d, 0x00000000, 0x00000000}},  //   mpuk, यरों_,   ,
  { {0x3ce60754, 0x63bd023a, 0xa7fc014a, 0x00000000}},  //   _करें_, bisn, _arıy,
  { {0x69d8041a, 0xaf06007e, 0x2498059f, 0x00000000}},  //   zove, спал, ärme_,
  { {0x245101ca, 0x82360151, 0x3209008e, 0x00000000}},  // [4020] lám_, _اربا, _guay_,
  { {0x67c10089, 0x7c3e000a, 0x00000000, 0x00000000}},  //   mēju, trpr,   ,
  { {0x24510027, 0x01fb00a0, 0x7ae00039, 0x00000000}},  //   nám_, _תפיל, _symt,
  { {0x7f860025, 0x69d800d9, 0x661b00e0, 0x00000000}},  //   _الحن, wove, kpuk,
  { {0x69d80142, 0xca5600ed, 0x29050058, 0x00000000}},  //   tove, стењ, _bgla_,
  { {0x20020020, 0x443e0d3e, 0x24510d7a, 0x00000000}},  //   _hiki_, yrt_, kám_,
  { {0x247700ad, 0x8c4301c0, 0x2002033b, 0x00000000}},  //   _năm_, _нере, _kiki_,
  { {0x69d80c55, 0x24510161, 0xa6140242, 0x00000000}},  //   sove, dám_, омич,
  { {0x69d80cce, 0x20020107, 0x5ebb0049, 0x00000000}},  //   pove, _miki_, ָזיק,
  { {0x68e10737, 0x67c10089, 0x7afd0161, 0x00000000}},  //   _fyld, dēju, _ústa,
  { {0x63bd01d9, 0x443e05f2, 0x6d5c1c75, 0x00000000}},  //   tisn, urt_, _mbra,
  { {0x9f40028c, 0x20020695, 0x443e010f, 0x00000000}},  //   blié_, _niki_, rrt_,
  { {0x63bd01cd, 0x3209001d, 0x51871534, 0x00000000}},  //   risn, _quay_, бува,
  { {0x443e0059, 0x63bd12f7, 0x611401e1, 0x00000000}},  //   prt_, sisn, здру,
  { {0x6811001e, 0x20020066, 0xbebb01d6, 0x00000000}},  //   _kāda, _biki_, _teëk,
  { {0x6d5c02d5, 0x02a701fb, 0x68110089, 0x00000000}},  //   _abra, _гром, _jāda,
  { {0x20021c76, 0x67c10089, 0x6d5c0145, 0x00000000}},  // [4030] _diki_, cēju, _bbra,
  { {0x800900a1, 0xdcfc0089, 0x6d4e00f6, 0x00000000}},  //   _پردہ_, _norē, _ccba,
  { {0x30f700a1, 0x24770011, 0x7bd90036, 0x00000000}},  //   _دودھ_, _xăm_, towu,
  { {0x6d5c0a19, 0x8f47007c, 0x6d43000c, 0x00000000}},  //   _ebra, _уход, ónab,
  { {0x24510010, 0xc33400b3, 0x75380cd6, 0x00000000}},  //   zám_, פוס_, _odvz,
  { {0xe3cf0055, 0x9f42021e, 0x6d5c07b0, 0x00000000}},  //   রতিব, _ehkä_, _gbra,
  { {0x319c01ce, 0x91660082, 0xa3d9006e, 0x00000000}},  //   רבונ, _hộ_, ़का_,
  { {0x6d5c07e4, 0x2fc9018e, 0x24510802, 0x00000000}},  //   _zbra, nnag_, vám_,
  { {0xbebb0112, 0x05a90088, 0x24770082, 0x00000000}},  //   _beëi, ивий_, _săm_,
  { {0xdcf5001e, 0x7e7d0146, 0x24510161, 0x00000000}},  //   _nozī, _mrsp, tám_,
  { {0xd38a0604, 0xe36601ab, 0x00000000, 0x00000000}},  //   айне_, окни,   ,
  { {0xd8d600bd, 0xe8d6007b, 0x67c10089, 0x00000000}},  //   _וועט_, _ווער_, tēju,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd3780046, 0x64a5008b, 0xbebb040f, 0x00000000}},  //   ść_, _мала, _geëi,
  { {0xa06a137c, 0x67c10089, 0x910302dc, 0x00000000}},  //   шава_, sēju, дпре,
  { {0xa2d50316, 0x6d5c0197, 0x91660082, 0x00000000}},  //   _युक्, _sbra, _bộ_,
  { {0x672b1c77, 0x4427018e, 0x6603006c, 0x00000000}},  // [4040] _megj, _hwn_, _kink,
  { {0x20020dfc, 0x672b1c77, 0x660301d5, 0x00000000}},  //   _wiki_, _legj, _jink,
  { {0x660300b0, 0x2002023a, 0xc2c900a1, 0x00000000}},  //   _mink, _tiki_, _نبیل_,
  { {0x53370049, 0x64410051, 0x680a0036, 0x00000000}},  //   ַנצן_, irli, _wędk,
  { {0xadeb02d2, 0x6441010f, 0x298a00ed, 0x00000000}},  //   _जीवन_, hrli, иско_,
  { {0x44270038, 0x6d5c0036, 0x66030066, 0x00000000}},  //   _own_, _ubra, _nink,
  { {0x672b0093, 0x7afd0062, 0x9939078e, 0x00000000}},  //   _begj, _ústn, сячу_,
  { {0x24800340, 0x2d980027, 0x6b63004c, 0x00000000}},  //   _čim_, _hore_, _окса,
  { {0x2d9804cd, 0x672b0065, 0x3ea00010, 0x00000000}},  //   _kore_, _degj, nyit_,
  { {0xa2d5013d, 0x68ed00b9, 0x7e7b16d0, 0x00000000}},  //   _युग्, řada, _šupk,
  { {0x2d980a8a, 0x66030107, 0x68110089, 0x00000000}},  //   _more_, _dink, _tāda,
  { {0x660314b4, 0x2d980c35, 0x44271c78, 0x00000000}},  //   _eink, _lore_, _dwn_,
  { {0x6603002d, 0x644101bb, 0x69ca0026, 0x00000000}},  //   _fink, arli, onfe,
  { {0xbf9b02d5, 0xa1840147, 0x66030006, 0x00000000}},  //   _ciên, мысл, _gink,
  { {0x84380025, 0x69ca0bf5, 0x44271b21, 0x00000000}},  //   _اكبر_, infe, _gwn_,
  { {0x6448020c, 0x65680065, 0x66030471, 0x00000000}},  //   mudi, ledh, _zink,
  { {0xdce70036, 0x6448016e, 0x2fc90007, 0x00000000}},  // [4050] _mają, ludi, rnag_,
  { {0xd90400e9, 0x2d981b2a, 0xe1ff0036, 0x00000000}},  //   _لی_, _core_, zwój_,
  { {0x2d980065, 0x64480340, 0xdb0000f6, 0x00000000}},  //   _dore_, nudi, _almà,
  { {0x09c30061, 0x00000000, 0x00000000, 0x00000000}},  //   वच्य,   ,   ,
  { {0x7e7d127c, 0x672b0220, 0x2d9813f7, 0x00000000}},  //   _ursp, _regj, _fore_,
  { {0x6568008d, 0x672b009f, 0x4efa009b, 0x00000000}},  //   jedh, _segj, _להרו,
  { {0x6603010a, 0x6c540679, 0x3f990166, 0x00000000}},  //   _rink, _окру, _kosu_,
  { {0x66031c79, 0xfe6e026c, 0x3f99002d, 0x00000000}},  //   _sink, _جگہ_, _josu_,
  { {0x66030007, 0x672b0065, 0x65680020, 0x00000000}},  //   _pink, _vegj, fedh,
  { {0x64481c7a, 0x6441013f, 0x442700b4, 0x00000000}},  //   fudi, trli, _pwn_,
  { {0x66031c79, 0xbf9b001d, 0xb0db0061, 0x00000000}},  //   _vink, _riên, _मुलग,
  { {0x660317cc, 0x6441010f, 0x7bcb0082, 0x00000000}},  //   _wink, rrli, nngu,
  { {0x6603010a, 0x7bcb002d, 0x00000000, 0x00000000}},  //   _tink, ingu,   ,
  { {0x6448049c, 0x77690203, 0x67e5008e, 0x00000000}},  //   budi, leex, dóji,
  { {0x64480f03, 0x00000000, 0x00000000, 0x00000000}},  //   cudi,   ,   ,
  { {0xf43a009b, 0xc00300ec, 0x776901c3, 0x00000000}},  //   _התקש, епск, neex,
  { {0xa3d9013d, 0x7e6d0058, 0x69ca005b, 0x00000000}},  // [4060] ़कर_, gwap, ynfe,
  { {0xc27b0476, 0xf27b00a3, 0x3f8f000c, 0x00000000}},  //   _פריי, _פריש, ögur_,
  { {0x2d980292, 0x1d190088, 0x319b009b, 0x00000000}},  //   _vore_, юють_, _הבינ,
  { {0x2b5f00f6, 0x2d98066d, 0x9f40004a, 0x00000000}},  //   _cbuc_, _wore_, rmió_,
  { {0x2d98006c, 0x09e60098, 0x93bd0035, 0x00000000}},  //   _tore_, подн, spăg,
  { {0x7bcb0020, 0xceb30049, 0x2ac100ea, 0x00000000}},  //   angu, _טיר_, _sæbø_,
  { {0x6448027b, 0xb4ea013d, 0x68ed013e, 0x00000000}},  //   xudi, _मरे_, řadn,
  { {0x644805ad, 0x6f1600bb, 0xcc57009b, 0x00000000}},  //   vudi, ncyc, _מבלי_,
  { {0x2a7f01ed, 0x65680ede, 0x00000000, 0x00000000}},  //   _grub_, tedh,   ,
  { {0x6448095e, 0xb21b000c, 0x7bc20020, 0x00000000}},  //   tudi, lvæg, liou,
  { {0x92e90055, 0xaac0001c, 0x79880009, 0x00000000}},  //   _বলে_, _शेतक, _indw,
  { {0x6448000b, 0xb4cc013d, 0x7bc20133, 0x00000000}},  //   rudi, _रखी_, niou,
  { {0x51871c7b, 0x2cb30061, 0x98a5001e, 0x00000000}},  //   пува, zzxd_, _ielā_,
  { {0xddcd0036, 0x6448007f, 0xe3b9005d, 0x00000000}},  //   ztał, pudi, nsız_,
  { {0xddcd0036, 0x557700a3, 0x98a70035, 0x00000000}},  //   ytał, _מעגן_, mană_,
  { {0x5f940072, 0x94730054, 0x21310065, 0x00000000}},  //   нист, _أدوا, sazh_,
  { {0x63ad034f, 0x7bc20938, 0xe3b9014a, 0x00000000}},  // [4070] _ilan, diou, ksız_,
  { {0x63ad1c7c, 0x6aa2000a, 0x7e6d040f, 0x00000000}},  //   _hlan, dyof, rwap,
  { {0x63ad0397, 0xa3c40061, 0x200c013e, 0x00000000}},  //   _klan, ्वच_, ídit_,
  { {0xff25089d, 0xa14900a1, 0x7bc200ab, 0x00000000}},  //   _تبدی, _اسکے_, giou,
  { {0xf8ae025a, 0x63ad0020, 0x1ee70167, 0x00000000}},  //   یکم_, _mlan, _روسی_,
  { {0x63ad1c7d, 0xddcd0046, 0xdcfc010a, 0x00000000}},  //   _llan, stał, _norė,
  { {0x63ad049d, 0x224b1c7e, 0x92e90044, 0x00000000}},  //   _olan, huck_, _বলো_,
  { {0xe6190594, 0x7bc21c7f, 0x79881c80, 0x00000000}},  //   оди_, ciou, _endw,
  { {0x6b89014a, 0x6d4a004a, 0xbebb01c3, 0x00000000}},  //   _ineg, ófag, _geët,
  { {0x63ad011f, 0x6b9b0145, 0xa3e6006e, 0x00000000}},  //   _alan, _houg, _बीज_,
  { {0x63ad0239, 0x69c30e2d, 0x6b891c81, 0x00000000}},  //   _blan, mine, _kneg,
  { {0x69c3021e, 0x224b012d, 0x21e4010f, 0x00000000}},  //   line, fuck_, höht_,
  { {0x69c30051, 0x63ad0213, 0x6b9b009d, 0x00000000}},  //   oine, _dlan, _moug,
  { {0xdcee001e, 0x63ad1c82, 0x6b9b0056, 0x00000000}},  //   _labā, _elan, _loug,
  { {0x63ad0390, 0xc0e3007e, 0x00000000, 0x00000000}},  //   _flan, ворк,   ,
  { {0xa3e603d7, 0x69c3010f, 0x6b9b1c83, 0x00000000}},  //   _बीच_, hine, _noug,
  { {0x69c3014a, 0x7bc20038, 0x6e360006, 0x00000000}},  // [4080] kine, viou, usyb,
  { {0xfbd2026c, 0x6aa20020, 0xad660076, 0x00000000}},  //   ھتا_, vyof, باره,
  { {0xbc6a03ec, 0x6b9b0549, 0xdb0b1374, 0x00000000}},  //   تمان_, _boug, bigü,
  { {0x160d0061, 0x80bc0061, 0x6b9b0133, 0x00000000}},  //   सदार_, ोपीं, _coug,
  { {0x7bc20038, 0x69c306d7, 0x799a0036, 0x00000000}},  //   riou, fine, _potw,
  { {0x6b890059, 0x7bc20066, 0x6aa20085, 0x00000000}},  //   _eneg, siou, ryof,
  { {0xa96700ec, 0xec16007a, 0xe3b9005d, 0x00000000}},  //   фија_, _آورد, rsız_,
  { {0x6d5e01d6, 0x69c3003c, 0x17f70025, 0x00000000}},  //   lfpa, aine, ورية_,
  { {0x7bc000ab, 0x056a01fc, 0x06e10044, 0x00000000}},  //   _immu, ојни_, মেসি,
  { {0xc9860464, 0xe3b9013f, 0xad76007e, 0x00000000}},  //   _تشري, qsız_, звiц,
  { {0x69dd0051, 0x6b9b009d, 0x98a70035, 0x00000000}},  //   _ísea, _youg, rană_,
  { {0xe7170014, 0x18a31c84, 0x00000000, 0x00000000}},  //   _قيمت_, _шахм,   ,
  { {0xbebb01d6, 0x63ad0142, 0x00000000, 0x00000000}},  //   _leër, _vlan,   ,
  { {0xa4d401fb, 0x63ad0058, 0x224b03a1, 0x00000000}},  //   _полі, _wlan, ruck_,
  { {0xcf9b098c, 0x2eed0825, 0x7bc000e0, 0x00000000}},  //   оја_, _šef_, _ommu,
  { {0x63ad0169, 0x657a0240, 0x6d5e054e, 0x00000000}},  //   _ulan, ldth, efpa,
  { {0x24581c85, 0x6b9b032c, 0x645a1c86, 0x00000000}},  // [4090] lém_, _roug, ltti,
  { {0x7bc0003c, 0xdce70036, 0x6b89037a, 0x00000000}},  //   _ammu, _zaję, _sneg,
  { {0x645a021e, 0x24580224, 0x61e5003f, 0x00000000}},  //   ntti, ném_, _ikhl,
  { {0x645a00b0, 0xce95005e, 0x69c318f8, 0x00000000}},  //   itti, _замъ, wine,
  { {0x69c31c87, 0x24580884, 0x290c012d, 0x00000000}},  //   tine, hém_, _bgda_,
  { {0x68e8018e, 0x245800b9, 0x7bc01c88, 0x00000000}},  //   _bydd, kém_, _emmu,
  { {0x3d1a001c, 0x69c301cb, 0x6b9b00ab, 0x00000000}},  //   मुळे_, rine, _toug,
  { {0x69c30038, 0x68e8018e, 0xa69500ed, 0x00000000}},  //   sine, _dydd, ерој,
  { {0x69c3110a, 0x92ea0055, 0x645a1c89, 0x00000000}},  //   pine, _গল্প_, etti,
  { {0x68e8018e, 0xe895007e, 0x201c0010, 0x00000000}},  //   _fydd, _пазь, _évig_,
  { {0x69c11c8a, 0xf77300f3, 0x00000000, 0x00000000}},  //   _imle, _لاش_,   ,
  { {0xe3b203ec, 0x61e5003f, 0x853c0006, 0x00000000}},  //   ارد_, _akhl, nkėj,
  { {0x645a182c, 0x6d550036, 0x3ce60061, 0x00000000}},  //   atti, _ocza, _जुने_,
  { {0xdb0900f6, 0x6d430f18, 0x00000000, 0x00000000}},  //   _lleï, ónal,   ,
  { {0xe3b20054, 0x24580181, 0xceb4006b, 0x00000000}},  //   _مرة_, cém_, hbət_,
  { {0xafe3025f, 0x201e0089, 0xc178007f, 0x00000000}},  //   госл, īti_, žė_,
  { {0x201e0e3f, 0x69c10056, 0x7ae90020, 0x00000000}},  // [40a0] ūti_, _omle, _nyet,
  { {0xe1f201af, 0x62840032, 0x00000000, 0x00000000}},  //   _حسب_, _irio,   ,
  { {0x3157007b, 0x28df03d7, 0x0b460242, 0x00000000}},  //   _איין_, _पुलि, енен,
  { {0x7ae9001c, 0x6284007f, 0x68e81c8b, 0x00000000}},  //   _byet, _krio, _rydd,
  { {0x68e81c8c, 0x24581c8d, 0x5b130088, 0x00000000}},  //   _sydd, zém_, уміт,
  { {0x645a0836, 0x7ae900e0, 0x6e2408d3, 0x00000000}},  //   ytti, _dyet, mpib,
  { {0xab2a0918, 0xd90d0014, 0x7ae900f2, 0x00000000}},  //   _нова_, زین_, _eyet,
  { {0x62840ec8, 0x24580224, 0xceb4006b, 0x00000000}},  //   _orio, vém_, bbət_,
  { {0x68e80016, 0xe5c60140, 0x98a7007f, 0x00000000}},  //   _wydd, есно, vaną_,
  { {0x24581c85, 0x98a70036, 0xb8e800a1, 0x00000000}},  //   tém_, waną_, _قبضے_,
  { {0xa4d40245, 0x645a00b0, 0x77920bb6, 0x00000000}},  //   тоні, utti, _میثا,
  { {0x24581c85, 0x62840016, 0x645a00b0, 0x00000000}},  //   rém_, _brio, rtti,
  { {0x6284090b, 0x645a02e7, 0x27e601a3, 0x00000000}},  //   _crio, stti, _ikon_,
  { {0x04940025, 0x22440161, 0x65780056, 0x00000000}},  //   _للتح, ámka_, _uavh,
  { {0x62840016, 0x9f35007e, 0x2fc20022, 0x00000000}},  //   _erio, кеві, _bmkg_,
  { {0x62840051, 0x8d770014, 0xddc40276, 0x00000000}},  //   _frio, کارا, ttiş,
  { {0x6284007f, 0x8afd013e, 0xa3de0309, 0x00000000}},  // [40b0] _grio, _obřa, तकर_,
  { {0x5d5400e2, 0x442e00d9, 0x00000000, 0x00000000}},  //   лкут, _kwf_,   ,
  { {0x7c670025, 0xdb3500ed, 0x9f5a00f6, 0x00000000}},  //   عائل, веењ, _cupó_,
  { {0x7ae9008d, 0xa03a0049, 0x443c1c8e, 0x00000000}},  //   _pyet, _קערפ, _mvv_,
  { {0xbf3600b6, 0x853c0006, 0xdb0e000c, 0x00000000}},  //   _בארץ_, rkėj, þjál,
  { {0x89a80088, 0x7ae91c8f, 0x00000000, 0x00000000}},  //   нків_, _vyet,   ,
  { {0xceb4006b, 0xbddb000a, 0x68110089, 0x00000000}},  //   sbət_, _avèg, _kādi,
  { {0x7c250ca4, 0xceb4006b, 0x00000000, 0x00000000}},  //   mphr, mbər_,   ,
  { {0x200b001a, 0x443c0197, 0x6448002d, 0x00000000}},  //   _mici_, _avv_, erdi,
  { {0x200b0107, 0x27e61b2c, 0x765b1c90, 0x00000000}},  //   _lici_, _ekon_, rtuy,
  { {0x443c02d4, 0x7c250048, 0x6f1d00d9, 0x00000000}},  //   _cvv_, nphr, _ofsc,
  { {0x200b000d, 0xe72e003b, 0x442e1c91, 0x00000000}},  //   _nici_, _ње_, _dwf_,
  { {0x27ff19b1, 0x644800c7, 0xe29703c8, 0x00000000}},  //   mmun_, ardi, вая_,
  { {0x27ed15a6, 0x27e00bf8, 0x200b1c92, 0x00000000}},  //   llen_, čine_, _aici_,
  { {0x200b16a3, 0xcfaa0014, 0xddd60161, 0x00000000}},  //   _bici_, وارم_, jvyš,
  { {0x62840129, 0x4425005b, 0x9f4f000c, 0x00000000}},  //   _trio, mpl_, ögð_,
  { {0x27ed010f, 0x200b0207, 0x76490173, 0x00000000}},  // [40c0] ilen_, _dici_, nrey,
  { {0x27ed001f, 0xf4240044, 0x00000000, 0x00000000}},  //   hlen_, _ভিতর_,   ,
  { {0x27ed0030, 0x7649000c, 0x442507a3, 0x00000000}},  //   klen_, hrey, npl_,
  { {0x61ee0210, 0x8fa6003b, 0x27ed0b38, 0x00000000}},  //   llbl, _раме, jlen_,
  { {0x27ed0016, 0x00000000, 0x00000000, 0x00000000}},  //   dlen_,   ,   ,
  { {0x27ed1c93, 0xdb0b009f, 0x200b001a, 0x00000000}},  //   elen_, rigð, _zici_,
  { {0x660a0aa3, 0x27ed0016, 0x00000000, 0x00000000}},  //   _rifk, flen_,   ,
  { {0x27ed018e, 0x3860002b, 0x64480091, 0x00000000}},  //   glen_, ċir_, vrdi,
  { {0xb8e902fb, 0x442e0061, 0xda650380, 0x00000000}},  //   _ले_, _swf_, _مالي,
  { {0x21380107, 0x64480059, 0x27ed0032, 0x00000000}},  //   jarh_, trdi, alen_,
  { {0x27ed1c94, 0x291e0022, 0x3a26046a, 0x00000000}},  //   blen_, _ifta_, lpop_,
  { {0xd5b0007a, 0xa73a0879, 0x7649000c, 0x00000000}},  //   _گفت_, _آثار_, brey,
  { {0xdcf500ca, 0x660a0066, 0x00000000, 0x00000000}},  //   _razč, _tifk,   ,
  { {0x442e0016, 0x201300f6, 0x443c00d9, 0x00000000}},  //   _twf_, _puxi_, _tvv_,
  { {0x3a260146, 0x99990142, 0x200b0232, 0x00000000}},  //   hpop_, _ísť_, _pici_,
  { {0x02a70256, 0xa347008b, 0xc355025f, 0x00000000}},  //   _аром, _рэкл, _скиј,
  { {0x291e0073, 0xfe700025, 0x200b00ca, 0x00000000}},  // [40d0] _ofta_, يدك_, _vici_,
  { {0x68ed00b9, 0x672901ee, 0x00000000, 0x00000000}},  //   řadi, zbej,   ,
  { {0x27ed1c95, 0x68110089, 0x200b01c5, 0x00000000}},  //   ylen_, _tādi, _tici_,
  { {0x291e1c96, 0x6f1d00fa, 0x00000000, 0x00000000}},  //   _afta_, _ufsc,   ,
  { {0xd9450517, 0xeab00379, 0x27ed08c8, 0x00000000}},  //   гели, يعه_, vlen_,
  { {0x27ed1a98, 0x48790ae0, 0x7649014a, 0x00000000}},  //   wlen_, есия_, vrey,
  { {0x27ed1c97, 0x3ea90173, 0x2d180014, 0x00000000}},  //   tlen_, lyat_, _شکلک_,
  { {0x869901f9, 0x27ed046a, 0x291e030e, 0x00000000}},  //   етот_, ulen_, _efta_,
  { {0x67290018, 0x27ed0016, 0x3ea91c98, 0x00000000}},  //   rbej, rlen_, nyat_,
  { {0x27ed0016, 0x59b7007d, 0x98c700ec, 0x00000000}},  //   slen_, _अतिर, _исел,
  { {0x27ed0052, 0x58d4073b, 0xf7551289, 0x00000000}},  //   plen_, _кофт, _مناج,
  { {0xc20900b6, 0x3ea9020c, 0xddcd0091, 0x00000000}},  //   _זה_, kyat_, jvaž,
  { {0xdcf401ee, 0x2fc90146, 0x4425013e, 0x00000000}},  //   _čača, diag_, spl_,
  { {0x06e50055, 0x3ea91c99, 0x44250133, 0x00000000}},  //   _পৃথি, dyat_, ppl_,
  { {0xa06700c0, 0x75d213d9, 0x200000e5, 0x00000000}},  //   лара_, _ديوا, tmii_,
  { {0x645c0129, 0x3a2602c2, 0x00000000, 0x00000000}},  //   àrie, ypop_,   ,
  { {0x4d6609e6, 0x3ea90b57, 0x20001507, 0x00000000}},  // [40e0] лкав, gyat_, rmii_,
  { {0xa0c60014, 0x00000000, 0x00000000, 0x00000000}},  //   _ميخو,   ,   ,
  { {0xacf602a8, 0xa0a6005e, 0xf5360049, 0x00000000}},  //   учај, _санд, רטער_,
  { {0x65ad0027, 0x7c650025, 0x00000000, 0x00000000}},  //   _súhl, شامل,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfce6012b, 0x82770049, 0x00000000, 0x00000000}},  //   _бого, טענע_,   ,
  { {0x3a261c9a, 0xdca30900, 0x00000000, 0x00000000}},  //   spop_, _лари,   ,
  { {0x7c3e0039, 0x3f800035, 0x3a2601d6, 0x00000000}},  //   mspr, ndiu_, ppop_,
  { {0x36d4007c, 0x35b41c9b, 0x00000000, 0x00000000}},  //   ропр, ибир,   ,
  { {0xd90e00a6, 0x2db70049, 0x00000000, 0x00000000}},  //   _عیب_, ָלטן_,   ,
  { {0x7c3e0292, 0x69ca133d, 0x81da0044, 0x00000000}},  //   nspr, mife, ়তা_,
  { {0x3ea9005f, 0x3f800065, 0x7c3e01a2, 0x00000000}},  //   yyat_, jdiu_, ispr,
  { {0xdcf5001e, 0x659400d7, 0x95ca0f93, 0x00000000}},  //   _mazā, _валу, _пука_,
  { {0x7c3e04d3, 0x33200375, 0x00000000, 0x00000000}},  //   kspr, _efix_,   ,
  { {0x753a002d, 0x351b00a3, 0x3ea91904, 0x00000000}},  //   matz, _אוונ, wyat_,
  { {0x443e1c9c, 0x753a022b, 0x7c3e00eb, 0x00000000}},  //   mst_, latz, dspr,
  { {0x7c3e0168, 0x00000000, 0x00000000, 0x00000000}},  // [40f0] espr,   ,   ,
  { {0x753a022b, 0x443e1c9d, 0x7c3e124c, 0x00000000}},  //   natz, ost_, fspr,
  { {0x69ca001a, 0x7c3e0af1, 0x9f490051, 0x00000000}},  //   dife, gspr, llaí_,
  { {0x443e0a48, 0xdb0001aa, 0x753a09ce, 0x00000000}},  //   ist_, _komè, hatz,
  { {0x753a022b, 0x443e010f, 0x2d851c9e, 0x00000000}},  //   katz, hst_, _óleo_,
  { {0x61e70107, 0x7c3e1c9f, 0xd8250a85, 0x00000000}},  //   nojl, bspr, адки,
  { {0x443e02ae, 0x753a022b, 0xa7b50098, 0x00000000}},  //   jst_, datz, исиј,
  { {0x07a50057, 0xc1d2013d, 0x443e0905, 0x00000000}},  //   раин, _सद्ग, dst_,
  { {0x443e01cb, 0x6a2300a1, 0x69ca00d9, 0x00000000}},  //   est_, _اہتم, bife,
  { {0x27e001d9, 0x446501fb, 0x7bcb04d4, 0x00000000}},  //   čina_, авов, ligu,
  { {0x232a0517, 0xa7751663, 0x2d810051, 0x00000000}},  //   кони_, _влеч, idhe_,
  { {0x888a007b, 0x7bcb125e, 0xbef500e8, 0x00000000}},  //   _שרײַ, nigu, _आरंभ_,
  { {0x2d9102ae, 0x753a002d, 0xdb001ca0, 0x00000000}},  //   _onze_, batz, _comè,
  { {0xdb0010cf, 0x7c3e04fd, 0x443e010f, 0x00000000}},  //   _domè, yspr, bst_,
  { {0x7bcb002d, 0x9f490051, 0x98a700b9, 0x00000000}},  //   kigu, alaí_, vaně_,
  { {0x673b010a, 0x788000b9, 0x3f800035, 0x00000000}},  //   nauj, lává, udiu_,
  { {0xef170888, 0xd007005e, 0x7bcb084b, 0x00000000}},  // [4100] рму_, рете_, digu,
  { {0x9d4601e0, 0x7c3e001f, 0x63a40035, 0x00000000}},  //   режд, tspr, _hoin,
  { {0x63a4002b, 0x7bcb0056, 0x98a700b9, 0x00000000}},  //   _koin, figu, raně_,
  { {0x63a40038, 0x7c3e1440, 0x753a022b, 0x00000000}},  //   _join, rspr, zatz,
  { {0x63a4028c, 0x63b61ca1, 0x7c3e0da6, 0x00000000}},  //   _moin, _mlyn, sspr,
  { {0x443e000c, 0x63a41ca2, 0x7c3e00f8, 0x00000000}},  //   yst_, _loin, pspr,
  { {0x7bcb03d2, 0xb9c30054, 0x7b9601fb, 0x00000000}},  //   bigu, تقوي, _краї,
  { {0x963401fb, 0x63a41c79, 0x2ca71ca3, 0x00000000}},  //   бниц, _noin, ände_,
  { {0x753a022b, 0x443e0016, 0x3b0700ed, 0x00000000}},  //   tatz, wst_, _вето_,
  { {0xdb0004bd, 0x443e00b5, 0x550605a7, 0x00000000}},  //   _nomé, tst_, ична,
  { {0x753a022b, 0x443e000c, 0x63b61b6c, 0x00000000}},  //   ratz, ust_, _blyn,
  { {0x63a4002a, 0x753a08a0, 0x6b820197, 0x00000000}},  //   _coin, satz, ndog,
  { {0x443e001f, 0x753a022b, 0x63a41ca4, 0x00000000}},  //   sst_, patz, _doin,
  { {0x463b007b, 0xdb001ca5, 0x7bcb0032, 0x00000000}},  //   _יעדע, _comé, zigu,
  { {0xdb000161, 0x63b60016, 0xa184008b, 0x00000000}},  //   _domé, _flyn, цыял,
  { {0x63a40038, 0x6d5c1ca6, 0x63b60016, 0x00000000}},  //   _goin, _acra, _glyn,
  { {0x7bcb009d, 0x6b821263, 0x764018f7, 0x00000000}},  // [4110] vigu, ddog, nsmy,
  { {0x71750076, 0x00000000, 0x00000000, 0x00000000}},  //   _اهدا,   ,   ,
  { {0x2ca7001a, 0x7bcb03c1, 0x2d810065, 0x00000000}},  //   ând_, tigu, rdhe_,
  { {0x6d5c10ff, 0x6f950025, 0x6b800016, 0x00000000}},  //   _ecra, _الحض, _camg,
  { {0x7bcb04f3, 0xb21b000c, 0x673b0006, 0x00000000}},  //   rigu, kvæm, vauj,
  { {0x7bcb08f0, 0x6d5c0051, 0x7af7006b, 0x00000000}},  //   sigu, _gcra, əxtl,
  { {0x6b82027b, 0x673b0e3f, 0x7bcb00d4, 0x00000000}},  //   bdog, tauj, pigu,
  { {0xb21b000c, 0x6b80005b, 0xba770014, 0x00000000}},  //   tvæl, _gamg, _پارت,
  { {0x63a4002a, 0x673b0dec, 0x7bdb016c, 0x00000000}},  //   _roin, rauj, _ijuu,
  { {0x63a41ca7, 0x67da002b, 0x63b60030, 0x00000000}},  //   _soin, rċja, _slyn,
  { {0x63a4030a, 0x63b60161, 0xd90f00a1, 0x00000000}},  //   _poin, _plyn, _کیں_,
  { {0xe29a0c4e, 0x79811ca8, 0x645c0129, 0x00000000}},  //   гам_, _halw, ària,
  { {0x6d470059, 0x1b7a0049, 0x63a416c7, 0x00000000}},  //   _odja, נטשע, _voin,
  { {0xc692009b, 0x00000000, 0x00000000, 0x00000000}},  //   _מאד_,   ,   ,
  { {0x63a4021e, 0x6b821ca9, 0x7e7d06ed, 0x00000000}},  //   _toin, ydog, _assp,
  { {0x79810263, 0x644100f8, 0x442700ca, 0x00000000}},  //   _lalw, msli, _itn_,
  { {0x8fa3047d, 0x24430676, 0x7e7d00e5, 0x00000000}},  // [4120] чате, lım_, _cssp,
  { {0x6b80000c, 0x7bc90e4b, 0x44271caa, 0x00000000}},  //   _samg, _ameu, _ktn_,
  { {0x64410af1, 0x2443047f, 0x6b820313, 0x00000000}},  //   nsli, nım_, tdog,
  { {0x80c10044, 0x4427006b, 0x644101a2, 0x00000000}},  //   _শুক্, _mtn_, isli,
  { {0x6b82108b, 0x7981005b, 0xab650089, 0x00000000}},  //   rdog, _balw, daļā,
  { {0x09e30200, 0x64410995, 0x3f821cab, 0x00000000}},  //   почн, ksli, _haku_,
  { {0xc17300a0, 0x78b5005f, 0x58860147, 0x00000000}},  //   פחה_, _üzvl, сыла,
  { {0x2443047f, 0xf09300b6, 0x644105b7, 0x00000000}},  //   dım_, לנו_, dsli,
  { {0xdcfc00d0, 0x64410007, 0x3f820052, 0x00000000}},  //   _marč, esli, _maku_,
  { {0x44271cac, 0x79811014, 0x3f8204cb, 0x00000000}},  //   _btn_, _galw, _laku_,
  { {0x644100eb, 0x539901fb, 0x442700fa, 0x00000000}},  //   gsli, авня_, _ctn_,
  { {0x3f82011c, 0x7e64059f, 0x61e1007d, 0x00000000}},  //   _naku_, ktip, पक्ष,
  { {0x64410007, 0x69d81cad, 0x798100bb, 0x00000000}},  //   asli, onve, _yalw,
  { {0x4427012d, 0x69d801e5, 0xbddb009d, 0x00000000}},  //   _ftn_, nnve, _avèn,
  { {0x3f820f9a, 0x44260380, 0x201a1cae, 0x00000000}},  //   _baku_, _ارتف, _cupi_,
  { {0x442c0022, 0x23bb0023, 0x69d801a2, 0x00000000}},  //   mpd_, _bëje_, hnve,
  { {0x680a0046, 0x6e94189f, 0x7e640058, 0x00000000}},  // [4130] _będz, питу, gtip,
  { {0xbddb03eb, 0x201a0020, 0x628d0032, 0x00000000}},  //   _evèn, _fupi_, _irao,
  { {0x6ad101f5, 0xccfb003b, 0x9f4000d4, 0x00000000}},  //   तप्र, ућа_, boià_,
  { {0x79810016, 0x2d9c0039, 0x395e00ab, 0x00000000}},  //   _salw, över_, _acts_,
  { {0x69d8009f, 0x2443005d, 0x201a012d, 0x00000000}},  //   fnve, zım_, _zupi_,
  { {0x2443005a, 0x6e2d0207, 0x201a1caf, 0x00000000}},  //   yım_, mpab, _yupi_,
  { {0x6e2d0919, 0x442c0022, 0x387e00d2, 0x00000000}},  //   lpab, jpd_, _cstr_,
  { {0x79811b43, 0x4427055e, 0x395e0ed6, 0x00000000}},  //   _walw, _rtn_, _ects_,
  { {0xe61604af, 0x64410035, 0xfbd20097, 0x00000000}},  //   оды_, wsli, _חתן_,
  { {0x644101bf, 0x2443047f, 0x44270093, 0x00000000}},  //   tsli, tım_, _ptn_,
  { {0x87e707ca, 0x628d1cb0, 0x2d830d61, 0x00000000}},  //   _люде, _arao, _maje_,
  { {0x2443047f, 0x64410006, 0xe6951095, 0x00000000}},  //   rım_, rsli, _ولاد,
  { {0x2443014a, 0x6441010f, 0x628d0051, 0x00000000}},  //   sım_, ssli, _crao,
  { {0x2d8301aa, 0xe69202fd, 0x3f821be3, 0x00000000}},  //   _naje_, _آلود, _saku_,
  { {0x03a601fb, 0xdcfc1cb1, 0x3f821a03, 0x00000000}},  //   _мико, _parč, _paku_,
  { {0x7e6400b0, 0x680a0036, 0x628d0bfb, 0x00000000}},  //   ttip, _sędz, _frao,
  { {0x2d831cb2, 0xf77200a3, 0xdb060279, 0x00000000}},  // [4140] _baje_, וקן_, ümün,
  { {0xdd9204e8, 0x3f820022, 0x201a1c30, 0x00000000}},  //   بوط_, _waku_, _tupi_,
  { {0x7e64001e, 0x2d830213, 0x3f6a10a9, 0x00000000}},  //   stip, _daje_, _кино_,
  { {0xcb6a003b, 0x6d43000c, 0x2ca70039, 0x00000000}},  //   раде_, ónar, ända_,
  { {0x395e0009, 0x387e0087, 0x00000000, 0x00000000}},  //   _pcts_, _sstr_,   ,
  { {0x2d830107, 0x387e0009, 0x8d760014, 0x00000000}},  //   _gaje_, _pstr_, _باحا,
  { {0x69d804f2, 0x00000000, 0x00000000, 0x00000000}},  //   rnve,   ,   ,
  { {0xca7603c8, 0xdd9000a1, 0x963401c0, 0x00000000}},  //   _музы, _توڑ_, пниц,
  { {0x2d830117, 0xdb0001ca, 0x317806ed, 0x00000000}},  //   _yaje_, _komí, kerz_,
  { {0x2896003b, 0x00000000, 0x00000000, 0x00000000}},  //   _мјес,   ,   ,
  { {0x3178031c, 0xd5b701ff, 0x00000000, 0x00000000}},  //   derz_, ісь_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f4904bd, 0xc6d600f3, 0x6e220048, 0x00000000}},  //   llaç_, _بتات, íobl,
  { {0x27e902aa, 0x675600a6, 0xd83801aa, 0x00000000}},  //   čane_, _ایکس_, _kwč_,
  { {0x2d830059, 0x8557009b, 0x00000000, 0x00000000}},  //   _raje_, _ושוב_,   ,
  { {0xcf98012b, 0x5f94017a, 0x09b70309, 0x00000000}},  //   оју_, мист, _अत्य,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [4150]   ,   ,   ,
  { {0xdc8b00ed, 0xdb001cb3, 0xc05b0c18, 0x00000000}},  //   исел_, _comí, _кім_,
  { {0xdb0000f7, 0x417a009b, 0x2d830059, 0x00000000}},  //   _domí, _הנתב, _vaje_,
  { {0x207a007b, 0x307a0049, 0x6e2d19a1, 0x00000000}},  //   _פארא, _פארנ, ppab,
  { {0xbf9a00b3, 0x720a00a1, 0x20091cb4, 0x00000000}},  //   _הירש, _خفیہ_, mmai_,
  { {0x20091cb5, 0xd8380173, 0x00000000, 0x00000000}},  //   lmai_, _bwč_,   ,
  { {0x0138009b, 0xcb35005e, 0xd6d90036, 0x00000000}},  //   חרות_, _невъ, dała_,
  { {0x200902d4, 0x60dc00a0, 0x00000000, 0x00000000}},  //   nmai_, יקונ,   ,
  { {0xe81b02d2, 0x2a7f010e, 0x00000000, 0x00000000}},  //   _पूरा_, _usub_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x20090010, 0x8458004d, 0xb9c4006d, 0x00000000}},  //   kmai_, орят_, _تقلي,
  { {0x78fa009b, 0x00000000, 0x00000000, 0x00000000}},  //   _הפעו,   ,   ,
  { {0x38670009, 0x6595005e, 0x27ed15cd, 0x00000000}},  //   ltnr_, _наду, moen_,
  { {0x7c290224, 0x27ed0032, 0x00000000, 0x00000000}},  //   _čern, loen_,   ,
  { {0xf9920049, 0x9103003b, 0x20020022, 0x00000000}},  //   ערל_, епре, _phki_,
  { {0xef1a1123, 0x27ed1cb6, 0xe3b9006b, 0x00000000}},  //   сма_, noen_, lqın_,
  { {0x7a19000a, 0xd12f009e, 0x00000000, 0x00000000}},  // [4160] _lňtb, ئمہ_,   ,
  { {0x27ed1cb7, 0x386700f8, 0x00000000, 0x00000000}},  //   hoen_, ktnr_,   ,
  { {0x61ee049a, 0x27ed1cb8, 0x711b0049, 0x00000000}},  //   mobl, koen_, _לויפ,
  { {0xdb00000d, 0x20091cb9, 0xe1ff008e, 0x00000000}},  //   _româ, cmai_, ntón_,
  { {0x27ed0343, 0xf38d0049, 0x7bc30065, 0x00000000}},  //   doen_, יראָ, ënua,
  { {0x61ee00f4, 0x00000000, 0x00000000, 0x00000000}},  //   nobl,   ,   ,
  { {0x2d980039, 0x38c80014, 0xfce302e9, 0x00000000}},  //   _inre_, غاتی_, _зоро,
  { {0x27ed1cba, 0xd6d90036, 0x6d5e006c, 0x00000000}},  //   goen_, wała_, lgpa,
  { {0x61ee0056, 0x9f400010, 0xd6d90036, 0x00000000}},  //   kobl, llió_, tała_,
  { {0x61ee00b9, 0x273a0082, 0x2009007f, 0x00000000}},  //   jobl, ẫn_, zmai_,
  { {0x20090006, 0x3dbe0044, 0x61ee0059, 0x00000000}},  //   ymai_, _আদাল, dobl,
  { {0x394c01f3, 0x23bb0023, 0xd6d90036, 0x00000000}},  //   _hdds_, _bëja_, sała_,
  { {0xa3be001c, 0x61ee03c9, 0x394c004a, 0x00000000}},  //   _इतर_, fobl, _kdds_,
  { {0xbf9b1cbb, 0xd49a0088, 0x00000000, 0x00000000}},  //   _chên, _гри_,   ,
  { {0x657a0038, 0x2009007f, 0x00000000, 0x00000000}},  //   meth, tmai_,   ,
  { {0x645a011c, 0x657a1cbc, 0x2d980035, 0x00000000}},  //   muti, leth, _anre_,
  { {0x61ee0190, 0x394c1cbd, 0xdb1b00fa, 0x00000000}},  // [4170] bobl, _odds_, _fluê,
  { {0xd9040a90, 0x27ed111a, 0xbbb50309, 0x00000000}},  //   _می_, zoen_, ंस्क,
  { {0x645a0027, 0xdcfc001e, 0xd2f900a1, 0x00000000}},  //   nuti, _parā, _دکھا_,
  { {0x394c0133, 0x22490087, 0x8af900ed, 0x00000000}},  //   _adds_, _kvak_, онес_,
  { {0xc5f80089, 0x657a0203, 0x645a010e, 0x00000000}},  //   klē_, keth, huti,
  { {0x3f891cbe, 0x386700ea, 0x00000000, 0x00000000}},  //   ldau_, ttnr_,   ,
  { {0xe7390057, 0x27ed0056, 0xb7b50082, 0x00000000}},  //   оей_, toen_, _dụn,
  { {0x645a1325, 0x3f890171, 0x2249016e, 0x00000000}},  //   duti, ndau_, _ovak_,
  { {0x27ed1cbf, 0x2b4d06c0, 0x38670634, 0x00000000}},  //   roen_, _idec_, stnr_,
  { {0x657a00ab, 0x27ed1cc0, 0x645a0020, 0x00000000}},  //   geth, soen_, futi,
  { {0x645a011c, 0x9f4b00b9, 0xdb000048, 0x00000000}},  //   guti, _akcí_, _iomá,
  { {0xd6ce00e9, 0x657a0016, 0xe3b9013f, 0x00000000}},  //   اقی_, aeth, sqın_,
  { {0x3f89018e, 0x657a005b, 0xe1ff15e3, 0x00000000}},  //   ddau_, beth, rtón_,
  { {0x645a0837, 0xe1ff008e, 0x213e0051, 0x00000000}},  //   buti, stón_, úth_,
  { {0xc7b80011, 0x2fc0005b, 0x7afd06ec, 0x00000000}},  //   _ttđt_, thig_, _østf,
  { {0xee3a0822, 0x3e6600f4, 0x3a2d0058, 0x00000000}},  //   жна_, tôt_, _otep_,
  { {0x7dc003a2, 0x61ee0b32, 0x66e80023, 0x00000000}},  // [4180] _löse, pobl, mëkë,
  { {0x3f89018e, 0x27e01034, 0xfd1203ec, 0x00000000}},  //   adau_, čini_, نجا_,
  { {0xdb1901aa, 0x93bd001a, 0x6d5e0168, 0x00000000}},  //   viwò, mpăr, rgpa,
  { {0x3e6600f4, 0x2b4d00f6, 0x657a0010, 0x00000000}},  //   pôt_, _cdec_, zeth,
  { {0x657a0061, 0xe1ff0010, 0x6d5e00e0, 0x00000000}},  //   yeth, któl_, pgpa,
  { {0x082a009a, 0x7dc001a2, 0x9f40004a, 0x00000000}},  //   оции_, _böse, plió_,
  { {0xdb00004f, 0xab2a0822, 0x701c0044, 0x00000000}},  //   _domá, _мова_, _তবুও_,
  { {0x645a1cc1, 0xf76f0d3a, 0x657a018e, 0x00000000}},  //   vuti, لاً_, weth,
  { {0x6e22002a, 0x896601e0, 0x7bc20222, 0x00000000}},  //   íobh, _окаж, mhou,
  { {0xb8b6012b, 0x27e91cc2, 0xfe9b009b, 0x00000000}},  //   _осећ, čana_, קיימ,
  { {0x657a0030, 0x799a0869, 0x628400b0, 0x00000000}},  //   reth, _intw, _asio,
  { {0x645a1cc3, 0x7bc201b5, 0xb21b000c, 0x00000000}},  //   ruti, nhou, kvæt,
  { {0x645a1cc4, 0x6d4e0091, 0x7c2918a2, 0x00000000}},  //   suti, _odba, _čerm,
  { {0x79881cc5, 0xa56800a1, 0x3f890016, 0x00000000}},  //   _jadw, _رشتے_, wdau_,
  { {0x798801d5, 0x7bc200bb, 0x69c60006, 0x00000000}},  //   _madw, khou, _įkel,
  { {0x98a70107, 0x64480c7a, 0x79880173, 0x00000000}},  //   žiću_, msdi, _ladw,
  { {0x799a049b, 0x63ad001a, 0x7c2e0089, 0x00000000}},  // [4190] _ontw, _ioan, _atbr,
  { {0x63ad0011, 0x8d7701f7, 0x6d4e04b7, 0x00000000}},  //   _hoan, بارا, _cdba,
  { {0xdb0013ae, 0x3a2d00ab, 0x798a0016, 0x00000000}},  //   _romá, _step_, ddfw,
  { {0x799a1cc6, 0x2d870027, 0x63ad1cc7, 0x00000000}},  //   _antw, žne_, _joan,
  { {0xdb0001ca, 0x79881cc8, 0x201900e0, 0x00000000}},  //   _pomá, _badw, _iisi_,
  { {0x9f40000c, 0xd6d90036, 0x79880016, 0x00000000}},  //   llið_, wało_, _cadw,
  { {0x6d450fe7, 0x20190e51, 0xfd4600a1, 0x00000000}},  //   maha, _kisi_, _سینٹ_,
  { {0x799a1cc9, 0x7bc203eb, 0x6d450475, 0x00000000}},  //   _entw, chou, laha,
  { {0xdb0001ca, 0x201904cb, 0x442e14ea, 0x00000000}},  //   _tomá, _misi_, _atf_,
  { {0x6d45006a, 0x77b51cca, 0x77bc049a, 0x00000000}},  //   naha, _máxi, _véxa,
  { {0x69c30051, 0x63ad00e5, 0x661801c5, 0x00000000}},  //   mhne, _boan, _divk,
  { {0x6d45006a, 0xceb4005f, 0x20191ccb, 0x00000000}},  //   haha, yyə_, _nisi_,
  { {0x63ad001d, 0x6d451ccc, 0x442e0197, 0x00000000}},  //   _doan, kaha, _etf_,
  { {0x1aec0044, 0x6d4504cb, 0x442e1ccd, 0x00000000}},  //   জেকে_, jaha, _ftf_,
  { {0x6d450475, 0x7dc0010f, 0xafe60545, 0x00000000}},  //   daha, _lösc, еовл,
  { {0x6729008e, 0x63ad0035, 0x93bd001a, 0x00000000}},  //   ncej, _goan, spăr,
  { {0x6d451cce, 0x764904cd, 0x62840020, 0x00000000}},  // [41a0] faha, nsey, _usio,
  { {0x6d451ccf, 0x7bc2103f, 0x6b9b1444, 0x00000000}},  //   gaha, whou, _anug,
  { {0x7bc21cd0, 0x20190e06, 0x63ad1cd1, 0x00000000}},  //   thou, _fisi_, _yoan,
  { {0xbea60888, 0x79880016, 0x63ad0082, 0x00000000}},  //   _замк, _sadw, _xoan,
  { {0x7bc2049b, 0x6d450475, 0xb21b0737, 0x00000000}},  //   rhou, baha, lvær,
  { {0x7bc201b5, 0x69c31cd2, 0x6d4504be, 0x00000000}},  //   shou, ghne, caha,
  { {0x7bc21cd3, 0x7c2e01c9, 0x307a0049, 0x00000000}},  //   phou, _utbr, לאַנ,
  { {0x2d8a1cd4, 0x6b89000a, 0x00000000, 0x00000000}},  //   _habe_, _gaeg,   ,
  { {0x7bc01cd5, 0x442e1cd6, 0x69c30051, 0x00000000}},  //   _ilmu, _stf_, bhne,
  { {0x69c3001f, 0x2d8a002d, 0xac9700a1, 0x00000000}},  //   chne, _jabe_, _تنہا_,
  { {0x81d60055, 0x6448010a, 0xd5b80089, 0x00000000}},  //   িকা_, usdi, rkā_,
  { {0xd5b8001e, 0x644813ea, 0x6d450032, 0x00000000}},  //   skā_, rsdi, zaha,
  { {0x6d451cd7, 0x63ad12f0, 0x201900af, 0x00000000}},  //   yaha, _voan, _risi_,
  { {0x20190a9a, 0x27e00209, 0x7afd0637, 0x00000000}},  //   _sisi_, činu_, _øste,
  { {0x7bc0038c, 0x442e08cb, 0x6d451cd8, 0x00000000}},  //   _olmu, _utf_, vaha,
  { {0x77b5081d, 0x00000000, 0x00000000, 0x00000000}},  //   _páxi,   ,   ,
  { {0x2d8a001c, 0x20190a5c, 0x2b46012d, 0x00000000}},  // [41b0] _babe_, _visi_, daoc_,
  { {0x2d8a1cd9, 0x7bc00dfb, 0x9ce701fc, 0x00000000}},  //   _cabe_, _almu, нцел,
  { {0x2d8a002d, 0x20191a7c, 0xf99f0011, 0x00000000}},  //   _dabe_, _tisi_, _đè_,
  { {0x6d450390, 0x77b500c4, 0x6d4a01e5, 0x00000000}},  //   saha, _táxi, ófar,
  { {0x6d450b9a, 0x69c30048, 0x00000000, 0x00000000}},  //   paha, thne,   ,
  { {0x2d8a022b, 0x7bc01ae2, 0x7e6d1cda, 0x00000000}},  //   _gabe_, _elmu, mtap,
  { {0x7e6d0052, 0x00000000, 0x00000000, 0x00000000}},  //   ltap,   ,   ,
  { {0x27e90f3a, 0x00000000, 0x00000000, 0x00000000}},  //   čano_,   ,   ,
  { {0x7e6d1cdb, 0x69c31cdc, 0xba74023c, 0x00000000}},  //   ntap, phne, _مالت,
  { {0x76491205, 0xdb0004ce, 0x6827007e, 0x00000000}},  //   rsey, _domä, _зьдз,
  { {0x69c10047, 0xf502005e, 0xef1f00f6, 0x00000000}},  //   _ille, изьо, _paül_,
  { {0x394704bd, 0x7e6d0199, 0x7d1a000c, 0x00000000}},  //   lans_, ktap, _útse,
  { {0x9585007c, 0xd2990088, 0x00000000, 0x00000000}},  //   _алле, нтрі_,   ,
  { {0x69c100f6, 0xdb1b00d4, 0x00000000, 0x00000000}},  //   _jlle, _lluï,   ,
  { {0xb21b0030, 0x2d8a00d0, 0x394700f6, 0x00000000}},  //   tvær, _rabe_, ians_,
  { {0x2d8a029d, 0x61fc001c, 0x394704d1, 0x00000000}},  //   _sabe_, slrl, hans_,
  { {0x394701aa, 0x69c1021e, 0xb21b0698, 0x00000000}},  // [41c0] kans_, _olle, rvær,
  { {0x39471cdd, 0xb21b0637, 0x00000000, 0x00000000}},  //   jans_, svær,   ,
  { {0x39471cde, 0xc1bb00b3, 0x0b460088, 0x00000000}},  //   dans_, _חמיש, внен,
  { {0x69c115a6, 0x224000bb, 0x24870919, 0x00000000}},  //   _alle, _kwik_, _msnm_,
  { {0x39471cdf, 0x2d8a1ce0, 0x7e6d0068, 0x00000000}},  //   fans_, _tabe_, ctap,
  { {0x3f8b1ce1, 0x394701cb, 0x00000000, 0x00000000}},  //   _zacu_, gans_,   ,
  { {0x8c4304b6, 0xdca300aa, 0x25ae071b, 0x00000000}},  //   _весе, _кари, _rofl_,
  { {0x69c10239, 0xd90d00a6, 0xe7b20061, 0x00000000}},  //   _elle, سین_, _जवळप,
  { {0x39470129, 0x83fd0091, 0x25ae0087, 0x00000000}},  //   bans_, nuđe, _pofl_,
  { {0x39471ce2, 0x00000000, 0x00000000, 0x00000000}},  //   cans_,   ,   ,
  { {0x62960022, 0x7e6d002d, 0xd76400a1, 0x00000000}},  //   _aryo, ztap, _منای,
  { {0x69d800ab, 0xccf3009b, 0xe73702dc, 0x00000000}},  //   live, יכת_, _аец_,
  { {0xe298008b, 0x3a2415a2, 0x645d0006, 0x00000000}},  //   ваў_, _jump_, ąsia,
  { {0x72050025, 0x69d8032c, 0x3f8b012d, 0x00000000}},  //   اوسم, nive, _sacu_,
  { {0x3a240784, 0x3f8b0093, 0x2fc20281, 0x00000000}},  //   _lump_, _pacu_, _blkg_,
  { {0x394718ae, 0x69d80035, 0x7e6d044e, 0x00000000}},  //   zans_, hive, ttap,
  { {0x39470263, 0x69d80292, 0xdf44007e, 0x00000000}},  // [41d0] yans_, kive, рэсп,
  { {0x7e6d0145, 0x3f8b0009, 0x69d80059, 0x00000000}},  //   rtap, _wacu_, jive,
  { {0x69d8027b, 0x7afb0093, 0x63bd0006, 0x00000000}},  //   dive, _syut, oksn,
  { {0x3a240ca4, 0x59c50061, 0xbddb01aa, 0x00000000}},  //   _bump_, वसभर, _avèt,
  { {0x39471ce3, 0xb5fd0161, 0x69d807f9, 0x00000000}},  //   tans_, luše, five,
  { {0x69d80378, 0xe81b02d2, 0x1a68025a, 0x00000000}},  //   give, _पूजा_, ئیلی_,
  { {0x39470263, 0x2d8106ad, 0xddc4001a, 0x00000000}},  //   rans_, mehe_, stiţ,
  { {0x39470d5b, 0x2d81006c, 0x17850679, 0x00000000}},  //   sans_, lehe_, угим,
  { {0x394701aa, 0x645a0141, 0x99670069, 0x00000000}},  //   pans_, erti, _ател,
  { {0xb5fd0059, 0x7dc00039, 0xceb20049, 0x00000000}},  //   kuše, _lösn, ציי_,
  { {0xddc40b4b, 0xd877023c, 0x224001c3, 0x00000000}},  //   ntiš, _جاذب, _swik_,
  { {0x2d8117ca, 0x62961ce4, 0xdb1b0129, 0x00000000}},  //   hehe_, _pryo, _lluí,
  { {0xe1ff0046, 0x645a01a2, 0x673b0023, 0x00000000}},  //   ntów_, arti, mbuj,
  { {0x27ff01d5, 0xa594005e, 0xddc40006, 0x00000000}},  //   llun_, _връщ, ktiš,
  { {0x057404e1, 0xaf9a085f, 0x957c0036, 0x00000000}},  //   _خاند, нтах_, snąc,
  { {0xe1ff0046, 0x69d8003b, 0x200b00b9, 0x00000000}},  //   któw_, zive, _chci_,
  { {0xd24f0076, 0xe81b013d, 0x27ff00b0, 0x00000000}},  // [41e0] _فني_, _पूछा_, ilun_,
  { {0xdca6012b, 0x3a240ace, 0x69d8033f, 0x00000000}},  //   лази, _rump_, xive,
  { {0x69d81ce5, 0x27e90209, 0x3a240145, 0x00000000}},  //   vive, čanj_, _sump_,
  { {0x4fa60c65, 0xab2a007c, 0x6e3600d9, 0x00000000}},  //   _симв, хода_, ppyb,
  { {0x69d80322, 0x693400a1, 0x673b0059, 0x00000000}},  //   tive, لکار, dbuj,
  { {0x7c29004f, 0x7d03010f, 0x645a000c, 0x00000000}},  //   _červ, ünsc, yrti,
  { {0x3945120d, 0xa2db006e, 0xdce70036, 0x00000000}},  //   _dels_, _पेन्, _obję,
  { {0x69d80006, 0x76aa007c, 0x645a0b4a, 0x00000000}},  //   sive, етов_, vrti,
  { {0x386e1ce6, 0xdcee007f, 0x6e2600d9, 0x00000000}},  //   stfr_, _pabė, _jukb,
  { {0x80ba0044, 0x6b820051, 0x645a00ca, 0x00000000}},  //   _উইন্, leog, trti,
  { {0x8d5b0049, 0x35f3007e, 0xcdf70049, 0x00000000}},  //   עכטי, спэр, רמיי_,
  { {0x1bf4013d, 0x6b820048, 0x00000000, 0x00000000}},  //   इकिल_, neog,   ,
  { {0x63bd08ad, 0xdb1901a2, 0x00000000, 0x00000000}},  //   rksn, chwä,   ,
  { {0x645a0059, 0x80d30044, 0x00000000, 0x00000000}},  //   prti, _দুষ্,   ,
  { {0x8607004b, 0xdb000211, 0xc9b7009b, 0x00000000}},  //   _حقوق_, _comú, נהלת_,
  { {0xb5fd01ca, 0x20000667, 0x00000000, 0x00000000}},  //   ruše, glii_,   ,
  { {0x6b820207, 0xa3ea001c, 0x141c00b6, 0x00000000}},  // [41f0] deog, _मदत_, _אוהב,
  { {0x21670b11, 0xbddb009d, 0x76420009, 0x00000000}},  //   _стиг, _avèr, _mwoy,
  { {0x2d81000b, 0x80d30055, 0xcd0700e3, 0x00000000}},  //   rehe_, _দুর্, учаи,
  { {0xa134025a, 0x672200e7, 0x3945009d, 0x00000000}},  //   _پریش, _ngoj, _sels_,
  { {0xa969003b, 0x394504bd, 0xddc409f4, 0x00000000}},  //   вила_, _pels_, stiš,
  { {0xa85500e1, 0x9f5200f4, 0xe1ff0036, 0x00000000}},  //   атиј, voyé_, rtów_,
  { {0xe1ff0046, 0x5b3701f7, 0x27ff000c, 0x00000000}},  //   stów_, _معذر, tlun_,
  { {0x9b89026c, 0x5a3500ed, 0x765b0211, 0x00000000}},  //   _جنرل_, _внат, truy,
  { {0x6d47020c, 0x394500f4, 0xdb09000c, 0x00000000}},  //   _keja, _tels_, _gleð,
  { {0x6d4704cb, 0x3ea900f6, 0x00000000, 0x00000000}},  //   _jeja, ixat_,   ,
  { {0xa3ea03d7, 0x79831ce7, 0x6d470145, 0x00000000}},  //   _मदद_, menw, _meja,
  { {0x6d4701aa, 0x7e7d1ce8, 0x79830016, 0x00000000}},  //   _leja, _opsp, lenw,
  { {0x75d504e1, 0x9814035b, 0xe5a500ed, 0x00000000}},  //   _پيغا, _ابلا, _вили,
  { {0x6d470027, 0x79831ce9, 0x865a009b, 0x00000000}},  //   _neja, nenw, _ידני,
  { {0x7e7d0089, 0x00000000, 0x00000000, 0x00000000}},  //   _apsp,   ,   ,
  { {0xa06701f9, 0x4427001a, 0x7e7d0022, 0x00000000}},  //   јата_, _iun_, _bpsp,
  { {0x44271cea, 0x6d470007, 0x798300bb, 0x00000000}},  // [4200] _hun_, _beja, kenw,
  { {0x44200be3, 0x44271ceb, 0x6d47008e, 0x00000000}},  //   _hii_, _kun_, _ceja,
  { {0x4427012b, 0x6d471cec, 0x7983146c, 0x00000000}},  //   _jun_, _deja, denw,
  { {0x44271ced, 0xfc03025f, 0x3e6f194f, 0x00000000}},  //   _mun_, опхо, büt_,
  { {0x4420001a, 0x0a94007e, 0x79831cee, 0x00000000}},  //   _mii_, салю, fenw,
  { {0xe85406ea, 0x798307eb, 0xe9f7008b, 0x00000000}},  //   منتد, genw, аніі_,
  { {0xfce307ca, 0x442703a1, 0x80b60044, 0x00000000}},  //   _доро, _nun_, ৃপক্,
  { {0x44200004, 0x2fc01cef, 0x99dd0173, 0x00000000}},  //   _nii_, nkig_, _pwňc,
  { {0x44270211, 0x64430784, 0x7983010f, 0x00000000}},  //   _aun_, _awni, benw,
  { {0x77bc1cf0, 0x44271cf1, 0x44200f2c, 0x00000000}},  //   _méxi, _bun_, _aii_,
  { {0x4427049a, 0x2fc006b2, 0x77860174, 0x00000000}},  //   _cun_, kkig_, _влез,
  { {0xe73a0517, 0x44271cf2, 0x67220107, 0x00000000}},  //   _ред_, _dun_, _ugoj,
  { {0x659401fb, 0x44270082, 0x2c510036, 0x00000000}},  //   _галу, _eun_, ząd_,
  { {0x442700ab, 0x44200145, 0x7c201cf3, 0x00000000}},  //   _fun_, _eii_, _limr,
  { {0x4420001a, 0x6d4701a3, 0x0ce10044, 0x00000000}},  //   _fii_, _reja, _ভর্ত,
  { {0x6d470149, 0x7c201431, 0xee1f007d, 0x00000000}},  //   _seja, _nimr, बद्ध_,
  { {0xd2510054, 0x6d47027e, 0x5d551cf4, 0x00000000}},  // [4210] _عند_, _peja, йкат,
  { {0x27e902aa, 0x4427006a, 0x44200035, 0x00000000}},  //   čani_, _yun_, _zii_,
  { {0x40950054, 0x79830112, 0x6d471049, 0x00000000}},  //   _الجر, venw, _veja,
  { {0x4420027b, 0xd7e60025, 0xfbd0023c, 0x00000000}},  //   _xii_, _رك_, وتن_,
  { {0x6d47008e, 0x2d87009d, 0x7c201cf5, 0x00000000}},  //   _teja, ônes_, _dimr,
  { {0xb5fd0119, 0x38950089, 0x69ca0048, 0x00000000}},  //   kuša, _pār_, ghfe,
  { {0xb5fd0089, 0x7983059b, 0xed0500a1, 0x00000000}},  //   juša, renw, _طورپ,
  { {0x2d911cf6, 0x442700ab, 0xb5fd0bf1, 0x00000000}},  //   _haze_, _run_, duša,
  { {0x2d91037e, 0x442700ab, 0x44200632, 0x00000000}},  //   _kaze_, _sun_, _rii_,
  { {0x442704be, 0x7c200173, 0x69ca01a2, 0x00000000}},  //   _pun_, _zimr, chfe,
  { {0x2d910541, 0x44201cf7, 0x69fa0049, 0x00000000}},  //   _maze_, _pii_, _עלעק,
  { {0x2d910107, 0x48151cf8, 0x44270082, 0x00000000}},  //   _laze_, _умес, _vun_,
  { {0x4420027b, 0x1af70044, 0x00000000, 0x00000000}},  //   _vii_, েশকে_,   ,
  { {0xa06a1cf9, 0x4427127d, 0x77bc027b, 0x00000000}},  //   лага_, _tun_, _réxi,
  { {0xd4350318, 0x8fa60265, 0x442011eb, 0x00000000}},  //   _اعتب, баве, _tii_,
  { {0x44200093, 0x98b0012d, 0x29c201e5, 0x00000000}},  //   _uii_, žaću_, _aðal_,
  { {0x2d911cfa, 0x63a40058, 0xd007003b, 0x00000000}},  // [4220] _baze_, _inin, сете_,
  { {0x7c2002e7, 0xef17003b, 0x00000000, 0x00000000}},  //   _simr, сму_,   ,
  { {0x63a40247, 0xd8381cfb, 0x00000000, 0x00000000}},  //   _knin, _krče_,   ,
  { {0xdee6003b, 0xf4560049, 0xe1ff00f6, 0x00000000}},  //   _гоми, מיער_, btós_,
  { {0x7e6404bd, 0x2d911140, 0xaad2013d, 0x00000000}},  //   quip, _faze_, _देखक,
  { {0xcaa50054, 0x9f49000c, 0x22440161, 0x00000000}},  //   تصمي, llað_, ámky_,
  { {0xc0f20011, 0x2a7f06fa, 0x63a41cbf, 0x00000000}},  //   _rượu_, _epub_, _onin,
  { {0x63b617e5, 0xb5fd1cfc, 0x9634003b, 0x00000000}},  //   _noyn, vuša, ониц,
  { {0xa37b0181, 0xcf93009b, 0x00000000, 0x00000000}},  //   niõe, לטה_,   ,
  { {0x63a402c6, 0x5454005e, 0x7bc200e0, 0x00000000}},  //   _anin, овот, lkou,
  { {0x2937007b, 0x69c80190, 0xc7af007c, 0x00000000}},  //   _האבן_, _ilde, _её_,
  { {0x7bc2078b, 0x290c1cfd, 0xb5fd04eb, 0x00000000}},  //   nkou, _izda_, ruša,
  { {0xadfa013d, 0xb5fd1cfe, 0x69c80087, 0x00000000}},  //   ्तान_, suša, _klde,
  { {0x236d0046, 0xb5fd0161, 0x63a400b0, 0x00000000}},  //   żej_, lušn, _enin,
  { {0x2fd90022, 0x2d911cff, 0x7bc200b0, 0x00000000}},  //   _pmsg_, _raze_, kkou,
  { {0x543b007b, 0x628d0051, 0x61fe0739, 0x00000000}},  //   _געהא, _tsao, _ekpl,
  { {0xa37b0181, 0x69c800ab, 0x98bc0006, 0x00000000}},  // [4230] giõe, _olde, ravę_,
  { {0xd8380173, 0x00000000, 0x00000000, 0x00000000}},  //   _otč_,   ,   ,
  { {0x2d910107, 0xb5fd0059, 0x9f49000c, 0x00000000}},  //   _vaze_, kušn, blað_,
  { {0x69c815cd, 0x69da1d00, 0xfd100025, 0x00000000}},  //   _alde, _amte, رجل_,
  { {0x957c0036, 0xd8380173, 0x2d91014a, 0x00000000}},  //   ciąg, _atč_, _taze_,
  { {0x7bc200b0, 0x957c0036, 0xdb1b0129, 0x00000000}},  //   akou, niąd, _lluç,
  { {0xd90e026c, 0xe1ff000c, 0x69c80009, 0x00000000}},  //   ہیے_, próf_, _dlde,
  { {0x7bc20ff3, 0x6fc90164, 0x00000000, 0x00000000}},  //   ckou, रसिं,   ,
  { {0x7bc904d2, 0x7bdb0168, 0x00000000, 0x00000000}},  //   _ileu, _imuu,   ,
  { {0xb5fd0e0d, 0xd838016c, 0x00000000, 0x00000000}},  //   krše, _srče_,   ,
  { {0x7bc9049b, 0xa5090072, 0x6386017f, 0x00000000}},  //   _kleu, рена_, огна,
  { {0x645c1d01, 0xf1a900b3, 0xe29a0fd8, 0x00000000}},  //   ária, _בס_, аам_,
  { {0xbddb000a, 0x00000000, 0x00000000, 0x00000000}},  //   _pwèl,   ,   ,
  { {0x38a0000d, 0x7bc90221, 0x69c3138a, 0x00000000}},  //   _fără_, _lleu, nkne,
  { {0x7bc9005b, 0x9f49000c, 0x7bc20068, 0x00000000}},  //   _oleu, tlað_, ykou,
  { {0x6fda00b9, 0x7c290161, 0x63a400ab, 0x00000000}},  //   můck, _čerp, _unin,
  { {0x82360188, 0x69c30eb6, 0xee37019d, 0x00000000}},  // [4240] _بربا, kkne, жну_,
  { {0x7bc900ea, 0xad6603ec, 0x7bdb1d02, 0x00000000}},  //   _aleu, تاره, _amuu,
  { {0x7bc900f4, 0xc2e900a1, 0x7afd0030, 0x00000000}},  //   _bleu, _نعیم_, _østj,
  { {0x61fc001a, 0xcb67007e, 0x2d0a0061, 0x00000000}},  //   lorl, жаце_, _वरील_,
  { {0xf38d0049, 0x00000000, 0x00000000, 0x00000000}},  //   טראָ,   ,   ,
  { {0x7e761d03, 0x61fc1d04, 0x7bc216e5, 0x00000000}},  //   mtyp, norl, skou,
  { {0xa96700e1, 0x7bc900f4, 0x7e760056, 0x00000000}},  //   ција_, _fleu, ltyp,
  { {0x7bc90168, 0x7c3e0190, 0x17f70025, 0x00000000}},  //   _gleu, mppr, يرية_,
  { {0x61fc0010, 0x7e760016, 0xa96a17a4, 0x00000000}},  //   korl, ntyp, _виза_,
  { {0xd5ba0265, 0x69c31153, 0x7c3e1d05, 0x00000000}},  //   рси_, ckne, oppr,
  { {0x7e761d06, 0x4438040f, 0xddcd0035, 0x00000000}},  //   htyp, ër_, ltaţ,
  { {0xb5fd0119, 0x47c30ae0, 0x3e741d07, 0x00000000}},  //   vrše, _обхв, kät_,
  { {0x61fc05b7, 0x3e7400b0, 0xddcd001a, 0x00000000}},  //   forl, jät_, ntaţ,
  { {0x35f70558, 0x7e7600ea, 0xdb0000dc, 0x00000000}},  //   _ورود_, dtyp, _homó,
  { {0xdb000036, 0xc1050025, 0x394c0133, 0x00000000}},  //   _komó, سوري, _meds_,
  { {0xd9c20044, 0x443e00ab, 0x1e35007e, 0x00000000}},  //   ্চিম, mpt_, знаў,
  { {0x443e00b5, 0x7e760190, 0x80dc0044, 0x00000000}},  // [4250] lpt_, gtyp, _মুদ্,
  { {0x7bc900c7, 0x443e00b5, 0xdd910025, 0x00000000}},  //   _sleu, opt_, عوا_,
  { {0xc172009b, 0x7bc900f4, 0x98bc00b9, 0x00000000}},  //   _אחי_, _pleu, ravě_,
  { {0x70fa00b6, 0x60fa009b, 0x22491d08, 0x00000000}},  //   _להתח, _להתק, _kwak_,
  { {0x7e760061, 0xbf3600a3, 0x3f891d09, 0x00000000}},  //   ctyp, _מארץ_, meau_,
  { {0x22490020, 0x443e0022, 0x3f89009d, 0x00000000}},  //   _mwak_, kpt_, leau_,
  { {0x69c300b5, 0x443e00b5, 0x6fbf0316, 0x00000000}},  //   rkne, jpt_, _एकां,
  { {0x3f8910ff, 0xdb000051, 0x7bdb011c, 0x00000000}},  //   neau_, _comó, _umuu,
  { {0x61fc0676, 0xab66006c, 0xddcd001a, 0x00000000}},  //   yorl, stüü, ctaţ,
  { {0x49b803ab, 0xdcfc012d, 0x6e3b01df, 0x00000000}},  //   _والد_, _zarđ, _çubu,
  { {0x61fc05b7, 0x64a5007e, 0x22490127, 0x00000000}},  //   vorl, чана, _awak_,
  { {0x7e761d0a, 0x2b4d00f6, 0x22490145, 0x00000000}},  //   ytyp, _jeec_, _bwak_,
  { {0x3f891d0b, 0x61fc014a, 0x443e00bb, 0x00000000}},  //   deau_, torl, apt_,
  { {0x3e74021e, 0x29051d0c, 0x443e00fa, 0x00000000}},  //   vät_, _kyla_, bpt_,
  { {0x8fa6008b, 0x5502013d, 0x61fc1d0d, 0x00000000}},  //   паве, _रुपए_, rorl,
  { {0x3e741d0e, 0x29050058, 0x61fc0146, 0x00000000}},  //   tät_, _myla_, sorl,
  { {0x61fc014a, 0x00000000, 0x00000000, 0x00000000}},  // [4260] porl,   ,   ,
  { {0x3e740444, 0x7d1a000c, 0x00000000, 0x00000000}},  //   rät_, _útsk,   ,
  { {0x7e760056, 0x91bb009b, 0x3b8600ed, 0x00000000}},  //   styp, _המיי, злег,
  { {0x3f891b0a, 0x7e761d0f, 0xcb6a0e82, 0x00000000}},  //   ceau_, ptyp, саде_,
  { {0x7f4400c4, 0x200200bb, 0xc33300b3, 0x00000000}},  //   mbiq, _ikki_, גוד_,
  { {0x443e1d10, 0x29050224, 0x2c750190, 0x00000000}},  //   ypt_, _byla_, båd_,
  { {0xdb000036, 0x7dcb0036, 0x6d5c153a, 0x00000000}},  //   _pomó, yższ, _idra,
  { {0xf0930104, 0x6d4e0127, 0x62840403, 0x00000000}},  //   תנה_, _heba, _opio,
  { {0x6d4e020c, 0x7c2e01a2, 0x6d5c02d4, 0x00000000}},  //   _keba, _hubr, _kdra,
  { {0x645c02d5, 0xddd60036, 0x7c2e0032, 0x00000000}},  //   ário, jwyż, _kubr,
  { {0x443e010f, 0x22490007, 0x493b009b, 0x00000000}},  //   upt_, _swak_, _הגבו,
  { {0x6d4e04cb, 0x00000000, 0x00000000, 0x00000000}},  //   _leba,   ,   ,
  { {0x3f89028c, 0x6d5c0340, 0xd7a90061, 0x00000000}},  //   veau_, _odra, कारच,
  { {0x171b00b6, 0x443e1d11, 0x7e641802, 0x00000000}},  //   _הודע, ppt_, drip,
  { {0x3cdc001c, 0x3f8900f4, 0x7e6408a6, 0x00000000}},  //   _गेले_, teau_, erip,
  { {0x443c1085, 0x6d5c018e, 0x224901d6, 0x00000000}},  //   _itv_, _adra, _twak_,
  { {0x3f8905f2, 0x6d4e04cb, 0x7dc0010f, 0x00000000}},  // [4270] reau_, _beba, _lösu,
  { {0x20020359, 0x3f89028c, 0x6d4e1d12, 0x00000000}},  //   _ekki_, seau_, _ceba,
  { {0x6d4e0018, 0x7c2e0211, 0x6d5c0016, 0x00000000}},  //   _deba, _cubr, _ddra,
  { {0x7c2e016e, 0x2c75080a, 0x442e1d13, 0x00000000}},  //   _dubr, råd_, _muf_,
  { {0x7e641d14, 0x6d4e0009, 0x443c08ad, 0x00000000}},  //   crip, _feba, _ltv_,
  { {0x6d4e046a, 0x2009018e, 0x64580207, 0x00000000}},  //   _geba, llai_, _ovvi,
  { {0x6d450066, 0x443c1102, 0xfc64005e, 0x00000000}},  //   mbha, _ntv_, _пътн,
  { {0x6d5c1d15, 0x6d451270, 0x6d4e10d2, 0x00000000}},  //   _zdra, lbha, _zeba,
  { {0x442e08ba, 0x6458054f, 0x6d450051, 0x00000000}},  //   _auf_, _avvi, obha,
  { {0x6b8b0292, 0x442e00f6, 0x443c1d16, 0x00000000}},  //   legg, _buf_, _btv_,
  { {0x442e0020, 0x62840051, 0xb5fd09fc, 0x00000000}},  //   _cuf_, _spio, lušk,
  { {0xe72e1d17, 0xf770007a, 0x6b8b0207, 0x00000000}},  //   _је_, _ماه_, negg,
  { {0xe56e102a, 0x27ff0263, 0x2738001d, 0x00000000}},  //   _из_, moun_, _ứng_,
  { {0x6b8b0207, 0x27ed010f, 0x442e00f8, 0x00000000}},  //   hegg, lnen_, _fuf_,
  { {0x27ed05b4, 0x957c0046, 0x9f8b000c, 0x00000000}},  //   onen_, siąc, töðu_,
  { {0x27ed1d18, 0x6d4e020c, 0x64411d19, 0x00000000}},  //   nnen_, _seba, mpli,
  { {0x27ed021e, 0x22160264, 0xd12f026c, 0x00000000}},  // [4280] inen_, _офор, امہ_,
  { {0x3f4c001d, 0x27ed001f, 0x7e640de2, 0x00000000}},  //   ếu_, hnen_, rrip,
  { {0x64411635, 0x225e0036, 0xeb9a007c, 0x00000000}},  //   npli, ątku_, жие_,
  { {0x6d4e0292, 0x27ed02ae, 0xab830057, 0x00000000}},  //   _weba, jnen_, вушк,
  { {0x6d4e04cb, 0x61ee01c3, 0xddcd0091, 0x00000000}},  //   _teba, onbl, staš,
  { {0x27ed1c9a, 0x6d43005a, 0x7c2e1d1a, 0x00000000}},  //   enen_, ınac, _tubr,
  { {0xdcfc001e, 0xd7a9001c, 0x27ed010f, 0x00000000}},  //   _varē, कांच, fnen_,
  { {0x27ed00eb, 0x443c01d9, 0x2d980944, 0x00000000}},  //   gnen_, _rtv_, _hare_,
  { {0x2d9804cd, 0x7dc0009f, 0x442e12bc, 0x00000000}},  //   _kare_, _föst, _suf_,
  { {0x7dc001f6, 0x891603ab, 0x2d980343, 0x00000000}},  //   _göst, _قبائ, _jare_,
  { {0x9cec0055, 0x2d98000d, 0x20090016, 0x00000000}},  //   _করুন_, _mare_, ylai_,
  { {0x443c0011, 0x2d981105, 0x61ee00d9, 0x00000000}},  //   _vtv_, _lare_, enbl,
  { {0x2d98001a, 0xdcf50089, 0x443c00d9, 0x00000000}},  //   _oare_, _pazī, _wtv_,
  { {0x442e000a, 0x8c140044, 0x2d980168, 0x00000000}},  //   _tuf_, িদিন_, _nare_,
  { {0x6e2700b5, 0x26c40006, 0xb5fd016c, 0x00000000}},  //   _rijb, lymo_, zušk,
  { {0x2d98010e, 0x2a660085, 0x6e2700d9, 0x00000000}},  //   _aare_, krob_, _sijb,
  { {0xd9040cd9, 0x6b8b0635, 0x2d981d1b, 0x00000000}},  // [4290] _چی_, vegg, _bare_,
  { {0x2d980585, 0xd90402fd, 0x20090006, 0x00000000}},  //   _care_, _نی_, slai_,
  { {0x7dc00039, 0x44290011, 0xb5fd07a0, 0x00000000}},  //   _röst, _kia_, kršn,
  { {0x26c40006, 0x00000000, 0x00000000, 0x00000000}},  //   kymo_,   ,   ,
  { {0x44290198, 0x6b8b0207, 0x2d981d1c, 0x00000000}},  //   _mia_, regg, _fare_,
  { {0x2d981017, 0x442901a3, 0x26c40006, 0x00000000}},  //   _gare_, _lia_, dymo_,
  { {0x3f990d49, 0x44290022, 0x6b8b1d1d, 0x00000000}},  //   _kasu_, _oia_, pegg,
  { {0x27ed054e, 0x44290020, 0xb5fd1d1e, 0x00000000}},  //   unen_, _nia_, muši,
  { {0x27ed051d, 0x27ff1d1f, 0x06960025, 0x00000000}},  //   rnen_, roun_, فنية_,
  { {0x7c2906b2, 0xe6160147, 0xe93800a2, 0x00000000}},  //   _hier, нды_, _قسمت_,
  { {0x7c291d20, 0x44291d21, 0xf3e6025f, 0x00000000}},  //   _kier, _bia_, ежно,
  { {0x4429010a, 0x644100b5, 0xc7c4034b, 0x00000000}},  //   _cia_, rpli, _исчи,
  { {0x442904be, 0x644101aa, 0x7c291d22, 0x00000000}},  //   _dia_, spli, _mier,
  { {0xb5fd129d, 0x64411d23, 0x44290253, 0x00000000}},  //   kuši, ppli, _eia_,
  { {0x44290010, 0xf50501fb, 0xb5fd0089, 0x00000000}},  //   _fia_, _язко, juši,
  { {0x442900ad, 0x7c290046, 0xee3a0517, 0x00000000}},  //   _gia_, _nier, зна_,
  { {0x2d981d24, 0x9cec0055, 0x7dd20018, 0x00000000}},  // [42a0] _pare_, _করেন_, _læse,
  { {0xddc40a14, 0x44290197, 0x2b5f1d25, 0x00000000}},  //   stiž, _zia_, _aduc_,
  { {0x7c290036, 0x2d980239, 0xb5fd12d5, 0x00000000}},  //   _bier, _vare_, guši,
  { {0x2d9801c3, 0x7c291d26, 0xf43a0049, 0x00000000}},  //   _ware_, _cier, לגעמ,
  { {0x7c291d27, 0x2d98001a, 0xb5fd10f7, 0x00000000}},  //   _dier, _tare_, vršn,
  { {0x98a50279, 0x7c290056, 0x3ea000ea, 0x00000000}},  //   _adlı_, _eier, mvit_,
  { {0x3ea00035, 0x699f0061, 0x7c291d28, 0x00000000}},  //   lvit_, _गोळी, _fier,
  { {0xf76f006d, 0x26c40006, 0xdb21010f, 0x00000000}},  //   ماً_, tymo_, _äuße,
  { {0xc6f801fb, 0x66010239, 0x4429008a, 0x00000000}},  //   ьних_, folk, _ria_,
  { {0x44291d29, 0x7c2901a2, 0xa3e3006e, 0x00000000}},  //   _sia_, _zier, फोन_,
  { {0x4429000b, 0x22400263, 0x6296000a, 0x00000000}},  //   _pia_, _atik_, _asyo,
  { {0x87da002c, 0x07da01f7, 0x7c29002b, 0x00000000}},  //   _عباس_, _عذاب_, _xier,
  { {0x44290a05, 0x518705c0, 0x799a18ba, 0x00000000}},  //   _via_, нува, _katw,
  { {0x442900d9, 0x3f9901ee, 0x3ea000ea, 0x00000000}},  //   _wia_, _sasu_, dvit_,
  { {0x44291d2a, 0x2240002d, 0x799a0058, 0x00000000}},  //   _tia_, _etik_, _matw,
  { {0x7e6d00c4, 0x44290145, 0x26140061, 0x00000000}},  //   tuap, _uia_, _नीती_,
  { {0x645a0089, 0x63ad01f6, 0x7c290129, 0x00000000}},  // [42b0] lsti, _inan, _rier,
  { {0x7c290036, 0xf41f00b0, 0x799a1d2b, 0x00000000}},  //   _sier, lmä_, _natw,
  { {0x7c290652, 0x3f99006c, 0x3a3f01ed, 0x00000000}},  //   _pier, _tasu_, _stup_,
  { {0x645a002d, 0xb5fd0142, 0x7c29008e, 0x00000000}},  //   isti, ruši, _qier,
  { {0x7c290308, 0x2bb80054, 0x9f490051, 0x00000000}},  //   _vier, عامة_, nnaí_,
  { {0x645a1d2c, 0x7c290046, 0xf41f00b0, 0x00000000}},  //   ksti, _wier, hmä_,
  { {0x7c291d2d, 0x63ad00f8, 0x660100c7, 0x00000000}},  //   _tier, _onan, volk,
  { {0x645a0030, 0xdb23007a, 0x7dd20030, 0x00000000}},  //   dsti, _موزی, _væse,
  { {0x799a04cb, 0x83fd016c, 0xdb000146, 0x00000000}},  //   _fatw, nuđu, _anmæ,
  { {0x6b9b0056, 0x645a01a2, 0x69ca01a2, 0x00000000}},  //   _haug, fsti, ckfe,
  { {0x6b9b1d2e, 0x645a01c9, 0x22401d2f, 0x00000000}},  //   _kaug, gsti, _stik_,
  { {0xa3dc03d7, 0x7bcb1d30, 0x957c0036, 0x00000000}},  //   णों_, nkgu, wnąt,
  { {0xe1ff008e, 0x799a0dfc, 0xdb1b009d, 0x00000000}},  //   rrón_, _yatw, _boué,
  { {0xf505017a, 0x63ad1d31, 0x6b9b124c, 0x00000000}},  //   _изло, _enan, _laug,
  { {0xdd9200a6, 0x91a90082, 0x645a005b, 0x00000000}},  //   یور_, _quá_, csti,
  { {0x6b9b1d32, 0xe1ff0010, 0xdfd2006d, 0x00000000}},  //   _naug, lról_, جير_,
  { {0xd00700d7, 0xf1c20089, 0x629600e0, 0x00000000}},  // [42c0] тете_, _pašā_, _usyo,
  { {0x63ad01d9, 0x3ea0088c, 0xa2db007d, 0x00000000}},  //   _znan, rvit_, _पेट्,
  { {0x6b9b00db, 0x9f400051, 0x3ea000b0, 0x00000000}},  //   _baug, iniú_, svit_,
  { {0x9f400051, 0xaa4610f3, 0x799a0093, 0x00000000}},  //   hniú_, ведл, _satw,
  { {0xdaba007a, 0x799a01aa, 0xe1ff0010, 0x00000000}},  //   بهشت_, _patw, król_,
  { {0x645a021e, 0x9d430081, 0x3fc8009e, 0x00000000}},  //   ysti, _верд, _آدھی_,
  { {0x38c800a2, 0x8b9600ed, 0x7d03010f, 0x00000000}},  //   عاتی_, _ирач, ünst,
  { {0xb0ba01f5, 0x2ca70030, 0x645a1d33, 0x00000000}},  //   _उपनग, ænde_, vsti,
  { {0x4b7b007b, 0x645a0ffd, 0x799a1d34, 0x00000000}},  //   _קאמו, wsti, _tatw,
  { {0x645a0039, 0xd6d90036, 0x9f400048, 0x00000000}},  //   tsti, nały_, gniú_,
  { {0xc8ca007a, 0x81c90055, 0x7afd068f, 0x00000000}},  //   _توان_, লোড_, _østr,
  { {0xf74610d8, 0x7bc01d35, 0x673b0026, 0x00000000}},  //   _редо, _jomu, ccuj,
  { {0x645a0089, 0xe737012b, 0x41e70245, 0x00000000}},  //   ssti, _реч_, віва,
  { {0x645a003b, 0x8af7006b, 0x9f490048, 0x00000000}},  //   psti, _şəkl, rnaí_,
  { {0xcf9b00ed, 0xdfd50a78, 0x3a2c0082, 0x00000000}},  //   мја_, говы, _midp_,
  { {0x63ad006a, 0x889b0097, 0x938b005e, 0x00000000}},  //   _unan, ובלי, _цска_,
  { {0x6d5700d4, 0x6b9b1d36, 0x8e3800a1, 0x00000000}},  // [42d0] taxa, _raug, نسلر_,
  { {0xab5d0046, 0x6b9b010a, 0x9d550025, 0x00000000}},  //   _może, _saug, انات,
  { {0x7bc0032e, 0x6d57006b, 0xb5fd1d37, 0x00000000}},  //   _bomu, raxa, mušt,
  { {0x80dc0055, 0x8af7006b, 0x6b820010, 0x00000000}},  //   _মুক্, _çəkm, gfog,
  { {0x7bc019c2, 0x290c005d, 0xbebb0023, 0x00000000}},  //   _domu, _ayda_, _egër,
  { {0x6b9b00e7, 0x7bcb0146, 0x00000000, 0x00000000}},  //   _waug, skgu,   ,
  { {0xe73917c3, 0xdb000073, 0xe80f0061, 0x00000000}},  //   ней_, _anmä, ातला_,
  { {0xccf2019b, 0x7c3a00f4, 0x765b0058, 0x00000000}},  //   _הכל_, _étra, tsuy,
  { {0x5a3407ca, 0x673b1d38, 0x6fca0161, 0x00000000}},  //   _внут, rcuj, _dých,
  { {0x6d550173, 0x673b016c, 0x3897013f, 0x00000000}},  //   _jeza, scuj, _lərə_,
  { {0x290c0bc4, 0x6d5504cd, 0xa3ea0113, 0x00000000}},  //   _gyda_, _meza, една_,
  { {0x6d55002d, 0x61e50051, 0xe1ff0010, 0x00000000}},  //   _leza, _amhl, sról_,
  { {0x5b7a0049, 0x966501ab, 0x00000000, 0x00000000}},  //   ערשא, _скле,   ,
  { {0x69c10032, 0xb5fd00d0, 0x80dc0044, 0x00000000}},  //   _jole, gušt, _মুগ্,
  { {0x69c11d39, 0x3942006b, 0xdb19010f, 0x00000000}},  //   _mole, _əks_, chwö,
  { {0xd6d90036, 0xb5fd1b4e, 0x60c104ce, 0x00000000}},  //   wały_, kršk, älma,
  { {0x6d551d3a, 0xb5fd0e0d, 0xe7f60164, 0x00000000}},  // [42e0] _beza, vršj, ुकता_,
  { {0x6d55014a, 0x69c11d3b, 0xb5fd0091, 0x00000000}},  //   _ceza, _nole, dršk,
  { {0x6d551d3c, 0x7bc00059, 0x0b4601e1, 0x00000000}},  //   _deza, _pomu, гнен,
  { {0x9f060151, 0x69c11d3d, 0x2d9c0ecc, 0x00000000}},  //   _موجو, _aole, žve_,
  { {0x69c1117c, 0x160302fb, 0x6fca0027, 0x00000000}},  //   _bole, रकार_, _rých,
  { {0x6d551cb7, 0x38a3014a, 0x6b820232, 0x00000000}},  //   _geza, _bır_, sfog,
  { {0x69c1018e, 0x082a05a7, 0x7bc00161, 0x00000000}},  //   _dole, нции_, _tomu,
  { {0x6e2e0145, 0x6d550213, 0x38a3005a, 0x00000000}},  //   _hibb, _zeza, _dır_,
  { {0x69c10e06, 0x7c220c43, 0x6e2e0ace, 0x00000000}},  //   _fole, mmor, _kibb,
  { {0x6e2e0c32, 0x290c02e1, 0x00000000, 0x00000000}},  //   _jibb, _tyda_,   ,
  { {0x6fca0027, 0x2db701ce, 0xb8e90044, 0x00000000}},  //   _tých, אלין_, _লে_,
  { {0x7c220e9c, 0x69c101aa, 0x7d0e0085, 0x00000000}},  //   nmor, _zole, _mybs,
  { {0x64431d3e, 0xe298007e, 0x69c1000a, 0x00000000}},  //   _etni, гаў_, _yole,
  { {0x69d8009f, 0x6e2e0066, 0x26db034e, 0x00000000}},  //   nhve, _nibb, _אקדמ,
  { {0x6d550209, 0x69cc03d7, 0xdcfc001e, 0x00000000}},  //   _reza, _तकनी, _darī,
  { {0x9f520173, 0x7c220645, 0x644800d9, 0x00000000}},  //   nnyè_, jmor, mpdi,
  { {0x5d550113, 0xb5fd0c1d, 0x6e2e01bc, 0x00000000}},  // [42f0] икат, pušt, _bibb,
  { {0xdcfc0089, 0x78a802e1, 0xbddb0173, 0x00000000}},  //   _garī, _ordv, _etèn,
  { {0x6d550213, 0x6e2e02c2, 0xa1150014, 0x00000000}},  //   _veza, _dibb, _خودت,
  { {0x7c22054e, 0xaf070044, 0x7d0e0146, 0x00000000}},  //   gmor, লেষণ_, _dybs,
  { {0x69c103e9, 0x6e2e0afb, 0xbd6b003b, 0x00000000}},  //   _pole, _fibb, _прве_,
  { {0x6e2e07be, 0x27e601aa, 0x6845007e, 0x00000000}},  //   _gibb, _amon_, анка,
  { {0x69c11d3f, 0x8c250379, 0x7e6d04d3, 0x00000000}},  //   _vole, _نفسه, lrap,
  { {0x16650216, 0x2d9300f4, 0xb5fd0107, 0x00000000}},  //   авим, lexe_, pršk,
  { {0x78a80006, 0x27e60173, 0x7e6d0203, 0x00000000}},  //   _erdv, _dmon_, nrap,
  { {0x69d8010f, 0x27e6002d, 0x2d931d40, 0x00000000}},  //   chve, _emon_, nexe_,
  { {0x7e6d00bb, 0x6aa9000c, 0x628d0032, 0x00000000}},  //   hrap, _href, _apao,
  { {0x6aa91d41, 0xcc76009b, 0x7e6d0058, 0x00000000}},  //   _kref, סגרת_, krap,
  { {0x6b890020, 0xb811013d, 0xdcfc0089, 0x00000000}},  //   _mbeg, _डीएम_, _parī,
  { {0xa06a008b, 0x6aa9000b, 0x76491d42, 0x00000000}},  //   кага_, _mref, mpey,
  { {0x7c2207be, 0x90c3005e, 0x7e6d00d9, 0x00000000}},  //   ymor, обре, erap,
  { {0x6aa90197, 0x6e2e141a, 0x00000000, 0x00000000}},  //   _oref, _sibb,   ,
  { {0x7e6d030a, 0x3f9200f6, 0x7c221d43, 0x00000000}},  // [4300] grap, reyu_, vmor,
  { {0x998c0089, 0x7c2201c3, 0x27e901ca, 0x00000000}},  //   _vidū_, wmor, čany_,
  { {0x7c220d44, 0xd8380243, 0xc1010082, 0x00000000}},  //   tmor, _trči_, _mượt_,
  { {0xc101001d, 0x7e6d00c4, 0x6e2e00d4, 0x00000000}},  //   _lượt_, brap, _wibb,
  { {0x6e2e006b, 0x6aa90016, 0x6fd812dd, 0x00000000}},  //   _tibb, _cref, _cíce,
  { {0x6aa9018e, 0xceb3009b, 0x7c220843, 0x00000000}},  //   _dref, _ויש_, smor,
  { {0xa3c603d7, 0x69d81d44, 0x00000000, 0x00000000}},  //   _एवं_, rhve,   ,
  { {0x7bd9010f, 0x4c9b009b, 0x6aa90009, 0x00000000}},  //   chwu, _בבלו, _fref,
  { {0x6aa904c1, 0x1996003b, 0x764d0279, 0x00000000}},  //   _gref, _вјер, _çayl,
  { {0x14ca007c, 0xe4a60216, 0x6b8910f5, 0x00000000}},  //   выми_, армо, _zbeg,
  { {0xd4970d99, 0xd5b70147, 0x388e006b, 0x00000000}},  //   аря_, рсы_, _sərf_,
  { {0xc7c7007c, 0x46ea00e2, 0xd5b80089, 0x00000000}},  //   _выше_, _иден_, mmām_,
  { {0x926b005e, 0x00000000, 0x00000000, 0x00000000}},  //   ърна_,   ,   ,
  { {0x7e6d0197, 0xf2070088, 0xab5d0066, 0x00000000}},  //   vrap, рямо, _moża,
  { {0x7e6d0019, 0x00000000, 0x00000000, 0x00000000}},  //   wrap,   ,   ,
  { {0x7e6d002b, 0xb5fd0295, 0x25e2006e, 0x00000000}},  //   trap, vrši, टोरी_,
  { {0xba3d0224, 0x9df900e3, 0xd83809ca, 0x00000000}},  // [4310] _prům, гнат_, _luč_,
  { {0x7e6d1692, 0x2705001d, 0xeca7003b, 0x00000000}},  //   rrap, ồng_, ијен,
  { {0x7e6d004e, 0x6fd80051, 0x7c671739, 0x00000000}},  //   srap, _síce, شاال,
  { {0x5b250054, 0x6aa90335, 0x7e6d0035, 0x00000000}},  //   مفضل, _pref, prap,
  { {0xd945005e, 0x7c3b012d, 0xc33400b3, 0x00000000}},  //   бели, _čuru, קוס_,
  { {0xceb200bd, 0x81c90044, 0x6fd800b9, 0x00000000}},  //   _זיך_, লোর_, _více,
  { {0xf0940049, 0xc1010082, 0xe89800a1, 0x00000000}},  //   ַנץ_, _rượt_, لموں_,
  { {0x6aa90bc6, 0xddcd0087, 0xd0f8019b, 0x00000000}},  //   _tref, ntaž, ימות_,
  { {0x06090751, 0x6aa90020, 0x00000000, 0x00000000}},  //   лник_, _uref,   ,
  { {0x5887045a, 0x66081d45, 0xb86b06e3, 0x00000000}},  //   _выда, godk, _ајде_,
  { {0xc3290097, 0xc1010011, 0x03a60216, 0x00000000}},  //   _נו_, _vượt_, бино,
  { {0xd8380173, 0x00000000, 0x00000000, 0x00000000}},  //   _prčv_,   ,   ,
  { {0x27ed021e, 0x8707007c, 0xe4d602fd, 0x00000000}},  //   mien_, _тяже, لویت_,
  { {0x27ed001f, 0xd5b105f3, 0xddc40089, 0x00000000}},  //   lien_, _رفع_, kriš,
  { {0x3f6a0d68, 0x7dd20030, 0x27ed00b5, 0x00000000}},  //   ливо_, _sæso, oien_,
  { {0xafe3012b, 0x6ab7013d, 0x543a0049, 0x00000000}},  //   посл, _आपूर, _געקא,
  { {0xef1a003b, 0x75460010, 0x44200058, 0x00000000}},  // [4320] ума_, _érzé, _ihi_,
  { {0x27ed002d, 0xeef5008b, 0x4432107e, 0x00000000}},  //   hien_, іятэ, _hiy_,
  { {0x442000ad, 0x7dc00047, 0x27ed0315, 0x00000000}},  //   _khi_, _kösz, kien_,
  { {0x27ed021e, 0x61ee006b, 0xab5d0036, 0x00000000}},  //   jien_, libl, _poża,
  { {0x27ed001e, 0x395c0089, 0x99dd000a, 0x00000000}},  //   dien_, tavs_, _pwňp,
  { {0x61ee1d46, 0xddc40209, 0x443201aa, 0x00000000}},  //   nibl, briš, _liy_,
  { {0x6d5e011c, 0x44200e33, 0x27ed122f, 0x00000000}},  //   mapa, _ohi_, fien_,
  { {0x6d5e0475, 0x27ed1d47, 0x44200011, 0x00000000}},  //   lapa, gien_, _nhi_,
  { {0x320a1d48, 0xb97a00a1, 0x95ca02dc, 0x00000000}},  //   koby_, _محاذ_, гуна_,
  { {0x6d5e006a, 0x44200211, 0x27ed00b5, 0x00000000}},  //   napa, _ahi_, aien_,
  { {0xab5d0046, 0x27ed0983, 0x1836007a, 0x00000000}},  //   _możn, bien_, _طراح,
  { {0x44201d49, 0x27ed00f4, 0x6d5e023a, 0x00000000}},  //   _chi_, cien_, hapa,
  { {0x6d5e006a, 0x44320169, 0x442003e7, 0x00000000}},  //   kapa, _diy_, _dhi_,
  { {0x61ee0e97, 0x6d5e0ac0, 0x41e4008b, 0x00000000}},  //   gibl, japa, піса,
  { {0x84460151, 0x6d5e027e, 0x388e006b, 0x00000000}},  //   _اختل, dapa, _hərb_,
  { {0x4420001d, 0x00000000, 0x00000000, 0x00000000}},  //   _ghi_,   ,   ,
  { {0x61ee05d5, 0xa3ce0061, 0xddcd09f4, 0x00000000}},  // [4330] bibl, _शकत_, rtaž,
  { {0x27ed1d4a, 0x61ee006b, 0x6d5e1d4b, 0x00000000}},  //   zien_, cibl, gapa,
  { {0x2bdd02f4, 0xddcd010a, 0x236901d9, 0x00000000}},  //   _मतदा, ptaž, _kdaj_,
  { {0x649e0107, 0x27ed00d4, 0xe1ff0036, 0x00000000}},  //   mšić, xien_, trów_,
  { {0x27ed0108, 0x7e790049, 0x4ea700ed, 0x00000000}},  //   vien_, _דאָז, _урна,
  { {0x27ed0036, 0xddcd0036, 0x3ea901d6, 0x00000000}},  //   wien_, ntaż, mvat_,
  { {0x27ed16c6, 0x3ea91d4c, 0x64ac0521, 0x00000000}},  //   tien_, lvat_, nđić,
  { {0x2369008d, 0x224904cb, 0x61ee1d4d, 0x00000000}},  //   _ndaj_, _otak_, zibl,
  { {0x9595008b, 0xed1800a1, 0x3ea901d6, 0x00000000}},  //   ошні, _نہےں_, nvat_,
  { {0x27ed1d4e, 0x44200632, 0x649e0107, 0x00000000}},  //   sien_, _shi_, kšić,
  { {0x4420001d, 0x22490c28, 0x27ed1744, 0x00000000}},  //   _phi_, _atak_, pien_,
  { {0x232a06e1, 0xb5fd0087, 0x6d5e04eb, 0x00000000}},  //   иони_, vršu, zapa,
  { {0x6d5e11b3, 0xdb000065, 0xfdfb0309, 0x00000000}},  //   yapa, _ramë, ्वास_,
  { {0xb21b0030, 0x6d5e00f6, 0x00000000, 0x00000000}},  //   stæn, xapa,   ,
  { {0x4420001d, 0x61ee006b, 0x320a0721, 0x00000000}},  //   _thi_, ribl, roby_,
  { {0x6d5e110d, 0x61ee0781, 0x320a0941, 0x00000000}},  //   wapa, sibl, soby_,
  { {0x6e4602fd, 0x61ee01aa, 0x81c90044, 0x00000000}},  // [4340] زنام, pibl, লোই_,
  { {0x63a4022b, 0x236901d9, 0x62860171, 0x00000000}},  //   _hain, _zdaj_, mtko,
  { {0x63a4010a, 0x6d5e110b, 0x3ea900b0, 0x00000000}},  //   _kain, rapa, avat_,
  { {0x63a4002d, 0xddcd001a, 0x2d851d4f, 0x00000000}},  //   _jain, tuaţ, _ölen_,
  { {0x6d5e1d50, 0x1a9603ab, 0xa3bb0204, 0x00000000}},  //   papa, تجاج, घात_,
  { {0xfce601bd, 0x63a41d51, 0xf2d30104, 0x00000000}},  //   _дого, _lain, ועד_,
  { {0x6d5c1d52, 0xa37b02d5, 0x7c3e0009, 0x00000000}},  //   _iera, lhõe, qqpr,
  { {0x6d5c0170, 0x63a40004, 0xd90d007a, 0x00000000}},  //   _hera, _nain, دیم_,
  { {0x6d5c027e, 0x7e6414b2, 0xab5d0046, 0x00000000}},  //   _kera, nsip, _możl,
  { {0x7c3c008d, 0x6d5c01a3, 0x186a10d8, 0x00000000}},  //   _kurr, _jera, _важи_,
  { {0x63a41d53, 0x6d5c020c, 0x29181d54, 0x00000000}},  //   _bain, _mera, _ára_,
  { {0x7bc2028c, 0x63a41d55, 0x6d5c0168, 0x00000000}},  //   njou, _cain, _lera,
  { {0x63a4010a, 0x69c80292, 0x7c3c022b, 0x00000000}},  //   _dain, _kode, _lurr,
  { {0xdb0000f4, 0x69c81d56, 0x345500a1, 0x00000000}},  //   _camé, _jode, _کروڑ,
  { {0x63a402f1, 0xe5e70014, 0xa3bb0070, 0x00000000}},  //   _fain, _بزنی, _ناظر_,
  { {0x6d5c0051, 0x63a40238, 0x69c80253, 0x00000000}},  //   _aera, _gain, _lode,
  { {0x6d5c033b, 0x7c3c0756, 0x2249011c, 0x00000000}},  // [4350] _bera, _aurr, _utak_,
  { {0x69c8001e, 0x7c3c008d, 0x6d5c01a3, 0x00000000}},  //   _node, _burr, _cera,
  { {0x7c3c0038, 0x6d5c02e1, 0x443c0ce3, 0x00000000}},  //   _curr, _dera, _juv_,
  { {0x7c3c0065, 0x00000000, 0x00000000, 0x00000000}},  //   _durr,   ,   ,
  { {0x69c8010f, 0x443c1d57, 0x29f60036, 0x00000000}},  //   _bode, _luv_, kład_,
  { {0x6d5c02d5, 0x7c3c08e9, 0x644a016c, 0x00000000}},  //   _gera, _furr, _otfi,
  { {0x69c8027b, 0x6e3d01a6, 0x6d4503ef, 0x00000000}},  //   _dode, _husb, mcha,
  { {0x62860046, 0x6d451d58, 0x69da1582, 0x00000000}},  //   ytko, lcha, _elte,
  { {0x69c800b7, 0x291e002d, 0x6e3d0181, 0x00000000}},  //   _fode, _ezta_, _jusb,
  { {0x6d451d59, 0x6d5c049a, 0x69c80207, 0x00000000}},  //   ncha, _xera, _gode,
  { {0x2b401332, 0xb21b05df, 0x63a40e2d, 0x00000000}},  //   žice_, rtæl, _pain,
  { {0x22840092, 0x6e350450, 0x62860056, 0x00000000}},  //   tök_, _lizb, ttko,
  { {0x63a40089, 0x98a7038c, 0x7dd3014a, 0x00000000}},  //   _vain, manı_, _kısı,
  { {0x7bc20050, 0x63a40020, 0x853c0006, 0x00000000}},  //   zjou, _wain, ndėl,
  { {0x6e3d001f, 0x22841d5a, 0x63a41c87, 0x00000000}},  //   _ausb, sök_, _tain,
  { {0x6d5c0281, 0xe1ff0046, 0x6e3d0190, 0x00000000}},  //   _sera, wrót_, _busb,
  { {0x6d5c020c, 0xdb00049a, 0x7c3c00ab, 0x00000000}},  // [4360] _pera, _tamé, _surr,
  { {0x65610190, 0x7e641d5b, 0x7c3c0052, 0x00000000}},  //   nalh, rsip, _purr,
  { {0x6d5c1d5c, 0x7e640007, 0x31570476, 0x00000000}},  //   _vera, ssip, _מיין_,
  { {0x6d45002a, 0x69c801d9, 0x7bc900f4, 0x00000000}},  //   acha, _sode, _coeu,
  { {0x69c81596, 0x7bc200b0, 0x656101e3, 0x00000000}},  //   _pode, rjou, kalh,
  { {0x7c3c1d5d, 0x09e300a8, 0x98c60cbc, 0x00000000}},  //   _turr, ночн, зсил,
  { {0x65611d5e, 0x69c8073a, 0x764b1d5f, 0x00000000}},  //   dalh, _vode, _atgy,
  { {0x79980263, 0x7bdb0501, 0x2d9a0c21, 0x00000000}},  //   sevw, _gluu, lepe_,
  { {0x69c81d60, 0x00000000, 0x00000000, 0x00000000}},  //   _tode,   ,   ,
  { {0x69da04b4, 0x65610181, 0xba3d00b9, 0x00000000}},  //   _ulte, galh, _prův,
  { {0x395e0100, 0x5399007c, 0x244100f6, 0x00000000}},  //   _iets_, овня_, _cóm_,
  { {0x883b009b, 0x443c00d2, 0x244101e5, 0x00000000}},  //   _התאו, _vuv_, _dóm_,
  { {0x656102d5, 0x7f5d0066, 0x6d45047a, 0x00000000}},  //   balh, _resq, ycha,
  { {0x656100c4, 0xa41000b9, 0x2d9a0243, 0x00000000}},  //   calh, ětší_, jepe_,
  { {0x7f5d02d5, 0x395e1d61, 0x2d9a00f6, 0x00000000}},  //   _pesq, _mets_, depe_,
  { {0x34fb00b6, 0x395e00ab, 0xd13000f3, 0x00000000}},  //   _להוד, _lets_, امِ_,
  { {0x6d450039, 0x9f40009f, 0x69c30036, 0x00000000}},  // [4370] tcha, rnið_, yjne,
  { {0x395e041d, 0x6d4500b9, 0x7bc900f4, 0x00000000}},  //   _nets_, ucha, _soeu,
  { {0x24410011, 0x98a70180, 0x7bdb1d62, 0x00000000}},  //   _xóm_, yanı_, _pluu,
  { {0x6d451d63, 0xbddb00f4, 0x398f005a, 0x00000000}},  //   scha, _suèd, zısı_,
  { {0x398f011f, 0x7bc9009d, 0x98a70180, 0x00000000}},  //   yısı_, _voeu, vanı_,
  { {0x2d9a001a, 0xf9c7041f, 0x00000000, 0x00000000}},  //   cepe_, ящен,   ,
  { {0xf89201f9, 0x395e1d64, 0x656100c4, 0x00000000}},  //   вајќ, _dets_, valh,
  { {0x6561036b, 0x9b590745, 0x2a660058, 0x00000000}},  //   walh, _фиат_, bsob_,
  { {0x656102d5, 0xaa5801f9, 0x395e0129, 0x00000000}},  //   talh, _ниту_, _fets_,
  { {0x395e1d65, 0x98a7005d, 0x7c2b00f8, 0x00000000}},  //   _gets_, sanı_, lmgr,
  { {0x31630e00, 0x656111da, 0x398f005a, 0x00000000}},  //   dajz_, ralh, rısı_,
  { {0xc16900a0, 0x656100c4, 0x6fd81d66, 0x00000000}},  //   _כח_, salh, _cícl,
  { {0xe60e0551, 0x65610181, 0x398f01df, 0x00000000}},  //   _ад_, palh, pısı_,
  { {0xc58e001d, 0x244114ab, 0x00000000, 0x00000000}},  //   _hồng_, _tóm_,   ,
  { {0x2fcb0129, 0x00000000, 0x00000000, 0x00000000}},  //   _bocg_,   ,   ,
  { {0x442b128e, 0x00000000, 0x00000000, 0x00000000}},  //   cmc_,   ,   ,
  { {0x2fcb0026, 0x2d9a0095, 0xc58e0082, 0x00000000}},  // [4380] _docg_, tepe_, _mồng_,
  { {0x270c001d, 0xc58e0011, 0x25a7000a, 0x00000000}},  //   ớng_, _lồng_, _janl_,
  { {0x2d9a02bb, 0x412a00e2, 0x2240010e, 0x00000000}},  //   repe_, _фоно_, _huik_,
  { {0xc58e0011, 0x395e00ab, 0x2d9a0197, 0x00000000}},  //   _nồng_, _sets_, sepe_,
  { {0xa3e3007d, 0x395e00ab, 0x2005009d, 0x00000000}},  //   फोट_, _pets_, élie_,
  { {0xc333034e, 0x8d760123, 0x3f800006, 0x00000000}},  //   דוד_, _تاحا, lgiu_,
  { {0xc58e0011, 0x3ea0040f, 0x224006a8, 0x00000000}},  //   _bồng_, lwit_, _luik_,
  { {0x466a0130, 0x3f801325, 0x6bda0014, 0x00000000}},  //   ором_, ngiu_, _بورس_,
  { {0x96340aef, 0xc6f80088, 0x00000000, 0x00000000}},  //   нниц, яних_,   ,
  { {0xb21b009f, 0xc6f703c8, 0xba23008b, 0x00000000}},  //   rtæk, ьных_, _адук,
  { {0xdb0010af, 0x442b0026, 0x25a70173, 0x00000000}},  //   _mamí, tmc_, _danl_,
  { {0x224000c1, 0x7e760814, 0x2ca7000c, 0x00000000}},  //   _buik_, kryp, ændi_,
  { {0x51871534, 0xf7d700a3, 0xfd650011, 0x00000000}},  //   мува, _קודש_, _chuỗ,
  { {0x69d81d67, 0x22400116, 0x23af0309, 0x00000000}},  //   nkve, _duik_, _जोरद,
  { {0x442b01d0, 0x86370104, 0xe8df0082, 0x00000000}},  //   pmc_, _קרוב_, _kiềm_,
  { {0x5f9400ed, 0x14cb0164, 0x6fa90061, 0x00000000}},  //   кист, ाहरण, _चोखं,
  { {0xee3f001d, 0xc3090044, 0x7e7601d6, 0x00000000}},  // [4390] _quý_, রেজি_, gryp,
  { {0xdb0000f6, 0x00000000, 0x00000000, 0x00000000}},  //   _camí,   ,   ,
  { {0x61f5005d, 0xf3900011, 0x3156009b, 0x00000000}},  //   mizl, _mảng_, _איתן_,
  { {0xe8df0011, 0xee3f0082, 0x60d6009b, 0x00000000}},  //   _niềm_, _tuý_, _נורא_,
  { {0xdb000ca7, 0xc58e0011, 0x9f8a006c, 0x00000000}},  //   _famí, _rồng_, tööd_,
  { {0x92a90036, 0x61f5005a, 0x8afd00b9, 0x00000000}},  //   _załó, nizl, _neře,
  { {0x2b4002db, 0x5fd3006e, 0x00000000, 0x00000000}},  //   žica_, _सवाल,   ,
  { {0x0138019b, 0x2d810026, 0xdb00013e, 0x00000000}},  //   ורות_, lghe_, _zamí,
  { {0xf390001d, 0xddcd001a, 0xc58e0082, 0x00000000}},  //   _bảng_, craţ, _vồng_,
  { {0x2d810207, 0xf3900011, 0xab62006c, 0x00000000}},  //   nghe_, _cảng_, _üüri,
  { {0x2d810048, 0xd5e80025, 0x00000000, 0x00000000}},  //   ighe_, بعين_,   ,
  { {0xe29a0088, 0x7dd2000c, 0x22400007, 0x00000000}},  //   пам_, _hæst, _puik_,
  { {0x45d51d68, 0x2bc7006e, 0x224002c2, 0x00000000}},  //   _подс, _रचना, _quik_,
  { {0x25a7004a, 0x00000000, 0x00000000, 0x00000000}},  //   _uanl_,   ,   ,
  { {0xc0e60d99, 0xdb00008e, 0x25aa00a6, 0x00000000}},  //   ховк, _ramí, _رضوی_,
  { {0x7dd20030, 0x27ff1361, 0x3ea00066, 0x00000000}},  //   _læst, nnun_, twit_,
  { {0xdee30081, 0x9f9d000c, 0x3f800716, 0x00000000}},  // [43a0] готи, ræðu_, rgiu_,
  { {0x7dd2124e, 0xdcee014a, 0xfce60264, 0x00000000}},  //   _næst, _sabı, нозо,
  { {0x3ea01d69, 0x5ec80044, 0x515b009b, 0x00000000}},  //   swit_, _রেখে, _מכיו,
  { {0x986600a1, 0xfc390173, 0xddcd0035, 0x00000000}},  //   ہیئے_, _ciŭ_, traţ,
  { {0x20000035, 0x7dd20146, 0x00000000, 0x00000000}},  //   mnii_, _bæst,   ,
  { {0xa8a601f9, 0x603c000a, 0x693402fd, 0x00000000}},  //   ерик, _fčmt, نکار,
  { {0xde0301fb, 0x27ff000c, 0x69d81d6a, 0x00000000}},  //   _спри, fnun_, rkve,
  { {0x20001d6b, 0x69d8000c, 0x6c360025, 0x00000000}},  //   nnii_, skve, _أفرا,
  { {0xd5b00025, 0x00000000, 0x00000000, 0x00000000}},  //   لفة_,   ,   ,
  { {0x7dd20030, 0x00000000, 0x00000000, 0x00000000}},  //   _gæst,   ,   ,
  { {0x8afd0224, 0xe8df0011, 0xddcd0006, 0x00000000}},  //   _veře, _tiềm_, nraš,
  { {0xab5d01d5, 0x982b00a1, 0x27ff0276, 0x00000000}},  //   _pożi, _فتنہ_, cnun_,
  { {0xf3900011, 0xdb1b00fa, 0x00000000, 0x00000000}},  //   _tảng_, _anuê,   ,
  { {0xddcd0006, 0xd5b80089, 0x00000000, 0x00000000}},  //   kraš, rmās_,   ,
  { {0xc60c0164, 0x61f506e6, 0x64a30545, 0x00000000}},  //   सकीय_, rizl, _баја,
  { {0xe8df001d, 0x61f5005d, 0xddcd1b8e, 0x00000000}},  //   _hiểm_, sizl, draš,
  { {0xe8df001d, 0x6fd81d6c, 0xd838000a, 0x00000000}},  // [43b0] _kiểm_, _mích, _asčk_,
  { {0x02fc012f, 0x443b0023, 0x6b8201d6, 0x00000000}},  //   _מלחמ, _hiq_, egog,
  { {0x6fd80051, 0xc5f30049, 0x2d810197, 0x00000000}},  //   _oích, נדע_, rghe_,
  { {0x6d58000c, 0x00000000, 0x00000000, 0x00000000}},  //   ðvar,   ,   ,
  { {0xfaa50069, 0x443b0065, 0x4429005b, 0x00000000}},  //   тало, _miq_, _mha_,
  { {0xe9d8008b, 0x44290093, 0xbddb1b43, 0x00000000}},  //   нкі_, _lha_, _etèr,
  { {0xd2620089, 0x394c0146, 0x603c0173, 0x00000000}},  //   _ziņā_, _dfds_, _kōma,
  { {0x4429001d, 0x386c008e, 0xe739004c, 0x00000000}},  //   _nha_, _dvdr_, мей_,
  { {0x5a3502be, 0x7c290009, 0x6fd80051, 0x00000000}},  //   _анат, _iher, _dích,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44290061, 0x7c290020, 0x7c3b0883, 0x00000000}},  //   _bha_, _kher, _kiur,
  { {0x44290be3, 0x7c29000a, 0x9f400068, 0x00000000}},  //   _cha_, _jher, phié_,
  { {0x44290065, 0x7c291d6d, 0x443b0023, 0x00000000}},  //   _dha_, _mher, _diq_,
  { {0xdb000211, 0x412a0131, 0x4429010e, 0x00000000}},  //   _jamá, дого_, _eha_,
  { {0x7c29018e, 0x703a007e, 0xdb00113f, 0x00000000}},  //   _oher, дчас_, _mamá,
  { {0x6443000d, 0x2000001a, 0x656301e3, 0x00000000}},  //   _iuni, unii_, _henh,
  { {0xee3a012b, 0x64430697, 0xfe4300ed, 0x00000000}},  // [43c0] дна_, _huni, инто,
  { {0xc27b00a0, 0xddcd0213, 0x7c291ba2, 0x00000000}},  //   _קריי, traš, _aher,
  { {0x7c3b1d6e, 0x64431d6f, 0x65630093, 0x00000000}},  //   _biur, _juni, _menh,
  { {0x7c29028c, 0x64431d70, 0x7c3b088c, 0x00000000}},  //   _cher, _muni, _ciur,
  { {0x64430de6, 0x7c3b01a3, 0x6b8211c6, 0x00000000}},  //   _luni, _diur, rgog,
  { {0x656302d5, 0xddcd0006, 0x7c291d71, 0x00000000}},  //   _nenh, praš, _eher,
  { {0xdb00102e, 0x644300bb, 0x2ca70030, 0x00000000}},  //   _damá, _nuni, ændt_,
  { {0x7c3b04b4, 0x7c291d72, 0xd6da041f, 0x00000000}},  //   _giur, _gher, дто_,
  { {0x6e3c1d73, 0x656316d4, 0x64430032, 0x00000000}},  //   _kirb, _benh, _auni,
  { {0x44291499, 0x7c3b0fec, 0x443b0065, 0x00000000}},  //   _sha_, _ziur, _siq_,
  { {0x6443145d, 0x44291d74, 0x7d7b009b, 0x00000000}},  //   _cuni, _pha_, וניו,
  { {0x64431d75, 0x656301bb, 0xa785023c, 0x00000000}},  //   _duni, _eenh, _مشهو,
  { {0xa3c903d7, 0x644300fa, 0x44290190, 0x00000000}},  //   लॉग_, _euni, _vha_,
  { {0x6563022c, 0x67fe0089, 0x6e3c0066, 0x00000000}},  //   _genh, dīji, _nirb,
  { {0x44291d76, 0x65680475, 0x64431d77, 0x00000000}},  //   _tha_, madh, _guni,
  { {0xd7c50061, 0x442f0292, 0x443b0082, 0x00000000}},  //   वायच, _òg_, _uiq_,
  { {0x6e3c005a, 0x403400da, 0x7c3b00d4, 0x00000000}},  // [43d0] _birb, ретс, _riur,
  { {0xf41f0f3c, 0x7c29000b, 0x3f73001d, 0x00000000}},  //   llä_, _sher, ệu_,
  { {0x6e3c010a, 0xd010026c, 0x63ad0013, 0x00000000}},  //   _dirb, صلے_, _kaan,
  { {0x63ad0004, 0x2d870046, 0x65680020, 0x00000000}},  //   _jaan, żne_, hadh,
  { {0x63ad1d78, 0x628f0061, 0x7c3b0129, 0x00000000}},  //   _maan, ntco, _viur,
  { {0x7c290038, 0x7d1c021a, 0x63ad1158, 0x00000000}},  //   _wher, _fyrs, _laan,
  { {0x7c290038, 0x3da40265, 0xc98416e0, 0x00000000}},  //   _ther, _тряб, ручи,
  { {0x656302d5, 0x7c2900b9, 0x644309cc, 0x00000000}},  //   _senh, _uher, _runi,
  { {0x6568000b, 0x64430d90, 0x7e6d1d79, 0x00000000}},  //   fadh, _suni, nsap,
  { {0x7a240263, 0x64431d7a, 0x63ad1d7b, 0x00000000}},  //   pòta, _puni, _aaan,
  { {0x65630181, 0x63ad00bb, 0xa3df0061, 0x00000000}},  //   _venh, _baan, णसं_,
  { {0xf1a900b6, 0x628f1d7c, 0x65630544, 0x00000000}},  //   _מס_, ftco, _wenh,
  { {0x656302d5, 0x63ad011c, 0xe8df0011, 0x00000000}},  //   _tenh, _daan, _diễm_,
  { {0x20191d7d, 0xa509034b, 0x00000000, 0x00000000}},  //   _aksi_, _пела_,   ,
  { {0xe0d501fb, 0xb21b0030, 0xdb0001a2, 0x00000000}},  //   ають, kræf, _unmö,
  { {0x63ad1d7e, 0xdce700b9, 0x8c43005d, 0x00000000}},  //   _gaan, ůměr, ışla,
  { {0x628f00bb, 0x6e3c0022, 0xd007007c, 0x00000000}},  // [43e0] ctco, _pirb, уете_,
  { {0xe058007a, 0xef170269, 0xcf250025, 0x00000000}},  //   _لیست_, уму_, شرقي,
  { {0xb33b0181, 0x63ad000b, 0xe5f60049, 0x00000000}},  //   meça, _yaan, נזער_,
  { {0x8afd00b9, 0x6e3c01a2, 0x3f8406ec, 0x00000000}},  //   _seřa, _wirb, _ømu_,
  { {0x388e006b, 0x6e3c002b, 0x7e6d0010, 0x00000000}},  //   _tərk_, _tirb, csap,
  { {0x9f52000c, 0x48aa003b, 0x6e3c0048, 0x00000000}},  //   ábær_, етим_, _uirb,
  { {0x2019021e, 0xf41f00b0, 0xfce601ab, 0x00000000}},  //   _yksi_, ylä_, _сово,
  { {0x76740517, 0x27e2000c, 0x9f49000c, 0x00000000}},  //   алиф, ókn_, nnað_,
  { {0x7bc00211, 0x628f107b, 0xeef70049, 0x00000000}},  //   _inmu, xtco, ָמיר_,
  { {0x63ad08b2, 0x35f4004c, 0x1a9b0049, 0x00000000}},  //   _saan, рпор, _אימע,
  { {0x4d7b007b, 0x63ad006a, 0x6568016a, 0x00000000}},  //   ערטע, _paan, radh,
  { {0x53350589, 0xd6d90036, 0xb6c800a1, 0x00000000}},  //   иент, był_, _لاتے_,
  { {0x2d980129, 0x63ad1d7f, 0x656804e7, 0x00000000}},  //   _obre_, _vaan, padh,
  { {0x63ad000b, 0x8556025a, 0x2d98009d, 0x00000000}},  //   _waan, _حیدر_, _nbre_,
  { {0x628f00b5, 0x6fd80129, 0x63ad01c2, 0x00000000}},  //   stco, _lícu, _taan,
  { {0x2d98029d, 0x7e6d006c, 0x9f49000c, 0x00000000}},  //   _abre_, tsap, gnað_,
  { {0xb33b00c4, 0x8c4301df, 0x388e006b, 0x00000000}},  // [43f0] beça, ışma, _dəri_,
  { {0x6b891d80, 0x7e6d01d6, 0x2d8a0045, 0x00000000}},  //   _sceg, rsap, _ccbe_,
  { {0x7e6d0625, 0x8d74006d, 0xd6d90036, 0x00000000}},  //   ssap, صالا, zył_,
  { {0x2d981d81, 0x78510089, 0x00000000, 0x00000000}},  //   _ebre_, _jāve,   ,
  { {0xe8df0011, 0x29f60036, 0x291e00e0, 0x00000000}},  //   _kiệm_, ałam_, _ayta_,
  { {0x291e0039, 0x7649006b, 0x3eb90045, 0x00000000}},  //   _byta_, vqey, _irst_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xccf2034e, 0x3eb9003b, 0x7df40036, 0x00000000}},  //   _וכל_, _krst_, yńsk,
  { {0xda78005e, 0x6aa900ab, 0x7a3902dc, 0x00000000}},  //   _бях_, _usef, _апар_,
  { {0xdcf5038c, 0x67fe001e, 0xe8df001d, 0x00000000}},  //   _hazı, dīju, _niệm_,
  { {0x69c11d82, 0x78430010, 0xa509017a, 0x00000000}},  //   _inle, _bőve, тена_,
  { {0x78bc05ee, 0x672e0010, 0xceb4006b, 0x00000000}},  //   _árva, önjü, yvə_,
  { {0xe9ff001d, 0xa2c60061, 0xf6790049, 0x00000000}},  //   _luận_, ामध्, _סאַמ,
  { {0xdcf5038c, 0x3f8b00b5, 0xd9e5007d, 0x00000000}},  //   _lazı, _accu_, कसित_,
  { {0xb33b0a06, 0x05960014, 0xddc4002b, 0x00000000}},  //   reça, _خانگ, rriż,
  { {0x853c0006, 0xdcf51d83, 0x3eb900fa, 0x00000000}},  //   rdėt, _nazı, _brst_,

  { {0x8d660057, 0xddc401d5, 0x05a90061, 0x00000000}},  // [4400] ивае, priż, _कसाब,
  { {0x957c0046, 0x68350006, 0xddd400b4, 0x00000000}},  //   wiąz, _išdu, _żało,
  { {0x0b461d84, 0x3eb9001f, 0x61fc0279, 0x00000000}},  //   анен, _erst_, mirl,
  { {0x61fc047f, 0x9f06089d, 0x69c103a9, 0x00000000}},  //   lirl, _نوجو, _anle,
  { {0x61fc0051, 0x00000000, 0x00000000, 0x00000000}},  //   oirl,   ,   ,
  { {0x61fc005d, 0x291e1d85, 0x00000000, 0x00000000}},  //   nirl, _pyta_,   ,
  { {0x67fe0089, 0x07e6003b, 0x99650088, 0x00000000}},  //   zīju, ицим, стіл,
  { {0xd90d01ef, 0x69c11d86, 0x7bc01d87, 0x00000000}},  //   رین_, _enle, _unmu,
  { {0xe5c60264, 0x61fc1d88, 0x6e2e0022, 0x00000000}},  //   асно, kirl, _khbb,
  { {0x7c2204bd, 0xd94301fc, 0xf8b80082, 0x00000000}},  //   llor, _дефи, _trĩ_,
  { {0xdcf501f6, 0x61fc0279, 0xc8ca02fd, 0x00000000}},  //   _yazı, dirl, _جوان_,
  { {0x67fe001e, 0xe7830269, 0x1aed0044, 0x00000000}},  //   tīju, _душо, _ছুটে_,
  { {0x61fc1d89, 0x2909005a, 0x7c220288, 0x00000000}},  //   firl, şaat_, ilor,
  { {0x321815a4, 0x67fe0089, 0x3d0f0309, 0x00000000}},  //   gory_, rīju, _तुझे_,
  { {0x67fe0089, 0x27e601a3, 0x8c43014a, 0x00000000}},  //   sīju, _klon_, ışka,
  { {0x78ba0091, 0x645a00ab, 0x44220009, 0x00000000}},  //   _mrtv, mpti, clk_,
  { {0xdcf5005f, 0xb33b0181, 0x61fc014a, 0x00000000}},  // [4410] _razı, meço, birl,
  { {0x61fc0211, 0x645a0056, 0xf1ab0014, 0x00000000}},  //   cirl, opti, _شاخه_,
  { {0x3318026c, 0xe9ff001d, 0x680800b9, 0x00000000}},  //   _مزید_, _quận_, vědn,
  { {0x1b100055, 0x3eb90bf8, 0xdcf5006b, 0x00000000}},  //   ়েছে_, _trst_, _qazı,
  { {0xfaa70404, 0x6fd80779, 0x78ba014a, 0x00000000}},  //   ршен, _víct, _artv,
  { {0xa258009b, 0x27e6011c, 0xbf360104, 0x00000000}},  //   סבוק_, _alon_, _לארץ_,
  { {0x78ba027b, 0x6ce401fb, 0xfb87008b, 0x00000000}},  //   _crtv, _діте, _вызн,
  { {0x61fc005f, 0x1a680167, 0x3f890016, 0x00000000}},  //   zirl, _چینی_, ngau_,
  { {0x61fc0180, 0x19590783, 0x78ba00d9, 0x00000000}},  //   yirl, _базы_, _ertv,
  { {0x27e60173, 0x69c100ab, 0xc4850900, 0x00000000}},  //   _elon_, _unle, блок,
  { {0x32180161, 0x80d70044, 0x27e6000a, 0x00000000}},  //   vory_, _ডেস্, _flon_,
  { {0x986400a1, 0x32180036, 0x3ea91659, 0x00000000}},  //   _بیٹے_, wory_, kwat_,
  { {0x32180324, 0x78ba037e, 0x61fc000c, 0x00000000}},  //   tory_, _zrtv, tirl,
  { {0x765b05cd, 0x00000000, 0x00000000, 0x00000000}},  //   mpuy,   ,   ,
  { {0x61fc1d8a, 0x7c220403, 0x25a50016, 0x00000000}},  //   rirl, ylor, mell_,
  { {0x32180387, 0x2b40050f, 0x25a500d4, 0x00000000}},  //   sory_, žici_, lell_,
  { {0xf41300b6, 0x61fc0197, 0x62800010, 0x00000000}},  // [4420] _מפה_, pirl, ámod,
  { {0x25a51c95, 0x62860058, 0x6b9b1d8b, 0x00000000}},  //   nell_, muko, _abug,
  { {0x1d19008b, 0x628600b0, 0xec7a1d8c, 0x00000000}},  //   аюць_, luko, упе_,
  { {0x6abb1d8d, 0x25a51959, 0x680800b9, 0x00000000}},  //   _bruf, hell_, vědo,
  { {0xeafa0076, 0x25a500cd, 0x62861d8e, 0x00000000}},  //   درات_, kell_, nuko,
  { {0x5ed10044, 0x25a50023, 0x645a1d8f, 0x00000000}},  //   _সেকে, jell_, ypti,
  { {0x6fcc0061, 0x27e60173, 0x62860d9c, 0x00000000}},  //   हापू, _plon_, huko,
  { {0x62860ac2, 0x6abb0146, 0x00000000, 0x00000000}},  //   kuko, _fruf,   ,
  { {0xe9ff001d, 0x25a50016, 0x69961adf, 0x00000000}},  //   _quản_, fell_, _грех,
  { {0x25a51d90, 0x78bc0181, 0x5498007e, 0x00000000}},  //   gell_, _árvo, авоў_,
  { {0xd497007c, 0x9d260044, 0xd5b7007c, 0x00000000}},  //   бря_, _বলুন_, ссы_,
  { {0x645a00ab, 0x63a60010, 0x62860161, 0x00000000}},  //   rpti, gekn, fuko,
  { {0x25a51d91, 0xb33b0181, 0x6286006c, 0x00000000}},  //   bell_, reço, guko,
  { {0x25a5014a, 0x073700b6, 0xe677009b, 0x00000000}},  //   cell_, _האדם_, _פתוח_,
  { {0xcf9b00ed, 0xba3d00b9, 0x63a604e7, 0x00000000}},  //   лја_, _průz, bekn,
  { {0x3ea91d92, 0x63a60022, 0x00000000, 0x00000000}},  //   twat_, cekn,   ,
  { {0x9df9026b, 0xe3b0023c, 0x3f891d93, 0x00000000}},  // [4430] анат_, _سري_, rgau_,
  { {0xdce70046, 0x644a06b7, 0x27170082, 0x00000000}},  //   _zdję, _kufi, ểng_,
  { {0x2127001d, 0x3ea90b36, 0x59c701f5, 0x00000000}},  //   _ánh_, swat_, लासर,
  { {0x60da006c, 0x6abb000c, 0x644a0729, 0x00000000}},  //   ätme, _pruf, _mufi,
  { {0x661a0052, 0xf42a00b0, 0x25a50ced, 0x00000000}},  //   kotk, lvää_, yell_,
  { {0x63a60089, 0x25a50129, 0xc9870077, 0x00000000}},  //   zekn, xell_, суди,
  { {0x25a51d94, 0x48520123, 0x20090006, 0x00000000}},  //   vell_, وپوز, onai_,
  { {0x6abb1d95, 0x869900ed, 0x6b9b011d, 0x00000000}},  //   _truf, атот_, _ubug,
  { {0x64581d96, 0x25a50039, 0x6abb0009, 0x00000000}},  //   _atvi, tell_, _uruf,
  { {0x644a0009, 0x661a016e, 0xb33b014a, 0x00000000}},  //   _bufi, gotk, reçl,
  { {0x25a50129, 0x668300a1, 0x20090093, 0x00000000}},  //   rell_, _کیخل, knai_,
  { {0x25a500d4, 0x628614f7, 0x644a1d97, 0x00000000}},  //   sell_, tuko, _dufi,
  { {0x8c1a019b, 0x25a5002b, 0x63a60010, 0x00000000}},  //   שורי, pell_, rekn,
  { {0x6d47008d, 0x27ff023a, 0x20090964, 0x00000000}},  //   _ngja, liun_, enai_,
  { {0x61430057, 0x62860004, 0xd61800a1, 0x00000000}},  //   дера, suko, _اتنا_,
  { {0x543602fd, 0x24750089, 0x27ff145d, 0x00000000}},  //   _برتر, mām_, niun_,
  { {0x44201d98, 0x9d260055, 0x76431483, 0x00000000}},  // [4440] _iki_, _বলেন_, _kiny,
  { {0x64441d99, 0x7643013e, 0x10a601ee, 0x00000000}},  //   _hiii, _jiny, _дион,
  { {0x2475001e, 0x7643027e, 0x442008a8, 0x00000000}},  //   nām_, _miny, _kki_,
  { {0xeb9a01f9, 0x7643011c, 0x27ed0059, 0x00000000}},  //   рид_, _liny, jhen_,
  { {0x27ed0065, 0x27ff1d9a, 0xa9230802, 0x00000000}},  //   dhen_, diun_, ížno,
  { {0x764311b3, 0x24750089, 0x27ed04ca, 0x00000000}},  //   _niny, kām_, ehen_,
  { {0x2475001e, 0xe7860072, 0xd7c50204, 0x00000000}},  //   jām_, оупо, वांच,
  { {0x6b8b001c, 0x2475001e, 0x6d470065, 0x00000000}},  //   cggg, dām_, _zgja,
  { {0xa3ce03d7, 0x76430922, 0x661a0d25, 0x00000000}},  //   रान_, _biny, totk,
  { {0x44200047, 0x644400f6, 0x44f40088, 0x00000000}},  //   _aki_, _aiii, зпос,
  { {0x644400ca, 0x24750089, 0x764304cb, 0x00000000}},  //   _biii, gām_, _diny,
  { {0x27ed08ba, 0x27ff001a, 0x2b401d9b, 0x00000000}},  //   chen_, ciun_, žicu_,
  { {0x4420023a, 0x661a1d9c, 0x76431d9d, 0x00000000}},  //   _dki_, potk, _finy,
  { {0x2475001e, 0x76431d81, 0x644418bd, 0x00000000}},  //   bām_, _giny, _eiii,
  { {0x29f60036, 0x64580292, 0x442005cd, 0x00000000}},  //   sław_, _utvi, _fki_,
  { {0x187b007b, 0x35e0006e, 0x7643055e, 0x00000000}},  //   יטלב, _पकड़, _ziny,
  { {0x20091cc4, 0x44391177, 0x54340014, 0x00000000}},  // [4450] rnai_, mms_, _ترور,
  { {0xdcbb1277, 0x27ed0066, 0x4420002d, 0x00000000}},  //   ище_, zhen_, _zki_,
  { {0x6b8b001c, 0x44391d9e, 0x27ed0023, 0x00000000}},  //   tggg, oms_, yhen_,
  { {0xc4d300a0, 0xf5370049, 0xdb1b00c4, 0x00000000}},  //   וגע_, קטאר_, _anuá,
  { {0x601301d5, 0xed15026c, 0x443900ab, 0x00000000}},  //   għme, _کہاں_, ims_,
  { {0xa96600e3, 0x7f3a009b, 0x44391d9f, 0x00000000}},  //   пиша_, _לערו, hms_,
  { {0xa3ce02fb, 0x27ed1da0, 0x682510fa, 0x00000000}},  //   राम_, then_, lódi,
  { {0xf77106dd, 0x24750089, 0x76431454, 0x00000000}},  //   راب_, vām_, _siny,
  { {0x76431da1, 0x27ff0065, 0x44320016, 0x00000000}},  //   _piny, riun_, _rhy_,
  { {0x27ed0065, 0x2475001e, 0x4439010a, 0x00000000}},  //   shen_, tām_, ems_,
  { {0x76430129, 0x442001a3, 0x64441da2, 0x00000000}},  //   _viny, _pki_, _piii,
  { {0x38350a78, 0xdce700b9, 0x24750089, 0x00000000}},  //   _энер, _nejč, rām_,
  { {0xddcd01ca, 0x24750089, 0x61ee005b, 0x00000000}},  //   draž, sām_, thbl,
  { {0x44320038, 0x44390787, 0x66ba0104, 0x00000000}},  //   _why_, ams_, _למנה,
  { {0x412a01f9, 0x44320011, 0x4420023a, 0x00000000}},  //   сово_, _thy_, _tki_,
  { {0x44391aaa, 0x66010c08, 0x61ee1da3, 0x00000000}},  //   cms_, lilk, shbl,
  { {0x3171000a, 0x20000145, 0x00000000, 0x00000000}},  // [4460] bazz_, riii_,   ,
  { {0xd8380173, 0x42fb009b, 0x200008c0, 0x00000000}},  //   _apčl_, _להפס, siii_,
  { {0x63b6011f, 0xddcd01d9, 0x2000001a, 0x00000000}},  //   _kayn, braž, piii_,
  { {0x20570097, 0x1b150044, 0x66010288, 0x00000000}},  //   _מיטל_, তেছে_, hilk,
  { {0x63b6011c, 0x66010eff, 0x61fe0361, 0x00000000}},  //   _mayn, kilk, _kmpl,
  { {0x63b61352, 0x6601012d, 0x00000000, 0x00000000}},  //   _layn, jilk,   ,
  { {0xdca30113, 0x66011da4, 0xa8a3007e, 0x00000000}},  //   _пари, dilk, ерык,
  { {0x7a2d004a, 0x368a00e2, 0x00000000, 0x00000000}},  //   rúta, бсон_,   ,
  { {0x61fe0129, 0x8626007e, 0x2e3400f8, 0x00000000}},  //   _ompl, зьне, räff_,
  { {0xf9c400e9, 0x44390022, 0x7ae2013f, 0x00000000}},  //   _تحری, wms_, myot,
  { {0x69c80905, 0xdcfc011f, 0xb21b000c, 0x00000000}},  //   _inde, _karı, fræn,
  { {0xb21b1da5, 0x21ef01a2, 0x00000000, 0x00000000}},  //   græn, _mühe_,   ,
  { {0x44391da6, 0xe9ff001d, 0x63b60058, 0x00000000}},  //   rms_, _quần_, _dayn,
  { {0x4439001e, 0x69da021e, 0x22450039, 0x00000000}},  //   sms_, _jote, ölk_,
  { {0xddcd0119, 0x859b009b, 0x69da1da7, 0x00000000}},  //   traž, _השוו, _mote,
  { {0x61fe1da8, 0xe9ff001d, 0x69da0325, 0x00000000}},  //   _empl, _tuần_, _lote,
  { {0x69c8049b, 0xe9ff0011, 0xadb506e3, 0x00000000}},  // [4470] _onde, _huấn_, мбаш,
  { {0x69da191c, 0xd5b80089, 0x9f490048, 0x00000000}},  //   _note, ndā_, mhaí_,
  { {0xdcfc005a, 0x68250181, 0x26c00006, 0x00000000}},  //   _barı, sódi, _šiol_,
  { {0xd7e60025, 0x3eb20052, 0x00000000, 0x00000000}},  //   _شك_, äntä_,   ,
  { {0xa3ce0183, 0x69da0065, 0x69c80181, 0x00000000}},  //   रात_, _bote, _bnde,
  { {0x69da02a4, 0xa859012b, 0xdea40167, 0x00000000}},  //   _cote, ојих_, _سیمی,
  { {0x660101d9, 0x7c840cee, 0x69da0142, 0x00000000}},  //   vilk, _путе, _dote,
  { {0x69c80917, 0x7b1901ee, 0x7b081da9, 0x00000000}},  //   _ende, _добр_, ástá,
  { {0x66011daa, 0x00000000, 0x00000000, 0x00000000}},  //   tilk,   ,   ,
  { {0xd7060057, 0x69da0b32, 0xa37b006c, 0x00000000}},  //   ьные_, _gote, skõl,
  { {0xdcfc01f6, 0xb21b0698, 0x7bc90116, 0x00000000}},  //   _yarı, træn, _kneu,
  { {0xd91a00bd, 0x68e3009f, 0x6601020c, 0x00000000}},  //   _וועל, mynd, silk,
  { {0x68e3000c, 0xb21b1dab, 0x7bdb000a, 0x00000000}},  //   lynd, rræn, _mouu,
  { {0x22960698, 0x63b60133, 0xf50501ee, 0x00000000}},  //   ræk_, _wayn, _озло,
  { {0xd13200a1, 0x7bc9194d, 0x63b60082, 0x00000000}},  //   ئمز_, _oneu, _tayn,
  { {0xdfd20379, 0xc7b90010, 0x9f400048, 0x00000000}},  //   خير_, ndő_, mhiú_,
  { {0xdb00009f, 0x9f490051, 0x1dc90309, 0x00000000}},  // [4480] _samþ, chaí_, रांत,
  { {0xee371dac, 0x7ae20020, 0xdcfc005a, 0x00000000}},  //   дну_, vyot, _sarı,
  { {0x69da06f8, 0x7e760b3d, 0x00000000, 0x00000000}},  //   _rote, ssyp,   ,
  { {0x69da1dad, 0xdcfc006b, 0x6286046a, 0x00000000}},  //   _sote, _qarı, orko,
  { {0x69da1dae, 0xbb43008b, 0x24530011, 0x00000000}},  //   _pote, вецк, _lãm_,
  { {0x7ae201aa, 0x98c609f1, 0x6286010e, 0x00000000}},  //   ryot, дсил, irko,
  { {0x68e30018, 0x69da028a, 0xdcfc014a, 0x00000000}},  //   gynd, _vote, _tarı,
  { {0x5fd10061, 0xb8d6013d, 0xb90600e8, 0x00000000}},  //   हायल, _छन_, _पथ_,
  { {0x69da1daf, 0x6d430bd9, 0x00000000, 0x00000000}},  //   _tote, žnat,   ,
  { {0x752f0036, 0xd49a0131, 0x7bc90161, 0x00000000}},  //   ęczn, орм_, _zneu,
  { {0x439501fb, 0x35f70025, 0xe9ff0082, 0x00000000}},  //   нанс, بريد_, _quấn_,
  { {0x9f490051, 0x00000000, 0x00000000, 0x00000000}},  //   thaí_,   ,   ,
  { {0x969600e2, 0x3dca000a, 0x00000000, 0x00000000}},  //   _цреш, _onbw_,   ,
  { {0xe9ff0011, 0x00000000, 0x00000000, 0x00000000}},  //   _tuấn_,   ,   ,
  { {0x301500ed, 0x9f400048, 0x00000000, 0x00000000}},  //   едвр, chiú_,   ,
  { {0xb21b000c, 0xdb00008e, 0x00000000, 0x00000000}},  //   mræm, _jamó,   ,
  { {0xdb00004a, 0x00000000, 0x00000000, 0x00000000}},  // [4490] _mamó,   ,   ,
  { {0x442b1db0, 0xe2a6000c, 0x25ac0016, 0x00000000}},  //   llc_, _áðan_, nedl_,
  { {0x7bc907ff, 0x3d94012d, 0xdcfc01c5, 0x00000000}},  //   _pneu, тихр, _marķ,
  { {0xdab9007e, 0x00000000, 0x00000000, 0x00000000}},  //   зыкі_,   ,   ,
  { {0x442b0051, 0xbddb00f6, 0x68e3005b, 0x00000000}},  //   ilc_, _quès, wynd,
  { {0x7bc9018e, 0xe9d8007e, 0xdb0b0023, 0x00000000}},  //   _wneu, мкі_, legë,
  { {0xdcee0036, 0x4c170167, 0x00000000, 0x00000000}},  //   _odbę, _قبرس,   ,
  { {0xbddb009d, 0xd7750025, 0x628600f8, 0x00000000}},  //   _guèr, رابع, yrko,
  { {0xa3ce024c, 0x68e3152f, 0xd90e00a1, 0x00000000}},  //   रास_, synd, لیے_,
  { {0x7c2b06a1, 0x9f400051, 0xb46502dc, 0x00000000}},  //   llgr, thiú_, нкол,
  { {0xdb000e27, 0x2a6d0288, 0x00000000, 0x00000000}},  //   _famó, _hweb_,   ,
  { {0xab5d0036, 0x00000000, 0x00000000, 0x00000000}},  //   _poży,   ,   ,
  { {0xc7d6061e, 0x1ae10044, 0x6286046a, 0x00000000}},  //   _רוני_, _খেতে_, urko,
  { {0xdb000046, 0x7c2b00f8, 0x645c004a, 0x00000000}},  //   _zamó, hlgr, íric,
  { {0xc95200b3, 0x3075189c, 0x00000000, 0x00000000}},  //   רמל_, кутс,   ,
  { {0x6286016e, 0xdb0000f6, 0x00000000, 0x00000000}},  //   prko, _mamò,   ,
  { {0x63a41db1, 0x4422143a, 0x8d660893, 0x00000000}},  // [44a0] _ibin, mok_, евзе,
  { {0x44221db2, 0xa3ce0164, 0x7c2b021f, 0x00000000}},  //   lok_, राव_, elgr,
  { {0x394c0300, 0x2d87004a, 0x44221db3, 0x00000000}},  //   _rgds_, ónea_, ook_,
  { {0x44220027, 0x2a6d0288, 0x00000000, 0x00000000}},  //   nok_, _bweb_,   ,
  { {0x5b230147, 0x63a4000b, 0xdb00008e, 0x00000000}},  //   льша, _mbin, _ramó,
  { {0x4422011c, 0xcb070025, 0x427b0049, 0x00000000}},  //   hok_, عيون_, לאנג,
  { {0x44220f55, 0x6d5c0061, 0xbad80044, 0x00000000}},  //   kok_, _ifra, _দেখছ,
  { {0x8c43013b, 0x44220010, 0x3ebf0243, 0x00000000}},  //   _бесе, jok_, _šuti_,
  { {0x44221b6d, 0x7c220007, 0x62800010, 0x00000000}},  //   dok_, moor, ámol,
  { {0x63a41793, 0xceb300a0, 0x5b35007e, 0x00000000}},  //   _abin, ריז_, _рэсу,
  { {0x44221db4, 0xa37b006c, 0x6d4e00e0, 0x00000000}},  //   fok_, lkõi, _mgba,
  { {0x44220047, 0x2bc6006e, 0x988b00a1, 0x00000000}},  //   gok_, _रोमा, _رحمہ_,
  { {0x6d5c01aa, 0x55e60242, 0xa2be0309, 0x00000000}},  //   _ofra, _подб, शिष्,
  { {0x7c220100, 0x442b0009, 0x63a40009, 0x00000000}},  //   hoor, slc_, _ebin,
  { {0x7c2217c6, 0x7c2b00ea, 0xa3ce0309, 0x00000000}},  //   koor, ylgr, राश_,
  { {0x44220390, 0x629a001a, 0x98bc014a, 0x00000000}},  //   cok_, ător, navı_,
  { {0x7c22020f, 0x7e64011c, 0xa3b80014, 0x00000000}},  // [44b0] door, gpip, _ساير_,
  { {0x63bd0635, 0x63af1db5, 0xab5d0066, 0x00000000}},  //   ldsn, lecn, _inżi,
  { {0x5577007b, 0x7c221db6, 0x63bd012d, 0x00000000}},  //   געבן_, foor, odsn,
  { {0x6d5c01aa, 0x7e640009, 0x7c221db7, 0x00000000}},  //   _efra, bpip, goor,
  { {0x629d0e0c, 0x6d5c018e, 0x7f76009b, 0x00000000}},  //   ntso, _ffra, _בערב_,
  { {0x44221db8, 0xc3340104, 0x2a6d0009, 0x00000000}},  //   zok_, נוס_, _vweb_,
  { {0x7c2200c7, 0x44221db9, 0x7c2c009d, 0x00000000}},  //   boor, yok_, éorè,
  { {0x7c2202c2, 0x629d00ea, 0x44220032, 0x00000000}},  //   coor, ktso, xok_,
  { {0xdcee00b9, 0x442208d0, 0x00000000, 0x00000000}},  //   _odbě, vok_,   ,
  { {0x4422023a, 0x628f117e, 0x62800010, 0x00000000}},  //   wok_, duco, ámom,
  { {0x44221b6d, 0x06df0044, 0xd7e70088, 0x00000000}},  //   tok_, _বেশি, _підо,
  { {0x629d00ea, 0x7e6400e0, 0x00000000, 0x00000000}},  //   ftso, ypip,   ,
  { {0x44221db2, 0x628f016c, 0x06df0044, 0x00000000}},  //   rok_, guco, _বেরি,
  { {0x44221dba, 0x6d5b014a, 0x21ef010e, 0x00000000}},  //   sok_, _şuan, _püha_,
  { {0x44221dbb, 0x21f4010f, 0x91030098, 0x00000000}},  //   pok_, _nähe_, апре,
  { {0xe3b2031d, 0x63a40020, 0x7e6410f0, 0x00000000}},  //   _ضرب_, _ubin, tpip,
  { {0x539b00b6, 0xf7720476, 0x7c220100, 0x00000000}},  // [44c0] _חיפו, יקן_, voor,
  { {0x4d6308f3, 0x7c22049b, 0x7e640ae3, 0x00000000}},  //   икув, woor, rpip,
  { {0x7c22006c, 0xc2c90014, 0x00000000, 0x00000000}},  //   toor, _قبیل_,   ,
  { {0x31780036, 0xe7270025, 0x7a2d0048, 0x00000000}},  //   larz_, _نص_, lúth,
  { {0x7c2200c7, 0x7f1a0088, 0x00000000, 0x00000000}},  //   roor, _ціну_,   ,
  { {0x7c2200c7, 0x69340014, 0x317800b4, 0x00000000}},  //   soor, هکار, narz_,
  { {0x7c221dbc, 0xa37b006c, 0x09e301fc, 0x00000000}},  //   poor, skõi, ројн,
  { {0x61df0164, 0x20120010, 0xb21b0030, 0x00000000}},  //   _नक्ष, nnyi_, træk,
  { {0x31780036, 0x63af1dbd, 0x682500fa, 0x00000000}},  //   karz_, vecn, tódr,
  { {0x2d980022, 0x00000000, 0x00000000, 0x00000000}},  //   _jcre_,   ,   ,
  { {0x624b01d5, 0xe8df0082, 0x395e0026, 0x00000000}},  //   _bżon, _thềm_, _ifts_,
  { {0x601301d5, 0x629d0479, 0xd5be0089, 0x00000000}},  //   għml, ttso, _šāda_,
  { {0x61e10039, 0x63af1958, 0x63bd0056, 0x00000000}},  //   öllo, recn, rdsn,
  { {0x629d022b, 0x63af1dbe, 0xdcfc000a, 0x00000000}},  //   rtso, secn, _adrč,
  { {0x629d013f, 0x67f50010, 0xdcee012d, 0x00000000}},  //   stso, _fájd, _bebč,
  { {0x2d980335, 0xb4de0061, 0x00000000, 0x00000000}},  //   _acre_, णही_,   ,
  { {0x4429006a, 0x2caa023a, 0x2d87004a, 0x00000000}},  // [44d0] _ika_, _apbd_, óneo_,
  { {0x20120009, 0x25be000a, 0x21f4006c, 0x00000000}},  //   anyi_, ndtl_, _pähe_,
  { {0x270e013d, 0x645e009d, 0x9f9c000c, 0x00000000}},  //   ापुर_, _épid, _tíð_,
  { {0x21f4006c, 0x44291dbf, 0x8b940088, 0x00000000}},  //   _vähe_, _jka_, иріч,
  { {0x2009122d, 0x3c3502e1, 0xaa580131, 0x00000000}},  //   miai_, gåva_, вичу_,
  { {0x2009010a, 0x644d009d, 0x2cb80022, 0x00000000}},  //   liai_, _liai, _fsrd_,
  { {0x44290010, 0xb4cc013d, 0x07a50088, 0x00000000}},  //   _oka_, रमो_, гайн,
  { {0x20090736, 0x44291dc0, 0x644d0068, 0x00000000}},  //   niai_, _nka_, _niai,
  { {0x7c29022b, 0xa3d7006e, 0x5b15012b, 0x00000000}},  //   _iker, सान_, _смат,
  { {0xf99304e8, 0x20090197, 0x26c600e7, 0x00000000}},  //   _خبر_, hiai_, _droo_,
  { {0x20091dc1, 0x44290058, 0x240a005e, 0x00000000}},  //   kiai_, _bka_, енни_,
  { {0x44290065, 0xb33b006b, 0x644d0026, 0x00000000}},  //   _cka_, veçr, _ciai,
  { {0xe2c709c0, 0x44291dc2, 0xe5a501ee, 0x00000000}},  //   гляд_, _dka_, _били,
  { {0x27ed1bea, 0x442900b0, 0xab5d0066, 0x00000000}},  //   lken_, _eka_, _inżu,
  { {0x7c29002d, 0x3eb90784, 0x624b0066, 0x00000000}},  //   _oker, _asst_, _iżol,
  { {0x200907bc, 0x2d830a2e, 0x644d0082, 0x00000000}},  //   giai_, _adje_, _giai,
  { {0xee3a017f, 0x27ed1dc3, 0x8f750245, 0x00000000}},  // [44e0] ена_, iken_, русі,
  { {0xdd92004b, 0x7c290056, 0x7c3b00ea, 0x00000000}},  //   صوص_, _aker, _ahur,
  { {0x27ed1dc4, 0x67f50224, 0x20090006, 0x00000000}},  //   kken_, _záje, biai_,
  { {0x27ed02ae, 0x7c3b00ab, 0x20091dc5, 0x00000000}},  //   jken_, _chur, ciai_,
  { {0x7c3b0065, 0xead40f62, 0x09e6005c, 0x00000000}},  //   _dhur, роль, лодн,
  { {0x2d830363, 0x27ed02ae, 0x2fc01dc6, 0x00000000}},  //   _gdje_, eken_, ldig_,
  { {0x3ea01256, 0xf9690088, 0x00000000, 0x00000000}},  //   ltit_, трій_,   ,
  { {0xd6da0200, 0x383402ea, 0xdbca010e, 0x00000000}},  //   ето_, јнир, _põõs,
  { {0x3ea00110, 0xb99601fa, 0x644d0051, 0x00000000}},  //   ntit_, _مشاغ, _riai,
  { {0x44290073, 0xa96a0025, 0x644d0006, 0x00000000}},  //   _ska_, _أمام_, _siai,
  { {0x2ed1006e, 0x44291dc7, 0x3ea00023, 0x00000000}},  //   _सप्त, _pka_, htit_,
  { {0x27ed1dc8, 0x3ea0045f, 0x78ba0010, 0x00000000}},  //   cken_, ktit_, _istv,
  { {0x518701f9, 0x2009010a, 0xe3bf0e65, 0x00000000}},  //   лува, viai_, goña_,
  { {0x2fc01dc9, 0x54e60025, 0x00000000, 0x00000000}},  //   edig_, _مسبق,   ,
  { {0xb21b0030, 0xf55b009b, 0xf8b401f5, 0x00000000}},  //   kræv, _אדומ, ंबिय,
  { {0x08770049, 0x442f1dca, 0x425500a1, 0x00000000}},  //   טעלט_, _óg_, _پندر,
  { {0x2009010a, 0x33a80265, 0xa4f800a1, 0x00000000}},  // [44f0] riai_, _също_, _سکھر_,
  { {0x7c29130e, 0x2009010a, 0x7c3b1dcb, 0x00000000}},  //   _sker, siai_, _shur,
  { {0x20090006, 0xd01000a1, 0x27ed12fd, 0x00000000}},  //   piai_, زلے_, yken_,
  { {0x200c00f4, 0x657a01a3, 0xce95005e, 0x00000000}},  //   édit_, hath, _камъ,
  { {0x657a164d, 0x78ba00f6, 0x3ea000d4, 0x00000000}},  //   kath, _astv, ctit_,
  { {0x2d830107, 0x88c50025, 0xf8650264, 0x00000000}},  //   _udje_, لتعل, авко,
  { {0x27ed0158, 0x14b00309, 0x624b0066, 0x00000000}},  //   tken_, _जनगण, _nżom,
  { {0x7c3b1dcc, 0x27ed1dcd, 0x7c291dce, 0x00000000}},  //   _uhur, uken_, _uker,
  { {0x27ed1dcf, 0x657a0016, 0xe7e60061, 0x00000000}},  //   rken_, fath, _ओकरा_,
  { {0x27ed059f, 0x657a0010, 0x80bb0044, 0x00000000}},  //   sken_, gath, _উপন্,
  { {0x21f4006c, 0x2fc00de7, 0xa8a7005e, 0x00000000}},  //   _näha_, ydig_, _щрак,
  { {0x245a0023, 0x3ea0013e, 0x09aa0044, 0x00000000}},  //   _dëm_, ytit_, _গোপা,
  { {0x657a0058, 0x3ea00288, 0x666701ab, 0x00000000}},  //   bath, xtit_, _съез,
  { {0x657a009d, 0xe1ff06c2, 0x20190087, 0x00000000}},  //   cath, spón_, _ajsi_,
  { {0xab5d0046, 0x61460a30, 0x412a025f, 0x00000000}},  //   _każd, рева, тово_,
  { {0x2fc001b5, 0x3ea000f8, 0x2fda0014, 0x00000000}},  //   udig_, ttit_, خورد_,
  { {0x2fc01dd0, 0xed5a02b0, 0x3ea01dd1, 0x00000000}},  // [4500] rdig_, воз_, utit_,
  { {0xc27b007b, 0x3ea004bd, 0x645e1dd2, 0x00000000}},  //   _שריי, rtit_, _épic,
  { {0x3ea0098a, 0x8fa6007e, 0x7a2d000c, 0x00000000}},  //   stit_, _кане, nútu,
  { {0x3ea00efc, 0x9f4000b0, 0xc50c0049, 0x00000000}},  //   ptit_, tkiä_, עלאָ,
  { {0xa3d70309, 0x62880036, 0x657a0284, 0x00000000}},  //   सात_, ądow, yath,
  { {0x78ba012d, 0x00000000, 0x00000000, 0x00000000}},  //   _pstv,   ,   ,
  { {0x21890049, 0x44c5001e, 0x657a06a5, 0x00000000}},  //   אָפּ, _nē_, vath,
  { {0x657a00e7, 0x21ef010e, 0x00000000, 0x00000000}},  //   wath, _rühm_,   ,
  { {0x657a1b25, 0x8f9b00a3, 0x2a6400f6, 0x00000000}},  //   tath, דיפי, _utmb_,
  { {0x26c00006, 0x7bc01dd3, 0x270e0164, 0x00000000}},  //   _šios_, _hamu, ापौर_,
  { {0x7bc00127, 0x78ba01d9, 0x7d7b00b3, 0x00000000}},  //   _kamu, _ustv, כניו,
  { {0x7bc00169, 0xc3200044, 0xb6a600ed, 0x00000000}},  //   _jamu, নেছি_, _видл,
  { {0x7bc0011c, 0x6aa21dd4, 0x657a028a, 0x00000000}},  //   _mamu, ntof, path,
  { {0x7bc0001a, 0x44c5000a, 0x7a2d12c3, 0x00000000}},  //   _lamu, _fē_, sútv,
  { {0x80071dd5, 0xb21b101b, 0xdfd500a5, 0x00000000}},  //   ачае, dræt, бовы,
  { {0x7bc00149, 0x7415089d, 0x2aa001aa, 0x00000000}},  //   _namu, _دوبا, kòb_,
  { {0x6458042b, 0xdb231dd6, 0xe7ee0061, 0x00000000}},  // [4510] _huvi, ürül, _जवना_,
  { {0x64581aa2, 0x7bc000b0, 0x6aa204b3, 0x00000000}},  //   _kuvi, _aamu, dtof,
  { {0x7bc01dd7, 0xdcbb005e, 0x64581dd8, 0x00000000}},  //   _bamu, ъща_, _juvi,
  { {0x81b80055, 0x64581dd9, 0x6aa20009, 0x00000000}},  //   ছাঃ_, _muvi, ftof,
  { {0x7bc00129, 0x61e5010f, 0x64580052, 0x00000000}},  //   _damu, _kohl, _luvi,
  { {0x64580181, 0x657806b8, 0x61e50066, 0x00000000}},  //   _ouvi, _nevh, _johl,
  { {0x61e5004f, 0x7bc0002b, 0x6458007f, 0x00000000}},  //   _mohl, _famu, _nuvi,
  { {0xe73903c8, 0x7bc00058, 0xa6950098, 0x00000000}},  //   лей_, _gamu, број,
  { {0x6aa204b7, 0x6abb08eb, 0x601301d5, 0x00000000}},  //   ctof, _usuf, għmi,
  { {0x7bc00059, 0x6458007f, 0x61e501f3, 0x00000000}},  //   _zamu, _buvi, _nohl,
  { {0x6458001a, 0x7bc01dda, 0x628f11fe, 0x00000000}},  //   _cuvi, _yamu, erco,
  { {0x69c100b5, 0x64580181, 0x69c301a2, 0x00000000}},  //   _hale, _duvi, ldne,
  { {0x9756009b, 0xa3e90316, 0x61e51ddb, 0x00000000}},  //   _הינו_, _मकर_, _bohl,
  { {0xbb3a0097, 0x69c10285, 0x69c31ddc, 0x00000000}},  //   טערי, _jale, ndne,
  { {0x9f420065, 0x61e50062, 0x628f00d9, 0x00000000}},  //   _tokë_, _dohl, arco,
  { {0x7e660022, 0x69c11ddd, 0x81b80044, 0x00000000}},  //   _ptkp, _lale, ছাই_,
  { {0x38a10051, 0x64581d93, 0x0d861d84, 0x00000000}},  // [4520] hór_, _zuvi, йлан,
  { {0x69c11dde, 0x7bc00515, 0xab8c011f, 0x00000000}},  //   _nale, _samu, _çözü,
  { {0x7bc0070d, 0x31570104, 0x41d50061, 0x00000000}},  //   _pamu, _ליין_, दारस,
  { {0x6d551ddf, 0x69c10302, 0x2aa001aa, 0x00000000}},  //   _egza, _aale, tòb_,
  { {0x7bc2032c, 0x00000000, 0x00000000, 0x00000000}},  //   rdou,   ,   ,
  { {0x6aa21de0, 0xe2a7000c, 0x2bfa0044, 0x00000000}},  //   rtof, óðir_, েকেই_,
  { {0x6aa214b4, 0x69c10667, 0xf8c50061, 0x00000000}},  //   stof, _dale, विषय,
  { {0x7bc00020, 0x9f4201aa, 0xb8d00164, 0x00000000}},  //   _uamu, _pokè_, _ओह_,
  { {0x69c10ab1, 0xa3d7006e, 0x69c307e4, 0x00000000}},  //   _fale, सास_, bdne,
  { {0x69c11de1, 0xceb30104, 0x38a10036, 0x00000000}},  //   _gale, ליח_, bór_,
  { {0x2813026c, 0xc9570025, 0xddc60006, 0x00000000}},  //   _کونس, _المش_, _atkū,
  { {0x69c10046, 0xd6df0044, 0xdb0b13aa, 0x00000000}},  //   _zale, _বেওয, legá,
  { {0x61e501ca, 0xa3ce007d, 0x628f1de2, 0x00000000}},  //   _pohl, राज_, urco,
  { {0x64581de3, 0x69c100d4, 0x27e60785, 0x00000000}},  //   _tuvi, _xale, _hoon_,
  { {0x27e60052, 0x00000000, 0x00000000, 0x00000000}},  //   _koon_,   ,   ,
  { {0x61e5010f, 0x27e61de4, 0x00000000, 0x00000000}},  //   _wohl, _joon_,   ,
  { {0x442b0a32, 0x63ad006a, 0x6d480428, 0x00000000}},  // [4530] moc_, _iban, _údaj,
  { {0xd047005f, 0x442b001a, 0x63ad1de5, 0x00000000}},  //   _əmək, loc_, _hban,
  { {0x69c10068, 0x442b0d9b, 0x63ad0082, 0x00000000}},  //   _rale, ooc_, _kban,
  { {0x27e61de6, 0x69c100ab, 0xb21b0030, 0x00000000}},  //   _noon_, _sale, præs,
  { {0x63ad0065, 0x38a10036, 0x332008f4, 0x00000000}},  //   _mban, wór_, _xxix_,
  { {0x69c1178e, 0xda780783, 0x7e6d1de7, 0x00000000}},  //   _qale, сяц_, mpap,
  { {0x69c30da6, 0x16d1013d, 0x6845007e, 0x00000000}},  //   rdne, तम्ब, онка,
  { {0x69c11196, 0x16651dac, 0x442b00d4, 0x00000000}},  //   _wale, овим, joc_,
  { {0x7c2b0b3d, 0x69c10292, 0x27e6006a, 0x00000000}},  //   mogr, _tale, _doon_,
  { {0x63ad1de8, 0x38c900a1, 0xb5fd016c, 0x00000000}},  //   _aban, _پائی_, opši,
  { {0xca480379, 0x04460805, 0x442b00d4, 0x00000000}},  //   _الله_, женн, foc_,
  { {0x3885001e, 0x7e6d023a, 0xa34a026b, 0x00000000}},  //   mēr_, kpap, изна_,
  { {0xe72e01fb, 0xf1d50061, 0x645e009d, 0x00000000}},  //   _це_, दांन, _épin,
  { {0x63ad002d, 0x27e600b5, 0x7c2b009d, 0x00000000}},  //   _eban, _zoon_, hogr,
  { {0x7c2b0056, 0x27e60082, 0x442b0035, 0x00000000}},  //   kogr, _yoon_, boc_,
  { {0x6b891de9, 0x7c2b002b, 0x442b00e5, 0x00000000}},  //   _ndeg, jogr, coc_,
  { {0xa3d70201, 0xc7b2019b, 0x7e6d006a, 0x00000000}},  // [4540] सार_, ובן_, gpap,
  { {0x13a6026c, 0x6b890207, 0x0d8603e8, 0x00000000}},  //   _اچھی_, _adeg, ілен,
  { {0x7c2b15a3, 0xb6070089, 0xad6503ec, 0x00000000}},  //   fogr, mašī, ساله,
  { {0xfbfa0044, 0x00000000, 0x00000000, 0x00000000}},  //   েক্ষ_,   ,   ,
  { {0x254e005f, 0x7d2400a1, 0x601301d5, 0x00000000}},  //   zəl_, _کہان, għmu,
  { {0x27e600ab, 0x6b890599, 0x00000000, 0x00000000}},  //   _soon_, _edeg,   ,
  { {0x27e60058, 0x2e2f010f, 0x200b0093, 0x00000000}},  //   _poon_, rüft_, _ymci_,
  { {0x254e005f, 0x76aa0242, 0x7a3f009d, 0x00000000}},  //   vəl_, атов_, vête,
  { {0x442b002b, 0xe7a60204, 0xfaa602e9, 0x00000000}},  //   voc_, क्षप, _фазо,
  { {0x80bb0055, 0x27e601bb, 0x1a6700a1, 0x00000000}},  //   _উপস্, _woon_, _بیوی_,
  { {0x27e60250, 0x957c0036, 0x2bcf0061, 0x00000000}},  //   _toon_, ejąc, _सोडा,
  { {0x7a3f00f4, 0xab5d0066, 0x3fc50044, 0x00000000}},  //   rête, _każa, _এক্ষ,
  { {0x442b10ff, 0x23dd0061, 0xb6cb00a1, 0x00000000}},  //   roc_, याबद, _پانے_,
  { {0x442b0784, 0x67fc00f4, 0x00000000, 0x00000000}},  //   soc_, _déje,   ,
  { {0xba3d0224, 0x957c0036, 0x7c2b09e5, 0x00000000}},  //   _způs, ając, yogr,
  { {0x68250036, 0x63ad011c, 0x7e6d0ebd, 0x00000000}},  //   wódz, _uban, tpap,
  { {0x7c2b0627, 0x00000000, 0x00000000, 0x00000000}},  // [4550] vogr,   ,   ,
  { {0x7c2b01aa, 0xf2d20049, 0xe2a7000c, 0x00000000}},  //   wogr, _װעט_, óður_,
  { {0x61e1000c, 0x7e6d0089, 0x6ce4007e, 0x00000000}},  //   öllu, spap, міце,
  { {0xf3ff0181, 0x7e6d0052, 0x32110036, 0x00000000}},  //   nhã_, ppap, lizy_,
  { {0xa969003b, 0x00000000, 0x00000000, 0x00000000}},  //   била_,   ,   ,
  { {0xb7bd0035, 0x00000000, 0x00000000, 0x00000000}},  //   moţi,   ,   ,
  { {0x7c2b0056, 0x3858007e, 0x67f50010, 0x00000000}},  //   pogr, орыю_, _fájl,
  { {0x96950228, 0x80cc0061, 0x00000000, 0x00000000}},  //   прош, हिते,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc9f70025, 0x2d8101a2, 0x245a0089, 0x00000000}},  //   _بسرع, nahe_, _zīmi_,
  { {0xc329009b, 0x645e009d, 0x00000000, 0x00000000}},  //   _עו_, _épil,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc5f5005e, 0x9f59000a, 0x00000000, 0x00000000}},  //   _някъ, _ilsè_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe3c2005d, 0xdb0900f6, 0x00000000, 0x00000000}},  //   _alış_, _obeï,   ,
  { {0xddc40059, 0x998700b9, 0x6d480048, 0x00000000}},  //   dpiš, konů_, _údai,
  { {0x35d0013d, 0x3f8000c4, 0x2bda0061, 0x00000000}},  // [4560] _थोड़, raiu_, णासा,
  { {0x6146008b, 0xb21b000c, 0x62860091, 0x00000000}},  //   _непа, nsæl, msko,
  { {0xd7bd001c, 0xc17300b6, 0xe7bd02f4, 0x00000000}},  //   ्याच, _אחת_, ्याप,
  { {0xfaa60216, 0x60db009b, 0x44200022, 0x00000000}},  //   задо, _הקטנ, _jji_,
  { {0x6286049c, 0x4420000b, 0x6456014a, 0x00000000}},  //   nsko, _mji_, _miyi,
  { {0x2012005f, 0x62861978, 0x4420016c, 0x00000000}},  //   liyi_, isko, _lji_,
  { {0x7af200b9, 0x26cf010e, 0x4420007f, 0x00000000}},  //   _řetě, _argo_, _oji_,
  { {0xab6608fd, 0x44200065, 0xfaa6007c, 0x00000000}},  //   _хвал, _nji_, _набо,
  { {0x62860091, 0xfaa40167, 0xf4220044, 0x00000000}},  //   jsko, _تجزی, নতার_,
  { {0x62861dea, 0x442001aa, 0xd7f800e5, 0x00000000}},  //   dsko, _aji_, _atăt_,
  { {0x62860b4d, 0x43951deb, 0xbebb0065, 0x00000000}},  //   esko, манс, _nxën,
  { {0x62861c81, 0x6b821dec, 0x44320146, 0x00000000}},  //   fsko, naog, _cky_,
  { {0x2012005f, 0x6286101e, 0x64561ded, 0x00000000}},  //   diyi_, gsko, _diyi,
  { {0x6f040036, 0x44320009, 0x171b009b, 0x00000000}},  //   dzic, _eky_, _פוגע,
  { {0x64a300ec, 0x62861dee, 0x6b8200e7, 0x00000000}},  //   _заја, asko, kaog,
  { {0x753700b6, 0x999e010a, 0x6456014a, 0x00000000}},  //   _מאוד_, _kitų_, _giyi,
  { {0xdb0800f4, 0xa3d30204, 0x2d811def, 0x00000000}},  // [4570] _élèv, _होय_, tahe_,
  { {0xdb0b07c4, 0x64560045, 0xddc404eb, 0x00000000}},  //   negå, _ziyi, tpiš,
  { {0x443900b5, 0x64570211, 0x271e0011, 0x00000000}},  //   ols_, _éxit, ịnh_,
  { {0x44cc0224, 0xa3d300e8, 0x09aa0044, 0x00000000}},  //   _mě_, _होम_, _গোলা,
  { {0x4439028c, 0xd90f026c, 0xb5fd1df0, 0x00000000}},  //   ils_, گیا_, opšt,
  { {0x44391df1, 0x3ea90f4a, 0x614700f4, 0x00000000}},  //   hls_, mtat_, célé,
  { {0xd90f04e1, 0x44cc00b9, 0x44390089, 0x00000000}},  //   دیا_, _ně_, kls_,
  { {0x2fc90343, 0x44391df2, 0x00000000, 0x00000000}},  //   ndag_, jls_,   ,
  { {0x3ea91800, 0x3c44008b, 0x44390bd8, 0x00000000}},  //   ntat_, _чэрв, dls_,
  { {0x64441df3, 0x4439032c, 0x645601aa, 0x00000000}},  //   _shii, els_, _siyi,
  { {0x6f040197, 0x3ea91df4, 0x79830145, 0x00000000}},  //   zzic, htat_, manw,
  { {0x62860209, 0x3ea900f8, 0x2fc900b5, 0x00000000}},  //   tsko, ktat_, jdag_,
  { {0x3ea90065, 0xe5a50ae0, 0x1307007e, 0x00000000}},  //   jtat_, _жили, дняй_,
  { {0x42551df5, 0xd25200a1, 0x2bcf0164, 0x00000000}},  //   етст, ئنس_, _सोसा,
  { {0x62861543, 0x644400eb, 0xcfc50044, 0x00000000}},  //   ssko, _thii, _একজন,
  { {0x6286037e, 0x442004d4, 0x2fc9006a, 0x00000000}},  //   psko, _uji_, gdag_,
  { {0xb22600ed, 0x79831df6, 0x8c130044, 0x00000000}},  // [4580] _омил, kanw, িকান_,
  { {0x6f041df7, 0x20000058, 0xdb08009d, 0x00000000}},  //   rzic, shii_, _élév,
  { {0x2a6d0016, 0x2bda0061, 0xfce3034b, 0x00000000}},  //   _ateb_, णाला, кофо,
  { {0x1ee8026c, 0xab5d0036, 0x7c65039d, 0x00000000}},  //   _فوجی_, _ważn, ءالل,
  { {0xaaba025a, 0x3ea91825, 0xbaba0b6c, 0x00000000}},  //   تدار_, ctat_, تداء_,
  { {0x79831df8, 0xab5d0066, 0x00000000, 0x00000000}},  //   ganw, _fażo,   ,
  { {0x6d5c0f3a, 0x6da300e2, 0xdcfc01f3, 0x00000000}},  //   _igra, _шира, _merċ,
  { {0xab2a003b, 0x63a401d1, 0x9b930025, 0x00000000}},  //   _доба_, _ncin, _للفت,
  { {0x9f49014a, 0x79831df9, 0x00000000, 0x00000000}},  //   rkaç_, banw,   ,
  { {0x4439002b, 0x67fc038e, 0x79831dfa, 0x00000000}},  //   wls_, _déja, canw,
  { {0x0d9701f8, 0x2fc90007, 0xdb0b044f, 0x00000000}},  //   וכים_, ydag_, regå,
  { {0x69c800b7, 0x443907f3, 0xa29501ff, 0x00000000}},  //   _hade, uls_, намі,
  { {0xf77300b6, 0x6d5c08c5, 0x443900ab, 0x00000000}},  //   _סקס_, _ogra, rls_,
  { {0x69c80263, 0x44cc00b9, 0x69ca010f, 0x00000000}},  //   _jade, _tě_, ndfe,
  { {0x24650089, 0x443906ed, 0x63a40026, 0x00000000}},  //   _tēma_, pls_, _fcin,
  { {0x6d5c06c2, 0x7658000b, 0x3ea91dfb, 0x00000000}},  //   _agra, _hivy, ttat_,
  { {0x69da0181, 0x63bd0006, 0x765800e7, 0x00000000}},  // [4590] _onte, mesn, _kivy,
  { {0xa3d3001c, 0x69c801b5, 0x3ea90a16, 0x00000000}},  //   _होत_, _nade, rtat_,
  { {0x629d011c, 0x6d5c0009, 0x69ca0016, 0x00000000}},  //   luso, _dgra, ddfe,
  { {0x69da0682, 0x60c50066, 0x3ea91dfc, 0x00000000}},  //   _ante, _ishm, ptat_,
  { {0x69c801e7, 0x629d0253, 0x656a00ea, 0x00000000}},  //   _bade, nuso, _offh,
  { {0xe29c009b, 0x6d5c0846, 0x6d8700a1, 0x00000000}},  //   קשור, _ggra, _زمرہ_,
  { {0x69c804bd, 0xa855025f, 0x79831601, 0x00000000}},  //   _dade, нтиј, ranw,
  { {0x69da15a4, 0x63bd1dfd, 0x6d5c0213, 0x00000000}},  //   _ente, jesn, _zgra,
  { {0x69c800eb, 0x63bd0006, 0x7bdb011c, 0x00000000}},  //   _fade, desn, _inuu,
  { {0x69c81244, 0x63a41dfe, 0x6b800089, 0x00000000}},  //   _gade, _scin, _zemg,
  { {0x76580035, 0x63a4144f, 0x63bd0861, 0x00000000}},  //   _divy, _pcin, fesn,
  { {0x9f4b02d5, 0x69c80763, 0x7bcb07b8, 0x00000000}},  //   _você_, _zade, ndgu,
  { {0x629d0010, 0x69da005b, 0xe78401ff, 0x00000000}},  //   guso, _ynte, _рухо,
  { {0x80cc0061, 0x2907016c, 0x3f8401ee, 0x00000000}},  //   हिले, ozna_, _žmu_,
  { {0x60260401, 0x79810022, 0x7e7d01f3, 0x00000000}},  //   едва, _melw, _awsp,
  { {0x63a4041a, 0x63bd0c8a, 0x6d5c09f9, 0x00000000}},  //   _ucin, cesn, _sgra,
  { {0xa3bf0204, 0x629d0adb, 0x2d9600e2, 0x00000000}},  // [45a0] ीयर_, cuso, ерес,
  { {0xee37012b, 0xab5d0036, 0x7bcb00d9, 0x00000000}},  //   ену_, _inży, edgu,
  { {0x27210011, 0x6d5c0059, 0x6b800022, 0x00000000}},  //   ỳnh_, _vgra, _pemg,
  { {0x69c8011f, 0x7bcf0181, 0x79810016, 0x00000000}},  //   _sade, _ócul, _aelw,
  { {0x69c80b53, 0x79811dff, 0x7afd1e00, 0x00000000}},  //   _pade, _belw, _üstl,
  { {0x63bd0fed, 0x6d5c0091, 0xca75007e, 0x00000000}},  //   zesn, _ugra, туцы,
  { {0x69c80100, 0x69ca0007, 0xf41f00b0, 0x00000000}},  //   _vade, rdfe, ynä_,
  { {0x69c803e1, 0x76581e01, 0x7791025a, 0x00000000}},  //   _wade, _sivy, لیما,
  { {0x63bd145e, 0x3a260245, 0x69c81e02, 0x00000000}},  //   vesn, _змаг, _tade,
  { {0x69da08ba, 0x48e61e03, 0x3f82002d, 0x00000000}},  //   _unte, _позв, _leku_,
  { {0x2918006c, 0x29070046, 0x63bd010a, 0x00000000}},  //   _ära_, czna_, tesn,
  { {0x3f820119, 0x629d003c, 0x388c00b9, 0x00000000}},  //   _neku_, tuso, měr_,
  { {0x63bd0dc6, 0x1dd1013d, 0xfbd3009b, 0x00000000}},  //   resn, _सफलत, אתר_,
  { {0x63bd0a8f, 0x629d0142, 0x00000000, 0x00000000}},  //   sesn, ruso,   ,
  { {0x63bd1e04, 0xadc30082, 0x3f82008a, 0x00000000}},  //   pesn, _ngạc, _beku_,
  { {0x653b009b, 0x629d0010, 0x00000000, 0x00000000}},  //   _מעוד, puso,   ,
  { {0xf4580049, 0xdcfc0087, 0x00000000, 0x00000000}},  // [45b0] _איהר_, _derč,   ,
  { {0x4df40088, 0x50f50264, 0x644f1e05, 0x00000000}},  //   ляєт, _азот, lmci,
  { {0xe29f000c, 0xe9df0082, 0x2cb800e5, 0x00000000}},  //   luð_, _đú_, _cprd_,
  { {0x2cb8023a, 0x7981005b, 0x00000000, 0x00000000}},  //   _dprd_, _selw,   ,
  { {0xe29f000c, 0x16bc0204, 0x7bcb0039, 0x00000000}},  //   nuð_, ्टोब, rdgu,
  { {0xb7bd0035, 0x25be012d, 0xa3d3013d, 0x00000000}},  //   inţe, jetl_, _होस_,
  { {0x9f40000c, 0x99830006, 0x00000000, 0x00000000}},  //   lkið_, _ųjų_,   ,
  { {0xf1e3013d, 0x79810016, 0xe29f000c, 0x00000000}},  //   खाड़_, _welw, kuð_,
  { {0x6d48002a, 0x395e00c4, 0xa3e5006e, 0x00000000}},  //   _údar, _fgts_, नान_,
  { {0x2d830211, 0x388c00b9, 0xdb0b0190, 0x00000000}},  //   _jeje_, běr_, degø,
  { {0x2d83036f, 0x53dd01f5, 0xb7bd0035, 0x00000000}},  //   _meje_, यांश, enţe,
  { {0x2d831e06, 0x26c60061, 0xe29f000c, 0x00000000}},  //   _leje_, _fsoo_, fuð_,
  { {0x72c3008b, 0x3f820de5, 0x65c5007e, 0x00000000}},  //   абяз, _reku_, _абла,
  { {0xb8230055, 0x1a9a0049, 0x72c300e2, 0x00000000}},  //   _পঠিত_, וישע, јбрз,
  { {0xdcfc1e07, 0xb7bd0035, 0x3f8204eb, 0x00000000}},  //   _perč, anţe, _peku_,
  { {0x601b00b0, 0x2b5f1e08, 0x00000000, 0x00000000}},  //   vämä, _nguc_,   ,
  { {0x2d830993, 0xdcfc0006, 0x3f820142, 0x00000000}},  // [45c0] _beje_, _verč, _veku_,
  { {0x601b021e, 0x44220009, 0x2fcb00f6, 0x00000000}},  //   tämä, lnk_, _eacg_,
  { {0x6026008b, 0x2d831068, 0xd00a0e82, 0x00000000}},  //   _адна, _deje_, _жене_,
  { {0x67fc009d, 0x388c00b9, 0x00000000, 0x00000000}},  //   _réjo, věr_,   ,
  { {0x67fc00f4, 0x44220010, 0x2d831e09, 0x00000000}},  //   _séjo, ink_, _feje_,
  { {0xc333019b, 0x67f50047, 0x5a3303e8, 0x00000000}},  //   בוד_, _máju, аніт,
  { {0xfce307ca, 0x3ea00168, 0x621b0049, 0x00000000}},  //   _коро, luit_, ווסק,
  { {0x8c46007c, 0x2fc01e0a, 0x00000000, 0x00000000}},  //   _ребе, neig_,   ,
  { {0x3ea001b5, 0x96340794, 0xf6e3007e, 0x00000000}},  //   nuit_, лниц, ацэн,
  { {0x7c220056, 0x25a70197, 0x442201c3, 0x00000000}},  //   lnor, _ccnl_, enk_,
  { {0x7c2208eb, 0x2a640065, 0x1514004d, 0x00000000}},  //   onor, _humb_, удня,
  { {0x7c220039, 0xd7ef0025, 0xe29f000c, 0x00000000}},  //   nnor, _وكل_, tuð_,
  { {0x51871e0b, 0xa2d0013d, 0x41de01f5, 0x00000000}},  //   кува, दिष्, मांस,
  { {0x3ea0028c, 0x7c22010f, 0xe29f000c, 0x00000000}},  //   duit_, hnor, ruð_,
  { {0xb65b0097, 0xc05b0088, 0x2258007c, 0x00000000}},  //   _קדוש, діа_, тиры_,
  { {0x23aa024c, 0x32180061, 0xf047007e, 0x00000000}},  //   _कायद, airy_, тэго,
  { {0x3ea01e0c, 0x7c221712, 0x53140014, 0x00000000}},  // [45d0] guit_, dnor, _پذير,
  { {0x7c22018e, 0x9f40000c, 0x00000000, 0x00000000}},  //   enor, rkið_,   ,
  { {0x2d831e0d, 0x83340123, 0x00000000, 0x00000000}},  //   _veje_, _مریض,   ,
  { {0x7c220207, 0x200c0129, 0x3ea01e0e, 0x00000000}},  //   gnor, èdit_, buit_,
  { {0xee8403c8, 0x2d830065, 0x6003006c, 0x00000000}},  //   _высо, _teje_, _tõmb,
  { {0x27ef01e3, 0x7c220288, 0xc3340097, 0x00000000}},  //   _sogn_, anor, סוס_,
  { {0x7c2200c4, 0x89d60025, 0x20020022, 0x00000000}},  //   bnor, طوير_, _ylki_,
  { {0x6d470213, 0xc30a0044, 0xf7710025, 0x00000000}},  //   _izja, রপতি_, حاث_,
  { {0x2a640059, 0x27ef0190, 0x00000000, 0x00000000}},  //   _gumb_, _vogn_,   ,
  { {0xab5d0066, 0x00000000, 0x00000000, 0x00000000}},  //   _nażi,   ,   ,
  { {0x3ea01e0f, 0x6abb0009, 0x00000000, 0x00000000}},  //   zuit_, _hpuf,   ,
  { {0xe29a008b, 0x4c9a01ce, 0x987a0049, 0x00000000}},  //   нам_, עברו, _נאנט,
  { {0xab5d002b, 0x44220087, 0x2fc001e5, 0x00000000}},  //   _bażi, rnk_, veig_,
  { {0xfb16007b, 0x7c22041a, 0x720600a1, 0x00000000}},  //   אַלט_, znor, اہدہ_,
  { {0x2fc01e10, 0x7c221e11, 0x09cd0044, 0x00000000}},  //   teig_, ynor, লাপা,
  { {0x3ea01e12, 0xd9c0013d, 0xe3b20426, 0x00000000}},  //   tuit_, _एस्ट, _طرب_,
  { {0xdee3026b, 0x2fc01e13, 0xab5d0066, 0x00000000}},  // [45e0] боти, reig_, _fażi,
  { {0x3ea001b5, 0xfce6025f, 0x1168025a, 0x00000000}},  //   ruit_, лозо, _جلدی_,
  { {0x3ea00173, 0x7c220afd, 0xb5fa0049, 0x00000000}},  //   suit_, tnor, עלעכ,
  { {0x9e660025, 0x63a600bb, 0xab83007c, 0x00000000}},  //   _ماسن, ngkn, бушк,
  { {0x7c220039, 0xa3e50201, 0x6d470032, 0x00000000}},  //   rnor, नात_, _ezja,
  { {0x7c2200ea, 0xe918007e, 0xddcd0035, 0x00000000}},  //   snor, колі_, rpaţ,
  { {0xb21b101b, 0x67f50142, 0x6e2b0010, 0x00000000}},  //   msæt, _nájs, égbe,
  { {0xa3d3013d, 0xb21b0030, 0x57f40081, 0x00000000}},  //   _हों_, lsæt, рпит,
  { {0x7bc20498, 0x6996030d, 0x81ea0044, 0x00000000}},  //   meou, _брех, _মতন_,
  { {0x88c60025, 0xb21b0030, 0x00000000, 0x00000000}},  //   _متصل, nsæt,   ,
  { {0xd5b70783, 0xce37009b, 0x9f5601e5, 0x00000000}},  //   усы_, ראית_, _ágæt_,
  { {0x7bc200ab, 0x4547007e, 0xc6a6003b, 0x00000000}},  //   neou, ычым_, _брки,
  { {0xa3d6006e, 0xb21b0030, 0xa83700a3, 0x00000000}},  //   _सफर_, ksæt, _גראד_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb21b1e14, 0x661a1e15, 0x683e0023, 0x00000000}},  //   dsæt, mitk, tëdh,
  { {0xd904009c, 0x661a1a56, 0x12e70088, 0x00000000}},  //   _ہی_, litk, _біог,
  { {0xdd9b0794, 0x7bc2006c, 0x8e15007e, 0x00000000}},  // [45f0] еше_, deou, адац,
  { {0x2733001d, 0x2721001d, 0xd90400e9, 0x00000000}},  //   ợng_, ẳng_, _فی_,
  { {0x628f0051, 0x645f00f4, 0x644d01a3, 0x00000000}},  //   lsco, _épis, _khai,
  { {0x907a00a3, 0x3d190061, 0x628f004a, 0x00000000}},  //   _שטרי, _येणे_, osco,
  { {0x644d002a, 0x628f0051, 0x661a003f, 0x00000000}},  //   _mhai, nsco, kitk,
  { {0x3d19001c, 0xe9d8007e, 0x628f0197, 0x00000000}},  //   _येथे_, лкі_, isco,
  { {0xa3d6006e, 0x661a010f, 0x628f04df, 0x00000000}},  //   _सफल_, ditk, hsco,
  { {0x44290065, 0x20091e16, 0xe8890082, 0x00000000}},  //   _nja_, nhai_, rẻ_,
  { {0x0ab802fd, 0x6f0d1140, 0x3d19001c, 0x00000000}},  //   _مطلب_, nzac, _येते_,
  { {0x44290390, 0x7c290637, 0x6b8b01d6, 0x00000000}},  //   _aja_, _hjer, lagg,
  { {0x644d002a, 0x628f0b32, 0xf3e6004c, 0x00000000}},  //   _bhai, esco, ажно,
  { {0x69c3011f, 0x6b8b0207, 0x644d0122, 0x00000000}},  //   lene, nagg, _chai,
  { {0x661a0085, 0x7c29028b, 0x7c3b0020, 0x00000000}},  //   bitk, _mjer, _mkur,
  { {0x412a0373, 0x6b8b0418, 0x442910c3, 0x00000000}},  //   вого_, hagg, _eja_,
  { {0x644d002a, 0x78a3006b, 0x7c3b014a, 0x00000000}},  //   _fhai, nunv, _okur,
  { {0x7c29048a, 0x69c31e17, 0x27ed0292, 0x00000000}},  //   _njer, hene, njen_,
  { {0xd00f0025, 0x0d8602d3, 0x6b8b0197, 0x00000000}},  // [4600] ذلك_, илан, dagg,
  { {0x7c3b000c, 0x69c30059, 0x27ed0065, 0x00000000}},  //   _akur, jene, hjen_,
  { {0x7c290030, 0x27ff000c, 0x27ed1e18, 0x00000000}},  //   _bjer, kkun_, kjen_,
  { {0x200901d6, 0x6b8b0197, 0x27ed1e19, 0x00000000}},  //   chai_, gagg, jjen_,
  { {0x69c30abe, 0x27ed016c, 0x7c290023, 0x00000000}},  //   fene, djen_, _djer,
  { {0x69c3001f, 0x7bc2001c, 0x7c291e1a, 0x00000000}},  //   gene, seou, _ejer,
  { {0x082a09de, 0x7c2902cc, 0xa96700ec, 0x00000000}},  //   кции_, _fjer, шија_,
  { {0x7c291e1b, 0x27ed09ef, 0xd6da005e, 0x00000000}},  //   _gjer, gjen_, вто_,
  { {0x644d018e, 0x69c31e1c, 0xa3e50204, 0x00000000}},  //   _rhai, bene, नास_,
  { {0x644d0051, 0xe83900b9, 0xceb3009b, 0x00000000}},  //   _shai, ější, קית_,
  { {0x2dd900bd, 0x661a0039, 0x644d0051, 0x00000000}},  //   אַרב, ritk, _phai,
  { {0x628f00bb, 0x661a1382, 0x78fb0049, 0x00000000}},  //   tsco, sitk, _שלאפ,
  { {0x628f0197, 0x629d00bb, 0xd7ef0025, 0x00000000}},  //   usco, urso, _تكن_,
  { {0x798810b4, 0x5466003b, 0x00000000, 0x00000000}},  //   _jedw, _књиз,   ,
  { {0x049406ea, 0x644d002a, 0x4639007b, 0x00000000}},  //   _البح, _thai, _געװע,
  { {0x6f0d04bd, 0xa3bb05d4, 0x1473026c, 0x00000000}},  //   tzac, _شاعر_, _باوج,
  { {0x44390325, 0x60d3010a, 0x69c30cca, 0x00000000}},  // [4610] mos_, _žemė, yene,
  { {0x44390977, 0xa3e503d7, 0x7c3b0056, 0x00000000}},  //   los_, नाव_, _skur,
  { {0x6b8b001c, 0xd010026c, 0x201e0129, 0x00000000}},  //   tagg, سلے_, ètic_,
  { {0x44391e1d, 0x69c300bb, 0x201b006b, 0x00000000}},  //   nos_, wene, qiqi_,
  { {0x7c290243, 0x6b8b15d4, 0x44390181, 0x00000000}},  //   _vjer, ragg, ios_,
  { {0x44391e1e, 0x89a801fb, 0x6b8b0207, 0x00000000}},  //   hos_, иків_, sagg,
  { {0x4439010a, 0x7c29008d, 0x69c3022b, 0x00000000}},  //   kos_, _tjer, rene,
  { {0x44390736, 0x7c3b0574, 0x7c291e1f, 0x00000000}},  //   jos_, _ukur, _ujer,
  { {0x44390977, 0xa9c70265, 0x27ed1105, 0x00000000}},  //   dos_, _всек, rjen_,
  { {0x27ed1e20, 0x63ad02f9, 0x79881e21, 0x00000000}},  //   sjen_, _acan, _gedw,
  { {0x44391814, 0x6b890004, 0xf2c90104, 0x00000000}},  //   fos_, _keeg, _רע_,
  { {0x44390325, 0x27ed0065, 0x63ad0048, 0x00000000}},  //   gos_, qjen_, _ccan,
  { {0x6b8900b5, 0x7c3a000c, 0x853c0006, 0x00000000}},  //   _meeg, _ítre, ngėj,
  { {0x6b89046a, 0xe736003b, 0xf6760049, 0x00000000}},  //   _leeg, _ћеш_, _הײסט_,
  { {0x44390a76, 0x63ad0009, 0x00000000, 0x00000000}},  //   bos_, _fcan,   ,
  { {0x44390f19, 0x6e3c0059, 0xb4fa009b, 0x00000000}},  //   cos_, _skrb, _תפקי,
  { {0x7c39005b, 0xa3e5007d, 0xdee3142c, 0x00000000}},  // [4620] dowr, नार_, поти,
  { {0xbd8a007a, 0xe0580014, 0x00000000, 0x00000000}},  //   انان_, _چیست_,   ,
  { {0xf8a504e1, 0xe058007a, 0x6b8900d9, 0x00000000}},  //   _تک_, _نیست_, _beeg,
  { {0x44d7000d, 0x00000000, 0x00000000, 0x00000000}},  //   _mă_,   ,   ,
  { {0xa91c0027, 0x6b890007, 0x79880016, 0x00000000}},  //   _veľm, _deeg, _pedw,
  { {0x4439049a, 0xfce6003b, 0xa2d9024c, 0x00000000}},  //   zos_, _лого, मित्,
  { {0x44391e22, 0xdca310dc, 0x7d2400a1, 0x00000000}},  //   yos_, _нари, _بہان,
  { {0x44391e23, 0xc7c60057, 0xe698005e, 0x00000000}},  //   xos_, сски, авиш_,
  { {0xf76f03ec, 0xceb4006b, 0x00000000, 0x00000000}},  //   راي_, ntə_,   ,
  { {0x63ad0122, 0x2d8a0247, 0x44d70035, 0x00000000}},  //   _scan, _jebe_, _bă_,
  { {0x44391e24, 0x44d7000d, 0xd7ef03f3, 0x00000000}},  //   tos_, _că_, _еу_,
  { {0x44d7001a, 0xceb4006b, 0xccf3009b, 0x00000000}},  //   _dă_, ktə_, לכת_,
  { {0x44391718, 0xb3aa0164, 0x6594007e, 0x00000000}},  //   ros_, _कारख, _далу,
  { {0x44390919, 0x5558008b, 0x2d9c0181, 0x00000000}},  //   sos_, _каля_, óvel_,
  { {0x4439006a, 0xa1591e25, 0x61fa0039, 0x00000000}},  //   pos_, раву_, ötla,
  { {0x4035007e, 0xceb4006b, 0x3ea0158f, 0x00000000}},  //   цебс, ftə_, frit_,
  { {0x6b89006c, 0x60250006, 0x3ea01d73, 0x00000000}},  // [4630] _reeg, nėmi, grit_,
  { {0x6b89006c, 0xf41f00b0, 0xafdb0190, 0x00000000}},  //   _seeg, liä_, _skød,
  { {0x2d8a0819, 0x3ea00065, 0x6b89006c, 0x00000000}},  //   _debe_, arit_, _peeg,
  { {0x3ea01cfa, 0xf41f00b0, 0xab940088, 0x00000000}},  //   brit_, niä_, зиці,
  { {0x3ea004bd, 0xdefb0147, 0x78670010, 0x00000000}},  //   crit_, _сын_, _műve,
  { {0x6b890328, 0x2d8a14c9, 0x600a0027, 0x00000000}},  //   _weeg, _gebe_, _výme,
  { {0xf41f00b0, 0xdd0e006b, 0xe7e50309, 0x00000000}},  //   kiä_, mışa, काला_,
  { {0xdd0e005a, 0x2d8a0bf8, 0xf41f00b0, 0x00000000}},  //   lışa, _zebe_, jiä_,
  { {0x44d71305, 0x6003006c, 0x2d9807c4, 0x00000000}},  //   _să_, _nõmm, _ydre_,
  { {0x069300a1, 0xdd0e0279, 0x00000000, 0x00000000}},  //   _ہاتھ, nışa,   ,
  { {0x25dd0061, 0xd7c8007a, 0xa3ea007e, 0x00000000}},  //   _कोणी_, _گونه_, адна_,
  { {0x44d7000d, 0x3f8b0091, 0x60250006, 0x00000000}},  //   _vă_, _necu_, bėmi,
  { {0x42ba007e, 0x61f70141, 0xd7c804b1, 0x00000000}},  //   шыню_, _boxl, _دونه_,
  { {0x3ea0164e, 0xf7480439, 0x00000000, 0x00000000}},  //   vrit_, _الهي_,   ,
  { {0x3f8b0107, 0x00000000, 0x00000000, 0x00000000}},  //   _becu_,   ,   ,
  { {0x1dac02d2, 0x3ea00715, 0x2d8a0387, 0x00000000}},  //   _चाहत, trit_, _sebe_,
  { {0xd00700e3, 0xda090061, 0x3f8b1e26, 0x00000000}},  // [4640] цете_, वसात_, _decu_,
  { {0x3ea00065, 0x64461802, 0x3fc600a1, 0x00000000}},  //   rrit_, llki, _ڈگری_,
  { {0xa91c0027, 0x24650089, 0xceb4006b, 0x00000000}},  //   _veľk, _tēmu_, stə_,
  { {0xdee602b0, 0x3ea000f4, 0x3f8b012d, 0x00000000}},  //   _доми, prit_, _gecu_,
  { {0x2d8a0119, 0x61f7006b, 0xf413009b, 0x00000000}},  //   _tebe_, _yoxl, ופא_,
  { {0xdd920123, 0xddd50089, 0x202300b4, 0x00000000}},  //   _زور_, _aizņ, ąpił_,
  { {0x8b96003b, 0xf1b2013d, 0x23aa0061, 0x00000000}},  //   _мрач, _जानन, _कांद,
  { {0x6d4e1e27, 0x60250006, 0x3b8601ab, 0x00000000}},  //   _izba, tėmi, _флаг,
  { {0xc6f704af, 0xf41f00b0, 0x3b07005e, 0x00000000}},  //   жных_, viä_, _дето_,
  { {0xc5fa00ed, 0x6025007f, 0x00000000, 0x00000000}},  //   рѓи_, rėmi,   ,
  { {0x629601aa, 0x64740245, 0xf41f00b0, 0x00000000}},  //   _avyo, ягну, tiä_,
  { {0x9f49000c, 0x6b8205de, 0x59e20061, 0x00000000}},  //   kkað_, nbog, पाकर,
  { {0xc34b005e, 0x93470025, 0xf41f00b0, 0x00000000}},  //   ряне_, تخدم, riä_,
  { {0xf41f021e, 0x72050025, 0x3f8b0035, 0x00000000}},  //   siä_, أوسم, _secu_,
  { {0x6aa21e28, 0xf41f00b0, 0x3f8b0087, 0x00000000}},  //   hrof, piä_, _pecu_,
  { {0x7a3f00f4, 0x6b821e29, 0x386c0161, 0x00000000}},  //   nêtr, jbog, _mudr_,
  { {0x855606c6, 0x656d0279, 0x3f8b06ed, 0x00000000}},  // [4650] _دیگر_, _şahi, _vecu_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27e61827, 0x2d810051, 0xd7bc0061, 0x00000000}},  //   _onon_, rbhe_, ्जाच,
  { {0x6b820190, 0x44cc0036, 0xa923013e, 0x00000000}},  //   gbog, _mś_, ůžko,
  { {0x7f760097, 0x442b0fcc, 0x6d4e0032, 0x00000000}},  //   _מערב_, inc_, _ezba,
  { {0x3ea90169, 0x28b90025, 0x2fc90311, 0x00000000}},  //   muat_, مطبخ_, leag_,
  { {0x6446000c, 0x3ea91e2a, 0x47d40044, 0x00000000}},  //   ylki, luat_, থানী,
  { {0x6aa20016, 0xf81302fd, 0x08d4007e, 0x00000000}},  //   brof, بستگ, ьція,
  { {0x3ea91e2b, 0xa3e5013d, 0x6b9b00e0, 0x00000000}},  //   nuat_, नाई_, _idug,
  { {0x442b00d4, 0x973200a6, 0x00000000, 0x00000000}},  //   enc_, رکنا,   ,
  { {0x04461e2c, 0x24520861, 0x7c2b0544, 0x00000000}},  //   зенн, háme_, ongr,
  { {0x3897001a, 0x7c2b00ea, 0x7a3f009d, 0x00000000}},  //   măr_, nngr, cêtr,
  { {0xe72e0017, 0x66e5017a, 0x26dd0061, 0x00000000}},  //   _че_, _хола, _urwo_,
  { {0xbb3a007b, 0x24520161, 0x442b005b, 0x00000000}},  //   מערי, dáme_, anc_,
  { {0x25e80164, 0x38970035, 0xa7fc014a, 0x00000000}},  //   जारी_, năr_, _atıy,
  { {0x6b9b000b, 0x6aa21e2d, 0x2fc90007, 0x00000000}},  //   _ndug, yrof, geag_,
  { {0x3ea9145d, 0xdfcf01b7, 0x38970035, 0x00000000}},  // [4660] guat_, ديق_, hăr_,
  { {0x273a0011, 0x7c2b0168, 0x13a800a1, 0x00000000}},  //   ừng_, engr, _انکی_,
  { {0x5046005c, 0x6b820296, 0x00000000, 0x00000000}},  //   _необ, tbog,   ,
  { {0x4422022b, 0x6aa2010f, 0x3ea9020c, 0x00000000}},  //   nik_, trof, buat_,
  { {0x3f920093, 0x00000000, 0x00000000, 0x00000000}},  //   mayu_,   ,   ,
  { {0xceb3019b, 0x3f921444, 0x6aa200d4, 0x00000000}},  //   _איש_, layu_, rrof,
  { {0xe3bf027b, 0x44220010, 0xa3ac0164, 0x00000000}},  //   liñe_, kik_, खला_,
  { {0x6aa20a83, 0x442215df, 0x4c9b009b, 0x00000000}},  //   prof, jik_, _לבלו,
  { {0x44220047, 0xfaa300ed, 0x442b0087, 0x00000000}},  //   dik_, _пато, vnc_,
  { {0x44980088, 0x3f920093, 0x6e3e1e2e, 0x00000000}},  //   овою_, hayu_, nopb,
  { {0x3f920022, 0x24590451, 0x69ca0095, 0x00000000}},  //   kayu_, жань_, mefe,
  { {0x442201a3, 0x7c221d7a, 0x6e3e00d2, 0x00000000}},  //   gik_, nior, hopb,
  { {0x394501c3, 0x6b9c01c5, 0x00000000, 0x00000000}},  //   _zyls_, _ērgl,   ,
  { {0x69d8000c, 0x245201dc, 0x7c220420, 0x00000000}},  //   ndve, váme_, hior,
  { {0x7c2b018e, 0x442201a3, 0x7c220d17, 0x00000000}},  //   yngr, bik_, kior,
  { {0x3ea905f7, 0x442201a3, 0x69ca01bf, 0x00000000}},  //   tuat_, cik_, hefe,
  { {0xdb1b009f, 0x7c220032, 0x69ca00ea, 0x00000000}},  // [4670] _nauð, dior, kefe,
  { {0x2bf90044, 0xdb07009d, 0x69d81e2f, 0x00000000}},  //   _আগেই_, _élég, jdve,
  { {0x69ca0129, 0x7c220197, 0xde4700a1, 0x00000000}},  //   defe, fior, _ہیرو_,
  { {0x7c220198, 0x3897001a, 0x69d80112, 0x00000000}},  //   gior, văr_, edve,
  { {0x3ea900d4, 0x7c2b06d3, 0xf42a00b0, 0x00000000}},  //   quat_, rngr, ltää_,
  { {0x44221e30, 0xdb1b000c, 0xd945005e, 0x00000000}},  //   zik_, _dauð, мели,
  { {0xf9900076, 0x44220047, 0x7c220036, 0x00000000}},  //   ابه_, yik_, bior,
  { {0x7c221e31, 0x2d93002d, 0x869900ed, 0x00000000}},  //   cior, laxe_, отот_,
  { {0x4422006c, 0x7bcb00e7, 0x69ca01a2, 0x00000000}},  //   vik_, megu, befe,
  { {0x49bb007a, 0x7bcb009f, 0x2d930061, 0x00000000}},  //   _دارد_, legu, naxe_,
  { {0x44220756, 0x38661e32, 0x69c104c6, 0x00000000}},  //   tik_, _fior_, _ible,
  { {0x7bcb04bd, 0xe8250014, 0xc209009b, 0x00000000}},  //   negu, _غذای, _דה_,
  { {0x44220756, 0x24800091, 0x15f50025, 0x00000000}},  //   rik_, _čime_, _يستح,
  { {0x7c221e33, 0x35fb007a, 0xd9f0007d, 0x00000000}},  //   zior, _درصد_, चायत_,
  { {0x69c10065, 0x442204cb, 0x7e7d0d90, 0x00000000}},  //   _mble, pik_, _atsp,
  { {0xdee60069, 0xd4360025, 0x7c220a49, 0x00000000}},  //   моби, _تعتب, xior,
  { {0x4420000d, 0x69c11e34, 0x6e3e1e35, 0x00000000}},  // [4680] _imi_, _oble, topb,
  { {0x44201e36, 0xdb1b000c, 0x9f590197, 0x00000000}},  //   _hmi_, _rauð, _mosè_,
  { {0x9b6a0175, 0xdd8f03ec, 0x442013b1, 0x00000000}},  //   ошла_, شون_, _kmi_,
  { {0xf7670025, 0x69c1010f, 0x7d0308e0, 0x00000000}},  //   _لا_, _able, ønsa,
  { {0x7c220d60, 0x44200515, 0x69ca01d6, 0x00000000}},  //   rior, _mmi_, tefe,
  { {0x7c2204f4, 0xe60700a2, 0x7e6700d9, 0x00000000}},  //   sior, _شش_, _gijp,
  { {0x69ca1e37, 0x69d81484, 0x38660181, 0x00000000}},  //   refe, rdve, _pior_,
  { {0x69c11e38, 0xc6f80793, 0x23aa0061, 0x00000000}},  //   _eble, зних_, _कागद,
  { {0x8b26008b, 0x9f590026, 0xf4140044, 0x00000000}},  //   _ўдзе, _cosè_, াচার_,
  { {0x44201e39, 0x44f401e0, 0xf42a00b0, 0x00000000}},  //   _ami_, епос, ytää_,
  { {0xf4be0055, 0x44200142, 0x3dd80016, 0x00000000}},  //   েম্ব, _bmi_, _marw_,
  { {0x442000c4, 0x69c1167a, 0x00000000, 0x00000000}},  //   _cmi_, _zble,   ,
  { {0x442010e4, 0x236d0059, 0x27f70161, 0x00000000}},  //   _dmi_, žejo_, žená_,
  { {0x34940057, 0xf42a021e, 0x4420010e, 0x00000000}},  //   _закр, ttää_, _emi_,
  { {0x4420001a, 0xd258007e, 0x7e6700bb, 0x00000000}},  //   _fmi_, ьцю_, _rijp,
  { {0x44de002b, 0xf42a00b0, 0x1fa40140, 0x00000000}},  //   _iċ_, rtää_, круг,
  { {0xf42a021e, 0x7bcb0a92, 0x7e6700b5, 0x00000000}},  // [4690] stää_, vegu, _pijp,
  { {0x9f590df9, 0x7bcb010f, 0x6d47009d, 0x00000000}},  //   _josé_, wegu, _pyja,
  { {0x7bcb1e3a, 0x997300b9, 0x6ac80044, 0x00000000}},  //   tegu, těži_, লিফো,
  { {0x4ea701fb, 0x6d4706b8, 0x3dcf0044, 0x00000000}},  //   _орга, _vyja, রাইল,
  { {0x7bcb1e3b, 0x8234007a, 0x6f160046, 0x00000000}},  //   regu, _سریا, czyc,
  { {0x7bcb0129, 0x9f5906c2, 0x3dd8005b, 0x00000000}},  //   segu, _nosé_, _garw_,
  { {0x7bcb0085, 0xa96601ee, 0x00000000, 0x00000000}},  //   pegu, ниша_,   ,
  { {0x2009010a, 0x76430058, 0x2d910032, 0x00000000}},  //   nkai_, _skny, _heze_,
  { {0x5a350437, 0x4420009d, 0x9f59004a, 0x00000000}},  //   _знат, _rmi_, _bosé_,
  { {0xe616007c, 0x64560009, 0x78ae0051, 0x00000000}},  //   едь_, _shyi, óivé,
  { {0x44200aa3, 0x20090687, 0x2d91013e, 0x00000000}},  //   _pmi_, kkai_, _meze_,
  { {0xafdb0030, 0x246c00b9, 0x44200c62, 0x00000000}},  //   _skøn, _němu_, _qmi_,
  { {0xe29703c8, 0xb3b1006e, 0xddc60655, 0x00000000}},  //   ная_, _झारख, _lukš,
  { {0xd25204e8, 0x00000000, 0x00000000, 0x00000000}},  //   انس_,   ,   ,
  { {0x76410010, 0x44200052, 0x00000000, 0x00000000}},  //   moly, _tmi_,   ,
  { {0x442001a3, 0x76410039, 0x251a0104, 0x00000000}},  //   _umi_, loly, _מוצא,
  { {0xddc6010a, 0xbea30256, 0xee0a00e2, 0x00000000}},  // [46a0] _aukš, латк, пеал_,
  { {0x6e4606b4, 0x76410232, 0x2cba0022, 0x00000000}},  //   رنام, noly, ttpd_,
  { {0x2d910662, 0x6f160046, 0xa3e50061, 0x00000000}},  //   _deze_, szyc, नाच_,
  { {0x61fe00ca, 0x207b0049, 0x601100ea, 0x00000000}},  //   _hopl, _מאטא, _påme,
  { {0xd12f007a, 0x76410039, 0x00000000, 0x00000000}},  //   _نمی_, koly,   ,
  { {0x61fe0253, 0x00000000, 0x00000000, 0x00000000}},  //   _jopl,   ,   ,
  { {0x76410016, 0x9f59009d, 0x00000000, 0x00000000}},  //   doly, _rosé_,   ,
  { {0x2fc01e3c, 0xd6d00025, 0x2d910023, 0x00000000}},  //   nfig_, لقب_, _zeze_,
  { {0x27fd0038, 0x87e3007c, 0x76410010, 0x00000000}},  //   _down_, ующе, foly,
  { {0xb9060044, 0x76411e3d, 0x61fe01c5, 0x00000000}},  //   _পথ_, goly, _nopl,
  { {0x545505f6, 0xe4e3007e, 0x3e76000c, 0x00000000}},  //   квот, гіян, _læt_,
  { {0x27fd103f, 0x38ba0065, 0x893700b3, 0x00000000}},  //   _gown_, mër_, _ארבע_,
  { {0x8c1b00b3, 0x3ebb0009, 0x645d0edb, 0x00000000}},  //   לוטי, xtqt_, rmsi,
  { {0x61fe0035, 0x69da002d, 0x24521db2, 0x00000000}},  //   _copl, _jate, ráma_,
  { {0x61fe004f, 0x2fc00016, 0xc0c8003b, 0x00000000}},  //   _dopl, ffig_, нуте_,
  { {0x69da05d0, 0x20090006, 0x657a0051, 0x00000000}},  //   _late, ukai_, lcth,
  { {0x4034007c, 0xfe730137, 0x2d9101aa, 0x00000000}},  // [46b0] уетс, ادر_, _peze_,
  { {0xe45f0039, 0x2fd9018e, 0x2009008f, 0x00000000}},  //   lmö_, _wasg_, skai_,
  { {0x2a7f011c, 0x463b0049, 0x2d910059, 0x00000000}},  //   _stub_, לעמע, _veze_,
  { {0x38ba0065, 0x2d210061, 0x249c0190, 0x00000000}},  //   dër_, _मधील_, _mvvm_,
  { {0x69da0756, 0x2d911053, 0x3f8904be, 0x00000000}},  //   _bate, _teze_, mbau_,
  { {0x3ea900ce, 0xddc60089, 0x38ba0023, 0x00000000}},  //   mrat_, _tukš, fër_,
  { {0x6b750a94, 0x69da03a1, 0x00000000, 0x00000000}},  //   _албу, _date,   ,
  { {0x3f89010f, 0x3ea900d4, 0x60d70050, 0x00000000}},  //   nbau_, orat_, _msxm,
  { {0x69da0016, 0x76411cbc, 0xf1b20204, 0x00000000}},  //   _fate, toly, _जालन,
  { {0xfbd0026c, 0x38ba0065, 0xe475007e, 0x00000000}},  //   _پتہ_, bër_, кумэ,
  { {0x27fd00ab, 0xa8020276, 0x7bdb00e0, 0x00000000}},  //   _town_, ğırm, _kauu,
  { {0x69da011f, 0x3ea901d9, 0xe29a0887, 0x00000000}},  //   _zate, krat_, мам_,
  { {0x61fe0387, 0x69da00e7, 0x7bdb011c, 0x00000000}},  //   _popl, _yate, _mauu,
  { {0x3ea904c7, 0x6d550026, 0xd25200a1, 0x00000000}},  //   drat_, _ozza, شنز_,
  { {0x27f400a1, 0x3e760f4b, 0x3f89010f, 0x00000000}},  //   _شہید_, _sæt_, fbau_,
  { {0x3ea900af, 0x7bdb011c, 0xa3b900e8, 0x00000000}},  //   frat_, _nauu, _चाय_,
  { {0x61fe011f, 0x6d551e3e, 0x1f660121, 0x00000000}},  // [46c0] _topl, _azza, ткам,
  { {0xee37019d, 0x628601d6, 0x9f590010, 0x00000000}},  //   вну_, mpko, _alsó_,
  { {0x69da00ab, 0xa3d60204, 0x3ea901a3, 0x00000000}},  //   _rate, _हसा_, arat_,
  { {0xdca301be, 0x3ea900b9, 0x3e760030, 0x00000000}},  //   раци, brat_, _tæt_,
  { {0x69da010a, 0x3ea9189d, 0x2f56007e, 0x00000000}},  //   _pate, crat_, _штос,
  { {0x38ba008d, 0x19580641, 0x69da0066, 0x00000000}},  //   tër_, налы_, _qate,
  { {0xc21300b6, 0x69da1582, 0x29071e3f, 0x00000000}},  //   שהו_, _vate, gyna_,
  { {0xc7c6007c, 0xf09300b6, 0x7d030039, 0x00000000}},  //   тски, בנה_, änse,
  { {0x38ba0065, 0x69da01a2, 0x15aa005e, 0x00000000}},  //   sër_, _tate, мъни_,
  { {0x38ba008d, 0x7bc20112, 0x35f401ee, 0x00000000}},  //   për_, lfou, упор,
  { {0x43950594, 0x2618006e, 0x7ae21e40, 0x00000000}},  //   ланс, योगी_, lvot,
  { {0x972300a1, 0x657a0051, 0x7bc20133, 0x00000000}},  //   افیو, scth, nfou,
  { {0x9f590198, 0x26d80089, 0x6d580161, 0x00000000}},  //   _così_, āros_, ývaj,
  { {0x3ea90161, 0x6594003b, 0x00000000, 0x00000000}},  //   vrat_, _саку,   ,
  { {0x628601c3, 0x3f8901a2, 0x00000000, 0x00000000}},  //   apko, tbau_,   ,
  { {0x3ea90314, 0xe3bf027b, 0xdcfc012d, 0x00000000}},  //   trat_, miño_, _nerđ,
  { {0x9f550d68, 0x3f8901a3, 0x3ea900d4, 0x00000000}},  // [46d0] увач, rbau_, urat_,
  { {0x3ea90129, 0x644f1460, 0x3f8912dc, 0x00000000}},  //   rrat_, llci, sbau_,
  { {0x629d03ed, 0x3ea91e41, 0x7bdb0058, 0x00000000}},  //   lsso, srat_, _pauu,
  { {0x3ea90065, 0x00000000, 0x00000000, 0x00000000}},  //   prat_,   ,   ,
  { {0x629d091a, 0x7e5502fd, 0x62520190, 0x00000000}},  //   nsso, _منحص, kæol,
  { {0xf2d40049, 0x629d0dd9, 0x201e0089, 0x00000000}},  //   שעס_, isso, ītie_,
  { {0x6d55012d, 0x9f40000c, 0xac190e82, 0x00000000}},  //   _uzza, ljið_, _зову_,
  { {0x315800b6, 0x629d03ed, 0xe3bf0e65, 0x00000000}},  //   כיון_, ksso, diño_,
  { {0xf9930426, 0x7ae20026, 0x98be007f, 0x00000000}},  //   _نبض_, cvot, _rytą_,
  { {0x629d04d3, 0xba550025, 0x32010161, 0x00000000}},  //   dsso, _صناع, _nohy_,
  { {0xdb0010cf, 0x629d00f8, 0x00000000, 0x00000000}},  //   _admè, esso,   ,
  { {0x629d03ed, 0x225a0023, 0x00000000, 0x00000000}},  //   fsso, _shpk_,   ,
  { {0x2bc5001c, 0xd90f026c, 0xafdb00ea, 0x00000000}},  //   ळ्या, _دیں_, _uhøy,
  { {0x644f016c, 0x9f5900d4, 0x00000000, 0x00000000}},  //   alci, _cosí_,   ,
  { {0x8fa6008b, 0xf65200b6, 0x629d00f8, 0x00000000}},  //   лаве, _הצג_, asso,
  { {0x629d074d, 0x27ef0022, 0x62861e42, 0x00000000}},  //   bsso, _jngn_, ppko,
  { {0x823600a2, 0x6446007f, 0x63a4011c, 0x00000000}},  // [46e0] _مردا, moki, _idin,
  { {0xdcfc016c, 0xa37b00c4, 0x7bc20133, 0x00000000}},  //   _serđ, rdõe, wfou,
  { {0x6446055e, 0x61fa0443, 0x7ae2004a, 0x00000000}},  //   ooki, ötlu, wvot,
  { {0x64461e43, 0xdb190036, 0x09bd0044, 0x00000000}},  //   noki, jewó, _আফগা,
  { {0x69c301a2, 0x63a413e1, 0x7bc2009d, 0x00000000}},  //   ffne, _mdin, rfou,
  { {0x69bf0164, 0x82d70049, 0x7bc2046a, 0x00000000}},  //   ल्ली, טונג_, sfou,
  { {0x2002008f, 0x64460205, 0x63a40a64, 0x00000000}},  //   _koki_, koki, _odin,
  { {0x63a40020, 0x20020089, 0x8c460153, 0x00000000}},  //   _ndin, _joki_, _себе,
  { {0x64460fec, 0xa614013b, 0x32180281, 0x00000000}},  //   doki, имич, khry_,
  { {0x63a4002d, 0x20021e44, 0xf48600ed, 0x00000000}},  //   _adin, _loki_, лумн,
  { {0x69c801f3, 0xdcfc0089, 0x13f51e45, 0x00000000}},  //   _ibde, _ierē, азня,
  { {0x64461e46, 0x629d03ed, 0xe3bf0ea1, 0x00000000}},  //   goki, tsso, riño_,
  { {0xe60f007a, 0x63a4018e, 0x2d9a01aa, 0x00000000}},  //   زشی_, _ddin, kape_,
  { {0x629d091a, 0xd576007c, 0x62840051, 0x00000000}},  //   rsso, _судь, _dtio,
  { {0x25dd001c, 0x628400ea, 0x20021547, 0x00000000}},  //   _कोटी_, _etio, _boki_,
  { {0x63a4016c, 0xb344006b, 0xb27500c0, 0x00000000}},  //   _gdin, zaçə, _клиш,
  { {0x442b1e47, 0x69c80059, 0xddab0c96, 0x00000000}},  // [46f0] mic_, _obde, етел_,
  { {0x68e81e48, 0xdb190036, 0x629b007f, 0x00000000}},  //   _ordd, zewó, šuos,
  { {0x5c070822, 0x63a4175c, 0xdcf50089, 0x00000000}},  //   ляда, _ydin, _iezī,
  { {0x69c81e49, 0x24b70049, 0x00000000, 0x00000000}},  //   _abde, רהאן_,   ,
  { {0xfaa7004c, 0x68e8018e, 0x3ec400b9, 0x00000000}},  //   ушен, _ardd, ěstí_,
  { {0xa2ad006e, 0x627c0049, 0x2d9a0498, 0x00000000}},  //   _जिन्, ענונ, cape_,
  { {0x442b0107, 0x6ce401fb, 0x5ce4007e, 0x00000000}},  //   kic_, _літе, _люта,
  { {0x442b003b, 0x69c80061, 0x64460288, 0x00000000}},  //   jic_, _ebde, xoki,
  { {0x442b001a, 0x64460006, 0x7c2b01cb, 0x00000000}},  //   dic_, voki, migr,
  { {0x7c2b0211, 0xe9d800a1, 0x7ae90d44, 0x00000000}},  //   ligr, _مذمت_, _iret,
  { {0x64461e4a, 0x442b0824, 0xa8a400e1, 0x00000000}},  //   toki, fic_, _грчк,
  { {0x7c2b049a, 0x0446003b, 0x442b03db, 0x00000000}},  //   nigr, ремн, gic_,
  { {0x64460a77, 0x20020059, 0xe356007e, 0x00000000}},  //   roki, _roki_, ртнэ,
  { {0x64461e4b, 0x00000000, 0x00000000, 0x00000000}},  //   soki,   ,   ,
  { {0x442b1e4c, 0x64461658, 0x00000000, 0x00000000}},  //   bic_, poki,   ,
  { {0x3075004c, 0x442b1547, 0x7c2b0209, 0x00000000}},  //   сурс, cic_, jigr,
  { {0xa0670265, 0x6d4e04d2, 0x5ea60025, 0x00000000}},  // [4700] рата_, _syba, شمال,
  { {0x6603021e, 0x7bc90146, 0x7c2b01c3, 0x00000000}},  //   _jonk, _abeu, eigr,
  { {0xeb9a1e4d, 0x2d9a0bbb, 0x7ae91635, 0x00000000}},  //   вие_, rape_, _aret,
  { {0x7ae91e4e, 0x6d4e004f, 0xa2ad006e, 0x00000000}},  //   _bret, _vyba, _जिम्,
  { {0x2459028c, 0x7ae90420, 0x60180010, 0x00000000}},  //   néma_, _cret, _címe,
  { {0x7ae91e4f, 0x1a8900a1, 0x66030022, 0x00000000}},  //   _dret, ائنٹ_, _nonk,
  { {0x8ccd006e, 0x7ae9065d, 0x24591e50, 0x00000000}},  //   _सहयो, _eret, héma_,
  { {0x2d981e51, 0x442b041d, 0x57f41e52, 0x00000000}},  //   _here_, xic_, спит,
  { {0x7ae90006, 0x2d981209, 0x442b0e81, 0x00000000}},  //   _gret, _kere_, vic_,
  { {0x9a6a031d, 0x2d9801aa, 0x3ea0089e, 0x00000000}},  //   _شمال_, _jere_, isit_,
  { {0x2d9805ec, 0x442b1e53, 0x660306b2, 0x00000000}},  //   _mere_, tic_, _donk,
  { {0x3ea01198, 0x2d981e54, 0x00000000, 0x00000000}},  //   ksit_, _lere_,   ,
  { {0x660304cd, 0x442b1e55, 0x00000000, 0x00000000}},  //   _fonk, ric_,   ,
  { {0x442b0038, 0x2d981e56, 0x7c2b04eb, 0x00000000}},  //   sic_, _nere_, zigr,
  { {0xe4530426, 0x3ea00065, 0x76480675, 0x00000000}},  //   _وضع_, esit_, mody,
  { {0x34fb01f8, 0x660300bb, 0x764814a6, 0x00000000}},  //   _יהוד, _zonk, lody,
  { {0x2d981e57, 0x442901d9, 0x66030173, 0x00000000}},  // [4710] _bere_, _ima_, _yonk,
  { {0x2733001d, 0x7ae9008d, 0x2d98001a, 0x00000000}},  //   ảng_, _rret, _cere_,
  { {0x7ae90363, 0x2d981e58, 0xd5b80089, 0x00000000}},  //   _sret, _dere_, igā_,
  { {0x7ae9049c, 0x37ac0044, 0x1b050044, 0x00000000}},  //   _pret, ক্তর, _শেষে_,
  { {0x3ea00047, 0xf1ec00e8, 0x3f990016, 0x00000000}},  //   csit_, _छोड़_, _iesu_,
  { {0x2ba7001d, 0x2d98185b, 0x7ae9001a, 0x00000000}},  //   ốc_, _gere_, _vret,
  { {0x44290cfc, 0xb7bd001a, 0x9f4b008e, 0x00000000}},  //   _oma_, liţi, _tocó_,
  { {0x0138019b, 0x2d810707, 0x44290058, 0x00000000}},  //   ירות_, lche_, _nma_,
  { {0x7ae9002d, 0x7c3b1e59, 0x2d98014a, 0x00000000}},  //   _uret, _ijur, _yere_,
  { {0x4429011f, 0x2d811e5a, 0x644d0020, 0x00000000}},  //   _ama_, nche_, _akai,
  { {0x2d811e5b, 0x44290544, 0x386f0087, 0x00000000}},  //   iche_, _bma_, _tigr_,
  { {0x44290007, 0xc20900a0, 0x3f990006, 0x00000000}},  //   _cma_, _אה_, _nesu_,
  { {0xa3b902fb, 0x76480019, 0xd7c80014, 0x00000000}},  //   _चार_, body, _خونه_,
  { {0x27ff002b, 0x661a054e, 0x644d022b, 0x00000000}},  //   ljun_, chtk, _ekai,
  { {0x2d981e5c, 0x3f99070c, 0x00000000, 0x00000000}},  //   _rere_, _besu_,   ,
  { {0x4429011c, 0x2d9801aa, 0x601800d6, 0x00000000}},  //   _gma_, _sere_, _símb,
  { {0x2d9801b9, 0xee3a026b, 0x3f9901c5, 0x00000000}},  // [4720] _pere_, гна_, _desu_,
  { {0x823600a2, 0x3ea00632, 0xc3330097, 0x00000000}},  //   _دربا, rsit_, _מוח_,
  { {0x4429018e, 0x2d980292, 0x3ea000b0, 0x00000000}},  //   _yma_, _vere_, ssit_,
  { {0x2d980038, 0x3f990afb, 0x3ea0001a, 0x00000000}},  //   _were_, _gesu_, psit_,
  { {0x7c3b0039, 0x2d981583, 0xcc880014, 0x00000000}},  //   _djur, _tere_, انچه_,
  { {0x2d810207, 0x2000016c, 0x00000000, 0x00000000}},  //   cche_, ljii_,   ,
  { {0x3f991e5d, 0x81cb0044, 0x7c3b002b, 0x00000000}},  //   _yesu_, _রোড_, _fjur,
  { {0x6c361847, 0x7c3b1e5e, 0x00000000, 0x00000000}},  //   _افرا, _gjur,   ,
  { {0xa3cb03d7, 0xe9a602be, 0x44290253, 0x00000000}},  //   र्फ_, _газп, _rma_,
  { {0x645f048a, 0x644d0a5c, 0x4429023a, 0x00000000}},  //   _shqi, _skai, _sma_,
  { {0x7648010a, 0xb7bd000d, 0x799a040f, 0x00000000}},  //   rody, ziţi, _ietw,
  { {0x6b82001b, 0xa2ad0316, 0x661a00e7, 0x00000000}},  //   ncog, _जिद्, shtk,
  { {0x44291e5f, 0x3f99025e, 0xdb0001dc, 0x00000000}},  //   _vma_, _resu_, _odmí,
  { {0x44290082, 0x799a1e60, 0x779202fd, 0x00000000}},  //   _wma_, _jetw, _بیکا,
  { {0x95830046, 0x6aa20022, 0x799a10e3, 0x00000000}},  //   łącz, hsof, _metw,
  { {0x44290fb3, 0xb7bd001a, 0x9055007e, 0x00000000}},  //   _uma_, tiţi, івац,
  { {0x4439098e, 0x6aa200bb, 0x6d5c0095, 0x00000000}},  // [4730] mns_, jsof, _azra,
  { {0x44391e61, 0x7c290027, 0x2d81101a, 0x00000000}},  //   lns_, _smer, uche_,
  { {0x4439062a, 0x2d811e62, 0x226400b9, 0x00000000}},  //   ons_, rche_, řské_,
  { {0x44390073, 0x2d8104e5, 0xafdb00ea, 0x00000000}},  //   nns_, sche_, _sjøf,
  { {0xa3cb02fb, 0x799a0038, 0x44391e63, 0x00000000}},  //   र्य_, _betw, ins_,
  { {0x79e700a1, 0xe29c0049, 0x44391e64, 0x00000000}},  //   صوبہ_, נשור, hns_,
  { {0xf8a9007a, 0x799a01aa, 0x6d4a006b, 0x00000000}},  //   شگاه_, _detw, üfat,
  { {0x7c291b5b, 0x6b820207, 0xa3cb007d, 0x00000000}},  //   _umer, ccog, र्म_,
  { {0xe61900aa, 0x27ff09f6, 0xd706007c, 0x00000000}},  //   иди_, rjun_, жные_,
  { {0xdce50180, 0xf62501fb, 0x799a0116, 0x00000000}},  //   lahı, ідно, _getw,
  { {0xbf9b009d, 0xdb1901a2, 0xafdb00ea, 0x00000000}},  //   _poêl, gewö, _gjøg,
  { {0xd7e40245, 0x799a01aa, 0x6b9b01b5, 0x00000000}},  //   _нічо, _zetw, _jeug,
  { {0x7c390675, 0x2fc900ea, 0x363400a1, 0x00000000}},  //   inwr, dfag_, _کرنس,
  { {0x44390541, 0x6b9b00bb, 0xca7a0097, 0x00000000}},  //   ans_, _leug, ינשט,
  { {0x7d030039, 0xaf9a142c, 0x6aa4002b, 0x00000000}},  //   änsl, итах_, ġifi,
  { {0x6b9b1e65, 0xdddc014a, 0xdfd2006d, 0x00000000}},  //   _neug, _birş, بير_,
  { {0x3e7f0035, 0x6aa200d2, 0x00000000, 0x00000000}},  // [4740] _cît_, xsof,   ,
  { {0x7e5601e1, 0x8d56005c, 0x00000000, 0x00000000}},  //   ітац, отеч,   ,
  { {0x6b9b0270, 0x6aa202d4, 0x799a060b, 0x00000000}},  //   _beug, wsof, _retw,
  { {0x799a0022, 0x6aa20052, 0x2743007f, 0x00000000}},  //   _setw, tsof, _kūną_,
  { {0x799a0173, 0x6b9b1e66, 0x6b8201c5, 0x00000000}},  //   _petw, _deug, rcog,
  { {0x6aa2001e, 0x13e30044, 0x48aa003b, 0x00000000}},  //   rsof, যায়, атим_,
  { {0xa3cb02d2, 0x6d5c0089, 0xdca601ee, 0x00000000}},  //   र्ड_, _uzra, _фаби,
  { {0x32c4014a, 0xafdb00ea, 0x799a0145, 0x00000000}},  //   köy_, _gjød, _wetw,
  { {0x44390030, 0xdcfc0006, 0x00000000, 0x00000000}},  //   vns_, _perė,   ,
  { {0x6b9b010f, 0x44391e67, 0xd6260025, 0x00000000}},  //   _zeug, wns_, تعبي,
  { {0xd7fa01ff, 0x7d7b009b, 0x69d80cfd, 0x00000000}},  //   _вул_, יניו, meve,
  { {0x69d81e68, 0xd7ef0054, 0x44391aff, 0x00000000}},  //   leve, _لكم_, uns_,
  { {0x78750006, 0xc2b80088, 0x69ca1e69, 0x00000000}},  //   _išva, оляє_, offe,
  { {0x69d80e69, 0x443901c5, 0x9f4001a2, 0x00000000}},  //   neve, sns_, weiß_,
  { {0xcf9b00e1, 0x6018000c, 0xdce5006b, 0x00000000}},  //   ија_, _síma, yahı,
  { {0x69d81dcd, 0x351b00a0, 0xdc3a0477, 0x00000000}},  //   heve, _כוונ, kçıs,
  { {0xa3cb0201, 0xd83801aa, 0x69d80292, 0x00000000}},  // [4750] र्ण_, _avčk_, keve,
  { {0x69d8016e, 0x63bd0006, 0x9f42000a, 0x00000000}},  //   jeve, lgsn, _makè_,
  { {0x69d80129, 0x6b9b048d, 0xa3cb0309, 0x00000000}},  //   deve, _peug, र्थ_,
  { {0x6018009f, 0x69ca02e7, 0x3eb215b3, 0x00000000}},  //   _tíma, effe, bryt_,
  { {0x7ccc0089, 0x9a871e6a, 0x3ffa009b, 0x00000000}},  //   vērš, цуел, _הפרע,
  { {0x69d802ae, 0x628f0009, 0xa3cb0309, 0x00000000}},  //   geve, ipco, र्त_,
  { {0x5ba700aa, 0x7e7d0190, 0xdcee002b, 0x00000000}},  //   _мраз, _husp, _rebħ,
  { {0x97d90088, 0x7e75002d, 0x00000000, 0x00000000}},  //   ську_, _hizp,   ,
  { {0x69d800b5, 0x2be00061, 0xb6a30082, 0x00000000}},  //   beve, _नसता, _giấ,
  { {0x69d81017, 0x80d20055, 0x61e50428, 0x00000000}},  //   ceve, হিত্, _nahl,
  { {0x7aeb001c, 0x7e7d070d, 0x7e750288, 0x00000000}},  //   lvgt, _lusp, _mizp,
  { {0x888300a1, 0x7e7d004a, 0x00000000, 0x00000000}},  //   _ٹیکن, _ousp,   ,
  { {0x7e7d1a72, 0x5ed30044, 0xb77a009b, 0x00000000}},  //   _nusp, সিডে, _האנש,
  { {0x61e500e5, 0xa1870ab6, 0x00000000, 0x00000000}},  //   _cahl, збра_,   ,
  { {0x7e7d010f, 0xe3b20025, 0xc5e10044, 0x00000000}},  //   _ausp, _كرة_, বাদপ,
  { {0x7e7d0190, 0x7e751e6b, 0xafdb0190, 0x00000000}},  //   _busp, _aizp, _skør,
  { {0x7e7d0051, 0xd0071662, 0x61e51e6c, 0x00000000}},  // [4760] _cusp, чете_, _fahl,
  { {0x6d550062, 0x0ea7007e, 0x9f4200b9, 0x00000000}},  //   _byza, якуй_, _jaké_,
  { {0xdcfc0089, 0x69d8068f, 0xb33b00c4, 0x00000000}},  //   _ierī, veve, maça,
  { {0x61e5001f, 0x69d80038, 0xb33b100d, 0x00000000}},  //   _zahl, weve, laça,
  { {0x69d800ab, 0x7e7d00f6, 0x37c30044, 0x00000000}},  //   teve, _gusp, ্যার,
  { {0x69ca05f2, 0xb33b1e6d, 0xceb4006b, 0x00000000}},  //   uffe, naça, mrə_,
  { {0x69d80378, 0x69ca018e, 0x7bd91955, 0x00000000}},  //   reve, rffe, bewu,
  { {0xa2ad04da, 0xebe301a4, 0x60110c72, 0x00000000}},  //   _जिल्, _посп, _påmi,
  { {0xc6f70147, 0x8c43005e, 0xba3d00b9, 0x00000000}},  //   зных_, _чете, _kvůl,
  { {0x69d80065, 0x69c10048, 0x6018004a, 0x00000000}},  //   qeve, _gcle, _oímo,
  { {0x9f4700b9, 0x61e50059, 0xb33b06c0, 0x00000000}},  //   ěné_, _rahl, daça,
  { {0x61e51e6e, 0x49170104, 0xd838012d, 0x00000000}},  //   _sahl, _מקבל_, _ovči_,
  { {0x61e5135f, 0xf3ff00c4, 0x00000000, 0x00000000}},  //   _pahl, smão_,   ,
  { {0x27e60a87, 0x7e7d1e6f, 0xdcfc0089, 0x00000000}},  //   _haon_, _rusp, _cerī,
  { {0x27e61d8b, 0xdcfc0089, 0x2b520036, 0x00000000}},  //   _kaon_, _derī, żych_,
  { {0x61e5010f, 0xd3db0025, 0x7e7d01a3, 0x00000000}},  //   _wahl, _طبعا_, _pusp,
  { {0x644f049a, 0x63ad01aa, 0x02a4007e, 0x00000000}},  // [4770] moci, _idan, _прэм,
  { {0x628d1e70, 0xb33b00c4, 0x27e60068, 0x00000000}},  //   _itao, caça, _laon_,
  { {0x63ad0085, 0x00000000, 0x00000000, 0x00000000}},  //   _kdan,   ,   ,
  { {0x644f0219, 0x79880116, 0x00000000, 0x00000000}},  //   noci, _afdw,   ,
  { {0x7e7d0103, 0x63ad0258, 0x9f4b00fa, 0x00000000}},  //   _uusp, _mdan, _cocô_,
  { {0x2d850004, 0x200b0142, 0x660a0023, 0x00000000}},  //   _üle_, _hoci_, _nofk,
  { {0xa3dd02d2, 0x08d4008b, 0x27e60058, 0x00000000}},  //   ड़ा_, ецыя, _baon_,
  { {0x63ad000b, 0xd0f8009b, 0x200b0035, 0x00000000}},  //   _ndan, למות_, _joci_,
  { {0x644f00b4, 0x27e60a49, 0x660a00d9, 0x00000000}},  //   doci, _daon_, _bofk,
  { {0x63ad0c2c, 0xa3cb02d2, 0x7b740025, 0x00000000}},  //   _adan, र्स_, _أطفا,
  { {0x04460805, 0x644f00d4, 0x64471ae3, 0x00000000}},  //   денн, foci, čkin,
  { {0x644f0219, 0x200b040d, 0x60180010, 0x00000000}},  //   goci, _noci_, _címl,
  { {0x9f4201c8, 0x0cba03d7, 0xe2970783, 0x00000000}},  //   _také_, _उम्म, мая_,
  { {0x628d0051, 0x63ad002d, 0x2bff0061, 0x00000000}},  //   _dtao, _edan, ळाडू_,
  { {0xb33b0a0a, 0x6b891e71, 0x644f0036, 0x00000000}},  //   raça, _ofeg, boci,
  { {0x644f008e, 0x63ad1e72, 0xdb1b004a, 0x00000000}},  //   coci, _gdan, _acuí,
  { {0x200b0091, 0x6da6003b, 0xb33b1e73, 0x00000000}},  // [4780] _doci_, диза, paça,
  { {0x6b8904bd, 0x63ad0832, 0x9f49000c, 0x00000000}},  //   _afeg, _zdan, rjað_,
  { {0xa3cb0316, 0x614600d7, 0x200b0010, 0x00000000}},  //   र्व_, _цена, _foci_,
  { {0x387e0022, 0x44220f02, 0x00000000, 0x00000000}},  //   _rutr_, nhk_,   ,
  { {0x27e60051, 0x7bc61e74, 0x0a6a007c, 0x00000000}},  //   _raon_, _ökum, орки_,
  { {0x2bae001d, 0x09e3012b, 0x2a650082, 0x00000000}},  //   ộc_, вољн, _chlb_,
  { {0x644f004a, 0x00000000, 0x00000000, 0x00000000}},  //   yoci,   ,   ,
  { {0x2fc00c7a, 0xb8d601f5, 0x00000000, 0x00000000}},  //   ngig_, _जि_,   ,
  { {0x644f037e, 0x19c600ed, 0x7c221625, 0x00000000}},  //   voci, _обам, mhor,
  { {0x7c2202d5, 0xb9930025, 0x63ad0022, 0x00000000}},  //   lhor, _للكب, _sdan,
  { {0xf9c7089d, 0x27e6006a, 0x628d1e75, 0x00000000}},  //   _تحقی, _taon_, _stao,
  { {0x7c220181, 0x00000000, 0x00000000, 0x00000000}},  //   nhor,   ,   ,
  { {0xa3cb006e, 0x3866012d, 0x60180010, 0x00000000}},  //   र्ष_, _ihor_, _címm,
  { {0x200b01e8, 0x9f590051, 0x32180007, 0x00000000}},  //   _soci_, _tosú_, gkry_,
  { {0x644f05e1, 0xdfd50a78, 0xdb000030, 0x00000000}},  //   poci, новы, _udmæ,
  { {0xa3cb0316, 0x63ad01a3, 0xe3d00011, 0x00000000}},  //   र्श_, _udan, _hằng_,
  { {0x200b1e76, 0x7c220065, 0x628d0020, 0x00000000}},  // [4790] _voci_, dhor, _utao,
  { {0x78650181, 0x6b890026, 0x7c220203, 0x00000000}},  //   móve, _sfeg, ehor,
  { {0x2919005f, 0x6aa9000c, 0x7c84003b, 0x00000000}},  //   _əsas_, _svef, вуче,
  { {0x7c220016, 0xe0d20049, 0xdea101b2, 0x00000000}},  //   ghor, _גײט_, _میری,
  { {0x2444005a, 0x1dc7013d, 0x3f890022, 0x00000000}},  //   nıma_, _लापत, mcau_,
  { {0x3ea908a8, 0x00000000, 0x00000000, 0x00000000}},  //   msat_,   ,   ,
  { {0x3ea91e77, 0x8bc70900, 0x00000000, 0x00000000}},  //   lsat_, _осад,   ,
  { {0x38660e93, 0x7c221e78, 0x3f8904aa, 0x00000000}},  //   _chor_, chor, ncau_,
  { {0xe3d0001d, 0x3ea91825, 0x3b5401e0, 0x00000000}},  //   _bằng_, nsat_, _актр,
  { {0xe3b202fd, 0x2444013f, 0x00000000, 0x00000000}},  //   گرد_, dıma_,   ,
  { {0x44220146, 0xb33b009d, 0x00000000, 0x00000000}},  //   thk_, faço,   ,
  { {0xccf2007b, 0x3ea90110, 0x765a1e79, 0x00000000}},  //   אכט_, ksat_, alty,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x386d02e1, 0x3ea90030, 0x44220065, 0x00000000}},  //   lmer_, dsat_, shk_,
  { {0x25a51446, 0x361a0097, 0x32180007, 0x00000000}},  //   mall_, _מוסד, rkry_,
  { {0xd0071e6a, 0xafe3003b, 0x386d1e7a, 0x00000000}},  //   несе_, лосл, nmer_,
  { {0x4420000b, 0x9f420263, 0x63a6096f, 0x00000000}},  // [47a0] _ili_, _ankò_, makn,
  { {0x386d010f, 0xa3c00309, 0x25a50048, 0x00000000}},  //   hmer_, ुभव_, nall_,
  { {0x44e1010a, 0x7c220038, 0x319b034e, 0x00000000}},  //   _jų_, thor, _מבינ,
  { {0xf7670380, 0xc5f80089, 0x386d0095, 0x00000000}},  //   _ما_, nmēr_, jmer_,
  { {0x7c2209f6, 0xa3b8013d, 0x386d0678, 0x00000000}},  //   rhor, _चयन_, dmer_,
  { {0x7c220ac7, 0xc333061e, 0x63a60169, 0x00000000}},  //   shor, נוג_, hakn,
  { {0x44200368, 0xeb9a01f9, 0xe3d0001d, 0x00000000}},  //   _oli_, _нив_, _rằng_,
  { {0xc6f819f1, 0x6444016c, 0x386d00eb, 0x00000000}},  //   дних_, _njii, gmer_,
  { {0x25a50002, 0x63a610ed, 0x09bf0044, 0x00000000}},  //   fall_, dakn, _ইসরা,
  { {0x442017fd, 0xceb300b6, 0x443201a3, 0x00000000}},  //   _ali_, נית_, _amy_,
  { {0x439502be, 0x4420067e, 0x60180010, 0x00000000}},  //   канс, _bli_, _címk,
  { {0x7bc2009d, 0x63a6008a, 0x44320554, 0x00000000}},  //   ngou, gakn, _cmy_,
  { {0x25a504bd, 0xe298008b, 0xb33b1b9e, 0x00000000}},  //   ball_, наў_, raço,
  { {0x4420021e, 0x171b007b, 0x7af600b0, 0x00000000}},  //   _eli_, _צוגע, äyty,
  { {0x9f470224, 0xb33b153d, 0x506700ed, 0x00000000}},  //   ění_, paço, етаа,
  { {0x442005d3, 0x3ea900f8, 0x00000000, 0x00000000}},  //   _gli_, tsat_,   ,
  { {0x50640269, 0x5fe20204, 0x3f891e7b, 0x00000000}},  // [47b0] утра, _पसरल, rcau_,
  { {0x645d0065, 0x6ca70106, 0x3ea9014a, 0x00000000}},  //   llsi, ердж, rsat_,
  { {0x09bf0055, 0x3ea904bd, 0x4420021e, 0x00000000}},  //   _ইসলা, ssat_, _yli_,
  { {0x2eed0107, 0x3ea900b9, 0xdb1b008e, 0x00000000}},  //   _šefu_, psat_, _acuá,
  { {0x645d0051, 0x25a50009, 0x00000000, 0x00000000}},  //   ilsi, yall_,   ,
  { {0xdc13027d, 0xdb000065, 0xf2d40049, 0x00000000}},  //   rşıs, _zemë, רעס_,
  { {0x25a51cde, 0x63a610ed, 0x6d42001a, 0x00000000}},  //   vall_, yakn, şoar,
  { {0x200908b3, 0x386d0146, 0x00000000, 0x00000000}},  //   njai_, umer_,   ,
  { {0x25a50292, 0x3a7505f6, 0x63a60039, 0x00000000}},  //   tall_, _алар, vakn,
  { {0x386d1c95, 0x645d037f, 0x644400d9, 0x00000000}},  //   smer_, elsi, _sjii,
  { {0x442001aa, 0x63a6016e, 0x25a5192b, 0x00000000}},  //   _pli_, takn, rall_,
  { {0x25a50203, 0x66b5091b, 0xe7870b21, 0x00000000}},  //   sall_, _абду, _чужо,
  { {0xe3b801f6, 0x27ed014a, 0x63a613ef, 0x00000000}},  //   ğı_, mden_, rakn,
  { {0xe3b80279, 0x27ed1e7c, 0x44e10006, 0x00000000}},  //   şı_, lden_, _tų_,
  { {0x69c31e7d, 0x44200066, 0x2056005e, 0x00000000}},  //   igne, _tli_, втар,
  { {0x27ed1e7e, 0x78480224, 0x4420011c, 0x00000000}},  //   nden_, pěve, _uli_,
  { {0x27ed021e, 0x26cd008e, 0x63a40e3f, 0x00000000}},  // [47c0] iden_, nteo_, _iein,
  { {0x63a40e53, 0x27ed021e, 0x764102e1, 0x00000000}},  //   _hein, hden_, nnly,
  { {0x63a4001f, 0x6018029a, 0xdb000065, 0x00000000}},  //   _kein, _lími, _temë,
  { {0x27ed02ae, 0x61ee123c, 0x69c40061, 0x00000000}},  //   jden_, ldbl, _राही,
  { {0x63a40109, 0x27ed1e7f, 0xa3d40201, 0x00000000}},  //   _mein, dden_, स्य_,
  { {0xbda505d4, 0x61ee0210, 0x27ed1e80, 0x00000000}},  //   _محفو, ndbl, eden_,
  { {0x7d030073, 0x27ed00bb, 0x885800e2, 0x00000000}},  //   änst, fden_, никс_,
  { {0x63a41e81, 0x6b850054, 0x27ed13ea, 0x00000000}},  //   _nein, _مشكل, gden_,
  { {0x7e7c0ecb, 0x6d5c1e82, 0x661a012d, 0x00000000}},  //   _kirp, _hyra, tktk,
  { {0x4b550265, 0x27ed0e9e, 0xdb001e83, 0x00000000}},  //   _съст, aden_, _remè,
  { {0x63a40953, 0x24e3008b, 0xdb0001aa, 0x00000000}},  //   _bein, ацяг, _semè,
  { {0x61fe0263, 0x63a41e84, 0x6d5c02e1, 0x00000000}},  //   _anpl, _cein, _myra,
  { {0x63a4001f, 0x59c90164, 0x6d5c0203, 0x00000000}},  //   _dein, _रामर, _lyra,
  { {0x752d00b9, 0xe717009b, 0x24590161, 0x00000000}},  //   _řaze, _בחדר_, vému_,
  { {0x63a40d72, 0xdb0000d4, 0x2fd20016, 0x00000000}},  //   _fein, _demé, ffyg_,
  { {0x63a400b5, 0x61fe1635, 0x7e7c00ab, 0x00000000}},  //   _gein, _enpl, _airp,
  { {0x4439010a, 0x62840919, 0x7e7c0032, 0x00000000}},  // [47d0] mis_, _guio, _birp,
  { {0x27ed011f, 0x63a4002d, 0x6d5c0145, 0x00000000}},  //   zden_, _zein, _byra,
  { {0x6b8b001c, 0x27ed0943, 0x7e7c0016, 0x00000000}},  //   tcgg, yden_, _dirp,
  { {0x44391750, 0xc4d3007b, 0x6d5c0039, 0x00000000}},  //   nis_, יגע_, _dyra,
  { {0x4439129a, 0x7e7c0555, 0x6d5c000c, 0x00000000}},  //   iis_, _firp, _eyra,
  { {0x27ed02c2, 0xa969003b, 0xdd94007e, 0x00000000}},  //   wden_, нила_, _вары,
  { {0x44391b18, 0x69c31e85, 0x6d5c0675, 0x00000000}},  //   kis_, rgne, _gyra,
  { {0x27ed0dcd, 0x44391e86, 0x317c00b6, 0x00000000}},  //   uden_, jis_, ורומ,
  { {0x27ed15a6, 0x9f4200c4, 0x6d5c0065, 0x00000000}},  //   rden_, _kaká_, _zyra,
  { {0x63a40109, 0xf9930151, 0x27ed010f, 0x00000000}},  //   _sein, _ضبط_, sden_,
  { {0x44391987, 0xf992012f, 0x63a400f4, 0x00000000}},  //   fis_, _הרב_, _pein,
  { {0x6018000c, 0x00000000, 0x00000000, 0x00000000}},  //   _tími,   ,   ,
  { {0x8c1a00b6, 0x62841a34, 0x63bb000c, 0x00000000}},  //   גורי, _quio, óuna,
  { {0x63a4014f, 0x44391049, 0x7ae90020, 0x00000000}},  //   _wein, ais_, _mset,
  { {0x443904be, 0x63a40004, 0x412a0e75, 0x00000000}},  //   bis_, _tein, хово_,
  { {0x44391e87, 0xd5cf001c, 0x7ae9003b, 0x00000000}},  //   cis_, त्रज, _oset,
  { {0x2d9601ee, 0x6d5c0aa4, 0x00000000, 0x00000000}},  // [47e0] грес, _syra,   ,
  { {0x6d5c0142, 0x61fe0133, 0xee37003b, 0x00000000}},  //   _pyra, _unpl, гну_,
  { {0xa3cb0164, 0x7ae9021e, 0x27330011, 0x00000000}},  //   र्क_, _aset, ảnh_,
  { {0x6d5c1e88, 0xc1780006, 0x201e0089, 0x00000000}},  //   _vyra, žės_, ītis_,
  { {0x6d5c0036, 0x1b170044, 0x7e7c0006, 0x00000000}},  //   _wyra, _দেবে_, _tirp,
  { {0xa3d402f4, 0x6447016c, 0xb8850142, 0x00000000}},  //   स्त_, čkii, zlíš,
  { {0x7ae90047, 0x44391566, 0x98a3003b, 0x00000000}},  //   _eset, yis_, бије,
  { {0x4439010f, 0x7981018e, 0xb81400ec, 0x00000000}},  //   xis_, _eglw, рдиј,
  { {0x44391e89, 0xdd3a00e5, 0x00000000, 0x00000000}},  //   vis_, _făţa,   ,
  { {0x4439018e, 0x68ed0036, 0xdb231430, 0x00000000}},  //   wis_, łada, _órái,
  { {0x4439010a, 0x97c6023c, 0xdb090d7a, 0x00000000}},  //   tis_, _مقاو, _ideá,
  { {0x443908ea, 0x661d0023, 0x00000000, 0x00000000}},  //   uis_, ëskr,   ,
  { {0xa3cb007d, 0x00000000, 0x00000000, 0x00000000}},  //   र्ग_,   ,   ,
  { {0x65940783, 0xf773009b, 0x00000000, 0x00000000}},  //   _таку, _פקס_,   ,
  { {0xa159003b, 0x66710014, 0x00000000, 0x00000000}},  //   таву_, _بگير,   ,
  { {0x44390023, 0x9f4b004a, 0x00000000, 0x00000000}},  //   qis_, _hacé_,   ,
  { {0x9f5900f6, 0x1e35007e, 0x00000000, 0x00000000}},  // [47f0] _rosó_, анаў,   ,
  { {0xafdb00ea, 0x7ae90022, 0x23690173, 0x00000000}},  //   _kjøk, _rset, _izaj_,
  { {0x7ae90066, 0x9f59004a, 0xa8070095, 0x00000000}},  //   _sset, _posó_, ngıç,
  { {0xf41f00b0, 0xac740014, 0x1dc70061, 0x00000000}},  //   nkä_, مانش, _लावत,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3cc007d, 0x48b51192, 0x9f49102e, 0x00000000}},  //   _लाभ_, ащит, ndaí_,
  { {0x6d430051, 0xf41f0052, 0x00000000, 0x00000000}},  //   únad, kkä_,   ,
  { {0xc8880025, 0xb8cd006e, 0xa8020279, 0x00000000}},  //   دخول_, _कब_, şınm,
  { {0xf745004c, 0x78a40091, 0x2a7e0022, 0x00000000}},  //   репо, ćiva, _fitb_,
  { {0xe61601ab, 0x00000000, 0x00000000, 0x00000000}},  //   иды_,   ,   ,
  { {0x998406ea, 0x64a51e8a, 0xa446004d, 0x00000000}},  //   _المو, јама, инод,
  { {0xf77004e1, 0xdcfc002b, 0x7bc6000c, 0x00000000}},  //   _کام_, _jerġ, _ökut,
  { {0x2bd70365, 0x72c30930, 0x32130471, 0x00000000}},  //   ण्या, обяз, _boxy_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x463a007b, 0x505a01ab, 0x00000000, 0x00000000}},  //   _בעסע, вшая_,   ,
  { {0xdb0b000c, 0xd3ba007e, 0x09af0044, 0x00000000}},  //   yggð, _рукі_, চ্চা,

  { {0xe5a30011, 0x27ef000c, 0x321304d2, 0x00000000}},  // [4800] _điệ, _magn_, _foxy_,
  { {0x2eeb0203, 0xbda50025, 0x9f590026, 0x00000000}},  //   _dscf_, محمو, _posò_,
  { {0xdddd001a, 0xdcfc01f3, 0x91bb009b, 0x00000000}},  //   _susţ, _berġ, _במיי,
  { {0xf1d201f5, 0x60de00e7, 0x2a7e0009, 0x00000000}},  //   द्रन, _ippm, _sitb_,
  { {0xa3cb02d2, 0x64460dde, 0xe809006e, 0x00000000}},  //   र्ट_, inki, वाना_,
  { {0xca56003b, 0x7c96005e, 0x3ceb00b0, 0x00000000}},  //   штењ, _врац, äivä_,
  { {0x2b4d001c, 0x68ed0036, 0x2c67006c, 0x00000000}},  //   _exec_, ładn, sõda_,
  { {0xf093009b, 0x6018000c, 0x22580288, 0x00000000}},  //   חנה_, _tímu, hork_,
  { {0x25a70061, 0x60de0022, 0xafdb00ea, 0x00000000}},  //   _benl_, _lppm, _sjøk,
  { {0x7afd000c, 0x225801ee, 0x644600b0, 0x00000000}},  //   _ásta, jork_, enki,
  { {0xf41f00b0, 0x77ca007e, 0x00000000, 0x00000000}},  //   tkä_, _алег_,   ,
  { {0x38600051, 0x27ef1e8b, 0x00000000, 0x00000000}},  //   _óir_, _gagn_,   ,
  { {0xe6940025, 0x63b60016, 0x69cd0061, 0x00000000}},  //   _التد, _ddyn, _सामी,
  { {0x200214fe, 0xa3cb0316, 0x27e41e8c, 0x00000000}},  //   _anki_, र्ज_, lemn_,
  { {0x26c40006, 0x9f490051, 0x6296042a, 0x00000000}},  //   lumo_, rdaí_, _etyo,
  { {0xcf98012b, 0x02a70057, 0x63b60036, 0x00000000}},  //   ију_, _кром, _gdyn,
  { {0xf7730049, 0xe4d800a1, 0x26c40006, 0x00000000}},  // [4810] ַקע_, _شوکت_, numo_,
  { {0x225800f6, 0x6018000c, 0x20021e8d, 0x00000000}},  //   cork_, _símt, _enki_,
  { {0x63b60016, 0xa3d40164, 0x00000000, 0x00000000}},  //   _ydyn, स्व_,   ,
  { {0xa3cb0164, 0x69da010f, 0xccf8003b, 0x00000000}},  //   र्च_, _abte, шћу_,
  { {0x2ef4008b, 0xe21400d3, 0x784800b9, 0x00000000}},  //   _дзяр, _طبیع, těvn,
  { {0x9ce700a1, 0xa802005a, 0xafdb00ea, 0x00000000}},  //   _پورے_, şılm, _sjøh,
  { {0x601800b9, 0x2b8d0051, 0xdcfc002b, 0x00000000}},  //   _tímt, _cócó_, _terġ,
  { {0x9f950004, 0x26c41c5e, 0x68ed0036, 0x00000000}},  //   _nüüd_, fumo_, łado,
  { {0x26c40006, 0x27ef1e8e, 0x2258004a, 0x00000000}},  //   gumo_, _vagn_, york_,
  { {0x7afb002d, 0x2480006c, 0x06090152, 0x00000000}},  //   _irut, _siim_, унок_,
  { {0xedf90044, 0x24960014, 0x2480010e, 0x00000000}},  //   _আকাশ_, ینید_, _piim_,
  { {0xe29a03e0, 0x225800ab, 0x2e24000c, 0x00000000}},  //   лам_, work_, _nöfn_,
  { {0x225807f9, 0x00000000, 0x00000000, 0x00000000}},  //   tork_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x01660888, 0x444700a1, 0x14db0061, 0x00000000}},  //   скво, _گروہ, _बहिण,
  { {0xdfd20380, 0x442b00f6, 0xa3ba083e, 0x00000000}},  //   ثير_, chc_, _صابر_,
  { {0xa06700e3, 0x92b60b03, 0xc4480014, 0x00000000}},  // [4820] сата_, _احبا, _میگن_,
  { {0xe8090204, 0xdcfc0089, 0x60180010, 0x00000000}},  //   वाडा_, _agrā, _címr,
  { {0xa63a007b, 0x7afb006c, 0x60de0039, 0x00000000}},  //   נגער, _arut, _uppm,
  { {0x7afb09c8, 0xd00a017f, 0x00000000, 0x00000000}},  //   _brut, _семе_,   ,
  { {0x7afb002a, 0xdb000325, 0xdb0b009d, 0x00000000}},  //   _crut, _temí, nagè,
  { {0xed5a012b, 0x6d43002a, 0x291c0006, 0x00000000}},  //   _бог_, únac, tyva_,
  { {0x442201a3, 0x6da30478, 0x7afb010e, 0x00000000}},  //   kkk_, _хиса, _erut,
  { {0x7afb0a15, 0x26c40006, 0x69cd0204, 0x00000000}},  //   _frut, tumo_, _साथी,
  { {0xfaa30887, 0x7afb1e8f, 0x00000000, 0x00000000}},  //   _нато, _grut,   ,
  { {0x26c4010a, 0xba23025f, 0x20f81e90, 0x00000000}},  //   rumo_, _едук, _oči_,
  { {0x26c40181, 0x8afd00b9, 0xba3d00b9, 0x00000000}},  //   sumo_, _vyře, _tvůr,
  { {0x69d80007, 0x00000000, 0x00000000, 0x00000000}},  //   lfve,   ,   ,
  { {0xcc3b007b, 0xb8570025, 0x25080014, 0x00000000}},  //   רעכט, _النص_, _چربی_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x463b007b, 0x2444006b, 0x765a0a3d, 0x00000000}},  //   _געגע, zımi_, moty,
  { {0x44220145, 0x7c2200b4, 0x00000000, 0x00000000}},  //   ckk_, jkor,   ,
  { {0x4429000b, 0x7c220059, 0x63af0036, 0x00000000}},  // [4830] _ila_, dkor, macn,
  { {0x629d1e91, 0x765a0133, 0x3e6f006c, 0x00000000}},  //   mpso, noty, küte_,
  { {0x44290007, 0x7afb0051, 0x443b0026, 0x00000000}},  //   _kla_, _srut, _kmq_,
  { {0x63af037e, 0x7afb011c, 0x442900ca, 0x00000000}},  //   nacn, _prut, _jla_,
  { {0xd90f00d3, 0x5ba8008b, 0x6e950242, 0x00000000}},  //   کیا_, скім_, _фигу,
  { {0x6e9401e0, 0x442900b0, 0xe9d8007e, 0x00000000}},  //   _хиру, _lla_, йкі_,
  { {0x44291e92, 0x1b170055, 0x44221e93, 0x00000000}},  //   _ola_, _দেশে_, ykk_,
  { {0x7c220039, 0xe739007c, 0x1bd4005e, 0x00000000}},  //   ckor, ией_, _нося,
  { {0x7afb0169, 0x7c29014a, 0x63af0107, 0x00000000}},  //   _urut, _iler, dacn,
  { {0xc8ab0265, 0x765a0dbf, 0x9f4b008e, 0x00000000}},  //   _бъде_, goty, _nací_,
  { {0x4429002b, 0xf3e601be, 0x7c291e94, 0x00000000}},  //   _bla_, ожно, _kler,
  { {0x7bcb020c, 0xc20900b6, 0x443b0207, 0x00000000}},  //   nggu, _בה_, _cmq_,
  { {0x44290df0, 0x61e70010, 0x44220943, 0x00000000}},  //   _dla_, fejl, rkk_,
  { {0x442902d5, 0x7c290b32, 0xdb0b00f4, 0x00000000}},  //   _ela_, _ller, gagé,
  { {0x7c29002d, 0x25ee0061, 0x60c7016c, 0x00000000}},  //   _oler, _असती_, gujm,
  { {0x41db0061, 0xff260131, 0x00000000, 0x00000000}},  //   म्बस, омбо,   ,
  { {0xf99f0011, 0xfe05013d, 0x7c220056, 0x00000000}},  // [4840] _đèn_, रांस_, vkor,
  { {0xdb000428, 0x7c3b0032, 0x26c20091, 0x00000000}},  //   _nemá, _amur, škog_,
  { {0x7c291e95, 0x4177025a, 0x20f80825, 0x00000000}},  //   _bler, _واپس, _uči_,
  { {0xab660a27, 0x228f0279, 0x656301d6, 0x00000000}},  //   овел, _yük_, _mynh,
  { {0x7c220039, 0x65631e96, 0x3ce60142, 0x00000000}},  //   rkor, _lynh, ňov_,
  { {0xceb4006b, 0x7c29060a, 0x00000000, 0x00000000}},  //   msə_, _eler,   ,
  { {0x7c29044f, 0x082a0d03, 0xdb000211, 0x00000000}},  //   _fler, иции_, _demá,
  { {0xd6da00aa, 0xdb000129, 0x7c29000c, 0x00000000}},  //   ато_, _temà, _gler,
  { {0x6996005e, 0xceb4006b, 0x00000000, 0x00000000}},  //   _дрех, nsə_,   ,
  { {0x442900bb, 0x7c3b012d, 0x19c30088, 0x00000000}},  //   _sla_, _zmur, _обум,
  { {0x442904bd, 0x6563018e, 0x61e70030, 0x00000000}},  //   _pla_, _cynh, vejl,
  { {0xceb4013f, 0x00000000, 0x00000000, 0x00000000}},  //   ksə_,   ,   ,
  { {0x2813031d, 0xdb0900d9, 0x00000000, 0x00000000}},  //   _تونس, _reeë,   ,
  { {0xe5340783, 0x4429011c, 0x601800d4, 0x00000000}},  //   _нель, _wla_, _símp,
  { {0x6563018e, 0x44290059, 0x63af0ed9, 0x00000000}},  //   _gynh, _tla_, pacn,
  { {0x60c7003b, 0x36340014, 0x6f0d0129, 0x00000000}},  //   rujm, _برچس, txac,
  { {0x645d09cf, 0x628f0009, 0x2328003b, 0x00000000}},  // [4850] mosi, qqco, _моћи_,
  { {0x645d000d, 0x7c3b0006, 0xdd9b0088, 0x00000000}},  //   losi, _smur, рша_,
  { {0x63ad0169, 0x69c4007d, 0x12780025, 0x00000000}},  //   _kean, _राजी, _بحيث_,
  { {0x645d0091, 0x515a009b, 0xdb000b33, 0x00000000}},  //   nosi, _לכתו, _semá,
  { {0x7c291e97, 0xfaa50265, 0x63ad0038, 0x00000000}},  //   _vler, чало, _mean,
  { {0x645d018e, 0x7e79007b, 0x628500b9, 0x00000000}},  //   hosi, _לאָז, _jiho,
  { {0x645d00b0, 0xa3cc007d, 0x201900ca, 0x00000000}},  //   kosi, _लाल_, _kosi_,
  { {0x1bb8004b, 0x7c3b0061, 0x63ad0207, 0x00000000}},  //   _واقع_, _umur, _nean,
  { {0x645d10d9, 0xdb000489, 0xd706007c, 0x00000000}},  //   dosi, _temá, зные_,
  { {0x80e10055, 0xdb000030, 0x628501ed, 0x00000000}},  //   _পছন্, _bemæ, _niho,
  { {0x63ad05c6, 0x6fcb0061, 0x1ddd0309, 0x00000000}},  //   _bean, िलां, न्यत,
  { {0x63ad002a, 0x645d04be, 0x20190091, 0x00000000}},  //   _cean, gosi, _nosi_,
  { {0x63ad1e98, 0x62851e99, 0x050b0044, 0x00000000}},  //   _dean, _biho, শনের_,
  { {0x1dc7001c, 0xf675007b, 0xf77004e8, 0x00000000}},  //   _लागत, _צײַט_, _شان_,
  { {0x7641006a, 0x20190020, 0x645d01c5, 0x00000000}},  //   mily, _bosi_, bosi,
  { {0xa3ad03d7, 0x20190207, 0x6b890093, 0x00000000}},  //   गरण_, _cosi_, _ngeg,
  { {0x20191e9a, 0x1b200044, 0x6285002b, 0x00000000}},  // [4860] _dosi_, _মেনে_, _fiho,
  { {0xceb4006b, 0x99c60044, 0x63ad0032, 0x00000000}},  //   rsə_, _এস্ক, _zean,
  { {0xceb4006b, 0x20190066, 0x00000000, 0x00000000}},  //   ssə_, _fosi_,   ,
  { {0x6285002d, 0x00000000, 0x00000000, 0x00000000}},  //   _ziho,   ,   ,
  { {0x76411e9b, 0x00000000, 0x00000000, 0x00000000}},  //   kily,   ,   ,
  { {0x78480224, 0x69d5011f, 0xa8a601fb, 0x00000000}},  //   pěvk, _özel, прик,
  { {0xfce3012b, 0x645d0020, 0x20190058, 0x00000000}},  //   _поро, yosi, _yosi_,
  { {0xafdb0637, 0x00000000, 0x00000000, 0x00000000}},  //   _hjør,   ,   ,
  { {0x2bd1001c, 0x63ad003b, 0x6aa9018e, 0x00000000}},  //   _हाता, _rean, _gwef,
  { {0x63ad002a, 0x764101aa, 0x3ea01e9c, 0x00000000}},  //   _sean, gily, ipit_,
  { {0xa96a004b, 0x645d083a, 0x63ad0d29, 0x00000000}},  //   _امام_, tosi, _pean,
  { {0xb8650151, 0x9f400211, 0x69dc0039, 0x00000000}},  //   _قانو, ndió_, _öreb,
  { {0xe80903d7, 0x7641014a, 0xa6fa0a4f, 0x00000000}},  //   वारा_, bily, _دعاء_,
  { {0x321a1e9d, 0x645d006b, 0xdcf7006b, 0x00000000}},  //   _copy_, sosi, zaxı,
  { {0x63ad002a, 0x20191460, 0x92cd0044, 0x00000000}},  //   _tean, _posi_, রবে_,
  { {0xc5f80089, 0x2d98000a, 0x248e009d, 0x00000000}},  //   ldē_, _afre_, _iufm_,
  { {0x62850d5d, 0xafdb1e9e, 0x3ea0011c, 0x00000000}},  // [4870] _tiho, _bjør, gpit_,
  { {0xc5f80089, 0x6b8900d9, 0x00000000, 0x00000000}},  //   ndē_, _sgeg,   ,
  { {0x201900b0, 0xa3d4006e, 0xa298009e, 0x00000000}},  //   _tosi_, स्क_, _وئیر_,
  { {0x22430662, 0x764104cd, 0x92030089, 0x00000000}},  //   lijk_, zily, žādi,
  { {0xdcf7006b, 0xafdb00ea, 0xb6a30082, 0x00000000}},  //   raxı, _fjør, _chấ,
  { {0x9b04008b, 0xafdb0292, 0x00000000, 0x00000000}},  //   эзід, _gjør,   ,
  { {0x61f70061, 0xe8090309, 0x23bf013d, 0x00000000}},  //   _maxl, वाला_, ्लाद,
  { {0xccf200b6, 0xdb000210, 0x76410016, 0x00000000}},  //   _בכל_, _bemä, wily,
  { {0x224302ae, 0x997e000d, 0x76410058, 0x00000000}},  //   kijk_, tăţi_, tily,
  { {0x20d7005a, 0x7a2f00ea, 0x00000000, 0x00000000}},  //   kçi_, _bøte,   ,
  { {0x7641011c, 0xa25b02d5, 0xa3ea007e, 0x00000000}},  //   rily, trôn, одна_,
  { {0x4ad101f5, 0x76411bd3, 0xe894007e, 0x00000000}},  //   _समाव, sily, _чаць,
  { {0xdb00010f, 0x76410058, 0x00000000, 0x00000000}},  //   _gemä, pily,   ,
  { {0xb77a00b3, 0x14c5013d, 0x052900e2, 0x00000000}},  //   _ואנש, _विपण, _молк_,
  { {0x3f990146, 0x987d1d83, 0x7a2f0146, 0x00000000}},  //   _bfsu_, lçın_, _gøte,
  { {0x98a70036, 0xafdb068f, 0x3ea000e0, 0x00000000}},  //   czną_, _amøb, tpit_,
  { {0x850500a1, 0x44770049, 0x3ea0013e, 0x00000000}},  // [4880] _روکن, _קעפל_, upit_,
  { {0xae0e013d, 0x3ea00ff8, 0xdddc0006, 0x00000000}},  //   साधन_, rpit_, _birš,
  { {0x3ea0014a, 0x00000000, 0x00000000, 0x00000000}},  //   spit_,   ,   ,
  { {0x6fb2013d, 0x3ea00a74, 0xd8380173, 0x00000000}},  //   _ज़िं, ppit_, _jwčt_,
  { {0x8db601fb, 0x9f40008e, 0x25ee0309, 0x00000000}},  //   _осві, rdió_, _असली_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xda650379, 0x2611007d, 0x35a7006e, 0x00000000}},  //   راهي, तानी_, _ग़ज़,
  { {0x7d030030, 0xb6f4025f, 0xb6a30082, 0x00000000}},  //   ænse, езиј, _thấ,
  { {0xc6f70147, 0x6b6302be, 0x78ad0091, 0x00000000}},  //   дных_, _акта, ćava,
  { {0x6aa20197, 0x7c290066, 0x00000000, 0x00000000}},  //   mpof, _ċeri,   ,
  { {0x994a039d, 0x6e20001a, 0x00000000, 0x00000000}},  //   _بلال_, _îmbu,   ,
  { {0x61f7005f, 0x224300b5, 0x69da006e, 0x00000000}},  //   _saxl, wijk_, प्री,
  { {0xe298008b, 0xd8380173, 0x00000000, 0x00000000}},  //   маў_, _dwčt_,   ,
  { {0x20d7005d, 0x7d030afc, 0x78530035, 0x00000000}},  //   tçi_, ånsk, măva,
  { {0x224302ae, 0xd01b01ee, 0x00000000, 0x00000000}},  //   rijk_, офа_,   ,
  { {0x4ea702a8, 0x1af40044, 0x20d71e9f, 0x00000000}},  //   држа, _আপনে_, rçi_,
  { {0x20d70477, 0x799a00d9, 0x00000000, 0x00000000}},  // [4890] sçi_, _oftw,   ,
  { {0xff04007c, 0xbd6b007c, 0x7c3a0006, 0x00000000}},  //   ъясн, орее_, _įtra,
  { {0x644f0026, 0x2489000a, 0x22410288, 0x00000000}},  //   onci, _kiam_, _imhk_,
  { {0xdddc010a, 0x447c007b, 0xdfa70025, 0x00000000}},  //   _virš, ַנגע, _تحدي,
  { {0xa3d40164, 0xd6c6002c, 0x644f0051, 0x00000000}},  //   स्ट_, _حق_, inci,
  { {0x24890051, 0x9f4200b9, 0x644f0009, 0x00000000}},  //   _liam_, _jaký_, hnci,
  { {0x1b170055, 0x9f40009f, 0xe94600a1, 0x00000000}},  //   _দেখে_, ldið_, ٹروی,
  { {0x3e74010f, 0xa25b00fa, 0x00000000, 0x00000000}},  //   räte_, drôm,   ,
  { {0xf62501e0, 0x9f40009f, 0x0a6b025f, 0x00000000}},  //   едпо, ndið_, _држи_,
  { {0xa3e202d2, 0x644f0211, 0xe6110025, 0x00000000}},  //   न्न_, enci, اشة_,
  { {0xd46a0cee, 0x00000000, 0x00000000, 0x00000000}},  //   зине_,   ,   ,
  { {0x644f0045, 0x00000000, 0x00000000, 0x00000000}},  //   gnci,   ,   ,
  { {0xe72e10d8, 0x27ed1ea0, 0x87270774, 0x00000000}},  //   _се_, meen_, _تعام,
  { {0x27ed02ae, 0x200b0197, 0x2369000a, 0x00000000}},  //   leen_, _anci_, _dyaj_,
  { {0xafe60373, 0x42d00044, 0xc076003b, 0x00000000}},  //   новл, িবেশ, ећањ,
  { {0x27ed021e, 0x24890011, 0xdfd20025, 0x00000000}},  //   neen_, _giam_, طيط_,
  { {0x64460149, 0x00000000, 0x00000000, 0x00000000}},  // [48a0] miki,   ,   ,
  { {0x64461a71, 0xe0da012b, 0xd12f00a1, 0x00000000}},  //   liki, _ево_, جمہ_,
  { {0x61d700bd, 0x27ed1ea1, 0x61ee1ea2, 0x00000000}},  //   _אויף_, keen_, mebl,
  { {0x6446000b, 0xdb1b008e, 0x27ed1ea3, 0x00000000}},  //   niki, _acuñ, jeen_,
  { {0xa3e20201, 0x27ed1ea4, 0x59f80ae0, 0x00000000}},  //   न्य_, deen_, деля_,
  { {0x61ee0190, 0x64461158, 0x78ad012d, 0x00000000}},  //   nebl, hiki, ćavn,
  { {0x644611ad, 0x27ed0190, 0x2ef20016, 0x00000000}},  //   kiki, feen_, lwyf_,
  { {0x683e001e, 0x27ed1cbf, 0x64460020, 0x00000000}},  //   līdz, geen_, jiki,
  { {0xc5f8001e, 0x6446033b, 0x61ee01d6, 0x00000000}},  //   klēt_, diki, kebl,
  { {0x2c75044f, 0x248901a3, 0x60180010, 0x00000000}},  //   råde_, _siam_, _címz,
  { {0x64461ea5, 0xa3cc02fb, 0x27ed044a, 0x00000000}},  //   fiki, _लाख_, been_,
  { {0x64461ea6, 0x27ed0c67, 0x00000000, 0x00000000}},  //   giki, ceen_,   ,
  { {0x61ee01c3, 0x644f00bb, 0x248900fa, 0x00000000}},  //   febl, rnci, _viam_,
  { {0x61ee010f, 0x00000000, 0x00000000, 0x00000000}},  //   gebl,   ,   ,
  { {0x2bd103d7, 0x644600e7, 0x248900e5, 0x00000000}},  //   _हाला, biki, _tiam_,
  { {0x6446013f, 0x7a2f00ea, 0x68fc00c4, 0x00000000}},  //   ciki, _møta, _árdu,
  { {0xe7e20204, 0xc275025f, 0x9f420142, 0x00000000}},  // [48b0] क्या_, _илиј, _taký_,
  { {0x04b7026c, 0x6b9b0197, 0x27ed0032, 0x00000000}},  //   _تھیں_, _sfug, zeen_,
  { {0x27ed0a18, 0x00000000, 0x00000000, 0x00000000}},  //   yeen_,   ,   ,
  { {0x09c90061, 0x683e0006, 0x27ed0032, 0x00000000}},  //   रल्य, būdi, xeen_,
  { {0x27ed1ea7, 0x9f590065, 0x00000000, 0x00000000}},  //   veen_, _masë_,   ,
  { {0x7bc00089, 0xceb2007b, 0x64460006, 0x00000000}},  //   _edmu, _דיך_, ziki,
  { {0x27ed021e, 0xed15026c, 0x644601aa, 0x00000000}},  //   teen_, _جہاں_, yiki,
  { {0x6446002d, 0x6e20001a, 0xac77025a, 0x00000000}},  //   xiki, _îmbr, _سازش,
  { {0x27ed0f12, 0x6b8400ca, 0x28cf01f5, 0x00000000}},  //   reen_, žigr, संहि,
  { {0x27ed021e, 0x26c30059, 0x644604fd, 0x00000000}},  //   seen_, čjo_, wiki,
  { {0x6446010a, 0x61ee0146, 0x853c0006, 0x00000000}},  //   tiki, vebl, lbėj,
  { {0x61ee011c, 0x29051ea8, 0xa3cc013d, 0x00000000}},  //   webl, _irla_, _लाओ_,
  { {0x386d011f, 0x61ee037f, 0x26cd008e, 0x00000000}},  //   mler_, tebl, queo_,
  { {0x6446000b, 0x6682026c, 0x387f1ea9, 0x00000000}},  //   siki, _پیپل, lmur_,
  { {0x386d00eb, 0xa06a00e3, 0x4f9600ed, 0x00000000}},  //   oler_, дава_, врзу,
  { {0x386d011f, 0x61ee0343, 0x7ae9021e, 0x00000000}},  //   nler_, sebl, _opet,
  { {0xc7b2007b, 0xa06708d6, 0x60ce0061, 0x00000000}},  // [48c0] יבן_, тата_, subm,
  { {0x44201eaa, 0x386d001f, 0xdee3004d, 0x00000000}},  //   _hoi_, hler_, рофи,
  { {0x386d011f, 0x387f0169, 0xdd8f05f3, 0x00000000}},  //   kler_, kmur_, زون_,
  { {0x351a007b, 0x69c10016, 0x386d0030, 0x00000000}},  //   ווענ, _adle, jler_,
  { {0x44201eab, 0x386d05b7, 0x80e203d7, 0x00000000}},  //   _moi_, dler_, _पहुं,
  { {0x44201eac, 0x386d010f, 0xa3e2007d, 0x00000000}},  //   _loi_, eler_, न्त_,
  { {0x386d1ead, 0x61e3014a, 0x44320010, 0x00000000}},  //   fler_, _önle, _oly_,
  { {0x4420061a, 0x386d0cb2, 0xc6f8019d, 0x00000000}},  //   _noi_, gler_, ених_,
  { {0xf76f0025, 0xa3cc0164, 0xe9da003b, 0x00000000}},  //   ياً_, _लाज_, _ока_,
  { {0x386d0302, 0xceb3009b, 0x44200051, 0x00000000}},  //   aler_, סית_, _aoi_,
  { {0x386d0030, 0x44320343, 0x2c750039, 0x00000000}},  //   bler_, _bly_, låda_,
  { {0x44200011, 0x07a6012b, 0x6d430051, 0x00000000}},  //   _coi_, _радн, únai,
  { {0x44201eae, 0x27e61eaf, 0x442b0087, 0x00000000}},  //   _doi_, _ibon_, rkc_,
  { {0x442002ac, 0x00000000, 0x00000000, 0x00000000}},  //   _eoi_,   ,   ,
  { {0x4432022d, 0x44200907, 0x76480f99, 0x00000000}},  //   _fly_, _foi_, midy,
  { {0xceb4005f, 0xa3e202d2, 0x44321eb0, 0x00000000}},  //   yyət_, न्द_, _gly_,
  { {0xda02001c, 0x09ca0055, 0xcddb003b, 0x00000000}},  // [48d0] लयात_, ল্যা, дње_,
  { {0x386d011f, 0xe7e2006e, 0x442001ee, 0x00000000}},  //   zler_, क्ता_, _zoi_,
  { {0x7ae91eb1, 0x2d87050d, 0x386d014a, 0x00000000}},  //   _spet, äne_, yler_,
  { {0xd0110025, 0x386d05af, 0x13b70044, 0x00000000}},  //   _الح_, xler_, _ঝাড়,
  { {0x7c2b00bb, 0x386d1eb2, 0x39e9004d, 0x00000000}},  //   rkgr, vler_, едло_,
  { {0x386d002b, 0x27e60093, 0x853c0006, 0x00000000}},  //   wler_, _abon_, rbėj,
  { {0x386d0483, 0x18691eb3, 0x00000000, 0x00000000}},  //   tler_, наки_,   ,
  { {0xb8db02d2, 0x386d009d, 0x387f01e5, 0x00000000}},  //   _अब_, uler_, umur_,
  { {0x386d011f, 0x44201eb4, 0x3b550822, 0x00000000}},  //   rler_, _roi_, _скар,
  { {0x386d1eb5, 0x44201eb6, 0x69c10030, 0x00000000}},  //   sler_, _soi_, _udle,
  { {0xc329007b, 0x44200198, 0xb7d50151, 0x00000000}},  //   _צו_, _poi_, _مقاب,
  { {0x889a009b, 0x26110316, 0x00000000, 0x00000000}},  //   _טבעי, ताही_,   ,
  { {0x4420021e, 0x27fd018e, 0xe2970783, 0x00000000}},  //   _voi_, _iawn_, лая_,
  { {0x27fd01d5, 0x27ff002d, 0x425500c0, 0x00000000}},  //   _hawn_, ldun_, атст,
  { {0x44201684, 0x27fd0145, 0xd838000a, 0x00000000}},  //   _toi_, _kawn_, _otčl_,
  { {0x27ff1eb7, 0x62491eb8, 0x6444011c, 0x00000000}},  //   ndun_, ržoa, _umii,
  { {0x67291eb9, 0x7d030030, 0x00000000, 0x00000000}},  // [48e0] nyej, ænsn,   ,
  { {0xc33300b6, 0x63b6021f, 0x7c201eba, 0x00000000}},  //   _לוח_, _heyn, _somr,
  { {0x63b60784, 0x645d1ebb, 0x7c2004eb, 0x00000000}},  //   _keyn, érig, _pomr,
  { {0x61fe163c, 0x62961ebc, 0xeaba0581, 0x00000000}},  //   _hapl, _kuyo, ейд_,
  { {0x61fe020d, 0x4af81ac0, 0x6296000a, 0x00000000}},  //   _kapl, телю_, _juyo,
  { {0x63b6000c, 0x2ee00093, 0x62960009, 0x00000000}},  //   _leyn, mtif_, _muyo,
  { {0x6f040035, 0x76480173, 0xb33b006b, 0x00000000}},  //   lvic, vidy, rbçi,
  { {0x61fe01aa, 0x76aa16c4, 0x26c20091, 0x00000000}},  //   _lapl, нтов_, škom_,
  { {0x963401bd, 0x2ee0033b, 0x9f59008e, 0x00000000}},  //   иниц, ntif_, _pasé_,
  { {0x14ca0057, 0xa3e20164, 0x00000000, 0x00000000}},  //   ными_, न्स_,   ,
  { {0x63b602b9, 0xb99301b7, 0x87e61ebd, 0x00000000}},  //   _beyn, _المب, _бюле,
  { {0x2ee0020c, 0x62960019, 0xd7f700ed, 0x00000000}},  //   ktif_, _buyo, _буш_,
  { {0x05140055, 0x0464008b, 0xfe04006e, 0x00000000}},  //   ানের_, стэм, रयास_,
  { {0x6f0400ca, 0x9f4b0051, 0x69d5014a, 0x00000000}},  //   dvic, _tacú_, _özet,
  { {0xd5b8001e, 0xe8090061, 0xa3e20164, 0x00000000}},  //   skās_, वाचा_, न्ह_,
  { {0x2ee00022, 0x62960145, 0x645d0068, 0x00000000}},  //   ftif_, _fuyo, érid,
  { {0x3da7003b, 0x62960068, 0x2ca300fa, 0x00000000}},  // [48f0] греб, _guyo, _stjd_,
  { {0x443900d4, 0x63b6005d, 0x61fe0022, 0x00000000}},  //   lhs_, _zeyn, _gapl,
  { {0x2ee0003f, 0x82340014, 0x6f040026, 0x00000000}},  //   atif_, _دريا, avic,
  { {0x61fe0161, 0xaed51020, 0x3e97006d, 0x00000000}},  //   _zapl, _комш, _مؤسس,
  { {0x2ee000f4, 0x26c20091, 0x69da0009, 0x00000000}},  //   ctif_, škoj_, _bcte,
  { {0x3ea9020c, 0x27fd0085, 0x00000000, 0x00000000}},  //   mpat_, _sawn_,   ,
  { {0x27fd01d0, 0x3ea90052, 0x00000000, 0x00000000}},  //   _pawn_, lpat_,   ,
  { {0x26df0026, 0xec680517, 0x00000000, 0x00000000}},  //   ttuo_, _брук_,   ,
  { {0x63b6009f, 0xdb26026c, 0x7d05001c, 0x00000000}},  //   _reyn, _پولی, lvhs,
  { {0x673b013e, 0x63b6009d, 0x3ea90a16, 0x00000000}},  //   rzuj, _seyn, ipat_,
  { {0x62961d42, 0x67290065, 0x61fe1ebe, 0x00000000}},  //   _suyo, syej, _rapl,
  { {0xe29a1963, 0x6386026b, 0x629606c2, 0x00000000}},  //   кам_, игна, _puyo,
  { {0x61fe0dec, 0x63bb000c, 0x8c1a00b3, 0x00000000}},  //   _papl, ðuna, דורי,
  { {0x6f040ec0, 0x09b50049, 0x00000000, 0x00000000}},  //   vvic, יפֿט_,   ,
  { {0x60260c4e, 0x216a07e1, 0x443900d9, 0x00000000}},  //   адва, тиви_, bhs_,
  { {0x32040046, 0x4439010f, 0x62961ebf, 0x00000000}},  //   śmy_, chs_, _tuyo,
  { {0x645d00f4, 0x00000000, 0x00000000, 0x00000000}},  // [4900] érie,   ,   ,
  { {0xee370bbd, 0x2ee01ec0, 0xb2bb0104, 0x00000000}},  //   ану_, rtif_, _שמיר,
  { {0x7afb01c2, 0x2ee0009d, 0x3ea90058, 0x00000000}},  //   _asut, stif_, apat_,
  { {0xa3d902d2, 0x115b0104, 0x2ee01ec1, 0x00000000}},  //   ालय_, _ידיע, ptif_,
  { {0x539b009b, 0x00000000, 0x00000000, 0x00000000}},  //   דינו,   ,   ,
  { {0x98c6013b, 0xa2ce01f5, 0x26c2007f, 0x00000000}},  //   асил, _तिन्, škok_,
  { {0x7a3400f6, 0x00000000, 0x00000000, 0x00000000}},  //   _càta,   ,   ,
  { {0x4814003b, 0xa5d8006e, 0x6835013e, 0x00000000}},  //   смис, _माहौ, _rádc,
  { {0xe7e202f4, 0xfaa3013b, 0x00000000, 0x00000000}},  //   क्षा_, _мато,   ,
  { {0xb3b00044, 0x7ae21ec2, 0x00000000, 0x00000000}},  //   _কাগজ, mtot,   ,
  { {0x0d9700b6, 0x44390133, 0x7ae21ec3, 0x00000000}},  //   יכים_, ths_, ltot,
  { {0x66e6026b, 0x26cd1ebf, 0x69d8037f, 0x00000000}},  //   _вода, breo_, lgve,
  { {0x7ae20687, 0x26cd1ec4, 0x66e301ee, 0x00000000}},  //   ntot, creo_, _моца,
  { {0x05dd0061, 0xb7e20309, 0x44391ec5, 0x00000000}},  //   _मायब, क्रम_, shs_,
  { {0x38950089, 0x443900ab, 0x661c000c, 0x00000000}},  //   _pāri_, phs_, örku,
  { {0xdb00010f, 0x5f450025, 0x3ea91ec6, 0x00000000}},  //   _bemü, منزل, tpat_,
  { {0xe7f90164, 0x63bd0107, 0xdb001665, 0x00000000}},  // [4910] ्यता_, masn, _memó,
  { {0x31350200, 0x3ea901c5, 0x8e140517, 0x00000000}},  //   _геор, rpat_, одуц,
  { {0x8d6800ed, 0xdd9801ff, 0x3ea90b4a, 0x00000000}},  //   ајца_, ршу_, spat_,
  { {0x63bd037e, 0xa2ce013d, 0x3ea91dfb, 0x00000000}},  //   nasn, _तिम्, ppat_,
  { {0x09df0055, 0xee871001, 0xdb00010f, 0x00000000}},  //   _যোগা, _выво, _gemü,
  { {0x6ca70088, 0x63bd0271, 0x69d81ec7, 0x00000000}},  //   _враж, hasn, ggve,
  { {0x2ef5006b, 0x63bd0091, 0xd90f0167, 0x00000000}},  //   şafı_, kasn, بیا_,
  { {0x63bd01cd, 0x9b8906b4, 0x26cd00fa, 0x00000000}},  //   jasn, _منزل_, treo_,
  { {0x63bd037e, 0xdb000f18, 0xfbd200b3, 0x00000000}},  //   dasn, _demó, _מתן_,
  { {0x26cd0819, 0x63bb000c, 0xa2ce013d, 0x00000000}},  //   rreo_, ðunn, _तिब्,
  { {0xd5490407, 0x63bd0145, 0x26cd11af, 0x00000000}},  //   упне_, fasn, sreo_,
  { {0x60d50107, 0x63bd1ec8, 0xd7950025, 0x00000000}},  //   duzm, gasn, _الإخ,
  { {0x686600a1, 0x3a2501f3, 0x06d50044, 0x00000000}},  //   _اپنے, _kolp_, _তৈরি,
  { {0xc6920049, 0xf3ff00c4, 0xdb00000a, 0x00000000}},  //   _זאג_, boão_, _kemò,
  { {0x645d0249, 0x6587007e, 0x63bd1ec9, 0x00000000}},  //   éric, _тыдз, basn,
  { {0xdb000129, 0x63bd0716, 0x7ae2009d, 0x00000000}},  //   _memò, casn, ytot,
  { {0xe7e9001c, 0x63a41eca, 0x00000000, 0x00000000}},  // [4920] झ्या_, _ifin,   ,
  { {0x60c90089, 0x00000000, 0x00000000, 0x00000000}},  //   ņema,   ,   ,
  { {0x2480000a, 0x7ae20048, 0x00000000, 0x00000000}},  //   _khim_, wtot,   ,
  { {0x7ae20dc9, 0xdee60cb3, 0x00000000, 0x00000000}},  //   ttot, _ломи,   ,
  { {0xa3d903d7, 0x853c0006, 0x63a40258, 0x00000000}},  //   ालत_, lbėt, _mfin,
  { {0x2002000b, 0x7ae21ecb, 0x3e360167, 0x00000000}},  //   _haki_, rtot, _افسر,
  { {0x7ae20059, 0xa8a3008b, 0x200204cb, 0x00000000}},  //   stot, прык, _kaki_,
  { {0x6d57007b, 0x20020036, 0x7d57009b, 0x00000000}},  //   _הילף_, _jaki_, _הילד_,
  { {0x3b071ecc, 0x20020760, 0x63bd08a4, 0x00000000}},  //   _лето_, _maki_, vasn,
  { {0x20020390, 0x63a40181, 0x63bd1ecd, 0x00000000}},  //   _laki_, _afin, wasn,
  { {0xe85300d3, 0x63bd10ed, 0x69c81d34, 0x00000000}},  //   _کنند, tasn, _idde,
  { {0x491700b6, 0x24800011, 0x16160061, 0x00000000}},  //   _לקבל_, _chim_, ताहर_,
  { {0x63bd11e4, 0xb8650a4f, 0x00000000, 0x00000000}},  //   rasn, _بالو,   ,
  { {0x60d50061, 0xe534085f, 0x63a400ea, 0x00000000}},  //   tuzm, _мель, _efin,
  { {0xdddc17dc, 0x20021ece, 0x63a41ecf, 0x00000000}},  //   _birž, _baki_, _ffin,
  { {0xf48500a1, 0x290c0107, 0x16160061, 0x00000000}},  //   _باتی, _mrda_, तावर_,
  { {0x69c80465, 0x20020cd8, 0x629d0009, 0x00000000}},  // [4930] _odde, _daki_, qqso,
  { {0x644f081d, 0x290c1ed0, 0x877b0049, 0x00000000}},  //   lici, _orda_, ראמי,
  { {0x59d20061, 0x2ca71ed1, 0x7f9504dd, 0x00000000}},  //   _साजर, ënd_, _манх,
  { {0x69db001c, 0x69c80038, 0xfbd00558, 0x00000000}},  //   _नाही, _adde, فته_,
  { {0xdc3901d5, 0x290c014a, 0x7a3400f6, 0x00000000}},  //   għġb, _arda_, _càto,
  { {0x8cbb05f3, 0x69c800f6, 0x644f096a, 0x00000000}},  //   _مدرس_, _cdde, hici,
  { {0xa3d90201, 0x20020085, 0xdbf200b9, 0x00000000}},  //   ाला_, _yaki_, _zříz,
  { {0x09ca0055, 0x644f0107, 0x69c808e0, 0x00000000}},  //   ল্লা, jici, _edde,
  { {0xba5500ed, 0x4e0d006e, 0x7a3400f6, 0x00000000}},  //   _двај, _सफाई_, _gàto,
  { {0x63a4001a, 0x24800061, 0x0a6b098c, 0x00000000}},  //   _sfin, _shim_, _срби_,
  { {0x248000ad, 0x6e2712d6, 0xe5710025, 0x00000000}},  //   _phim_, _mojb, بطة_,
  { {0x644f028c, 0x546a007c, 0x787e0065, 0x00000000}},  //   gici, рамм_, tëve,
  { {0xe29a1ed2, 0x67d40245, 0x38690645, 0x00000000}},  //   раг_, _хочу, čard_,
  { {0x20021ed3, 0xa509007c, 0x6e27016c, 0x00000000}},  //   _saki_, _века_, _nojb,
  { {0xf41f021e, 0x2002011c, 0x9103004d, 0x00000000}},  //   mmän_, _paki_, мпре,
  { {0x6603021e, 0xf41f04ee, 0xdbf200b9, 0x00000000}},  //   _hank, lmän_, _příz,
  { {0x3e6f0010, 0x26c20087, 0x1ea90379, 0x00000000}},  // [4940] yütt_, škov_, مالي_,
  { {0x66030142, 0x7bc90d7b, 0x44220f46, 0x00000000}},  //   _jank, _adeu, ljk_,
  { {0x20020046, 0x6835015f, 0x9f4b00f6, 0x00000000}},  //   _taki_, _nádo, _bacó_,
  { {0x6603010a, 0x717b00b6, 0x2aaa0072, 0x00000000}},  //   _lank, _כניס, атко_,
  { {0xda660265, 0xd83805fa, 0x7bc90016, 0x00000000}},  //   овди, _juče_, _ddeu,
  { {0x683c00f4, 0x66030890, 0x3b0d0023, 0x00000000}},  //   _méde, _nank, _dreq_,
  { {0x2d980059, 0x644f1ed4, 0x00000000, 0x00000000}},  //   _igre_, yici,   ,
  { {0x6603049b, 0x2fc00058, 0x644f0133, 0x00000000}},  //   _aank, naig_, xici,
  { {0x644f1cae, 0xb5fc01d5, 0x69c80009, 0x00000000}},  //   vici, loġi, _tdde,
  { {0x644f0036, 0x66031ed5, 0x69c801bf, 0x00000000}},  //   wici, _cank, _udde,
  { {0x660303a8, 0x644f0781, 0x2918012d, 0x00000000}},  //   _dank, tici, _šraf_,
  { {0x7c221ed6, 0xd838050f, 0xd6d90036, 0x00000000}},  //   njor, _buče_, szła_,
  { {0x2d980089, 0x6756035b, 0x66030142, 0x00000000}},  //   _ogre_, _بخار, _fank,
  { {0x644f0c1f, 0x7e04007d, 0x2d980023, 0x00000000}},  //   sici, रयोग_, _ngre_,
  { {0x9f590026, 0x925801ee, 0x00000000, 0x00000000}},  //   _sasà_, царт_,   ,
  { {0x660300ca, 0x60c90089, 0x20c50089, 0x00000000}},  //   _zank, ņemo, rķi_,
  { {0xdd9b04f9, 0x9f4b0129, 0x260f0164, 0x00000000}},  // [4950] аше_, _racó_, _थोडी_,
  { {0x4429001d, 0x26c40e32, 0x9f4b008e, 0x00000000}},  //   _hoa_, ismo_, _sacó_,
  { {0x6aa9009f, 0x4429002d, 0x765a1ed7, 0x00000000}},  //   _stef, _koa_, inty,
  { {0x442906aa, 0x1c0b0309, 0x26c4088e, 0x00000000}},  //   _joa_, _सोशल_, ksmo_,
  { {0x442900f8, 0x3b09005e, 0xe47c0049, 0x00000000}},  //   _moa_, село_, בראכ,
  { {0xceb2061e, 0x44291ed8, 0x6f0f0026, 0x00000000}},  //   _איך_, _loa_, _ircc,
  { {0x66031ed9, 0x644d00b0, 0x5d3300a1, 0x00000000}},  //   _rank, _omai, _تہائ,
  { {0x59d70201, 0x9f400181, 0x44290032, 0x00000000}},  //   _ठाकर, ceió_, _noa_,
  { {0x660303b6, 0x7c3b0fc3, 0x00000000, 0x00000000}},  //   _pank, _ilur,   ,
  { {0x644d022b, 0x3eb9010f, 0x7c290168, 0x00000000}},  //   _amai, _mwst_, _hoer,
  { {0x44290907, 0x7c291eda, 0x66030ac1, 0x00000000}},  //   _boa_, _koer, _vank,
  { {0x4429049a, 0x7c290215, 0x660301d6, 0x00000000}},  //   _coa_, _joer, _wank,
  { {0x66030263, 0x7c290168, 0x44290653, 0x00000000}},  //   _tank, _moer, _doa_,
  { {0x2496007a, 0x683c0010, 0x7c3b0129, 0x00000000}},  //   _کنيد_, _véde, _llur,
  { {0x7c3b047f, 0x3eb9018e, 0x44290190, 0x00000000}},  //   _olur, _awst_, _foa_,
  { {0x44290460, 0x7c290022, 0x644d0322, 0x00000000}},  //   _goa_, _noer, _gmai,
  { {0x2fc00fb8, 0x7d0e0b41, 0xe7e3007d, 0x00000000}},  // [4960] raig_, _srbs, _गाना_,
  { {0x2fc00129, 0x3ea00065, 0xd6bd0044, 0x00000000}},  //   saig_, rqit_, _আমায,
  { {0x7c2906b2, 0x7c3b016e, 0x7c221edb, 0x00000000}},  //   _boer, _blur, tjor,
  { {0x7c29060c, 0xd6d90036, 0x44290082, 0x00000000}},  //   _coer, kuł_, _xoa_,
  { {0x08e60044, 0x6e3e00f6, 0x386d0146, 0x00000000}},  //   কিছু_, phpb, doer_,
  { {0x38a30279, 0x7c3b023e, 0x7c220ed6, 0x00000000}},  //   _sıra_, _elur, sjor,
  { {0x7c3b01a2, 0x60c80048, 0x00000000, 0x00000000}},  //   _flur, ádmh,   ,
  { {0x97141364, 0xd6da0088, 0x386d1edc, 0x00000000}},  //   дмиц, бто_, goer_,
  { {0x7a3d01aa, 0x26c4007f, 0x00000000, 0x00000000}},  //   _sète, usmo_,   ,
  { {0xba291edd, 0x644d0089, 0xceb3009b, 0x00000000}},  //   _وسلم_, _smai, עית_,
  { {0x386d0bcb, 0x645d0181, 0x44291ede, 0x00000000}},  //   boer_, ério, _poa_,
  { {0x897b007b, 0x889b01f8, 0x644d01f3, 0x00000000}},  //   _פראצ, _הבאי, _qmai,
  { {0x288b01ef, 0x442901aa, 0xd050006b, 0x00000000}},  //   _اصلی_, _voa_, _ödəy,
  { {0x26c20006, 0x44290082, 0x00000000, 0x00000000}},  //   škos_, _woa_,   ,
  { {0x0cd70055, 0x44290020, 0x7bc200e7, 0x00000000}},  //   _সন্ত, _toa_, kaou,
  { {0x644d01a3, 0x7a2f00ea, 0x656f01a2, 0x00000000}},  //   _umai, _høtt, ßche,
  { {0xd01000a1, 0x7c290112, 0x92080089, 0x00000000}},  // [4970] ھلے_, _roer, _brāļ,
  { {0xd35800b6, 0x7c2904d4, 0xb2bc009b, 0x00000000}},  //   _משחק_, _soer, _המזר,
  { {0xd7dc0365, 0x7c290093, 0xfe700025, 0x00000000}},  //   _यांच, _poer, ادق_,
  { {0x645d1edf, 0x628500e0, 0x98c4013e, 0x00000000}},  //   nnsi, _hhho, štěn_,
  { {0x25dd0201, 0x7c2901b5, 0x386d00c7, 0x00000000}},  //   _खाली_, _voer, voer_,
  { {0xae0a001c, 0x2009010a, 0x7c291a0f, 0x00000000}},  //   _होऊन_, ldai_, _woer,
  { {0x2ee9009f, 0x7c290100, 0xa8890ae0, 0x00000000}},  //   ltaf_, _toer, ойка_,
  { {0x77f90201, 0x20091ee0, 0xd6d90036, 0x00000000}},  //   ्येक_, ndai_, tuł_,
  { {0xfaf00380, 0x2ee9018e, 0xd706007c, 0x00000000}},  //   _مثل_, ntaf_, дные_,
  { {0x62971ee1, 0xd6d90036, 0x645d0052, 0x00000000}},  //   _nixo, szło_, ensi,
  { {0x69c31ee2, 0x01e30044, 0x91e30044, 0x00000000}},  //   mane, য়াদ, য়াখ,
  { {0x69c31406, 0x9f40000c, 0x62850010, 0x00000000}},  //   lane, keið_, _ahho,
  { {0x2009018e, 0x69c30035, 0x62971ee3, 0x00000000}},  //   ddai_, oane, _bixo,
  { {0x2019000c, 0x27ed010f, 0x69c30142, 0x00000000}},  //   _ansi_, lfen_, nane,
  { {0xafe60088, 0x6b9b0107, 0x409602dc, 0x00000000}},  //   мовл, _ogug, драт,
  { {0x62971052, 0x69c308a7, 0x27ed1c1a, 0x00000000}},  //   _eixo, hane, nfen_,
  { {0x69c30343, 0xf41300b6, 0x27ed010f, 0x00000000}},  // [4980] kane, _יפה_, ifen_,
  { {0x69c3000c, 0x201900b0, 0xd12f00a1, 0x00000000}},  //   jane, _ensi_, دمہ_,
  { {0x621b007b, 0x69c31ee4, 0x61fc05cd, 0x00000000}},  //   _וויק, dane, merl,
  { {0x61fc1907, 0xeb9a0545, 0x61ee0168, 0x00000000}},  //   lerl, цид_, lfbl,
  { {0xdb0b1ee5, 0x69c30c56, 0xdb000027, 0x00000000}},  //   dagó, fane, _nemô,
  { {0x320a0030, 0x69c31ee6, 0x27ed063c, 0x00000000}},  //   ndby_, gane, efen_,
  { {0x26f8024c, 0x27ed04e5, 0xafdb05b7, 0x00000000}},  //   ्ट्र_, ffen_, _flød,
  { {0x27ed0016, 0xd8380087, 0x61fc1469, 0x00000000}},  //   gfen_, _buča_, herl,
  { {0x69c3004e, 0x61fc1ee7, 0xa3e2007d, 0x00000000}},  //   bane, kerl, न्छ_,
  { {0x645d0016, 0x38690ce4, 0xdb0000c4, 0x00000000}},  //   wnsi, čara_, _demô,
  { {0x61fc02ae, 0x7bc01ee8, 0x6aa000e7, 0x00000000}},  //   derl, _kemu, _humf,
  { {0x7bc00061, 0x6aa00020, 0xb8650025, 0x00000000}},  //   _jemu, _kumf, _كانو,
  { {0x645d1ee9, 0x7bc01eea, 0x61fc1402, 0x00000000}},  //   rnsi, _memu, ferl,
  { {0xc5d50044, 0x60dc002b, 0x00000000, 0x00000000}},  //   ত্বপ, furm,   ,
  { {0xe5f7009b, 0xa2940088, 0xf7080082, 0x00000000}},  //   _חזור_, тарі, _hủ_,
  { {0x7bc001ca, 0x20090006, 0x7a3d000a, 0x00000000}},  //   _nemu, udai_, _mèta,
  { {0x61fc011f, 0x69c30148, 0x20091eeb, 0x00000000}},  // [4990] berl, yane, rdai_,
  { {0x6f0d049a, 0x61fc0211, 0xab5d0046, 0x00000000}},  //   rvac, cerl, _jeże,
  { {0x69c31eec, 0x7bc00010, 0x2ee900f8, 0x00000000}},  //   vane, _bemu, staf_,
  { {0x69c30046, 0x09d70061, 0xdb0b0129, 0x00000000}},  //   wane, ठल्य, dagò,
  { {0xa3e7024c, 0x7bc01632, 0x44390089, 0x00000000}},  //   _पान_, _demu, iks_,
  { {0xd33800b6, 0x683c00f4, 0x53380049, 0x00000000}},  //   ורדה_, _réda, ונדן_,
  { {0xdb0b002a, 0x27ed011f, 0x3e740039, 0x00000000}},  //   tagó, tfen_, rätt_,
  { {0x7bc00390, 0x27ed010f, 0x443900b5, 0x00000000}},  //   _gemu, ufen_, jks_,
  { {0x27ed010f, 0x69c31eed, 0xf7080011, 0x00000000}},  //   rfen_, pane, _củ_,
  { {0x44391eee, 0x7bc005fa, 0x60dc019a, 0x00000000}},  //   eks_, _zemu, yurm,
  { {0x61fc05c6, 0xc8c906c6, 0x27ed010f, 0x00000000}},  //   verl, _روشن_, pfen_,
  { {0x69c102ae, 0x29050211, 0x61e50016, 0x00000000}},  //   _hele, _isla_, _achl,
  { {0x2bd00061, 0x7a3400f6, 0x00000000, 0x00000000}},  //   हणता, _sàti,   ,
  { {0x69c10047, 0x975600b6, 0x60dc00b0, 0x00000000}},  //   _jele, _אינו_, turm,
  { {0x69c1020c, 0x463a0049, 0x61fc04fb, 0x00000000}},  //   _mele, _מעסע, rerl,
  { {0x44391eef, 0x61fc0016, 0x1de20061, 0x00000000}},  //   cks_, serl, _पाहत,
  { {0x7bc00181, 0x68350211, 0x61fc0971, 0x00000000}},  // [49a0] _remu, _cádi, perl,
  { {0x7bc0020c, 0x69c11109, 0x2d9c05b7, 0x00000000}},  //   _semu, _nele, øve_,
  { {0x1636007b, 0x7bc00149, 0x41bb009b, 0x00000000}},  //   ענער_, _pemu, _מציע,
  { {0x09c80061, 0xdd8f004b, 0x3a3e0093, 0x00000000}},  //   रण्य, حوم_, _sltp_,
  { {0x2905014a, 0x7a3d01aa, 0x94210061, 0x00000000}},  //   _asla_, _sèta, यातच_,
  { {0xfce6189f, 0x78a10142, 0xf7080011, 0x00000000}},  //   _пого, _bulv, _rủ_,
  { {0x69c10c46, 0x7bc00169, 0xf1b30104, 0x00000000}},  //   _dele, _temu, נסה_,
  { {0x6e2e0161, 0x628e0288, 0x69c1010e, 0x00000000}},  //   _hobb, hmbo, _eele,
  { {0x69c10047, 0xc6f700a5, 0x6e2e101b, 0x00000000}},  //   _fele, еных_, _kobb,
  { {0x69c10334, 0x6e2e1ef0, 0x3a06026c, 0x00000000}},  //   _gele, _jobb, _سکتی_,
  { {0x6e2e002b, 0x78a10030, 0x3ea21ef1, 0x00000000}},  //   _mobb, _gulv, _lukt_,
  { {0x61e5001f, 0xf708001d, 0x628e02c2, 0x00000000}},  //   _schl, _tủ_, embo,
  { {0x44391ef2, 0x27e61ef3, 0xa3e7007d, 0x00000000}},  //   rks_, _icon_, _पाठ_,
  { {0x44391ef4, 0x171b00b6, 0x6e2e00f8, 0x00000000}},  //   sks_, _מודע, _nobb,
  { {0x44390093, 0x68350325, 0x316800e2, 0x00000000}},  //   pks_, _sádi, ешто_,
  { {0x4ea70805, 0xaf3402fd, 0x683c009d, 0x00000000}},  //   ержа, گرفت, _médo,
  { {0x63ad018e, 0x660a0095, 0x63bb000c, 0x00000000}},  // [49b0] _ifan, _kafk, ðunu,
  { {0x5d67041f, 0x7f5817a4, 0x6e2e0133, 0x00000000}},  //   нтез, хаус_, _cobb,
  { {0x6e2e1ef5, 0x69c10038, 0xf653007b, 0x00000000}},  //   _dobb, _rele, נצע_,
  { {0x3ea21d43, 0x447c0049, 0x00000000, 0x00000000}},  //   _fukt_, ִנגע,   ,
  { {0x69c104cb, 0x63ad000b, 0x09e50893, 0x00000000}},  //   _pele, _mfan, волн,
  { {0x6e2e0197, 0x53380049, 0x9f490051, 0x00000000}},  //   _gobb, ענגן_, nfaí_,
  { {0x63ad000c, 0xecf80245, 0x200b1ef6, 0x00000000}},  //   _ofan, _перш_, _kaci_,
  { {0x200b0107, 0x69c11ef7, 0x78a11815, 0x00000000}},  //   _jaci_, _wele, _vulv,
  { {0xdb00009f, 0xdcfc0089, 0x200b0232, 0x00000000}},  //   _afmæ, _izrā, _maci_,
  { {0x63ad1ef8, 0x27e6016b, 0x69c10020, 0x00000000}},  //   _afan, _econ_, _uele,
  { {0xd46a012b, 0x04460057, 0x55890eec, 0x00000000}},  //   дине_, венн, ьбом_,
  { {0x200b037e, 0x24890082, 0x387a0014, 0x00000000}},  //   _naci_, _cham_, _قشنگ_,
  { {0xe72e1ef9, 0x66051efa, 0x66e500e2, 0x00000000}},  //   _те_, _апла, _рола,
  { {0xe29703c8, 0x7a3d0129, 0x2d9c0027, 0x00000000}},  //   кая_, _mèto, ľvek_,
  { {0xe2971efb, 0x200b0197, 0x63ad0016, 0x00000000}},  //   тар_, _baci_, _ffan,
  { {0x200b001a, 0x6e2e0197, 0xdfd20025, 0x00000000}},  //   _caci_, _sobb, شيط_,
  { {0x59d10061, 0x200b11c9, 0x00000000, 0x00000000}},  // [49c0] सणार, _daci_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x200b1efc, 0x27ff0022, 0x248900e0, 0x00000000}},  //   _faci_, keun_, _yham_,
  { {0x92e40044, 0x7a3d0173, 0x64460082, 0x00000000}},  //   নবী_, _bèto, nhki,
  { {0x7c6500f9, 0x6e2e002b, 0x20000035, 0x00000000}},  //   دالل, _tobb, meii_,
  { {0x6f041780, 0x683c009d, 0x200b012d, 0x00000000}},  //   mwic, _pédo, _zaci_,
  { {0x98c3008b, 0xdcf5009e, 0x27e600d9, 0x00000000}},  //   асыл, _مہلت_, _pcon_,
  { {0xd838012d, 0x27ff0022, 0x00000000, 0x00000000}},  //   _vučo_, geun_,   ,
  { {0x6f0400bb, 0xc053009b, 0xe3d80044, 0x00000000}},  //   nwic, יזה_, তভাব,
  { {0x2489103f, 0x63ad001a, 0x44ea0026, 0x00000000}},  //   _sham_, _sfan, tù_,
  { {0x24891efd, 0xd5b80089, 0x63ad01a2, 0x00000000}},  //   _pham_, rbā_, _pfan,
  { {0x2ee00007, 0x00000000, 0x00000000, 0x00000000}},  //   kuif_,   ,   ,
  { {0x200b1efe, 0x44ea0026, 0x2ee00068, 0x00000000}},  //   _raci_, sù_, juif_,
  { {0x7df30224, 0x200b0035, 0xab5d0066, 0x00000000}},  //   _měsí, _saci_, _jeża,
  { {0x2489001d, 0x6f040036, 0xdfd50a78, 0x00000000}},  //   _tham_, ewic, ловы,
  { {0x63ad0020, 0x2ee001c3, 0x44ce093c, 0x00000000}},  //   _ufan, fuif_, mę_,
  { {0x44ce0a67, 0x22840039, 0x0f15007e, 0x00000000}},  // [49d0] lę_, söka_, ымаю,
  { {0xf1b702fb, 0x61e9016c, 0x7a3d00d4, 0x00000000}},  //   _अभिन, đels, _rèto,
  { {0x44ce06dc, 0x3cd50ae0, 0x72340025, 0x00000000}},  //   nę_, ужес, _خريط,
  { {0x1c1d013d, 0x442b1eff, 0xfbd0067a, 0x00000000}},  //   फाइल_, njc_, قته_,
  { {0x44fa0044, 0x00000000, 0x00000000, 0x00000000}},  //   েমিক_,   ,   ,
  { {0x44ce0a67, 0x2fc90112, 0x38660085, 0x00000000}},  //   kę_, laag_, _ajor_,
  { {0x44ce1f00, 0x27ff01bb, 0xe8f50025, 0x00000000}},  //   ję_, teun_, استخ,
  { {0xd70910a9, 0x44ce0fed, 0xdcfc0089, 0x00000000}},  //   ение_, dę_, _uzrā,
  { {0xe5a500e2, 0x27ff0288, 0x00000000, 0x00000000}},  //   липи, reun_,   ,
  { {0x9a870783, 0x27ff01d6, 0x2fc901d6, 0x00000000}},  //   _рубл, seun_, haag_,
  { {0x44ce0fed, 0x38661bea, 0x00000000, 0x00000000}},  //   gę_, _fjor_,   ,
  { {0xc20900b6, 0x2fc90007, 0xb8090025, 0x00000000}},  //   _מה_, jaag_, _سيتم_,
  { {0x2fc90007, 0x2e360190, 0x00000000, 0x00000000}},  //   daag_, _kæft_,   ,
  { {0x6446008d, 0x387f0028, 0x6fe10164, 0x00000000}},  //   shki, llur_, _फाउं,
  { {0x44ce0036, 0x213e1f01, 0x61430072, 0x00000000}},  //   cę_, áth_, бера,
  { {0x6f04001f, 0x0495007e, 0x1fb50849, 0x00000000}},  //   twic, _крыў, исур,
  { {0x44200149, 0x3326005f, 0x64560009, 0x00000000}},  // [49e0] _ini_, _çox_, _imyi,
  { {0x44321f02, 0xa20614ec, 0x6f041459, 0x00000000}},  //   _hoy_, _спод, rwic,
  { {0x4432066b, 0x644401c2, 0x63a9198a, 0x00000000}},  //   _koy_, _klii, žene,
  { {0xf767007a, 0xdd8f00b8, 0x0b4601be, 0x00000000}},  //   _ها_, سون_, лнен,
  { {0xa3e7062e, 0xa09b007b, 0x60c9001e, 0x00000000}},  //   _पास_, _ריכט, ņemt,
  { {0xa2d7006e, 0xf41f00b0, 0x44320145, 0x00000000}},  //   _बिस्, lmät_, _loy_,
  { {0x660101d9, 0x629e0087, 0x644401b1, 0x00000000}},  //   delk, _mipo, _olii,
  { {0xc6f8019d, 0x387f1f03, 0x44321f04, 0x00000000}},  //   вних_, glur_, _noy_,
  { {0xab660265, 0x44ce0036, 0x81dc0044, 0x00000000}},  //   _свал, wę_, ণ্য_,
  { {0x44201f05, 0x44ce0bd7, 0x64440020, 0x00000000}},  //   _ani_, tę_, _alii,
  { {0x7ae21e43, 0x4420023a, 0x387f04e2, 0x00000000}},  //   luot, _bni_, blur_,
  { {0x69ca00d4, 0x2b9a005a, 0x44320300, 0x00000000}},  //   lafe, _gücü_, _coy_,
  { {0x44201f06, 0x44ce0a67, 0x44320211, 0x00000000}},  //   _dni_, sę_, _doy_,
  { {0xe298008b, 0x44200059, 0x629e0197, 0x00000000}},  //   лаў_, _eni_, _cipo,
  { {0x629e0169, 0xbe0500a1, 0x765a00b0, 0x00000000}},  //   _dipo, یورٹ, mity,
  { {0x765a1f07, 0xa2ce001c, 0x7ae20006, 0x00000000}},  //   lity, _तिच्, kuot,
  { {0xcddb02a8, 0x147a026c, 0x2fc900c1, 0x00000000}},  // [49f0] ење_, _ججوں_, raag_,
  { {0x59e002f4, 0x765a0052, 0x7ae2010a, 0x00000000}},  //   _नागर, nity, duot,
  { {0x2d870afc, 0x44320022, 0x7afb0213, 0x00000000}},  //   åne_, _yoy_, _sput,
  { {0x78b8001c, 0x5b15003b, 0x66010046, 0x00000000}},  //   dpvv, имет, zelk,
  { {0x34c102f4, 0x7ae20006, 0x998c00b9, 0x00000000}},  //   _शब्द, guot, _bodů_,
  { {0x50b800d3, 0x08d5046c, 0x683501ca, 0x00000000}},  //   _جدید_, ация, _nádr,
  { {0x1a6800a1, 0x765a0022, 0x3238009b, 0x00000000}},  //   دیلی_, dity, רטון_,
  { {0x66010d31, 0x2bbb0025, 0x00000000, 0x00000000}},  //   welk, _سارة_,   ,
  { {0x7bcb0725, 0x7afb1f08, 0x44200022, 0x00000000}},  //   magu, _uput, _rni_,
  { {0x44320219, 0x7bcb022b, 0x44201f09, 0x00000000}},  //   _soy_, lagu, _sni_,
  { {0x99670888, 0x629e1f0a, 0xb466007c, 0x00000000}},  //   _стал, _ripo, икол,
  { {0x68e314ce, 0x7bcb011c, 0x2aab0018, 0x00000000}},  //   mund, nagu, _køb_,
  { {0x68e3011f, 0x44320211, 0x6601002d, 0x00000000}},  //   lund, _voy_, pelk,
  { {0x7bcb000b, 0x44200093, 0x44320173, 0x00000000}},  //   hagu, _wni_, _woy_,
  { {0x68e3038c, 0x2056008b, 0x4420023a, 0x00000000}},  //   nund, атар, _tni_,
  { {0x645d1729, 0x7bcb0093, 0xf09f0026, 0x00000000}},  //   érit, jagu, _cià_,
  { {0x7bcb1f0b, 0xd00705f6, 0x6b890dfc, 0x00000000}},  // [4a00] dagu, шете_, _nzeg,
  { {0x68e3022b, 0x7ae2042c, 0x7e23003b, 0x00000000}},  //   kund, vuot, одуж,
  { {0x68e3006c, 0x6b890026, 0x7bcb0145, 0x00000000}},  //   jund, _azeg, fagu,
  { {0xdee60113, 0xf09f1f0c, 0x68e3002d, 0x00000000}},  //   _коми, _già_, dund,
  { {0x69ca0016, 0x6b890036, 0xc5fe0044, 0x00000000}},  //   tafe, _czeg, ্ঞতা_,
  { {0x68e305de, 0x7ae2010a, 0xaa530451, 0x00000000}},  //   fund, ruot, овіш,
  { {0x68e30df9, 0x765a00b0, 0x7bcb0503, 0x00000000}},  //   gund, vity, bagu,
  { {0x63a40058, 0xa2d7007d, 0x69ca014a, 0x00000000}},  //   _ngin, _बिल्, safe,
  { {0x09e6007c, 0x765a1f0d, 0x68350051, 0x00000000}},  //   _возн, tity, _pádr,
  { {0x68e3000c, 0x63a4022b, 0xd83810f7, 0x00000000}},  //   bund, _agin, _muči_,
  { {0x24420219, 0x69c802ae, 0x765a0943, 0x00000000}},  //   _cómo_, _iede, rity,
  { {0x765a021e, 0x69c8014a, 0x290c011c, 0x00000000}},  //   sity, _hede, _isda_,
  { {0x69c80475, 0x59ba0204, 0xe87500a1, 0x00000000}},  //   _kede, _उभार, _اننگ,
  { {0x69c8001f, 0x63a4022b, 0x7bcb002d, 0x00000000}},  //   _jede, _egin, zagu,
  { {0x69c80fcf, 0x645d00f4, 0x7bcb0093, 0x00000000}},  //   _mede, éris, yagu,
  { {0x69c81e68, 0xd8380087, 0x78a804a5, 0x00000000}},  //   _lede, _buči_, _mudv,
  { {0x69c800bb, 0x9df902b3, 0x68e31f0e, 0x00000000}},  // [4a10] _oede, лнат_, zund,
  { {0x3869037e, 0x7bcb1f0f, 0x683c00f4, 0x00000000}},  //   čari_, wagu, _dédi,
  { {0x7bcb011c, 0x6b890047, 0x68e31f10, 0x00000000}},  //   tagu, _szeg, xund,
  { {0x68e31f11, 0x69c81f12, 0x62950026, 0x00000000}},  //   vund, _aede, lmzo,
  { {0x290c0ca4, 0xd838016c, 0x68e3010f, 0x00000000}},  //   _asda_, _guči_, wund,
  { {0x69c8027b, 0x7bcb10a4, 0xa969003b, 0x00000000}},  //   _cede, sagu, лила_,
  { {0x7bcb002d, 0x69c81f13, 0x9915007e, 0x00000000}},  //   pagu, _dede, сьлі,
  { {0xccf200b6, 0x645d0453, 0x8c3d014a, 0x00000000}},  //   _מכל_, jisi, _bişe,
  { {0x69c800d6, 0x63a400f6, 0x00000000, 0x00000000}},  //   _fede, _rgin,   ,
  { {0x69c801b5, 0x68e3013f, 0x00000000, 0x00000000}},  //   _gede, pund,   ,
  { {0x645d1f14, 0xda7a0049, 0x63a400f6, 0x00000000}},  //   fisi, _ענער, _pgin,
  { {0x6aa1001f, 0x645d011c, 0xafdb00ea, 0x00000000}},  //   _hilf, gisi, _bløm,
  { {0xd8740025, 0x69c8014a, 0x7bc90328, 0x00000000}},  //   _بالب, _yede, _meeu,
  { {0x7bc901b5, 0x683c00f4, 0x69c8002d, 0x00000000}},  //   _leeu, _rédi, _xede,
  { {0x6143008b, 0x6aa10061, 0x64b50137, 0x00000000}},  //   пера, _milf, _احتر,
  { {0x44f100b9, 0x683c009d, 0x63a41f15, 0x00000000}},  //   má_, _pédi, _ugin,
  { {0x44f11f16, 0xef1a1f17, 0x76410133, 0x00000000}},  // [4a20] lá_, ыма_, okly,
  { {0x76410146, 0x6aa10146, 0x2d96007c, 0x00000000}},  //   nkly, _nilf, брес,
  { {0x44f10428, 0x69c80f12, 0x9f59004a, 0x00000000}},  //   ná_, _rede, _basó_,
  { {0x9f59008e, 0x683c00fa, 0x1eaa0025, 0x00000000}},  //   _casó_, _tédi, _ماسي_,
  { {0x7ff700a2, 0x6aa10239, 0x44f10161, 0x00000000}},  //   _اسپا, _bilf, há_,
  { {0x645d027d, 0x2fc006be, 0x29180010, 0x00000000}},  //   zisi, lbig_, _árak_,
  { {0x69c81d22, 0x645d08af, 0xa3d8007d, 0x00000000}},  //   _vede, yisi, ाणा_,
  { {0x69c8037f, 0xdd8f0025, 0x44f11f18, 0x00000000}},  //   _wede, _سوق_, dá_,
  { {0x69c81f19, 0x2ee00016, 0x44270082, 0x00000000}},  //   _tede, nrif_, _đn_,
  { {0x645d0016, 0x7bc90376, 0x6aa10544, 0x00000000}},  //   wisi, _zeeu, _gilf,
  { {0x645d0d2a, 0x998601b7, 0xd7fa05f6, 0x00000000}},  //   tisi, _الاو, _бул_,
  { {0x3d0003d7, 0x2ee00935, 0x225a0c7d, 0x00000000}},  //   _रहने_, krif_, _ampk_,
  { {0xd79606ea, 0x645d1f1a, 0x073a0318, 0x00000000}},  //   _الشخ, risi, _حساب_,
  { {0x2ee016a7, 0x76410203, 0xa7850389, 0x00000000}},  //   drif_, ckly, _بشمو,
  { {0x6e350721, 0x645d0091, 0xd25801ff, 0x00000000}},  //   _rozb, pisi, сця_,
  { {0x2ee0018e, 0xdbf100b9, 0x8c3d001a, 0x00000000}},  //   frif_, _přík, _mişc,
  { {0x9412006b, 0x4034007c, 0x6e3515b1, 0x00000000}},  // [4a30] _niyə_, четс, _pozb,
  { {0x3dd81f1b, 0x00000000, 0x00000000, 0x00000000}},  //   _cdrw_,   ,   ,
  { {0x9f590211, 0x6e35012d, 0x64b30035, 0x00000000}},  //   _pasó_, _vozb, _tăie,
  { {0xd1b8025a, 0xbebb0065, 0x6aa11f1c, 0x00000000}},  //   _پایا_, _rrëf, _silf,
  { {0x79810610, 0xab2903dc, 0x44f10211, 0x00000000}},  //   _sylw, рола_, zá_,
  { {0x6ca70242, 0x6e350107, 0x683c0299, 0x00000000}},  //   _граж, _uozb, _médu,
  { {0x44f100c4, 0x6aa11f1d, 0x768f00ea, 0x00000000}},  //   xá_, _vilf, nøye,
  { {0x81c10055, 0x44f10428, 0xeaf800d3, 0x00000000}},  //   ুলি_, vá_, _گرفت_,
  { {0x6aa10374, 0xb8d00309, 0x2d830023, 0x00000000}},  //   _tilf, _टू_, _hyje_,
  { {0xe81e0061, 0x44f10027, 0x8f9c0049, 0x00000000}},  //   _मोठा_, tá_, ניזי,
  { {0x2fc00009, 0x386a0048, 0x44f100fa, 0x00000000}},  //   ybig_, úiré_, uá_,
  { {0x78a20198, 0x225a04be, 0x00000000, 0x00000000}},  //   _giov, _smpk_,   ,
  { {0x6842008b, 0x683c1f1e, 0xd6290aed, 0x00000000}},  //   _інша, _cédu, _воле_,
  { {0x38690107, 0x44f10181, 0x683c1f1f, 0x00000000}},  //   čaru_, pá_, _dédu,
  { {0x6f1d14c3, 0xc05a003b, 0xd6780025, 0x00000000}},  //   _arsc, арац_, _احنا_,
  { {0x44d5001e, 0xe3b201fa, 0xe2e6073b, 0x00000000}},  //   mā_, _غرب_, _джип,
  { {0x44d5001e, 0x44c70010, 0x3ea30a5b, 0x00000000}},  // [4a40] lā_, lő_, _bijt_,
  { {0x22570025, 0x3eab0133, 0x2ee00fd1, 0x00000000}},  //   _وليد_, _duct_, rrif_,
  { {0x44d5001e, 0x6f1d010f, 0x2ee0012d, 0x00000000}},  //   nā_, _ersc, srif_,
  { {0x984c00b9, 0xb4fa0049, 0x00000000, 0x00000000}},  //   věď_, ילער,   ,
  { {0xb6050e0d, 0x3eb900bb, 0x3f82014a, 0x00000000}},  //   _kršč, _gtst_, _uyku_,
  { {0x44d5001e, 0x24800145, 0x00000000, 0x00000000}},  //   kā_, _lkim_,   ,
  { {0x44d5001e, 0x7c060025, 0xbea3008b, 0x00000000}},  //   jā_, _وبرك, _царк,
  { {0x44d50089, 0x473401fc, 0xec770364, 0x00000000}},  //   dā_, знис, _дпс_,
  { {0xf09301f8, 0x7bc200f4, 0x466a0437, 0x00000000}},  //   ונה_, mbou, иром_,
  { {0x683c00f4, 0x7bc21f20, 0x248001a3, 0x00000000}},  //   _rédu, lbou, _akim_,
  { {0x683c00f4, 0xe45f00b0, 0x44d50089, 0x00000000}},  //   _sédu, tiö_, gā_,
  { {0x7bc21f21, 0x80b10204, 0xd838012d, 0x00000000}},  //   nbou, _आंबे, _puču_,
  { {0xfbd300b6, 0x63a90466, 0xe45f00b0, 0x00000000}},  //   ותר_, ženo, riö_,
  { {0xa3e702d2, 0x2480014a, 0x46140879, 0x00000000}},  //   _पाक_, _ekim_, _روبر,
  { {0x63b60016, 0xa2d7006e, 0x7ae201a2, 0x00000000}},  //   _ffyn, _बिक्, hrot,
  { {0x7ae20036, 0x1eab0389, 0x00000000, 0x00000000}},  //   krot, لائي_,   ,
  { {0xddab1666, 0x7bc200d9, 0x69da0235, 0x00000000}},  // [4a50] ател_, dbou, _odte,
  { {0x291e0279, 0x7ae21543, 0x325501ff, 0x00000000}},  //   _orta_, drot, _хвор,
  { {0x61f8006b, 0x62870091, 0x30f700a1, 0x00000000}},  //   _övla, mljo, _بوجھ_,
  { {0x69da1f22, 0x7bc200bb, 0x7ae200f2, 0x00000000}},  //   _adte, gbou, frot,
  { {0x44c70047, 0x7ae200c7, 0x291e001a, 0x00000000}},  //   ző_, grot, _arta_,
  { {0x6f0d0020, 0xab5d002b, 0x00000000, 0x00000000}},  //   mwac, _jeżi,   ,
  { {0xa3eb006e, 0x7ae20026, 0x6f0d0270, 0x00000000}},  //   मला_, arot, lwac,
  { {0x44d50089, 0x3d00013d, 0x2bcc0061, 0x00000000}},  //   vā_, _रहते_, ारणा,
  { {0x787e0023, 0x78ba00ea, 0x291e0145, 0x00000000}},  //   tëvr, _ettv, _erta_,
  { {0x44d5001e, 0x44c70047, 0xe649003b, 0x00000000}},  //   tā_, tő_, спод_,
  { {0x69c30059, 0x6f0d010f, 0x64b30035, 0x00000000}},  //   mbne, hwac, _băia,
  { {0x44d50089, 0x78fa009b, 0x764a005b, 0x00000000}},  //   rā_, _לפעו, _elfy,
  { {0x44d50089, 0x93430a1e, 0x38b1000c, 0x00000000}},  //   sā_, еняе, _hár_,
  { {0x27ed0270, 0x44d50089, 0x76ba00b3, 0x00000000}},  //   lgen_, pā_, _המספ,
  { {0x20d701d5, 0x38b10010, 0x7bc202c2, 0x00000000}},  //   għi_, _jár_, ybou,
  { {0x38b10010, 0x216700ed, 0x644f1f23, 0x00000000}},  //   _már_, чиси_, chci,
  { {0x27ed059b, 0x62871217, 0x38b10051, 0x00000000}},  // [4a60] igen_, bljo, _lár_,
  { {0x2d96003b, 0x644600b0, 0x7bc200d9, 0x00000000}},  //   прес, lkki, wbou,
  { {0x60261f24, 0x7bc20dda, 0x38b10af6, 0x00000000}},  //   _една, tbou, _nár_,
  { {0x27ed02ae, 0xeb9a1f25, 0x6446021e, 0x00000000}},  //   jgen_, бие_, nkki,
  { {0x291e004a, 0x27ed113b, 0x7bc20f12, 0x00000000}},  //   _srta_, dgen_, rbou,
  { {0x7ae2002d, 0x38b10047, 0x27ed05c6, 0x00000000}},  //   rrot, _bár_, egen_,
  { {0xdd8600a1, 0x66081f26, 0x7ae20048, 0x00000000}},  //   _رجسٹ, vedk, srot,
  { {0x27ed02ae, 0x7e7e028c, 0x7ae20213, 0x00000000}},  //   ggen_, lopp, prot,
  { {0xab5d0036, 0x00000000, 0x00000000, 0x00000000}},  //   _odży,   ,   ,
  { {0x7e7e0056, 0x0f57009b, 0x291e00ee, 0x00000000}},  //   nopp, פיים_, _trta_,
  { {0xab5d1f27, 0x320a032e, 0x66080142, 0x00000000}},  //   _reżi, deby_, redk,
  { {0x33200646, 0x27ed00e5, 0x6f0d00b4, 0x00000000}},  //   _brix_, cgen_, ywac,
  { {0xafdb068f, 0x00000000, 0x00000000, 0x00000000}},  //   _kløv,   ,   ,
  { {0x56b700a0, 0x644f004a, 0x00000000, 0x00000000}},  //   _צפון_, shci,   ,
  { {0xd5fb00b6, 0x7e7e0056, 0x64b31f28, 0x00000000}},  //   _הפור, dopp, _tăia,
  { {0xd468045e, 0xb4d8001c, 0x11f70014, 0x00000000}},  //   _није_, ाळी_, _کودک_,
  { {0x44291f29, 0x7a3d1f2a, 0x645f0066, 0x00000000}},  // [4a70] _ina_, _mètr, _imqi,
  { {0x6f0d1f2b, 0x9f40009f, 0x3f870089, 0x00000000}},  //   rwac, rfið_, ānu_,
  { {0x644d1750, 0x6abb00ab, 0x27ed00ab, 0x00000000}},  //   _klai, _stuf, ygen_,
  { {0x4429037e, 0x26d91f2c, 0x27ed01f3, 0x00000000}},  //   _jna_, ások_, xgen_,
  { {0x44290142, 0x38b11f2d, 0x7e7e00ea, 0x00000000}},  //   _mna_, _sár_, bopp,
  { {0x38b113aa, 0x7e7e0197, 0x644d0016, 0x00000000}},  //   _pár_, copp, _llai,
  { {0x4429005f, 0x27ed00d4, 0x644d1f2e, 0x00000000}},  //   _ona_, tgen_, _olai,
  { {0x63a90f3a, 0xccf20104, 0x442900ea, 0x00000000}},  //   ženj, _שכן_, _nna_,
  { {0x7c290207, 0xf1bf0309, 0x64b300e5, 0x00000000}},  //   _iner, ्रान, _căin,
  { {0x4429011f, 0x7c3b0038, 0x27ed005b, 0x00000000}},  //   _ana_, _hour, sgen_,
  { {0x644d018e, 0x7c3b0263, 0x240a0401, 0x00000000}},  //   _blai, _kour, онни_,
  { {0x3320028c, 0x7c3b030a, 0x644d0549, 0x00000000}},  //   _prix_, _jour, _clai,
  { {0x7c3b0263, 0x6446021e, 0x442900ab, 0x00000000}},  //   _mour, rkki, _dna_,
  { {0x7c3b0f07, 0x4429040e, 0x644d0c61, 0x00000000}},  //   _lour, _ena_, _elai,
  { {0x386d033d, 0xa3e7001c, 0x7c29065d, 0x00000000}},  //   oner_, _पाच_, _oner,
  { {0x386d04d3, 0x7c3b00f4, 0x644d1189, 0x00000000}},  //   nner_, _nour, _glai,
  { {0x386d010f, 0xa0670745, 0x09e50044, 0x00000000}},  // [4a80] iner_, фата_, প্যা,
  { {0x44290119, 0x387f0b8b, 0x386d010f, 0x00000000}},  //   _zna_, hour_, hner_,
  { {0x4429018e, 0x7e7e133a, 0x386d1f2f, 0x00000000}},  //   _yna_, ropp, kner_,
  { {0x7c3b030a, 0x387f00f4, 0x7e7e0056, 0x00000000}},  //   _cour, jour_, sopp,
  { {0x7c3b0181, 0x386d01e7, 0x387f009d, 0x00000000}},  //   _dour, dner_, dour_,
  { {0x386d006c, 0xf6470025, 0xa6e2000c, 0x00000000}},  //   ener_, _شئ_, _æðis,
  { {0x387f027b, 0x7c3b032c, 0x7aeb0006, 0x00000000}},  //   four_, _four, augt,
  { {0xd6da0200, 0x386d1f30, 0x7c3b00f4, 0x00000000}},  //   ото_, gner_, _gour,
  { {0x6e3c023a, 0xd90e026c, 0x63a90161, 0x00000000}},  //   _korb, _چیت_, ženk,
  { {0x4429002a, 0x644d1f31, 0xdb1901aa, 0x00000000}},  //   _sna_, _slai, pawò,
  { {0x6e3c0207, 0x386d0302, 0x644d028a, 0x00000000}},  //   _morb, bner_, _plai,
  { {0x6e3c01c3, 0x2121008e, 0x387f0f8e, 0x00000000}},  //   _lorb, _rrhh_, cour_,
  { {0x6e3c07a5, 0x644d0b94, 0x44290082, 0x00000000}},  //   _oorb, _vlai, _vna_,
  { {0x6e3c022b, 0x4429005b, 0x6aa80066, 0x00000000}},  //   _norb, _wna_, _jidf,
  { {0x6aa80719, 0x30a7017f, 0x00000000, 0x00000000}},  //   _midf, драв,   ,
  { {0x442908d3, 0x44f81f32, 0x672204eb, 0x00000000}},  //   _una_, mé_, _kroj,
  { {0x6e3c0363, 0x44f81d1f, 0x63ad13d2, 0x00000000}},  // [4a90] _borb, lé_, _igan,
  { {0x7c3b030a, 0x3ea71f33, 0x7c29000c, 0x00000000}},  //   _sour, önt_, _sner,
  { {0x44f8004f, 0x7c3b032c, 0x2d870030, 0x00000000}},  //   né_, _pour, æne_,
  { {0x22840039, 0x7aeb0c23, 0x67221f34, 0x00000000}},  //   sökt_, tugt, _oroj,
  { {0x6e3c1f35, 0x44f801ca, 0xfbd0007a, 0x00000000}},  //   _forb, hé_, شتن_,
  { {0x2019022b, 0x386d0675, 0x44f80062, 0x00000000}},  //   _hasi_, wner_, ké_,
  { {0x2019006a, 0x386d0c53, 0x387f028c, 0x00000000}},  //   _kasi_, tner_, tour_,
  { {0x67220119, 0x44f807e4, 0x63ad1f36, 0x00000000}},  //   _broj, dé_, _ngan,
  { {0x20190093, 0xd706007c, 0x6d450516, 0x00000000}},  //   _masi_, еные_, lyha,
  { {0x386d0190, 0x20191f37, 0x63ad094f, 0x00000000}},  //   sner_, _lasi_, _agan,
  { {0x44f800f4, 0x66181a2d, 0x20191f38, 0x00000000}},  //   gé_, _davk, _oasi_,
  { {0x20190727, 0xa01b0039, 0x67221f39, 0x00000000}},  //   _nasi_, _skön, _froj,
  { {0x67220006, 0x64ba0066, 0x00000000, 0x00000000}},  //   _groj, _rċie,   ,
  { {0x63ad027b, 0x44f80161, 0xe60500b0, 0x00000000}},  //   _egan, bé_, ärää,
  { {0x2019000b, 0x7d020046, 0x44f800f4, 0x00000000}},  //   _basi_, łosz, cé_,
  { {0x20190e1d, 0x6e3c0010, 0x543609bc, 0x00000000}},  //   _casi_, _sorb, _سربر,
  { {0x64960051, 0x20190093, 0x2cbf0091, 0x00000000}},  // [4aa0] ráid, _dasi_, _čuda_,
  { {0x64960051, 0x09e50044, 0x63ad1f3a, 0x00000000}},  //   sáid, প্তা, _zgan,
  { {0x6e3c1f3b, 0x09d80044, 0x20190197, 0x00000000}},  //   _vorb, সলমা, _fasi_,
  { {0xfbd200f3, 0x2019001a, 0xeb9a1548, 0x00000000}},  //   اتا_, _gasi_, пие_,
  { {0x98a70006, 0x76480006, 0x20570049, 0x00000000}},  //   lynė_, ykdy, _טיטל_,
  { {0x44f800f4, 0xb8660014, 0x67220023, 0x00000000}},  //   yé_, کاتو, _rroj,
  { {0x321a067f, 0x44f81f3c, 0x64b300e5, 0x00000000}},  //   _mapy_, xé_, _băim,
  { {0x44f80428, 0x63a90027, 0x660300e0, 0x00000000}},  //   vé_, ženi, _abnk,
  { {0xd5bd02fb, 0x6aa800ea, 0xb6a50082, 0x00000000}},  //   ोरंज, _tidf, _thậ,
  { {0x44f81f3d, 0x63ad1f3e, 0x64401bf0, 0x00000000}},  //   té_, _sgan, ömin,
  { {0x44f8009d, 0x63ad0026, 0x3a2c00f6, 0x00000000}},  //   ué_, _pgan, _indp_,
  { {0x44f80428, 0xe73a007c, 0xe7ea007d, 0x00000000}},  //   ré_, _нее_, _टाटा_,
  { {0x44f800f4, 0x2019007f, 0x0614007e, 0x00000000}},  //   sé_, _rasi_, _адлю,
  { {0x20190307, 0xbebb0023, 0x00000000, 0x00000000}},  //   _sasi_, _brën,   ,
  { {0x2019008d, 0xdfd50147, 0xc693071c, 0x00000000}},  //   _pasi_, ковы, _גאס_,
  { {0x63ad0020, 0x8c3d014a, 0x244201e5, 0x00000000}},  //   _ugan, _pişm, _dóms_,
  { {0x20190059, 0x747c0097, 0x7d150087, 0x00000000}},  // [4ab0] _vasi_, _מנהג, _sszs,
  { {0x44390039, 0x20191f3f, 0xbebb0023, 0x00000000}},  //   ljs_, _wasi_, _frën,
  { {0x7059007c, 0x27ff0095, 0x00000000, 0x00000000}},  //   _жанр_, yfun_,   ,
  { {0x20191b6f, 0x2d8a0190, 0x443901c5, 0x00000000}},  //   _uasi_, _dybe_, njs_,
  { {0x2fc9011c, 0x7de70088, 0xee3f0011, 0x00000000}},  //   mbag_, _півд, _buýt_,
  { {0x3eaa001f, 0xd2b800b3, 0x2fc9013e, 0x00000000}},  //   _gibt_, עלות_, lbag_,
  { {0xdd9407d0, 0x7ae4002b, 0x99d40439, 0x00000000}},  //   _бары, ġita, اتها,
  { {0x2fc90a5e, 0x00000000, 0x00000000, 0x00000000}},  //   nbag_,   ,   ,
  { {0x39490580, 0x443900d2, 0x00000000, 0x00000000}},  //   ņas_, djs_,   ,
  { {0x9f400197, 0xa01b092e, 0xe6450256, 0x00000000}},  //   ggiù_, _sköl, теоп,
  { {0x2ee91f40, 0x57f502dc, 0x00000000, 0x00000000}},  //   hraf_, _апет,   ,
  { {0xbebb0065, 0xb9360049, 0x99641c0a, 0x00000000}},  //   _rrën, _ברעג_, _стул,
  { {0x321a009d, 0xae02006e, 0x00000000, 0x00000000}},  //   _papy_, र्डन_,   ,
  { {0x2ee91f41, 0x00000000, 0x00000000, 0x00000000}},  //   draf_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3eaa002b, 0x2fc90058, 0x88e30044, 0x00000000}},  //   _sibt_, gbag_, _মহাক,
  { {0xf4870123, 0xdfcf0379, 0x10a30264, 0x00000000}},  // [4ac0] _جاوی, زيل_, ритн,
  { {0xc33300a0, 0x78ab1f42, 0x394701e5, 0x00000000}},  //   _כוח_, _ligv, kyns_,
  { {0x2fc91f43, 0x777901f3, 0x00000000, 0x00000000}},  //   bbag_, _lxwx,   ,
  { {0x0b4601e1, 0xee3f0082, 0x628e124c, 0x00000000}},  //   кнен, _suýt_, llbo,
  { {0x768f0056, 0x628e01c3, 0x00000000, 0x00000000}},  //   tøyl, olbo,   ,
  { {0xee3f0082, 0xdb0900d9, 0x00000000, 0x00000000}},  //   _quýt_, _egeï,   ,
  { {0x9e6303f3, 0x628e00d9, 0x00000000, 0x00000000}},  //   _тврд, ilbo,   ,
  { {0xb81407d8, 0xdd8f1095, 0xa9270088, 0x00000000}},  //   удиј, _ذوق_, тіше_,
  { {0xae02006e, 0xc6f7007c, 0xe5c602d3, 0x00000000}},  //   र्थन_, вных_, ксно,
  { {0x8f9b01ce, 0x953800ed, 0x44ce013e, 0x00000000}},  //   ויפי, езот_, tř_,
  { {0x39581a95, 0x499300a1, 0xa01b000c, 0x00000000}},  //   _års_, _پیٹر, _sköm,
  { {0x69d8009f, 0x443f009f, 0xae02006e, 0x00000000}},  //   lave, ðu_, र्तन_,
  { {0x38b8009f, 0xc458007c, 0x00000000, 0x00000000}},  //   _hér_, тиях_,   ,
  { {0xe298008b, 0x69d81f44, 0xdb090068, 0x00000000}},  //   каў_, nave, énég,
  { {0x44391f45, 0x2cbf0091, 0x2fc91f46, 0x00000000}},  //   pjs_, _čudo_, tbag_,
  { {0x38b80359, 0x69d805b7, 0x628e013e, 0x00000000}},  //   _mér_, have, albo,
  { {0x2fc90142, 0x69d81f47, 0x2d8e010f, 0x00000000}},  // [4ad0] rbag_, kave, üfen_,
  { {0x2ee91f48, 0x1d6b01f7, 0x5dd500a1, 0x00000000}},  //   rraf_, وصاً_, اقائ,
  { {0xf3ff02d5, 0x3da7008b, 0x94170061, 0x00000000}},  //   nião_, траб, _तसाच_,
  { {0x8c3d047f, 0x321108d2, 0x24890085, 0x00000000}},  //   _kişi, lezy_, _jkam_,
  { {0x81d60055, 0x69d81edb, 0x99850035, 0x00000000}},  //   _হাত_, fave, _balş_,
  { {0xfe71089d, 0x69d8068f, 0xf41f021e, 0x00000000}},  //   _اگر_, gave, hdä_,
  { {0x08d4008b, 0xdddc0521, 0x1ce900a1, 0x00000000}},  //   ацыя, _ukrš, _سکاٹ_,
  { {0x39470c73, 0x22411013, 0x768f0056, 0x00000000}},  //   ryns_, _lohk_, røym,
  { {0x69d8004f, 0xfc64005e, 0x64560065, 0x00000000}},  //   bave, _търн, ëzim,
  { {0x996701e0, 0x69d800d4, 0x69ca0316, 0x00000000}},  //   _ител, cave, _स्पी,
  { {0xf3ff02d5, 0x04460264, 0x6fd30061, 0x00000000}},  //   gião_, генн, तरां,
  { {0x8c3d0276, 0x26d90010, 0x36d501ab, 0x00000000}},  //   _bişi, ásos_, _бодр,
  { {0x66e50517, 0x6f070089, 0x00000000, 0x00000000}},  //   _сола, nībā,   ,
  { {0x2cad063c, 0x09e50044, 0x41a50164, 0x00000000}},  //   _lied_, প্রা, _गृहस,
  { {0x50b5012b, 0x09d80055, 0xe297003b, 0x00000000}},  //   исту, _সামা, уар_,
  { {0x3dcd0044, 0x69d81f49, 0x8c3d1f4a, 0x00000000}},  //   _লাগল, zave, _fişi,
  { {0x7afd01a2, 0x7bd90022, 0x00000000, 0x00000000}},  // [4ae0] _ästh, dawu,   ,
  { {0x533700a3, 0xed5a06e7, 0x2bcc007d, 0x00000000}},  //   _ענין_, ноз_, ार्थ,
  { {0x01fb012f, 0x2cad1f4b, 0x69d80181, 0x00000000}},  //   _אפיל, _bied_, vave,
  { {0x3ce60027, 0x69d80472, 0x00000000, 0x00000000}},  //   čov_, wave,   ,
  { {0x38b8009f, 0x69d81f4c, 0x20121f4d, 0x00000000}},  //   _sér_, tave, meyi_,
  { {0x20120180, 0xd37b0049, 0x2ab9000a, 0x00000000}},  //   leyi_, ערסט, _dèb_,
  { {0xdd920167, 0x69d801ca, 0xf41f00b0, 0x00000000}},  //   _طور_, rave, ydä_,
  { {0x06c80044, 0x2ab901aa, 0x6456008f, 0x00000000}},  //   _শিবি, _fèb_, ūzij,
  { {0xd5b00054, 0xc9f60379, 0x6f070089, 0x00000000}},  //   يفة_, _مساع, cībā,
  { {0x24891beb, 0x6aca0044, 0x38b80010, 0x00000000}},  //   _skam_, _রিপো, _tér_,
  { {0x2ab901aa, 0xbebb0065, 0x24590088, 0x00000000}},  //   _zèb_, _rrëm, вань_,
  { {0xf99300a0, 0x8c3d005d, 0xf3ff00fa, 0x00000000}},  //   _הרע_, _pişi, rião_,
  { {0x41e7008b, 0xf3ff0181, 0xf64f00a1, 0x00000000}},  //   ліва, sião_, زئی_,
  { {0xa54600a1, 0xd627012b, 0x51870478, 0x00000000}},  //   _مضبو, _боље_, губа,
  { {0x64960a87, 0x7bd90045, 0x00000000, 0x00000000}},  //   máin, yawu,   ,
  { {0x60180245, 0x64960051, 0x00000000, 0x00000000}},  //   лося_, láin,   ,
  { {0xe8060204, 0x2cad0bdf, 0x93f6006b, 0x00000000}},  // [4af0] व्या_, _ried_, şəcə,
  { {0x63a90161, 0x2cad1f4e, 0x290c04a5, 0x00000000}},  //   žens, _sied_, _opda_,
  { {0x2cad00f4, 0x61e50869, 0x201206af, 0x00000000}},  //   _pied_, _idhl, beyi_,
  { {0x62870145, 0x3d05007d, 0x6f070089, 0x00000000}},  //   lojo, _रहीं_, tībā,
  { {0x1614013d, 0x649d0051, 0x69d9013d, 0x00000000}},  //   तजार_, méid, _नजदी,
  { {0x38661261, 0xeab0007a, 0x628708ad, 0x00000000}},  //   _amor_, سعه_, nojo,
  { {0xa3c5013d, 0x6f070089, 0x2ab901aa, 0x00000000}},  //   एडा_, sībā, _wèb_,
  { {0xaae700b8, 0xa6e5003b, 0x00000000, 0x00000000}},  //   _مسئو, ажил,   ,
  { {0xfd10026c, 0x62870089, 0x869901f9, 0x00000000}},  //   _وجہ_, kojo, ктот_,
  { {0xe7080025, 0x60c50518, 0x7b741f4f, 0x00000000}},  //   اتين_, _othm, _اطفا,
  { {0x48150680, 0x6f160036, 0x628708ad, 0x00000000}},  //   _вмес, zwyc, dojo,
  { {0xd46a0d68, 0x61e50048, 0x00000000, 0x00000000}},  //   тиме_, _adhl,   ,
  { {0xd6c301ef, 0x62870a15, 0x64960a87, 0x00000000}},  //   _امتی, fojo, báin,
  { {0x35a5007e, 0xe5a50364, 0x64960051, 0x00000000}},  //   _калг, _кили, cáin,
  { {0xa06a0467, 0x2012014a, 0x649d0048, 0x00000000}},  //   вава_, teyi_, féid,
  { {0x7643005b, 0x00000000, 0x00000000, 0x00000000}},  //   _hony,   ,   ,
  { {0x764318cf, 0x6287040d, 0x3329008e, 0x00000000}},  // [4b00] _kony, bojo, _grax_,
  { {0x44201f50, 0x76431f51, 0x44320085, 0x00000000}},  //   _hai_, _jony, _hny_,
  { {0x4420010a, 0x7643008a, 0x44321f52, 0x00000000}},  //   _kai_, _mony, _kny_,
  { {0x44200f0d, 0x09d80055, 0x649d0051, 0x00000000}},  //   _jai_, _সাধা, réig,
  { {0x442007c8, 0x2b16007c, 0xee3f0082, 0x00000000}},  //   _mai_, рьер, _tuýp_,
  { {0x44201f53, 0xae0202fb, 0x38660645, 0x00000000}},  //   _lai_, र्शन_, _smor_,
  { {0x09cf0044, 0x44200082, 0xfce3041f, 0x00000000}},  //   _রাখা, _oai_, _моро,
  { {0x44201f54, 0xd90d0167, 0x64440026, 0x00000000}},  //   _nai_, عین_, _noii,
  { {0x04f20055, 0x2ee00169, 0xa2b202f4, 0x00000000}},  //   _জনের_, nsif_, _इंग्,
  { {0x44320a2c, 0x7c22010f, 0x76430d62, 0x00000000}},  //   _any_, ldor, _cony,
  { {0x4420022b, 0x7c20002b, 0x76430058, 0x00000000}},  //   _bai_, _kamr, _dony,
  { {0x7c220710, 0x442002d4, 0x4432175b, 0x00000000}},  //   ndor, _cai_, _cny_,
  { {0x44200198, 0x628708ad, 0x443200b9, 0x00000000}},  //   _dai_, tojo, _dny_,
  { {0x1779008b, 0xb287007e, 0x44320093, 0x00000000}},  //   _ёсць_, рымк, _eny_,
  { {0x44201f55, 0x62870027, 0xd5af0140, 0x00000000}},  //   _fai_, rojo, _фс_,
  { {0x44201f56, 0x7c200059, 0x76430173, 0x00000000}},  //   _gai_, _namr, _zony,
  { {0x7c22018e, 0x81d60044, 0x76430009, 0x00000000}},  // [4b10] ddor, _হার_, _yony,
  { {0x7d010039, 0xe3b00025, 0x44201f57, 0x00000000}},  //   _älsk, _ترى_, _zai_,
  { {0x2cb8098e, 0x442000a9, 0x2ee00022, 0x00000000}},  //   _curd_, _yai_, asif_,
  { {0x7c200082, 0x8c3d001a, 0x4c95007c, 0x00000000}},  //   _camr, _nişt, щиес,
  { {0x69c1010f, 0xa2cb0061, 0x64960051, 0x00000000}},  //   _pfle, तीच्, dáil,
  { {0x98e50054, 0x7c220325, 0x27e60022, 0x00000000}},  //   مكتو, ador, _adon_,
  { {0x7643096b, 0x94170061, 0xf09f0082, 0x00000000}},  //   _rony, _तसंच_, _khà_,
  { {0x764300b0, 0x64960051, 0x3eb91f58, 0x00000000}},  //   _sony, gáil, _kust_,
  { {0x3eb91f59, 0x44201f5a, 0x764301aa, 0x00000000}},  //   _just_, _rai_, _pony,
  { {0x44200004, 0x3eb90038, 0x27e601aa, 0x00000000}},  //   _sai_, _must_, _edon_,
  { {0xb9950054, 0x671c02fb, 0x44201f5b, 0x00000000}},  //   _الاب, _बैठक_, _pai_,
  { {0xf09f00ad, 0x645d0006, 0x64960051, 0x00000000}},  //   _nhà_, ūrin, cáil,
  { {0x44200580, 0x386d028c, 0x47a50044, 0x00000000}},  //   _vai_, mier_, _গ্রী,
  { {0x386d028c, 0x44201f5c, 0x6146013b, 0x00000000}},  //   lier_, _wai_, бега,
  { {0x44201082, 0x3eb90056, 0x6f1d1e2e, 0x00000000}},  //   _tai_, _aust_, _assc,
  { {0x386d0685, 0xe3b205d4, 0x3eb90061, 0x00000000}},  //   nier_, _عرب_, _bust_,
  { {0x44e301f6, 0x3eb91042, 0x8fa310a9, 0x00000000}},  // [4b20] lı_, _cust_, зате,
  { {0x7c20009f, 0x386d009d, 0x3eb90133, 0x00000000}},  //   _samr, hier_, _dust_,
  { {0x44e301f6, 0x2ee01184, 0x9f400197, 0x00000000}},  //   nı_, ssif_, ggiò_,
  { {0xaae60054, 0xa01b00f8, 0xb4fa0049, 0x00000000}},  //   مستو, _sköv, טלער,
  { {0x7c22008d, 0x09cf0055, 0x3eb905f7, 0x00000000}},  //   rdor, _রাজা, _gust_,
  { {0x44e3005f, 0x4df500c5, 0x09d80055, 0x00000000}},  //   kı_, _мяст, _সাহা,
  { {0x6f040089, 0x386d028c, 0xa3d80164, 0x00000000}},  //   ltic, fier_, िरा_,
  { {0x44e301f6, 0x6f040387, 0x00000000, 0x00000000}},  //   dı_, otic,   ,
  { {0x2bce001c, 0x6f04051b, 0x64960051, 0x00000000}},  //   _ह्या, ntic, ráil,
  { {0x59cf024c, 0xb8fe0044, 0x386d0116, 0x00000000}},  //   _स्पर, _তম_, aier_,
  { {0x69da001e, 0x386d002d, 0x994a002c, 0x00000000}},  //   _iete, bier_, _حلال_,
  { {0x7bc2028c, 0x69da1ef0, 0x6f040161, 0x00000000}},  //   ncou, _hete, ktic,
  { {0x7ae4002a, 0x69da0149, 0x136b044b, 0x00000000}},  //   áith, _kete, ушни_,
  { {0x69da008d, 0x3eb900b5, 0x44e3005a, 0x00000000}},  //   _jete, _rust_, bı_,
  { {0x44e301df, 0x6f040197, 0x7ea90006, 0x00000000}},  //   cı_, etic, _užpi,
  { {0x69da04c8, 0x6f040061, 0x7ae20205, 0x00000000}},  //   _lete, ftic, ksot,
  { {0x2557005f, 0x7bc201a3, 0x2ca600e0, 0x00000000}},  // [4b30] vələ_, dcou, dmod_,
  { {0x386d00b5, 0x69da0006, 0x291e0cfc, 0x00000000}},  //   zier_, _nete, _osta_,
  { {0xdd9b017a, 0xf09f0082, 0x93780bb6, 0x00000000}},  //   уша_, _thà_, _نصیر_,
  { {0xfebb0014, 0x2ca6098e, 0xa01b18f7, 0x00000000}},  //   _ماست_, gmod_, _sjöf,
  { {0x291e000d, 0x6f041e47, 0x7055007a, 0x00000000}},  //   _asta_, ctic, _هنگا,
  { {0x44e30676, 0x2557006b, 0x291e0058, 0x00000000}},  //   yı_, sələ_, _bsta_,
  { {0x386d1f5d, 0x69da1e53, 0xd942005e, 0x00000000}},  //   tier_, _dete, дещи,
  { {0xd6d10a4f, 0x7bc205f2, 0x5c74005e, 0x00000000}},  //   وقع_, ccou, _елст,
  { {0x291e1f5e, 0x386d04d7, 0x9f40009f, 0x00000000}},  //   _esta_, rier_, ngið_,
  { {0x69da0141, 0x44e3027d, 0x386d00fe, 0x00000000}},  //   _gete, tı_, sier_,
  { {0xe806001c, 0xa509003b, 0x64a6007e, 0x00000000}},  //   व्हा_, шена_, жана,
  { {0x44e301f6, 0x69da00bb, 0x6abb0020, 0x00000000}},  //   rı_, _zete, _kuuf,
  { {0x44e301f6, 0x69da011f, 0x8c1a0104, 0x00000000}},  //   sı_, _yete, בורי,
  { {0x59cf0164, 0x26cd054f, 0x44e3014a, 0x00000000}},  //   _स्मर, mpeo_, pı_,
  { {0x69c30051, 0x67290190, 0x645d0048, 0x00000000}},  //   icne, lvej, bhsi,
  { {0x6f040207, 0x645d010f, 0xa9270006, 0x00000000}},  //   ttic, chsi, mažė,
  { {0x67290030, 0x9f40000c, 0xc61c0044, 0x00000000}},  // [4b40] nvej, ggið_, তারা_,
  { {0xee3702e9, 0xa01b092e, 0x7bc20019, 0x00000000}},  //   ону_, _sköt, wcou,
  { {0x69da000d, 0x32180410, 0x09d80044, 0x00000000}},  //   _rete, mery_, _সালা,
  { {0x6f040209, 0x69da0149, 0x32181f5f, 0x00000000}},  //   ptic, _sete, lery_,
  { {0x7bc200f4, 0xbb430147, 0x2ca60016, 0x00000000}},  //   rcou, мецк, rmod_,
  { {0x1ad9008b, 0x98c60264, 0x7bc20549, 0x00000000}},  //   сьць_, осил, scou,
  { {0x7ae2002b, 0x69da071e, 0x7bc20009, 0x00000000}},  //   ssot, _vete, pcou,
  { {0xe8e0001d, 0x69da1f60, 0x00000000, 0x00000000}},  //   hiệp_, _wete,   ,
  { {0x69da0010, 0x645d0065, 0x32180aba, 0x00000000}},  //   _tete, ërim, kery_,
  { {0x78ba0004, 0x93f6006b, 0x00000000, 0x00000000}},  //   _tutv, şələ,   ,
  { {0x680200b9, 0x291e0213, 0x32180fb6, 0x00000000}},  //   _půjč, _usta_, dery_,
  { {0x2ef20007, 0xafdb00ea, 0x00000000, 0x00000000}},  //   kryf_, _fløy,   ,
  { {0x321800b4, 0xafdb0056, 0x00000000, 0x00000000}},  //   fery_, _gløy,   ,
  { {0x2ef20007, 0x32180a68, 0x00000000, 0x00000000}},  //   dryf_, gery_,   ,
  { {0x306b0098, 0x768f00ea, 0x00000000, 0x00000000}},  //   ајан_, røyt,   ,
  { {0x6295004a, 0x768f00ea, 0x00000000, 0x00000000}},  //   slzo, søyt,   ,
  { {0x32180142, 0x2a6c0087, 0x69c30133, 0x00000000}},  // [4b50] bery_, _omdb_, ycne,
  { {0x551e013d, 0x9f40000c, 0x32181f61, 0x00000000}},  //   _बनाए_, rgið_, cery_,
  { {0x8d6800ed, 0x7d050544, 0x3b1f0066, 0x00000000}},  //   ојца_, uths, _ssuq_,
  { {0x7d050ca4, 0x21210145, 0x00000000, 0x00000000}},  //   rths, _ishh_,   ,
  { {0x2cbf0ec4, 0x00000000, 0x00000000, 0x00000000}},  //   _čudu_,   ,   ,
  { {0xdcfb007a, 0x01d90044, 0x76b20036, 0x00000000}},  //   _پرسش_, _তাঁদ, _słyn,
  { {0x76b20036, 0x768f0056, 0x69c31f62, 0x00000000}},  //   _płyn, køyr, rcne,
  { {0x78a201ca, 0x787e0089, 0xd6c30014, 0x00000000}},  //   _chov, tīva, ومبی,
  { {0xf7710054, 0x78a20022, 0x321801c3, 0x00000000}},  //   عاب_, _dhov, yery_,
  { {0x67291f63, 0x0565007c, 0x38b10087, 0x00000000}},  //   rvej, звон, _išrm_,
  { {0x321800ab, 0xceb40097, 0x26cd01ee, 0x00000000}},  //   very_, ויץ_, speo_,
  { {0x32181f64, 0x59cf0309, 0x00000000, 0x00000000}},  //   wery_, _स्तर,   ,
  { {0x32180036, 0x29070066, 0x3a25014a, 0x00000000}},  //   tery_, ltna_, _kalp_,
  { {0x78a90023, 0x768f00ea, 0x00000000, 0x00000000}},  //   lmev, røys,   ,
  { {0x29070213, 0x753c01a2, 0xe3b200a6, 0x00000000}},  //   ntna_, ärzt, برگ_,
  { {0xa01b092e, 0x649d00c4, 0x32180652, 0x00000000}},  //   _skör, péia, sery_,
  { {0x32180387, 0x823601fa, 0x00000000, 0x00000000}},  // [4b60] pery_, _فردا,   ,
  { {0x29070a0f, 0xbebb0023, 0x00000000, 0x00000000}},  //   ktna_, _arës,   ,
  { {0x628e016e, 0xc1bb009b, 0x00000000, 0x00000000}},  //   mobo, _למיש,   ,
  { {0x628e0466, 0xdd8f0188, 0x78a90065, 0x00000000}},  //   lobo, دوم_, jmev,
  { {0x2007006b, 0x2a6c0181, 0x2905002b, 0x00000000}},  //   əni_, _pmdb_, _aqla_,
  { {0x78a20e0a, 0x19940605, 0x3a2500f6, 0x00000000}},  //   _shov, маля, _calp_,
  { {0xa3ac0309, 0x3a2500f6, 0x692300e2, 0x00000000}},  //   केत_, _dalp_, емја,
  { {0x24800295, 0x628e1f65, 0xc8660088, 0x00000000}},  //   _njim_, hobo, ятли,
  { {0x628e016e, 0x29071f66, 0x649d1059, 0x00000000}},  //   kobo, atna_, féin,
  { {0x78a20009, 0xc87f006b, 0x20020022, 0x00000000}},  //   _whov, ışam_, _lcki_,
  { {0xd7ef1867, 0x186a0184, 0x00000000, 0x00000000}},  //   _пу_, _лажи_,   ,
  { {0xf8aa012b, 0x00000000, 0x00000000, 0x00000000}},  //   _увек_,   ,   ,
  { {0x628e0061, 0xd90e0014, 0xa3be013d, 0x00000000}},  //   fobo, _شیک_, ेड़_,
  { {0x672200b0, 0x00000000, 0x00000000, 0x00000000}},  //   _isoj,   ,   ,
  { {0x06b100b9, 0x00000000, 0x00000000, 0x00000000}},  //   řící_,   ,   ,
  { {0x661a0010, 0x5597009b, 0xa01b0039, 0x00000000}},  //   letk, _מדוע_, _sjöb,
  { {0xead70055, 0x628e1f67, 0xbebb0023, 0x00000000}},  // [4b70] _সম্ম, bobo, _rrës,
  { {0x0378009b, 0x672d0521, 0x628e0253, 0x00000000}},  //   _מתחת_, _šajk, cobo,
  { {0x55bb0104, 0x8c3d014a, 0xef1f0095, 0x00000000}},  //   צמאו, _ahşa, _eyüp_,
  { {0x69c81f68, 0xfc64005e, 0x661a0103, 0x00000000}},  //   _afde, нъчн, hetk,
  { {0x0dcb017a, 0xcfab0014, 0xbebb0023, 0x00000000}},  //   _губи_, _دادم_, _erër,
  { {0x661a047c, 0x2296000c, 0x290718f7, 0x00000000}},  //   jetk, tæki_, ttna_,
  { {0x661a07a0, 0x649d0051, 0xed4e00a1, 0x00000000}},  //   detk, véin, _پھل_,
  { {0x29070059, 0x97d901e1, 0xfbd303ab, 0x00000000}},  //   rtna_, цьку_, _ستر_,
  { {0x628e0061, 0x260103d7, 0x29070059, 0x00000000}},  //   yobo, _शादी_, stna_,
  { {0x7ae90142, 0x00000000, 0x00000000, 0x00000000}},  //   _ivet,   ,   ,
  { {0x628e1556, 0xa7870014, 0x7ae9000c, 0x00000000}},  //   vobo, _کشاو, _hvet,
  { {0x628e1f69, 0x7ae90f6c, 0x00000000, 0x00000000}},  //   wobo, _kvet,   ,
  { {0x628e00b5, 0x4463005e, 0x661a1f6a, 0x00000000}},  //   tobo, твяв, betk,
  { {0x6e2701d9, 0x661a037e, 0x764a018e, 0x00000000}},  //   _najb, cetk, _gofy,
  { {0xe7d10164, 0x27ff1f6b, 0x661c010e, 0x00000000}},  //   _सभाप, ogun_, õrke,
  { {0x27ff0149, 0x10a306e3, 0x628e0142, 0x00000000}},  //   ngun_, висн, sobo,
  { {0xdee3017f, 0x628e1b5f, 0x27ff0032, 0x00000000}},  // [4b80] коти, pobo, igun_,
  { {0xe29201fa, 0x649d0048, 0x64460ecc, 0x00000000}},  //   _جذب_, héil, ljki,
  { {0x7ae90412, 0xdbc60004, 0x8c460088, 0x00000000}},  //   _avet, _mööd, меже,
  { {0xed570088, 0x00000000, 0x00000000, 0x00000000}},  //   ьох_,   ,   ,
  { {0x7ae91f6c, 0x671c03d7, 0xb5e30044, 0x00000000}},  //   _cvet, _बैंक_, _মানচ,
  { {0x6e270107, 0xbe16007a, 0x27ff0032, 0x00000000}},  //   _gajb, _توسع, egun_,
  { {0x661a0047, 0xdd9200a6, 0x24760089, 0x00000000}},  //   vetk, _شور_, nāms_,
  { {0x764a1f6d, 0x200001d1, 0x33320146, 0x00000000}},  //   _sofy, ngii_, _oryx_,
  { {0x59cf02f4, 0xf09300b6, 0x2d981f6e, 0x00000000}},  //   _स्वर, כנה_, _hyre_,
  { {0x7afd1d43, 0x00000000, 0x00000000, 0x00000000}},  //   _åsta,   ,   ,
  { {0xe01e0754, 0x984c0036, 0x661a016e, 0x00000000}},  //   _पसंद_, jść_, retk,
  { {0x7ae91f6f, 0x628016ff, 0x24760089, 0x00000000}},  //   _yvet, émon, dāms_,
  { {0xe666026b, 0x984c0036, 0xd62a1f70, 0x00000000}},  //   _отко, eść_, _моде_,
  { {0xe56f02fd, 0x27e400e0, 0x00000000, 0x00000000}},  //   اطی_, lamn_,   ,
  { {0x6e270305, 0x00000000, 0x00000000, 0x00000000}},  //   _rajb,   ,   ,
  { {0x6e271f71, 0x27e4093b, 0x3eb80048, 0x00000000}},  //   _sajb, namn_, _airt_,
  { {0x44290cea, 0x3eb8000c, 0x442b012d, 0x00000000}},  // [4b90] _iaa_, _birt_, mdc_,
  { {0x5ec80055, 0x8009026c, 0x27e40039, 0x00000000}},  //   _লিখে, _کردہ_, hamn_,
  { {0x44290089, 0x649d0051, 0x3eb8032c, 0x00000000}},  //   _kaa_, héim, _dirt_,
  { {0x442900b0, 0x260e0164, 0xfbd00379, 0x00000000}},  //   _jaa_, त्ती_, لته_,
  { {0x442903b6, 0x6e2701d5, 0x38a1000c, 0x00000000}},  //   _maa_, _tajb, jóra_,
  { {0xf2d40049, 0x442901a3, 0x2d980190, 0x00000000}},  //   דעס_, _laa_, _fyre_,
  { {0x2d9804a5, 0x27ff0133, 0xdbd901e5, 0x00000000}},  //   _gyre_, tgun_, _fæðu,
  { {0x44290be4, 0xf8a80025, 0x98a2005e, 0x00000000}},  //   _naa_, وديه_, лище,
  { {0x7c3b1f72, 0x2b9000a2, 0x7ae91f73, 0x00000000}},  //   _inur, _پیوس, _uvet,
  { {0x44290161, 0x7c2b01e5, 0x7c291f74, 0x00000000}},  //   _aaa_, ldgr, _haer,
  { {0xa90700a6, 0x44290020, 0x442b1f75, 0x00000000}},  //   _زبان, _baa_, fdc_,
  { {0xc20900b6, 0x7c2b0039, 0x3d07013d, 0x00000000}},  //   _לה_, ndgr, _हमने_,
  { {0x7c2905a6, 0x44291f76, 0x7c3b0022, 0x00000000}},  //   _maer, _daa_, _mnur,
  { {0x66f600b6, 0x7c290007, 0x44290052, 0x00000000}},  //   _נמצא_, _laer, _eaa_,
  { {0xf992007b, 0x44290190, 0x7c3b1b01, 0x00000000}},  //   ָרן_, _faa_, _onur,
  { {0xe3da0055, 0x387f000c, 0x3eb80066, 0x00000000}},  //   _থাকব, nnur_, _sirt_,
  { {0x20000667, 0x3f860181, 0xa3ac013d, 0x00000000}},  // [4ba0] rgii_, çou_, केश_,
  { {0x63a4014a, 0x7c3b0048, 0x44290258, 0x00000000}},  //   _izin, _anur, _zaa_,
  { {0x44291f77, 0x3eb801e5, 0x7c290e42, 0x00000000}},  //   _yaa_, _virt_, _baer,
  { {0x7c29018e, 0x3eb811f0, 0x64960051, 0x00000000}},  //   _caer, _wirt_, máis,
  { {0x7c290149, 0x64960051, 0xc3330049, 0x00000000}},  //   _daer, láis, ָוו_,
  { {0x2d98008d, 0x63a400e7, 0x7c290032, 0x00000000}},  //   _tyre_, _mzin, _eaer,
  { {0x6da31f78, 0x387f01e5, 0x00000000, 0x00000000}},  //   _бира, fnur_,   ,
  { {0x3b0a0175, 0x7c290016, 0x38a11f79, 0x00000000}},  //   _небо_, _gaer, tóra_,
  { {0x44290943, 0x00000000, 0x00000000, 0x00000000}},  //   _raa_,   ,   ,
  { {0x44290ac2, 0x6280049a, 0xb6020224, 0x00000000}},  //   _saa_, émol, _část,
  { {0x442916e7, 0xa3d50a78, 0x63a40041, 0x00000000}},  //   _paa_, конч, _azin,
  { {0x6aba0095, 0x00000000, 0x00000000, 0x00000000}},  //   _hitf,   ,   ,
  { {0x44290052, 0x442b0068, 0x00000000, 0x00000000}},  //   _vaa_, rdc_,   ,
  { {0x63a40089, 0x6726000c, 0x44290145, 0x00000000}},  //   _dzin, ækju, _waa_,
  { {0x6aba0bdf, 0x44291f7a, 0x63a41f7b, 0x00000000}},  //   _mitf, _taa_, _ezin,
  { {0x759b0c9f, 0x645f1f7c, 0x44290093, 0x00000000}},  //   _מיוח, _ulqi, _uaa_,
  { {0x187b0097, 0x09e60044, 0x64960051, 0x00000000}},  // [4bb0] פטמב, _নানা, ráit,
  { {0x38a1009f, 0x765a0006, 0x7c3b00f8, 0x00000000}},  //   jórn_, nkty, _snur,
  { {0x64960051, 0x5ff5013b, 0x7c2900d4, 0x00000000}},  //   cáis, _изну, _paer,
  { {0x64960051, 0x2fcb00fa, 0x61e70095, 0x00000000}},  //   láir, _ufcg_, lajl,
  { {0x7c291f7d, 0x7c2b1f7e, 0x09d80044, 0x00000000}},  //   _vaer, rdgr, _সাজা,
  { {0x50d400a6, 0x64960048, 0xd5b80089, 0x00000000}},  //   _جزیر, náir, ndās_,
  { {0x6f0d052e, 0x26cf004a, 0xf41f00b0, 0x00000000}},  //   ltac, _stgo_, keä_,
  { {0x61e71f7f, 0x64960051, 0x7c3b002b, 0x00000000}},  //   hajl, háir, _unur,
  { {0x387f023a, 0xd706007c, 0xc6250044, 0x00000000}},  //   rnur_, вные_, বাসা_,
  { {0x6f0d004a, 0x387f1372, 0x00000000, 0x00000000}},  //   itac, snur_,   ,
  { {0xc959089d, 0x63a40047, 0x69ca006e, 0x00000000}},  //   _تلاش_, _szin, _स्टी,
  { {0x6f0d0036, 0xa01b0039, 0x00000000, 0x00000000}},  //   ktac, _sjön,   ,
  { {0x03230088, 0xa3ac013d, 0xa856009b, 0x00000000}},  //   адян, कें_, _שינה_,
  { {0x765a0190, 0x64961f80, 0x00000000, 0x00000000}},  //   ckty, gáir,   ,
  { {0x4096003b, 0x09e60044, 0x26c20027, 0x00000000}},  //   врат, _নামা, íkov_,
  { {0x20c70011, 0x645d0065, 0x3e640274, 0x00000000}},  //   _dõi_, ërit, _möte_,
  { {0x6b9b0047, 0x63a40020, 0x61e7012d, 0x00000000}},  // [4bc0] _nyug, _uzin, bajl,
  { {0x3f9c0089, 0x02fb01ce, 0x00000000, 0x00000000}},  //   āvu_, _קלימ,   ,
  { {0xa01b000c, 0x99870010, 0x00000000, 0x00000000}},  //   _kjöl, kenő_,   ,
  { {0xf536007b, 0x6f0d00f6, 0x00000000, 0x00000000}},  //   כטער_, btac,   ,
  { {0xa01b0039, 0x6f0d1f81, 0xafdb00ea, 0x00000000}},  //   _mjöl, ctac, _snøg,
  { {0x9f420065, 0x00000000, 0x00000000, 0x00000000}},  //   _lekë_,   ,   ,
  { {0xda65006d, 0x6b890716, 0xc27b0104, 0x00000000}},  //   داني, _exeg, ורסי,
  { {0xd7f00025, 0x00000000, 0x00000000, 0x00000000}},  //   حكة_,   ,   ,
  { {0xe3e10055, 0x9f49009f, 0x6aba0066, 0x00000000}},  //   _ভালব, ngað_, _titf,
  { {0x6aba01d6, 0x00000000, 0x00000000, 0x00000000}},  //   _uitf,   ,   ,
  { {0x4e35007b, 0x765a1f82, 0x3a3e0253, 0x00000000}},  //   אָרן_, rkty, _intp_,
  { {0x89790049, 0x99790049, 0x6f0d1f83, 0x00000000}},  //   _אָנה, _אָנפ, ytac,
  { {0x61e71f84, 0x00000000, 0x00000000, 0x00000000}},  //   tajl,   ,   ,
  { {0x1757009b, 0x07a3003b, 0xc7a3003b, 0x00000000}},  //   _בסדר_, _тачн, _тичк,
  { {0xc69300bd, 0xa01b009f, 0x645d0065, 0x00000000}},  //   _דאס_, _fjöl, ëris,
  { {0x20c7061f, 0x260e02fb, 0x61e7011f, 0x00000000}},  //   _või_, त्री_, sajl,
  { {0x53350b11, 0xc6250044, 0xe81401f5, 0x00000000}},  // [4bd0] _септ, বারা_, थ्या_,
  { {0x20c7006c, 0x3a3e0026, 0x752f0036, 0x00000000}},  //   _tõi_, _nntp_, łcze,
  { {0x6f0d095e, 0x7bf901fc, 0xc7b90010, 0x00000000}},  //   stac, енер_, ndőr_,
  { {0x645d008d, 0xda05007d, 0x00000000, 0x00000000}},  //   nksi, _राहत_,   ,
  { {0x9f9d000c, 0x61e501a2, 0x200e013f, 0x00000000}},  //   _gæði_, _kehl, əfi_,
  { {0x61e5013e, 0x60c51c3b, 0x00000000, 0x00000000}},  //   _jehl, _kuhm,   ,
  { {0x645d000c, 0xa3e30164, 0xf4bd0044, 0x00000000}},  //   kksi, धरा_, _আব্ব,
  { {0xccf200b6, 0x7af6010a, 0x39490091, 0x00000000}},  //   _לכל_, šyta, ćas_,
  { {0x62950047, 0x60c51f85, 0x00000000, 0x00000000}},  //   kozo, _luhm,   ,
  { {0xb7bd001a, 0x645d00bb, 0xe9d30025, 0x00000000}},  //   deţe, eksi, _ضغط_,
  { {0x69c11433, 0xf3e616c4, 0xdd120276, 0x00000000}},  //   _igle, лжно, _müşr,
  { {0x38850089, 0xd6d900b4, 0x00000000, 0x00000000}},  //   mēro_, zyły_,   ,
  { {0x81d508b7, 0xc87915ec, 0x61e5019a, 0x00000000}},  //   _হয়_, miş_, _behl,
  { {0x412a0373, 0xc8790279, 0x43750900, 0x00000000}},  //   ного_, liş_, руют,
  { {0x61e50190, 0x216a04cf, 0x00000000, 0x00000000}},  //   _dehl, хиви_,   ,
  { {0xc8790279, 0x787e0089, 0x645d03a1, 0x00000000}},  //   niş_, tīvi, cksi,
  { {0x44221baf, 0x69c101d9, 0xee3a0780, 0x00000000}},  // [4be0] mek_, _ogle, нна_,
  { {0x44220047, 0xb226005e, 0xc879006b, 0x00000000}},  //   lek_, _смол, hiş_,
  { {0xdca6026b, 0xc879014a, 0x2d9c0030, 0x00000000}},  //   гажи, kiş_, æve_,
  { {0x44221bc0, 0x1613007d, 0x61e51f86, 0x00000000}},  //   nek_, त्तर_, _zehl,
  { {0x6d430039, 0x4422002d, 0xc8791f87, 0x00000000}},  //   änar, iek_, diş_,
  { {0x90e500a6, 0x44221f88, 0x31e20044, 0x00000000}},  //   _حسین, hek_, _বাঁশ,
  { {0x44221f89, 0x645d00b0, 0x09e60044, 0x00000000}},  //   kek_, yksi, _নাদা,
  { {0x44220aa5, 0xb6f40098, 0xd6da0517, 0x00000000}},  //   jek_, азиј, нто_,
  { {0x44221f8a, 0x2057007b, 0x6e2e002b, 0x00000000}},  //   dek_, טיקל_, _kabb,
  { {0x6e2e1f8b, 0x09b90044, 0x7c22001a, 0x00000000}},  //   _jabb, ঁড়া, leor,
  { {0x629500b9, 0x44221f8c, 0x6e2e01a3, 0x00000000}},  //   vozo, fek_, _mabb,
  { {0x44220047, 0x6e2e1f8d, 0x69c10059, 0x00000000}},  //   gek_, _labb, _zgle,
  { {0x62950232, 0x645d1f8e, 0xb8930025, 0x00000000}},  //   tozo, rksi, _النع,
  { {0x442d0119, 0xae03006e, 0x6d41000c, 0x00000000}},  //   že_, _लाइन_, _álag,
  { {0xd49b0256, 0x4422011f, 0x62950010, 0x00000000}},  //   _при_, bek_, rozo,
  { {0x4422011f, 0x629500ea, 0x4fd50cee, 0x00000000}},  //   cek_, sozo, ржат,
  { {0x7c221f8f, 0xf3ff0181, 0x62950065, 0x00000000}},  // [4bf0] deor, lhão_, pozo,
  { {0xe45f0510, 0xc879006b, 0x2bba0061, 0x00000000}},  //   lkö_, ziş_, ेशना,
  { {0xf3ff0181, 0xfbd60055, 0xc8790180, 0x00000000}},  //   nhão_, _হয়ত, yiş_,
  { {0x7c220c53, 0x27e60051, 0x69c1005b, 0x00000000}},  //   geor, _neon_, _sgle,
  { {0x6e2e1a64, 0xab2901f9, 0xbb4509e8, 0x00000000}},  //   _fabb, тола_, релк,
  { {0x2bd5007d, 0x27e91531, 0x27e60145, 0x00000000}},  //   _ड्रा, _žan_, _aeon_,
  { {0x44221f90, 0x6845005e, 0x3258009b, 0x00000000}},  //   yek_, инка, רסום_,
  { {0x5d840054, 0x7ccc005a, 0x6e2e0066, 0x00000000}},  //   _الفل, _uğra, _zabb,
  { {0xc879005a, 0x27e60007, 0x5746005e, 0x00000000}},  //   riş_, _deon_, изъм_,
  { {0x44221f91, 0x69c10213, 0x00000000, 0x00000000}},  //   wek_, _ugle,   ,
  { {0x44221f92, 0xd46a0e82, 0xe5a5007c, 0x00000000}},  //   tek_, вине_, рини,
  { {0x6f1d1f93, 0x76b20036, 0x3e640039, 0x00000000}},  //   _opsc, _błys, _möta_,
  { {0x44221f94, 0x76b20036, 0x00000000, 0x00000000}},  //   rek_, _płyt,   ,
  { {0x44220047, 0x368b02dc, 0x200b004a, 0x00000000}},  //   sek_, _ясен_, _acci_,
  { {0x44220047, 0xc0e609c0, 0x64a60679, 0x00000000}},  //   pek_, робк, _кака,
  { {0x6e2e1f95, 0x251a034e, 0x7cc50006, 0x00000000}},  //   _sabb, _יוצא, _gėri,

  { {0x6e2e000c, 0x7d1c0521, 0x00000000, 0x00000000}},  // [4c00] _pabb, _sprs,   ,
  { {0x2bde0164, 0x6e2e002b, 0x2cbf0035, 0x00000000}},  //   मर्थ, _qabb, _aiud_,
  { {0x716a003b, 0x6e2e0197, 0x10a602d3, 0x00000000}},  //   _ранг_, _vabb, _винн,
  { {0x6e2e0066, 0xe3bf004a, 0x213a00f6, 0x00000000}},  //   _wabb, señe_, _irph_,
  { {0x6e2e00bb, 0x7e60001a, 0x7bc40006, 0x00000000}},  //   _tabb, _împo, žiuo,
  { {0x7c22027e, 0xb8f40025, 0xe9df0011, 0x00000000}},  //   seor, مكتب, _đúc_,
  { {0x672b008d, 0x6f040051, 0x7c22008e, 0x00000000}},  //   _asgj, luic, peor,
  { {0x649d07cb, 0xc5f00044, 0x9cd700b3, 0x00000000}},  //   néit, জ্ঞা_, _כולה_,
  { {0x44f101d5, 0x76aa007c, 0xbebb0065, 0x00000000}},  //   eġ_, ктов_, _rrëz,
  { {0x649d009d, 0x27e6004a, 0x24890023, 0x00000000}},  //   héit, _weon_, _sjam_,
  { {0x994a06b4, 0x76b20036, 0xe45f00b0, 0x00000000}},  //   _جلال_, _słys, tkö_,
  { {0x7d030129, 0x291e01a3, 0x00000000, 0x00000000}},  //   ànsi, _ipta_,   ,
  { {0x6f04008e, 0x3d080204, 0x38660035, 0x00000000}},  //   juic, ांडे_, _ilor_,
  { {0x3d07013d, 0x3866016c, 0x291e0022, 0x00000000}},  //   _हमले_, _hlor_, _kpta_,
  { {0x20190022, 0x248900fa, 0x313502dc, 0x00000000}},  //   _pbsi_, _tjam_, щевр,
  { {0x61e20107, 0x4e19006e, 0xc1040025, 0x00000000}},  //   _đole, न्नई_, توفي,
  { {0x6f040197, 0x3e6400f8, 0x2cbf00f6, 0x00000000}},  // [4c10] guic, _söta_, _riud_,
  { {0x291e0035, 0x7e60001a, 0xb7fe0044, 0x00000000}},  //   _opta_, _împl, ্জিত_,
  { {0x38660efe, 0x9f4000c4, 0x00000000, 0x00000000}},  //   _olor_, raiá_,   ,
  { {0xbd440025, 0x62800161, 0x6f0400fa, 0x00000000}},  //   تنمي, émov, buic,
  { {0x291e1505, 0x6f1d0a60, 0x00000000, 0x00000000}},  //   _apta_, _upsc,   ,
  { {0xa3ac02d2, 0x386601a3, 0x20090fec, 0x00000000}},  //   केट_, _alor_, lgai_,
  { {0xceb2007b, 0x649d1f96, 0x5c070a7c, 0x00000000}},  //   _מיך_, néis, _вяза,
  { {0x20091f97, 0x6c850054, 0x3829003b, 0x00000000}},  //   ngai_, _الرم, ужио_,
  { {0xf7490014, 0xdd380089, 0x09e60044, 0x00000000}},  //   اجعه_, māša, _নারা,
  { {0xd4d9008b, 0x62870107, 0x1a6500a1, 0x00000000}},  //   льмі_, jnjo, _دیتی_,
  { {0x386600d6, 0x62870091, 0xc3290097, 0x00000000}},  //   _flor_, dnjo, _רו_,
  { {0xdd38001e, 0x44e30010, 0xe77800a1, 0x00000000}},  //   nāša, rű_, الیں_,
  { {0x38a1000c, 0x27ed0016, 0x00000000, 0x00000000}},  //   jóri_, maen_,   ,
  { {0x27ed018e, 0x628701ee, 0x00000000, 0x00000000}},  //   laen_, gnjo,   ,
  { {0x76430046, 0xa06a0265, 0xa3ac007d, 0x00000000}},  //   _inny, гава_, केज_,
  { {0x320c0036, 0x20091f98, 0x27ed1f99, 0x00000000}},  //   żdy_, ggai_, naen_,
  { {0x6444011c, 0x649d0051, 0x3fcb00a2, 0x00000000}},  // [4c20] _inii, réit, ادفی_,
  { {0x44321f9a, 0xf76700a1, 0xf41f00b0, 0x00000000}},  //   _hay_, _ہا_, nnän_,
  { {0x44321f9b, 0x61ee00f4, 0x5bc60379, 0x00000000}},  //   _kay_, mabl, مقال,
  { {0xdd8f06dd, 0x61ee00f4, 0xe3bf008e, 0x00000000}},  //   رون_, labl, leña_,
  { {0x44321f9c, 0x64560263, 0x6f040b33, 0x00000000}},  //   _may_, _moyi, quic,
  { {0x523a007b, 0x649d0051, 0x320a1f9d, 0x00000000}},  //   רײַנ, néir, ngby_,
  { {0x629e1489, 0x27ed1506, 0xdd380089, 0x00000000}},  //   _mkpo, faen_, bāša,
  { {0xc6f8058f, 0x76430047, 0x62870107, 0x00000000}},  //   аних_, _anny, znjo,
  { {0x61ee00f8, 0x6d5e0006, 0x254e006b, 0x00000000}},  //   kabl, lypa, məli_,
  { {0xbb3b007b, 0x7e7e0bf3, 0x44f40364, 0x00000000}},  //   _געמי, nipp, опос,
  { {0x44321f9e, 0x61ee0781, 0xe3bf004a, 0x00000000}},  //   _bay_, dabl, deña_,
  { {0x76431f9f, 0x44320011, 0x629e0093, 0x00000000}},  //   _enny, _cay_, _akpo,
  { {0x44320038, 0x61ee0919, 0xa3b3013d, 0x00000000}},  //   _day_, fabl, झें_,
  { {0x61ee0efe, 0x649d0051, 0xa6b6005e, 0x00000000}},  //   gabl, téis, _усещ,
  { {0x44320173, 0x62870247, 0x7e7e1254, 0x00000000}},  //   _fay_, rnjo, dipp,
  { {0x62871aa8, 0x44320472, 0x6d5e0240, 0x00000000}},  //   snjo, _gay_, dypa,
  { {0x6235178d, 0x61ee00ab, 0x200901a3, 0x00000000}},  // [4c30] _депу, babl, rgai_,
  { {0x61ee0682, 0x63ad0756, 0x518702be, 0x00000000}},  //   cabl, _izan, _гума,
  { {0x4432006b, 0x601904dd, 0x254e006b, 0x00000000}},  //   _yay_, _коня_, fəli_,
  { {0xac190269, 0x44320011, 0x6e2501a2, 0x00000000}},  //   роду_, _xay_, sehb,
  { {0x3de80055, 0xdea4025a, 0x6d5e0009, 0x00000000}},  //   _পারল, _کیلی, aypa,
  { {0x6d5e00bb, 0x7a07007e, 0xdcf4005a, 0x00000000}},  //   bypa, сядж, _çağl,
  { {0x27ed00b0, 0x00000000, 0x00000000, 0x00000000}},  //   taen_,   ,   ,
  { {0x61ee192f, 0x63ad0095, 0x00000000, 0x00000000}},  //   zabl, _ozan,   ,
  { {0x27ed0ee6, 0x61ee0549, 0x00000000, 0x00000000}},  //   raen_, yabl,   ,
  { {0x44320038, 0x06960025, 0xe6160131, 0x00000000}},  //   _say_, ينية_, одь_,
  { {0x61ee006b, 0x443200ab, 0x63ad006b, 0x00000000}},  //   vabl, _pay_, _azan,
  { {0xccf20049, 0x61ee0133, 0x6fd90204, 0x00000000}},  //   וכט_, wabl, _फ्लू,
  { {0xd6db064b, 0x6d5e0046, 0x44321fa0, 0x00000000}},  //   _сте_, zypa, _vay_,
  { {0x44320038, 0x386d02d5, 0x95cb1fa1, 0x00000000}},  //   _way_, lher_, _суда_,
  { {0x61ee1fa2, 0x4432001d, 0x29070279, 0x00000000}},  //   rabl, _tay_, nuna_,
  { {0xe3bf0219, 0xd12f00a1, 0x205500c0, 0x00000000}},  //   seña_, کمہ_, птур,
  { {0x8fa31fa3, 0xa0670200, 0x29070058, 0x00000000}},  // [4c40] дате, цата_, huna_,
  { {0x2907000b, 0xa3af001c, 0x6d5e1fa4, 0x00000000}},  //   kuna_, _करत_, typa,
  { {0x7e7e0541, 0x29071fa5, 0x629c1fa6, 0x00000000}},  //   ripp, juna_, moro,
  { {0x629c0395, 0x2907002d, 0x6d5e0009, 0x00000000}},  //   loro, duna_, rypa,
  { {0x386d01d5, 0x9d0a0044, 0x254e006b, 0x00000000}},  //   dher_, রবেন_, rəli_,
  { {0x290719bd, 0x63a41fa7, 0xeaaf00a1, 0x00000000}},  //   funa_, _myin, نٹن_,
  { {0xa967025f, 0xed5a0088, 0x20e8001a, 0x00000000}},  //   жија_, _тов_, nşi_,
  { {0x386d00ab, 0x629c1fa8, 0x63a40045, 0x00000000}},  //   gher_, horo, _oyin,
  { {0x63a4000b, 0x629c10fa, 0x29071fa9, 0x00000000}},  //   _nyin, koro, auna_,
  { {0x629c0023, 0xda66006d, 0x00000000, 0x00000000}},  //   joro, _باري,   ,
  { {0x29070cff, 0x629c1fa8, 0x63ad0ef2, 0x00000000}},  //   cuna_, doro, _szan,
  { {0x386d1faa, 0x6f160036, 0x63a40061, 0x00000000}},  //   cher_, ktyc, _byin,
  { {0x629c0016, 0x63a40045, 0x2ca600f6, 0x00000000}},  //   foro, _cyin, ilod_,
  { {0x63a40133, 0x67221fab, 0xcfe70044, 0x00000000}},  //   _dyin, _ipoj, _ফাইন,
  { {0x2ca60058, 0xc0cb17da, 0xc7ad00a1, 0x00000000}},  //   klod_, руге_, _لڑی_,
  { {0x200f006c, 0x439501e1, 0x63ad01c3, 0x00000000}},  //   ügi_, _найс, _tzan,
  { {0x629c0142, 0x2907022b, 0x63ad005d, 0x00000000}},  // [4c50] boro, zuna_, _uzan,
  { {0x629c0a9c, 0xe3bf008e, 0x317101f3, 0x00000000}},  //   coro, leño_, pzzz_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3af0183, 0x29070020, 0x69c800ea, 0x00000000}},  //   _करा_, vuna_, _agde,
  { {0x386d014a, 0xfe7301fa, 0xcfab0355, 0x00000000}},  //   vher_, _قدس_, _خادم_,
  { {0xdc55026c, 0x5ba8007e, 0x00000000, 0x00000000}},  //   _کرسک, цкім_,   ,
  { {0x386d0038, 0x6b8d001a, 0x2ca602e7, 0x00000000}},  //   ther_, _ţigă, blod_,
  { {0x629c0142, 0x25ed0061, 0xbd440025, 0x00000000}},  //   zoro, _आजही_, _تنفي,
  { {0x2907022b, 0x386d010f, 0x629c0020, 0x00000000}},  //   suna_, rher_, yoro,
  { {0x2907037e, 0x386d192b, 0x6e3500d0, 0x00000000}},  //   puna_, sher_, _jazb,
  { {0x629c167a, 0xe9d00774, 0x386d00ab, 0x00000000}},  //   voro, _شغل_, pher_,
  { {0x7ae91fac, 0x629c1fad, 0xdb00009d, 0x00000000}},  //   _kwet, woro, _symé,
  { {0x629c0027, 0x87040318, 0x888c0049, 0x00000000}},  //   toro, _قبول, _דראַ,
  { {0xf77002fd, 0x70b400e8, 0x2f140039, 0x00000000}},  //   _جام_, ंग्ल, väg_,
  { {0x629c1fae, 0x213e0051, 0xe5a2007c, 0x00000000}},  //   roro, íth_, _пиши,
  { {0x629c10fa, 0x3de80044, 0xe3bf004a, 0x00000000}},  //   soro, _পাইল, ceño_,
  { {0x629c01d9, 0x44200061, 0x00000000, 0x00000000}},  // [4c60] poro, _ibi_,   ,
  { {0x6f160036, 0x38850089, 0xa01b1faf, 0x00000000}},  //   rtyc, mēru_, _sjöt,
  { {0x6f160046, 0x0c2601fc, 0x44201f66, 0x00000000}},  //   styc, змен, _kbi_,
  { {0x3d1c03d7, 0x9b6a0245, 0x7ae900de, 0x00000000}},  //   _नहीं_, йшла_, _bwet,
  { {0x4420008d, 0xfaa6072b, 0x2ca61fb0, 0x00000000}},  //   _mbi_, падо, rlod_,
  { {0x8d66007c, 0x44201fb1, 0xe9940014, 0x00000000}},  //   _евге, _lbi_, وهشگ,
  { {0x6722047c, 0x6f0401a2, 0x00000000, 0x00000000}},  //   _spoj, lric,   ,
  { {0xdca3017a, 0x44200b57, 0xa01b000c, 0x00000000}},  //   _заси, _nbi_, _hjör,
  { {0x07f70054, 0x6f041fb2, 0xa01b000c, 0x00000000}},  //   سريع_, nric, _kjör,
  { {0x44200004, 0xe67801fb, 0x6f040051, 0x00000000}},  //   _abi_, ійні_, iric,
  { {0x7ae9054e, 0x442001a3, 0x47960014, 0x00000000}},  //   _zwet, _bbi_, _کجاس,
  { {0x2b2003d7, 0x60c604cb, 0x6f0401ed, 0x00000000}},  //   _यहाँ_, _nikm, kric,
  { {0xe3bf04de, 0x44200253, 0xa5f81649, 0x00000000}},  //   reño_, _dbi_, _делу_,
  { {0xe3bf0219, 0xf7bb009b, 0x7afd0190, 0x00000000}},  //   seño_, _הזדמ, _æste,
  { {0x442000ca, 0x6e350091, 0x6f041fb3, 0x00000000}},  //   _fbi_, _razb, eric,
  { {0x6f040211, 0x3eba00e0, 0x30a40457, 0x00000000}},  //   fric, empt_, ерув,
  { {0xa01b1fb4, 0xbfab1036, 0x442b05d2, 0x00000000}},  // [4c70] _björ, стве_, mec_,
  { {0x442b0c06, 0x44391fb5, 0x7bc90009, 0x00000000}},  //   lec_, lds_, _sgeu,
  { {0x7ae901aa, 0x6e3501dc, 0x6f040026, 0x00000000}},  //   _swet, _vazb, aric,
  { {0xc0ab06dd, 0x442b07e4, 0x7ae909d7, 0x00000000}},  //   _داخل_, nec_, _pwet,
  { {0x44390bd3, 0x6f04049a, 0x1a6500d3, 0x00000000}},  //   ids_, cric, ویری_,
  { {0x442b1fb6, 0xbb4201fc, 0xa01b000c, 0x00000000}},  //   hec_, тешк, _gjör,
  { {0x442b0027, 0x63a800b4, 0x00000000, 0x00000000}},  //   kec_, ędni,   ,
  { {0x673b0107, 0xba7700d3, 0x443915ff, 0x00000000}},  //   tvuj, _کارت, jds_,
  { {0x442b00b9, 0x7c2b0133, 0x00000000, 0x00000000}},  //   dec_, megr,   ,
  { {0x4439049b, 0x7c2b1fb7, 0x78a203c9, 0x00000000}},  //   eds_, legr, _ekov,
  { {0xb579007c, 0x442b00d4, 0x44201fb8, 0x00000000}},  //   ющих_, fec_, _pbi_,
  { {0x6f041352, 0x44390f4a, 0x78a20087, 0x00000000}},  //   yric, gds_, _gkov,
  { {0x08760049, 0xe7380088, 0x78a902e7, 0x00000000}},  //   _קענט_, _неї_, mlev,
  { {0x78a901e8, 0x7c2b00e0, 0x6f0400ca, 0x00000000}},  //   llev, hegr, vric,
  { {0x442b0161, 0x3d0c03d7, 0x6f0400bb, 0x00000000}},  //   bec_, _हमें_, wric,
  { {0x78a900b5, 0x26c700c4, 0x442b05bd, 0x00000000}},  //   nlev, _hino_, cec_,
  { {0x26c71fb9, 0xaec600e1, 0x7c2b0056, 0x00000000}},  // [4c80] _kino_, дбал, degr,
  { {0x26c71fba, 0x2fcb19a7, 0x7c3901c3, 0x00000000}},  //   _jino_, _egcg_, edwr,
  { {0x26cf049a, 0x6f04010f, 0x60c60485, 0x00000000}},  //   _lugo_, sric, _tikm,
  { {0x50b60099, 0x06e30044, 0x78a900b9, 0x00000000}},  //   _існу, _মিনি, jlev,
  { {0x628e0045, 0x78a91fbb, 0xa01b1fbc, 0x00000000}},  //   onbo, dlev, _tjör,
  { {0x26c7027b, 0x78a20030, 0x442b0d0a, 0x00000000}},  //   _nino_, _skov, zec_,
  { {0x44390007, 0x628e021f, 0x7c2b05c6, 0x00000000}},  //   yds_, inbo, begr,
  { {0x7c2b0061, 0x6c3100a1, 0x8b2600ed, 0x00000000}},  //   cegr, _مہما, _одбе,
  { {0x442b086e, 0x26c70058, 0x61fe07ac, 0x00000000}},  //   vec_, _bino_, _odpl,
  { {0x7ae20035, 0x26cf011c, 0x26c70026, 0x00000000}},  //   mpot, _dugo_, _cino_,
  { {0x78a900b5, 0x7ae21fbd, 0x26c7016e, 0x00000000}},  //   blev, lpot, _dino_,
  { {0x27ef009f, 0x628e00bb, 0x4439028a, 0x00000000}},  //   _gegn_, enbo, uds_,
  { {0x26c70198, 0x442b1d15, 0x7ae21635, 0x00000000}},  //   _fino_, rec_, npot,
  { {0x442b11e6, 0x26c70197, 0x6d41007f, 0x00000000}},  //   sec_, _gino_, _šlam,
  { {0x442b0142, 0x44390300, 0x6d5800b0, 0x00000000}},  //   pec_, pds_, äval,
  { {0x628e00bb, 0x3de80044, 0x26c70006, 0x00000000}},  //   anbo, _পাগল, _zino_,
  { {0x69da11d1, 0x7c2b0d22, 0xeb0d013d, 0x00000000}},  // [4c90] _ofte, vegr, _समेत_,
  { {0x26c700f6, 0x00000000, 0x00000000, 0x00000000}},  //   _xino_,   ,   ,
  { {0x8c3d014a, 0x61f5005d, 0x78a9017b, 0x00000000}},  //   _akşa, mazl, ylev,
  { {0x1ddf02f4, 0x69da1fbe, 0x1bd51ac0, 0x00000000}},  //   _प्रत, _afte, ходя,
  { {0x27ef03bd, 0x7c3900d9, 0xd9e60044, 0x00000000}},  //   _regn_, rdwr, _নাজম,
  { {0xdcfb007a, 0x26cf0009, 0x27ef0292, 0x00000000}},  //   _ورزش_, _rugo_, _segn_,
  { {0x6f0d0779, 0x26cf011c, 0x78a9006c, 0x00000000}},  //   luac, _sugo_, tlev,
  { {0x69da033d, 0x26c70ac6, 0x61f501df, 0x00000000}},  //   _efte, _sino_, hazl,
  { {0x78a90047, 0x6f0d0779, 0x26c70555, 0x00000000}},  //   rlev, nuac, _pino_,
  { {0x9967007c, 0x78a900bb, 0x5b3400a6, 0x00000000}},  //   _отел, slev, _جعفر,
  { {0x78a91fbf, 0x27ef01e3, 0x6d41016c, 0x00000000}},  //   plev, _tegn_, _šlaj,
  { {0xa7750259, 0x6f0d09cc, 0x26c71fc0, 0x00000000}},  //   _плеч, kuac, _wino_,
  { {0x3ea10004, 0x2f230089, 0xe3b20644, 0x00000000}},  //   koht_, nīgā_, طرح_,
  { {0xd774031d, 0x6f0d1fc1, 0x7afb0020, 0x00000000}},  //   _جامع, duac, _mvut,
  { {0x628e000c, 0xe2970887, 0x7ae200ca, 0x00000000}},  //   rnbo, хар_, zpot,
  { {0xa40a0061, 0x7afb00d9, 0x7ae21fc2, 0x00000000}},  //   _वाटप_, _ovut, ypot,
  { {0x06e30044, 0x61f51fc3, 0x6f0d08d3, 0x00000000}},  // [4ca0] _মিডি, bazl, guac,
  { {0xa2d50164, 0xee3706e7, 0x337700b3, 0x00000000}},  //   _यंत्, нну_, _נעים_,
  { {0x9f42021e, 0x7afb0207, 0x5bba007d, 0x00000000}},  //   _sekä_, _avut, ेश्व,
  { {0xdee60216, 0x7ae20203, 0x00000000, 0x00000000}},  //   _поми, tpot,   ,
  { {0x7ae205fa, 0x29070039, 0x6f0d0efe, 0x00000000}},  //   upot, erna_, cuac,
  { {0x9f5201aa, 0x7ae20169, 0x00000000, 0x00000000}},  //   vayè_, rpot,   ,
  { {0xdd920054, 0x0903008b, 0x7ae20142, 0x00000000}},  //   _صور_, гчым, spot,
  { {0x7ae21fc4, 0x9d1b0104, 0x6da30140, 0x00000000}},  //   ppot, _מולט, _сиса,
  { {0x29070051, 0x78a001a2, 0x61f5005a, 0x00000000}},  //   arna_, romv, yazl,
  { {0x3b83003b, 0x57b3007e, 0x00000000, 0x00000000}},  //   _слуг, ыбыт,   ,
  { {0x659400ed, 0xf76f0cd9, 0xc58a007c, 0x00000000}},  //   тану, لای_, ящие_,
  { {0x7ccc0180, 0x15f20061, 0xd90f009e, 0x00000000}},  //   _uğru, _आजवर_, _ایٹ_,
  { {0x7eb000f8, 0x00000000, 0x00000000, 0x00000000}},  //   väpn,   ,   ,
  { {0x1ee700a1, 0x00000000, 0x00000000, 0x00000000}},  //   ہوری_,   ,   ,
  { {0xe4a7007c, 0xe29f000c, 0x644000c4, 0x00000000}},  //   _прио, nuði_, ômic,
  { {0x6f0d1fc5, 0xd498008b, 0x00000000, 0x00000000}},  //   tuac, _пры_,   ,
  { {0x644d000d, 0x9e07005e, 0x3eb8012d, 0x00000000}},  // [4cb0] _inai, ечел, _bhrt_,
  { {0x290e0020, 0x290701e5, 0x6f0d0048, 0x00000000}},  //   kufa_, yrna_, ruac,
  { {0x443b008d, 0x62870006, 0xdd910a4f, 0x00000000}},  //   _kaq_, mijo, جوا_,
  { {0x62870042, 0xfbd00025, 0x788701aa, 0x00000000}},  //   lijo, مته_, _mèvè,
  { {0x6f0d00d4, 0x201c006b, 0xdd9000a1, 0x00000000}},  //   quac, əvi_, لوے_,
  { {0x6287010a, 0x2f230089, 0x29070087, 0x00000000}},  //   nijo, rīgā_, trna_,
  { {0x644d0032, 0x290e0045, 0x00000000, 0x00000000}},  //   _onai, gufa_,   ,
  { {0x7e60001a, 0x62871fc6, 0x00000000, 0x00000000}},  //   _împr, hijo,   ,
  { {0x5b15007e, 0x6287042c, 0xead5007e, 0x00000000}},  //   _шмат, kijo, _розь,
  { {0x7c3b0d89, 0x644d120e, 0x7bd20089, 0x00000000}},  //   _haur, _anai, ājuš,
  { {0x6287010a, 0x7c3b1fc7, 0x443b00f6, 0x00000000}},  //   dijo, _kaur, _baq_,
  { {0x7c3b022b, 0xddce00b9, 0x9f5200f4, 0x00000000}},  //   _jaur, _dobř, sayé_,
  { {0x7c3b0a15, 0xe7390113, 0x987a0476, 0x00000000}},  //   _maur, _цел_, _קאנט,
  { {0xd2520025, 0x6287010a, 0x412a041f, 0x00000000}},  //   جنس_, gijo, мого_,
  { {0x7fd601e1, 0xc616009b, 0x644d0068, 0x00000000}},  //   візі, _יחסי_, _fnai,
  { {0x7c3b00b0, 0xc00300e2, 0x6aa30090, 0x00000000}},  //   _naur, ипск, honf,
  { {0x62870ff9, 0x98450089, 0xef1a1fc8, 0x00000000}},  // [4cc0] bijo, dēļ_, ьма_,
  { {0x628719f0, 0x6aa30056, 0x00000000, 0x00000000}},  //   cijo, jonf,   ,
  { {0x5fa7001c, 0x7c3b1fc9, 0x68e11fca, 0x00000000}},  //   _कुठल, _baur, _ntld,
  { {0x7c3b1fcb, 0x81d90044, 0x3f84012d, 0x00000000}},  //   _caur, ারণ_, _žmuu_,
  { {0x7c3b0129, 0x6aa300f8, 0x6a6f0190, 0x00000000}},  //   _daur, fonf, _søfa,
  { {0xe18900e9, 0x290e1343, 0x291c01c5, 0x00000000}},  //   _آئین_, tufa_, ttva_,
  { {0x6e3c0fff, 0x7c3b009d, 0x3e6400f8, 0x00000000}},  //   _iarb, _faur, _dött_,
  { {0x628719f0, 0x7c3b1fcc, 0x290e002b, 0x00000000}},  //   zijo, _gaur, rufa_,
  { {0x291c01cd, 0x00000000, 0x00000000, 0x00000000}},  //   stva_,   ,   ,
  { {0x7c2205b7, 0x644d007f, 0xb9080044, 0x00000000}},  //   lfor, _snai, _বি_,
  { {0xa96a035b, 0xb7bd001a, 0x6e3c0b25, 0x00000000}},  //   _تمام_, deţu, _marb,
  { {0xb97b00a3, 0x70be006e, 0x6e3c1fcd, 0x00000000}},  //   _קנאי, ्दोल, _larb,
  { {0x62870006, 0x63b60036, 0xa3e2013d, 0x00000000}},  //   tijo, _czyn, धड़_,
  { {0x7c220061, 0x86730088, 0x3e6400f8, 0x00000000}},  //   hfor, _кліє, _möts_,
  { {0x6287010a, 0x7c220056, 0x236d0027, 0x00000000}},  //   rijo, kfor, šej_,
  { {0x6287010a, 0x6d410051, 0x644d0020, 0x00000000}},  //   sijo, _álai, _unai,
  { {0x7c220606, 0xdef803c8, 0x62870006, 0x00000000}},  // [4cd0] dfor, вых_, pijo,
  { {0x7c220c95, 0x7c3b00f4, 0x6e3c1e53, 0x00000000}},  //   efor, _saur, _carb,
  { {0x6e3c0ebc, 0x7c22018e, 0x7c3b0207, 0x00000000}},  //   _darb, ffor, _paur,
  { {0x7c220030, 0x63ad1fce, 0xd577009b, 0x00000000}},  //   gfor, _kyan, כתבה_,
  { {0x6e3c1fcf, 0x201900ca, 0x16020061, 0x00000000}},  //   _farb, _icsi_, लणार_,
  { {0x63ad0051, 0x6e3c1fd0, 0xddde0035, 0x00000000}},  //   _myan, _garb, ripţ,
  { {0x7c3b0006, 0x7c2215c9, 0x63ad0173, 0x00000000}},  //   _taur, bfor, _lyan,
  { {0x81d90055, 0xf8a90014, 0x7c221fd1, 0x00000000}},  //   ারি_, رگاه_, cfor,
  { {0x63ad181b, 0x628502ae, 0x7c84004c, 0x00000000}},  //   _nyan, _omho, _туре,
  { {0x3d08001c, 0xdb000146, 0x6e3c0066, 0x00000000}},  //   ांचे_, _bymæ, _xarb,
  { {0x3945020f, 0x63ad1fd2, 0x81d90055, 0x00000000}},  //   _urls_, _ayan, ারা_,
  { {0x63ad1fd3, 0xf2c90049, 0xf8b000a1, 0x00000000}},  //   _byan, _זע_, _وکٹ_,
  { {0x63ad1fd4, 0xd7f80245, 0x00000000, 0x00000000}},  //   _cyan, _рух_,   ,
  { {0x386d05af, 0xd29501fb, 0x4545035b, 0x00000000}},  //   lker_, арсь, _منتق,
  { {0x7c220792, 0x7eab010f, 0x63ad0022, 0x00000000}},  //   yfor, nüpu, _eyan,
  { {0x6e3c04f8, 0x388c00b9, 0x7c221c7e, 0x00000000}},  //   _sarb, běru_, xfor,
  { {0x386d015c, 0x6d470f99, 0x6e3c07c8, 0x00000000}},  // [4ce0] iker_, _arja, _parb,
  { {0x7c220857, 0xd045013f, 0x00000000, 0x00000000}},  //   wfor, _muhə,   ,
  { {0x386d0374, 0x6e3c001e, 0x85f60049, 0x00000000}},  //   kker_, _varb, רמעס_,
  { {0xeb9a10a9, 0x386d00b5, 0x7c220145, 0x00000000}},  //   ние_, jker_, ufor,
  { {0x6e3c0004, 0x7c220038, 0xab62006b, 0x00000000}},  //   _tarb, rfor, _şübh,
  { {0x7c220018, 0x386d00b5, 0x00000000, 0x00000000}},  //   sfor, eker_,   ,
  { {0x7c220056, 0x14cf0204, 0xe9df0082, 0x00000000}},  //   pfor, _संगण, _đút_,
  { {0x63a90046, 0x66030197, 0xb4ae01f5, 0x00000000}},  //   żeni, _adnk, कतो_,
  { {0x6a160137, 0x44f1010a, 0x2ca6017b, 0x00000000}},  //   _مبار, eš_, mood_,
  { {0x386d00ab, 0x2ca6010e, 0x388c013e, 0x00000000}},  //   aker_, lood_, věru_,
  { {0x63ad130b, 0x38ba01d6, 0x48e6004d, 0x00000000}},  //   _syan, eëre_, _соев,
  { {0x386d1fd5, 0x2ca6006a, 0x65680023, 0x00000000}},  //   cker_, nood_, rydh,
  { {0x6d41008e, 0x657a0010, 0x00000000, 0x00000000}},  //   _álav, szth,   ,
  { {0x63ad1896, 0x20190145, 0x2ca600ab, 0x00000000}},  //   _vyan, _scsi_, hood_,
  { {0x69ce0b32, 0x2ca6006c, 0x9f4b00d4, 0x00000000}},  //   _úbed, kood_, _secà_,
  { {0x63ad020e, 0x9f4b00f6, 0x00000000, 0x00000000}},  //   _tyan, _pecà_,   ,
  { {0x44291fd6, 0x26ce0020, 0x2ca607a5, 0x00000000}},  // [4cf0] _iba_, _kifo_, dood_,
  { {0x442905ae, 0xdd9b0088, 0x261c007d, 0x00000000}},  //   _hba_, нше_, _माफी_,
  { {0x386d0007, 0xbc190451, 0x00000000, 0x00000000}},  //   yker_, вілі_,   ,
  { {0x44290ee1, 0x26ce005b, 0x7a1e0173, 0x00000000}},  //   _jba_, _lifo_, _lņtč,
  { {0x44291fd7, 0x447c0049, 0x291e0066, 0x00000000}},  //   _mba_, ענדע, _aqta_,
  { {0xaa450a27, 0x386d1fd8, 0xcb661fd9, 0x00000000}},  //   рекл, wker_, раше_,
  { {0x386d0170, 0x60cf0107, 0xe509013d, 0x00000000}},  //   tker_, _kicm, _विधि_,
  { {0x6f0d0051, 0x7c8701fc, 0x00000000, 0x00000000}},  //   orac, _суге,   ,
  { {0x386d004e, 0x7c290885, 0x6f0d0051, 0x00000000}},  //   rker_, _iber, nrac,
  { {0x4429011c, 0x386d02cc, 0xa5250264, 0x00000000}},  //   _aba_, sker_, амод,
  { {0x44290145, 0x6f0d19ad, 0xc9840545, 0x00000000}},  //   _bba_, hrac, _луци,
  { {0x6f0d1fda, 0x64a603e0, 0x60cf00b9, 0x00000000}},  //   krac, рама, _nicm,
  { {0x44290030, 0x27ed0047, 0x7c291dcb, 0x00000000}},  //   _dba_, mben_, _mber,
  { {0x27ed138a, 0x44291fdb, 0x877a01ce, 0x00000000}},  //   lben_, _eba_, _באני,
  { {0x7c291fdc, 0x44290b69, 0xdd19002b, 0x00000000}},  //   _ober, _fba_, għże,
  { {0x3fe61fdd, 0x6f0d001a, 0x4429008e, 0x00000000}},  //   ржав, frac, _gba_,
  { {0x27ed001f, 0x1e860088, 0x7eb000b0, 0x00000000}},  // [4d00] iben_, алам, läpi,
  { {0x7c291fde, 0x2ca600ab, 0xe0da1281, 0x00000000}},  //   _aber, wood_, _иво_,
  { {0x27ed0047, 0x61fc014a, 0x6f0d1fdf, 0x00000000}},  //   kben_, marl, arac,
  { {0x61fc049d, 0x0b460264, 0x6f0d1e7c, 0x00000000}},  //   larl, инен, brac,
  { {0x6f0d049a, 0x2ca6109a, 0xa01b0039, 0x00000000}},  //   crac, rood_, _omöj,
  { {0x61fc000c, 0x27ed001f, 0x7c290109, 0x00000000}},  //   narl, eben_, _eber,
  { {0xfa6706e3, 0x2ca6006c, 0xe2a7000c, 0x00000000}},  //   рајк_, pood_, úðir_,
  { {0xec1600a2, 0x27ed0010, 0x5838004d, 0x00000000}},  //   _خورد, gben_, узия_,
  { {0x61fc1fe0, 0xc6f7008b, 0x44291fe1, 0x00000000}},  //   karl, аных_, _rba_,
  { {0x61fc1fe2, 0xa3bd013d, 0x442903c9, 0x00000000}},  //   jarl, _अरब_, _sba_,
  { {0x27ed0376, 0x61fc1fe3, 0x44290058, 0x00000000}},  //   bben_, darl, _pba_,
  { {0x746b09e8, 0x61f70193, 0x6f0d0016, 0x00000000}},  //   тров_, _sexl, yrac,
  { {0xec71007b, 0x61fc00eb, 0x4429101a, 0x00000000}},  //   פֿט_, farl, _vba_,
  { {0x443f04a3, 0x6f0d0235, 0x61fc0ee4, 0x00000000}},  //   žu_, vrac, garl,
  { {0x6f0d0036, 0x787501e5, 0x44290133, 0x00000000}},  //   wrac, _háva, _tba_,
  { {0x61ee0003, 0x44291588, 0x38a10036, 0x00000000}},  //   abbl, _uba_, wórz_,
  { {0x248901d9, 0x6f0d0c0f, 0x61fc1ece, 0x00000000}},  // [4d10] _imam_, urac, barl,
  { {0x61fc0e1d, 0x27ed0047, 0xe45f0039, 0x00000000}},  //   carl, zben_, ljö_,
  { {0x27ed0010, 0x6f0d0051, 0x00000000, 0x00000000}},  //   yben_, srac,   ,
  { {0x6f0d0161, 0xa136012f, 0x88bc00b9, 0x00000000}},  //   prac, _פארק_, _zpěv,
  { {0x27ed08fe, 0x78751539, 0x00000000, 0x00000000}},  //   vben_, _náva,   ,
  { {0x53380049, 0x7f3a0049, 0x00000000, 0x00000000}},  //   ינדן_, _געשו,   ,
  { {0x27ed0047, 0x7c290066, 0xaa56003b, 0x00000000}},  //   tben_, _tber, сију_,
  { {0x61fc1fe4, 0x7c290181, 0x27ed010f, 0x00000000}},  //   zarl, _uber, uben_,
  { {0x27ed196d, 0xbb850054, 0x61fc1fe5, 0x00000000}},  //   rben_, _الذي, yarl,
  { {0x27ed0010, 0x60c40107, 0xe8190164, 0x00000000}},  //   sben_, zmim, _धावा_,
  { {0x61fc030e, 0xb658007e, 0x764100eb, 0x00000000}},  //   varl, ршых_, rdly,
  { {0x2545001e, 0x3e76000c, 0x00000000, 0x00000000}},  //   _vēl_, _mæta_,   ,
  { {0xb7da0049, 0xd6291fe6, 0x7eb00052, 0x00000000}},  //   _עקסי, _боле_, säpi,
  { {0x91e3017f, 0x2cbf0066, 0x00000000, 0x00000000}},  //   зоре, _lhud_,   ,
  { {0x61fc011f, 0x787501ca, 0xceb4006b, 0x00000000}},  //   rarl, _záva, stək_,
  { {0x61fc1fe7, 0x3493025f, 0x00000000, 0x00000000}},  //   sarl, _најр,   ,
  { {0x60c40065, 0x61fc014a, 0x63a90ddb, 0x00000000}},  // [4d20] rmim, parl, üent,
  { {0x3e76009f, 0xc7b200a3, 0xe29f000c, 0x00000000}},  //   _bæta_, לבן_, yrði_,
  { {0xa0a6007e, 0x63a901d5, 0x628e1fe8, 0x00000000}},  //   _ганд, żent, mibo,
  { {0x628e011c, 0x31570049, 0x78a9016c, 0x00000000}},  //   libo, _היטן_, joev,
  { {0x38ba0065, 0x78a91fe9, 0x00000000, 0x00000000}},  //   jëra_, doev,   ,
  { {0xdee300d7, 0x2cbf013f, 0x2ce800a2, 0x00000000}},  //   _хори, _ehud_, _نظری_,
  { {0xb50902fb, 0x649601d5, 0x3e76000c, 0x00000000}},  //   _विषय_, rġij, _gæta_,
  { {0xe45f0039, 0x628e07b1, 0x38c800a1, 0x00000000}},  //   xjö_, hibo, جاتی_,
  { {0x628e01aa, 0x1ddc007d, 0xe819006e, 0x00000000}},  //   kibo, _बलात, _धारा_,
  { {0x8c44001a, 0xda650379, 0xbdf60044, 0x00000000}},  //   ăşur, _والي, _চাঁদ_,
  { {0xd7ef1fea, 0x499a005e, 0xa96a05f3, 0x00000000}},  //   _ну_, _стая_, _حمام_,
  { {0x7d03008e, 0x6aaa0116, 0x7eab010e, 0x00000000}},  //   ánsi, loff, hüpp,
  { {0x628e18d9, 0x938b02dc, 0x6a6f0146, 0x00000000}},  //   fibo, усна_, _bøfh,
  { {0x38660100, 0x3f800006, 0x171b0049, 0x00000000}},  //   _hoor_, dziu_, _עווע,
  { {0x54e606b4, 0x9f590343, 0x3866109a, 0x00000000}},  //   _استق, _gesê_, _koor_,
  { {0x439501a4, 0x760200b9, 0x81d90044, 0x00000000}},  //   _майс, bízí, ারই_,
  { {0x386601d6, 0x6aaa0240, 0x628e0009, 0x00000000}},  // [4d30] _moor_, koff, bibo,
  { {0x88bc00b9, 0x394c00ea, 0x7aeb0009, 0x00000000}},  //   _zpět, _ords_, vpgt,
  { {0x6aaa005b, 0xe2a7000c, 0x00000000, 0x00000000}},  //   doff, úður_,   ,
  { {0x38661feb, 0x2a6500e0, 0xf3ff00c4, 0x00000000}},  //   _noor_, _solb_, naã_,
  { {0x501a00a0, 0x629a04bb, 0x6d5816af, 0x00000000}},  //   _דורו, čtov, ävar,
  { {0x6aaa1915, 0xbebb0023, 0xdea400a1, 0x00000000}},  //   goff, _epër, _ٹیمی,
  { {0x48790401, 0xeab0006d, 0x38660112, 0x00000000}},  //   исия_, رعه_, _boor_,
  { {0xd7090589, 0x2cbf1fec, 0x201b01f3, 0x00000000}},  //   ание_, _uhud_, ngqi_,
  { {0x38660f12, 0x78a91fed, 0x869900ed, 0x00000000}},  //   _door_, roev, итот_,
  { {0x78a410f7, 0x69a401f5, 0x394c00e5, 0x00000000}},  //   čiva, _चुकी, _frds_,
  { {0x628e18d9, 0x7ae90521, 0x2d810051, 0x00000000}},  //   vibo, _htet, nzhe_,
  { {0x38660112, 0x00000000, 0x00000000, 0x00000000}},  //   _goor_,   ,   ,
  { {0x628e082c, 0x63ba0036, 0x28df0309, 0x00000000}},  //   tibo, ętno, _पंडि,
  { {0x479a0049, 0x27ff000c, 0x7ae900e7, 0x00000000}},  //   _דינס, laun_, _mtet,
  { {0x628e1fee, 0x9f590065, 0x76430127, 0x00000000}},  //   ribo, _fesë_, _iany,
  { {0x76430149, 0x7ae900b0, 0x628e19be, 0x00000000}},  //   _hany, _otet, sibo,
  { {0x76430811, 0x4420028c, 0x6d411fef, 0x00000000}},  // [4d40] _kany, _ici_, _šlap,
  { {0x3f800f04, 0xaec30088, 0x6aaa0019, 0x00000000}},  //   rziu_, дбул, xoff,
  { {0x7643018e, 0x78750161, 0x64440058, 0x00000000}},  //   _many, _návo, _kaii,
  { {0x9b6a0175, 0x614300b9, 0x6aaa0009, 0x00000000}},  //   ишла_, sílá, woff,
  { {0x6aaa1440, 0x2b4d0129, 0x44201ff0, 0x00000000}},  //   toff, _crec_, _mci_,
  { {0x6f0401d6, 0x76431ff1, 0x4420009d, 0x00000000}},  //   msic, _nany, _lci_,
  { {0x6aaa1c95, 0x44201ff2, 0x1d07003b, 0x00000000}},  //   roff, _oci_, _мери_,
  { {0x6aaa00f8, 0x6444006a, 0x44200095, 0x00000000}},  //   soff, _naii, _nci_,
  { {0x3866017c, 0x76430149, 0x6f04010f, 0x00000000}},  //   _voor_, _bany, nsic,
  { {0xf76f0379, 0x0f57009b, 0x64560969, 0x00000000}},  //   ضاً_, קיים_, _anyi,
  { {0x76430036, 0x2fc70011, 0x9f590065, 0x00000000}},  //   _dany, ̀ng_, _pesë_,
  { {0x629e0129, 0x4420009d, 0x9f59000a, 0x00000000}},  //   _ajpo, _cci_, _fesè_,
  { {0x76430016, 0x787501ca, 0x27e601aa, 0x00000000}},  //   _fany, _závo, _ifon_,
  { {0x787c028c, 0x7643006a, 0x6d4e0e57, 0x00000000}},  //   _déve, _gany, _orba,
  { {0x442000ca, 0x867b009b, 0x6f060087, 0x00000000}},  //   _fci_, _דרגו, _avkc,
  { {0xa2bb02d2, 0x44201ff3, 0x6f0401a2, 0x00000000}},  //   _शीर्, _gci_, fsic,
  { {0xcddb03f3, 0x6d4e0006, 0x76431c39, 0x00000000}},  // [4d50] ање_, _arba, _yany,
  { {0x44391ff4, 0xc33400a0, 0x6d4e016c, 0x00000000}},  //   les_, _חוץ_, _brba,
  { {0x7ae91ff5, 0x443900fa, 0x27e60761, 0x00000000}},  //   _stet, oes_, _ofon_,
  { {0x44391718, 0x2b4d1ff6, 0x6f041ff7, 0x00000000}},  //   nes_, _prec_, bsic,
  { {0x09e51ae1, 0x443900f4, 0x6d4e169c, 0x00000000}},  //   полн, ies_, _erba,
  { {0x27e60016, 0x38970035, 0x27ff005b, 0x00000000}},  //   _afon_, mări_, waun_,
  { {0xc27c009b, 0x76430173, 0x38970035, 0x00000000}},  //   שרוי, _rany, lări_,
  { {0x4439004a, 0x76431ff8, 0x2b4d001a, 0x00000000}},  //   jes_, _sany, _trec_,
  { {0x764301aa, 0x7ae9000b, 0x27ff0f30, 0x00000000}},  //   _pany, _utet, raun_,
  { {0x673b1ff9, 0x78750010, 0x787c1ffa, 0x00000000}},  //   rwuj, _távo, _réve,
  { {0x764301aa, 0x442b0009, 0x44391ffb, 0x00000000}},  //   _vany, ffc_, fes_,
  { {0x4439032c, 0x6f040038, 0x76430020, 0x00000000}},  //   ges_, ysic, _wany,
  { {0xe72e008b, 0x76430127, 0x387f1d7d, 0x00000000}},  //   _яе_, _tany, mhur_,
  { {0x11da0054, 0x20000133, 0x200b0026, 0x00000000}},  //   صورة_, waii_, _adci_,
  { {0x95cb007c, 0x6b820197, 0x6601003f, 0x00000000}},  //   _туда_, zzog, malk,
  { {0x53a60099, 0x44200107, 0x73060aa2, 0x00000000}},  //   _найб, _uci_, _епиз,
  { {0x27fd0bc4, 0x6d4e0645, 0xa067005e, 0x00000000}},  // [4d60] _mewn_, _srba, чата_,
  { {0x6f04001f, 0x660104cb, 0x59cb0164, 0x00000000}},  //   rsic, nalk, ाधार,
  { {0x6f040912, 0x44e10047, 0x8ebb0044, 0x00000000}},  //   ssic, _jó_, _অংশগ,
  { {0x44e1002a, 0x3897001a, 0x660101a2, 0x00000000}},  //   _mó_, bări_, halk,
  { {0x387f008d, 0x660101a3, 0x3897001a, 0x00000000}},  //   dhur_, kalk, cări_,
  { {0x44391ffc, 0x63b6021e, 0x66011d9c, 0x00000000}},  //   zes_, _myyn, jalk,
  { {0x44e11ffd, 0x44390e76, 0xa96700e1, 0x00000000}},  //   _nó_, yes_, зија_,
  { {0x8c4310df, 0x44390b25, 0x0d7700a2, 0x00000000}},  //   _песе, xes_, _عینک_,
  { {0x443903db, 0x76aa007c, 0xbb98009e, 0x00000000}},  //   ves_, йтов_, _بچاؤ_,
  { {0x5574029b, 0x44391ffe, 0x61fe0161, 0x00000000}},  //   дгот, wes_, _nepl,
  { {0x44e100ad, 0x27fd018e, 0x3897001a, 0x00000000}},  //   _có_, _fewn_, zări_,
  { {0x44e1002a, 0x443900cc, 0x387f0051, 0x00000000}},  //   _dó_, ues_, chur_,
  { {0x61fe0007, 0x66010723, 0x69da00e0, 0x00000000}},  //   _bepl, balk, _kgte,
  { {0x442b0066, 0x61fe0059, 0x17570097, 0x00000000}},  //   sfc_, _cepl, _מסדר_,
  { {0x61fe1fff, 0xa5d702fd, 0xf1a40264, 0x00000000}},  //   _depl, _عبور_, ертн,
  { {0x44390a61, 0x3897001a, 0x629c02d4, 0x00000000}},  //   qes_, tări_, anro,
  { {0x60de00f6, 0xe2aa0014, 0x69da00d9, 0x00000000}},  // [4d70] _eupm, _ژاپن_, _ogte,
  { {0x61fe17cc, 0xdcfc01f6, 0x76480016, 0x00000000}},  //   _gepl, _ayrı, nddy,
  { {0x705500a1, 0x200b0253, 0x06e30044, 0x00000000}},  //   _ہنگا, _tdci_, _মিছি,
  { {0x69da0343, 0x254c0224, 0x81d90044, 0x00000000}},  //   _agte, _měl_, ারও_,
  { {0xfebb0014, 0xdb1b0082, 0xed600089, 0x00000000}},  //   _هاست_, _nguô, āžas_,
  { {0x52da0044, 0x00000000, 0x00000000, 0x00000000}},  //   বীকৃ,   ,   ,
  { {0x387f0675, 0x66010059, 0x6d3400d7, 0x00000000}},  //   thur_, valk, _перф,
  { {0x315800b6, 0x69da0343, 0x46e901c0, 0x00000000}},  //   ליון_, _egte, один_,
  { {0x44e10907, 0x00000000, 0x00000000, 0x00000000}},  //   _só_,   ,   ,
  { {0x387f008d, 0x2caf00b5, 0x44e100c4, 0x00000000}},  //   shur_, logd_, _pó_,
  { {0x61fe2000, 0xd9990054, 0x660100ca, 0x00000000}},  //   _repl, _بنات_, ralk,
  { {0x69c1011f, 0x9507026c, 0xc20900b3, 0x00000000}},  //   _izle, _ہفتے_, _כה_,
  { {0xf74502b0, 0xae1e0316, 0x66012001, 0x00000000}},  //   _цело, _पालन_, palk,
  { {0x44e10010, 0x2caf00ea, 0x00000000, 0x00000000}},  //   _tó_, hogd_,   ,
  { {0x91e30256, 0x67290087, 0x00000000, 0x00000000}},  //   тосе, ltej,   ,
  { {0x63a4002d, 0x63b60052, 0x00000000, 0x00000000}},  //   _txin, _tyyn,   ,
  { {0xe4c701ef, 0x67290129, 0x61fe004f, 0x00000000}},  // [4d80] _تصوی, ntej, _tepl,
  { {0x290700d0, 0xee370407, 0xb8810802, 0x00000000}},  //   ksna_, мну_, _šíle,
  { {0xa06a012b, 0xa01b0210, 0xf41f0039, 0x00000000}},  //   _дана_, _blöd, miär_,
  { {0xe819007d, 0x78750161, 0x00000000, 0x00000000}},  //   _धागा_, _dávk,   ,
  { {0x7648018e, 0x7c650025, 0x00000000, 0x00000000}},  //   yddy, عامل,   ,
  { {0x9f400062, 0x00000000, 0x00000000, 0x00000000}},  //   ncií_,   ,   ,
  { {0xa01b0039, 0x44321d85, 0xb05b00f8, 0x00000000}},  //   _flöd, _oby_, _ohäl,
  { {0x807b007b, 0xc07b0049, 0x907b0049, 0x00000000}},  //   ַניצ, ַטיש, ַטיי,
  { {0x6f160016, 0x69da0026, 0xba26003b, 0x00000000}},  //   nryc, _tgte, _одак,
  { {0x44320ce2, 0x787c2002, 0x77910014, 0x00000000}},  //   _aby_, _déva, دیها,
  { {0xc58a007c, 0x6d5a0010, 0x6f16005b, 0x00000000}},  //   ющие_, _átad, hryc,
  { {0x7ae0000b, 0x6f160036, 0x291c010e, 0x00000000}},  //   _kumt, kryc, muva_,
  { {0x44320009, 0x7ae00089, 0x291c0142, 0x00000000}},  //   _dby_, _jumt, luva_,
  { {0xf7d700a0, 0x44322003, 0xeb910049, 0x00000000}},  //   _חודש_, _eby_, אָל_,
  { {0x7ae00065, 0x403500ed, 0x306b01fc, 0x00000000}},  //   _lumt, невс, ојан_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ae00e9b, 0x00000000, 0x00000000, 0x00000000}},  // [4d90] _numt,   ,   ,
  { {0x291c00b0, 0x752f0036, 0x290701d6, 0x00000000}},  //   kuva_, ńcze, ysna_,
  { {0xe3b00123, 0xdd910025, 0x60c9002b, 0x00000000}},  //   _مری_, دوا_, ċemb,
  { {0x62952004, 0x6f160036, 0x291c2005, 0x00000000}},  //   lizo, bryc, duva_,
  { {0x60cd0740, 0xefcb02e9, 0xceb4006b, 0x00000000}},  //   mmam, _функ_, rtər_,
  { {0x60cd014a, 0xceb4006b, 0x388c00b9, 0x00000000}},  //   lmam, stər_, měry_,
  { {0x63ba0036, 0x291c0089, 0x08d50401, 0x00000000}},  //   ętni, guva_, нция,
  { {0x60cd005a, 0x672900b0, 0x29072006, 0x00000000}},  //   nmam, ttej, rsna_,
  { {0x29070039, 0x6fdc009b, 0xb906007d, 0x00000000}},  //   ssna_, חחחח, _यू_,
  { {0x672900d4, 0x44320762, 0x629500e7, 0x00000000}},  //   rtej, _sby_, jizo,
  { {0x6729021e, 0x69c10107, 0x291c041a, 0x00000000}},  //   stej, _uzle, cuva_,
  { {0x67292007, 0x6a7400f6, 0x60cd0142, 0x00000000}},  //   ptej, _ràfi, jmam,
  { {0x68e12008, 0x78bb01dc, 0x62950065, 0x00000000}},  //   _huld, mluv, fizo,
  { {0x68e111ef, 0x62952009, 0x78bb044e, 0x00000000}},  //   _kuld, gizo, lluv,
  { {0x205600d7, 0xa5640025, 0xe6b40014, 0x00000000}},  //   нтар, _لدين, _جلوگ,
  { {0x6f160ae1, 0x68e1200a, 0x60cd006a, 0x00000000}},  //   tryc, _muld, gmam,
  { {0xaec6098c, 0x91e601fb, 0x1fa70726, 0x00000000}},  // [4da0] ебал, _попе, екти_,
  { {0x7a3301df, 0x60cd0197, 0x7875200b, 0x00000000}},  //   nıtı, amam, _dávi,
  { {0xe8200061, 0x6d5a200c, 0x24800007, 0x00000000}},  //   _याला_, _štab, _klim_,
  { {0x44220460, 0x60cd009d, 0x388c013e, 0x00000000}},  //   ngk_, cmam, běry_,
  { {0xfe1e001c, 0x8b660025, 0x2a7e0145, 0x00000000}},  //   _पाऊस_, عاصم, _pltb_,
  { {0x291c010a, 0x78a2200d, 0x68e1014a, 0x00000000}},  //   tuva_, _sjov, _buld,
  { {0xa3d001f5, 0xbea300ed, 0x78750161, 0x00000000}},  //   वेत_, _сарк, _závi,
  { {0xb5090309, 0x291c00f8, 0x62950bb2, 0x00000000}},  //   _विजय_, ruva_, zizo,
  { {0x9f40200e, 0x7d1e0030, 0x8626007e, 0x00000000}},  //   ncià_, lups, ньне,
  { {0x68e10030, 0x2480200f, 0x7e6e0190, 0x00000000}},  //   _fuld, _alim_, _jobp,
  { {0x68e10193, 0x04b800a1, 0x60cd049d, 0x00000000}},  //   _guld, کھوں_, ymam,
  { {0x20022010, 0x7c2201a3, 0x62950036, 0x00000000}},  //   _neki_, ngor, wizo,
  { {0x62950142, 0x00000000, 0x00000000, 0x00000000}},  //   tizo,   ,   ,
  { {0x20020022, 0x24800095, 0x64960006, 0x00000000}},  //   _aeki_, _elim_, ršia,
  { {0x3e76009f, 0x64960521, 0xc1770151, 0x00000000}},  //   _gæti_, mšin, ردست,
  { {0x7c222011, 0x62950020, 0x248001c3, 0x00000000}},  //   jgor, sizo, _glim_,
  { {0x7c22016c, 0x2002014a, 0x00000000, 0x00000000}},  // [4db0] dgor, _deki_,   ,
  { {0x60cd2012, 0x62950023, 0x764a000a, 0x00000000}},  //   smam, qizo, _jafy,
  { {0x9873000d, 0x60cd014a, 0x200200e7, 0x00000000}},  //   nţă_, pmam, _feki_,
  { {0x6d5a1b84, 0x764a0173, 0x6ac9006e, 0x00000000}},  //   _štac, _lafy, िग्र,
  { {0xbb4500e3, 0x68e1002b, 0x290c0efe, 0x00000000}},  //   телк, _suld, _avda_,
  { {0xc3340104, 0x7c220032, 0x2002014a, 0x00000000}},  //   רוס_, agor, _zeki_,
  { {0xecbb0123, 0x00000000, 0x00000000, 0x00000000}},  //   _فطرت_,   ,   ,
  { {0x787c00f4, 0xccf2009b, 0x64960006, 0x00000000}},  //   _dévo, _ככל_, ešin,
  { {0x3e76000c, 0x7b18005e, 0x66150010, 0x00000000}},  //   _sæti_, _потр_, ózko,
  { {0x68e10be4, 0x78bb12de, 0x24800aba, 0x00000000}},  //   _tuld, sluv, _slim_,
  { {0xe5a5003b, 0x24802013, 0x764a0016, 0x00000000}},  //   тини, _plim_, _dafy,
  { {0xf7700063, 0x39580048, 0x00000000, 0x00000000}},  //   _گام_, _ársa_,   ,
  { {0xe3b20025, 0x20022014, 0x98730035, 0x00000000}},  //   شرح_, _reki_, aţă_,
  { {0x09d50055, 0xf770031d, 0x67d42015, 0x00000000}},  //   _স্যা, _دام_, _сочу,
  { {0x2b91001d, 0x9987010a, 0x9103003b, 0x00000000}},  //   ạch_, menų_, ипре,
  { {0x6603021e, 0xa3e80164, 0x38ba0023, 0x00000000}},  //   _henk, मुख_, tëri_,
  { {0x6d470004, 0x3fe317b9, 0x66030ecb, 0x00000000}},  // [4dc0] _asja, ржув, _kenk,
  { {0x660300b0, 0x6d552016, 0x2b5800b9, 0x00000000}},  //   _jenk, _brza, _črc_,
  { {0x66032017, 0x200200b0, 0x7c220544, 0x00000000}},  //   _menk, _teki_, tgor,
  { {0x6d55021d, 0x38ba008d, 0x66032018, 0x00000000}},  //   _drza, përi_, _lenk,
  { {0x4fa301fb, 0x38ba0065, 0x787c000a, 0x00000000}},  //   _вияв, qëri_, _dévl,
  { {0x7c220b36, 0x290c00b5, 0x66030023, 0x00000000}},  //   sgor, _pvda_, _nenk,
  { {0x09d50055, 0x81b40055, 0x7d53026c, 0x00000000}},  //   _স্বা, জের_, _پہنچ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf09301f8, 0x1ae601fb, 0x66030020, 0x00000000}},  //   ינה_, _розм, _benk,
  { {0x78ad0091, 0x64960006, 0x99870006, 0x00000000}},  //   čava, ušin, genų_,
  { {0x66031440, 0x64961a72, 0xf76f007a, 0x00000000}},  //   _denk, ršin, مای_,
  { {0x7d030181, 0x66030007, 0x98730035, 0x00000000}},  //   ânsi, _eenk, rţă_,
  { {0x64962019, 0x16340256, 0x00000000, 0x00000000}},  //   pšin, _беля,   ,
  { {0x66030030, 0x261c0164, 0x00000000, 0x00000000}},  //   _genk, _माटी_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6603007f, 0x43850025, 0xb42700a1, 0x00000000}},  //   _zenk, _ملعق, _شعبو,
  { {0x4429201a, 0xd904026c, 0x6603000a, 0x00000000}},  // [4dd0] _ica_, _ڈی_, _yenk,
  { {0xd90406c6, 0x249900ab, 0x44290ee6, 0x00000000}},  //   _وی_, lism_, _hca_,
  { {0xf1ab0014, 0x44290bca, 0x644d0168, 0x00000000}},  //   _زاده_, _kca_, _kaai,
  { {0x261c001c, 0x24990e5f, 0x644f00d9, 0x00000000}},  //   _माझी_, nism_, ndci,
  { {0x644d08b2, 0x44290145, 0xff04007e, 0x00000000}},  //   _maai, _mca_, _вясн,
  { {0x6e9513e7, 0x26dc01aa, 0x20090007, 0x00000000}},  //   _сигу, _nivo_, laai_,
  { {0x261c0061, 0x6603201b, 0xceb2009b, 0x00000000}},  //   _माजी_, _renk, _הים_,
  { {0x6603121b, 0x644d201c, 0x44290792, 0x00000000}},  //   _senk, _naai, _nca_,
  { {0x60dd201d, 0x66030f38, 0x249911f2, 0x00000000}},  //   _mism, _penk, dism_,
  { {0x44290211, 0x66030065, 0x645f01f3, 0x00000000}},  //   _aca_, _qenk, _anqi,
  { {0x660300b9, 0x44290093, 0x3e76000c, 0x00000000}},  //   _venk, _bca_, _gætu_,
  { {0x09d50055, 0x60dd0119, 0x442907e4, 0x00000000}},  //   _স্থা, _nism, _cca_,
  { {0x66030056, 0x442902c1, 0xddce0006, 0x00000000}},  //   _tenk, _dca_, _pobū,
  { {0x479a0097, 0x81bf0044, 0x442912dd, 0x00000000}},  //   _אינס, েশন_, _eca_,
  { {0x60dd0091, 0x24990e4e, 0x76410010, 0x00000000}},  //   _bism, bism_, mely,
  { {0x26dc0107, 0x249900ab, 0x76411b18, 0x00000000}},  //   _zivo_, cism_, lely,
  { {0xa3d00316, 0x60dd201e, 0x6f0d00f6, 0x00000000}},  // [4de0] वेश_, _dism, gsac,
  { {0xe1fa008b, 0x7c29201f, 0x60dd0006, 0x00000000}},  //   _яго_, _acer, _eism,
  { {0x8d760025, 0x60dd2020, 0x20090007, 0x00000000}},  //   داءا, _fism, baai_,
  { {0x76412021, 0xac250088, 0x60dd1a3a, 0x00000000}},  //   hely, ифік, _gism,
  { {0x7c2901ca, 0x7f76003b, 0x3e76000c, 0x00000000}},  //   _dcer, _сунц, _bætt_,
  { {0x7c29023a, 0x24990203, 0x76410374, 0x00000000}},  //   _ecer, zism_, jely,
  { {0x7641174d, 0x24992022, 0xe5670025, 0x00000000}},  //   dely, yism_, _اط_,
  { {0x320a1a0b, 0x7521004a, 0xe45f000c, 0x00000000}},  //   haby_, dulz, mlög_,
  { {0x26dc016e, 0xb6060088, 0x644d07a5, 0x00000000}},  //   _pivo_, лянк, _raai,
  { {0x76410007, 0x442900f8, 0x644d0116, 0x00000000}},  //   gely, _sca_, _saai,
  { {0x26dc029d, 0x2499121e, 0x649605fa, 0x00000000}},  //   _vivo_, tism_, mšij,
  { {0x69c81710, 0x6f0d0544, 0x00000000, 0x00000000}},  //   _izde, ysac,   ,
  { {0x2499001a, 0x66080046, 0xe6c4000c, 0x00000000}},  //   rism_, padk, þjóð,
  { {0x60dd0e32, 0x249900f8, 0x20090116, 0x00000000}},  //   _sism, sism_, waai_,
  { {0x44290173, 0x6486002a, 0x6d5a0142, 0x00000000}},  //   _tca_, _dóib, _štan,
  { {0x60dd006b, 0x6f0d010f, 0x4429006b, 0x00000000}},  //   _qism, tsac, _uca_,
  { {0x60dd001e, 0x200907a5, 0x657a005b, 0x00000000}},  // [4df0] _vism, raai_, lyth,
  { {0x6f0d2023, 0x81b40044, 0x291c0107, 0x00000000}},  //   rsac, জেই_, krva_,
  { {0x60dd2024, 0x62852025, 0x6f0d00ab, 0x00000000}},  //   _tism, _ilho, ssac,
  { {0x3b5502dc, 0xac1902d3, 0x3e7601e5, 0x00000000}},  //   икер, тоду_, _sætt_,
  { {0x69c801ee, 0x6f0f00e7, 0x2ee9002b, 0x00000000}},  //   _azde, _uvcc, qqaf_,
  { {0x78750428, 0xfbd00014, 0xfaa502ea, 0x00000000}},  //   _návr, ستن_, јако,
  { {0x76410ff8, 0x27ed0032, 0x00000000, 0x00000000}},  //   vely, tcen_,   ,
  { {0x7af50088, 0x76410016, 0x69d50161, 0x00000000}},  //   _взає, wely, _územ,
  { {0x0685012b, 0x62850181, 0x764100b0, 0x00000000}},  //   игин, _olho, tely,
  { {0xbb840025, 0x27ed001a, 0x7a5700f3, 0x00000000}},  //   _الكي, scen_, _حضرا,
  { {0x81eb0044, 0x657a0016, 0x38ba0023, 0x00000000}},  //   মরা_, gyth, tërt_,
  { {0x62852026, 0x752f0036, 0x764100b0, 0x00000000}},  //   _alho, ńczo, sely,
  { {0x386d0243, 0x7521006b, 0xa01b01e5, 0x00000000}},  //   mjer_, sulz, _plön,
  { {0x386d05cc, 0x471a007b, 0x36690184, 0x00000000}},  //   ljer_, _יונג, _јако_,
  { {0x62850142, 0x3aeb00ea, 0x38ba0023, 0x00000000}},  //   _dlho, _løp_, përt_,
  { {0xe0df0207, 0x386d0292, 0x64a3005e, 0x00000000}},  //   _ciò_, njer_, _маща,
  { {0xe3b8006b, 0x4e060072, 0x386d00bb, 0x00000000}},  // [4e00] şıb_, изаб, ijer_,
  { {0x7c3d0095, 0x22930025, 0x00000000, 0x00000000}},  //   _ısra, _وليس,   ,
  { {0x387f009f, 0x386d05e3, 0x629c0091, 0x00000000}},  //   kkur_, kjer_, miro,
  { {0xf536007b, 0xe5360049, 0xe0580123, 0x00000000}},  //   יטער_, יטעט_, _حیرت_,
  { {0x63ad2027, 0x386d016e, 0xf4170049, 0x00000000}},  //   _xxan, djer_, בֿות_,
  { {0x291c2028, 0xd35700b3, 0x00000000, 0x00000000}},  //   trva_, ייני_,   ,
  { {0x64962029, 0x38ba0023, 0x00000000, 0x00000000}},  //   ršij, dërr_,   ,
  { {0x69c8202a, 0x386d0056, 0x787c0068, 0x00000000}},  //   _vzde, gjer_, _kévi,
  { {0xe6660603, 0x629c202b, 0x657a0016, 0x00000000}},  //   атно, kiro, wyth,
  { {0x291c11af, 0x657a02d4, 0x00000000, 0x00000000}},  //   prva_, tyth,   ,
  { {0xd7ef0954, 0x629c202c, 0x69c80089, 0x00000000}},  //   _му_, diro, _uzde,
  { {0x657a0edd, 0x2ca60016, 0x629c1690, 0x00000000}},  //   ryth, nnod_, eiro,
  { {0x68e800f8, 0x6d5a04eb, 0x00000000, 0x00000000}},  //   _hudd, _štal,   ,
  { {0x629c202d, 0x68e80a74, 0x877b0097, 0x00000000}},  //   giro, _kudd, _באדי,
  { {0x80070d11, 0x00000000, 0x00000000, 0x00000000}},  //   ичае,   ,   ,
  { {0x68e80190, 0x63ad002d, 0x629c01c3, 0x00000000}},  //   _mudd, _txan, airo,
  { {0x629c202e, 0x68e800f8, 0x0eeb0088, 0x00000000}},  // [4e10] biro, _ludd, тьби_,
  { {0x629c01ee, 0x787c009d, 0x387f007f, 0x00000000}},  //   ciro, _dévi, zkur_,
  { {0x2ca6018e, 0xab62014a, 0x6d5a0010, 0x00000000}},  //   fnod_, _şüph, _átal,
  { {0xa5d90049, 0xe5370049, 0x940b006b, 0x00000000}},  //   אַני, שטאט_, ticə_,
  { {0x7bc0018e, 0x64860181, 0xb7c10044, 0x00000000}},  //   _cymu, _jóia, _উল্ট,
  { {0x68e8202f, 0x7bc00016, 0x8e850025, 0x00000000}},  //   _budd, _dymu, _السه,
  { {0x68e80016, 0x386d00ea, 0x00000000, 0x00000000}},  //   _cudd, tjer_,   ,
  { {0x629c0091, 0x68e82030, 0xbca51095, 0x00000000}},  //   ziro, _dudd, _امري,
  { {0x387f000c, 0x7bc0018e, 0x6a7d01aa, 0x00000000}},  //   rkur_, _gymu, _lèfi,
  { {0xba740054, 0xca740025, 0x387f000c, 0x00000000}},  //   _والت, _والغ, skur_,
  { {0x629c0c03, 0xe820001c, 0xb34801d5, 0x00000000}},  //   viro, _याचा_, _maħż,
  { {0x7ae1002d, 0xb4e7007d, 0x00000000, 0x00000000}},  //   _hilt, _बढी_,   ,
  { {0x7ae12031, 0x629c0016, 0x7c3b0065, 0x00000000}},  //   _kilt, tiro, _mbur,
  { {0x412a004c, 0x6d5a05fa, 0x69c100f8, 0x00000000}},  //   лого_, _štam, _kyle,
  { {0x7ae10ef7, 0x7ae900b0, 0xd1790088, 0x00000000}},  //   _milt, _luet, асті_,
  { {0x629c010a, 0x69c1007f, 0x27ff0022, 0x00000000}},  //   siro, _myle, nbun_,
  { {0xee3a1281, 0xa01b0073, 0x6446006c, 0x00000000}},  // [4e20] лна_, _glöm, meki,
  { {0x64462032, 0xcf250025, 0x7c3b04f3, 0x00000000}},  //   leki, ترفي, _abur,
  { {0x7bc012a7, 0x69c10056, 0x7ae90315, 0x00000000}},  //   _symu, _nyle, _auet,
  { {0xa06a013b, 0x1d070893, 0x6446022b, 0x00000000}},  //   _сама_, сеци_, neki,
  { {0x7ae1002d, 0x7d1e0107, 0x20000035, 0x00000000}},  //   _bilt, srps, mbii_,
  { {0x60c42033, 0x68e80606, 0x7ae90391, 0x00000000}},  //   llim, _pudd, _duet,
  { {0x5d860054, 0x68e801d5, 0x7ae10065, 0x00000000}},  //   _الأل, _qudd, _dilt,
  { {0x6d5c1692, 0x60c40922, 0x69c112a7, 0x00000000}},  //   _irra, nlim, _dyle,
  { {0x69c1014a, 0xc6f70783, 0x661c1530, 0x00000000}},  //   _eyle, бных_, órko,
  { {0x7ae1002d, 0x60c4010f, 0x7c3b2034, 0x00000000}},  //   _gilt, hlim, _zbur,
  { {0xe72f06c6, 0x60c401a3, 0x6d5a0059, 0x00000000}},  //   وصی_, klim, _štaj,
  { {0x64460217, 0x996400b9, 0xab5d0036, 0x00000000}},  //   geki, _kůže_, _wyże,
  { {0x60c40062, 0xdc9b009b, 0x7ae900f6, 0x00000000}},  //   dlim, ריכל, _xuet,
  { {0x99640224, 0x442d0036, 0x6d5c0032, 0x00000000}},  //   _může_, że_, _orra,
  { {0x7e750ce2, 0x64460b79, 0x9f490051, 0x00000000}},  //   _rozp, beki, rcaí_,
  { {0x64a403f3, 0x9f490051, 0x60c413bf, 0x00000000}},  //   _наја, scaí_, glim,
  { {0x6d5c0238, 0x6d4e008a, 0x68e200b4, 0x00000000}},  // [4e30] _arra, _asba, _miod,
  { {0x44390100, 0x60c40052, 0x7c3b00e5, 0x00000000}},  //   lfs_, alim, _sbur,
  { {0x7ae901d6, 0x9f59000c, 0x60c401cb, 0x00000000}},  //   _suet, _jesú_, blim,
  { {0x7ae12035, 0x71f8026c, 0x27e60011, 0x00000000}},  //   _silt, _پریس_, _ngon_,
  { {0x6d5c022b, 0x6d4e2036, 0x7ae10004, 0x00000000}},  //   _erra, _esba, _pilt,
  { {0x64462037, 0x3cf80009, 0x27e60f86, 0x00000000}},  //   zeki, _ftrv_, _agon_,
  { {0x68e2027b, 0x7ae1025c, 0x644600e7, 0x00000000}},  //   _biod, _vilt, yeki,
  { {0x7c3b0061, 0x645a0089, 0x4739007e, 0x00000000}},  //   _ubur, ētik, ачоў_,
  { {0x68e20016, 0x7c24002a, 0x7b670077, 0x00000000}},  //   _diod, óire, _утве,
  { {0x24892038, 0x69c10019, 0x27e6022b, 0x00000000}},  //   _alam_, _tyle, _egon_,
  { {0x64460e33, 0x24892039, 0x443903ce, 0x00000000}},  //   teki, _blam_, ffs_,
  { {0x7c2b04d4, 0xf992009b, 0x2ee300bb, 0x00000000}},  //   nggr, _קרא_, _lijf_,
  { {0xe60e03f3, 0x6446203a, 0x78bb0370, 0x00000000}},  //   _од_, reki, mouv,
  { {0x64460fa8, 0x78bb00b9, 0x2489203b, 0x00000000}},  //   seki, louv, _elam_,
  { {0x78a90065, 0x644601e5, 0x2cbf012d, 0x00000000}},  //   onev, peki, _okud_,
  { {0x200b00f4, 0x78a91603, 0x78bb0e16, 0x00000000}},  //   _ceci_, nnev, nouv,
  { {0x200b000d, 0x60c401a3, 0x3eba00bb, 0x00000000}},  // [4e40] _deci_, rlim, topt_,
  { {0x60c4008d, 0x245f021e, 0x66cf0056, 0x00000000}},  //   slim, _tämä_, bøke,
  { {0x0d86008b, 0x60c40571, 0x78bb01aa, 0x00000000}},  //   ўлен, plim, kouv,
  { {0x5f2a007c, 0x00000000, 0x00000000, 0x00000000}},  //   _комм_,   ,   ,
  { {0x78a90825, 0x69c5050d, 0x2cad0243, 0x00000000}},  //   dnev, ühen, _djed_,
  { {0x200b001a, 0x6d5c1089, 0x442b0009, 0x00000000}},  //   _zeci_, _trra, zgc_,
  { {0x6d5c203c, 0xcb1c0061, 0x6d4e00e0, 0x00000000}},  //   _urra, _निवड_, _usba,
  { {0xdd8f05d4, 0x26c5203d, 0x78a90010, 0x00000000}},  //   _شوق_, ello_, gnev,
  { {0xa01b000c, 0x920a007d, 0x76aa007c, 0x00000000}},  //   _slök, वराज_, итов_,
  { {0xd6d0039d, 0x00000000, 0x00000000, 0x00000000}},  //   عقد_,   ,   ,
  { {0xceb3007b, 0x994a0054, 0x286a012b, 0x00000000}},  //   ויז_, _خلال_, _врло_,
  { {0x66e6203e, 0x78bb028c, 0xe3b801f6, 0x00000000}},  //   _дода, couv, ğın_,
  { {0x200b01cd, 0x4439000c, 0xe3b801f6, 0x00000000}},  //   _reci_, rfs_, şın_,
  { {0x9f590207, 0x628e00ab, 0x44390203, 0x00000000}},  //   _gesù_, ghbo, sfs_,
  { {0x31c40069, 0xd258008b, 0x7cf301d5, 0x00000000}},  //   дств, цця_, _oħra,
  { {0x7648047a, 0x24891084, 0x00000000, 0x00000000}},  //   ledy, _ulam_,   ,
  { {0x200b0027, 0x66cf0292, 0x9f340088, 0x00000000}},  // [4e50] _veci_, søke, меті,
  { {0x2cbf0286, 0x628e0fd6, 0x78a9203f, 0x00000000}},  //   _skud_, chbo, znev,
  { {0x92b40054, 0x2ee300b5, 0x38662040, 0x00000000}},  //   _تحيا, _vijf_, _onor_,
  { {0x7c84003b, 0x76480058, 0xfcda00a1, 0x00000000}},  //   муче, hedy, مانڈ_,
  { {0x7c2b00f8, 0x26c5005b, 0xdb070279, 0x00000000}},  //   rggr, yllo_, _ömür,
  { {0x78bb01aa, 0x76480036, 0x38660150, 0x00000000}},  //   wouv, jedy, _anor_,
  { {0x7f4d01d5, 0x6ca7003b, 0x76480190, 0x00000000}},  //   lwaq, _драж, dedy,
  { {0x2cad016c, 0x00000000, 0x00000000, 0x00000000}},  //   _ujed_,   ,   ,
  { {0x32112041, 0x78bb009d, 0x00000000, 0x00000000}},  //   kazy_, rouv,   ,
  { {0x78bb00b9, 0x26c50026, 0x7afb011c, 0x00000000}},  //   souv, ullo_, _itut,
  { {0xc8ab0265, 0x64860051, 0x78a92042, 0x00000000}},  //   _къде_, _fóil, pnev,
  { {0xc86401e0, 0x3f4d01ed, 0x00000000, 0x00000000}},  //   _отчи, _ožu_,   ,
  { {0x69c70030, 0x75280089, 0x00000000, 0x00000000}},  //   _øjeb, audz,   ,
  { {0x75280871, 0x7afb00e7, 0x00000000, 0x00000000}},  //   budz, _mtut,   ,
  { {0xd1320025, 0xa06a0893, 0xe2972043, 0x00000000}},  //   عمر_, бава_, чар_,
  { {0x628e1cf6, 0x2b5f006b, 0xb4ba00a1, 0x00000000}},  //   shbo, _oruc_, _دُعا_,
  { {0x03a613e7, 0x1e86007e, 0x44321e55, 0x00000000}},  // [4e60] _хипо, плам, _icy_,
  { {0xef170451, 0x6456014a, 0x6496007f, 0x00000000}},  //   яму_, _hayi, ršiu,
  { {0x6456014a, 0x1c460143, 0x7afb00b4, 0x00000000}},  //   _kayi, знем, _atut,
  { {0x2b5f2044, 0xdee60069, 0x6456000a, 0x00000000}},  //   _bruc_, _номи, _jayi,
  { {0x64860051, 0x6f6305b8, 0x64562045, 0x00000000}},  //   _nóim, _звяз, _mayi,
  { {0x6456005f, 0x787c1152, 0x2b5f00e5, 0x00000000}},  //   _layi, _névr, _druc_,
  { {0xd90d02fd, 0x64860051, 0xadc30082, 0x00000000}},  //   لیل_, _póil, _trạc,
  { {0x64562046, 0x20122047, 0x236000d9, 0x00000000}},  //   _nayi, nayi_, _orij_,
  { {0x64860048, 0x3b070072, 0x672900f6, 0x00000000}},  //   _cóim, _нето_, guej,
  { {0x44322048, 0xbafb009b, 0x9f9700b3, 0x00000000}},  //   _acy_, _להמש, פדיה_,
  { {0x76482049, 0x6456014a, 0x2fc70011, 0x00000000}},  //   redy, _bayi, ́ng_,
  { {0x629e0fdb, 0x3866000d, 0x236000d9, 0x00000000}},  //   _ampo, _unor_, _brij_,
  { {0x787c00f4, 0x7648204a, 0x64560263, 0x00000000}},  //   _févr, pedy, _dayi,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe63b00b6, 0x32110ce2, 0x64560173, 0x00000000}},  //   _התוכ, razy_, _fayi,
  { {0x629e0129, 0x95530025, 0xa2cd0309, 0x00000000}},  //   _empo, _أخوا, _दीर्,
  { {0xa2b50f97, 0xe8d7009b, 0xddeb0439, 0x00000000}},  // [4e70] _обич, לולר_, مراه_,
  { {0x6456204b, 0x00000000, 0x00000000, 0x00000000}},  //   _zayi,   ,   ,
  { {0x7afb00db, 0x6456014a, 0x201214b2, 0x00000000}},  //   _stut, _yayi, bayi_,
  { {0x317e010f, 0x76840173, 0x00000000, 0x00000000}},  //   ätze_, _bòyk,   ,
  { {0x2d871470, 0x61ec0047, 0xfc300439, 0x00000000}},  //   šne_, _állá, احم_,
  { {0x64860048, 0x62870146, 0x00000000, 0x00000000}},  //   _róim, nkjo,   ,
  { {0xa2a00061, 0x6d5a0ebe, 0x00000000, 0x00000000}},  //   _ऑगस्, _štav,   ,
  { {0x2b5f0d35, 0xa3ad00e8, 0x08d4007e, 0x00000000}},  //   _truc_, कपा_, нцыя,
  { {0x64560173, 0x6605010e, 0x00000000, 0x00000000}},  //   _rayi, _õhkk,   ,
  { {0x645615a4, 0x64960471, 0x00000000, 0x00000000}},  //   _sayi, jšir,   ,
  { {0x6aa31073, 0xe3b8005a, 0x20120a44, 0x00000000}},  //   minf, ğım_, yayi_,
  { {0xe3b80676, 0x03a60741, 0x6aa31c9d, 0x00000000}},  //   şım_, димо, linf,
  { {0x6729204c, 0x2012204d, 0x79830016, 0x00000000}},  //   quej, vayi_, lynw,
  { {0xa50901b3, 0x236000b5, 0x6aa3010f, 0x00000000}},  //   _дека_, _vrij_, ninf,
  { {0x2012204e, 0x2d1c007d, 0x6456014a, 0x00000000}},  //   tayi_, _पटेल_, _tayi,
  { {0x39450300, 0x23600925, 0x2055005c, 0x00000000}},  //   _mpls_, _trij_, нтур,
  { {0x8fa30057, 0x20120284, 0x44f3204f, 0x00000000}},  // [4e80] вате, rayi_, _hã_,
  { {0x20120173, 0x629e00e7, 0xc3c901af, 0x00000000}},  //   sayi_, _umpo, _عظيم_,
  { {0x6aa3010e, 0x6f160253, 0x00000000, 0x00000000}},  //   dinf, ssyc,   ,
  { {0x44f3001d, 0x6aa3010e, 0x00000000, 0x00000000}},  //   _mã_, einf,   ,
  { {0x4bda0123, 0x44f3204f, 0xcce50025, 0x00000000}},  //   آباد_, _lã_, رسمي,
  { {0x6aa32050, 0x39450022, 0x00000000, 0x00000000}},  //   ginf, _bpls_,   ,
  { {0xa96703f3, 0x9f4b000c, 0x44f3204f, 0x00000000}},  //   дија_, élög_, _nã_,
  { {0xd90d0014, 0x64960465, 0x00000000, 0x00000000}},  //   صیه_, zšir,   ,
  { {0x7e7c0127, 0xb05b0039, 0x6aa30232, 0x00000000}},  //   _korp, _okän, binf,
  { {0xda66006d, 0xceb4006b, 0x44f30082, 0x00000000}},  //   _تاري, qsəd_, _bã_,
  { {0x7e7c00ab, 0x99861095, 0x98a7013e, 0x00000000}},  //   _morp, _تلاو, ntně_,
  { {0x9f40200e, 0x25fe02fb, 0x44f30011, 0x00000000}},  //   nció_, _श्री_, _dã_,
  { {0x69c80016, 0xddce0036, 0xbf9b01c3, 0x00000000}},  //   _hyde, _jabł, _leêr,
  { {0x44f30181, 0x09d50044, 0x81d80044, 0x00000000}},  //   _fã_, _স্টা, িশন_,
  { {0x7ae805b7, 0x9f400010, 0x44f30011, 0x00000000}},  //   _midt, kció_, _gã_,
  { {0x76582051, 0x62872052, 0x69c81091, 0x00000000}},  //   _havy, skjo, _myde,
  { {0x69c82053, 0x6aa300d2, 0x00000000, 0x00000000}},  // [4e90] _lyde, yinf,   ,
  { {0x765a130a, 0x2348007a, 0x6aa300f6, 0x00000000}},  //   ndty, _کلیپ_, xinf,
  { {0x44f3001d, 0x7e7c00c7, 0x69c82054, 0x00000000}},  //   _xã_, _dorp, _nyde,
  { {0x7e7c002a, 0x6aa32055, 0x6ab9007d, 0x00000000}},  //   _eorp, winf, ेत्र,
  { {0x7e7c01e3, 0x9098005e, 0x3b092056, 0x00000000}},  //   _forp, _цвят_, чело_,
  { {0x9f400129, 0x7e7c002d, 0x69c82057, 0x00000000}},  //   ació_, _gorp, _byde,
  { {0xa01b2058, 0x7ae8011c, 0x69c80675, 0x00000000}},  //   _flöt, _didt, _cyde,
  { {0x9f4004bd, 0x6aa30056, 0x44f31155, 0x00000000}},  //   cció_, sinf, _rã_,
  { {0x6aa300df, 0xe7a9022a, 0x44f300c4, 0x00000000}},  //   pinf, явил_, _sã_,
  { {0xb6cc047f, 0xe3b8014a, 0x00000000, 0x00000000}},  //   şünü, şık_,   ,
  { {0x76582059, 0x9f400197, 0x69c8205a, 0x00000000}},  //   _davy, nciò_, _gyde,
  { {0xb05b0274, 0x44f31155, 0xe79500e2, 0x00000000}},  //   _skän, _vã_, _пиењ,
  { {0xf7450057, 0x7dee0010, 0x69c804a5, 0x00000000}},  //   _чело, nősí, _zyde,
  { {0x27390263, 0x09e30044, 0xf770004b, 0x00000000}},  //   mèn_, _ন্যা, _خام_,
  { {0x64a6008b, 0x673b0052, 0x21670745, 0x00000000}},  //   _пака, ltuj, нири_,
  { {0xafe60326, 0xa0b5003b, 0x645a0089, 0x00000000}},  //   еобл, вљуј, ētis,
  { {0x44200477, 0x7e7c0093, 0x673b0395, 0x00000000}},  // [4ea0] _idi_, _porp, ntuj,
  { {0x4420205b, 0x00000000, 0x00000000, 0x00000000}},  //   _hdi_,   ,   ,
  { {0xa01b205c, 0x7e7c010f, 0x9f59004a, 0x00000000}},  //   _plöt, _vorp, _besó_,
  { {0x673b0387, 0x273901aa, 0x6d5e006c, 0x00000000}},  //   ktuj, kèn_, rvpa,
  { {0x7e7c005f, 0x9f40200e, 0x98a700b9, 0x00000000}},  //   _torp, rció_, stně_,
  { {0xada60265, 0x273901aa, 0xa01b01e5, 0x00000000}},  //   _загл, dèn_, _flös,
  { {0x9f40205d, 0x6f04008e, 0x291a01cc, 0x00000000}},  //   pció_, lpic, épa_,
  { {0x7ae80365, 0x7762049a, 0x4420011c, 0x00000000}},  //   _widt, _prox, _ndi_,
  { {0x7658010a, 0x656300b5, 0xc6a6019d, 0x00000000}},  //   _pavy, _arnh, ерни,
  { {0x4420006b, 0x69c81aef, 0x6996109e, 0x00000000}},  //   _adi_, _tyde, _прех,
  { {0x44200065, 0x765a00ea, 0x00000000, 0x00000000}},  //   _bdi_, rdty,   ,
  { {0x442000f4, 0xd5b7007e, 0xc9b70104, 0x00000000}},  //   _cdi_, эсы_, _אהבת_,
  { {0x366a0057, 0xa88701e0, 0x44200016, 0x00000000}},  //   _надо_, _яйца_, _ddi_,
  { {0xa6aa031d, 0x44200065, 0x6f0407e7, 0x00000000}},  //   _عاشق_, _edi_, dpic,
  { {0xe5f700b6, 0x44200785, 0xf1240900, 0x00000000}},  //   _אזור_, _fdi_, льто,
  { {0x78a20022, 0xceb4006b, 0x00000000, 0x00000000}},  //   _jmov, zrət_,   ,
  { {0x6d47009f, 0x644f007f, 0x7ff40014, 0x00000000}},  // [4eb0] _spja, meci, اسفا,
  { {0x644f02d5, 0x442018e1, 0x645d01e5, 0x00000000}},  //   leci, _zdi_, ldsi,
  { {0x44200016, 0x273901aa, 0x6d5a0134, 0x00000000}},  //   _ydi_, zèn_, _štar,
  { {0x645d000c, 0x644f0926, 0x9f400207, 0x00000000}},  //   ndsi, neci, rciò_,
  { {0x2009205e, 0x60cd005a, 0x645d00bb, 0x00000000}},  //   mbai_, mlam, idsi,
  { {0x60cd0010, 0xaa4500ed, 0xcb66003b, 0x00000000}},  //   llam, текл, таше_,
  { {0x60cd0026, 0x644f008a, 0xf2d40049, 0x00000000}},  //   olam, keci, װעק_,
  { {0x644f0036, 0x673b021e, 0x60cd014a, 0x00000000}},  //   jeci, ttuj, nlam,
  { {0x644f0249, 0x75280036, 0x60cd0b33, 0x00000000}},  //   deci, erdz, ilam,
  { {0x2d850004, 0x673b205f, 0x27391d81, 0x00000000}},  //   _üles_, rtuj, rèn_,
  { {0x673b0428, 0x44200093, 0x20f8012d, 0x00000000}},  //   stuj, _pdi_, _ačin_,
  { {0x64a6008b, 0x6f042060, 0x644f008e, 0x00000000}},  //   тама, ypic, geci,
  { {0x60cd2061, 0x96b5003b, 0x289a00a3, 0x00000000}},  //   dlam, _искљ, _קינא,
  { {0x67292062, 0x645d0007, 0x68eb00e0, 0x00000000}},  //   mrej, adsi, _higd,
  { {0x60cd014a, 0x44200142, 0xa5640054, 0x00000000}},  //   flam, _tdi_, _مدين,
  { {0x68fc0047, 0x44202062, 0x7641032e, 0x00000000}},  //   _érde, _udi_, lfly,
  { {0x68eb0129, 0xc0e32063, 0x7d1c0091, 0x00000000}},  // [4ec0] _migd, ротк, _svrs,
  { {0x60cd161f, 0xaefb0011, 0x68eb0120, 0x00000000}},  //   alam, _trùn, _ligd,
  { {0xe0da012b, 0x60cd2064, 0x321800ab, 0x00000000}},  //   _ово_, blam, mary_,
  { {0x68eb2065, 0x3218077a, 0x6f0401a2, 0x00000000}},  //   _nigd, lary_, ppic,
  { {0x26c707ac, 0x03e40044, 0x2ca60133, 0x00000000}},  //   _okno_, কুরী_, riod_,
  { {0x644f0046, 0x321800ab, 0xba18006d, 0x00000000}},  //   zeci, nary_, ريبا_,
  { {0x7d1c01ae, 0x7641011b, 0x6da601fc, 0x00000000}},  //   _uvrs, dfly, _рива,
  { {0x7d570476, 0x60c40052, 0x32180253, 0x00000000}},  //   _בילד_, noim, hary_,
  { {0x67290de5, 0x644f0035, 0x68eb000a, 0x00000000}},  //   grej, veci, _digd,
  { {0x60c40051, 0x3aeb0014, 0x60cd0823, 0x00000000}},  //   hoim, _قبلی_, zlam,
  { {0x644f1bae, 0x60cd1811, 0x2455067a, 0x00000000}},  //   teci, ylam, هندس,
  { {0x52bd0164, 0x60cd006b, 0x61fe101b, 0x00000000}},  //   ोत्स, xlam, _afpl,
  { {0x644f0977, 0x24840039, 0x00000000, 0x00000000}},  //   reci, ömma_,   ,
  { {0x644f0a0f, 0xc7d7009b, 0x46a3005e, 0x00000000}},  //   seci, _סוגי_, _качв,
  { {0x61141020, 0x60cd083a, 0xb6d90049, 0x00000000}},  //   идру, tlam, _אַקט,
  { {0xf0b405b8, 0x64860048, 0x00000000, 0x00000000}},  //   айсь, _sóiv,   ,
  { {0x2009010a, 0x9ed905f6, 0x6d5a0091, 0x00000000}},  // [4ed0] rbai_, емат_, _štap,
  { {0xd251007a, 0x60cd000b, 0xa2c40061, 0x00000000}},  //   _اند_, slam, ळवण्,
  { {0x60cd014a, 0x67290f6c, 0x69a20061, 0x00000000}},  //   plam, zrej, _केली,
  { {0x1b19007c, 0x672908e0, 0x60cd006b, 0x00000000}},  //   ежды_, yrej, qlam,
  { {0x0c2401e1, 0xa09a0049, 0x291e00ca, 0x00000000}},  //   рмін, _נישט, _avta_,
  { {0x672905fa, 0xbbd3013d, 0x68eb00ea, 0x00000000}},  //   vrej, _तरीक, _sigd,
  { {0x98ac0180, 0x3f89005b, 0x127c0049, 0x00000000}},  //   _ardı_, lyau_, ואגע,
  { {0xc17400b6, 0x67291f49, 0x88c500b9, 0x00000000}},  //   שחק_, trej, _ověř,
  { {0x64860051, 0x67292066, 0xf09400a0, 0x00000000}},  //   _móit, urej, ינק_,
  { {0x67292067, 0x60c40bb2, 0x249201c3, 0x00000000}},  //   rrej, zoim, _slym_,
  { {0x34aa0517, 0x764102e7, 0x32180161, 0x00000000}},  //   евно_, rfly, vary_,
  { {0x67290208, 0x76410cf5, 0x321800b4, 0x00000000}},  //   prej, sfly, wary_,
  { {0x32182068, 0x60c400b0, 0x61e9006b, 0x00000000}},  //   tary_, voim, əmlə,
  { {0x78a909dd, 0xb6071662, 0x3ced00e5, 0x00000000}},  //   liev, _рядк, _liev_,
  { {0x60c4021e, 0x26c50197, 0x321800ab, 0x00000000}},  //   toim, molo_, rary_,
  { {0x78a90065, 0x32180784, 0x26c50416, 0x00000000}},  //   niev, sary_, lolo_,
  { {0xddd5004f, 0x64860051, 0x60c40705, 0x00000000}},  // [4ee0] _rozš, _dóit, roim,
  { {0x9419006b, 0x78a900ab, 0x26c50919, 0x00000000}},  //   disə_, hiev, nolo_,
  { {0x60c40181, 0xa2c101f5, 0x26c52069, 0x00000000}},  //   poim, लकर्, iolo_,
  { {0x20561b89, 0x317b007b, 0x628e02ab, 0x00000000}},  //   _стор, _נאכד, lkbo,
  { {0x26c512a8, 0xa3aa007d, 0xb4370049, 0x00000000}},  //   kolo_, _गेम_, אָוו_,
  { {0xc333019b, 0x628e018d, 0x98a00059, 0x00000000}},  //   מוד_, nkbo, čič_,
  { {0x26c5206a, 0x78a90026, 0x2ca40022, 0x00000000}},  //   dolo_, fiev, _tmmd_,
  { {0x7d0306f4, 0x78a90afd, 0x00000000, 0x00000000}},  //   ínse, giev,   ,
  { {0x64860051, 0x26c50026, 0xfa360879, 0x00000000}},  //   _lóis, folo_, _مراد,
  { {0x0f5700b6, 0x9b930054, 0x26c50207, 0x00000000}},  //   ניים_, _الكت, golo_,
  { {0x88c5013e, 0x6475206b, 0x00000000, 0x00000000}},  //   _svěř, агну,   ,
  { {0x6aaa1fa8, 0x628e0168, 0xceb4006b, 0x00000000}},  //   liff, ekbo, xsən_,
  { {0x26c50142, 0xe8b20061, 0x752f0036, 0x00000000}},  //   bolo_, ुकीच, ącza,
  { {0x26c50198, 0x39ae006b, 0xb05b00b0, 0x00000000}},  //   colo_, _kəs_, _ikäi,
  { {0x661a206c, 0xa194007e, 0x64860048, 0x00000000}},  //   matk, барч, _cóis,
  { {0x661a0047, 0x6aaa010f, 0x88bc00b9, 0x00000000}},  //   latk, hiff, _uvěd,
  { {0xb4c302fb, 0xceb4006b, 0x2ba401f5, 0x00000000}},  // [4ef0] ्ती_, rsən_, _खेला,
  { {0x628e001c, 0x661a0010, 0x78a90026, 0x00000000}},  //   ckbo, natk, ziev,
  { {0x5d5501f9, 0xf1ab0014, 0x6aaa06e2, 0x00000000}},  //   ркет, _ساده_, diff,
  { {0x44fa048a, 0x3af90263, 0x23690387, 0x00000000}},  //   _më_, _pèp_, _kraj_,
  { {0x09dd001c, 0x661a020c, 0x44fa0065, 0x00000000}},  //   मध्य, katk, _lë_,
  { {0x2ba4001c, 0x44fa0343, 0x39ae006b, 0x00000000}},  //   _खेळा, _oë_, _bəs_,
  { {0x44fa048a, 0x661a14d4, 0x78a902ae, 0x00000000}},  //   _në_, datk, tiev,
  { {0x7d0100e5, 0x00000000, 0x00000000, 0x00000000}},  //   _cârţ,   ,   ,
  { {0x26c50198, 0x6c840025, 0x78a91c71, 0x00000000}},  //   tolo_, _القم, riev,
  { {0x44fa0065, 0x78a900bb, 0x443b0026, 0x00000000}},  //   _bë_, siev, _acq_,
  { {0x26c50197, 0xb4c301f5, 0x78a901c5, 0x00000000}},  //   rolo_, ्तू_, piev,
  { {0x26c50724, 0xe3660184, 0x29050066, 0x00000000}},  //   solo_, акми, _itla_,
  { {0x6486002a, 0x26c50207, 0x661a04cb, 0x00000000}},  //   _sóis, polo_, batk,
  { {0x412a0373, 0x64860051, 0x27ff0197, 0x00000000}},  //   кого_, _cóir, lcun_,
  { {0x91e601f9, 0x7c3b0211, 0x6b8b1dab, 0x00000000}},  //   рове, _ocur, hygg,
  { {0x27ff206d, 0x7bcd0089, 0x23690087, 0x00000000}},  //   ncun_, ļauj, _fraj_,
  { {0xb4d2007d, 0xee3a072b, 0x44fa0065, 0x00000000}},  // [4f00] वती_, кна_, _zë_,
  { {0x7c3b0a16, 0x27e00045, 0x00000000, 0x00000000}},  //   _acur, _ùine_,   ,
  { {0xc27b00b6, 0x2b4d206e, 0x127b0049, 0x00000000}},  //   _סרטי, _apec_, _סאטע,
  { {0xdd8f06f1, 0x8c460069, 0xeb06003b, 0x00000000}},  //   بوم_, реде, ачко,
  { {0x39ae006b, 0x661a003f, 0xbb43206f, 0x00000000}},  //   _səs_, yatk, жечк,
  { {0x7c3b1176, 0x394c1a0b, 0x00000000, 0x00000000}},  //   _ecur, _ppds_,   ,
  { {0x6aaa08ed, 0x661a0ec6, 0x00000000, 0x00000000}},  //   riff, vatk,   ,
  { {0x6b8b01bf, 0x20002070, 0x798a0007, 0x00000000}},  //   bygg, ncii_, ryfw,
  { {0x44fa048a, 0xd6da046c, 0x661a0010, 0x00000000}},  //   _së_, кто_, tatk,
  { {0x7afd008e, 0x3cf80030, 0x752f00b4, 0x00000000}},  //   _ésta, _kurv_, ączn,
  { {0x44fa048a, 0xb05b00b0, 0x20000142, 0x00000000}},  //   _që_, _ikäv, kcii_,
  { {0xb4c30309, 0x69da2071, 0x44fa0065, 0x00000000}},  //   ्ते_, _izte, _vë_,
  { {0x661a020c, 0x645f006b, 0x00000000, 0x00000000}},  //   patk, _vaqi,   ,
  { {0x44fa2072, 0x171b019b, 0x6d4e0030, 0x00000000}},  //   _të_, _יודע, _opba,
  { {0x30a7007e, 0xa0a72073, 0x443b00f6, 0x00000000}},  //   арав, ашал, _tcq_,
  { {0x64a40143, 0xe3b8019a, 0x00000000, 0x00000000}},  //   _маја, ğır_,   ,
  { {0xe3b80279, 0x6d5c2074, 0x44390009, 0x00000000}},  // [4f10] şır_, _asra, mgs_,
  { {0xde1901f7, 0x4255035b, 0x44390190, 0x00000000}},  //   اقات_, _اندر, lgs_,
  { {0x2b4d2075, 0xc212009b, 0x2d872076, 0x00000000}},  //   _spec_, _מהי_, âne_,
  { {0x44390b8d, 0x31560049, 0x6722050f, 0x00000000}},  //   ngs_, _פירן_, _ovoj,
  { {0x69da022b, 0x62852077, 0x6b65007e, 0x00000000}},  //   _azte, _koho, скла,
  { {0x62852078, 0x6b8b000c, 0x5a47007e, 0x00000000}},  //   _joho, rygg, рэда,
  { {0x2019000b, 0x62852079, 0x8d950025, 0x00000000}},  //   _kesi_, _moho, _الأش,
  { {0x20190091, 0x9601006e, 0xb4c3006e, 0x00000000}},  //   _jesi_, ोर्ट_, ्तो_,
  { {0xb8fe03d7, 0x20190198, 0xd706007c, 0x00000000}},  //   _दी_, _mesi_, бные_,
  { {0x27ff01e8, 0x4439136b, 0x628505d2, 0x00000000}},  //   scun_, egs_, _noho,
  { {0x752f0036, 0x79a700ed, 0x27e900fa, 0x00000000}},  //   ączo, _трае, _ºano_,
  { {0x443906a1, 0x6486002a, 0xb4d20061, 0x00000000}},  //   ggs_, _cóip, वते_,
  { {0x26d904bd, 0x62850142, 0xe60e0245, 0x00000000}},  //   ïsos_, _boho, _нд_,
  { {0xcb1200b6, 0xd2950088, 0x44390328, 0x00000000}},  //   הלך_, орсь, ags_,
  { {0x4096007c, 0x6285207a, 0x20190169, 0x00000000}},  //   брат, _doho, _besi_,
  { {0x387f207b, 0x10a3025f, 0x20190c56, 0x00000000}},  //   njur_, писн, _cesi_,
  { {0xa0670265, 0x2019001a, 0x2000175b, 0x00000000}},  // [4f20] щата_, _desi_, rcii_,
  { {0x62850059, 0x1fb503e8, 0xdc10006e, 0x00000000}},  //   _goho, істр, ार्ड_,
  { {0x629c0051, 0x387f207c, 0x7bdb00d9, 0x00000000}},  //   mhro, kjur_, _azuu,
  { {0xeb9a09da, 0x20190020, 0xa5da0049, 0x00000000}},  //   лие_, _gesi_, אַדי,
  { {0x387f0039, 0x69da0010, 0x38c800a2, 0x00000000}},  //   djur_, _szte, یابی_,
  { {0x6e960054, 0x6d5c0051, 0x20100036, 0x00000000}},  //   _السا, _tsra, łnić_,
  { {0x67220cce, 0x5fac001c, 0x3e8500b9, 0x00000000}},  //   _svoj, _घेतल, _dítě_,
  { {0xceb4005f, 0x8c430256, 0x387f0028, 0x00000000}},  //   ksək_, _несе, gjur_,
  { {0x7f44207d, 0xdddc001a, 0x6618207e, 0x00000000}},  //   ntiq, _forţ, _pevk,
  { {0x44390c6a, 0x1f5b0104, 0x3ce60134, 0x00000000}},  //   wgs_, נדיא, lmov_,
  { {0x69da207f, 0x69960088, 0x984a005e, 0x00000000}},  //   _uzte, _урах, _бяла_,
  { {0xc97701f8, 0x44390089, 0xfbdc013d, 0x00000000}},  //   _לגבי_, ugs_, _बराम,
  { {0x4439138f, 0x62850428, 0x20192080, 0x00000000}},  //   rgs_, _poho, _resi_,
  { {0x201901a3, 0x6594030d, 0x629c0048, 0x00000000}},  //   _sesi_, _малу, ghro,
  { {0x20190197, 0xc69301ce, 0xe3b8014a, 0x00000000}},  //   _pesi_, _מאס_, şıp_,
  { {0x62852081, 0x3eaa00bb, 0x00000000, 0x00000000}},  //   _woho, _ambt_,   ,
  { {0x628501ca, 0x4429006c, 0x644d002d, 0x00000000}},  // [4f30] _toho, _ida_, _ibai,
  { {0x43d4006d, 0x68fa00ab, 0x4155203e, 0x00000000}},  //   _عزيز, _outd, _двос,
  { {0x20190207, 0x7f4400f4, 0x44292082, 0x00000000}},  //   _tesi_, atiq, _kda_,
  { {0x425500a1, 0x3e8500b9, 0x442910d4, 0x00000000}},  //   _انگر, _sítě_, _jda_,
  { {0xa03a007b, 0x644d002a, 0x7f442083, 0x00000000}},  //   _דערפ, _mbai, ctiq,
  { {0x44290181, 0x660d0166, 0x00000000, 0x00000000}},  //   _lda_, _đako,   ,
  { {0x644d002a, 0x44292084, 0x09e20d11, 0x00000000}},  //   _obai, _oda_, мошн,
  { {0xa3aa001c, 0x4429014a, 0x7afd0211, 0x00000000}},  //   _गइल_, _nda_, _ésto,
  { {0x6d450232, 0x660401f6, 0x6f0d01a2, 0x00000000}},  //   ltha, _şika, npac,
  { {0x44290149, 0x644d0b0c, 0xda02006e, 0x00000000}},  //   _ada_, _abai, रुआत_,
  { {0x6d452085, 0x7afb00b0, 0xe4520025, 0x00000000}},  //   ntha, _huut, وضح_,
  { {0x6d45018e, 0x442900b5, 0x7afb0929, 0x00000000}},  //   itha, _cda_, _kuut,
  { {0x4429018e, 0x629c0531, 0x4393007e, 0x00000000}},  //   _dda_, thro, даўс,
  { {0x7afb0368, 0x44290095, 0x6d4500f8, 0x00000000}},  //   _muut, _eda_, ktha,
  { {0x04460265, 0xa18700da, 0x44290133, 0x00000000}},  //   _дейн, обра_, _fda_,
  { {0x7c29008d, 0x6f0d00d9, 0x629c0133, 0x00000000}},  //   _nder, fpac, shro,
  { {0x7afb0343, 0x6d45018e, 0x2caf00b5, 0x00000000}},  // [4f40] _nuut, etha, digd_,
  { {0x6d450030, 0x44292086, 0x7c29060c, 0x00000000}},  //   ftha, _zda_, _ader,
  { {0x7f442087, 0xed5a007c, 0x225801bb, 0x00000000}},  //   stiq, рое_, merk_,
  { {0x823604e1, 0xa3be0309, 0x44290082, 0x00000000}},  //   _ارکا, _आशा_, _xda_,
  { {0xdee608f3, 0x6d450051, 0x7c29018e, 0x00000000}},  //   _моми, atha, _dder,
  { {0x7c290612, 0x752f0036, 0x60d61241, 0x00000000}},  //   _eder, ńczy, llym,
  { {0xdd9200a1, 0xdddc0089, 0x6d452088, 0x00000000}},  //   _غور_, _forš, ctha,
  { {0xf8ba0055, 0xd90d0014, 0x00000000, 0x00000000}},  //   ুষ্ঠ, این_,   ,
  { {0xda0b024c, 0x225801bb, 0xa3aa0164, 0x00000000}},  //   _स्वत_, kerk_, _गेल_,
  { {0x44292089, 0x09e600ec, 0x68fa006b, 0x00000000}},  //   _sda_, _дозн, _tutd,
  { {0x7c290018, 0xa806007e, 0x6f0d00b4, 0x00000000}},  //   _yder, _дзел, zpac,
  { {0xe4a703e8, 0x290e208a, 0xbfa30082, 0x00000000}},  //   ірно, mpfa_, _biể,
  { {0x443f0089, 0x44290873, 0x00000000, 0x00000000}},  //   ļu_, _vda_,   ,
  { {0x6d450016, 0x443f208b, 0x4429208c, 0x00000000}},  //   ytha, żu_, _wda_,
  { {0x26cc1ad2, 0x3495005e, 0x4429005b, 0x00000000}},  //   modo_, _накр, _tda_,
  { {0xd5b901fb, 0x212d089f, 0x644d033b, 0x00000000}},  //   _усі_, čeh_, _ubai,
  { {0x68e20051, 0x2258208d, 0xdddc012d, 0x00000000}},  // [4f50] _mhod, berk_, _rorš,
  { {0x6f0d0e22, 0xa2b40057, 0x7afb03b6, 0x00000000}},  //   rpac, _обыч, _ruut,
  { {0x6f0d0365, 0x7afb03b6, 0x6d45208e, 0x00000000}},  //   spac, _suut, utha,
  { {0x6d45002a, 0x7afb0b3e, 0x26cc0022, 0x00000000}},  //   rtha, _puut, hodo_,
  { {0x0f79007b, 0x3f790049, 0x00000000, 0x00000000}},  //   _האָב, _האָס,   ,
  { {0xda6201ab, 0x5338009b, 0x60cd0258, 0x00000000}},  //   евши, קנון_, loam,
  { {0x26cc0093, 0x752f00b4, 0x00000000, 0x00000000}},  //   dodo_, ączk,   ,
  { {0x68e20395, 0x60cd0211, 0x248900f6, 0x00000000}},  //   _chod, noam, _noam_,
  { {0x64ab013e, 0xe7310025, 0x00000000, 0x00000000}},  //   přij, رصة_,   ,
  { {0x2cad012d, 0x60cd1414, 0x00000000, 0x00000000}},  //   _hmed_, hoam,   ,
  { {0x2258208f, 0xd46a0e82, 0x60cd0052, 0x00000000}},  //   verk_, бине_, koam,
  { {0x22582090, 0x2a650eaa, 0x649a0256, 0x00000000}},  //   werk_, _halb_, стор_,
  { {0x68e9068f, 0x22580007, 0x26cc2091, 0x00000000}},  //   mmed, terk_, bodo_,
  { {0x68e9014a, 0x2cbf0039, 0x98a00006, 0x00000000}},  //   lmed, _ljud_, čią_,
  { {0x40960200, 0x24890133, 0x66cf0056, 0x00000000}},  //   прат, _foam_, søks,
  { {0x032618ea, 0xb05b0039, 0x68e9014a, 0x00000000}},  //   _един, _skär, nmed,
  { {0x4422011f, 0x2d870706, 0x225800c7, 0x00000000}},  // [4f60] mak_, änen_, perk_,
  { {0x44221964, 0x68e90107, 0x60d60023, 0x00000000}},  //   lak_, hmed, slym,
  { {0x4422022b, 0x68360180, 0x68e90095, 0x00000000}},  //   oak_, nüdü, kmed,
  { {0x442207ef, 0xa3b10164, 0x60cd00c4, 0x00000000}},  //   nak_, _टेड_, coam,
  { {0x68e2018e, 0x4422022b, 0x68e900f8, 0x00000000}},  //   _rhod, iak_, dmed,
  { {0x4422027e, 0x68e200b9, 0x68e90020, 0x00000000}},  //   hak_, _shod, emed,
  { {0x44222092, 0x20070046, 0xceb30049, 0x00000000}},  //   kak_, śnie_, _טיש_,
  { {0x44222093, 0x68e90190, 0x7ce3006c, 0x00000000}},  //   jak_, gmed, võrg,
  { {0x4422020c, 0x68e2031f, 0x2ca701d6, 0x00000000}},  //   dak_, _vhod, ënde_,
  { {0x7bcd0089, 0x7c2200e0, 0x24570082, 0x00000000}},  //   ļaut, laor, _ầm_,
  { {0x1dbe0201, 0x26cc010a, 0x4422014a, 0x00000000}},  //   ्थित, rodo_, fak_,
  { {0x4422034d, 0x26cc00ca, 0x7c222094, 0x00000000}},  //   gak_, sodo_, naor,
  { {0xb4bd01f5, 0x60cd0511, 0x00000000, 0x00000000}},  //   _आदी_, voam,   ,
  { {0x1dbe007d, 0xcfc40044, 0x7ce3010e, 0x00000000}},  //   ्थात, ্ধান, põrg,
  { {0x765a0052, 0x60cd00b0, 0x629500bb, 0x00000000}},  //   mety, toam, rkzo,
  { {0x4422011f, 0x765a093a, 0x753a1b99, 0x00000000}},  //   cak_, lety, mutz,
  { {0x290c0181, 0x60cd0211, 0xf3ff00c4, 0x00000000}},  // [4f70] _ltda_, roam, ldão_,
  { {0x765a0639, 0x2cad06d9, 0x60cd004a, 0x00000000}},  //   nety, _smed_, soam,
  { {0x753a001f, 0xf3ff0181, 0x68e90016, 0x00000000}},  //   nutz, ndão_, ymed,
  { {0x765a00b0, 0x00000000, 0x00000000, 0x00000000}},  //   hety,   ,   ,
  { {0x753a010f, 0x765a00ea, 0x68e92095, 0x00000000}},  //   hutz, kety, vmed,
  { {0x44221e3a, 0x9f9600b6, 0x2a65002b, 0x00000000}},  //   zak_, _חדשה_, _qalb_,
  { {0x4422170b, 0x68e9014a, 0x64ab00b9, 0x00000000}},  //   yak_, tmed, přih,
  { {0x4422002d, 0x753a15ed, 0x2cad0035, 0x00000000}},  //   xak_, dutz, _umed_,
  { {0x765a12fe, 0xcb340265, 0x44221d7a, 0x00000000}},  //   fety, _петъ, vak_,
  { {0x68e901bf, 0x44221312, 0x765a0009, 0x00000000}},  //   smed, wak_, gety,
  { {0x44220d01, 0x68e92096, 0x753a022b, 0x00000000}},  //   tak_, pmed, gutz,
  { {0x4422002d, 0x7e672097, 0x6836019a, 0x00000000}},  //   uak_, _lajp, rüdü,
  { {0x442212d9, 0x765a0dbf, 0xd629003b, 0x00000000}},  //   rak_, bety, _доле_,
  { {0x7ea0145c, 0x753a0032, 0x6d5500d9, 0x00000000}},  //   _köpe, butz, _opza,
  { {0x44222098, 0xaca30011, 0x2d47006c, 0x00000000}},  //   pak_, _chừn, jõe_,
  { {0x98a001cd, 0x25d60049, 0xe0da05b8, 0x00000000}},  //   čić_, _קוקן_, іва_,
  { {0x4420001a, 0x7ea000f8, 0x2484000c, 0x00000000}},  // [4f80] _iei_, _löpe, ömmu_,
  { {0xf76706c6, 0x44200e67, 0x00000000, 0x00000000}},  //   _یا_, _hei_,   ,
  { {0x442000bb, 0x629e0026, 0x7c220145, 0x00000000}},  //   _kei_, _ilpo, taor,
  { {0x4420010a, 0x80dc0044, 0x00000000, 0x00000000}},  //   _jei_, _মূর্,   ,
  { {0x7c2201bc, 0x00000000, 0x00000000, 0x00000000}},  //   raor,   ,   ,
  { {0x44202099, 0x3866002a, 0x34bb0309, 0x00000000}},  //   _lei_, _saor_, _उद्द,
  { {0xd90d01ef, 0x2f040039, 0x442000bb, 0x00000000}},  //   میل_, _hög_, _oei_,
  { {0x4420086f, 0x00000000, 0x00000000, 0x00000000}},  //   _nei_,   ,   ,
  { {0x6f020195, 0x765a209a, 0xb6f4025f, 0x00000000}},  //   íoch, tety, нзиј,
  { {0x6996004d, 0x753a209b, 0x7c2000f8, 0x00000000}},  //   _орех, tutz, _hemr,
  { {0x4420209c, 0xf76f0a90, 0x2f04000c, 0x00000000}},  //   _bei_, های_, _lög_,
  { {0x4420000d, 0x753a002d, 0xf3ff0181, 0x00000000}},  //   _cei_, rutz, rdão_,
  { {0x4420209d, 0x4992026c, 0x7d09057c, 0x00000000}},  //   _dei_, _سیکر, _česm,
  { {0x80dc0044, 0x7d03209e, 0x753a0dab, 0x00000000}},  //   _মূল্, ínsk, putz,
  { {0xd5af003b, 0xd6570104, 0x7e67209f, 0x00000000}},  //   _рс_, _חיות_, _rajp,
  { {0x7c2020a0, 0x629e01c5, 0x442017b4, 0x00000000}},  //   _nemr, _elpo, _gei_,
  { {0x645d1109, 0x7e6720a1, 0x00000000, 0x00000000}},  // [4f90] mesi, _pajp,   ,
  { {0x442000b5, 0xaca30082, 0x00000000, 0x00000000}},  //   _zei_, _thừn,   ,
  { {0x75280089, 0x21270082, 0x00000000, 0x00000000}},  //   nsdz, _ình_,   ,
  { {0x645d20a2, 0x8b6b001e, 0xdfd10025, 0x00000000}},  //   nesi, ņēmē, _ميج_,
  { {0x7e670066, 0x511f01f5, 0x660a0085, 0x00000000}},  //   _tajp, _बबुआ_, _offk,
  { {0xa9690265, 0x2d470181, 0x645d00ab, 0x00000000}},  //   зика_, põe_, hesi,
  { {0x7c20008d, 0x645d014a, 0xac190088, 0x00000000}},  //   _femr, kesi, _нову_,
  { {0x645d20a3, 0xe3b8005a, 0x6e2500e0, 0x00000000}},  //   jesi, ğız_, lahb,
  { {0x44200a0a, 0x59e1013d, 0xbb190025, 0x00000000}},  //   _rei_, _फरवर, _رياض_,
  { {0x4420038b, 0x45850849, 0x7c20008d, 0x00000000}},  //   _sei_, егов, _zemr,
  { {0x04460500, 0x44200145, 0x4815007e, 0x00000000}},  //   ненн, _pei_, _змес,
  { {0x64ca0204, 0xf77101af, 0x7ea000f8, 0x00000000}},  //   रवेश, _مات_, _köpc,
  { {0xe72e20a4, 0xaca3001d, 0x5695008b, 0x00000000}},  //   _ще_, _chứn, _падт,
  { {0x442001a3, 0xa7640088, 0x00000000, 0x00000000}},  //   _wei_, _шкід,   ,
  { {0x44200035, 0x81d80044, 0x76410009, 0x00000000}},  //   _tei_, ়েন_, mgly,
  { {0x645d0845, 0xf41f00b0, 0x20e801a2, 0x00000000}},  //   cesi, ljän_, ißig_,
  { {0x672920a5, 0x8fa3007c, 0x00000000, 0x00000000}},  // [4fa0] nsej, гате,   ,
  { {0x6da608d6, 0x76410dba, 0x7c201454, 0x00000000}},  //   низа, ngly, _semr,
  { {0x7c20023a, 0x20070036, 0xe0da025f, 0x00000000}},  //   _pemr, śnia_, _нво_,
  { {0x61e1169c, 0x0ca90025, 0xac0702dc, 0x00000000}},  //   ülle, وطني_, енца_,
  { {0xc5f8001e, 0xeb97007c, 0x7cfa013e, 0x00000000}},  //   ldēt_, ниц_, _důra,
  { {0x99660175, 0x645d20a6, 0xef110049, 0x00000000}},  //   етил, zesi, _כּל_,
  { {0x645d20a7, 0xed57007c, 0x672b15c5, 0x00000000}},  //   yesi, _пор_, _avgj,
  { {0xbf6300a1, 0xd90d0014, 0x00000000, 0x00000000}},  //   _جگہو, زیه_,   ,
  { {0xb907024c, 0xdca3003b, 0x645d1047, 0x00000000}},  //   _मी_, _сати, vesi,
  { {0x645d0007, 0xa96a0098, 0x95ca1fe6, 0x00000000}},  //   wesi, _низа_, зума_,
  { {0x7d09004f, 0x645d20a7, 0xf99f00ed, 0x00000000}},  //   _česk, tesi, _сè_,
  { {0x7afa02e1, 0x7792007a, 0xddc70089, 0x00000000}},  //   _hitt, _میبا, _sajū,
  { {0x645d20a8, 0x0877007b, 0xddc70964, 0x00000000}},  //   resi, _רעדט_, _pajū,
  { {0x645d14b2, 0x7afa01d5, 0x877b00a3, 0x00000000}},  //   sesi, _jitt, _מאדי,
  { {0x7afa20a9, 0x645d1089, 0xf09f00f6, 0x00000000}},  //   _mitt, pesi, _plà_,
  { {0x7afa20aa, 0x7bde0036, 0x645d0065, 0x00000000}},  //   _litt, ępuj, qesi,
  { {0xe3bf008e, 0x00000000, 0x00000000, 0x00000000}},  // [4fb0] baña_,   ,   ,
  { {0x7afa002b, 0xa3aa007d, 0x3f8704eb, 0x00000000}},  //   _nitt, _गेट_, ćnu_,
  { {0xeab100a6, 0x81d80044, 0x69da0479, 0x00000000}},  //   یعت_, ়েব_, _nyte,
  { {0x7c84005c, 0x7afa014a, 0x61e50087, 0x00000000}},  //   луче, _aitt, _izhl,
  { {0x7afa001f, 0x5fe401ff, 0xdcee0087, 0x00000000}},  //   _bitt, _бірж, _grbč,
  { {0x69da0039, 0x7afa0198, 0xc5f80089, 0x00000000}},  //   _byte, _citt, ndēs_,
  { {0x7afa0a19, 0x7f4d12d7, 0xa9660aef, 0x00000000}},  //   _ditt, ltaq, вища_,
  { {0x7afa009f, 0x672920ab, 0xa3c3007d, 0x00000000}},  //   _eitt, tsej, ्था_,
  { {0x7afa086a, 0x69c800f6, 0x81d70044, 0x00000000}},  //   _fitt, _exde, িধি_,
  { {0x7afa011f, 0xd6ce13d9, 0x7ea00039, 0x00000000}},  //   _gitt, يقي_, _köpa,
  { {0x64a6008b, 0x67290129, 0x9aa400a1, 0x00000000}},  //   вана, ssej, _حملو,
  { {0x7afa02ae, 0x7bdb0022, 0x6729179a, 0x00000000}},  //   _zitt, _kyuu, psej,
  { {0xccf20049, 0x386d04d3, 0xe3bf008e, 0x00000000}},  //   יכט_, mder_, taña_,
  { {0x64410006, 0x00000000, 0x00000000, 0x00000000}},  //   ėlia,   ,   ,
  { {0xaca300ad, 0xa01b0039, 0xe5a20088, 0x00000000}},  //   _nhữn, _onöd, _вищи,
  { {0x92b20044, 0xe3bf004a, 0x3a270058, 0x00000000}},  //   টকে_, saña_, hanp_,
  { {0xe3bf0958, 0xb05b0073, 0x64560061, 0x00000000}},  // [4fc0] paña_, _tjän, _ibyi,
  { {0xb05b0073, 0x386d0016, 0xee37003b, 0x00000000}},  //   _hjäl, hder_, кну_,
  { {0x44320224, 0x7afa010f, 0x2d9c0027, 0x00000000}},  //   _kdy_, _ritt, áve_,
  { {0x7afa20ac, 0x386d1e68, 0x6aa113f7, 0x00000000}},  //   _sitt, jder_, _allf,
  { {0xef170057, 0x8c43026b, 0x386d0905, 0x00000000}},  //   _имя_, рече, dder_,
  { {0x386d00b5, 0x63890065, 0x61e900b9, 0x00000000}},  //   eder_, _hënë, řele,
  { {0x69da008d, 0x7afa0207, 0x00000000, 0x00000000}},  //   _qyte, _vitt,   ,
  { {0xfce601fb, 0x7afa0270, 0x386d02e1, 0x00000000}},  //   _робо, _witt, gder_,
  { {0x7afa01e2, 0xc6f80805, 0x4734012b, 0x00000000}},  //   _titt, нних_, ћнос,
  { {0x386d0857, 0x7afa16db, 0x44320d9f, 0x00000000}},  //   ader_, _uitt, _ady_,
  { {0xceb300b6, 0x2294006c, 0xb866009e, 0x00000000}},  //   שית_, _läks_, _لاشو,
  { {0x79b700b6, 0x63890065, 0x629c20ad, 0x00000000}},  //   _בלבד_, _nënë, ekro,
  { {0x78a220ae, 0xf7430088, 0x44320544, 0x00000000}},  //   _ilov, _вечо, _ddy_,
  { {0x443204d4, 0xf2c4007c, 0x64560009, 0x00000000}},  //   _edy_, ассн, _ebyi,
  { {0xb05b0039, 0x403508d6, 0xe2f80088, 0x00000000}},  //   _fjäl, левс, тері_,
  { {0x44320046, 0x30a420af, 0x3a270263, 0x00000000}},  //   _gdy_, арув, zanp_,
  { {0xe3bf0211, 0x26de20b0, 0x2d8e01a2, 0x00000000}},  // [4fd0] maño_, olto_, äfen_,
  { {0x78a2008e, 0xa3e80164, 0xe3bf004a, 0x00000000}},  //   _llov, _भरत_, laño_,
  { {0x386d05a6, 0x7f4d20b1, 0x78a2016e, 0x00000000}},  //   yder_, staq, _olov,
  { {0x27e61aef, 0xe7e20309, 0x23690023, 0x00000000}},  //   _ozon_, _परंप, _ksaj_,
  { {0x6f020051, 0x386d068f, 0x00000000, 0x00000000}},  //   íoct, vder_,   ,
  { {0x386d00ab, 0x78a220b2, 0x00000000, 0x00000000}},  //   wder_, _alov,   ,
  { {0x27e60010, 0x79a7005e, 0x6aa10045, 0x00000000}},  //   _azon_, ърде, _vllf,
  { {0x2ca6004f, 0x78a20142, 0x386d00b5, 0x00000000}},  //   chod_, _clov, uder_,
  { {0x386d0365, 0x00000000, 0x00000000, 0x00000000}},  //   rder_,   ,   ,
  { {0xb05b0073, 0x27e601ee, 0x55890140, 0x00000000}},  //   _själ, _dzon_, ебом_,
  { {0x2369008d, 0x3915005c, 0x69c40035, 0x00000000}},  //   _asaj_, _смер, şier,
  { {0x3a250038, 0xe3bf008e, 0x79b600b3, 0x00000000}},  //   _help_, gaño_, _גלעד_,
  { {0x2905011c, 0x2007013e, 0x00000000, 0x00000000}},  //   _hula_, ěnil_,   ,
  { {0x29050020, 0x2d7304eb, 0x2ebf0309, 0x00000000}},  //   _kula_, _oće_, ्वोत,
  { {0x2905003b, 0xe3bf008e, 0x00000000, 0x00000000}},  //   _jula_, baño_,   ,
  { {0x629c0039, 0x29051312, 0xa067132e, 0x00000000}},  //   skro, _mula_, ласа_,
  { {0x29050181, 0xc0e30b52, 0x3fe60999, 0x00000000}},  // [4fe0] _lula_, сотк, ужав,
  { {0xa3c3006e, 0x98a7013e, 0x11d60379, 0x00000000}},  //   ्थर_, trně_, _متجد,
  { {0x2176008b, 0x88bc0224, 0x2ca620b3, 0x00000000}},  //   _супр, _květ, thod_,
  { {0x6446020c, 0x673b185c, 0xb5fa0049, 0x00000000}},  //   ngki, kruj, גלעכ,
  { {0x290509f7, 0x60c400ca, 0x6ab820b4, 0x00000000}},  //   _aula_, mnim, tivf,
  { {0x78a20c30, 0xaa5820b5, 0x60c40059, 0x00000000}},  //   _slov, тику_, lnim,
  { {0x2905037e, 0x24800091, 0xa01b01c3, 0x00000000}},  //   _cula_, _onim_, _koöp,
  { {0x4734025f, 0x60c40051, 0x2905011c, 0x00000000}},  //   анис, nnim, _dula_,
  { {0x7c930054, 0xec13026c, 0x86261280, 0x00000000}},  //   _القص, _چوہد, льне,
  { {0x2480011c, 0x290500f8, 0x23690022, 0x00000000}},  //   _anim_, _fula_, _rsaj_,
  { {0x290504cb, 0x60c401e5, 0xe3bf008e, 0x00000000}},  //   _gula_, knim, taño_,
  { {0x60c41e8d, 0x13f50088, 0x78a220b6, 0x00000000}},  //   jnim, изня, _ulov,
  { {0x60c40627, 0x3a250133, 0x2480012d, 0x00000000}},  //   dnim, _yelp_, _dnim_,
  { {0x236901d9, 0xc6270044, 0x24801553, 0x00000000}},  //   _vsaj_, _মাথা_, _enim_,
  { {0x6eeb0fb5, 0x81dd0044, 0x30eb00aa, 0x00000000}},  //   nübe, তেন_, ефан_,
  { {0x60c420b7, 0x301500ed, 0x00000000, 0x00000000}},  //   gnim, рдар,   ,
  { {0x442b037e, 0x6d5c20b8, 0xe4500a4f, 0x00000000}},  // [4ff0] mac_, _apra, _رضي_,
  { {0x32550822, 0x442b037e, 0x88bc00b9, 0x00000000}},  //   _твор, lac_, _zvět,
  { {0x60c40059, 0x7cd900a1, 0x00000000, 0x00000000}},  //   bnim, نڈرز_,   ,
  { {0x442b0119, 0x60c410c1, 0xb19a009b, 0x00000000}},  //   nac_, cnim, _ייתכ,
  { {0x29050051, 0xcb69003b, 0x765801ca, 0x00000000}},  //   _sula_, тале_, _obvy,
  { {0x2905027e, 0xeb96005e, 0x7c2d01e5, 0x00000000}},  //   _pula_, риш_, ðarb,
  { {0x0dc801fb, 0xe509001d, 0xa2d6007d, 0x00000000}},  //   _бути_, _mặc_, णवत्,
  { {0x38ba0dec, 0x442b0213, 0x673b09b6, 0x00000000}},  //   tūra_, jac_, truj,
  { {0x8b5806dd, 0x6d5c0224, 0x7c2b01f4, 0x00000000}},  //   _مجلس_, _zpra, magr,
  { {0x88bc0224, 0x2905006a, 0x60c40059, 0x00000000}},  //   _svět, _tula_, znim,
  { {0x442b0035, 0xda7a009b, 0xd5e50088, 0x00000000}},  //   fac_, _שנער, ржни,
  { {0x7c2b0036, 0x442b14da, 0x6e2701f3, 0x00000000}},  //   nagr, gac_, _lejb,
  { {0x60c40059, 0x87e70827, 0x2480012d, 0x00000000}},  //   vnim, _сюже, _vnim_,
  { {0x6e2700b9, 0x7ea0014a, 0x442b0045, 0x00000000}},  //   _nejb, _röpo, aac_,
  { {0x60c40627, 0x442b0091, 0x6f060036, 0x00000000}},  //   tnim, bac_, _sukc,
  { {0x442b001c, 0x8066025f, 0x7c2b20b9, 0x00000000}},  //   cac_, јваж, jagr,

  { {0xb4c40183, 0xa0670113, 0x6d5c1fa6, 0x00000000}},  // [5000] ्वी_, шата_, _spra,
  { {0x2d9a0056, 0x60c4006c, 0x7d070023, 0x00000000}},  //   type_, snim, _bujs,
  { {0x3eba0365, 0x69da0061, 0x60c400ca, 0x00000000}},  //   ript_, _पुढी, pnim,
  { {0xeb9a0057, 0x7d090119, 0x6d5c0059, 0x00000000}},  //   кие_, _čest, _vpra,
  { {0x7e6e0009, 0x78bb0197, 0x6d5c00b4, 0x00000000}},  //   _tabp, diuv, _wpra,
  { {0x442b08c5, 0x3d280014, 0x6e270087, 0x00000000}},  //   zac_, _متری_, _gejb,
  { {0x6d5c07ac, 0x67220046, 0x81d80055, 0x00000000}},  //   _upra, _swoj, ়ের_,
  { {0x8c430200, 0x67220263, 0x6eeb010f, 0x00000000}},  //   _месе, _pwoj, rübe,
  { {0x442b0119, 0xcb670256, 0x6eeb01a2, 0x00000000}},  //   vac_, _кате_, sübe,
  { {0xf70800ad, 0x442b0036, 0x7d0000ab, 0x00000000}},  //   _của_, wac_, _hims,
  { {0x442b006b, 0x7d0020ba, 0xe5c6004d, 0x00000000}},  //   tac_, _kims, рспо,
  { {0x67220046, 0x78a90197, 0x08fa0188, 0x00000000}},  //   _twoj, chev, _شراب_,
  { {0x442b0119, 0xbf9b0181, 0x20070036, 0x00000000}},  //   rac_, _agên, śnik_,
  { {0x7c2b1827, 0x395e0093, 0x442b08c5, 0x00000000}},  //   zagr, _kpts_, sac_,
  { {0x45440084, 0xddce0089, 0x6440008e, 0x00000000}},  //   _انعق, _dabū, ómic,
  { {0xd251007a, 0xd5fb00b6, 0x8d870123, 0x00000000}},  //   _کند_, _בפור, یشان,
  { {0xe5090082, 0x9e070545, 0x7c2b007f, 0x00000000}},  // [5010] _tặc_, ачел, vagr,
  { {0x7d00002a, 0x44290004, 0x4fc40ee0, 0x00000000}},  //   _aims, _hea_, іста,
  { {0x5d55005e, 0x442920bb, 0x6e2707c4, 0x00000000}},  //   скет, _kea_, _vejb,
  { {0x442912e0, 0x321100b4, 0x00000000, 0x00000000}},  //   _jea_, lczy_,   ,
  { {0xa3dd03d7, 0x4429000d, 0x395e0319, 0x00000000}},  //   _तुम_, _mea_, _apts_,
  { {0x442904f8, 0x3e5700b9, 0x6e350521, 0x00000000}},  //   _lea_, _dětí_, _udzb,
  { {0x442901aa, 0xec6b0893, 0x78a90065, 0x00000000}},  //   _oea_, _ирак_, thev,
  { {0xc31d0055, 0x6d45011c, 0xb7bd000d, 0x00000000}},  //   _তিনি_, muha, laţi,
  { {0x6d4520bc, 0x7c2900e0, 0x78a920bd, 0x00000000}},  //   luha, _ieer, rhev,
  { {0x7d0000ee, 0x7c2901b5, 0x78a90065, 0x00000000}},  //   _zims, _heer, shev,
  { {0x442904f5, 0x7c29006c, 0x6d4520be, 0x00000000}},  //   _bea_, _keer, nuha,
  { {0x4429000d, 0x443e010f, 0x7c290e4e, 0x00000000}},  //   _cea_, ßt_, _jeer,
  { {0x7c2920bf, 0x4429094e, 0x6d450058, 0x00000000}},  //   _meer, _dea_, huha,
  { {0x7c290100, 0xb7bd0035, 0x00000000, 0x00000000}},  //   _leer, jaţi,   ,
  { {0x91e6051f, 0x4429008e, 0x6d45006c, 0x00000000}},  //   сове, _fea_, juha,
  { {0x7c2900c7, 0x644d0051, 0x3eb8018b, 0x00000000}},  //   _neer, _gcai, _smrt_,
  { {0x7d000213, 0x7f4a0025, 0x4fea003b, 0x00000000}},  // [5020] _rims, طلاق_, уман_,
  { {0x7d000089, 0xb7bd001a, 0x44290032, 0x00000000}},  //   _sims, gaţi, _zea_,
  { {0x6d4509f3, 0x69150066, 0x2b5f0035, 0x00000000}},  //   guha, _jġed, _apuc_,
  { {0x30860025, 0x69150066, 0x14d80061, 0x00000000}},  //   _الحف, _mġed, ठविण,
  { {0x7c2901d6, 0x7c2d000c, 0x00000000, 0x00000000}},  //   _deer, ðara,   ,
  { {0xb7bd000d, 0x6d4520c0, 0x427a0049, 0x00000000}},  //   caţi, buha, ראַג,
  { {0xfce602b8, 0x7c2906c5, 0x6d450022, 0x00000000}},  //   _гово, _feer, cuha,
  { {0x7c290dda, 0x3ae90051, 0x26dc016c, 0x00000000}},  //   _geer, rúpa_, _skvo_,
  { {0x4429119c, 0x4fbb0049, 0x4c35007e, 0x00000000}},  //   _rea_, ָציא, _фэст,
  { {0xed4f009c, 0x44290781, 0x644d0051, 0x00000000}},  //   _تھے_, _sea_, _scai,
  { {0x44290004, 0x2fc70082, 0x6aa8068f, 0x00000000}},  //   _pea_, ̃ng_, _ildf,
  { {0xf1c00011, 0xb7bd001a, 0x23600022, 0x00000000}},  //   _ương_, zaţi, _bpij_,
  { {0x442920c1, 0xc6270044, 0x6d451b8a, 0x00000000}},  //   _vea_, _মারা_, zuha,
  { {0x46f6007c, 0x4429008e, 0x6d45011c, 0x00000000}},  //   _учет, _wea_, yuha,
  { {0x5184005c, 0x30a70265, 0x32110036, 0x00000000}},  //   пута, брав, rczy_,
  { {0xfd4d001d, 0x442900d4, 0xddc70142, 0x00000000}},  //   _thoạ, _uea_, _najš,
  { {0xb7bd001a, 0x59df0309, 0x9f8a010f, 0x00000000}},  // [5030] taţi, _पुनर, röße_,
  { {0x6d450390, 0x7c29109a, 0x2fc7001d, 0x00000000}},  //   tuha, _seer, ăng_,
  { {0x6285049b, 0xb7bd000d, 0xe5090082, 0x00000000}},  //   _inho, raţi, _lặn_,
  { {0x6d45027e, 0xa3bd006e, 0x6aa800d9, 0x00000000}},  //   ruha, _आधा_, _aldf,
  { {0x7c29017b, 0x2aab0030, 0x6d45027c, 0x00000000}},  //   _veer, _løbe_, suha,
  { {0x7c29049b, 0xbdfb00a1, 0xab64007e, 0x00000000}},  //   _weer, _مرزا_, явіл,
  { {0x9d18005e, 0x62970288, 0xb05b00f8, 0x00000000}},  //   _гост_, _moxo, _djäv,
  { {0x98bc0089, 0xddc70087, 0x00000000, 0x00000000}},  //   tuvā_, _gajš,   ,
  { {0xdddc011f, 0x628501d6, 0xe5090082, 0x00000000}},  //   _karş, _onho, _cặn_,
  { {0xe5090082, 0x628500ea, 0x00000000, 0x00000000}},  //   _dặn_, _nnho,   ,
  { {0xaca30011, 0xdddc0279, 0x00000000, 0x00000000}},  //   _chủn, _marş,   ,
  { {0x2b400027, 0x62850030, 0x394709f7, 0x00000000}},  //   šice_, _anho, muns_,
  { {0x394700f6, 0x62970253, 0x00000000, 0x00000000}},  //   luns_, _boxo,   ,
  { {0xe5a503f3, 0xe0df01aa, 0x629700fa, 0x00000000}},  //   _мили, _akò_, _coxo,
  { {0x4096026b, 0xc616009b, 0x00000000, 0x00000000}},  //   орат, _וחצי_,   ,
  { {0xd0070001, 0x62850b32, 0x6ab6007d, 0x00000000}},  //   жете_, _enho, _अग्र,
  { {0xddc700ca, 0xdd0100b9, 0x00000000, 0x00000000}},  // [5040] _rajš, štěs,   ,
  { {0x62970032, 0x539b0097, 0x7ea000f8, 0x00000000}},  //   _goxo, _כיפו, _köpi,
  { {0x39470035, 0xa01b04ce, 0x00000000, 0x00000000}},  //   juns_, _knöl,   ,
  { {0x23770167, 0x44220085, 0x1cba0025, 0x00000000}},  //   _امید_, nbk_, جائب_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x5f27004c, 0x629720c2, 0xbab7007e, 0x00000000}},  //   _форм_, _xoxo, огіх_,
  { {0xa2cd0201, 0x39470ca7, 0xdca6003b, 0x00000000}},  //   _सदस्, guns_, _дави,
  { {0x7cf101bf, 0x29020039, 0xbc6308d6, 0x00000000}},  //   gård, öka_, _овск,
  { {0xdb240167, 0xb86600a1, 0xe666007c, 0x00000000}},  //   _روای, ماکو, отно,
  { {0x7c220018, 0x39470181, 0xb50b0164, 0x00000000}},  //   lbor, buns_, _संशय_,
  { {0x394720c3, 0x291a01ca, 0x00000000, 0x00000000}},  //   cuns_, ípad_,   ,
  { {0x7c22022b, 0x1b1d0055, 0x8afd013e, 0x00000000}},  //   nbor, _নিতে_, _vpře,
  { {0x04b800a1, 0x290c00ca, 0x7c2201c3, 0x00000000}},  //   تھوں_, _huda_, ibor,
  { {0x290c04cb, 0xaca30082, 0xc1a702ea, 0x00000000}},  //   _kuda_, _thủn, ојби,
  { {0x290c11de, 0x7c2200b5, 0x8afd00b9, 0x00000000}},  //   _juda_, kbor, _upře,
  { {0x290c0d92, 0x1f15007e, 0x213e20c4, 0x00000000}},  //   _muda_, змаў, átha_,
  { {0x9f5902cc, 0x7c220039, 0x290c0166, 0x00000000}},  // [5050] _også_, dbor, _luda_,
  { {0xdddc005f, 0x51870121, 0xf3ff00c4, 0x00000000}},  //   _qarş, _дума, leão_,
  { {0x7af8001c, 0x802701b7, 0xbc190451, 0x00000000}},  //   dmvt, _ورحم, білі_,
  { {0x7c220145, 0x3ce600ca, 0xfe1b007d, 0x00000000}},  //   gbor, glov_, _प्रस_,
  { {0x7cf10039, 0x443b00d9, 0x290c20c5, 0x00000000}},  //   vård, _mdq_, _auda_,
  { {0x290c0095, 0xfbd00879, 0x8f9a0104, 0x00000000}},  //   _buda_, ختم_, _הישי,
  { {0x81dd0055, 0x7c220c0d, 0x290c1547, 0x00000000}},  //   তের_, bbor, _cuda_,
  { {0x290c0211, 0x39470181, 0x81d80044, 0x00000000}},  //   _duda_, runs_, ়েক_,
  { {0x7c3b20c6, 0x00000000, 0x00000000, 0x00000000}},  //   _idur,   ,   ,
  { {0x443b00f6, 0xca740025, 0x7545004d, 0x00000000}},  //   _adq_, _يالغ, пноз,
  { {0x6d57002d, 0x290c0032, 0x44220032, 0x00000000}},  //   ntxa, _guda_, tbk_,
  { {0x895a00b3, 0x7c3b0066, 0x00000000, 0x00000000}},  //   _לדעת, _jdur,   ,
  { {0xb4ac0061, 0x4422007f, 0x00000000, 0x00000000}},  //   _गती_, rbk_,   ,
  { {0xb77a009b, 0x290c0557, 0x7c220091, 0x00000000}},  //   _לאנש, _yuda_, zbor,
  { {0xd179103e, 0x64a60920, 0x703a0057, 0x00000000}},  //   ості_, _нака, йчас_,
  { {0x7c2d000c, 0x7c22098e, 0x7c3b01d1, 0x00000000}},  //   ðarl, xbor, _ndur,
  { {0x60c101aa, 0x7c2220c7, 0x9f58006b, 0x00000000}},  // [5060] èlma, vbor, _özüm_,
  { {0x7c3b11a8, 0xee3a007e, 0x7c220133, 0x00000000}},  //   _adur, ёне_, wbor,
  { {0x929b00b6, 0xe29b009b, 0x7c220fcf, 0x00000000}},  //   _היית, _השיר, tbor,
  { {0x2fcd016c, 0x290c00b4, 0xdcb90088, 0x00000000}},  //   _žege_, _ruda_, ощі_,
  { {0x3ce6032e, 0x200700b9, 0x752f0036, 0x00000000}},  //   rlov_, ěnit_, ączy,
  { {0x7c2200eb, 0x3ce601d9, 0x7c3b0032, 0x00000000}},  //   sbor, slov_, _edur,
  { {0x3ce601ed, 0xe5090082, 0x00000000, 0x00000000}},  //   plov_, _bặm_,   ,
  { {0x6e2e02ae, 0xb05b0039, 0x7e7520c8, 0x00000000}},  //   _hebb, _hjär, _zazp,
  { {0xd6da0265, 0x7f440181, 0xbb430954, 0x00000000}},  //   йто_, nriq, _петк,
  { {0x7cf10030, 0x953800e2, 0x00000000, 0x00000000}},  //   råre, озот_,   ,
  { {0x94d51618, 0xe6d9000c, 0x2bc00061, 0x00000000}},  //   донц, þráð, _शेता,
  { {0x8ec40044, 0x443b0b32, 0xe5090082, 0x00000000}},  //   ্তিগ, _qdq_, _gặm_,
  { {0x8387007e, 0xd7e30088, 0xe45f0010, 0x00000000}},  //   чыне, _пішо, lnök_,
  { {0x27e6006a, 0x6e2e1d1d, 0x7f4420c9, 0x00000000}},  //   _iyon_, _nebb, driq,
  { {0x26de0020, 0x7e7501d9, 0xe81301f5, 0x00000000}},  //   moto_, _razp, णुका_,
  { {0x61e5004f, 0x26de029d, 0xc7b90010, 0x00000000}},  //   _vyhl, loto_, kből_,
  { {0xb4d9013d, 0xc43c009b, 0x7c2d000c, 0x00000000}},  // [5070] ़की_, _התחי, ðarm,
  { {0x26de0089, 0xc3320049, 0x61e5013e, 0x00000000}},  //   noto_, _שוי_, _tyhl,
  { {0x6e2e0a19, 0x27e600f4, 0x26cc0181, 0x00000000}},  //   _debb, _lyon_, indo_,
  { {0x26de01ca, 0x7f4400f4, 0x6d57002d, 0x00000000}},  //   hoto_, briq, rtxa,
  { {0x6e2e0198, 0xb05b0039, 0x60cd006b, 0x00000000}},  //   _febb, _fjär, mnam,
  { {0xe9a90014, 0x68e20173, 0xfe710123, 0x00000000}},  //   يگان_, _akod, _جگر_,
  { {0x27e6006a, 0xac190245, 0x26de01c5, 0x00000000}},  //   _ayon_, _мову_, doto_,
  { {0x60cd006c, 0x26cc20ca, 0x645d00b5, 0x00000000}},  //   nnam, endo_, jfsi,
  { {0x60cd0181, 0x26de0142, 0xa806004a, 0x00000000}},  //   inam, foto_, _riñó,
  { {0x6f0f0197, 0x26de00c4, 0x248920cb, 0x00000000}},  //   _mucc, goto_, _anam_,
  { {0x044603c8, 0x6f0f0207, 0x60cd00f8, 0x00000000}},  //   менн, _lucc, knam,
  { {0x26cc20cc, 0x98bc0006, 0x89340025, 0x00000000}},  //   ando_, tuvą_, _أعلا,
  { {0x7ea00039, 0x26de0059, 0x68e901e3, 0x00000000}},  //   _köpt, boto_, mled,
  { {0x65c50264, 0x68e90018, 0x248920cd, 0x00000000}},  //   _обла, lled, _enam_,
  { {0x91e301fb, 0x81e60055, 0x2cad0004, 0x00000000}},  //   воре, বেন_, _oled_,
  { {0x60cd0207, 0x6f0f0026, 0x6e2e0197, 0x00000000}},  //   gnam, _bucc, _sebb,
  { {0x7d0e20ce, 0x6f0f0ef1, 0x7d1c20cf, 0x00000000}},  // [5080] _subs, _cucc, _strs,
  { {0x248901cd, 0x68e90224, 0x81dd0055, 0x00000000}},  //   _znam_, hled, তেই_,
  { {0xd00a02e9, 0x602620d0, 0x2cad0059, 0x00000000}},  //   _мене_, _одна, _bled_,
  { {0x6e2e0007, 0x68e90018, 0x6e3c0061, 0x00000000}},  //   _webb, jled, _wdrb,
  { {0x68e90ee6, 0xeb9700ed, 0x26de004a, 0x00000000}},  //   dled, миц_, yoto_,
  { {0x6d43002a, 0x68e20142, 0x26de00c4, 0x00000000}},  //   ánac, _skod, xoto_,
  { {0xde0309ae, 0x6d45018e, 0x6f0f0207, 0x00000000}},  //   _апри, crha, _zucc,
  { {0x68e90119, 0xa7740242, 0x88bc00b9, 0x00000000}},  //   gled, елич, _hvěz,
  { {0x26de20d1, 0x9646007e, 0x00000000, 0x00000000}},  //   toto_, мэнд,   ,
  { {0x60cd0387, 0xd6d90036, 0x26cc00fa, 0x00000000}},  //   znam, kułu_, undo_,
  { {0x68e907b5, 0x26de061c, 0x60cd00b4, 0x00000000}},  //   bled, roto_, ynam,
  { {0x68e91014, 0x26de00fa, 0x3f82000c, 0x00000000}},  //   cled, soto_, _orku_,
  { {0x2508026c, 0x26de00ca, 0x60cd013e, 0x00000000}},  //   _کرتی_, poto_, vnam,
  { {0x45d420d2, 0x60cd20d3, 0x00000000, 0x00000000}},  //   _полс, wnam,   ,
  { {0x60cd001d, 0x6f0f051b, 0x7c2d000c, 0x00000000}},  //   tnam, _succ, ðark,
  { {0x6f0f0197, 0x2489008e, 0x60cd007f, 0x00000000}},  //   _pucc, _unam_, unam,
  { {0x2bde0204, 0xa3c2007d, 0xbfab007e, 0x00000000}},  // [5090] _फुला, ्पण_, цтве_,
  { {0x60cd20d4, 0x2cad1958, 0xf09f0082, 0x00000000}},  //   snam, _sled_, _giàn_,
  { {0x40350088, 0x60cd046a, 0x68e920d5, 0x00000000}},  //   _пенс, pnam, yled,
  { {0x3f820107, 0x6f0f0026, 0x20c50089, 0x00000000}},  //   _frku_, _tucc, rķis_,
  { {0x68e9177a, 0x00000000, 0x00000000, 0x00000000}},  //   vled,   ,   ,
  { {0x68e900ab, 0xfaa702d3, 0xef1f014a, 0x00000000}},  //   wled, ьшен, _itü_,
  { {0x68e9006c, 0x00000000, 0x00000000, 0x00000000}},  //   tled,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68e90168, 0x68fb04cb, 0x291e20d6, 0x00000000}},  //   rled, rmud, _etta_,
  { {0x68e90428, 0x7d0920d7, 0xef1f006c, 0x00000000}},  //   sled, _hies, _mtü_,
  { {0x7d0900b5, 0x68e90190, 0x7ea0138d, 0x00000000}},  //   _kies, pled, _köpr,
  { {0x7c2d000c, 0x00000000, 0x00000000, 0x00000000}},  //   ðarh,   ,   ,
  { {0x7d0920d8, 0x386d0168, 0x850b006e, 0x00000000}},  //   _mies, meer_, _संकट_,
  { {0x386d00c7, 0x78a920d9, 0xd6d90036, 0x00000000}},  //   leer_, lkev, tułu_,
  { {0x60c401b1, 0x00000000, 0x00000000, 0x00000000}},  //   tiim,   ,   ,
  { {0xef1a013b, 0x7d091551, 0x78a90995, 0x00000000}},  //   зма_, _nies, nkev,
  { {0x64560061, 0xff2400a1, 0x60c401b1, 0x00000000}},  // [50a0] _icyi, ئبری, riim,
  { {0x386d01b5, 0x60c40006, 0x3fe317b9, 0x00000000}},  //   heer_, siim, ужув,
  { {0x443200ab, 0x386d20da, 0x8c46142c, 0x00000000}},  //   _key_, keer_, ееее,
  { {0x7d090871, 0x26c50058, 0xfb1900a1, 0x00000000}},  //   _cies, hilo_, ڈروں_,
  { {0x7d0908ba, 0x386d0007, 0x629e1892, 0x00000000}},  //   _dies, deer_, _kopo,
  { {0x44320211, 0xc33300b6, 0x2b460129, 0x00000000}},  //   _ley_, רוג_, rroc_,
  { {0x7d090211, 0x26c50340, 0x386d123c, 0x00000000}},  //   _fies, dilo_, feer_,
  { {0x386d01b5, 0xa3c20164, 0x7d090171, 0x00000000}},  //   geer_, ्पा_, _gies,
  { {0x26c50198, 0x68e000f8, 0xc6f8019d, 0x00000000}},  //   filo_, romd, мних_,
  { {0xc6f70eb1, 0x0f57009b, 0x26c520db, 0x00000000}},  //   нных_, עיים_, gilo_,
  { {0xceb3019b, 0x386d06b2, 0x4432014a, 0x00000000}},  //   רית_, beer_, _bey_,
  { {0x38ba0089, 0x78a9007f, 0x386d00bb, 0x00000000}},  //   tūru_, ckev, ceer_,
  { {0xdcf50046, 0x7c2d000c, 0x46a6007e, 0x00000000}},  //   _urzą, ðari, _падв,
  { {0x629e0adb, 0x26c5041a, 0xda1002f4, 0x00000000}},  //   _copo, cilo_, ाशित_,
  { {0x629e07e4, 0x44320173, 0xd5af017f, 0x00000000}},  //   _dopo, _fey_, _сс_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7d090555, 0x84640265, 0x8c3d014a, 0x00000000}},  // [50b0] _ries, _съще, _hoşg,
  { {0x752d0036, 0x386d00bb, 0x00000000, 0x00000000}},  //   _łazi, zeer_,   ,
  { {0x7d0920dc, 0x443200e0, 0x56370049, 0x00000000}},  //   _pies, _yey_, גאבע_,
  { {0x38b10010, 0xef1f010e, 0x7d090066, 0x00000000}},  //   _márc_, _ttü_, _qies,
  { {0x7d0920dd, 0x386d01b5, 0x7e2b007e, 0x00000000}},  //   _vies, veer_, _ніва_,
  { {0x7d0920de, 0xf09f0011, 0x386d00c7, 0x00000000}},  //   _wies, _hoà_, weer_,
  { {0x7d090ebc, 0x26c501d9, 0x386d01bb, 0x00000000}},  //   _ties, vilo_, teer_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x386d0343, 0x44320211, 0x78a920df, 0x00000000}},  //   reer_, _rey_, rkev,
  { {0x386d0944, 0x78a900b0, 0x443220e0, 0x00000000}},  //   seer_, skev, _sey_,
  { {0x26c50027, 0x386d01d6, 0x443217cf, 0x00000000}},  //   rilo_, peer_, _pey_,
  { {0x26c520e1, 0x7ae303e2, 0x629e0211, 0x00000000}},  //   silo_, lont, _sopo,
  { {0xcc3a007b, 0x26c50466, 0x69dc0190, 0x00000000}},  //   וערט, pilo_, _ører,
  { {0x7ae301a3, 0x7cf8008e, 0x63a607c4, 0x00000000}},  //   nont, míre, rykn,
  { {0x2056008b, 0x91e6005e, 0xc7b90010, 0x00000000}},  //   ктар, тове, lző_,
  { {0x205506e1, 0xe3b200a2, 0x7ae30023, 0x00000000}},  //   лтур, _نرخ_, hont,
  { {0x7ae30292, 0x629e0027, 0xb22600ed, 0x00000000}},  // [50c0] kont, _topo, _импл,
  { {0x3f8005ea, 0xd0f40061, 0x7ae30065, 0x00000000}},  //   rviu_, _आठवण_, jont,
  { {0x7ae30110, 0xf09f0026, 0xdb08000c, 0x00000000}},  //   dont, _foà_, _ólét,
  { {0x673b00b0, 0xdd8f0f8b, 0x00000000, 0x00000000}},  //   ksuj, توم_,   ,
  { {0x7ae30007, 0x7cf8013e, 0xdca30545, 0x00000000}},  //   font, jíre, јачи,
  { {0x7ae320e2, 0x81dd0044, 0xda6316e8, 0x00000000}},  //   gont, তেও_, ивчи,
  { {0xa96701fc, 0x987d006b, 0x00000000, 0x00000000}},  //   вија_, _açıb_,   ,
  { {0x7e7c022b, 0xdca302dc, 0xd90d0014, 0x00000000}},  //   _harp, _каси, سیه_,
  { {0xb50c007d, 0x7ae30010, 0x6d5e20e3, 0x00000000}},  //   _संजय_, bont, ltpa,
  { {0x7ae320e4, 0xa3e60164, 0x41db013d, 0x00000000}},  //   cont, _बुध_, _मुझस,
  { {0x6d5e0061, 0x7e7c013e, 0x6b82101b, 0x00000000}},  //   ntpa, _marp, lvog,
  { {0x249f009f, 0x69da002d, 0xd5b80089, 0x00000000}},  //   ðum_, _ixte, rzā_,
  { {0x6b8220e5, 0x6d5e015b, 0x00000000, 0x00000000}},  //   nvog, htpa,   ,
  { {0x63a000f8, 0x2d85012d, 0x00000000, 0x00000000}},  //   ämna, _šlem_,   ,
  { {0x623420e6, 0xf1a4007e, 0x6d5c01f3, 0x00000000}},  //   ресу, артн, _nqra,
  { {0x7ae30181, 0x5455013b, 0x6d5e0109, 0x00000000}},  //   zont, _свит, dtpa,
  { {0x44390736, 0x7e7c0146, 0x6d5e01d6, 0x00000000}},  // [50d0] mas_, _barp, etpa,
  { {0x717920e7, 0x7e7c20e8, 0x6d5e06d3, 0x00000000}},  //   _збор_, _carp, ftpa,
  { {0x7e7c018e, 0xf09f0011, 0x7ae30ae4, 0x00000000}},  //   _darp, _toà_, vont,
  { {0xac1901a4, 0x7ae30173, 0x7afa00f6, 0x00000000}},  //   ходу_, wont, _ahtt,
  { {0x7ae30efc, 0x44390181, 0x6d5e00d9, 0x00000000}},  //   tont, ias_, atpa,
  { {0xeb9003ab, 0xddce0010, 0x7e7c20e9, 0x00000000}},  //   تظم_, _ebbő, _garp,
  { {0x443920ea, 0x7ae30207, 0xdd94008b, 0x00000000}},  //   kas_, ront, _кары,
  { {0x44390580, 0x48d10055, 0x7ae320eb, 0x00000000}},  //   jas_, াত্র, sont,
  { {0x44390576, 0xe50a001d, 0x7ae320ec, 0x00000000}},  //   das_, _mặt_, pont,
  { {0xc7b90010, 0x1ab700e8, 0xaab7007d, 0x00000000}},  //   rző_, _अतिथ, _अतिक,
  { {0x64a601a4, 0xe45f00b0, 0x00000000, 0x00000000}},  //   гана, riön_,   ,
  { {0xb4de0204, 0x0446007e, 0xa90702fd, 0x00000000}},  //   तके_, ыемн, _شبان,
  { {0x889a061e, 0xf745026b, 0x387f20ed, 0x00000000}},  //   _רבני, _село, mdur_,
  { {0x387f009f, 0x6e3501ca, 0x386620ee, 0x00000000}},  //   ldur_, _nezb, _zbor_,
  { {0x44391e86, 0xa06a01f9, 0x6aa10eba, 0x00000000}},  //   bas_, нава_, _molf,
  { {0x44390df9, 0x387f20ef, 0x7e7c20f0, 0x00000000}},  //   cas_, ndur_, _sarp,
  { {0x6e35037e, 0x0e660517, 0xa4fb00b6, 0x00000000}},  // [50e0] _bezb, лкан, _אלקט,
  { {0x387d0016, 0x6aa100f6, 0x4256004d, 0x00000000}},  //   _lawr_, _nolf, _стит,
  { {0x6e35001a, 0x7e7c0d96, 0x16360049, 0x00000000}},  //   _dezb, _varp, רנער_,
  { {0x6d5e00b5, 0x387d0016, 0x6b8220f1, 0x00000000}},  //   rtpa, _nawr_, tvog,
  { {0x7e7c1082, 0xfaa60245, 0x6d5e0056, 0x00000000}},  //   _tarp, ладо, stpa,
  { {0x4439082b, 0x6b8206ce, 0x44200ba5, 0x00000000}},  //   zas_, rvog, _lfi_,
  { {0x81e60055, 0x44391433, 0x44200173, 0x00000000}},  //   বের_, yas_, _ofi_,
  { {0xfce60f13, 0xa9670025, 0x443914dc, 0x00000000}},  //   _собо, اميم_, xas_,
  { {0x4439081d, 0x7d0213d7, 0x00000000, 0x00000000}},  //   vas_, mmos,   ,
  { {0x4439001f, 0x4420000c, 0xba1a0025, 0x00000000}},  //   was_, _afi_, _أيضا_,
  { {0xa92620f2, 0x387d018e, 0x8b0300b9, 0x00000000}},  //   _сдел, _fawr_, ířen,
  { {0xd5b70b87, 0x6f0e00d2, 0x6aa10026, 0x00000000}},  //   усь_, _libc, _zolf,
  { {0x44200146, 0x442b0087, 0x00000000, 0x00000000}},  //   _dfi_, rbc_,   ,
  { {0x78a2006c, 0x44200145, 0x8c3d006b, 0x00000000}},  //   _hoov, _efi_, _xoşb,
  { {0x443920f3, 0x2b400161, 0x44200016, 0x00000000}},  //   pas_, šich_, _ffi_,
  { {0x443901d5, 0xd468012b, 0x30a400ed, 0x00000000}},  //   qas_, _биће_, брув,
  { {0xe50a001d, 0x611c0059, 0x81e60044, 0x00000000}},  // [50f0] _vặt_, _včla, বেল_,
  { {0xd2510123, 0x78a2006c, 0x387f0276, 0x00000000}},  //   _بند_, _loov, zdur_,
  { {0xd0111298, 0x2d8720f4, 0x6aa100ea, 0x00000000}},  //   _ولد_, íne_, _rolf,
  { {0x387f005f, 0x6aa120f5, 0x78a20087, 0x00000000}},  //   xdur_, _solf, _noov,
  { {0x2d9c01e3, 0x6aa100ca, 0x00000000, 0x00000000}},  //   øver_, _polf,   ,
  { {0x7d020205, 0x00000000, 0x00000000, 0x00000000}},  //   amos,   ,   ,
  { {0x9ed800ed, 0x7c2d000c, 0x59df01f5, 0x00000000}},  //   _смрт_, ðars, _पुखर,
  { {0x6aa1010f, 0x00000000, 0x00000000, 0x00000000}},  //   _wolf,   ,   ,
  { {0x387f20f6, 0x4420009d, 0x78a2012d, 0x00000000}},  //   rdur_, _rfi_, _doov,
  { {0x46f500ec, 0x442000f8, 0xb05b0039, 0x00000000}},  //   јчит, _sfi_, _smäl,
  { {0x996201ca, 0x44200675, 0x00000000, 0x00000000}},  //   píše_, _pfi_,   ,
  { {0x385803ec, 0x6b8900b5, 0x00000000, 0x00000000}},  //   _مشهد_, _kreg,   ,
  { {0xa3e6007d, 0x76430022, 0x00000000, 0x00000000}},  //   _बुश_, _tdny,   ,
  { {0x76430030, 0x290f0058, 0x7d021431, 0x00000000}},  //   _udny, _higa_, zmos,
  { {0x7d02007f, 0x6f0e0087, 0xe2970269, 0x00000000}},  //   ymos, _ribc, шар_,
  { {0xdd2f00b9, 0x6b8909dd, 0x7f4d00c4, 0x00000000}},  //   _běžn, _oreg, fraq,
  { {0x1fa71c9b, 0xaec6007e, 0x290f1c2e, 0x00000000}},  // [5100] акти_, абал, _miga_,
  { {0x2480025e, 0x00000000, 0x00000000, 0x00000000}},  //   _haim_,   ,   ,
  { {0x6b891163, 0xed5a0783, 0x290f004a, 0x00000000}},  //   _areg, тое_, _oiga_,
  { {0x6b8920f7, 0xab2a0175, 0xb4c4001c, 0x00000000}},  //   _breg, вода_, _एगो_,
  { {0x6b89063e, 0x7d020781, 0x1be70478, 0x00000000}},  //   _creg, rmos, адци_,
  { {0x78a20004, 0x7d0206aa, 0x6b89000c, 0x00000000}},  //   _soov, smos, _dreg,
  { {0x8c96008b, 0x7d0220f8, 0x2245000c, 0x00000000}},  //   _краі, pmos, ólki_,
  { {0x6b890a15, 0x7afd0089, 0x24800f7c, 0x00000000}},  //   _freg, _īste, _naim_,
  { {0x290f00d6, 0x7c2d0e65, 0x00000000, 0x00000000}},  //   _diga_, ñare,   ,
  { {0x290f0635, 0x1b1d0044, 0x27ef0039, 0x00000000}},  //   _eiga_, _নিচে_, _dygn_,
  { {0x290f0724, 0x24800022, 0x78a2010e, 0x00000000}},  //   _figa_, _baim_, _toov,
  { {0x290f0093, 0xe786003b, 0x7f4d006b, 0x00000000}},  //   _giga_, _вуко, yraq,
  { {0xe8d700b6, 0x2480006b, 0x29040087, 0x00000000}},  //   _דואר_, _daim_, mmma_,
  { {0x17570049, 0x2d8a06d2, 0x00000000, 0x00000000}},  //   _כסדר_, _orbe_,   ,
  { {0x6ac4024c, 0x26cc0489, 0x4de60061, 0x00000000}},  //   _वगैर, mido_, _जुलै_,
  { {0x26cc0325, 0x7435025f, 0x24800288, 0x00000000}},  //   lido_, _униф, _gaim_,
  { {0x2d8a00eb, 0x7eb200ea, 0x00000000, 0x00000000}},  // [5110] _arbe_, _væpn,   ,
  { {0x26cc0219, 0x6b89008d, 0x7f4d00d4, 0x00000000}},  //   nido_, _rreg, rraq,
  { {0xa184007e, 0x3ea3002b, 0x00000000, 0x00000000}},  //   _дыял, _vojt_,   ,
  { {0x40950025, 0x8c3d005d, 0x88bc00b9, 0x00000000}},  //   _الحر, _boşa, _stěn,
  { {0x290f0089, 0x60cd0006, 0x2d8a185d, 0x00000000}},  //   _riga_, miam, _erbe_,
  { {0x60cd0006, 0x290f0181, 0x26cc008e, 0x00000000}},  //   liam, _siga_, jido_,
  { {0x26cc20f9, 0x290f0509, 0x00000000, 0x00000000}},  //   dido_, _piga_,   ,
  { {0x60cd06dc, 0x6b89008d, 0x394906b8, 0x00000000}},  //   niam, _treg, čas_,
  { {0x290f006c, 0x26cc20fa, 0x6b891285, 0x00000000}},  //   _viga_, fido_, _ureg,
  { {0x26cc0489, 0x60cd0207, 0xa4f900a1, 0x00000000}},  //   gido_, hiam, یکٹر_,
  { {0x672920fb, 0x60cd010a, 0x290f020c, 0x00000000}},  //   spej, kiam, _tiga_,
  { {0xe50a0011, 0x60cd0020, 0x672900b0, 0x00000000}},  //   _cặp_, jiam, ppej,
  { {0x26cc0b76, 0x60cd20fc, 0x68e920fd, 0x00000000}},  //   bido_, diam, moed,
  { {0x26cc0977, 0x68e920fe, 0x26c70127, 0x00000000}},  //   cido_, loed, _umno_,
  { {0x60cd0724, 0x248020ff, 0x00000000, 0x00000000}},  //   fiam, _taim_,   ,
  { {0xe50a001d, 0x60cd0006, 0x672d01d5, 0x00000000}},  //   _gặp_, giam, _ħajj,
  { {0x2d8a05fa, 0xddd50059, 0xff2700a1, 0x00000000}},  // [5120] _srbe_, _razš, مبلی,
  { {0x68e9018e, 0xee3709c0, 0x44220190, 0x00000000}},  //   hoed, йну_, lck_,
  { {0x60cd0198, 0xc27b0476, 0x2bc00061, 0x00000000}},  //   biam, _גריי, _शेजा,
  { {0x60cd2100, 0x442200f4, 0x26cc0181, 0x00000000}},  //   ciam, nck_, zido_,
  { {0x4427005f, 0x68e92101, 0x00000000, 0x00000000}},  //   _ən_, doed,   ,
  { {0x26cc004a, 0xd37b009b, 0x00000000, 0x00000000}},  //   xido_, טרנט,   ,
  { {0x26cc0181, 0x2d8a2102, 0x68e90016, 0x00000000}},  //   vido_, _urbe_, foed,
  { {0xa3b80164, 0x68e92103, 0x6cd601f7, 0x00000000}},  //   चना_, goed, _اقرا,
  { {0x26cc029d, 0xf09f0011, 0x2fc0010f, 0x00000000}},  //   tido_, _giàu_, nzig_,
  { {0x60cd0207, 0x6e3e1892, 0xda6603ec, 0x00000000}},  //   ziam, napb, _داري,
  { {0x26cc029d, 0xa5f81344, 0x7c220026, 0x00000000}},  //   rido_, рену_, ocor,
  { {0x7c220a15, 0x7aea0007, 0x6d430051, 0x00000000}},  //   ncor, loft, ánai,
  { {0x60cd0207, 0x26cc0325, 0x2fc000b5, 0x00000000}},  //   viam, pido_, jzig_,
  { {0x60cd0036, 0x4422009d, 0x7aea0ede, 0x00000000}},  //   wiam, ack_, noft,
  { {0x60cd0026, 0x3f8b0059, 0x00000000, 0x00000000}},  //   tiam, _srcu_,   ,
  { {0x44220288, 0x7aea00d9, 0x00000000, 0x00000000}},  //   cck_, hoft,   ,
  { {0x60cd2104, 0x4034007c, 0x2aab0030, 0x00000000}},  // [5130] riam, яетс, _købt_,
  { {0x765a2105, 0x60cd0006, 0x4255036d, 0x00000000}},  //   ngty, siam, _بندر,
  { {0x443b008d, 0x60cd05fc, 0x257a0089, 0x00000000}},  //   _keq_, piam, _jūl_,
  { {0xaca30011, 0x00000000, 0x00000000, 0x00000000}},  //   _miện,   ,   ,
  { {0xeb9918ea, 0xfd1005f3, 0x68e901bb, 0x00000000}},  //   рил_, رجم_, voed,
  { {0x93fc01ce, 0x7c222106, 0xd35800a0, 0x00000000}},  //   אלדי, acor, מידי_,
  { {0x44220039, 0xaa56012b, 0x7c22121e, 0x00000000}},  //   yck_, цију_, bcor,
  { {0x81fb0055, 0x7c221017, 0xd0fb007d, 0x00000000}},  //   _আলাপ_, ccor, ्षिण_,
  { {0x68e90016, 0x78bb0039, 0xcb3402dc, 0x00000000}},  //   roed, rhuv, _нетъ,
  { {0x7c3b2107, 0x68e92108, 0x611c01aa, 0x00000000}},  //   _heur, soed, _sčlm,
  { {0x7c3b00b5, 0x68e90116, 0x2aab0190, 0x00000000}},  //   _keur, poed, _døbt_,
  { {0x7c3b00e7, 0x44220068, 0x00000000, 0x00000000}},  //   _jeur, uck_,   ,
  { {0x7c3b00f4, 0x7cf80010, 0x00000000, 0x00000000}},  //   _meur, zíro,   ,
  { {0x7c3b028c, 0x67d80049, 0x00000000, 0x00000000}},  //   _leur, _פֿײג,   ,
  { {0x64a6005e, 0x7e7700bb, 0xa3e60061, 0x00000000}},  //   _мака, dexp, _बँक_,
  { {0x7c3b1624, 0x92da0044, 0x8066007e, 0x00000000}},  //   _neur, ়তে_, ўваж,
  { {0x3eb80022, 0x611c0173, 0x26050061, 0x00000000}},  // [5140] _plrt_, _kčlk, हेरी_,
  { {0x7e772109, 0x7c220009, 0x2fc001a2, 0x00000000}},  //   gexp, wcor, rzig_,
  { {0x7c3b0168, 0xa06a1867, 0x00000000, 0x00000000}},  //   _beur, _кана_,   ,
  { {0x61fe066e, 0x2fc0010f, 0x7afd0089, 0x00000000}},  //   _izpl, pzig_, _īsta,
  { {0x7c3b210a, 0x7c220c16, 0x7aea0190, 0x00000000}},  //   _deur, rcor, toft,
  { {0x7c220207, 0x7cf80d7f, 0x3a25000a, 0x00000000}},  //   scor, píro, _cflp_,
  { {0x7aea0023, 0x6e3c0035, 0x00000000, 0x00000000}},  //   roft, _ierb,   ,
  { {0xbebb008d, 0x7c3b210b, 0x00000000, 0x00000000}},  //   _atëh, _geur,   ,
  { {0xd6da0265, 0xd7fa0099, 0x7d1c059f, 0x00000000}},  //   ито_, шук_, _hurs,
  { {0x7aea0065, 0x7c3b210c, 0x6e3c0166, 0x00000000}},  //   qoft, _zeur, _jerb,
  { {0x69150224, 0x7d1c145e, 0x6e3c01a3, 0x00000000}},  //   _všec, _jurs, _merb,
  { {0x92da0055, 0x7d1c0059, 0xef1f010f, 0x00000000}},  //   ়তো_, _murs, _früh_,
  { {0x7d1c210d, 0x443b0065, 0x7bc2210e, 0x00000000}},  //   _lurs, _veq_, nzou,
  { {0xd6d90036, 0x6e3c082c, 0x7d1c210f, 0x00000000}},  //   kuły_, _nerb, _ours,
  { {0x7d1c00ab, 0x30a7003b, 0x27200011, 0x00000000}},  //   _nurs, орав, _hòn_,
  { {0x27202110, 0x92bd0044, 0xa3e6006e, 0x00000000}},  //   _kòn_, েকে_, _बुक_,
  { {0x6e3c2111, 0x7c3b00d4, 0x200f006c, 0x00000000}},  // [5150] _berb, _reur, ägi_,
  { {0x7c3b021e, 0x27202110, 0x6e3c0016, 0x00000000}},  //   _seur, _mòn_, _cerb,
  { {0x7d1c081d, 0x6e3c02f1, 0x7c3b2112, 0x00000000}},  //   _curs, _derb, _peur,
  { {0x645d0292, 0x6aba2113, 0x317a007b, 0x00000000}},  //   ngsi, _altf, _פארד,
  { {0x798a001c, 0x7c3b04bd, 0x6285011c, 0x00000000}},  //   evfw, _veur, _kaho,
  { {0x6e3c0fdd, 0x7d1c0020, 0x628700ea, 0x00000000}},  //   _gerb, _furs, ndjo,
  { {0xf2d4007b, 0x62850020, 0x7c3b2114, 0x00000000}},  //   ועס_, _maho, _teur,
  { {0x6e3c022b, 0x6d450020, 0x27202115, 0x00000000}},  //   _zerb, msha, _bòn_,
  { {0x2720001d, 0x6e3c008e, 0x6f1d0ab2, 0x00000000}},  //   _còn_, _yerb, _jusc,
  { {0x628501c8, 0x869901e0, 0x6aa803ef, 0x00000000}},  //   _naho, стит_, _godf,
  { {0x6d45004e, 0xf3e90097, 0x6e2501a2, 0x00000000}},  //   nsha, _עף_, ichb,
  { {0xf2c9007b, 0x7f4400f4, 0x6d4500e7, 0x00000000}},  //   _גע_, ysiq, isha,
  { {0x27200011, 0x56950245, 0x6285010e, 0x00000000}},  //   _gòn_, _надт, _baho,
  { {0x0cb802f4, 0x6d450030, 0x6285009d, 0x00000000}},  //   _आत्म, ksha, _caho,
  { {0x27200263, 0x6285011c, 0xdddc001a, 0x00000000}},  //   _zòn_, _daho, _marţ,
  { {0x6f1d0219, 0x6e3c008d, 0x6d450611, 0x00000000}},  //   _busc, _serb, dsha,
  { {0x6e3c2116, 0x7d1c000d, 0xef1701e1, 0x00000000}},  // [5160] _perb, _surs, зму_,
  { {0x1fb501fb, 0x6f1d03a9, 0x62850922, 0x00000000}},  //   єстр, _dusc, _gaho,
  { {0x6e3c19fa, 0xc27b00b6, 0x7f4400f4, 0x00000000}},  //   _verb, _פרטי, ssiq,
  { {0x13b00055, 0x6e3c001f, 0x62850235, 0x00000000}},  //   _চেয়, _werb, _zaho,
  { {0x62852117, 0x6e3c020c, 0xfe70026c, 0x00000000}},  //   _yaho, _terb, _لگا_,
  { {0x9d460fa6, 0x7d1c0091, 0xff07007e, 0x00000000}},  //   _негд, _turs, _неяк_,
  { {0x6f1d010f, 0x76411a9d, 0xfe550123, 0x00000000}},  //   _zusc, daly, _زینب_,
  { {0x4ddb009b, 0xc8790035, 0xc1731881, 0x00000000}},  //   _החלו, geş_, גחה_,
  { {0xb6050087, 0x00000000, 0x00000000, 0x00000000}},  //   _lušč,   ,   ,
  { {0x35b4041f, 0x95d800e2, 0x76412118, 0x00000000}},  //   дбор, ждот_, galy,
  { {0x69c30046, 0x628500b0, 0xc8790a4b, 0x00000000}},  //   czne, _raho, beş_,
  { {0x6285011c, 0xbec30089, 0xdcfc0087, 0x00000000}},  //   _saho, _ķīmi, _osrč,
  { {0x62852001, 0xd706007c, 0x76412119, 0x00000000}},  //   _paho, _езди, baly,
  { {0x6d450052, 0x764a0030, 0x6f1d211a, 0x00000000}},  //   ysha, _udfy, _rusc,
  { {0x6f1d0845, 0x291e0149, 0x62870093, 0x00000000}},  //   _susc, _juta_, rdjo,
  { {0x55770049, 0x62850246, 0x6f1d0035, 0x00000000}},  //   _זעהן_, _waho, _pusc,
  { {0x6285211b, 0x291e0181, 0x4429006b, 0x00000000}},  // [5170] _taho, _luta_, _ifa_,
  { {0x6d450302, 0x6e2501a2, 0x7cf8013e, 0x00000000}},  //   tsha, uchb, bírk,
  { {0x3f82002d, 0x6e2500ac, 0x6f150553, 0x00000000}},  //   _esku_, rchb, _vizc,
  { {0x7bf900ed, 0x6e25010f, 0x44290093, 0x00000000}},  //   онер_, schb, _jfa_,
  { {0x6d450039, 0x291e0387, 0x2d9c0039, 0x00000000}},  //   ssha, _auta_, äver_,
  { {0x69c30109, 0x291e033b, 0x1ee700a2, 0x00000000}},  //   tzne, _buta_, _روزی_,
  { {0x7641075a, 0x644d0adb, 0x442900e7, 0x00000000}},  //   valy, _odai, _ofa_,
  { {0xfc3306dd, 0x7cf105b7, 0x291e04cb, 0x00000000}},  //   _سحر_, rårs, _duta_,
  { {0xf7080011, 0x69c30c59, 0xc8791f4a, 0x00000000}},  //   _hủy_, szne, reş_,
  { {0x4429000c, 0x644d0020, 0x291e0f3e, 0x00000000}},  //   _afa_, _adai, _futa_,
  { {0x7641211c, 0xb05b0039, 0x291e0b94, 0x00000000}},  //   raly, _kläd, _guta_,
  { {0x2d910107, 0xb605211d, 0x4429009d, 0x00000000}},  //   _mrze_, _rušč, _cfa_,
  { {0xdddc0d90, 0xaca3001d, 0x291e0107, 0x00000000}},  //   _marš, _chỉn, _zuta_,
  { {0x44290fd1, 0x77690c3f, 0x386d010f, 0x00000000}},  //   _efa_, mtex, lfer_,
  { {0x7769211e, 0x44291625, 0xa187003b, 0x00000000}},  //   ltex, _ffa_, мбра_,
  { {0xf1b801d5, 0xdddc0006, 0x7c2d008e, 0x00000000}},  //   ġġ_, _narš, ñarl,
  { {0x98a60107, 0x386d01a2, 0x4de6013d, 0x00000000}},  // [5180] žiće_, ifer_, _जुड़े_,
  { {0x7c291717, 0xb6050006, 0x2d910091, 0x00000000}},  //   _afer, _tušč, _brze_,
  { {0xdddc1288, 0x77690009, 0x6449000c, 0x00000000}},  //   _barš, htex, ðeig,
  { {0x291e029a, 0x2d910107, 0x386d00b5, 0x00000000}},  //   _ruta_, _drze_, jfer_,
  { {0x69150626, 0x291e001a, 0x3f82211f, 0x00000000}},  //   _pšen, _suta_, _usku_,
  { {0x2bd2001c, 0x386d002b, 0x77690387, 0x00000000}},  //   _देणा, efer_, dtex,
  { {0x7c29018e, 0x77690009, 0xe2a7000c, 0x00000000}},  //   _ffer, etex, æðir_,
  { {0x52bb0201, 0xb05b0039, 0xdddc0089, 0x00000000}},  //   _उत्स, _gläd, _garš,
  { {0x77692120, 0x78ab012d, 0xc7c6007c, 0x00000000}},  //   gtex, _dogv, ьски,
  { {0x291e013f, 0x44290675, 0xc6f70783, 0x00000000}},  //   _tuta_, _sfa_, мных_,
  { {0x2bd20061, 0x44292121, 0x186a00ed, 0x00000000}},  //   _देता, _pfa_, _мажи_,
  { {0x77690050, 0xb8930025, 0x7cf80051, 0x00000000}},  //   btex, _للمع, fíri,
  { {0x77690009, 0x442902d4, 0x00000000, 0x00000000}},  //   ctex, _vfa_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2906001d, 0x22430096, 0x26de0555, 0x00000000}},  //   _khoa_, rajk_, mnto_,
  { {0xd788001d, 0xe45f0210, 0x92cf0044, 0x00000000}},  //   _kể_, riös_, ষকে_,
  { {0xa2950ee0, 0x332000d4, 0x7c2d004a, 0x00000000}},  // [5190] _запі, _guix_, ñarm,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7c29010f, 0x6d5a0039, 0x386d0abb, 0x00000000}},  //   _pfer, _åtal, yfer_,
  { {0x6fd00061, 0x77690009, 0xfc300439, 0x00000000}},  //   _ठेवू, ytex, لحه_,
  { {0x77690061, 0x225800a6, 0x24890058, 0x00000000}},  //   xtex, _عجیب_, _maam_,
  { {0x77690009, 0x29062122, 0xf7080082, 0x00000000}},  //   vtex, _ahoa_, _tủy_,
  { {0x77690061, 0xd940007e, 0x7c290066, 0x00000000}},  //   wtex, ацыi_, _tfer,
  { {0x2489049b, 0x26de0211, 0x77692123, 0x00000000}},  //   _naam_, ento_, ttex,
  { {0x386d0abe, 0x68e2012d, 0xd76400a1, 0x00000000}},  //   rfer_, _djod, نچوی,
  { {0xd7060057, 0x7769211e, 0x8aa7007e, 0x00000000}},  //   нные_, rtex, _ўрад,
  { {0x68e201ee, 0x386d010f, 0x776905b4, 0x00000000}},  //   _fjod, pfer_, stex,
  { {0x26de0aa3, 0x77690009, 0x332000d4, 0x00000000}},  //   anto_, ptex, _puix_,
  { {0x2cad01bb, 0xa3f5007e, 0x68fb014a, 0x00000000}},  //   _moed_, вярш, mlud,
  { {0x290d2124, 0x00000000, 0x00000000, 0x00000000}},  //   lmea_,   ,   ,
  { {0xf6520097, 0x11d50088, 0x24890116, 0x00000000}},  //   _עצה_, вітр, _faam_,
  { {0x205501fb, 0x7cf800f7, 0xb05b0039, 0x00000000}},  //   ктур, píri, _smär,
  { {0x6446020c, 0x48fa0049, 0xaf06030d, 0x00000000}},  // [51a0] maki, פּלא, епал,
  { {0x6446006a, 0x2a651cdc, 0x611c000a, 0x00000000}},  //   laki, _nclb_, _bčlt,
  { {0xd00f00a1, 0x68fb0292, 0x6e170025, 0x00000000}},  //   للہ_, klud, فيكس_,
  { {0x64462125, 0x8fa603c8, 0x2cad0016, 0x00000000}},  //   naki, _заме, _coed_,
  { {0xfbd20063, 0x00000000, 0x00000000, 0x00000000}},  //   دتا_,   ,   ,
  { {0x6446000b, 0x60c400c4, 0xd7880082, 0x00000000}},  //   haki, lhim, _rể_,
  { {0x64462126, 0x317a0049, 0x00000000, 0x00000000}},  //   kaki, לאַד,   ,
  { {0x2cad01b5, 0x7e7e006c, 0x7d0300c1, 0x00000000}},  //   _goed_, lepp, ïnst,
  { {0x6d5e04bd, 0x64462127, 0xe66600ed, 0x00000000}},  //   lupa, daki, нтно,
  { {0x24890343, 0x2906103f, 0x26de0207, 0x00000000}},  //   _saam_, _whoa_, unto_,
  { {0xd5b70eec, 0x49ba00f3, 0x26de0009, 0x00000000}},  //   еся_, _عائد_, rnto_,
  { {0x68fb0038, 0x7e7e00bb, 0x94d5013b, 0x00000000}},  //   clud, hepp, томц,
  { {0x60c41ac5, 0x7e7e000c, 0x6d5e044e, 0x00000000}},  //   dhim, kepp, hupa,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x64462128, 0x2bd20164, 0x31c417a4, 0x00000000}},  //   baki, _देसा, гств,
  { {0x6d5e020c, 0xd5fb00b3, 0x60c42129, 0x00000000}},  //   dupa, _מפור, ghim,
  { {0xf1b9001e, 0x44390339, 0x00000000, 0x00000000}},  // [51b0] ņš_, mbs_,   ,
  { {0xdd950057, 0xaca30011, 0xb05b0039, 0x00000000}},  //   казы, _thịn, _bläc,
  { {0xe2a7000c, 0x44390f36, 0x2cad006c, 0x00000000}},  //   æður_, obs_, _poed_,
  { {0xec150014, 0x60c400e4, 0xc5f30049, 0x00000000}},  //   نواد, chim, אדע_,
  { {0x2cad01d6, 0xbc180088, 0x00000000, 0x00000000}},  //   _voed_, ніші_,   ,
  { {0x6446212a, 0x6d5e0390, 0xb05b0a35, 0x00000000}},  //   zaki, bupa, _fläc,
  { {0x64460169, 0x2cad0003, 0x6d5e051b, 0x00000000}},  //   yaki, _toed_, cupa,
  { {0xa3c10365, 0x394c0181, 0x2bd201f5, 0x00000000}},  //   ंना_, _dvds_, _देवा,
  { {0x64460027, 0x7d09002d, 0x290d212b, 0x00000000}},  //   vaki, _ihes, rmea_,
  { {0x64460258, 0xa6950098, 0x60c40065, 0x00000000}},  //   waki, триј, zhim,
  { {0x644604ff, 0x7d1b212c, 0x442b0009, 0x00000000}},  //   taki, _kius, fcc_,
  { {0x89340025, 0x60c40065, 0x7e7e0066, 0x00000000}},  //   _إعلا, xhim, zepp,
  { {0x64460f42, 0x7d090020, 0x387f00f4, 0x00000000}},  //   raki, _mhes, meur_,
  { {0x387f028c, 0x480401fb, 0x78a90213, 0x00000000}},  //   leur_, _спів, ljev,
  { {0x6446006a, 0xf09f001d, 0x60c4212d, 0x00000000}},  //   paki, _chào_, thim,
  { {0x78a90627, 0x387f00f4, 0x8c3d011f, 0x00000000}},  //   njev, neur_, _koşu,
  { {0x76430596, 0x44201fae, 0x60c4003f, 0x00000000}},  // [51c0] _keny, _igi_, rhim,
  { {0x60c406b7, 0x6d5e011c, 0x06e30044, 0x00000000}},  //   shim, tupa, _নীতি,
  { {0x2b4d0a8d, 0x7643020c, 0x629e002d, 0x00000000}},  //   _avec_, _meny, _inpo,
  { {0x6d5e0149, 0x7e7e0207, 0x628e0030, 0x00000000}},  //   rupa, sepp, ldbo,
  { {0x2bd204da, 0x78a9037e, 0x387f193b, 0x00000000}},  //   _देशा, djev, deur_,
  { {0x628e0286, 0x3866212e, 0xc882006b, 0x00000000}},  //   ndbo, _scor_, mişə_,
  { {0xada30216, 0x387f1de2, 0x6df60025, 0x00000000}},  //   _карл, feur_, _شكرا,
  { {0x7d1b0198, 0x68e00061, 0x78a9212f, 0x00000000}},  //   _gius, unmd, gjev,
  { {0x6f1c010f, 0xaca3001d, 0x76432130, 0x00000000}},  //   _kirc, _giốn, _beny,
  { {0x752300d9, 0x6f1c0066, 0x7d092131, 0x00000000}},  //   _bunz, _jirc, _zhes,
  { {0x764301aa, 0x387f0343, 0x6f1c001a, 0x00000000}},  //   _deny, beur_, _mirc,
  { {0x44202132, 0xb8650014, 0x628e2133, 0x00000000}},  //   _cgi_, _ماهو, edbo,
  { {0x4439001e, 0x7c2d027b, 0x317a0846, 0x00000000}},  //   rbs_, ñari, _appz_,
  { {0x76430607, 0x75230409, 0x6b9d000c, 0x00000000}},  //   _geny, _funz, _ásge,
  { {0x76480b9a, 0x44390022, 0x442b005b, 0x00000000}},  //   mady, pbs_, pcc_,
  { {0x76430020, 0x629e01aa, 0x628e01c3, 0x00000000}},  //   _zeny, _enpo, adbo,
  { {0x7d09018e, 0x7643000b, 0x7d1b0207, 0x00000000}},  // [51d0] _rhes, _yeny, _rius,
  { {0xfe7001b7, 0x539a009b, 0x7d090065, 0x00000000}},  //   قدم_, _ניתו, _shes,
  { {0x387f00f4, 0x6f1c0810, 0x7d1b2134, 0x00000000}},  //   yeur_, _dirc, _pius,
  { {0x8c3d001a, 0x387f009d, 0x6f1c2135, 0x00000000}},  //   _noşt, xeur_, _eirc,
  { {0x387f00f4, 0x7d090022, 0x76480058, 0x00000000}},  //   veur_, _vhes, kady,
  { {0x69150006, 0x6d580161, 0x00000000, 0x00000000}},  //   _išei, ávac,   ,
  { {0x387f028c, 0x7d090038, 0x80ba0061, 0x00000000}},  //   teur_, _thes, _एकमे,
  { {0x76432136, 0xf91300a1, 0x7d0900e7, 0x00000000}},  //   _seny, جستھ, _uhes,
  { {0x7643020c, 0x78a90059, 0x387f00f4, 0x00000000}},  //   _peny, rjev, reur_,
  { {0x6b892137, 0xb7bd000d, 0x387f00f4, 0x00000000}},  //   _iseg, ncţi, seur_,
  { {0x044606e7, 0x211f0061, 0x78a9016e, 0x00000000}},  //   ленн, _मंगळ_, pjev,
  { {0x7643000b, 0x3f4f001e, 0x26c50066, 0x00000000}},  //   _weny, kļu_, shlo_,
  { {0x765c0046, 0xe91801fb, 0x7e9b001e, 0x00000000}},  //   óryc, _році_, _kāpē,
  { {0x7eb20030, 0xf09f00d4, 0x291d011c, 0x00000000}},  //   _næpp, _anà_, _hiwa_,
  { {0x2729009f, 0x67290065, 0x11da0025, 0x00000000}},  //   _hún_, lqej, رورة_,
  { {0xdfd20025, 0x6f1c016c, 0x291d04cb, 0x00000000}},  //   ميز_, _sirc, _jiwa_,
  { {0x3f4f0089, 0x27292138, 0x6f1c0089, 0x00000000}},  // [51e0] gļu_, _jún_, _pirc,
  { {0x291d0093, 0x27290011, 0x21a601ee, 0x00000000}},  //   _liwa_, _mún_, _биом,
  { {0x6b8904a8, 0x224a0009, 0x27292139, 0x00000000}},  //   _aseg, mabk_, _lún_,
  { {0x5fd5001c, 0x9b6a017a, 0x1b4a213a, 0x00000000}},  //   _ठेवल, ешка_, езди_,
  { {0xb05b0a5d, 0x2d870030, 0xc882006b, 0x00000000}},  //   _klän, æner_, qişə_,
  { {0x408600a1, 0x69ca01a2, 0x00000000, 0x00000000}},  //   _جھڑپ_, tzfe,   ,
  { {0x27290211, 0xa96700e1, 0x6b89213b, 0x00000000}},  //   _aún_, гија_, _eseg,
  { {0x37e80055, 0x7ae30051, 0x27290082, 0x00000000}},  //   _পরবর, annt, _bún_,
  { {0xd90d0014, 0x291d011c, 0x76480a81, 0x00000000}},  //   ذیه_, _diwa_, tady,
  { {0x557401e0, 0x27290051, 0x00000000, 0x00000000}},  //   агот, _dún_,   ,
  { {0x76480a77, 0x65610181, 0xdef70049, 0x00000000}},  //   rady, gulh, רמיט_,
  { {0x26d9009d, 0xf8ad0014, 0x7648011c, 0x00000000}},  //   ésor_, _يکي_, sady,
  { {0xf09f0011, 0x9cd7009b, 0xb05b00f8, 0x00000000}},  //   _giày_, רוכה_, _blän,
  { {0x248d04a3, 0x291d0020, 0x65940256, 0x00000000}},  //   žem_, _ziwa_, _ваку,
  { {0x5a9b0049, 0x61fe07c0, 0x6234030d, 0x00000000}},  //   עשלא, _cypl, сесу,
  { {0x95530426, 0x61fe0036, 0xb05b0c43, 0x00000000}},  //   _اخوا, _dypl, _elän,
  { {0x1ee7007a, 0x2d98213c, 0x7ae3000c, 0x00000000}},  // [51f0] هوری_, _arre_, ynnt,
  { {0xaca30011, 0x32670081, 0xb05b09b0, 0x00000000}},  //   _phỏn, _стив, _glän,
  { {0x9e0712ab, 0x6b890066, 0x00000000, 0x00000000}},  //   учал, _sseg,   ,
  { {0x2007005f, 0x00000000, 0x00000000, 0x00000000}},  //   ənin_,   ,   ,
  { {0x2d980047, 0x90980265, 0x20c7006c, 0x00000000}},  //   _erre_, _свят_, _võid_,
  { {0x27291573, 0x6b890059, 0x00000000, 0x00000000}},  //   _rún_, _vseg,   ,
  { {0x6115010a, 0x20c7010e, 0x291d00b4, 0x00000000}},  //   _sąly, _tõid_, _piwa_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6a6702fd, 0x2903001e, 0x7e9b001e, 0x00000000}},  //   _مطال, ēja_, _tāpē,
  { {0x81bb0044, 0x681b0089, 0x65611824, 0x00000000}},  //   _আইন_, _rādī, tulh,
  { {0x27e0000c, 0x291d0f65, 0x81c30089, 0x00000000}},  //   _þinn_, _tiwa_, šēji,
  { {0x65610181, 0xb05b0039, 0x00000000, 0x00000000}},  //   rulh, _slän,   ,
  { {0xf74500da, 0xb05b01a2, 0x2aab0374, 0x00000000}},  //   _тело, _plän, _søby_,
  { {0x61fe11de, 0x00000000, 0x00000000, 0x00000000}},  //   _pypl,   ,   ,
  { {0xa3e20316, 0x61460478, 0xe2970143, 0x00000000}},  //   _दशक_, реба, јас_,
  { {0x92d60055, 0x61fe0428, 0x91e30088, 0x00000000}},  //   িকে_, _vypl, іоте,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [5200]   ,   ,   ,
  { {0xee3720b5, 0x00000000, 0x00000000, 0x00000000}},  //   ину_,   ,   ,
  { {0x720602fd, 0x5d6a007c, 0x3f990026, 0x00000000}},  //   _خودم, тием_, _ersu_,
  { {0x3f8b01c3, 0x00000000, 0x00000000, 0x00000000}},  //   _fscu_,   ,   ,
  { {0x9abc002b, 0x60c30035, 0x92e80044, 0x00000000}},  //   _liċe, _înma, বতী_,
  { {0xd9540a4f, 0x27e00006, 0x00000000, 0x00000000}},  //   منتخ, _žino_,   ,
  { {0x27e00035, 0x8c460072, 0x2d98213d, 0x00000000}},  //   _ţin_, _вебе, _urre_,
  { {0xfce60437, 0xf4c10044, 0x7c2d004a, 0x00000000}},  //   _тобо, _উদ্ব, ñart,
  { {0xc6a600ed, 0x7d02021f, 0xab2a0256, 0x00000000}},  //   арни, mlos, _роза_,
  { {0x6d5e0692, 0x00000000, 0x00000000, 0x00000000}},  //   orpa,   ,   ,
  { {0x7aed00f4, 0x7d02213e, 0x3ce60087, 0x00000000}},  //   éate, olos, onov_,
  { {0x7d02010f, 0x9abc002b, 0x66c4000a, 0x00000000}},  //   nlos, _diċe, _dòka,
  { {0x44320045, 0xd407213f, 0x00000000, 0x00000000}},  //   _dfy_, ряни,   ,
  { {0x7d02001f, 0x60c600bb, 0xc7d70104, 0x00000000}},  //   hlos, _alkm, _דודי_,
  { {0x8546008b, 0x7d022140, 0x2d85004a, 0x00000000}},  //   _тэле, klos, _álex_,
  { {0x30a400ed, 0x7d02016c, 0x63a218c5, 0x00000000}},  //   орув, jlos, _šone,
  { {0x7d020471, 0x3ce60059, 0x6d580f6c, 0x00000000}},  // [5210] dlos, dnov_, ávan,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x20c70004, 0x63bd2141, 0x78a21fed, 0x00000000}},  //   _võib_, lysn, _onov,
  { {0xf3ff00c4, 0x61fb1a6f, 0xb05b00f8, 0x00000000}},  //   ngão_, ğuld, _kläm,
  { {0x307a007b, 0x2a6c012d, 0x799a0133, 0x00000000}},  //   _גארנ, _bcdb_, _artw,
  { {0x78a21ee1, 0x3ce60087, 0xe8e00082, 0x00000000}},  //   _anov, anov_, ướt_,
  { {0x6ca70441, 0xfc67005e, 0x7d02014a, 0x00000000}},  //   _краж, _възн, blos,
  { {0x9abc01d5, 0x7d0212a0, 0xb05b00f8, 0x00000000}},  //   _riċe, clos, _oläm,
  { {0xcb34005e, 0x6c6a00a1, 0xf09f0082, 0x00000000}},  //   _метъ, _حلقہ_, _chài_,
  { {0x78a218e1, 0x38b811ea, 0x6b9b0032, 0x00000000}},  //   _enov, _sért_, _irug,
  { {0x8afa0049, 0x00000000, 0x00000000, 0x00000000}},  //   _עפעק,   ,   ,
  { {0x6b9b0213, 0x3915007c, 0xe799002c, 0x00000000}},  //   _krug, _умер, _مختص_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x78a211b0, 0x673b0052, 0x232700d7, 0x00000000}},  //   _znov, mpuj, сори_,
  { {0xb05b021e, 0x7d020197, 0x3ce62142, 0x00000000}},  //   _eläm, ylos, ynov_,
  { {0x2571009f, 0x92e80044, 0xb05b0210, 0x00000000}},  //   mál_, বতে_, _fläm,
  { {0x543b007b, 0x8fa3007c, 0x4fa3005e, 0x00000000}},  // [5220] _געפא, пате, питв,
  { {0x52860054, 0x6d5e0091, 0x00000000, 0x00000000}},  //   _الدك, trpa,   ,
  { {0x257113a5, 0x7d020166, 0x3ce600b9, 0x00000000}},  //   nál_, tlos, tnov_,
  { {0x6b9b05ec, 0xab2a004c, 0x6d5e2143, 0x00000000}},  //   _brug, года_, rrpa,
  { {0x7d020007, 0x3ce6013e, 0x2bd20164, 0x00000000}},  //   rlos, rnov_, _देखा,
  { {0x6b9b0490, 0x7d020161, 0x78a20ecc, 0x00000000}},  //   _drug, slos, _snov,
  { {0xf41f0210, 0x6b9b00f6, 0x00000000, 0x00000000}},  //   ndär_, _erug,   ,
  { {0x6b9b0030, 0x4734003b, 0x00000000, 0x00000000}},  //   _frug, онис,   ,
  { {0x6b9b01f4, 0x3198000a, 0x00000000, 0x00000000}},  //   _grug, _lčz_,   ,
  { {0x8c3d005d, 0x7e7c000a, 0x00000000, 0x00000000}},  //   _inşa, _jbrp,   ,
  { {0x7c2d016c, 0xf76f0014, 0xb7d800a1, 0x00000000}},  //   žare, وای_, _ھوتا_,
  { {0x241901ab, 0x68eb0288, 0x00000000, 0x00000000}},  //   ионы_, _gjgd,   ,
  { {0x691513a1, 0x38cb00a2, 0x2f0f01a2, 0x00000000}},  //   _všet, _حالی_, lüge_,
  { {0x7ae40051, 0x29040f2e, 0xa49b00f6, 0x00000000}},  //   éith, llma_, clòn,
  { {0x26de01ca, 0x225f014a, 0x6d580d7f, 0x00000000}},  //   mito_, ğuk_, ával,
  { {0x764a018e, 0x26de0207, 0x69150161, 0x00000000}},  //   _hefy, lito_, _ušet,
  { {0x644f2144, 0x6d58001e, 0x29040cfc, 0x00000000}},  // [5230] maci, šval, ilma_,
  { {0x644f0845, 0x6b9b008d, 0xdddc0006, 0x00000000}},  //   laci, _rrug, _darž,
  { {0x6287008e, 0x60c30035, 0x6b9b012d, 0x00000000}},  //   mejo, _înmo, _srug,
  { {0xe9a9007a, 0xd5fb007b, 0x62870871, 0x00000000}},  //   یگان_, נפאר, lejo,
  { {0x26de0d94, 0x60cd0051, 0x61ef0082, 0x00000000}},  //   kito_, mham, ânlư,
  { {0x60cd0181, 0x8f341020, 0x26de0fa4, 0x00000000}},  //   lham, _херц, jito_,
  { {0x644f01d9, 0x26de0207, 0x00000000, 0x00000000}},  //   kaci, dito_,   ,
  { {0x644f2145, 0x60cd1cd6, 0x6b9b0056, 0x00000000}},  //   jaci, nham, _trug,
  { {0x644f2146, 0x6b9b0211, 0x26de002b, 0x00000000}},  //   daci, _urug, fito_,
  { {0x2571139d, 0x60cd0146, 0x00000000, 0x00000000}},  //   tál_, hham,   ,
  { {0x644f0d46, 0x34aa01fc, 0x764a2147, 0x00000000}},  //   faci, авно_, _defy,
  { {0x644f0c1f, 0x673b00b0, 0x62950089, 0x00000000}},  //   gaci, ppuj, edzo,
  { {0x26de0198, 0x60cd0020, 0x98f401f7, 0x00000000}},  //   bito_, dham, _عثما,
  { {0x68fb00b0, 0x68e90c73, 0xb05b0039, 0x00000000}},  //   loud, lned, _fläk,
  { {0x644f2148, 0x7641007f, 0xdd1c01ca, 0x00000000}},  //   baci, mbly, vážn,
  { {0x644f2149, 0x3366058e, 0x60cd0b57, 0x00000000}},  //   caci, _двиг, gham,
  { {0x6723016c, 0x2f0f01a2, 0x62871472, 0x00000000}},  // [5240] _kinj, züge_, bejo,
  { {0x68fb017c, 0x67230066, 0xdddc0006, 0x00000000}},  //   houd, _jinj, _varž,
  { {0xc27b0476, 0x527b0104, 0x2d9c0d7a, 0x00000000}},  //   _דריי, _דניא, íve_,
  { {0x60cd000b, 0x26de0c33, 0x672302c0, 0x00000000}},  //   cham, zito_, _linj,
  { {0x26de0e7f, 0x60c40416, 0x6603214a, 0x00000000}},  //   yito_, mkim, _lynk,
  { {0x60c400b0, 0x539b0104, 0x26de04f3, 0x00000000}},  //   lkim, יינו, xito_,
  { {0x26de016e, 0x765c0036, 0x7c2f0b41, 0x00000000}},  //   vito_, órym, _širš,
  { {0x764a018e, 0x644f00d4, 0x60c4010a, 0x00000000}},  //   _sefy, xaci, nkim,
  { {0x26de0211, 0xb05b0039, 0x6723214b, 0x00000000}},  //   tito_, _släk, _binj,
  { {0x672305fa, 0x60c41256, 0xddde001a, 0x00000000}},  //   _cinj, hkim, cepţ,
  { {0x644f0682, 0x672301d5, 0x6287214c, 0x00000000}},  //   taci, _dinj, vejo,
  { {0x26de00d6, 0x69d30061, 0x26cc0065, 0x00000000}},  //   sito_, _भेटी, shdo_,
  { {0x26de08a6, 0x6d580161, 0x672300ea, 0x00000000}},  //   pito_, ávaj, _finj,
  { {0x25470047, 0xe572031d, 0x644f15e5, 0x00000000}},  //   ből_, _قطع_, saci,
  { {0x644f201e, 0x60cd0020, 0x6295214d, 0x00000000}},  //   paci, tham, rdzo,
  { {0x62870181, 0x22b401df, 0x68e0026d, 0x00000000}},  //   sejo, _aşkı_, nimd,
  { {0x3eb81f82, 0x44290004, 0x60cd01a3, 0x00000000}},  // [5250] _bort_, _iga_, rham,
  { {0xdd9b012b, 0x60cd000b, 0x67231864, 0x00000000}},  //   ише_, sham, _xinj,
  { {0x68e9018e, 0x3eb8001f, 0x44291372, 0x00000000}},  //   yned, _dort_, _kga_,
  { {0x4429008a, 0x00000000, 0x00000000, 0x00000000}},  //   _jga_,   ,   ,
  { {0x4429084e, 0x65680020, 0x644d0051, 0x00000000}},  //   _mga_, hudh, _meai,
  { {0xda7b081e, 0x68fb214e, 0x65680162, 0x00000000}},  //   ряд_, woud, kudh,
  { {0xceb2007b, 0x6994007e, 0x67230065, 0x00000000}},  //   _אים_, дрых, _rinj,
  { {0x4429214f, 0x67232150, 0xa3cb02d2, 0x00000000}},  //   _nga_, _sinj, लना_,
  { {0x7641018e, 0x68e90030, 0x68fb00b5, 0x00000000}},  //   tbly, rned, roud,
  { {0x44290004, 0x25470047, 0x68e900bb, 0x00000000}},  //   _aga_, től_, sned,
  { {0x67230089, 0x76412151, 0xe5a5003b, 0x00000000}},  //   _vinj, rbly, чини,
  { {0x25470047, 0x81e90044, 0x644d2152, 0x00000000}},  //   ről_, _বরং_, _ceai,
  { {0x6723008a, 0x6603052b, 0x00000000, 0x00000000}},  //   _tinj, _wynk,   ,
  { {0xf675007b, 0x386d02cc, 0x44292153, 0x00000000}},  //   _זײַט_, lger_, _ega_,
  { {0x2f140901, 0x60c4021e, 0x20c7006c, 0x00000000}},  //   lägg_, tkim, _võin_,
  { {0x386d02cc, 0xf99200bd, 0x55ba00b6, 0x00000000}},  //   nger_, ערן_, _למצו,
  { {0x60c42154, 0x3eb8032c, 0x386d059b, 0x00000000}},  // [5260] rkim, _port_, iger_,
  { {0x7c29022b, 0xd00f0025, 0x60c4044e, 0x00000000}},  //   _ager, الك_, skim,
  { {0x3eb80190, 0x3f8f000c, 0x68e00276, 0x00000000}},  //   _vort_, ægur_, yimd,
  { {0x3eb8010f, 0xf5360049, 0x386d00bb, 0x00000000}},  //   _wort_, לטער_, jger_,
  { {0x3eb801eb, 0x6e3b014a, 0x386d0aa4, 0x00000000}},  //   _tort_, _şube, dger_,
  { {0x386d07eb, 0x7c290010, 0x3eab01d5, 0x00000000}},  //   eger_, _eger, ċità_,
  { {0x24800107, 0x68e001df, 0x26dc01c3, 0x00000000}},  //   _obim_, timd, _rmvo_,
  { {0x386d00eb, 0x63a20066, 0x00000000, 0x00000000}},  //   gger_, _ġonn,   ,
  { {0x644d0181, 0x7b09000c, 0x68e0005d, 0x00000000}},  //   _reai, ðstö, rimd,
  { {0x692a101c, 0x68e02155, 0x644d0048, 0x00000000}},  //   _před, simd, _seai,
  { {0x44290193, 0xceb300b6, 0x6aa80030, 0x00000000}},  //   _pga_, תית_, _indf,
  { {0x6aba0051, 0xc9850025, 0x65680023, 0x00000000}},  //   _hotf, _تشكي, rudh,
  { {0x46a61227, 0x44290011, 0x28a9006e, 0x00000000}},  //   _надв, _vga_, कारि,
  { {0x44290bca, 0x97130245, 0x60dd00d2, 0x00000000}},  //   _wga_, _зміц, _smsm,
  { {0x44290058, 0x27320011, 0x867b009b, 0x00000000}},  //   _tga_, _hân_, _הרוו,
  { {0x44290729, 0x116a0014, 0x00000000, 0x00000000}},  //   _uga_, تلفی_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [5270]   ,   ,   ,
  { {0x6aba2156, 0x27320031, 0x386d00d9, 0x00000000}},  //   _notf, _mân_, zger_,
  { {0x386d0039, 0x2732130d, 0x5c75007e, 0x00000000}},  //   yger_, _lân_, длет,
  { {0xd01000a1, 0x6aa81fbc, 0x00000000, 0x00000000}},  //   ئلے_, _andf,   ,
  { {0x05de007d, 0x7aed009d, 0xa09a009b, 0x00000000}},  //   _फेसब, éato, _וירט,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x386d2157, 0x62970387, 0x7c290066, 0x00000000}},  //   tger_, _maxo, _tger,
  { {0x7c292158, 0xbca50439, 0xb05b00b0, 0x00000000}},  //   _uger, _تمري, _eläv,
  { {0x27322159, 0xcd020036, 0x63a20066, 0x00000000}},  //   _cân_, _dość_, _ġono,
  { {0x2732001d, 0x05750054, 0x62970197, 0x00000000}},  //   _dân_, واجد, _naxo,
  { {0x7ae31082, 0x386d00f8, 0x00000000, 0x00000000}},  //   mint, pger_,   ,
  { {0x7ae31082, 0xcd020046, 0x69c30016, 0x00000000}},  //   lint, _gość_, myne,
  { {0x1e0a02d2, 0x7e0a0316, 0x69c30010, 0x00000000}},  //   _वर्ष_, _वर्ग_, lyne,
  { {0x7ae30006, 0x069300a1, 0x629706c2, 0x00000000}},  //   nint, _ساتھ, _caxo,
  { {0xb0c901f5, 0xdb26006b, 0x00000000, 0x00000000}},  //   रसंग, şqçi,   ,
  { {0x7ae30176, 0x9fca00e2, 0x00000000, 0x00000000}},  //   hint, огба_,   ,
  { {0x7ae30047, 0xd007017f, 0x31780036, 0x00000000}},  // [5280] kint, дете_, strz_,
  { {0x9d4601e0, 0x7ae30006, 0x69c3215a, 0x00000000}},  //   дежд, jint, kyne,
  { {0x7ae30713, 0x6aba00f8, 0x00000000, 0x00000000}},  //   dint, _rotf,   ,
  { {0x69c30036, 0x7c83007c, 0x04040044, 0x00000000}},  //   dyne, вуше, রেণী_,
  { {0xe7e80055, 0x6d67010a, 0x7ae30039, 0x00000000}},  //   _পর্য, _įraš, fint,
  { {0x7ae3215b, 0x6d57006b, 0x7bc2007f, 0x00000000}},  //   gint, bsxa, ryou,
  { {0x2732001d, 0x7bc21cdc, 0x00000000, 0x00000000}},  //   _sân_, syou,   ,
  { {0x7bc2000a, 0xcc872015, 0x692a00b9, 0x00000000}},  //   pyou, _обсе_, _přeb,
  { {0x7ae31e4a, 0x692a00b9, 0xb05b01a2, 0x00000000}},  //   bint, _břec, _gläu,
  { {0x2732001d, 0xcaa6006d, 0x00000000, 0x00000000}},  //   _vân_, _تصري,   ,
  { {0x27e9009f, 0xb05b0039, 0x62970032, 0x00000000}},  //   _þann_, _klät, _raxo,
  { {0x2732215c, 0x692a0224, 0x2246016c, 0x00000000}},  //   _tân_, _třeb, _đoka_,
  { {0xd91b012f, 0x00000000, 0x00000000, 0x00000000}},  //   _וואל,   ,   ,
  { {0x05760d3a, 0x20c7010e, 0x00000000, 0x00000000}},  //   _قاعد, _võim_,   ,
  { {0xdb000065, 0x41e40245, 0x26ce000a, 0x00000000}},  //   _armë, віта, _ilfo_,
  { {0x7ae3000d, 0x00000000, 0x00000000, 0x00000000}},  //   zint,   ,   ,
  { {0x7ae30010, 0x00000000, 0x00000000, 0x00000000}},  // [5290] yint,   ,   ,
  { {0x20c70004, 0x44390010, 0x7ae30288, 0x00000000}},  //   _kõik_, lcs_, xint,
  { {0x7ae316c7, 0x25780047, 0xb05b010f, 0x00000000}},  //   vint, nél_, _blät,
  { {0x7ae30fd5, 0x213e0051, 0x4439215d, 0x00000000}},  //   wint, íthe_, ncs_,
  { {0x60d6019b, 0x7ae30006, 0x443900d4, 0x00000000}},  //   _נושא_, tint, ics_,
  { {0xdb250010, 0x69c3042c, 0x49951023, 0x00000000}},  //   _épül, tyne, ешит,
  { {0x7ae30390, 0x64460036, 0x9f040025, 0x00000000}},  //   rint, ybki, _شوفو,
  { {0x7ae3215e, 0x2f14001f, 0x69c3215f, 0x00000000}},  //   sint, räge_, ryne,
  { {0x7ae30006, 0x692a00b9, 0x69c3113b, 0x00000000}},  //   pint, _přec, syne,
  { {0xcf920104, 0x657a0173, 0xb659007c, 0x00000000}},  //   נטי_, ftth, чших_,
  { {0xa50a0780, 0x4aac0204, 0x00000000, 0x00000000}},  //   зена_, चारव,   ,
  { {0x92bc0055, 0xcdda0049, 0xdb0000f6, 0x00000000}},  //   _আগে_, פֿיר, _armè,
  { {0x61fb014a, 0x78ab06a1, 0x692a00b9, 0x00000000}},  //   şull, _ingv, _třec,
  { {0x387f000c, 0x60cf01f3, 0xf6790049, 0x00000000}},  //   lfur_, _alcm, _זאַמ,
  { {0xd1320426, 0x7c3b000c, 0x00000000, 0x00000000}},  //   امر_, _ofur,   ,
  { {0xa2c10204, 0x602600ed, 0x44390232, 0x00000000}},  //   रॉब्, едба, ccs_,
  { {0xd00f0054, 0x6e3b014a, 0x6fd60088, 0x00000000}},  // [52a0] ملف_, _şuba, хівц,
  { {0x7c3b2160, 0x63a40937, 0x4df6007c, 0x00000000}},  //   _afur, _irin, няет,
  { {0x628e0857, 0x63a4009f, 0xb05b010f, 0x00000000}},  //   mebo, _hrin, _plät,
  { {0x628e0a2e, 0x63a42161, 0x629c02f1, 0x00000000}},  //   lebo, _krin, ldro,
  { {0xaaac01f5, 0x00000000, 0x00000000, 0x00000000}},  //   चालक,   ,   ,
  { {0x629c2162, 0xb05b0b75, 0x7d0b010e, 0x00000000}},  //   ndro, _fläs, algs,
  { {0x7c3b0016, 0x629c2163, 0x9c830bf8, 0x00000000}},  //   _ffur, idro, ščar,
  { {0x2578134d, 0x63a4157e, 0xf1b3009b, 0x00000000}},  //   vél_, _orin, רסה_,
  { {0xb05b01a2, 0x63a400e0, 0x628e0322, 0x00000000}},  //   _klär, _nrin, kebo,
  { {0x7d02109a, 0x628e2164, 0x78ab2165, 0x00000000}},  //   loos, jebo, _engv,
  { {0x63a4002d, 0x628e06da, 0x629c0ee6, 0x00000000}},  //   _arin, debo, ddro,
  { {0x443902d0, 0x629c02ab, 0x7d02044e, 0x00000000}},  //   ucs_, edro, noos,
  { {0x44390129, 0x63a40035, 0xdb002166, 0x00000000}},  //   rcs_, _crin, _armé,
  { {0x628e001f, 0x69a40309, 0x6d5c2167, 0x00000000}},  //   gebo, किपी, _ovra,
  { {0x63a40004, 0x30a7007c, 0x44390232, 0x00000000}},  //   _erin, нрав, pcs_,
  { {0x629c1904, 0x69d80213, 0x00000000, 0x00000000}},  //   adro, izve,   ,
  { {0x2906000b, 0x6d5c0207, 0xe31500ed, 0x00000000}},  // [52b0] _mkoa_, _avra, _имињ,
  { {0xdef803c8, 0x798801c3, 0x7c3b0066, 0x00000000}},  //   ных_, _opdw, _sfur,
  { {0x2d872168, 0xf6530049, 0x63a4016e, 0x00000000}},  //   ïne_, רצע_, _zrin,
  { {0x69d82169, 0x00000000, 0x00000000, 0x00000000}},  //   dzve,   ,   ,
  { {0x6d5c014a, 0x00000000, 0x00000000, 0x00000000}},  //   _evra,   ,   ,
  { {0x68e2018e, 0xda62007c, 0x212b0022, 0x00000000}},  //   _amod, авши, _hich_,
  { {0xdef4216a, 0x212b216b, 0x69ce01a2, 0x00000000}},  //   _спры, _kich_, _übel,
  { {0x629c0036, 0x628e0036, 0x212b00b9, 0x00000000}},  //   zdro, zebo, _jich_,
  { {0x212b001f, 0x387f19bd, 0x629c0b78, 0x00000000}},  //   _mich_, rfur_, ydro,
  { {0x2cad01ca, 0x212b0011, 0x2cbf00b5, 0x00000000}},  //   _hned_, _lich_, _houd_,
  { {0xb9b50447, 0x628e01e3, 0x2cbf216c, 0x00000000}},  //   _جماع, vebo, _koud_,
  { {0x212b1712, 0x6285010f, 0x32cf014a, 0x00000000}},  //   _nich_, _abho, _rüya_,
  { {0x7565026c, 0x65680168, 0x62850026, 0x00000000}},  //   ریکہ_, ardh, _bbho,
  { {0x63a401d6, 0xa24800a1, 0x6b890203, 0x00000000}},  //   _vrin, ڈیکل_, _mpeg,
  { {0x232700d7, 0x628e216d, 0x212b0082, 0x00000000}},  //   тори_, rebo, _bich_,
  { {0x628e05d5, 0x55f6009b, 0x7c2d00ca, 0x00000000}},  //   sebo, _במצב_, žarj,
  { {0x6d5c037e, 0x212b216e, 0x6e3b0107, 0x00000000}},  // [52c0] _svra, _dich_, _đubr,
  { {0x212b0bc4, 0x7f440065, 0xa1c6007e, 0x00000000}},  //   _eich_, rpiq, _абод,
  { {0x6b890b33, 0x212b0173, 0x7d020ac2, 0x00000000}},  //   _apeg, _fich_, toos,
  { {0x0b8a06e1, 0xcb6a0a94, 0xbb46007e, 0x00000000}},  //   дски_, даде_, ведк,
  { {0x6bd606b4, 0x2bb70061, 0x290d0035, 0x00000000}},  //   ختار, _आपणा, dlea_,
  { {0x212b02ae, 0xdd9200a6, 0x6e4300ec, 0x00000000}},  //   _zich_, _پور_, _верз,
  { {0x610c010f, 0xd91a007c, 0x7d020052, 0x00000000}},  //   eßli, мьи_, poos,
  { {0x2cbf216f, 0x5886007e, 0x0798003b, 0x00000000}},  //   _goud_, тыка, евић_,
  { {0x6c7b007b, 0x00000000, 0x00000000, 0x00000000}},  //   _קאמפ,   ,   ,
  { {0x2b460129, 0x291f0020, 0x68e20009, 0x00000000}},  //   mpoc_, amua_, _wmod,
  { {0xd5b701fb, 0x290d2170, 0x22582171, 0x00000000}},  //   вся_, blea_, dark_,
  { {0x290d060c, 0x77ca041f, 0x68e20146, 0x00000000}},  //   clea_, _олег_, _umod,
  { {0x212b2172, 0x29040e0d, 0x212000ca, 0x00000000}},  //   _rich_, moma_, dmih_,
  { {0x212b08ba, 0x29040059, 0x66e300ed, 0x00000000}},  //   _sich_, loma_, _коча,
  { {0x7aed028c, 0x31c4078d, 0x212b1b43, 0x00000000}},  //   éati, аств, _pich_,
  { {0x2904010a, 0xe4d90014, 0x2f140894, 0x00000000}},  //   noma_, _سوخت_, väga_,
  { {0x212b00f6, 0x30150140, 0x00000000, 0x00000000}},  // [52d0] _vich_, удар,   ,
  { {0x2cbf00b9, 0x290d002d, 0x29040339, 0x00000000}},  //   _soud_, zlea_, homa_,
  { {0xa3e7001c, 0x29040006, 0x6e9400ed, 0x00000000}},  //   _येत_, koma_, риху,
  { {0x0ce10055, 0x60d62173, 0x290401c5, 0x00000000}},  //   যক্ত, chym, joma_,
  { {0x29042174, 0xfbd00379, 0x692a00b9, 0x00000000}},  //   doma_, يته_, _přen,
  { {0x499901e0, 0x3f99009d, 0x2cbf040f, 0x00000000}},  //   етия_, _issu_, _woud_,
  { {0x49bb007a, 0x6d58007f, 0xc8790279, 0x00000000}},  //   باشد_, švar, lişi_,
  { {0x60cd010a, 0x29040020, 0x2cad0016, 0x00000000}},  //   nkam, goma_, _uned_,
  { {0x2fc92175, 0x290d1424, 0x291f0023, 0x00000000}},  //   nyag_, rlea_, rmua_,
  { {0x60cd0127, 0x290d002d, 0x77690032, 0x00000000}},  //   hkam, slea_, rrex,
  { {0x7d1b0149, 0x60cd0961, 0xf875023c, 0x00000000}},  //   _khus, kkam, _مهاج,
  { {0xc32900b6, 0xaca30082, 0x60cd0091, 0x00000000}},  //   _זו_, _khốn, jkam,
  { {0x7d0913e1, 0x225803e1, 0x7d1b2176, 0x00000000}},  //   _mkes, tark_, _mhus,
  { {0x68e9001f, 0xb05b0039, 0xe6890025, 0x00000000}},  //   lied, _släp, _أنثى_,
  { {0x60d61241, 0x7d1b006c, 0x60cd0168, 0x00000000}},  //   thym, _ohus, fkam,
  { {0x68e91031, 0x60cd011c, 0x7d090045, 0x00000000}},  //   nied, gkam, _nkes,
  { {0xef1a012b, 0x212008f0, 0x10a30242, 0x00000000}},  // [52e0] ема_, rmih_, щитн,
  { {0x68e9111d, 0x539b00b6, 0x93b700b6, 0x00000000}},  //   hied, _טיפו, _עליו_,
  { {0xc27b007b, 0x2904107e, 0x6456014a, 0x00000000}},  //   _אריי, yoma_, _keyi,
  { {0x629e011c, 0x7d1b2177, 0x60cd0253, 0x00000000}},  //   _hapo, _chus, ckam,
  { {0x629e1dbb, 0xaca3001d, 0x78bb2178, 0x00000000}},  //   _kapo, _chốn, djuv,
  { {0x67210ce4, 0x7d0900e0, 0x99850087, 0x00000000}},  //   jmlj, _ekes, _sglš_,
  { {0x68e92179, 0x29040006, 0x4432217a, 0x00000000}},  //   fied, toma_, _ogy_,
  { {0x6d5e002d, 0x26d90023, 0x68e9005b, 0x00000000}},  //   mspa, ëson_, gied,
  { {0x6d5e001c, 0x290401d9, 0x3f80217b, 0x00000000}},  //   lspa, roma_, ntiu_,
  { {0x2904000b, 0xcaa60054, 0x60cd09b6, 0x00000000}},  //   soma_, _حصري, zkam,
  { {0x68e9217c, 0x752d0207, 0x6d5e217d, 0x00000000}},  //   bied, _piaz, nspa,
  { {0x68e9217e, 0x799a0263, 0x2ec1007d, 0x00000000}},  //   cied, _istw, _शक्त,
  { {0x645602b9, 0x60cd0142, 0x752d217f, 0x00000000}},  //   _deyi, vkam, _viaz,
  { {0x44321bc0, 0x629e0207, 0x53340088, 0x00000000}},  //   _egy_, _capo, серт,
  { {0x765a1d6e, 0x629e0093, 0x403500ed, 0x00000000}},  //   maty, _dapo, иевс,
  { {0x64560279, 0x765a014a, 0x60cd007f, 0x00000000}},  //   _geyi, laty, ukam,
  { {0xce6b004c, 0x3e6b00e3, 0x7aea05fe, 0x00000000}},  // [52f0] еред_, ешен_, kift,
  { {0x9e15008b, 0xc87901df, 0x7d1b0020, 0x00000000}},  //   адзі, rişi_, _shus,
  { {0x999e010a, 0x3d9500e3, 0xdd9105f3, 0x00000000}},  //   _metų_, риер, توا_,
  { {0x629e01d9, 0x6456006b, 0x1df5013d, 0x00000000}},  //   _zapo, _xeyi, _आशीष_,
  { {0x3f8004bd, 0xeb992180, 0x629e2181, 0x00000000}},  //   ctiu_, тил_, _yapo,
  { {0x68e90df0, 0x7aea05fe, 0xa96900ed, 0x00000000}},  //   wied, gift, вика_,
  { {0x68e92182, 0x08d501e0, 0x7d090066, 0x00000000}},  //   tied, иция, _tkes,
  { {0xaca3001d, 0x7d1b0020, 0x2d8102d4, 0x00000000}},  //   _thốn, _uhus, mthe_,
  { {0x68e92183, 0x64560263, 0x2d810146, 0x00000000}},  //   ried, _reyi, lthe_,
  { {0xfaf304e8, 0x68e90036, 0x4585003b, 0x00000000}},  //   _اثر_, sied, агов,
  { {0x629e000d, 0x68e92184, 0x2d811250, 0x00000000}},  //   _rapo, pied, nthe_,
  { {0x2d810195, 0x629e0207, 0x03a60242, 0x00000000}},  //   ithe_, _sapo, аимо,
  { {0x629e027b, 0x64562185, 0x81e30044, 0x00000000}},  //   _papo, _veyi, _ফুল_,
  { {0xdb000181, 0x6d5e16e5, 0xe5a5005c, 0x00000000}},  //   _irmã, yspa, _вики,
  { {0x273b2186, 0x7bcb00f6, 0x00000000, 0x00000000}},  //   _hên_, hygu,   ,
  { {0x6d5e2187, 0x629e2188, 0x6b9b012d, 0x00000000}},  //   vspa, _wapo, _osug,
  { {0x629e006a, 0x6d5e0866, 0x4127026b, 0x00000000}},  // [5300] _tapo, wspa, рото_,
  { {0x3f800a01, 0x6d5e1440, 0x20c7010e, 0x00000000}},  //   rtiu_, tspa, _sõit_,
  { {0x273b001d, 0x2d810051, 0x6d5e0052, 0x00000000}},  //   _lên_, gthe_, uspa,
  { {0x692a00b9, 0xeb0e0204, 0x00000000, 0x00000000}},  //   _přem, ित्त_,   ,
  { {0x273b001d, 0x7aea0039, 0x20c7006c, 0x00000000}},  //   _nên_, tift, _võit_,
  { {0x9966013b, 0x6d5e0b38, 0x4ed5007e, 0x00000000}},  //   атил, pspa, _люст,
  { {0x7aea0292, 0xaca3001d, 0x2d810051, 0x00000000}},  //   rift, _chồn, cthe_,
  { {0x273b001d, 0x291d2189, 0x692a218a, 0x00000000}},  //   _bên_, _chwa_, _zřej,
  { {0x69d50047, 0x765a010a, 0xd90d007a, 0x00000000}},  //   _üzen, taty, ریه_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdcfc0bd7, 0x765a0006, 0x248900e0, 0x00000000}},  //   _sprę, raty, _pbam_,
  { {0xf48500a6, 0xdb000035, 0x00000000, 0x00000000}},  //   حادی, _urmâ,   ,
  { {0x765a131c, 0x38660288, 0x00000000, 0x00000000}},  //   paty, _idor_,   ,
  { {0x81e80055, 0x00000000, 0x00000000, 0x00000000}},  //   _বড়_,   ,   ,
  { {0x171b007b, 0xf1a40364, 0x925800ed, 0x00000000}},  //   _שווע, ортн, раст_,
  { {0x273b001d, 0x4034007c, 0x6b820a76, 0x00000000}},  //   _yên_, жетс, ktog,
  { {0x645d010a, 0x692a0224, 0x765800b0, 0x00000000}},  // [5310] masi, _přej, _kevy,
  { {0x427503f4, 0x539c009b, 0xfda7003b, 0x00000000}},  //   _угос, _ייחו, ијем,
  { {0x20070036, 0x62870190, 0xf1a4004d, 0x00000000}},  //   łni_, mfjo, _дрян,
  { {0x645d218b, 0x765800b0, 0x2d81218c, 0x00000000}},  //   nasi, _levy, rthe_,
  { {0x2d8100ea, 0x7ae80022, 0x61fb0180, 0x00000000}},  //   sthe_, _bmdt, ğulu,
  { {0x645d0149, 0x62950211, 0x76580428, 0x00000000}},  //   hasi, nezo, _nevy,
  { {0x49930167, 0xceb20049, 0x2d9c0030, 0x00000000}},  //   تیار, _ציל_, ævet_,
  { {0x645d218d, 0x6b9b0058, 0x39450145, 0x00000000}},  //   jasi, _tsug, _vtls_,
  { {0xa49b0263, 0x6b821de2, 0x645d095c, 0x00000000}},  //   vlòp, ctog, dasi,
  { {0x4ec50044, 0x00000000, 0x00000000, 0x00000000}},  //   _এগুল,   ,   ,
  { {0x645d218e, 0xdb2600d3, 0x09e50044, 0x00000000}},  //   fasi, _اولی, _পুরা,
  { {0x645d218f, 0x6aa10168, 0x273b001d, 0x00000000}},  //   gasi, _half, _tên_,
  { {0x6aa106af, 0xb05b0039, 0x39812190, 0x00000000}},  //   _kalf, _poän, lós_,
  { {0x629507eb, 0x8c1a00b6, 0x6d470022, 0x00000000}},  //   gezo, טורי, _otja,
  { {0x6aa101aa, 0xf8db03d7, 0x3981042f, 0x00000000}},  //   _malf, _बताय, nós_,
  { {0x645d06e2, 0xaca30011, 0xc0e315c4, 0x00000000}},  //   casi, _khổn, поск,
  { {0x6295054e, 0x6d47001e, 0xdb0900b5, 0x00000000}},  // [5320] bezo, _atja, _creë,
  { {0x692a0224, 0xe45f000c, 0xe29a00aa, 0x00000000}},  //   _přek, gjöf_, _сао_,
  { {0x0d86012b, 0x3981000c, 0x6b820544, 0x00000000}},  //   слен, jós_, wtog,
  { {0x6b822191, 0xdd8f0647, 0x26d90023, 0x00000000}},  //   ttog, عون_, ësoj_,
  { {0xdb0007e4, 0x8c3d014a, 0x6b740088, 0x00000000}},  //   _armá, _başb, ілку,
  { {0x645d006b, 0x39a70011, 0x2d9c0030, 0x00000000}},  //   zasi, _bđs_, æves_,
  { {0x6b820006, 0x645d006b, 0xdca60216, 0x00000000}},  //   stog, yasi, _лави,
  { {0x1d0a012b, 0x6b8200c4, 0x62952192, 0x00000000}},  //   _себи_, ptog, zezo,
  { {0x645d2193, 0xbb8b009e, 0x00000000, 0x00000000}},  //   vasi, _محلے_,   ,
  { {0x645d000b, 0x6aa10a18, 0x39811715, 0x00000000}},  //   wasi, _galf, bós_,
  { {0x645d0004, 0x62950059, 0x39811374, 0x00000000}},  //   tasi, vezo, cós_,
  { {0xf79a039d, 0xa9262194, 0x00000000, 0x00000000}},  //   _منصب_, _удел,   ,
  { {0x645d2195, 0x629504eb, 0x00000000, 0x00000000}},  //   rasi, tezo,   ,
  { {0xadfa006e, 0x80db0061, 0x2f0f01a2, 0x00000000}},  //   ्थान_, नसभे, nügt_,
  { {0x62952004, 0x645d0f42, 0x692a0224, 0x00000000}},  //   rezo, pasi, _přeh,
  { {0x957c0046, 0x3ddf0044, 0x316c0027, 0x00000000}},  //   rząd, _বুঝল, ádza_,
  { {0x78a20020, 0x6d4703b4, 0xcf270025, 0x00000000}},  // [5330] _maov, _stja, مرئي,
  { {0x63ad005f, 0xf44800a1, 0xd25100a2, 0x00000000}},  //   _iran, _پلیٹ_, _تند_,
  { {0x4035008b, 0x6aa101c5, 0x00000000, 0x00000000}},  //   _менс, _ralf,   ,
  { {0x63ad1e1c, 0x78a20107, 0x00000000, 0x00000000}},  //   _kran, _naov,   ,
  { {0x2d9c0030, 0x25630279, 0x2f0f010f, 0x00000000}},  //   æver_, zıl_, fügt_,
  { {0x63ad188a, 0x39810010, 0x25630477, 0x00000000}},  //   _mran, tós_, yıl_,
  { {0xfd13031d, 0x6aa10039, 0x2563006b, 0x00000000}},  //   _فجر_, _valf, xıl_,
  { {0x63ad020c, 0x3981060d, 0x69d50010, 0x00000000}},  //   _oran, rós_, _üzem,
  { {0x6aa10090, 0x3ea30087, 0x00000000, 0x00000000}},  //   _talf, _kajt_,   ,
  { {0x7d0b068f, 0x66e50088, 0x46e90088, 0x00000000}},  //   logs, іона, рдон_,
  { {0xceb40104, 0x9abc0066, 0x8c3d00e5, 0x00000000}},  //   ליץ_, _tiċr, _gaşc,
  { {0x81c10055, 0xa50a0072, 0x7d0b00ea, 0x00000000}},  //   ্ছা_, рема_, nogs,
  { {0x2563011f, 0x68eb0009, 0x63ad0531, 0x00000000}},  //   sıl_, _imgd, _cran,
  { {0x63ad00c7, 0x78a20645, 0xe5710445, 0x00000000}},  //   _dran, _zaov, _قطب_,
  { {0x63ad2196, 0xd765026c, 0x33330066, 0x00000000}},  //   _eran, _انڈی, _dixx_,
  { {0x63ad0a8d, 0xddc70036, 0x2f14006c, 0x00000000}},  //   _fran, _wejś, mägi_,
  { {0xa3e70061, 0x80ca01f5, 0x04040044, 0x00000000}},  // [5340] _येऊ_, _रवीं, রেজী_,
  { {0xafdb01e3, 0x26c7007f, 0xd048006b, 0x00000000}},  //   _iføl, _jono_, _əməy,
  { {0xa2a30061, 0x63ad2041, 0x14af0061, 0x00000000}},  //   _छोट्, _zran, _जोडण,
  { {0xa3c10061, 0x2eea0066, 0x00000000, 0x00000000}},  //   ूनच_, _wmbf_,   ,
  { {0x78a20011, 0x7ed60088, 0x69c52197, 0x00000000}},  //   _raov, _дівч, ähen,
  { {0x4402013d, 0xf96a0764, 0x29002198, 0x00000000}},  //   _लखनऊ_, арий_, čiam_,
  { {0xa3e70204, 0x00000000, 0x00000000, 0x00000000}},  //   _येई_,   ,   ,
  { {0x478a0872, 0x1d071376, 0x6cd60025, 0x00000000}},  //   асом_, _деси_, _بقرا,
  { {0x26c7008e, 0xd6d00025, 0x29180089, 0x00000000}},  //   _bono_, فقة_, ēra_,
  { {0x63ad0ea9, 0x26c72199, 0x8574007c, 0x00000000}},  //   _rran, _cono_, плох,
  { {0x957c0036, 0xd6d701fb, 0x26c7219a, 0x00000000}},  //   dząc, іть_, _dono_,
  { {0x63ad16cf, 0xd05f006b, 0x2ca60544, 0x00000000}},  //   _pran, biqə, ndod_,
  { {0x26c7157e, 0x63ad006b, 0x18180014, 0x00000000}},  //   _fono_, _qran, _اراک_,
  { {0x24800023, 0x8c3d026d, 0x00000000, 0x00000000}},  //   _ecim_, _maşa,   ,
  { {0x63ad0016, 0x692a0224, 0x3ea3219b, 0x00000000}},  //   _wran, _dřev, _rajt_,
  { {0x63ad00ad, 0x3ea3219c, 0x00000000, 0x00000000}},  //   _tran, _sajt_,   ,
  { {0x26c70093, 0x7d0b000c, 0x2ca6005b, 0x00000000}},  // [5350] _yono_, vogs, ddod_,
  { {0xddab219d, 0x957c0046, 0x7f4d006b, 0x00000000}},  //   ител_, cząc, rpaq,
  { {0x80c70044, 0x26d90023, 0x00000000, 0x00000000}},  //   রোগ্, ësoi_,   ,
  { {0x8c3d011f, 0x8f350269, 0xd25100a6, 0x00000000}},  //   _başa, _немц, _تنگ_,
  { {0x21290145, 0x7d0b219e, 0x3ea3219f, 0x00000000}},  //   mmah_, rogs, _tajt_,
  { {0x7f3a00b6, 0xdbd8000c, 0x21290145, 0x00000000}},  //   _לעשו, ræða, lmah_,
  { {0x7c970025, 0x00000000, 0x00000000, 0x00000000}},  //   _وشرا,   ,   ,
  { {0x26c705d3, 0x26de00b0, 0x01fc009b, 0x00000000}},  //   _sono_, ehto_, יפול,
  { {0xacda0049, 0xf7710025, 0x26c721a0, 0x00000000}},  //   _פֿלי, راة_, _pono_,
  { {0x212905cd, 0xd05f013f, 0x00000000, 0x00000000}},  //   hmah_, riqə,   ,
  { {0x38350594, 0x212921a1, 0x5afa0049, 0x00000000}},  //   _енер, kmah_, _פלעצ,
  { {0x8c3d01f6, 0x656e0051, 0x64410036, 0x00000000}},  //   _yaşa, ábha, ślin,
  { {0xf74906ea, 0x69ce001f, 0x692a0224, 0x00000000}},  //   _التي_, _über, _přev,
  { {0x26de0428, 0x68fb010e, 0x00000000, 0x00000000}},  //   chto_, lnud,   ,
  { {0x76ba009b, 0x957c00b4, 0x00000000, 0x00000000}},  //   _למספ, rząc,   ,
  { {0x68fb000c, 0xa507005e, 0x2480016c, 0x00000000}},  //   nnud, _неща_, _ucim_,
  { {0x8e3a0257, 0x75240288, 0x2ca401a3, 0x00000000}},  // [5360] مسار_, _ihiz, _ramd_,
  { {0x6fb30025, 0x2ca407c8, 0x3ced00d9, 0x00000000}},  //   عملا, _samd_, _amev_,
  { {0x68fb0190, 0x00000000, 0x00000000, 0x00000000}},  //   knud,   ,   ,
  { {0x64460fed, 0x8c3d21a2, 0x00000000, 0x00000000}},  //   ncki, _paşa,   ,
  { {0x2ca621a3, 0xdb0900d4, 0x3cdd013d, 0x00000000}},  //   rdod_, _creï, _खतरे_,
  { {0x60c40091, 0x05cb013d, 0x442000d9, 0x00000000}},  //   ljim, ाहाब, _mzi_,
  { {0xd9100123, 0x75240032, 0x61ba0061, 0x00000000}},  //   پیش_, _ohiz, _उपोष,
  { {0x60c40213, 0x60d60ecb, 0x57b4173a, 0x00000000}},  //   njim, nkym, дбит,
  { {0x442021a4, 0x3eb80022, 0x00000000, 0x00000000}},  //   _nzi_, _knrt_,   ,
  { {0xfa6702d3, 0x64460036, 0x75241f34, 0x00000000}},  //   _наук_, ecki, _ahiz,
  { {0x4420001a, 0xceb3009b, 0xd5ae00a1, 0x00000000}},  //   _azi_, גית_, اہب_,
  { {0x26de003b, 0x48e3017f, 0x493b00a0, 0x00000000}},  //   shto_, _похв, _הגאו,
  { {0x60c40107, 0xa81a00a1, 0x00000000, 0x00000000}},  //   djim, _اتار_,   ,
  { {0xa195007e, 0x7524002d, 0x236d0059, 0x00000000}},  //   магч, _ehiz, šejo_,
  { {0x44200095, 0x26dc00d9, 0x2f14010e, 0x00000000}},  //   _ezi_, _ilvo_, nägu_,
  { {0xd5fb00b6, 0x60c40065, 0x657a0145, 0x00000000}},  //   _לפור, gjim, muth,
  { {0x212921a5, 0x657a154f, 0x00000000, 0x00000000}},  // [5370] rmah_, luth,   ,
  { {0x692a218a, 0x3f1421a6, 0x290d0020, 0x00000000}},  //   _křes, едус, zoea_,
  { {0x645f0065, 0x657a0203, 0x00000000, 0x00000000}},  //   _keqi, nuth,   ,
  { {0x645f0066, 0x60d60253, 0x00000000, 0x00000000}},  //   _jeqi, ckym,   ,
  { {0xfaa500ed, 0x6f02009d, 0x0b440088, 0x00000000}},  //   дало, éocc, енін,
  { {0x4fd6009b, 0x657a00e7, 0x00000000, 0x00000000}},  //   _חושב_, kuth,   ,
  { {0x3f890c0e, 0xdd94007e, 0x644621a7, 0x00000000}},  //   ltau_, _пары, ycki,
  { {0x23690119, 0x26dc0181, 0x00000000, 0x00000000}},  //   _ovaj_, _alvo_,   ,
  { {0x68fb0089, 0x3f8901a3, 0x66e5004d, 0x00000000}},  //   rnud, ntau_, допа,
  { {0x68fb1526, 0x60c4016c, 0x2b4d00fa, 0x00000000}},  //   snud, zjim, _itec_,
  { {0xf7710167, 0x23690521, 0x692a00b9, 0x00000000}},  //   راک_, _avaj_, _přet,
  { {0xf9900025, 0x661d00b9, 0x00000000, 0x00000000}},  //   _حبك_, řsko,   ,
  { {0x366902e9, 0x94d3007e, 0x78a901c5, 0x00000000}},  //   _дало_, тоўц, mdev,
  { {0xc72401fb, 0x78a9018d, 0xe8e00011, 0x00000000}},  //   _здій, ldev, ượt_,
  { {0x692a00b9, 0x7c3b16bf, 0x60c40925, 0x00000000}},  //   _třet, _ogur, tjim,
  { {0x387f009f, 0x78a90065, 0x6ee00a35, 0x00000000}},  //   ngur_, ndev, _möbe,
  { {0x3f89003b, 0x60d60006, 0x442021a8, 0x00000000}},  // [5380] gtau_, rkym, _uzi_,
  { {0x63a4006a, 0x2900010a, 0x7c3b002d, 0x00000000}},  //   _isin, čiai_, _agur,
  { {0xdb09008e, 0xc0e6007e, 0x6ee0014a, 0x00000000}},  //   _creí, _жонк, _nöbe,
  { {0xdb000010, 0x628e21a9, 0x63a400e0, 0x00000000}},  //   _ismé, lfbo, _ksin,
  { {0xab9a0167, 0xbb4300ed, 0x3f890016, 0x00000000}},  //   تخار_, вечк, ctau_,
  { {0x629c0142, 0x63a4000b, 0xed5a21aa, 0x00000000}},  //   nero, _msin, _мог_,
  { {0x78a9040f, 0x60dd0009, 0x7c3b0066, 0x00000000}},  //   fdev, _ylsm, _fgur,
  { {0x2b58026c, 0x63a421ab, 0x387f21ac, 0x00000000}},  //   _فیصد_, _osin, ggur_,
  { {0x63a40d33, 0x00000000, 0x00000000, 0x00000000}},  //   _nsin,   ,   ,
  { {0x629c19da, 0x692a0224, 0x66cd0027, 0x00000000}},  //   jero, _přes, _súkr,
  { {0x629c21ad, 0x9e7700b6, 0x63a4033b, 0x00000000}},  //   dero, וגיה_, _asin,
  { {0x657a002a, 0x6aa8005b, 0x00000000, 0x00000000}},  //   ruth, _hadf,   ,
  { {0x629c21ae, 0x63a40047, 0x2b4d00d4, 0x00000000}},  //   fero, _csin, _xtec_,
  { {0x81cd0055, 0xf793008b, 0x7f44006b, 0x00000000}},  //   _শেষ_, _рашэ, dqiq,
  { {0x8c3d01f6, 0x63a421af, 0x23c50065, 0x00000000}},  //   _başl, _esin, _bëjë_,
  { {0x629c0288, 0xe7d20316, 0x00000000, 0x00000000}},  //   aero, _तथाप,   ,
  { {0x6d4e001e, 0x629c21b0, 0x6aba040f, 0x00000000}},  // [5390] _atba, bero, _ontf,
  { {0xdef803c8, 0xbf150025, 0x78a90089, 0x00000000}},  //   мых_, رواب, zdev,
  { {0x3f890016, 0x2d8700f4, 0x84e80123, 0x00000000}},  //   stau_, îne_, _رفیق_,
  { {0xd010026c, 0x3f890035, 0x200f010e, 0x00000000}},  //   الے_, ptau_, ügis_,
  { {0x0076009b, 0xdcfc0089, 0x6aa80203, 0x00000000}},  //   _אתרי_, _aprē, _badf,
  { {0x2b4d01a3, 0x6aa8005b, 0x21390145, 0x00000000}},  //   _vtec_, _cadf, _hish_,
  { {0x8c3d038c, 0xf9910879, 0x6d5c018e, 0x00000000}},  //   _yaşl, ابت_, _gwra,
  { {0x6aba010f, 0x764a0190, 0x78a90026, 0x00000000}},  //   _entf, _affy, udev,
  { {0x78a90089, 0x62850142, 0x629c21b1, 0x00000000}},  //   rdev, _ocho, yero,
  { {0x629c002d, 0x78a9004a, 0x21390d28, 0x00000000}},  //   xero, sdev, _lish_,
  { {0x63a40061, 0x78a900d4, 0x67380059, 0x00000000}},  //   _ssin, pdev, _divj,
  { {0x628521b2, 0x629c0036, 0x21390ede, 0x00000000}},  //   _acho, wero, _nish_,
  { {0x36d501fe, 0x9343007c, 0xdcf50089, 0x00000000}},  //   _подр, лняе, _apzī,
  { {0xe0df01aa, 0x7ae321b3, 0x21390d28, 0x00000000}},  //   _alò_, nhnt, _aish_,
  { {0x629c1632, 0x91e60517, 0x412a0920, 0x00000000}},  //   rero, хове, зово_,
  { {0x63a4011c, 0xe45f0c49, 0x67381922, 0x00000000}},  //   _tsin, ljön_, _zivj,
  { {0x63a40038, 0x213921b4, 0x629c04cb, 0x00000000}},  // [53a0] _usin, _dish_, pero,
  { {0xef1721b5, 0x629c0065, 0x213901d6, 0x00000000}},  //   ему_, qero, _eish_,
  { {0x213900ab, 0x8c3d014a, 0x6aa801a2, 0x00000000}},  //   _fish_, _taşl, _radf,
  { {0x71a3007e, 0x63f70014, 0x16360049, 0x00000000}},  //   _саюз, _آفیس_, גנער_,
  { {0x7bdd006b, 0xbc67023c, 0x6aa801c3, 0x00000000}},  //   _üsul, رمون_, _padf,
  { {0x61050006, 0x39a61649, 0x77690203, 0x00000000}},  //   mėla, ешив, dsex,
  { {0x7c960822, 0x6ee00047, 0x00000000, 0x00000000}},  //   _прац, _több,   ,
  { {0x3eaa010f, 0x673821b6, 0x38af0010, 0x00000000}},  //   _habt_, _sivj, yörű_,
  { {0xfce3007c, 0xdb0900f6, 0xa09b00a3, 0x00000000}},  //   _сото, _freà, ליקט,
  { {0xc66a007c, 0x00000000, 0x00000000, 0x00000000}},  //   чшие_,   ,   ,
  { {0xd90f009e, 0x00000000, 0x00000000, 0x00000000}},  //   _گیٹ_,   ,   ,
  { {0x628505af, 0x26d90065, 0x26c300f8, 0x00000000}},  //   _scho, ësor_, öjor_,
  { {0x2139000a, 0x00000000, 0x00000000, 0x00000000}},  //   _rish_,   ,   ,
  { {0x2900010a, 0x24710011, 0x00000000, 0x00000000}},  //   čiau_, ễm_,   ,
  { {0x59a6013d, 0xd627003b, 0x21390023, 0x00000000}},  //   _कैमर, _поље_, _pish_,
  { {0x62850036, 0x00000000, 0x00000000, 0x00000000}},  //   _wcho,   ,   ,
  { {0x2d9821b7, 0x62850e6d, 0xd2510014, 0x00000000}},  // [53b0] _apre_, _tcho, _پنج_,
  { {0x62850016, 0x2139180b, 0x4ed40088, 0x00000000}},  //   _ucho, _wish_, люєт,
  { {0x26ce21b8, 0x21390ede, 0x00000000, 0x00000000}},  //   _mofo_, _tish_,   ,
  { {0x2b490285, 0xbc19007e, 0x776900fa, 0x00000000}},  //   íaco_, мілі_, ysex,
  { {0x5c140a78, 0xdb0921b9, 0x00000000, 0x00000000}},  //   льшу, _areá,   ,
  { {0xb4ce0204, 0xbb520025, 0x60cf0082, 0x00000000}},  //   _शक्_, جنوب, _hocm,
  { {0x692a00b9, 0xdb09004a, 0x00000000, 0x00000000}},  //   _přep, _creá,   ,
  { {0x0c720014, 0x7769053d, 0x6b89002b, 0x00000000}},  //   _نگهد, tsex, _tqeg,
  { {0x2d04008b, 0x3a3e0009, 0x00000000, 0x00000000}},  //   _сярг, _fgtp_,   ,
  { {0x644d0191, 0x776902ec, 0x60cf21ba, 0x00000000}},  //   _afai, rsex, _locm,
  { {0xa50a026b, 0x776900c4, 0xb8950025, 0x00000000}},  //   дена_, ssex, _للاع,
  { {0x434600e3, 0x81e00044, 0xe45f00f8, 0x00000000}},  //   кемв, _দখল_, sjön_,
  { {0xe72e00ed, 0x26ce088a, 0x6ec40204, 0x00000000}},  //   _ве_, _fofo_, रामु,
  { {0x8c3d011f, 0xd25200a1, 0xf1aa0014, 0x00000000}},  //   _başk, شنر_, وازه_,
  { {0x45d2098c, 0x644d0016, 0x3f99012d, 0x00000000}},  //   _војс, _ffai, _apsu_,
  { {0xdd1c007f, 0x8c3d013f, 0x00000000, 0x00000000}},  //   ršūn, _daşk,   ,
  { {0x1e860256, 0x2d98000d, 0x7ae10048, 0x00000000}},  // [53c0] клам, _spre_, _ollt,
  { {0xd37b00a3, 0xdfcf0025, 0x321a197c, 0x00000000}},  //   _קריט, غيل_, _typy_,
  { {0xdca6007c, 0x254c013e, 0x181e006e, 0x00000000}},  //   кажи, _těle_, _पर्व_,
  { {0x7ae1091a, 0x78ab01d6, 0x3ce00048, 0x00000000}},  //   _allt, _nagv, óiv_,
  { {0x3eaa0030, 0x3eab00b0, 0x00000000, 0x00000000}},  //   _tabt_, öitä_,   ,
  { {0x5b13007e, 0xdb0903fd, 0x00000000, 0x00000000}},  //   аміт, _preá,   ,
  { {0x3f8000c4, 0xa9c3005e, 0x78ab0190, 0x00000000}},  //   luiu_, исък, _bagv,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbb460a1e, 0x3f8000c4, 0x00000000, 0x00000000}},  //   _резк, nuiu_,   ,
  { {0xb9960025, 0x00000000, 0x00000000, 0x00000000}},  //   _للطب,   ,   ,
  { {0x24f900a5, 0x63b60022, 0x00000000, 0x00000000}},  //   енны_, _aryn,   ,
  { {0x7d0221bb, 0x63b6056d, 0x29000006, 0x00000000}},  //   nnos, _bryn, čias_,
  { {0x69d5011f, 0x63b60016, 0x5694007e, 0x00000000}},  //   _üzer, _cryn, _балт,
  { {0x7d0221bc, 0x60cf04df, 0x78ab01ed, 0x00000000}},  //   hnos, _socm, _zagv,
  { {0x69d80047, 0x68e20146, 0x7d020b79, 0x00000000}},  //   nyve, _klod, knos,
  { {0x7d020161, 0x63b60ee6, 0x863700b3, 0x00000000}},  //   jnos, _fryn, _ברוב_,
  { {0x3f80153d, 0x63b60fdd, 0xb4df013d, 0x00000000}},  // [53d0] guiu_, _gryn, णसी_,
  { {0x64490006, 0x628911af, 0x8c3d00e5, 0x00000000}},  //   žeid, đeos, _iaşi,
  { {0x60cf001a, 0x63ba0089, 0x68e200fa, 0x00000000}},  //   _tocm, ātne, _olod,
  { {0x3f8000c4, 0x657a0048, 0x69b80204, 0x00000000}},  //   buiu_, irth, ्मनी,
  { {0x64410036, 0x24890145, 0x00000000, 0x00000000}},  //   śliw, _mcam_,   ,
  { {0x8c3d21bd, 0xa9270027, 0x28c50316, 0x00000000}},  //   _maşi, _obľú, वाभि,
  { {0x7d021d15, 0x69d80429, 0x5f100061, 0x00000000}},  //   bnos, gyve, तकर्_,
  { {0x3ea10004, 0x7d020027, 0x68e20016, 0x00000000}},  //   leht_, cnos, _clod,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68e2009d, 0x248900fa, 0x00000000, 0x00000000}},  //   _elod, _acam_,   ,
  { {0x2cbf08c8, 0xb955005e, 0x2d810087, 0x00000000}},  //   _knud_, _свещ, nuhe_,
  { {0x63b6018e, 0x78a000f6, 0x2a650288, 0x00000000}},  //   _pryn, cemv, _helb_,
  { {0x657a0051, 0x2d81010f, 0x2a65002b, 0x00000000}},  //   arth, huhe_, _kelb_,
  { {0x6449049a, 0xa6b4005e, 0x877a01ce, 0x00000000}},  //   ñeir, _всъщ, _נאצי,
  { {0x7d02157e, 0x91e300ed, 0xdb0900fa, 0x00000000}},  //   ynos, боре, _ereç,
  { {0xc48602a8, 0x205501e0, 0x63b6007f, 0x00000000}},  //   _слик, итур, _tryn,
  { {0xd36f0025, 0x291f21be, 0x8c3d019a, 0x00000000}},  // [53e0] _فهي_, ilua_, _faşi,
  { {0x3ea1010f, 0x7d02026e, 0x3f8000fa, 0x00000000}},  //   geht_, wnos, ruiu_,
  { {0xd83e0006, 0x6b9b00f6, 0x3945009d, 0x00000000}},  //   ščio_, _apug, _nuls_,
  { {0x0b8a0265, 0x5c060878, 0x00000000, 0x00000000}},  //   ески_, ляла,   ,
  { {0x62810489, 0x254c00b9, 0x7af800b9, 0x00000000}},  //   ólog, _měla_, tivt,
  { {0x7d02041a, 0x68e221bf, 0x69d8205a, 0x00000000}},  //   snos, _slod, tyve,
  { {0x7d020387, 0x39450a39, 0x78a000ea, 0x00000000}},  //   pnos, _culs_, temv,
  { {0x58d40001, 0xd90d02fd, 0x00000000, 0x00000000}},  //   роит, ویل_,   ,
  { {0x657a005b, 0x68e200d9, 0x00000000, 0x00000000}},  //   wrth, _vlod,   ,
  { {0xd9460140, 0x2a6501a2, 0x6b821b50, 0x00000000}},  //   _бежи, _gelb_, muog,
  { {0x6b821f5a, 0x9e7b0049, 0x21200f3a, 0x00000000}},  //   luog, ענטפ, klih_,
  { {0xdb0902d5, 0x657a0051, 0x2db70049, 0x00000000}},  //   _preç, rrth, אלטן_,
  { {0xf3ff00c4, 0x21200e0d, 0x6b82007f, 0x00000000}},  //   raão_, dlih_, nuog,
  { {0xf41f00f8, 0x00000000, 0x00000000, 0x00000000}},  //   ffär_,   ,   ,
  { {0x31c40001, 0x8c3d006b, 0x290401d6, 0x00000000}},  //   бств, _vaşi, onma_,
  { {0x6ad10061, 0x905509b2, 0x2489004a, 0x00000000}},  //   _तक्र, рвац, _ucam_,
  { {0x81cd0055, 0x3ea1010f, 0x42550014, 0x00000000}},  // [53f0] _শেখ_, teht_, _پنجر,
  { {0x3866002a, 0x212013e1, 0x26de21c0, 0x00000000}},  //   _leor_, alih_, nkto_,
  { {0x7127004b, 0x7095008b, 0x2cbf0173, 0x00000000}},  //   _مرحل, _канф, _pnud_,
  { {0x4c9515c4, 0x644f003b, 0x629521c1, 0x00000000}},  //   ридс, ncci, lfzo,
  { {0xfb35007e, 0x60cd0943, 0xda65051f, 0x00000000}},  //   андэ, mjam, авли,
  { {0x450b0055, 0x628700f8, 0x60cd21c2, 0x00000000}},  //   রতিক_, ngjo, ljam,
  { {0x60cd010a, 0x6ee021c3, 0x09e50920, 0x00000000}},  //   ojam, _möbl, ройн,
  { {0x60cd04cb, 0x6d55002d, 0x4429000a, 0x00000000}},  //   njam, _itza, _oza_,
  { {0x7d1b022b, 0x6d4721c4, 0x442921c5, 0x00000000}},  //   _ikus, _huja, _nza_,
  { {0x6d47195b, 0x59670265, 0x8c3d011f, 0x00000000}},  //   _kuja, _бъда, _başv,
  { {0x442901aa, 0xe4c60f71, 0x28c5013d, 0x00000000}},  //   _aza_, айни, वादि,
  { {0x38690359, 0x6d47006c, 0x6aa31297, 0x00000000}},  //   _þar_, _muja, lenf,
  { {0x7d090243, 0x8934002c, 0x68e921c6, 0x00000000}},  //   _mjes, _اعلا, mhed,
  { {0x60cd001e, 0x6aa308db, 0x7e6700b9, 0x00000000}},  //   ejam, nenf, _nejp,
  { {0xa06a0c4e, 0x7d1b02db, 0x4429002d, 0x00000000}},  //   кава_, _okus, _eza_,
  { {0x752d002b, 0x68e91244, 0x7d090065, 0x00000000}},  //   _ghaz, nhed, _njes,

  { {0x0e6601f9, 0x27ed21c7, 0x7c2921c8, 0x00000000}},  // [5400] икан, nzen_, _nzer,
  { {0x4420011f, 0x63a9011f, 0x2120092f, 0x00000000}},  //   _iyi_, çene, slih_,
  { {0x7c29005f, 0x6aa321c9, 0xc27b00a3, 0x00000000}},  //   _azer, denf, _בריי,
  { {0x44201fdb, 0xf76706dd, 0x6d47007f, 0x00000000}},  //   _kyi_, _وا_, _duja,
  { {0x7c290046, 0x27ed02ae, 0x6f170061, 0x00000000}},  //   _czer, jzen_, boxc,
  { {0x6aa31582, 0x7c290089, 0x27ed21ca, 0x00000000}},  //   genf, _dzer, dzen_,
  { {0x38660211, 0x7c291a19, 0x27ed00b5, 0x00000000}},  //   _peor_, _ezer, ezen_,
  { {0x68e921cb, 0x68fb0207, 0xa3e6007d, 0x00000000}},  //   ghed, giud, पना_,
  { {0x6d400058, 0xb5fc002b, 0x656301f3, 0x00000000}},  //   _iima, maġi, _awnh,
  { {0x6d4021cc, 0x7d1b00b9, 0x752d0c6a, 0x00000000}},  //   _hima, _zkus, _shaz,
  { {0x6d40000b, 0x386600c4, 0x752d0085, 0x00000000}},  //   _kima, _teor_, _phaz,
  { {0x68e90016, 0x6d4001a3, 0x68fb21cd, 0x00000000}},  //   ched, _jima, ciud,
  { {0xdcfc001e, 0x6d40014a, 0x645d007f, 0x00000000}},  //   _aprī, _mima, rbsi,
  { {0x6d40011c, 0x35f70014, 0xc207003b, 0x00000000}},  //   _lima, ارید_, аџби,
  { {0x60cd0129, 0xc1050025, 0x628716aa, 0x00000000}},  //   tjam, موسي, rgjo,
  { {0x6d4001d9, 0x6d470209, 0x9553007a, 0x00000000}},  //   _nima, _ruja, _بخوا,
  { {0x44290526, 0x60cd21ce, 0x692a00b9, 0x00000000}},  // [5410] _uza_, rjam, _břez,
  { {0x63ad0811, 0x6d4704bd, 0x6d4021cf, 0x00000000}},  //   _isan, _puja, _aima,
  { {0x7c29182e, 0x7d0921d0, 0x6d400093, 0x00000000}},  //   _szer, _pjes, _bima,
  { {0xbd1801fb, 0x6d40023a, 0x6d4701ee, 0x00000000}},  //   ації_, _cima, _vuja,
  { {0x7c200bc4, 0x6d400149, 0x8c3d001a, 0x00000000}},  //   _cymr, _dima, _naşt,
  { {0x63ad0020, 0x6d40007f, 0x6d4700e7, 0x00000000}},  //   _msan, _eima, _tuja,
  { {0xa3a9013d, 0x7d090243, 0x6aa321d1, 0x00000000}},  //   _गैस_, _tjes, renf,
  { {0x27ed09ce, 0x7d1b21d2, 0x6d40023a, 0x00000000}},  //   tzen_, _ukus, _gima,
  { {0x7c20018e, 0x8aa701f9, 0x68e91650, 0x00000000}},  //   _gymr, _вред, rhed,
  { {0x39b5001e, 0x27ed010f, 0x06c90783, 0x00000000}},  //   _tās_, rzen_, угой_,
  { {0x63ad097e, 0x4426001e, 0x99d90054, 0x00000000}},  //   _asan, _šo_, _حواء_,
  { {0x6d4021d3, 0x7d190036, 0x03a6022a, 0x00000000}},  //   _xima, nows, бимо,
  { {0x386d05b7, 0x69cc0035, 0x00000000, 0x00000000}},  //   maer_, ăneş,   ,
  { {0x386d01d6, 0x63ad0022, 0x8c1a00b3, 0x00000000}},  //   laer_, _dsan, רושי,
  { {0x63ad21d4, 0x41b50265, 0x69dc011f, 0x00000000}},  //   _esan, остт, _üret,
  { {0x6f1c012d, 0xe3b21739, 0x8c3d0095, 0x00000000}},  //   _skrc, _فرخ_, _yaşt,
  { {0x6d4021d5, 0x4426001d, 0x692a00b9, 0x00000000}},  // [5420] _rima, _áo_, _přez,
  { {0x52aa012b, 0x386d005b, 0x00000000, 0x00000000}},  //   _свом_, haer_,   ,
  { {0x6d400173, 0xdd8f0439, 0x00000000, 0x00000000}},  //   _pima, فول_,   ,
  { {0x237f0b41, 0xfb1900a1, 0x61e10190, 0x00000000}},  //   šuje_, یروں_, ølle,
  { {0x6d400145, 0x00000000, 0x00000000, 0x00000000}},  //   _vima,   ,   ,
  { {0x3eb10032, 0x6e3a000c, 0x6f1c11af, 0x00000000}},  //   _gazt_, _útbo, _ukrc,
  { {0xa96700e1, 0x6d4021d6, 0x7d1900b4, 0x00000000}},  //   бија_, _tima, bows,
  { {0x6d4021d7, 0xa3a90061, 0x386d21d8, 0x00000000}},  //   _uima, _गईल_, gaer_,
  { {0x7b0721d9, 0x00000000, 0x00000000, 0x00000000}},  //   órtá,   ,   ,
  { {0xb6c60057, 0x67530054, 0x6d41009d, 0x00000000}},  //   ссий, أخير, _élar,
  { {0x63ad00b4, 0x00000000, 0x00000000, 0x00000000}},  //   _ssan,   ,   ,
  { {0x6fc801f5, 0x63ad00b9, 0x499000a1, 0x00000000}},  //   रमां, _psan, _فیڈر,
  { {0x254c00b9, 0x6354013e, 0x28c5006e, 0x00000000}},  //   _tělo_, věný, वारि,
  { {0x3f801460, 0x61050006, 0x248d0036, 0x00000000}},  //   driu_, mėli, żem_,
  { {0x31c400e1, 0xa3a9006e, 0x61050006, 0x00000000}},  //   пств, _गैर_, lėli,
  { {0x63ad08e3, 0x3f8000f6, 0x00000000, 0x00000000}},  //   _tsan, friu_,   ,
  { {0x2ca6006c, 0x61050006, 0xa49b0129, 0x00000000}},  // [5430] deod_, nėli, riòd,
  { {0xfbc30044, 0x00000000, 0x00000000, 0x00000000}},  //   ্নমত,   ,   ,
  { {0x957c0046, 0xf5490082, 0x7d1900b4, 0x00000000}},  //   cząt, _lấn_, tows,
  { {0x3f8000c4, 0x2d93002d, 0x61050006, 0x00000000}},  //   briu_, rtxe_, kėli,
  { {0x7d190036, 0x3f800129, 0xa2be0061, 0x00000000}},  //   rows, criu_, शाच्,
  { {0x61050006, 0x386d0016, 0x3ea50325, 0x00000000}},  //   dėli, waer_, _últ_,
  { {0xda7809b5, 0x28c500e8, 0x272b00ea, 0x00000000}},  //   сяч_, वालि, jøna_,
  { {0xa3a9013d, 0xf5490082, 0x00000000, 0x00000000}},  //   _गईं_, _bấn_,   ,
  { {0x386d004e, 0x98be001a, 0xf5490082, 0x00000000}},  //   raer_, _sută_, _cấn_,
  { {0x81c20044, 0x0a6800e2, 0xf5490082, 0x00000000}},  //   ্নত_, _грци_, _dấn_,
  { {0x64a60264, 0x7ac401ab, 0x00000000, 0x00000000}},  //   оана, _эсте,   ,
  { {0xf2c900b6, 0x657c11ea, 0x399300c4, 0x00000000}},  //   _בע_, árha, mãs_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7b1f00c4, 0x55e5014c, 0xe75601fa, 0x00000000}},  //   cêut, _молб, _بلوغ_,
  { {0xc5d50822, 0x00000000, 0x00000000, 0x00000000}},  //   _філь,   ,   ,
  { {0x3f800c56, 0xafe60194, 0x957c0036, 0x00000000}},  //   triu_, ообл, rząt,
  { {0x254501c5, 0x00000000, 0x00000000, 0x00000000}},  // [5440] _vēlu_,   ,   ,
  { {0x3f8000c4, 0x00000000, 0x00000000, 0x00000000}},  //   rriu_,   ,   ,
  { {0x412a0088, 0x6da60025, 0x00000000, 0x00000000}},  //   _воно_, تمام,   ,
  { {0x0c2600aa, 0x3f8021da, 0xc7b90010, 0x00000000}},  //   омен, priu_, kvő_,
  { {0x8c3d005f, 0x00000000, 0x00000000, 0x00000000}},  //   _başq,   ,   ,
  { {0xe81d013d, 0x61050006, 0x00000000, 0x00000000}},  //   _पड़ा_, vėli,   ,
  { {0xfce6013b, 0x8c3d006b, 0x00000000, 0x00000000}},  //   _дово, _daşq,   ,
  { {0x6d5e00b0, 0x1d0a003b, 0x394221db, 0x00000000}},  //   mppa, _теби_, öks_,
  { {0xc6f801fb, 0x629e00ca, 0x6d5e0052, 0x00000000}},  //   йних_, _obpo, lppa,
  { {0xf549001d, 0xd6da1447, 0x35f407e1, 0x00000000}},  //   _vấn_, рти_, зпор,
  { {0x81df0055, 0x9405006b, 0xbb3b0049, 0x00000000}},  //   _দেন_, ələ_, _כעמי,
  { {0xf549001d, 0x98a6013b, 0x98be0006, 0x00000000}},  //   _tấn_, _фиде, _butą_,
  { {0x25a90521, 0x7b1f00c4, 0x629e0022, 0x00000000}},  //   _ćale_, pêut, _bbpo,
  { {0x050b0044, 0xdb00010f, 0x00000000, 0x00000000}},  //   রতের_, _ermö,   ,
  { {0xb5fc002b, 0x6b82088f, 0x306b01fc, 0x00000000}},  //   taġu, hrog, ијан_,
  { {0x6ab70061, 0x394c00f6, 0xb97b0097, 0x00000000}},  //   _आफ्र, _muds_, ינלי,
  { {0xd8d70049, 0x00000000, 0x00000000, 0x00000000}},  // [5450] קומט_,   ,   ,
  { {0x394c01d6, 0x623500c0, 0x00000000, 0x00000000}},  //   _ouds_, _непу,   ,
  { {0x6d5e00e0, 0xde190025, 0x00000000, 0x00000000}},  //   gppa, حقات_,   ,
  { {0x6f0e0022, 0x272b00ea, 0x00000000, 0x00000000}},  //   _ejbc, jønn_,   ,
  { {0xef9300e9, 0x7ba70025, 0x6b82060d, 0x00000000}},  //   _زیاد, تصام, grog,
  { {0x399300c4, 0x394c21dc, 0x00000000, 0x00000000}},  //   tãs_, _buds_,   ,
  { {0x26c90011, 0xc27c01ce, 0x3ebe01e5, 0x00000000}},  //   _đao_, ברוי, _ótta_,
  { {0xab9500ed, 0x9d1801ab, 0x88c91ba8, 0x00000000}},  //   _набљ, _дост_, слив_,
  { {0x236901aa, 0x6b820133, 0x00000000, 0x00000000}},  //   _nwaj_, crog,   ,
  { {0xb05b0039, 0x00000000, 0x00000000, 0x00000000}},  //   _snäl,   ,   ,
  { {0x394c1861, 0xd7c90014, 0x7d0b0082, 0x00000000}},  //   _guds_, _گوشه_, ongs,
  { {0xa50a00ed, 0x499a009b, 0x00000000, 0x00000000}},  //   сема_, _לשעב,   ,
  { {0xddd50010, 0x7d0b21dd, 0x00000000, 0x00000000}},  //   _mező, ings,   ,
  { {0x78a900ea, 0xfbd2034e, 0x8c1a00b3, 0x00000000}},  //   leev, עתם_, מורי,
  { {0x26c721de, 0x52b9007e, 0x81df0044, 0x00000000}},  //   _inno_, цыяў_, _দেব_,
  { {0x6b821a90, 0x00000000, 0x00000000, 0x00000000}},  //   yrog,   ,   ,
  { {0x8fa301ab, 0x00000000, 0x00000000, 0x00000000}},  // [5460] нате,   ,   ,
  { {0x63a421df, 0x00000000, 0x00000000, 0x00000000}},  //   _ipin,   ,   ,
  { {0x32db009b, 0x6b820696, 0xfbd200a1, 0x00000000}},  //   _החינ, wrog, کتا_,
  { {0x3157007b, 0x6b820209, 0x629c0168, 0x00000000}},  //   _מיטן_, trog, lfro,
  { {0xaac7013d, 0x26c71372, 0x394c005b, 0x00000000}},  //   लांक, _onno_, _suds_,
  { {0x628e0039, 0x63a40020, 0x629c051b, 0x00000000}},  //   ngbo, _mpin, nfro,
  { {0xf5490011, 0xa96700ec, 0x6da30069, 0x00000000}},  //   _bấm_, пија_, _пира,
  { {0x26c70198, 0x6b820056, 0x6d5c00bb, 0x00000000}},  //   _anno_, prog, _itra,
  { {0x6d4e011c, 0x7d021ac4, 0x629c0203, 0x00000000}},  //   _huba, mios, kfro,
  { {0x6d4e000b, 0x7d020020, 0x3ce61a2d, 0x00000000}},  //   _kuba, lios, lkov_,
  { {0x6d4e21e0, 0x63a40052, 0x18a6007c, 0x00000000}},  //   _juba, _apin, _нажм,
  { {0x7d020036, 0x3ce621e1, 0x6aaa0052, 0x00000000}},  //   nios, nkov_, leff,
  { {0xa8470318, 0x6d4e0004, 0x629c074e, 0x00000000}},  //   _علوم_, _luba, ffro,
  { {0x569302a8, 0x6d5c21e2, 0xa77b00b6, 0x00000000}},  //   _зашт, _otra, _פרופ,
  { {0x63a421e3, 0xa69b009b, 0x39460093, 0x00000000}},  //   _epin, _השופ, _kios_,
  { {0x6aaa00bb, 0x7d020032, 0x7bc001e5, 0x00000000}},  //   heff, jios, _ormu,
  { {0x6d5c1ffc, 0x7d02006b, 0x8498006d, 0x00000000}},  // [5470] _atra, dios, _رئيس_,
  { {0x629c00d9, 0x6aaa0146, 0x39460eb3, 0x00000000}},  //   cfro, jeff, _lios_,
  { {0x6d4e21e4, 0x7bc0006c, 0x7d020197, 0x00000000}},  //   _cuba, _armu, fios,
  { {0xe81d0061, 0x6d5c0048, 0x39460048, 0x00000000}},  //   _पडला_, _dtra, _nios_,
  { {0x6d5c21e5, 0x21290149, 0x6f1e00f6, 0x00000000}},  //   _etra, mlah_, bopc,
  { {0x21290127, 0x6d5c0009, 0x99d40014, 0x00000000}},  //   llah_, _ftra, کتها,
  { {0x7bc00b7c, 0x6d4e09f3, 0x78a901c3, 0x00000000}},  //   _ermu, _guba, teev,
  { {0x7d020211, 0x2129027e, 0x8c3d006b, 0x00000000}},  //   cios, nlah_, _abşe,
  { {0x39460ac6, 0x78a90146, 0x6d5c01dc, 0x00000000}},  //   _dios_, reev, _ztra,
  { {0x212921e6, 0x6d4e0f00, 0x6b8b04ce, 0x00000000}},  //   hlah_, _yuba, mugg,
  { {0x34aa0264, 0x6d5c071b, 0x394621e7, 0x00000000}},  //   овно_, _xtra, _fios_,
  { {0x59a6013d, 0x69c10032, 0x63a410e8, 0x00000000}},  //   _कैटर, _irle, _ppin,
  { {0x4c9a00b3, 0x6b8b0433, 0x2129013e, 0x00000000}},  //   חברו, nugg, dlah_,
  { {0x7d020207, 0x66050735, 0x6d5a00f4, 0x00000000}},  //   zios, _опла, _étag,
  { {0x6b8b032e, 0x290d0cb6, 0x3ced006c, 0x00000000}},  //   hugg, onea_, _olev_,
  { {0x2d7821e8, 0x629c01d6, 0x290d043a, 0x00000000}},  //   vče_, sfro, nnea_,
  { {0x6d4e21e9, 0xd24f026c, 0x3ce60cce, 0x00000000}},  // [5480] _suba, انہ_, vkov_,
  { {0x3ced014a, 0x21290145, 0x6d4e21ea, 0x00000000}},  //   _alev_, alah_, _puba,
  { {0x3ced05fe, 0x3ce60b9f, 0x6f1e0146, 0x00000000}},  //   _blev_, tkov_, ropc,
  { {0x25d600bd, 0x7e6e00b5, 0x2d780107, 0x00000000}},  //   ווען_, _webp, rče_,
  { {0x69c10f75, 0x394621eb, 0x3ce60142, 0x00000000}},  //   _arle, _rios_, rkov_,
  { {0x45060055, 0x6d4e006c, 0x7d02042c, 0x00000000}},  //   ৈতিক_, _tuba, sios,
  { {0x6d5c092c, 0x7d020052, 0xf98f006d, 0x00000000}},  //   _utra, pios, لبي_,
  { {0x3eb80343, 0x57b40265, 0xdd8f03ab, 0x00000000}},  //   _hart_, ебит, _خوف_,
  { {0x69c114b4, 0x3eb821ec, 0xb7be0044, 0x00000000}},  //   _erle, _kart_, েন্ট,
  { {0xddce0ebc, 0x75240244, 0x98a30089, 0x00000000}},  //   _nebū, _akiz, ējā_,
  { {0x3eb821ed, 0xceb300b6, 0x39461d66, 0x00000000}},  //   _mart_, דית_, _tios_,
  { {0x3eb80065, 0xa4d50088, 0x67230087, 0x00000000}},  //   _lart_, хомі, _eknj,
  { {0x44320046, 0xd943003b, 0x29040091, 0x00000000}},  //   _czy_, _реци, mima_,
  { {0x2904010a, 0x752421ee, 0x00000000, 0x00000000}},  //   lima_, _ekiz,   ,
  { {0x98a60036, 0x2129003f, 0xf2040b52, 0x00000000}},  //   _choć_, tlah_, вято,
  { {0x29041adc, 0x4395012b, 0xe4a700ed, 0x00000000}},  //   nima_, _заис, _црко,
  { {0x3eb821ef, 0x26dc0006, 0x21291444, 0x00000000}},  // [5490] _bart_, _kovo_, rlah_,
  { {0x442918a8, 0x26dc01ee, 0x3eb80133, 0x00000000}},  //   _iya_, _jovo_, _cart_,
  { {0x3eb80061, 0x61e10039, 0x2904016e, 0x00000000}},  //   _dart_, älld, kima_,
  { {0x29040119, 0xd251089d, 0x4429011c, 0x00000000}},  //   jima_, _جنگ_, _kya_,
  { {0x29040119, 0x3eb81bea, 0xcb69007c, 0x00000000}},  //   dima_, _fart_, чале_,
  { {0x26dc21f0, 0x78a200ab, 0x44290a18, 0x00000000}},  //   _novo_, _abov, _mya_,
  { {0x442921f1, 0x6b8b00bb, 0xdb0201a2, 0x00000000}},  //   _lya_, sugg, stoß,
  { {0x290d000d, 0x29040213, 0x644d0051, 0x00000000}},  //   unea_, gima_, _ngai,
  { {0x442921f2, 0x290d001a, 0x60dd0065, 0x00000000}},  //   _nya_, rnea_, _mosm,
  { {0x644d21f3, 0x60dd01d6, 0x26dc0026, 0x00000000}},  //   _agai, _losm, _covo_,
  { {0x2904037e, 0x44290020, 0x69c10311, 0x00000000}},  //   bima_, _aya_, _urle,
  { {0x290421f4, 0x44290061, 0xd75600a2, 0x00000000}},  //   cima_, _bya_, بلیت_,
  { {0x44290061, 0x644d00f6, 0x00000000, 0x00000000}},  //   _cya_, _dgai,   ,
  { {0x68e90010, 0x67230107, 0x44290058, 0x00000000}},  //   lked, _uknj, _dya_,
  { {0x5692025f, 0x60dd0501, 0x28d3006e, 0x00000000}},  //   _сајт, _bosm, थापि,
  { {0x69dc0129, 0x78bb21f5, 0x60dd0585, 0x00000000}},  //   _àree, nduv, _cosm,
  { {0x7c290047, 0x3eb821f6, 0x60dd00ca, 0x00000000}},  // [54a0] _nyer, _part_, _dosm,
  { {0x29040258, 0x139b009b, 0x63b60203, 0x00000000}},  //   zima_, _צביע, _isyn,
  { {0x68e90030, 0x3eb815c5, 0x7c292045, 0x00000000}},  //   kked, _vart_, _ayer,
  { {0x61e121f7, 0x7c2904b3, 0x3eb81134, 0x00000000}},  //   älle, _byer, _wart_,
  { {0x29040119, 0x3eb80010, 0x28d301f5, 0x00000000}},  //   vima_, _tart_, थानि,
  { {0x9404006b, 0x7c290065, 0x60dd18d9, 0x00000000}},  //   ümə_, _dyer, _zosm,
  { {0xfbd80055, 0x672121f8, 0x291801e5, 0x00000000}},  //   _দেখত, dolj, _írak_,
  { {0x7c290023, 0x26dc0087, 0x63b600f8, 0x00000000}},  //   _fyer, _sovo_, _osyn,
  { {0x7c290047, 0x6d5a00f4, 0x26dc0181, 0x00000000}},  //   _gyer, _étab, _povo_,
  { {0x672121f9, 0x29040091, 0x442921fa, 0x00000000}},  //   golj, sima_, _rya_,
  { {0x442921fb, 0x2360008d, 0x29041080, 0x00000000}},  //   _sya_, _atij_, pima_,
  { {0x68e90240, 0x399a0065, 0x78a20c8e, 0x00000000}},  //   cked, mës_, _ubov,
  { {0x66e601fb, 0x67210bf8, 0x2480018e, 0x00000000}},  //   _пода, bolj, _ddim_,
  { {0x4429000b, 0xd5b0007a, 0x26dc0197, 0x00000000}},  //   _vya_, _نفت_, _uovo_,
  { {0x399a008d, 0x60dd21fc, 0x6aba00f8, 0x00000000}},  //   nës_, _posm, _matf,
  { {0x88bd0046, 0x644d0246, 0x657a00ea, 0x00000000}},  //   mośc, _ugai, msth,
  { {0x81df0055, 0x399a0065, 0xff530464, 0x00000000}},  // [54b0] _দেশ_, hës_, اخر_,
  { {0x399a008d, 0x7c2921fd, 0x68e90010, 0x00000000}},  //   kës_, _ryer, zked,
  { {0x88bd0046, 0xe3140054, 0x399a0065, 0x00000000}},  //   nośc, _حبيب, jës_,
  { {0x3079007b, 0x672121fe, 0x399a0065, 0x00000000}},  //   _קאָנ, zolj, dës_,
  { {0x06b70044, 0x2d570066, 0x6ef21f7d, 0x00000000}},  //   জাতি, _għen_, _sæbe,
  { {0x88bd0046, 0x399a0023, 0xdb09004a, 0x00000000}},  //   kośc, fës_, _preñ,
  { {0x67210c1e, 0x399a0065, 0x6ca7007e, 0x00000000}},  //   volj, gës_, _праж,
  { {0xdddc014a, 0x657a0030, 0x88bd0036, 0x00000000}},  //   _herş, dsth, dośc,
  { {0x68e902cc, 0x672121ff, 0x78bb006c, 0x00000000}},  //   rked, tolj, rduv,
  { {0x68e906a5, 0x0ab40879, 0x2caf00b5, 0x00000000}},  //   sked, _محمد, legd_,
  { {0x940c005f, 0x67210010, 0x399a0065, 0x00000000}},  //   ədə_, rolj, cës_,
  { {0xe945007a, 0x672102bb, 0x9f400026, 0x00000000}},  //   _شرای, solj, nziò_,
  { {0x6721037e, 0x6c7a0049, 0x00000000, 0x00000000}},  //   polj, וארפ,   ,
  { {0x3f892200, 0x00000000, 0x00000000, 0x00000000}},  //   drau_,   ,   ,
  { {0x4096008b, 0x412a07e1, 0x6b9b0066, 0x00000000}},  //   крат, дово_, _lqug,
  { {0x3f890abe, 0x2fc008e0, 0x00000000, 0x00000000}},  //   frau_, tvig_,   ,
  { {0x3f8912fe, 0xd0070265, 0x4127026b, 0x00000000}},  // [54c0] grau_, вете_, тото_,
  { {0x2fc02201, 0x45140044, 0xddc70521, 0x00000000}},  //   rvig_, _সঠিক_, _sejš,
  { {0xdd8f0647, 0x127b0049, 0x9d46005e, 0x00000000}},  //   قول_, _קאטע, вежд,
  { {0x399a008d, 0x13e60055, 0x7afd010a, 0x00000000}},  //   vës_, _পেয়, _įsta,
  { {0x8b96007c, 0xe4570049, 0x88bd00b4, 0x00000000}},  //   треч, דינט_, zośc,
  { {0x399a008d, 0x6e960076, 0x9f400010, 0x00000000}},  //   tës_, _جلسا, rzió_,
  { {0xf54a0082, 0x00000000, 0x00000000, 0x00000000}},  //   _hấu_,   ,   ,
  { {0x399a008d, 0xfce300e1, 0x52df03d7, 0x00000000}},  //   rës_, _косо, _नक्स,
  { {0x88bd0046, 0x8afd0224, 0x399a0065, 0x00000000}},  //   wośc, _stře, sës_,
  { {0x399a0065, 0x95d80423, 0x88bd0036, 0x00000000}},  //   pës_, едот_, tośc,
  { {0x7bc22202, 0x399a0065, 0x00000000, 0x00000000}},  //   lvou, qës_,   ,
  { {0x657a2203, 0x3f89005b, 0x88bd00b4, 0x00000000}},  //   rsth, yrau_, rośc,
  { {0x7bc201b5, 0xf54a0011, 0x657a00ea, 0x00000000}},  //   nvou, _nấu_, ssth,
  { {0x2caf00b5, 0x213902d4, 0x00000000, 0x00000000}},  //   zegd_, _shsh_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3b07006b, 0x3f892204, 0x00000000, 0x00000000}},  //   zinq_, trau_,   ,
  { {0xf54a001d, 0xdddc014a, 0xab5d0066, 0x00000000}},  // [54d0] _cấu_, _perş, _arżn,
  { {0xf54a001d, 0x3f892205, 0x00000000, 0x00000000}},  //   _dấu_, rrau_,   ,
  { {0x7bc200d9, 0x00000000, 0x00000000, 0x00000000}},  //   evou,   ,   ,
  { {0x50640088, 0x273900f4, 0x645d0010, 0x00000000}},  //   _втра, mène_, ncsi,
  { {0xceeb035b, 0x273900f4, 0xf54a0011, 0x00000000}},  //   _قرآن_, lène_, _gấu_,
  { {0x8f9a00b6, 0xd9d70044, 0x62950232, 0x00000000}},  //   _אישי, তনসম, ngzo,
  { {0xf2d4007b, 0x3b07006b, 0x39b7013f, 0x00000000}},  //   יעס_, rinq_, _kəsə_,
  { {0xa5020061, 0x26ce0026, 0x00000000, 0x00000000}},  //   _लगेच_, _anfo_,   ,
  { {0xf54a001d, 0xf7710647, 0x6d551658, 0x00000000}},  //   _mất_, حاب_, _huza,
  { {0x6d550020, 0xc987005c, 0x00000000, 0x00000000}},  //   _kuza, _ауди,   ,
  { {0x66052206, 0x6d550066, 0x7e750288, 0x00000000}},  //   упна, _juza, _mezp,
  { {0x6d551e54, 0x26ce01aa, 0xa8790049, 0x00000000}},  //   _muza, _enfo_, _װאַר,
  { {0x6d55002d, 0x7ae1014a, 0x06df0044, 0x00000000}},  //   _luza, _kolt, যোগি,
  { {0x81df0044, 0xc7b2009b, 0x7ae10052, 0x00000000}},  //   _দেই_, _לבד_, _jolt,
  { {0x7ae12207, 0xf54a0011, 0x273900f4, 0x00000000}},  //   _molt, _bất_, gène_,
  { {0x61e10039, 0xb4db0129, 0xf54a0011, 0x00000000}},  //   älla, rmàc, _cất_,
  { {0x7e7513c2, 0xb348002b, 0xc54200a1, 0x00000000}},  // [54e0] _bezp, _agħż, _پڑھی,
  { {0x4df60057, 0x6d55001a, 0x00000000, 0x00000000}},  //   ляет, _buza,   ,
  { {0x4bda0752, 0x80d30044, 0x91e6007e, 0x00000000}},  //   کباد_, _সতর্, _соне,
  { {0x2d87008e, 0x6d550107, 0xf54a0011, 0x00000000}},  //   ánea_, _duza, _tấu_,
  { {0x7ae10daf, 0xc87901df, 0x1bd407d0, 0x00000000}},  //   _bolt, daş_, роля,
  { {0x7bc20f12, 0x7ae11d28, 0x6d551049, 0x00000000}},  //   rvou, _colt, _fuza,
  { {0x13ad0044, 0xee3703f6, 0xea95007e, 0x00000000}},  //   খিয়, _бнр_, ршчэ,
  { {0x8c4608f3, 0x00000000, 0x00000000, 0x00000000}},  //   _бебе,   ,   ,
  { {0x3f92014a, 0x7ae10232, 0x6d5504bb, 0x00000000}},  //   nuyu_, _folt, _zuza,
  { {0x7ae100ca, 0x7f4e002b, 0x00000000, 0x00000000}},  //   _golt, _jibq,   ,
  { {0x97d7026c, 0xd8840014, 0x645a00b9, 0x00000000}},  //   نظیر_, _نهای, ětin,
  { {0x7ae10010, 0x27391259, 0x3f9215dc, 0x00000000}},  //   _zolt, vène_, kuyu_,
  { {0xf54a001d, 0x090600a1, 0x2bc7006e, 0x00000000}},  //   _rất_, _لڑکی_, लिया,
  { {0x88bd0036, 0x27391339, 0x7f4e002b, 0x00000000}},  //   nośn, tène_, _nibq,
  { {0xd13b017f, 0x68e22208, 0x00000000, 0x00000000}},  //   еха_, _kood,   ,
  { {0x68e22209, 0x2739009d, 0x555100a1, 0x00000000}},  //   _jood, rène_, _گھیر,
  { {0x68e2006c, 0x6d550213, 0xf54a0082, 0x00000000}},  // [54f0] _mood, _suza, _vất_,
  { {0x200d009f, 0x68e20004, 0xdef80147, 0x00000000}},  //   _þeim_, _lood, лых_,
  { {0xf54a001d, 0x7ae101d6, 0x628501f3, 0x00000000}},  //   _tất_, _rolt, _idho,
  { {0x68e200c7, 0xf54a0082, 0x6e2e0190, 0x00000000}},  //   _nood, _uất_, _dybb,
  { {0x69c802a4, 0x7ae11414, 0x6d5a00f4, 0x00000000}},  //   _arde, _polt, _étan,
  { {0xdefb008b, 0x63ad000b, 0x6d550095, 0x00000000}},  //   _чым_, _mpan, _tuza,
  { {0x7ae1220a, 0x68e20100, 0xdb000030, 0x00000000}},  //   _volt, _bood, _opmæ,
  { {0x77850081, 0x7ae105af, 0x63ad0821, 0x00000000}},  //   ализ, _wolt, _opan,
  { {0x68e2220b, 0xccf2009b, 0x69c82084, 0x00000000}},  //   _dood, _וכן_, _erde,
  { {0x7d0b01e3, 0xe739003b, 0xa3b0013d, 0x00000000}},  //   ligs, ђен_, _टैग_,
  { {0xa2d90309, 0x63ad00c4, 0x68e200ab, 0x00000000}},  //   मान्, _apan, _food,
  { {0x7bc9010f, 0x7d0b010f, 0x68e200ab, 0x00000000}},  //   _kreu, nigs, _good,
  { {0x61e10073, 0x2cbf0946, 0x63ad0133, 0x00000000}},  //   älln, _maud_, _cpan,
  { {0xf770007a, 0x386d010f, 0xcb120049, 0x00000000}},  //   _راه_, lber_, ַלן_,
  { {0x11d50088, 0x7d0b220c, 0x63ad220d, 0x00000000}},  //   бітр, kigs, _epan,
  { {0x63ad0009, 0x386d01e5, 0x2fcd0087, 0x00000000}},  //   _fpan, nber_, _šega_,
  { {0x386d010f, 0x7d0b037f, 0xaf06007e, 0x00000000}},  // [5500] iber_, digs, апал,
  { {0x543b0049, 0x386d014a, 0x00000000, 0x00000000}},  //   _בעפא, hber_,   ,
  { {0x386d002b, 0x7d0b010f, 0xdcff00b9, 0x00000000}},  //   kber_, figs, _úvěr,
  { {0x0b8a031b, 0xdca6025f, 0x7bc903cd, 0x00000000}},  //   вски_, ради, _breu,
  { {0x7bc9220e, 0x69c8220f, 0x68e200c7, 0x00000000}},  //   _creu, _srde, _rood,
  { {0x6d42002d, 0x68e2006c, 0x69c80062, 0x00000000}},  //   smoa, _sood, _prde,
  { {0x68e2006c, 0xf9e90044, 0xf2890049, 0x00000000}},  //   _pood, _কেবল_, אָפֿ,
  { {0x7bc9001f, 0xa7740726, 0x394f0026, 0x00000000}},  //   _freu, блич, _cigs_,
  { {0x68e2006c, 0x7bc91825, 0x6fc9013d, 0x00000000}},  //   _vood, _greu, रियं,
  { {0x68e200ab, 0x81bc0044, 0x69c800ca, 0x00000000}},  //   _wood, _আপন_, _trde,
  { {0xd5b72210, 0x386d068f, 0x68e20004, 0x00000000}},  //   ася_, bber_, _tood,
  { {0x186a0805, 0x394f0016, 0x2ca6018e, 0x00000000}},  //   _ради_, _gigs_, nfod_,
  { {0xda780027, 0x8af9006b, 0x07da0431, 0x00000000}},  //   _keď_, bləğ, _جذاب_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb6cb026c, 0x31c4007e, 0x00000000, 0x00000000}},  //   _جانے_, оств,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63ad11ad, 0x3eb32211, 0x2cbf2212, 0x00000000}},  // [5510] _upan, text_, _raud_,
  { {0xf54a0011, 0x6e67007e, 0x2d87008e, 0x00000000}},  //   _hấp_, ртаж, áneo_,
  { {0x8af9006b, 0x7d0b010f, 0x2cbf0093, 0x00000000}},  //   nləş, tigs, _paud_,
  { {0x7c87012b, 0x7bc90466, 0x6728016c, 0x00000000}},  //   руже, _preu, hodj,
  { {0x67282213, 0x752d0020, 0x7d0b00ea, 0x00000000}},  //   kodj, _mkaz, rigs,
  { {0x7bc92214, 0x7d0b021f, 0xf54a0011, 0x00000000}},  //   _vreu, sigs, _lấp_,
  { {0x752d2215, 0xceb200b6, 0x7db40025, 0x00000000}},  //   _okaz, _מים_, _وصفا,
  { {0x7bc90129, 0xc9150044, 0xac94041f, 0x00000000}},  //   _treu, াত্ত_, _масш,
  { {0x7d092216, 0x394f0007, 0x7bc90022, 0x00000000}},  //   _imes, _vigs_, _ureu,
  { {0x67280107, 0x752d0cd1, 0x7d1b01ee, 0x00000000}},  //   godj, _akaz, _hjus,
  { {0x25ae00fa, 0x00000000, 0x00000000, 0x00000000}},  //   _cpfl_,   ,   ,
  { {0xf54a001d, 0x3f800006, 0xda78013e, 0x00000000}},  //   _cấp_, ysiu_, _zeď_,
  { {0x67280107, 0xa856009b, 0x7d0900e7, 0x00000000}},  //   bodj, _הינה_, _mmes,
  { {0x7d1b2217, 0x7c3b0020, 0x6263007c, 0x00000000}},  //   _ljus, _mzur, звра,
  { {0x27ed2218, 0xf5950025, 0x7d092219, 0x00000000}},  //   lyen_, _العج, _omes,
  { {0xf54a001d, 0xa564023c, 0x09bc0044, 0x00000000}},  //   _gấp_, _بدون, _অপমা,
  { {0x27ed0607, 0x7c3b000b, 0x3f800006, 0x00000000}},  // [5520] nyen_, _nzur, usiu_,
  { {0x7e56008b, 0x7d09000b, 0x7d1b0325, 0x00000000}},  //   стац, _ames, _ajus,
  { {0xe1f20014, 0x3f80221a, 0x27ed0f82, 0x00000000}},  //   _رسد_, ssiu_, hyen_,
  { {0xa13602fd, 0x27ed0173, 0xf54a0082, 0x00000000}},  //   _درخش, kyen_, _xấp_,
  { {0x2ca6018e, 0x27ed04cd, 0x7d1b016c, 0x00000000}},  //   rfod_, jyen_, _djus,
  { {0x27ed01aa, 0x6441005f, 0x7d0916a3, 0x00000000}},  //   dyen_, əlid, _emes,
  { {0x6728221b, 0xa2d9007d, 0xf967007c, 0x00000000}},  //   vodj, मात्, брый_,
  { {0x60c4008d, 0x2a7c01ee, 0x44200082, 0x00000000}},  //   ndim, savb_, _oxi_,
  { {0x27ed0047, 0xda7800b9, 0x20000f04, 0x00000000}},  //   gyen_, _teď_, nzii_,
  { {0xf76f0a4f, 0x8b26008b, 0xc6f700a5, 0x00000000}},  //   راً_, _удзе, йных_,
  { {0x6728003b, 0x7d090016, 0x7c3b0026, 0x00000000}},  //   rodj, _ymes, _zzur,
  { {0x27ed0263, 0x8af9005f, 0x68fb0036, 0x00000000}},  //   byen_, rləş, chud,
  { {0x7e7e0343, 0x6b8200f6, 0xf54a0011, 0x00000000}},  //   kapp, nsog, _vấp_,
  { {0x64560047, 0x2d810065, 0xd7650014, 0x00000000}},  //   _egyi, yshe_, _بنوی,
  { {0x249900e0, 0x7e7e0397, 0xf54a0082, 0x00000000}},  //   pgsm_, dapp, _tấp_,
  { {0x39ae006b, 0x7e7e0f46, 0x2d81012d, 0x00000000}},  //   _kəsb_, eapp, vshe_,
  { {0x14d60164, 0x6133014a, 0xe1f000a1, 0x00000000}},  // [5530] धारण, nçli, وسہ_,
  { {0x9e15008b, 0x6d4004be, 0x2bc7001c, 0x00000000}},  //   одзі, _ahma, लिसा,
  { {0x27ed0f5c, 0x7c3b0010, 0x60c4093e, 0x00000000}},  //   zyen_, _szur, bdim,
  { {0x7a420010, 0x2d810023, 0x8d74221c, 0x00000000}},  //   zíté, rshe_, ساما,
  { {0x7e7e0197, 0x7d09221d, 0x00000000, 0x00000000}},  //   bapp, _vmes,   ,
  { {0x7e7e221e, 0x2d8101ee, 0xa8a70279, 0x00000000}},  //   capp, pshe_, şmüş_,
  { {0x6d580027, 0xdd9400a5, 0x9cf5013a, 0x00000000}},  //   ívat, _нары, _дзві,
  { {0x7d09221f, 0x27ed01aa, 0x27ff002d, 0x00000000}},  //   _umes, tyen_, tzun_,
  { {0xe8f60245, 0x7c3b0020, 0x68fb04d3, 0x00000000}},  //   іль_, _uzur, rhud,
  { {0x458500c0, 0x27ed01aa, 0xd709007c, 0x00000000}},  //   огов, ryen_, рное_,
  { {0x27ed1dbf, 0x443200b0, 0x7a420344, 0x00000000}},  //   syen_, _syy_, ríté,
  { {0x7a420047, 0x03a6007c, 0x89370076, 0x00000000}},  //   síté, оимо, _اعطا,
  { {0xdd0c0036, 0x7a420010, 0x7ccd0089, 0x00000000}},  //   _późn, píté, mērķ,
  { {0x3669012b, 0x61ee00d4, 0x387f0035, 0x00000000}},  //   _тако_, tybl, laur_,
  { {0xd5ac026c, 0x23692220, 0x2cad0142, 0x00000000}},  //   _یہی_, _etaj_, _obed_,
  { {0x60c40006, 0x463a0049, 0x44202221, 0x00000000}},  //   udim, _דעצע, _txi_,
  { {0x60c42222, 0x7e7e01b5, 0x8fa30264, 0x00000000}},  // [5540] rdim, tapp, мате,
  { {0x6d400065, 0xa3e7013d, 0x63ab00f8, 0x00000000}},  //   _shma, पहर_, _ägna,
  { {0x7e7e2223, 0xbc6a035b, 0x049300a1, 0x00000000}},  //   rapp, لمان_, _علیح,
  { {0x629c00d9, 0x2bca00ed, 0x60c4006b, 0x00000000}},  //   lgro, илеп_, qdim,
  { {0x7e7e0039, 0x8bb603ec, 0x387f0022, 0x00000000}},  //   papp, تصاص, daur_,
  { {0x6b82049a, 0x99660cb7, 0x2fcf0030, 0x00000000}},  //   rsog, отил, ægge_,
  { {0x6b820066, 0x14ca013d, 0x629c01c3, 0x00000000}},  //   ssog, ियाण, igro,
  { {0x6d5c2224, 0x629c005b, 0x00000000, 0x00000000}},  //   _iura, hgro,   ,
  { {0x629c046a, 0x28a6007d, 0x6d5c01a3, 0x00000000}},  //   kgro, क्षि, _hura,
  { {0x6bd70025, 0x7e7c00f6, 0x00000000, 0x00000000}},  //   _بوكس_, _jerp,   ,
  { {0x6d5c0142, 0x2489023a, 0xa01b010f, 0x00000000}},  //   _jura, _pdam_, _geöf,
  { {0x6d5c04d4, 0x5507008b, 0x30c50055, 0x00000000}},  //   _mura, ічна, _এক্স,
  { {0x38cb00a6, 0x6d5c2225, 0x81af0044, 0x00000000}},  //   _خالی_, _lura, ওয়া_,
  { {0x2d870224, 0x28a6007d, 0x629c01c3, 0x00000000}},  //   ánek_, क्रि, ggro,
  { {0x7ae80018, 0x6d5c2226, 0x38660065, 0x00000000}},  //   _modt, _nura, _kfor_,
  { {0x63a40065, 0x2489016c, 0x7ae80179, 0x00000000}},  //   _fqin, _udam_, _lodt,
  { {0x6d5c2227, 0x7e7c020c, 0xdced0089, 0x00000000}},  // [5550] _aura, _berp, ākļo,
  { {0x6d5c01f6, 0x539a009b, 0xfe70023c, 0x00000000}},  //   _bura, _פיתו, ندم_,
  { {0x6d5c001a, 0x7e7c2228, 0x7bc00006, 0x00000000}},  //   _cura, _derp, _asmu,
  { {0xd7bc0309, 0x7afa1047, 0x00000000, 0x00000000}},  //   ्टाच, _altt,   ,
  { {0x6aaa0061, 0x7f5f0ea9, 0x3af50a78, 0x00000000}},  //   ffff, qqqq, зяйс,
  { {0x6d5c0937, 0x9b68007e, 0x00000000, 0x00000000}},  //   _fura, ішча_,   ,
  { {0x6d5c002d, 0x7f5d0197, 0x7bc000d4, 0x00000000}},  //   _gura, _husq, _esmu,
  { {0x629c0035, 0xddc70087, 0x621c08cd, 0x00000000}},  //   zgro, _kejž, יווק,
  { {0x7f5d028c, 0x2d9e0039, 0x6d5c0b55, 0x00000000}},  //   _jusq, _äter_, _zura,
  { {0x7e650bca, 0x7ae82229, 0x6d5c01a3, 0x00000000}},  //   nchp, _godt, _yura,
  { {0xe8550025, 0x00000000, 0x00000000, 0x00000000}},  //   _فناد,   ,   ,
  { {0x69c1222a, 0x629c222b, 0x26c300ca, 0x00000000}},  //   _isle, wgro, žjo_,
  { {0x629c00bb, 0x08760049, 0x81e80044, 0x00000000}},  //   tgro, _זענט_, _মেং_,
  { {0x254d00b9, 0xfbbd0044, 0x36c40088, 0x00000000}},  //   _měly_, _আপাত, _обіг,
  { {0x629c01b5, 0x867a009b, 0x91e60954, 0x00000000}},  //   rgro, _הרצו, чове,
  { {0x6d5a028c, 0x7f5d222c, 0x629c01b5, 0x00000000}},  //   _étai, _busq, sgro,
  { {0x6d5c0149, 0x7e7c033b, 0x629c00d4, 0x00000000}},  // [5560] _sura, _perp, pgro,
  { {0x6d5c01a3, 0xdfcf0025, 0x543600a1, 0x00000000}},  //   _pura, ديك_, _ورکر,
  { {0x7e7c0cac, 0xfc660265, 0x6d5c005f, 0x00000000}},  //   _verp, пълн, _qura,
  { {0x4096007c, 0x6d5c005d, 0x7e7c0328, 0x00000000}},  //   _эрот, _vura, _werp,
  { {0x7e7c020c, 0x92e900d3, 0x20570104, 0x00000000}},  //   _terp, _طریق_, _מיכל_,
  { {0x6d5c002a, 0x60c61a03, 0x386601ee, 0x00000000}},  //   _tura, _hakm, _sfor_,
  { {0x2bb8013d, 0x00000000, 0x00000000, 0x00000000}},  //   _इनका,   ,   ,
  { {0x61e1222d, 0xc8fc0044, 0xae1b009b, 0x00000000}},  //   älli, ুক্ত_, _הולכ,
  { {0x2d9a008e, 0x69c1002d, 0x60c604cb, 0x00000000}},  //   lupe_, _esle, _makm,
  { {0xd6da222e, 0x86260230, 0x60c60023, 0x00000000}},  //   сти_, зьме, _lakm,
  { {0x2fc70011, 0xcfb70044, 0x2d9a00e0, 0x00000000}},  //   ̉ng_, ুৎপন, nupe_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x395e002d, 0x3eba0173, 0x00000000, 0x00000000}},  //   _huts_, kept_,   ,
  { {0x66e301fb, 0xa1590816, 0x2d9a0465, 0x00000000}},  //   _поча, жаву_, kupe_,
  { {0x60c6014a, 0x2d9a02d0, 0x7f5d222f, 0x00000000}},  //   _bakm, jupe_, _susq,
  { {0x6ab90164, 0xd2500084, 0x395e2230, 0x00000000}},  //   _इस्र, انِ_, _muts_,
  { {0x60c600e0, 0x7e650133, 0x00000000, 0x00000000}},  // [5570] _dakm, tchp,   ,
  { {0x395e0f12, 0x00000000, 0x00000000, 0x00000000}},  //   _outs_,   ,   ,
  { {0x7e65106a, 0x00000000, 0x00000000, 0x00000000}},  //   rchp,   ,   ,
  { {0x7e6501a2, 0xbd180088, 0x00000000, 0x00000000}},  //   schp, пції_,   ,
  { {0xfbab07ca, 0x00000000, 0x00000000, 0x00000000}},  //   стей_,   ,   ,
  { {0x3eba2231, 0x395e009d, 0x3dc60036, 0x00000000}},  //   cept_, _buts_, łowa_,
  { {0xa9c40025, 0x2d9a009d, 0xceb20049, 0x00000000}},  //   فزيو, cupe_, _שיל_,
  { {0x6ca4003b, 0x25611a43, 0x395e00d4, 0x00000000}},  //   _пруж, _ról_, _duts_,
  { {0x25611530, 0x752f0036, 0x29030006, 0x00000000}},  //   _sól_, docz, ėja_,
  { {0x09bc0055, 0xca480014, 0x55892232, 0x00000000}},  //   _অপরা, _کلمه_, обом_,
  { {0x395e0ace, 0x69c105fa, 0xf212013d, 0x00000000}},  //   _guts_, _usle, _डेढ़_,
  { {0x3eba010f, 0x6b8900ea, 0x00000000, 0x00000000}},  //   zept_, _kveg,   ,
  { {0x60c62233, 0x00000000, 0x00000000, 0x00000000}},  //   _rakm,   ,   ,
  { {0x2561134d, 0x853d0006, 0x60c61de7, 0x00000000}},  //   _tól_, ntėj, _sakm,
  { {0x26c70026, 0x752f0036, 0xb0c9013d, 0x00000000}},  //   _iano_, bocz, ाएंग,
  { {0x78bb00b0, 0x26c70009, 0x69ce0204, 0x00000000}},  //   neuv, _hano_, थिती,
  { {0x26c71f72, 0x0326041f, 0x3eba001a, 0x00000000}},  // [5580] _kano_, _один, tept_,
  { {0x2480009f, 0x2d9a0142, 0x290f01d6, 0x00000000}},  //   _heim_, tupe_, _lmga_,
  { {0x26c7010a, 0x60c60027, 0x6b89061d, 0x00000000}},  //   _mano_, _takm, _aveg,
  { {0x2d9a2234, 0x3eba2235, 0x2d8700c4, 0x00000000}},  //   rupe_, sept_, ânea_,
  { {0x1ab401ab, 0x00000000, 0x00000000, 0x00000000}},  //   ебля,   ,   ,
  { {0x26c70065, 0x27e001d5, 0x78a20197, 0x00000000}},  //   _nano_, _ħin_, _scov,
  { {0x200d009f, 0x68eb001a, 0x2fc001d6, 0x00000000}},  //   _þeir_, _bogd, lwig_,
  { {0x478a11a6, 0x98a3003b, 0x7cde0035, 0x00000000}},  //   осом_, виће, _dărâ,
  { {0x2004006b, 0x7d020146, 0x00000000, 0x00000000}},  //   _ümid_, mhos,   ,
  { {0x7d020181, 0x26c70325, 0x752f0036, 0x00000000}},  //   lhos, _cano_, wocz,
  { {0x2480001f, 0x26c70181, 0x1515007c, 0x00000000}},  //   _beim_, _dano_, едня,
  { {0x7d0200c4, 0x78bb00f6, 0x00000000, 0x00000000}},  //   nhos, ceuv,   ,
  { {0x26c70197, 0x27e0005d, 0x752f0036, 0x00000000}},  //   _fano_, _çin_, rocz,
  { {0xe60f00a6, 0xf54a001d, 0x26c71ebf, 0x00000000}},  //   اشی_, _mấy_, _gano_,
  { {0xf54a001d, 0x925808fc, 0x752f0036, 0x00000000}},  //   _lấy_, дарт_, pocz,
  { {0x26c7016c, 0x6441006b, 0xd25805b8, 0x00000000}},  //   _zano_, əlin, ьця_,
  { {0x26c700e0, 0xf54a0082, 0x4ea70216, 0x00000000}},  // [5590] _yano_, _nấy_, дреа,
  { {0xf3ff0181, 0x26c700f6, 0x8afd013e, 0x00000000}},  //   lcão_, _xano_, _kuře,
  { {0x6b892236, 0x7d020e93, 0xe2a7000c, 0x00000000}},  //   _sveg, fhos, áður_,
  { {0x7d020010, 0xf54a0082, 0xf3ff00fa, 0x00000000}},  //   ghos, _bấy_, ncão_,
  { {0x3f9b006b, 0xf54a0082, 0x6ac80044, 0x00000000}},  //   ququ_, _cấy_, লানো,
  { {0xdb1b0051, 0x68eb0058, 0x539c00a3, 0x00000000}},  //   _tsuí, _sogd, קסוא,
  { {0x7d020161, 0x26c70871, 0xfe54007e, 0x00000000}},  //   bhos, _rano_, _акрэ,
  { {0x7d022237, 0xc7c8001d, 0x6b891d6a, 0x00000000}},  //   chos, _bố_, _tveg,
  { {0xc7c8001d, 0x26c7011c, 0x78bb1a5a, 0x00000000}},  //   _cố_, _pano_, reuv,
  { {0xeab00025, 0x3ea10020, 0x6e2a0023, 0x00000000}},  //   _نعم_, nght_, _ëmbë,
  { {0x3ea10857, 0x6d5a00f4, 0x26c70e32, 0x00000000}},  //   ight_, _état, _vano_,
  { {0xed590224, 0x673a0112, 0x26c70009, 0x00000000}},  //   _již_, altj, _wano_,
  { {0x394d028c, 0xdd0c0046, 0x26c70020, 0x00000000}},  //   mmes_, _różn, _tano_,
  { {0x394d1665, 0x00000000, 0x00000000, 0x00000000}},  //   lmes_,   ,   ,
  { {0x394d0129, 0x00000000, 0x00000000, 0x00000000}},  //   omes_,   ,   ,
  { {0x7d0201d6, 0x250800a1, 0x0446073b, 0x00000000}},  //   xhos, _زرعی_, _пейн,
  { {0x14dd0164, 0x1e960152, 0xc952009b, 0x00000000}},  // [55a0] यारण, ерер, רמן_,
  { {0x394d0efd, 0x2fc01996, 0x00000000, 0x00000000}},  //   hmes_, rwig_,   ,
  { {0x7d02001c, 0xf54a0011, 0x394d0d90, 0x00000000}},  //   thos, _sấy_, kmes_,
  { {0xa6de001d, 0xfd660011, 0x91360088, 0x00000000}},  //   _nhưn, _khuấ, _їхні,
  { {0x99bc0044, 0x28c3007d, 0x7d021747, 0x00000000}},  //   _অপেক, वजनि, rhos,
  { {0x2120092f, 0xada6007e, 0x7d020023, 0x00000000}},  //   lnih_, _пагл, shos,
  { {0xc7c800ad, 0x7d02002a, 0x6e4300ed, 0x00000000}},  //   _số_, phos, _берз,
  { {0x394d009d, 0xa6de0082, 0x3cff016c, 0x00000000}},  //   gmes_, _chưn, _gluv_,
  { {0xf76f007a, 0xf7720379, 0x7d00006c, 0x00000000}},  //   یای_, داع_, _ilms,
  { {0x09e60216, 0x394d2238, 0x2f0401e5, 0x00000000}},  //   _позн, ames_, _dögg_,
  { {0xceb3009b, 0x00000000, 0x00000000, 0x00000000}},  //   אית_,   ,   ,
  { {0xc7c8001d, 0x21200f3a, 0x3f890016, 0x00000000}},  //   _tố_, jnih_, ysau_,
  { {0x21200f3a, 0x25860802, 0xf7f303ab, 0x00000000}},  //   dnih_, _bílá_, _مسود,
  { {0x6441006b, 0xf3ff00c4, 0x644401c5, 0x00000000}},  //   əlil, scão_, _dzii,
  { {0x212000d0, 0x72280088, 0x00000000, 0x00000000}},  //   fnih_, ецтв_,   ,
  { {0xa63b009b, 0xd1382239, 0xe63b009b, 0x00000000}},  //   _מגור, еху_, _מתוכ,
  { {0x1017007a, 0x69170035, 0xed5900ca, 0x00000000}},  // [55b0] ربرد, nţea, _riž_,
  { {0x3ea100ab, 0x61e10039, 0x26cc0016, 0x00000000}},  //   ught_, älls, nddo_,
  { {0x21201034, 0x3f8901a2, 0x394d0838, 0x00000000}},  //   bnih_, ssau_, ymes_,
  { {0x21201279, 0x5ce4005c, 0x3f89223a, 0x00000000}},  //   cnih_, люча, psau_,
  { {0x60cd006a, 0xfaa5004c, 0x2cbd01f3, 0x00000000}},  //   mdam, вало, rewd_,
  { {0x60cd0004, 0x62870142, 0x386903b2, 0x00000000}},  //   ldam, najo, _żar_,
  { {0x60cd010a, 0xf2d40049, 0x394d223b, 0x00000000}},  //   odam, טעס_, tmes_,
  { {0x60cd0114, 0xe8bd0061, 0x6f17004a, 0x00000000}},  //   ndam, ्येच, lixc,
  { {0x394d03d5, 0xf77101d8, 0x20090026, 0x00000000}},  //   rmes_, جاب_, nzai_,
  { {0x2120092f, 0x394d0bdb, 0x62870059, 0x00000000}},  //   znih_, smes_, jajo,
  { {0x62870d0a, 0x44290716, 0x60cd0006, 0x00000000}},  //   dajo, _axa_, kdam,
  { {0xb815025f, 0xdb1b002d, 0x290405eb, 0x00000000}},  //   _идеј, _iruñ, chma_,
  { {0x2120092f, 0x6d49002a, 0x60cd0197, 0x00000000}},  //   vnih_, _mhea, ddam,
  { {0xe61100d3, 0x60dd0173, 0x68e9016e, 0x00000000}},  //   _پشت_, _ansm, ljed,
  { {0x2120092f, 0x5eca0055, 0x442900fa, 0x00000000}},  //   tnih_, রামে, _exa_,
  { {0x60cd13b1, 0x68fb1e17, 0x2f0401a2, 0x00000000}},  //   gdam, nkud, _möge_,
  { {0x62870211, 0x21200340, 0xb4db0129, 0x00000000}},  // [55c0] bajo, rnih_, rmàt,
  { {0x21200295, 0x6d4900ab, 0x656300b0, 0x00000000}},  //   snih_, _ahea, _kunh,
  { {0x6d49002a, 0x656302d5, 0x2120092f, 0x00000000}},  //   _bhea, _junh, pnih_,
  { {0x6d49223c, 0x68e916d0, 0x7bc20173, 0x00000000}},  //   _chea, jjed, twou,
  { {0x6d49223d, 0x26cc018e, 0x6d5b0022, 0x00000000}},  //   _dhea, yddo_, _diua,
  { {0x6d490b3d, 0x7bc20112, 0x00000000, 0x00000000}},  //   _ehea, rwou,   ,
  { {0xe567004b, 0x6563027b, 0x6d49002a, 0x00000000}},  //   _خط_, _nunh, _fhea,
  { {0x6d49002a, 0x68e90065, 0x2004000c, 0x00000000}},  //   _ghea, gjed, _ýmis_,
  { {0xaae20309, 0x7c3b0010, 0x6e3c00f8, 0x00000000}},  //   पादक, _gyur, _hyrb,
  { {0x81b90055, 0x60cd0091, 0x29040f3e, 0x00000000}},  //   চিত_, zdam, shma_,
  { {0xdb1b223e, 0x68e90209, 0x65630181, 0x00000000}},  //   _usuá, bjed, _cunh,
  { {0x6563049a, 0xdddc0119, 0x26ca0059, 0x00000000}},  //   _dunh, _održ, žbo_,
  { {0xd7060ad9, 0x62870089, 0x60cd1793, 0x00000000}},  //   _изди, tajo, vdam,
  { {0xd5b00014, 0x6563223f, 0x69170035, 0x00000000}},  //   _هفت_, _funh, nţen,
  { {0x30a701e1, 0x60cd0146, 0x363300a6, 0x00000000}},  //   крав, tdam, _پروس,
  { {0x44290ab4, 0x62870052, 0x60cd007f, 0x00000000}},  //   _txa_, sajo, udam,
  { {0x628700ca, 0x6d5b00f6, 0x14190025, 0x00000000}},  // [55d0] pajo, _riua, _سيدة_,
  { {0x60cd0006, 0xdf390025, 0x7f5c009d, 0x00000000}},  //   sdam, ركات_, _cirq,
  { {0x6d490051, 0x24920016, 0x7f5c0009, 0x00000000}},  //   _phea, _ydym_, _dirq,
  { {0xdd94008b, 0x20092240, 0xada40088, 0x00000000}},  //   рацы, pzai_, раїл,
  { {0x68e90243, 0x62852241, 0xeab90401, 0x00000000}},  //   vjed, _keho, ейл_,
  { {0x628500b9, 0x93fc01ce, 0x6d490133, 0x00000000}},  //   _jeho, ולדי, _whea,
  { {0x3c9301ef, 0x6d490122, 0x443e0082, 0x00000000}},  //   _نیاز, _thea, ́t_,
  { {0x6d5a00f4, 0x17c9047d, 0x7c29002d, 0x00000000}},  //   _étap, егии_, _txer,
  { {0x69c80129, 0x68e90010, 0x7b990014, 0x00000000}},  //   _esde, rjed, _سپاس_,
  { {0x68e90243, 0x62850161, 0x656300c4, 0x00000000}},  //   sjed, _neho, _punh,
  { {0x941e005f, 0xdddc00e5, 0x00000000, 0x00000000}},  //   ətə_, _ierţ,   ,
  { {0xf2c9061e, 0x5a0c0049, 0x97c5002c, 0x00000000}},  //   _מע_, _קלאַ, _مقصو,
  { {0x9cd60104, 0x6441006b, 0x48e0013d, 0x00000000}},  //   אורה_, əlik, कारो_,
  { {0xe363003b, 0x386d003b, 0x62851140, 0x00000000}},  //   скри, lcer_, _ceho,
  { {0x021901fb, 0x62852242, 0xd04f006b, 0x00000000}},  //   віть_, _deho, _incə,
  { {0x386d2243, 0x00000000, 0x00000000, 0x00000000}},  //   ncer_,   ,   ,
  { {0x6143025f, 0x7f5c004a, 0x00000000, 0x00000000}},  // [55e0] сета, _pirq,   ,
  { {0x62850fe2, 0x82360879, 0x6d43009d, 0x00000000}},  //   _geho, _مرجا, înan,
  { {0x386d0022, 0x00000000, 0x00000000, 0x00000000}},  //   kcer_,   ,   ,
  { {0x1636007b, 0x7e4b00a1, 0x00000000, 0x00000000}},  //   אנער_, رسلہ_,   ,
  { {0x925a007a, 0xaff5026c, 0xdddc01ca, 0x00000000}},  //   _تشکر_, _پہلا_, _udrž,
  { {0x386d00c4, 0xbb830025, 0x6e3c16f5, 0x00000000}},  //   ecer_, حلوي, _tyrb,
  { {0x14aa0061, 0x5f030c27, 0x7bc90035, 0x00000000}},  //   _काढण, _узра, _eseu,
  { {0xdbca010e, 0x3dca00d9, 0x6b4400d4, 0x00000000}},  //   _sõõr, _isbw_, cògn,
  { {0x1d07007c, 0x99470025, 0x28b30025, 0x00000000}},  //   _сети_, دليل_, صحيح,
  { {0x5694025f, 0x35b4007e, 0x00000000, 0x00000000}},  //   јант, абор,   ,
  { {0xdbca006c, 0xe814013d, 0x62850142, 0x00000000}},  //   _võõr, _तेरा_, _reho,
  { {0x6917001a, 0x2ca6011c, 0x386d00ab, 0x00000000}},  //   nţel, ngod_, ccer_,
  { {0x62852244, 0xab00000c, 0x63af0045, 0x00000000}},  //   _peho, _þjóð_, utcn,
  { {0xf53f080a, 0x00000000, 0x00000000, 0x00000000}},  //   slå_,   ,   ,
  { {0x62851978, 0x2b5e0145, 0xd5a208d4, 0x00000000}},  //   _veho, _mitc_, _العی,
  { {0x2eff009d, 0x212d013e, 0x63ad0066, 0x00000000}},  //   _œuf_, čeho_, _tqan,
  { {0x62852245, 0xa29501e1, 0x2ca6016c, 0x00000000}},  // [55f0] _teho, _капі, dgod_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8afc0046, 0x7bc901c3, 0x84e808d4, 0x00000000}},  //   _międ, _sseu, _شفیق_,
  { {0x7bc900f4, 0x00000000, 0x00000000, 0x00000000}},  //   _pseu,   ,   ,
  { {0x92e70044, 0x00000000, 0x00000000, 0x00000000}},  //   পসী_,   ,   ,
  { {0x60cf1841, 0x49950216, 0xff04007e, 0x00000000}},  //   _hacm, ашит, _лясн,
  { {0x7e74026c, 0x53380049, 0x1af90044, 0x00000000}},  //   _چاہئ, אנגן_, ্চলে_,
  { {0x60cf18d9, 0x00000000, 0x00000000, 0x00000000}},  //   _jacm,   ,   ,
  { {0x2f040039, 0x2ca021e7, 0x39430089, 0x00000000}},  //   _höga_, óide_, ējs_,
  { {0xc9871b49, 0x386d0181, 0x60cf00f6, 0x00000000}},  //   _буди, scer_, _lacm,
  { {0xa50a0794, 0x2fcb012d, 0x8afc0036, 0x00000000}},  //   вена_, _lscg_, _sięg,
  { {0x69dc029d, 0x27e0016c, 0x7dd00010, 0x00000000}},  //   _área, _šine_, lósá,
  { {0x888c0049, 0x261501f5, 0x66e50bb8, 0x00000000}},  //   _טראַ, _फेरी_, _вола,
  { {0x39ae006b, 0x00000000, 0x00000000, 0x00000000}},  //   _səsi_,   ,   ,
  { {0x2ca6005b, 0x00000000, 0x00000000, 0x00000000}},  //   ygod_,   ,   ,
  { {0x61e10039, 0x60262246, 0x6448006b, 0x00000000}},  //   ålla, адба, ədin,
  { {0x8fa600e3, 0x1e8610e1, 0x8e86007c, 0x00000000}},  // [5600] разе, илам, игае,
  { {0xbe850054, 0x2fcb0115, 0x27e00048, 0x00000000}},  //   مجمو, _dscg_, _áine_,
  { {0x127b0049, 0x729b009b, 0xe29b009b, 0x00000000}},  //   _שאטע, _בסיס, _בשיר,
  { {0x8fa6008b, 0x33380061, 0xdddc0087, 0x00000000}},  //   _каме, lorx_, _cerš,
  { {0x69170035, 0x2ca60048, 0x60c40924, 0x00000000}},  //   rţel, rgod_, meim,
  { {0x2ca60016, 0x60c400e7, 0x99d60025, 0x00000000}},  //   sgod_, leim, لتعا,
  { {0x79450046, 0x2ca600e0, 0x00000000, 0x00000000}},  //   równ, pgod_,   ,
  { {0x60c40052, 0xdca30364, 0x940c006b, 0x00000000}},  //   neim, _маси, şdə_,
  { {0xfaa602dc, 0x082a005e, 0x6d42016b, 0x00000000}},  //   _вазо, ъцки_, mloa,
  { {0x60c400db, 0xd6da2247, 0x6d420032, 0x00000000}},  //   heim, тти_, lloa,
  { {0x3ed9007b, 0xa3a90164, 0x4ed90049, 0x00000000}},  //   אַרא, खून_, אַרנ,
  { {0x69da002d, 0x6d421a8d, 0x25090014, 0x00000000}},  //   _irte, nloa, اردی_,
  { {0x68e2008e, 0x442d0023, 0x60c4005b, 0x00000000}},  //   _inod, çe_, deim,
  { {0x81c3001e, 0x6566012b, 0x2fcb0009, 0x00000000}},  //   ņēmu, _књиж, _rscg_,
  { {0x316800ec, 0x6d42002d, 0xdbd1000c, 0x00000000}},  //   ишто_, kloa, _lýðr,
  { {0x6d42001a, 0x69da17d8, 0x00000000, 0x00000000}},  //   jloa, _mrte,   ,
  { {0x6e67004c, 0x6d422248, 0xa1580a27, 0x00000000}},  // [5610] атеж, dloa, рату_,
  { {0x69da06d3, 0xa857009b, 0x6d420146, 0x00000000}},  //   _orte, שימה_, eloa,
  { {0xdddc0b4d, 0x23690065, 0x6d422249, 0x00000000}},  //   _perš, _huaj_, floa,
  { {0x60c41e3c, 0x657a0048, 0x00000000, 0x00000000}},  //   ceim, ipth,   ,
  { {0x69da15cd, 0xee870057, 0x23690065, 0x00000000}},  //   _arte, _выбо, _juaj_,
  { {0x68e20016, 0x23690065, 0x8d7700a6, 0x00000000}},  //   _anod, _muaj_, _نارا,
  { {0x6ef30224, 0xa3a9006e, 0xdd94007e, 0x00000000}},  //   _výbě, खंड_, _мары,
  { {0x77850088, 0x6d4201a2, 0x24890035, 0x00000000}},  //   близ, cloa, _neam_,
  { {0x69da014a, 0x2369000a, 0xe0df0082, 0x00000000}},  //   _erte, _nuaj_, _chòi_,
  { {0x68e200ca, 0xd706007c, 0x7c240048, 0x00000000}},  //   _enod, йные_, úire,
  { {0x24892082, 0x00000000, 0x00000000, 0x00000000}},  //   _beam_,   ,   ,
  { {0x7bdb03b6, 0x00000000, 0x00000000, 0x00000000}},  //   _kruu,   ,   ,
  { {0x387f1105, 0xb4c8013d, 0x61e10039, 0x00000000}},  //   mbur_, _उसी_, ålln,
  { {0xa2ad0061, 0x6448006b, 0x78a9224a, 0x00000000}},  //   _जाण्, ədil, lgev,
  { {0x60c4001b, 0x00000000, 0x00000000, 0x00000000}},  //   teim,   ,   ,
  { {0x78a900b5, 0xf0660818, 0x24890035, 0x00000000}},  //   ngev, скап, _geam_,
  { {0x60c400b0, 0x939603ec, 0x00000000, 0x00000000}},  // [5620] reim, _اجبا,   ,
  { {0xb33b011f, 0x26c501ee, 0x2cad00f6, 0x00000000}},  //   nuçl, nelo_, _aced_,
  { {0x628e082c, 0xa3ba0123, 0x25a51c95, 0x00000000}},  //   mabo, _شاکر_, null_,
  { {0x7bdb08e0, 0x26c5008e, 0x2f04000c, 0x00000000}},  //   _bruu, helo_, _gögn_,
  { {0x78a90112, 0x25a50023, 0x6d420133, 0x00000000}},  //   dgev, hull_, rloa,
  { {0x26c50209, 0x628e0016, 0x25a50065, 0x00000000}},  //   jelo_, nabo, kull_,
  { {0x26c5049a, 0x00000000, 0x00000000, 0x00000000}},  //   delo_,   ,   ,
  { {0x69da0618, 0x78a9046a, 0x628e011c, 0x00000000}},  //   _vrte, ggev, habo,
  { {0x7d021a20, 0x628e224b, 0x7bdb224c, 0x00000000}},  //   mkos, kabo, _gruu,
  { {0x25a505ad, 0x26c50026, 0x628e01ee, 0x00000000}},  //   full_, gelo_, jabo,
  { {0xd6d704af, 0x69da022b, 0x25a50ac7, 0x00000000}},  //   сты_, _urte, gull_,
  { {0x7d020006, 0x68e20af2, 0x387f0180, 0x00000000}},  //   nkos, _unod, cbur_,
  { {0x26c5224d, 0x38660c30, 0x14aa0309, 0x00000000}},  //   belo_, _igor_, _कारण,
  { {0x26c5049a, 0x628e01aa, 0x25a500ea, 0x00000000}},  //   celo_, gabo, bull_,
  { {0x248901ac, 0x41e401ff, 0x25a50129, 0x00000000}},  //   _team_, піта, cull_,
  { {0x2369008d, 0x673a0129, 0xa2d9007d, 0x00000000}},  //   _tuaj_, lotj, _फोर्,
  { {0x752d0145, 0x7d020142, 0x00000000, 0x00000000}},  // [5630] _ijaz, dkos,   ,
  { {0x2fc90007, 0x644d01c5, 0x628e0197, 0x00000000}},  //   rwag_, _izai, cabo,
  { {0x7d020116, 0x00000000, 0x00000000, 0x00000000}},  //   fkos,   ,   ,
  { {0x30a70057, 0x7bdb006c, 0x26c5013e, 0x00000000}},  //   _уров, _pruu, zelo_,
  { {0x752d0202, 0x25a50023, 0x26c500e0, 0x00000000}},  //   _mjaz, zull_, yelo_,
  { {0x3866018e, 0x49990ae0, 0xe0df000a, 0x00000000}},  //   _agor_, атия_, _chòv_,
  { {0x26c5037e, 0x78a9015c, 0x28da0164, 0x00000000}},  //   velo_, tgev, _मोहि,
  { {0xb4c803d7, 0x14d90061, 0x672800bb, 0x00000000}},  //   _उसे_, _बोलण, endj,
  { {0x78a900b5, 0x26c508d3, 0x628e0058, 0x00000000}},  //   rgev, telo_, yabo,
  { {0x80d20055, 0x78a900c7, 0x25a50065, 0x00000000}},  //   হায্, sgev, tull_,
  { {0x8afc0046, 0x628e1732, 0x26c50181, 0x00000000}},  //   _więc, vabo, relo_,
  { {0x63a60aa5, 0x25a501b8, 0x6f1e0009, 0x00000000}},  //   tukn, rull_, zipc,
  { {0x80d20055, 0x26c50059, 0x752d01aa, 0x00000000}},  //   হাম্, pelo_, _djaz,
  { {0x25a50065, 0x63a6224e, 0x7d09224f, 0x00000000}},  //   pull_, rukn, _lles,
  { {0x628e1591, 0x39ae006b, 0x7d1b0061, 0x00000000}},  //   rabo, _həsr_, _omus,
  { {0x628e011c, 0xb1460245, 0x69c12250, 0x00000000}},  //   sabo, інал, _mple,
  { {0xef1a0269, 0x628e0058, 0x00000000, 0x00000000}},  // [5640] ама_, pabo,   ,
  { {0x7d092251, 0x69c11e68, 0x27ed04bd, 0x00000000}},  //   _ales, _ople, ixen_,
  { {0x6f1e095e, 0x7d0200b0, 0x656400b0, 0x00000000}},  //   ripc, tkos, _kiih,
  { {0xf767006d, 0x76430016, 0x7d0907b9, 0x00000000}},  //   _يا_, _myny, _cles,
  { {0x7d0200b0, 0x6b4404bd, 0x69c12252, 0x00000000}},  //   rkos, lògi, _aple,
  { {0x60d6010a, 0x1af3007e, 0x69c10048, 0x00000000}},  //   ldym, мпія, _bple,
  { {0xa2ad001c, 0xf98f0379, 0xd90d00a6, 0x00000000}},  //   _जास्, نبي_, گین_,
  { {0xd7c80558, 0x60d60006, 0x44320082, 0x00000000}},  //   موعه_, ndym, _oxy_,
  { {0xd90d06c6, 0x69c100ea, 0x752d1962, 0x00000000}},  //   دین_, _eple, _rjaz,
  { {0x7d1b0036, 0x2ef80068, 0x00000000, 0x00000000}},  //   _zmus, _jorf_,   ,
  { {0x76430016, 0x752d002b, 0x673a0059, 0x00000000}},  //   _cyny, _pjaz, rotj,
  { {0x290d0937, 0xe9ff0011, 0x37e6007c, 0x00000000}},  //   chea_, _hiếm_, _моег,
  { {0xe9ff001d, 0x8d5b007b, 0x60d60016, 0x00000000}},  //   _kiếm_, יכטי, ddym,
  { {0x76430016, 0x9943014a, 0x00000000, 0x00000000}},  //   _fyny, _kış_,   ,
  { {0x32050d7f, 0x21292253, 0x764310fd, 0x00000000}},  //   ály_, tnah_, _gyny,
  { {0x77630023, 0x644d0032, 0x752d1f3f, 0x00000000}},  //   _zinx, _tzai, _ujaz,
  { {0xc05b01fb, 0x2129020c, 0x644d0089, 0x00000000}},  // [5650] рів_, rnah_, _uzai,
  { {0x79450036, 0x753d2254, 0x7d0901c6, 0x00000000}},  //   tówk, losz, _sles,
  { {0x2d870e16, 0x7d090209, 0x2ef82255, 0x00000000}},  //   ène_, _ples, _dorf_,
  { {0x753d0ef2, 0x79450036, 0x2d4700c4, 0x00000000}},  //   nosz, rówk, põem_,
  { {0x69c12256, 0x999e00b9, 0xe9ff0082, 0x00000000}},  //   _sple, _bytů_, _biếm_,
  { {0x79450046, 0x6d4000f8, 0xeb9600c0, 0x00000000}},  //   mówi, _ekma, чиш_,
  { {0x290d018d, 0x7d09002b, 0x753d0f88, 0x00000000}},  //   thea_, _tles, kosz,
  { {0x6ca42257, 0x7d1b1bf2, 0x9943014a, 0x00000000}},  //   _оруж, _umus, _dış_,
  { {0x47c2007c, 0x65640052, 0x6d591a91, 0x00000000}},  //   ебыв, _riih, mmwa,
  { {0x6564021e, 0xd7091001, 0x290d00e7, 0x00000000}},  //   _siih, сное_, shea_,
  { {0x27ff0058, 0x60d6005b, 0x69c101ed, 0x00000000}},  //   syun_, ydym, _uple,
  { {0x753d0010, 0x6b890009, 0x9cf90044, 0x00000000}},  //   gosz, _kweg, _আগুন_,
  { {0x437500ed, 0x656400b0, 0x77631347, 0x00000000}},  //   дуст, _viih, _tinx,
  { {0xe6890025, 0xd066006b, 0x00000000, 0x00000000}},  //   _انثى_, əqəl,   ,
  { {0x67210f86, 0xcaf40061, 0x753d2258, 0x00000000}},  //   milj, _अवघड_, bosz,
  { {0x672102d8, 0x016301ab, 0x00000000, 0x00000000}},  //   lilj, ексо,   ,
  { {0x442600c4, 0x60d610fd, 0x5c260044, 0x00000000}},  // [5660] _ão_, rdym, _বর্গ_,
  { {0x672120d6, 0xe0df000a, 0x9f5f000c, 0x00000000}},  //   nilj, _akòd_, órða_,
  { {0x02fb00b3, 0x660100ea, 0x42fb009b, 0x00000000}},  //   _הלימ, nylk, _ההיס,
  { {0xccf90046, 0x61e10030, 0x656e0051, 0x00000000}},  //   _coś_, ælle, íbhi,
  { {0x67212259, 0xead40878, 0x2ef81156, 0x00000000}},  //   kilj, доль, _torf_,
  { {0x67210521, 0x291d000a, 0x660106d5, 0x00000000}},  //   jilj, _amwa_, kylk,
  { {0x67210091, 0x99d30025, 0x9943006b, 0x00000000}},  //   dilj, فتيا, _qış_,
  { {0x8b6606b4, 0x97a60216, 0x2d98009d, 0x00000000}},  //   _فاطم, прол, _ivre_,
  { {0x67210337, 0x6b89005b, 0xed57034b, 0x00000000}},  //   filj, _gweg, _хот_,
  { {0x9f9b010f, 0x660105ed, 0x95ca02dc, 0x00000000}},  //   _läßt_, fylk, бума_,
  { {0xd90f008b, 0x7ae80018, 0xe947026c, 0x00000000}},  //   _зь_, _indt, _کرلی,
  { {0x7afa0133, 0x00000000, 0x00000000, 0x00000000}},  //   _hott,   ,   ,
  { {0x67210119, 0x753d0c59, 0x7afa225a, 0x00000000}},  //   bilj, rosz, _kott,
  { {0x67210209, 0x7afa00b0, 0x2d980190, 0x00000000}},  //   cilj, _jott, _ovre_,
  { {0x2d9c02d5, 0x7afa0292, 0x76bb009b, 0x00000000}},  //   ável_, _mott, _המופ,
  { {0xd5b80089, 0x00000000, 0x00000000, 0x00000000}},  //   mtā_,   ,   ,
  { {0x4034007c, 0x88bd0036, 0xd5b80089, 0x00000000}},  // [5670] еетс, liśc, ltā_,
  { {0x7afa0207, 0x6b890e92, 0x42750581, 0x00000000}},  //   _nott, _rweg, _югос,
  { {0xd5b80089, 0x6b890036, 0x2cbf0022, 0x00000000}},  //   ntā_, _sweg, _pbud_,
  { {0x7ae8225b, 0xd5b80089, 0x00000000, 0x00000000}},  //   _andt, itā_,   ,
  { {0x7afa0472, 0x2d981ed5, 0x00000000, 0x00000000}},  //   _bott, _evre_,   ,
  { {0xd5b80089, 0xaa880025, 0x7afa085d, 0x00000000}},  //   ktā_, كنهم_, _cott,
  { {0x7afa1340, 0x6721225c, 0x68f900ab, 0x00000000}},  //   _dott, vilj, _powd,
  { {0x7ae80030, 0x2cbf0093, 0x6b89225d, 0x00000000}},  //   _endt, _ubud_, _tweg,
  { {0x2d9e0039, 0x7afa0197, 0x67210091, 0x00000000}},  //   _åter_, _fott, tilj,
  { {0x7afa1153, 0x6673007a, 0xd75600a1, 0x00000000}},  //   _gott, رگتر, وليت_,
  { {0x64a6007e, 0xcb12009b, 0x00000000, 0x00000000}},  //   мана, _שלב_,   ,
  { {0x67210c1e, 0x92ea0044, 0x00000000, 0x00000000}},  //   silj, _মতে_,   ,
  { {0x6721022e, 0x00000000, 0x00000000, 0x00000000}},  //   pilj,   ,   ,
  { {0xf62501fc, 0x88bd0036, 0x2bc0013d, 0x00000000}},  //   _одло, biśc, _एहसा,
  { {0x6146138c, 0xc5d50088, 0xc7b90010, 0x00000000}},  //   дева, _ціль, ltő_,
  { {0x70a80061, 0xd01200a1, 0xdb02225e, 0x00000000}},  //   गलेल, نلز_, troë,
  { {0xc7b90010, 0x4aae0061, 0x61430131, 0x00000000}},  // [5680] ntő_, _घालव, тета,
  { {0x3f800006, 0x00000000, 0x00000000, 0x00000000}},  //   rpiu_,   ,   ,
  { {0x7afa0692, 0x8236026c, 0xdd8f0380, 0x00000000}},  //   _rott, _زردا, لول_,
  { {0x0c260057, 0x7afa0409, 0x69dc000c, 0x00000000}},  //   ммен, _sott, _árei,
  { {0xe7d80055, 0xeb9701fc, 0x7afa124c, 0x00000000}},  //   _তথ্য, дич_, _pott,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d68011f, 0x7afa000c, 0x2d980068, 0x00000000}},  //   _eğer_, _vott, _uvre_,
  { {0x92ea0055, 0xa022014a, 0x00000000, 0x00000000}},  //   _মতো_, _şöyl,   ,
  { {0xb8d60164, 0x629e0395, 0x7afa00b0, 0x00000000}},  //   _जा_, _odpo, _tott,
  { {0x35f409ae, 0x6b82225f, 0x7ae80030, 0x00000000}},  //   епор, mpog, _undt,
  { {0xda650025, 0x00000000, 0x00000000, 0x00000000}},  //   _كامي,   ,   ,
  { {0xd5b80089, 0x629e01cf, 0x63a600d0, 0x00000000}},  //   rtā_, _adpo, frkn,
  { {0xd5b8001e, 0x80a20061, 0x00000000, 0x00000000}},  //   stā_, गणने,   ,
  { {0x17540e09, 0x65940364, 0xd703005e, 0x00000000}},  //   _явля, _заку, _изчи,
  { {0x26cc008e, 0x399a0089, 0x00000000, 0x00000000}},  //   medo_, nīs_,   ,
  { {0x26cc0211, 0x6907004a, 0x656e0048, 0x00000000}},  //   ledo_, _añej, íbhu,
  { {0x6b820746, 0x6133002b, 0x9f552260, 0x00000000}},  // [5690] jpog, għla, евач,
  { {0x3ed50025, 0x629e0026, 0x6b8200ca, 0x00000000}},  //   عقار, _gdpo, dpog,
  { {0xdb020068, 0x00000000, 0x00000000, 0x00000000}},  //   croé,   ,   ,
  { {0x62952261, 0x399a0089, 0xa2bb01f5, 0x00000000}},  //   lazo, dīs_, श्र्,
  { {0x50640780, 0x60cd0020, 0x3f790049, 0x00000000}},  //   _атра, meam, _מאָס,
  { {0x6295000b, 0x60cd002a, 0x26cc01ed, 0x00000000}},  //   nazo, leam, jedo_,
  { {0x8d7403d9, 0x00000000, 0x00000000, 0x00000000}},  //   _لاقا,   ,   ,
  { {0x60cd002a, 0x62952262, 0xc7b90010, 0x00000000}},  //   neam, hazo, ttő_,
  { {0x62950142, 0xf77106dd, 0x7d0400b0, 0x00000000}},  //   kazo, داب_, öise,
  { {0x6d4b1c77, 0x60cd0051, 0x6b9b0009, 0x00000000}},  //   llga, heam, _ivug,
  { {0x62952263, 0x2d73016c, 0x60cd00b0, 0x00000000}},  //   dazo, _oćem_, keam,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe72e03dc, 0x60cd2264, 0x26cc008e, 0x00000000}},  //   _бе_, deam, bedo_,
  { {0x26cc00c4, 0x62950010, 0x6b9b0009, 0x00000000}},  //   cedo_, gazo, _mvug,
  { {0xa18a0265, 0xa50a00e3, 0x6b8200ca, 0x00000000}},  //   ябва_, _нека_, zpog,
  { {0x61e10030, 0x6441010f, 0x6440006c, 0x00000000}},  //   ælla, ßlic, ümis,
  { {0x4fa3003b, 0x8fa30c96, 0xb4cc01f5, 0x00000000}},  // [56a0] литв, лате, रजी_,
  { {0x6d4b014f, 0x29d11cfc, 0x6295004a, 0x00000000}},  //   elga, _oša_, cazo,
  { {0x6b9b0061, 0x60cd021f, 0x7bde0089, 0x00000000}},  //   _avug, beam, āpum,
  { {0xe5720049, 0x26cc012d, 0x00000000, 0x00000000}},  //   אַס_, zedo_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x399a001e, 0x290f154c, 0x6d4b0ddc, 0x00000000}},  //   tīs_, _alga_, alga,
  { {0x26cc0181, 0x13c90044, 0x6b820089, 0x00000000}},  //   vedo_, শিয়, spog,
  { {0xa9670080, 0xdb022265, 0xdcfe0089, 0x00000000}},  //   нија_, croî, rspē,
  { {0x399a0089, 0x62950d06, 0xeab20647, 0x00000000}},  //   sīs_, yazo, _معا_,
  { {0x8afc0036, 0xb33b014a, 0x68eb0239, 0x00000000}},  //   _mięk, nuçt, _engd,
  { {0x26cc0a15, 0x62952266, 0x60cd00e7, 0x00000000}},  //   redo_, vazo, yeam,
  { {0x26cc2267, 0x2ca00051, 0x62951f3f, 0x00000000}},  //   sedo_, óidh_, wazo,
  { {0x04670057, 0x62950471, 0x26cc04a5, 0x00000000}},  //   этом, tazo, pedo_,
  { {0x6d42010e, 0xdc12013f, 0x00000000, 0x00000000}},  //   hooa, nğıc,   ,
  { {0x60cd0056, 0xdb0204f3, 0x00000000, 0x00000000}},  //   team, ntoñ,   ,
  { {0x6295013e, 0x69c80022, 0x00000000, 0x00000000}},  //   sazo, _mpde,   ,
  { {0x6d4b001c, 0x6295027b, 0x60cd0122, 0x00000000}},  // [56b0] vlga, pazo, ream,
  { {0x60cd001a, 0x63af0107, 0x69c80190, 0x00000000}},  //   seam, mucn, _opde,
  { {0x60cd2268, 0x63bd0c3f, 0x6b9b0091, 0x00000000}},  //   peam, ltsn, _svug,
  { {0xeb090164, 0x764a018e, 0xc0ab0025, 0x00000000}},  //   वस्त_, _myfy, _عاجل_,
  { {0x4ea70080, 0x69c80e07, 0x63bd0146, 0x00000000}},  //   _прва, _apde, ntsn,
  { {0x9f3501fb, 0xfe70023c, 0x4ea70f62, 0x00000000}},  //   _регі, _هدف_, _ярма,
  { {0xae1e0061, 0x8f340088, 0x9f340088, 0x00000000}},  //   _येऊन_, _серц, _сері,
  { {0x22450861, 0x00000000, 0x00000000, 0x00000000}},  //   ýlky_,   ,   ,
  { {0x63af0e00, 0x6b9b0117, 0x00000000, 0x00000000}},  //   jucn, _uvug,   ,
  { {0x63af0ebe, 0x55e50594, 0x394600fa, 0x00000000}},  //   ducn, вооб, _ekos_,
  { {0x764a0016, 0x290f011c, 0x8afa0049, 0x00000000}},  //   _cyfy, _tlga_, _קלעז,
  { {0x68eb0b16, 0x2f040039, 0xb4ac01f5, 0x00000000}},  //   _ungd, _högt_, खले_,
  { {0x63af037e, 0x2d470181, 0x394d2269, 0x00000000}},  //   gucn, lões_, mles_,
  { {0x394d02b6, 0x395f0a0e, 0x764a0016, 0x00000000}},  //   lles_, lmus_, _fyfy,
  { {0x764a0016, 0x320c04bb, 0x63bd00bb, 0x00000000}},  //   _gyfy, ády_, atsn,
  { {0x394d049a, 0xdddc010a, 0x8afc0036, 0x00000000}},  //   nles_, _perž, _pięk,
  { {0x394d00f4, 0x2d4700c4, 0x75241b75, 0x00000000}},  // [56c0] iles_, hões_, _imiz,
  { {0x395f226a, 0xdddc226b, 0x00000000, 0x00000000}},  //   hmus_, _verž,   ,
  { {0x8afc0046, 0x394d0006, 0xe0df000a, 0x00000000}},  //   _więk, kles_, _ikòn_,
  { {0x6da3226c, 0x2d4700c4, 0x6026007e, 0x00000000}},  //   рица, dões_, _адма,
  { {0x2f04000c, 0xdd0c0036, 0x394d1d9f, 0x00000000}},  //   _sögu_, _półn, dles_,
  { {0x394d0181, 0xf9c60152, 0x3946226d, 0x00000000}},  //   eles_, вщин, _skos_,
  { {0x2d4700c4, 0x6c860025, 0x394d0dcb, 0x00000000}},  //   gões_, _للأم, fles_,
  { {0x394d0322, 0x3ced0521, 0x3cff0bf2, 0x00000000}},  //   gles_, _gnev_, _gouv_,
  { {0xab6606b6, 0xb4db00f6, 0x00000000, 0x00000000}},  //   _авал, ilàt,   ,
  { {0x394d226e, 0x7d000ff4, 0x75240377, 0x00000000}},  //   ales_, _homs, _amiz,
  { {0x394d1da8, 0xceb300b6, 0x7d00226f, 0x00000000}},  //   bles_, בית_, _koms,
  { {0x394d028a, 0x98a30794, 0x63bd02e1, 0x00000000}},  //   cles_, _вице, ttsn,
  { {0x7d00032e, 0x39440006, 0x27e005d7, 0x00000000}},  //   _moms, moms_, _éin_,
  { {0x63af2270, 0x63bd0056, 0x39442271, 0x00000000}},  //   rucn, rtsn, loms_,
  { {0x5757009b, 0x67281300, 0x92942272, 0x00000000}},  //   _שבוע_, midj, расц,
  { {0x39442273, 0x75240a11, 0x26dc00bb, 0x00000000}},  //   noms_, _gmiz, _havo_,
  { {0x2d470181, 0x26dc09ca, 0x93470025, 0x00000000}},  // [56d0] zões_, _kavo_, _لخدم,
  { {0x3f9b19f3, 0x395f1db8, 0x752401ca, 0x00000000}},  //   rsqu_, zmus_, _zmiz,
  { {0x8d740647, 0x39440343, 0x395f0006, 0x00000000}},  //   لانا, koms_, ymus_,
  { {0x7d001cf6, 0x39440d90, 0x27e600f8, 0x00000000}},  //   _coms, joms_, _oron_,
  { {0x39440e07, 0x21290169, 0xfaa50451, 0x00000000}},  //   doms_, miah_, гало,
  { {0x21290169, 0xf1c70061, 0x2d4700c4, 0x00000000}},  //   liah_, _लहान, tões_,
  { {0x27e62274, 0x60dd0006, 0x394d109b, 0x00000000}},  //   _aron_, _kasm, tles_,
  { {0x27e62275, 0x60dd01a3, 0xdb02000c, 0x00000000}},  //   _bron_, _jasm, stoð,
  { {0x2d470181, 0x2009003f, 0x7cd40036, 0x00000000}},  //   sões_, nyai_, _wśró,
  { {0x395f0a3a, 0x394d007f, 0x26dc0207, 0x00000000}},  //   smus_, sles_, _cavo_,
  { {0x88bd0046, 0x394d0549, 0x26dc04c6, 0x00000000}},  //   liśm, ples_, _davo_,
  { {0x60dd0213, 0x3944009d, 0x27e60016, 0x00000000}},  //   _nasm, coms_, _fron_,
  { {0x2129027e, 0x67282276, 0xef280279, 0x00000000}},  //   diah_, bidj, lmüş_,
  { {0x68fb017b, 0x26dc0006, 0x6b4d00c4, 0x00000000}},  //   ljud, _gavo_, fúgi,
  { {0x25be0061, 0x6d492277, 0x60dd014a, 0x00000000}},  //   cttl_, _okea, _basm,
  { {0xdd00001e, 0xdddc002b, 0x60dd00fa, 0x00000000}},  //   ītīb, _verż, _casm,
  { {0x2d830065, 0x2f160030, 0x60dd0065, 0x00000000}},  // [56e0] _atje_, _læge_, _dasm,
  { {0x63a9050f, 0x6d5b00fa, 0xf063007e, 0x00000000}},  //   šenc, _ahua, скуп,
  { {0x6d5b002a, 0x7c3b2278, 0x127b0049, 0x00000000}},  //   _bhua, _axur, _ראטע,
  { {0x6d5b002a, 0x672810f5, 0x00000000, 0x00000000}},  //   _chua, zidj,   ,
  { {0x5b26007e, 0xac970076, 0xda7a007e, 0x00000000}},  //   лька, انها_, няй_,
  { {0x9e660014, 0x6d5b0288, 0x00000000, 0x00000000}},  //   _مازن, _ehua,   ,
  { {0x67280107, 0x60dd01a3, 0x2fc00a35, 0x00000000}},  //   vidj, _yasm, ltig_,
  { {0x26dc010a, 0x60c401aa, 0x6d5b0048, 0x00000000}},  //   _savo_, nfim, _ghua,
  { {0x2fc00168, 0x3944007f, 0xabaa03ec, 0x00000000}},  //   ntig_, roms_, _سهام_,
  { {0x2fc0010f, 0x6d5b2279, 0xf77f00c4, 0x00000000}},  //   itig_, _zhua, íça_,
  { {0x68fb0073, 0x6441005f, 0xceb3009b, 0x00000000}},  //   bjud, əliy, זית_,
  { {0x27e6227a, 0x2ed102fb, 0x2fc0067e, 0x00000000}},  //   _tron_, _हस्त, ktig_,
  { {0x60dd227b, 0x26dc010a, 0x212901d6, 0x00000000}},  //   _rasm, _tavo_, viah_,
  { {0xe81d007d, 0x3dc60036, 0x59b80309, 0x00000000}},  //   _बेटा_, łowy_, _इमार,
  { {0x60dd049a, 0x2fc00007, 0x21290022, 0x00000000}},  //   _pasm, etig_, tiah_,
  { {0xdbd1006c, 0x70af0061, 0x69da0146, 0x00000000}},  //   _püüa, टलेल, _mste,
  { {0x2fc00caf, 0x212904cb, 0x200f0010, 0x00000000}},  // [56f0] gtig_, riah_, ági_,
  { {0x69da022b, 0x6d5b0065, 0x2129008a, 0x00000000}},  //   _oste, _shua, siah_,
  { {0x212910ed, 0x5c750887, 0x69da0270, 0x00000000}},  //   piah_, алет, _nste,
  { {0x60dd0051, 0xdb1b004a, 0x00000000, 0x00000000}},  //   _uasm, _iqué,   ,
  { {0x69da227c, 0x2ba7003b, 0xec780088, 0x00000000}},  //   _aste, ујев, упі_,
  { {0x3f89227d, 0x00000000, 0x00000000, 0x00000000}},  //   mpau_,   ,   ,
  { {0x6d5b227e, 0xd2b8009b, 0xf2d40049, 0x00000000}},  //   _thua, אלות_, מעס_,
  { {0x6297008d, 0x7c3b002d, 0xef28019a, 0x00000000}},  //   _lexo, _txur, rmüş_,
  { {0xf719008b, 0x68fb01a3, 0x290d21be, 0x00000000}},  //   віны_, rjud, rkea_,
  { {0x6297049a, 0xd709007c, 0x81cc0044, 0x00000000}},  //   _nexo, тное_, লিত_,
  { {0x28c20061, 0xdce9227f, 0x69940088, 0x00000000}},  //   व्हि, _lieč, _гріх,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd456005e, 0xdb1b00dc, 0xdce90027, 0x00000000}},  //   ртнь, _aqué, _nieč,
  { {0x69da2280, 0x00000000, 0x00000000, 0x00000000}},  //   _yste,   ,   ,
  { {0xe29706b6, 0xd5e8006d, 0xa2a20309, 0x00000000}},  //   рас_, _معين_, कृष्,
  { {0x2fc02281, 0x387f04cb, 0x7bdb00b0, 0x00000000}},  //   ttig_, ncur_, _osuu,
  { {0x21670a27, 0xd0070589, 0x06d80055, 0x00000000}},  // [5700] рити_, аете_, তারি,
  { {0xef17008b, 0x2fc004fb, 0x26c50203, 0x00000000}},  //   аму_, rtig_, nflo_,
  { {0x2fc00343, 0x629c147e, 0x00000000, 0x00000000}},  //   stig_, maro,   ,
  { {0xad65023c, 0x00000000, 0x00000000, 0x00000000}},  //   مانه,   ,   ,
  { {0x3f5401a2, 0x00000000, 0x00000000, 0x00000000}},  //   läum_,   ,   ,
  { {0x629c016c, 0x39a61f70, 0x00000000, 0x00000000}},  //   naro, ашив,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x629c0016, 0x3b860242, 0xed5a142c, 0x00000000}},  //   haro, _влаг, _роб_,
  { {0x629c2282, 0xc60e0164, 0xe0df1e60, 0x00000000}},  //   karo, ान्य_, _chòy_,
  { {0xa9a60265, 0x629c0211, 0xe6660264, 0x00000000}},  //   _вижд, jaro, итно,
  { {0x69da2283, 0x629c0006, 0x6297027b, 0x00000000}},  //   _uste, daro, _rexo,
  { {0x7bc20116, 0xd7e60088, 0x7c35000c, 0x00000000}},  //   otou, _віко, _áfrý,
  { {0x7bc216c6, 0x629c0350, 0x00000000, 0x00000000}},  //   ntou, faro,   ,
  { {0x629c0211, 0x823715dd, 0x20e30082, 0x00000000}},  //   garo, لرزا, _ổi_,
  { {0x012700e2, 0x7bc20943, 0x00000000, 0x00000000}},  //   аќам, htou,   ,
  { {0x09c30044, 0x00000000, 0x00000000, 0x00000000}},  //   ্মচা,   ,   ,
  { {0x25de013d, 0x00000000, 0x00000000, 0x00000000}},  // [5710] गिकी_,   ,   ,
  { {0x629c0211, 0x02a71662, 0x8afc0036, 0x00000000}},  //   caro, _трим, _mięs,
  { {0xdcfc001e, 0xa3df0309, 0x00000000, 0x00000000}},  //   _strā, णिक_,   ,
  { {0xdb0b008e, 0xc5790049, 0x00000000, 0x00000000}},  //   rugí, אָסט,   ,
  { {0x2bda0164, 0x00000000, 0x00000000, 0x00000000}},  //   _मैदा,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4998007e, 0x3e3300a1, 0x29d80082, 0x00000000}},  //   атыя_, _بہار, _cũa_,
  { {0x629c04f3, 0xf77f00c4, 0x00000000, 0x00000000}},  //   zaro, íço_,   ,
  { {0x629c006b, 0x6133002b, 0x7c240051, 0x00000000}},  //   yaro, għli, úirt,
  { {0x629c002d, 0x46f5007c, 0x387f2284, 0x00000000}},  //   xaro, счит, scur_,
  { {0x629c01d9, 0x160e007d, 0x00000000, 0x00000000}},  //   varo, ानगर_,   ,
  { {0x7ae1010f, 0x629c039b, 0x25aa2285, 0x00000000}},  //   _halt, waro, ábla_,
  { {0x629c16b9, 0x7ae12286, 0x08760049, 0x00000000}},  //   taro, _kalt, _הענט_,
  { {0x4463005e, 0x2bfa0061, 0x00000000, 0x00000000}},  //   явяв, ्हतं_,   ,
  { {0x7ae101d5, 0x7b320046, 0x629c0211, 0x00000000}},  //   _malt, sług, raro,
  { {0x645a005f, 0x629c183d, 0xd1320025, 0x00000000}},  //   ətin, saro, أمر_,
  { {0x629c20e3, 0x00000000, 0x00000000, 0x00000000}},  // [5720] paro,   ,   ,
  { {0x1ea90380, 0x93fb00b3, 0x7ae10023, 0x00000000}},  //   لامي_, _עליי, _nalt,
  { {0x6146007e, 0x69c3012d, 0xd00f009e, 0x00000000}},  //   _гена, jtne, ولہ_,
  { {0xdca30f40, 0x63a4044f, 0x7ae100b0, 0x00000000}},  //   заци, _kvin, _aalt,
  { {0x5c97008b, 0xd9e00164, 0x7bc20319, 0x00000000}},  //   скія_, पट्ट, utou,
  { {0x7bc2028c, 0x7ae10197, 0x60d62287, 0x00000000}},  //   rtou, _calt, leym,
  { {0x7bc200b9, 0x7ae10051, 0xf2d300b3, 0x00000000}},  //   stou, _dalt, פעה_,
  { {0x63a400ca, 0x61e105b7, 0x636005ee, 0x00000000}},  //   _ovin, ælli, lönd,
  { {0xfaa610f3, 0xaaba01fa, 0x17fa0025, 0x00000000}},  //   _газо, _مدار_, ارعة_,
  { {0xd6da019d, 0x7ae115cd, 0xbb560439, 0x00000000}},  //   ути_, _galt, _انطب,
  { {0x63a42288, 0x8626007e, 0x60d600d9, 0x00000000}},  //   _avin, сьпе, keym,
  { {0x7ae12289, 0x2d730166, 0xf48400e2, 0x00000000}},  //   _zalt, _kćer_, зурн,
  { {0x443f00c4, 0x07e900a1, 0x7ae10276, 0x00000000}},  //   çu_, _پرنٹ_, _yalt,
  { {0x63a900b9, 0xdc37007b, 0x6594008b, 0x00000000}},  //   šeno, מאכט_, _даку,
  { {0x63a4005d, 0x00000000, 0x00000000, 0x00000000}},  //   _evin,   ,   ,
  { {0x8637009b, 0x60d601e5, 0x4155007e, 0x00000000}},  //   _לרוב_, geym, івас,
  { {0x752f0036, 0x6e9900ed, 0x00000000, 0x00000000}},  // [5730] micz, ивар_,   ,
  { {0x752f0046, 0x68e20082, 0x00000000, 0x00000000}},  //   licz, _laod,   ,
  { {0xf3cb007a, 0x2d87228a, 0xa2820014, 0x00000000}},  //   _شبکه_, ëne_, _آیفو,
  { {0x7ae1049a, 0x752f0046, 0x81cc0055, 0x00000000}},  //   _salt, nicz, লিশ_,
  { {0x7ae1006b, 0xdcfc001a, 0x5ee10044, 0x00000000}},  //   _palt, _stră, নাবে,
  { {0x69c30039, 0x539c071c, 0x81cc0044, 0x00000000}},  //   ttne, ניוו, লির_,
  { {0x7ae1021e, 0x68e20082, 0x2d73012d, 0x00000000}},  //   _valt, _baod, _ećer_,
  { {0x7ae1010f, 0x2bd900a6, 0x17850140, 0x00000000}},  //   _walt, _پارک_, огим,
  { {0x6d4b0047, 0x69c320dc, 0x61fc0009, 0x00000000}},  //   moga, stne, zxrl,
  { {0x6d4b07bc, 0x6b89228b, 0x00000000, 0x00000000}},  //   loga, _iteg,   ,
  { {0xceb20476, 0x752f0036, 0x6f070059, 0x00000000}},  //   ויי_, ficz, _mojc,
  { {0x752f0046, 0x6d4b1e2d, 0x62850030, 0x00000000}},  //   gicz, noga, _afho,
  { {0xe72e05c7, 0x6360010f, 0x39a50089, 0x00000000}},  //   _же_, höne, lēs_,
  { {0x6d4b228c, 0x68e20107, 0xe297007e, 0x00000000}},  //   hoga, _zaod, жар_,
  { {0x6d4b0059, 0x39a50089, 0x00000000, 0x00000000}},  //   koga, nēs_,   ,
  { {0x63a405ad, 0x6b890032, 0x78bb006c, 0x00000000}},  //   _tvin, _oteg, nguv,
  { {0x6d4b0016, 0xaf06003b, 0x6b890807, 0x00000000}},  // [5740] doga, опал, _nteg,
  { {0x0cd60044, 0x60d60ee1, 0x27e201e5, 0x00000000}},  //   _সচেত, seym, ækni_,
  { {0x6d4b08fe, 0x6b890016, 0xec7a0641, 0x00000000}},  //   foga, _ateg, апе_,
  { {0xa3ce03d7, 0xf09f001d, 0x92b60167, 0x00000000}},  //   _रहा_, _hoàn_, _احکا,
  { {0x6133002b, 0x653b0049, 0xdb1b228d, 0x00000000}},  //   għlu, סענד, _equí,
  { {0x63600047, 0xf76701fa, 0x00000000, 0x00000000}},  //   lönb, _زا_,   ,
  { {0xddc3003b, 0x9cb60025, 0x8ad5007e, 0x00000000}},  //   _обри, _ومست, яюцц,
  { {0x984f0279, 0x8c4601c0, 0x9f4000d4, 0x00000000}},  //   _ağır_, _дебе, lvià_,
  { {0x79e800a1, 0x8afc00b4, 0x00000000, 0x00000000}},  //   _گواہ_, _chęc,   ,
  { {0xe5c60057, 0x752f0036, 0x15ea0088, 0x00000000}},  //   осмо, wicz, аємо_,
  { {0xd5b700c2, 0x6d4300f4, 0x88ac0044, 0x00000000}},  //   ося_, énag, ক্ষক,
  { {0x7d020059, 0xb865025a, 0x3ce60142, 0x00000000}},  //   njos, _کامو, ndov_,
  { {0xdce200ca, 0x66e600aa, 0x18360439, 0x00000000}},  //   jmoč, _мода, _براح,
  { {0x672a000c, 0x00000000, 0x00000000, 0x00000000}},  //   _umfj,   ,   ,
  { {0x31c4008b, 0x3983011f, 0x645a006b, 0x00000000}},  //   мств, _kısa_, ətim,
  { {0x2eed228e, 0x3ce60925, 0x2ee3002b, 0x00000000}},  //   _şef_, jdov_, _sajf_,
  { {0x6d4b0181, 0x752d0065, 0x7d020107, 0x00000000}},  // [5750] voga, _imaz, djos,
  { {0x7c220305, 0x6d4b228f, 0x6fac0316, 0x00000000}},  //   dzor, woga, _चिरं,
  { {0x57b7001c, 0x673a00c7, 0x6f070d9b, 0x00000000}},  //   _आम्ह, intj, _vojc,
  { {0x7bf9004d, 0x6f070036, 0x7d020023, 0x00000000}},  //   йнер_, _wojc, gjos,
  { {0x2bbb0025, 0x8c4500e2, 0x00000000, 0x00000000}},  //   شاشة_, џеле,   ,
  { {0x37c20055, 0x31692290, 0x673a00bb, 0x00000000}},  //   ্টার, lmaz_, jntj,
  { {0x5ee10055, 0xeab00025, 0x6d4b1833, 0x00000000}},  //   নাদে, ئعه_, poga,
  { {0x31690279, 0x2919000c, 0x39a50089, 0x00000000}},  //   nmaz_, ósa_, rēs_,
  { {0x7d1b006c, 0x63a90825, 0x6b8900d0, 0x00000000}},  //   _ilus, šenj, _uteg,
  { {0x752d0335, 0x7d1b000c, 0x7d0900bb, 0x00000000}},  //   _amaz, _hlus, _hoes,
  { {0x7d1b2291, 0x7d090b36, 0x6448006b, 0x00000000}},  //   _klus, _koes, ədiy,
  { {0x673a0116, 0x7d090052, 0x00000000, 0x00000000}},  //   antj, _joes,   ,
  { {0x7d0900b5, 0x8c46006b, 0x987a0104, 0x00000000}},  //   _moes, _peşə, _האנט,
  { {0x394d00c4, 0x752d002d, 0x7d1b005b, 0x00000000}},  //   loes_, _emaz, _llus,
  { {0x6263007c, 0xf7700014, 0x7c220197, 0x00000000}},  //   евра, _شاه_, zzor,
  { {0x0446005e, 0x64430036, 0x394d0133, 0x00000000}},  //   _нейн, _śnie, noes_,
  { {0xf09f001d, 0xa06700e3, 0x65642292, 0x00000000}},  // [5760] _toàn_, зата_, _ihih,
  { {0x7d1b08b2, 0x394d0386, 0x8c3d014a, 0x00000000}},  //   _alus, hoes_, _keşf,
  { {0x7d090007, 0xf297034e, 0x78ab012d, 0x00000000}},  //   _boes, _מכיר_, _odgv,
  { {0xdd8f0151, 0x7c22022b, 0x7d091f3e, 0x00000000}},  //   اون_, tzor, _coes,
  { {0x394d0436, 0x98a4010a, 0x629e10ed, 0x00000000}},  //   does_, nimą_, _kepo,
  { {0xada6003b, 0x7d1b142b, 0x7c2200b5, 0x00000000}},  //   _нагл, _elus, rzor,
  { {0x7c220010, 0x394d0016, 0x7d1b2293, 0x00000000}},  //   szor, foes_, _flus,
  { {0xfce30001, 0x629e01d9, 0x3983006b, 0x00000000}},  //   _посо, _lepo, _qısa_,
  { {0x98a40006, 0xeb972294, 0x00000000, 0x00000000}},  //   jimą_, _нит_,   ,
  { {0x752d00b9, 0x98a40006, 0x65640058, 0x00000000}},  //   _smaz, dimą_, _ahih,
  { {0x2720001d, 0x78a00061, 0x6448006b, 0x00000000}},  //   _lòng_, pamv, şdil,
  { {0x6564008e, 0x394d00c4, 0xe9950014, 0x00000000}},  //   _chih, coes_, _آهنگ,
  { {0x399a0006, 0x27200082, 0x656400e7, 0x00000000}},  //   lūs_, _nòng_, _dhih,
  { {0x629e0190, 0x00000000, 0x00000000, 0x00000000}},  //   _cepo,   ,   ,
  { {0x629e0325, 0x658800b9, 0xd765025a, 0x00000000}},  //   _depo, _běhe, _تنوی,
  { {0x752d00ca, 0xe63b009b, 0x25d70049, 0x00000000}},  //   _umaz, _לתוכ, _זוהן_,
  { {0xc05b01fb, 0x7d0900bb, 0x224d0036, 0x00000000}},  // [5770] сів_, _roes, łek_,
  { {0x629e2295, 0x2720001d, 0x3169001e, 0x00000000}},  //   _gepo, _dòng_, smaz_,
  { {0x7d1b028c, 0x753d01a2, 0x00000000, 0x00000000}},  //   _plus, onsz,   ,
  { {0x629e0173, 0x65640023, 0xdb0b01a2, 0x00000000}},  //   _zepo, _xhih, zugä,
  { {0xdb1b0181, 0xaf370014, 0xed580088, 0x00000000}},  //   _aquá, _فرست, чої_,
  { {0x7d0907a5, 0x60cd00d4, 0x62870036, 0x00000000}},  //   _woes, lfam, ncjo,
  { {0x2fc90c53, 0x7d0901b5, 0xe9d901fb, 0x00000000}},  //   ltag_, _toes, іки_,
  { {0xa3ce001c, 0x7d1b014a, 0x9be7007e, 0x00000000}},  //   _रहल_, _ulus, _нізк,
  { {0x2fc90a35, 0xb8d50309, 0x394d0dcb, 0x00000000}},  //   ntag_, _जय_, roes_,
  { {0x65640a61, 0x05a90057, 0x2fc9010f, 0x00000000}},  //   _shih, овой_, itag_,
  { {0xdb26007a, 0x6aa30169, 0xdbd700b0, 0x00000000}},  //   _تولی, manf, säät,
  { {0x629e04d4, 0xdbd700b0, 0x78ab0009, 0x00000000}},  //   _sepo, päät, _udgv,
  { {0x629e0020, 0xe3b20025, 0x00000000, 0x00000000}},  //   _pepo, خرج_,   ,
  { {0x63a61861, 0x6aa304b2, 0x06e10044, 0x00000000}},  //   rskn, nanf, বাহি,
  { {0x60cd2296, 0x27200082, 0xa50a05f6, 0x00000000}},  //   ffam, _sòng_, _мека_,
  { {0x68e90977, 0x4f9600ed, 0x6e25012d, 0x00000000}},  //   nded, држу, dzhb,
  { {0x27ed0870, 0x8fa30069, 0x2fc901d6, 0x00000000}},  // [5780] nven_, кате, gtag_,
  { {0x2720001d, 0xfe720137, 0x27ed00bb, 0x00000000}},  //   _vòng_, ندا_, iven_,
  { {0x6aa30635, 0x6ce60088, 0xa3e6006e, 0x00000000}},  //   danf, діле, फिक_,
  { {0x68e90030, 0x27200082, 0x2cad0045, 0x00000000}},  //   jded, _tòng_, _cded_,
  { {0x27ed02ae, 0x68e90016, 0x9b6a01fc, 0x00000000}},  //   jven_, dded, ошка_,
  { {0x27ed0173, 0x6d5900d9, 0x399a0006, 0x00000000}},  //   dven_, alwa, tūs_,
  { {0x81cc0055, 0x27ed00b5, 0x999e0006, 0x00000000}},  //   লিক_, even_, _rytų_,
  { {0x63a90027, 0xa96701fc, 0x399a0006, 0x00000000}},  //   šeni, мија_, rūs_,
  { {0x5ee10044, 0x6aa3012d, 0x00000000, 0x00000000}},  //   নারে, banf,   ,
  { {0x291d0016, 0x00000000, 0x00000000, 0x00000000}},  //   _elwa_,   ,   ,
  { {0x27ed00d4, 0xc94f007e, 0x60cd014a, 0x00000000}},  //   aven_, _аў_, yfam,
  { {0x249f000c, 0x6b8000e7, 0x291d0173, 0x00000000}},  //   úum_, _kumg, _glwa_,
  { {0x7a130224, 0x2fc90541, 0x7ae80058, 0x00000000}},  //   _větš, xtag_, _kadt,
  { {0xbcfd0011, 0x2720000a, 0xdb0b00f8, 0x00000000}},  //   _nhũn, _bòne_, stgö,
  { {0x7ae80146, 0x88c30044, 0x69ca2297, 0x00000000}},  //   _madt, ্যরক, ntfe,
  { {0x2fc90a35, 0x2d550190, 0x00000000, 0x00000000}},  //   ttag_, nået_,   ,
  { {0x40340057, 0xe7bc0044, 0x6360000c, 0x00000000}},  // [5790] ветс, _অনুয, mönn,
  { {0x60cd06d3, 0x2fc901a2, 0x067b0049, 0x00000000}},  //   sfam, rtag_, ַנדל,
  { {0x7cd90242, 0x68e92298, 0xc1750735, 0x00000000}},  //   змер_, yded, _площ,
  { {0xdd94007e, 0x7afa00b0, 0x27ed00ea, 0x00000000}},  //   тацы, _antt, yven_,
  { {0xeb99051f, 0x7ae81fe8, 0x6aa30232, 0x00000000}},  //   чил_, _badt, tanf,
  { {0xa3d70164, 0xdcf50035, 0x7afa00f6, 0x00000000}},  //   _सहन_, _buză, _cntt,
  { {0x6d590263, 0x636011ea, 0x6aa30808, 0x00000000}},  //   plwa, könn, ranf,
  { {0x63bd0091, 0x7afa01a2, 0x7d0400b0, 0x00000000}},  //   kusn, _entt, öist,
  { {0x68e92299, 0x7ae8229a, 0x69c80066, 0x00000000}},  //   rded, _fadt, _eqde,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x777805f0, 0x8c3d0035, 0x4c990049, 0x00000000}},  //   _divx, _deşe, ּבֿו,
  { {0x6aa1147c, 0x672101ee, 0x8996009b, 0x00000000}},  //   _helf, shlj, _נכנס_,
  { {0x61e50857, 0x74160076, 0x2d9c0211, 0x00000000}},  //   _ashl, روسا, ávez_,
  { {0x5ecf0055, 0xe9ff001d, 0x2d5c0129, 0x00000000}},  //   _হোসে, _giảm_, víem_,
  { {0x6aa109f9, 0x76580006, 0x216a0f93, 0x00000000}},  //   _melf, _gyvy, зиви_,
  { {0x7bcb1c8c, 0x63bd02db, 0xc57a009b, 0x00000000}},  //   ktgu, busn, _צרפת,
  { {0xc5690076, 0x9f4000b0, 0x6f66003b, 0x00000000}},  // [57a0] _تحول_, yviä_, еваз,
  { {0xe9e5001d, 0x6fb30188, 0x2d5c0129, 0x00000000}},  //   _đúng_, املا, ríem_,
  { {0xdd8f06b4, 0x2d9c0e16, 0x82360167, 0x00000000}},  //   مول_, ève_, _سردا,
  { {0x2ca00051, 0xb81f0061, 0x7ae801c3, 0x00000000}},  //   úid_, यनाम_, _sadt,
  { {0x6aa10010, 0x80c90061, 0x7ae801d6, 0x00000000}},  //   _belf, _हॉटे, _padt,
  { {0x853d0006, 0x6aa10016, 0x69ca0056, 0x00000000}},  //   gsėj, _celf, ttfe,
  { {0x6aa11263, 0x3f82000b, 0x2d550637, 0x00000000}},  //   _delf, _huku_, tået_,
  { {0x2c570046, 0x3f8216c3, 0xdcfc0b4a, 0x00000000}},  //   _będą_, _kuku_, _kurč,
  { {0x0b460264, 0x6aa10010, 0x69ca00ea, 0x00000000}},  //   _знан, _felf, stfe,
  { {0x6f0e0030, 0x2ca60058, 0x6aa10016, 0x00000000}},  //   _jobc, laod_, _gelf,
  { {0x3f8200b0, 0x613b00b0, 0x6f0e229b, 0x00000000}},  //   _luku_, nälä, _mobc,
  { {0x6aa102ae, 0x81c80044, 0x00000000, 0x00000000}},  //   _zelf, োটা_,   ,
  { {0x8c3d011f, 0x3f821256, 0x00000000, 0x00000000}},  //   _teşe, _nuku_,   ,
  { {0x63bd027e, 0x6123006c, 0x613b00b0, 0x00000000}},  //   rusn, _mõle, kälä,
  { {0x63bd0169, 0xf09f0011, 0x26de0325, 0x00000000}},  //   susn, _hoài_, meto_,
  { {0x26de00d6, 0x365b00b6, 0x3f82020c, 0x00000000}},  //   leto_, _מכונ, _buku_,
  { {0xb4dd02d2, 0x64a4003b, 0x00000000, 0x00000000}},  // [57b0] ड़ी_, _сања,   ,
  { {0x63ad0119, 0xc43c00b6, 0xce6b0f97, 0x00000000}},  //   _ivan, _מתחי, пред_,
  { {0xf09f0011, 0x6123006c, 0x61e5012d, 0x00000000}},  //   _loài_, _põld, _ushl,
  { {0x6aa10343, 0x78a20738, 0x7db40688, 0x00000000}},  //   _self, _neov, اصلا,
  { {0x6aa10544, 0x7981229c, 0x00000000, 0x00000000}},  //   _pelf, _sulw,   ,
  { {0x26de02d5, 0x3ce90059, 0x501800ed, 0x00000000}},  //   jeto_, žav_, _џорџ_,
  { {0x9412005f, 0x7bcb00d4, 0x6aa1229d, 0x00000000}},  //   _deyə_, stgu, _velf,
  { {0x63ad02e1, 0x6aa1229e, 0x9875003b, 0x00000000}},  //   _ovan, _welf, купљ,
  { {0x6aa11a8f, 0x6123010e, 0x2d8300ca, 0x00000000}},  //   _telf, _kõlb, _huje_,
  { {0x26de229f, 0x3cff0061, 0x00000000, 0x00000000}},  //   geto_, ळावे_,   ,
  { {0x63ad22a0, 0x64c60061, 0x2d830173, 0x00000000}},  //   _avan, _वादळ, _juje_,
  { {0x33330051, 0x63ad00d9, 0xf9880025, 0x00000000}},  //   _amxx_, _bvan, _أنني_,
  { {0x26de22a1, 0x7784007e, 0x290f22a2, 0x00000000}},  //   beto_, _бліз, _ioga_,
  { {0x3f820091, 0x26de00fa, 0xe73303ab, 0x00000000}},  //   _ruku_, ceto_, _حصص_,
  { {0x290f0dbd, 0x3f8222a3, 0xdcfc012d, 0x00000000}},  //   _koga_, _suku_, _surč,
  { {0x216700c0, 0x290f00c4, 0xddc70036, 0x00000000}},  //   виси_, _joga_, _wyjś,
  { {0x68eb006a, 0x290f016e, 0x82fa00a1, 0x00000000}},  // [57c0] _magd, _moga_, _ہرگز_,
  { {0xfbe70044, 0x290f22a4, 0x68eb004e, 0x00000000}},  //   পমাত, _loga_, _lagd,
  { {0x63ad1a47, 0x1b200044, 0x2d5500d8, 0x00000000}},  //   _zvan, _বদলে_, våer_,
  { {0x290f22a5, 0x26de0107, 0x6123006c, 0x00000000}},  //   _noga_, zeto_, _põle,
  { {0xe7bc0055, 0x99410036, 0x78a2010e, 0x00000000}},  //   _অন্য, kół_, _reov,
  { {0x60c41d79, 0xf09f0082, 0x3ea30066, 0x00000000}},  //   lgim, _roài_, _gejt_,
  { {0x290f05c9, 0x13db0044, 0x6da6004d, 0x00000000}},  //   _boga_, দিয়, _шива,
  { {0x60c422a6, 0x23b203d7, 0x26de0007, 0x00000000}},  //   ngim, _जिंद, weto_,
  { {0x26de0042, 0xf803008b, 0x68eb011c, 0x00000000}},  //   teto_, ачэн, _dagd,
  { {0xd6da22a7, 0x24800065, 0xd5b80089, 0x00000000}},  //   фти_, _agim_, trā_,
  { {0x26de00fa, 0xc9d50123, 0x5ebb009b, 0x00000000}},  //   reto_, _مملک, וזיק,
  { {0xb4dd02d2, 0x69da023a, 0x439501fc, 0x00000000}},  //   ड़े_, _ipte, ламс,
  { {0x26de0709, 0xe72f007a, 0xa0120044, 0x00000000}},  //   peto_, صصی_, _সেসব_,
  { {0x2d871580, 0x68e0014a, 0x59c6007d, 0x00000000}},  //   ínek_, lemd, रंपर,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x741501fa, 0x63ad22a8, 0x60c40197, 0x00000000}},  //   _موبا, _tvan, ggim,
  { {0x691c00f4, 0x2fc00319, 0x63ad0056, 0x00000000}},  // [57d0] _réel, guig_, _uvan,
  { {0x63a90161, 0x4fc4025f, 0x69da0091, 0x00000000}},  //   šens, јста, _opte,
  { {0x39460211, 0x3cff0061, 0x02a4007e, 0x00000000}},  //   _ojos_, ळाले_, _трым,
  { {0xa3d70061, 0x2fc022a9, 0x705500a1, 0x00000000}},  //   _सहा_, buig_, _منجا,
  { {0x68eb22aa, 0x69da13db, 0x8bc700ed, 0x00000000}},  //   _ragd, _apte, тсед,
  { {0xe1f0026c, 0x6b65008b, 0x68eb0030, 0x00000000}},  //   _اسی_, ыкла, _sagd,
  { {0x68eb006a, 0x1cbb0025, 0x38660173, 0x00000000}},  //   _pagd, _يارب_, _azor_,
  { {0x89d6035b, 0xa96606c4, 0x7c8706e3, 0x00000000}},  //   اوير_, лища_, _јуве,
  { {0x6eca013d, 0x00000000, 0x00000000, 0x00000000}},  //   स्कु,   ,   ,
  { {0x290f00e7, 0x060901ab, 0x68eb01c3, 0x00000000}},  //   _woga_, енок_, _wagd,
  { {0x290f22ab, 0x64a60269, 0x9f9b00b0, 0x00000000}},  //   _toga_, лана, _häät_,
  { {0x2f16009f, 0xdcfc0089, 0x442b0009, 0x00000000}},  //   _hægt_, _kurā, fzc_,
  { {0xf7f404e1, 0x9f40008e, 0x7c2b01a2, 0x00000000}},  //   _پسند, rviú_, nzgr,
  { {0x395f00b0, 0x78a9006c, 0x3ced010e, 0x00000000}},  //   llus_, laev, _laev_,
  { {0x321e0161, 0x395f010e, 0x200f010e, 0x00000000}},  //   áty_, olus_, ägin_,
  { {0x2fc001bb, 0x78a90087, 0x46cf0316, 0x00000000}},  //   tuig_, naev, त्रह,
  { {0x60c40065, 0xe3b200f3, 0x752416fc, 0x00000000}},  // [57e0] rgim, _ارب_, _iliz,
  { {0xa2e600ed, 0x139b00b3, 0x693a002b, 0x00000000}},  //   _соод, _רביע, nċer,
  { {0x629c0489, 0x75240091, 0x78a9010e, 0x00000000}},  //   mbro, _kliz, kaev,
  { {0xe45f0039, 0x629c09b0, 0xd00a00ed, 0x00000000}},  //   mför_, lbro, _земе_,
  { {0x6d420032, 0x395f006c, 0xdb5a181f, 0x00000000}},  //   rnoa, dlus_, нюк_,
  { {0xbda60151, 0xdb0b00d4, 0x395f010e, 0x00000000}},  //   _محرو, nsgè, elus_,
  { {0xe45f0039, 0xe6070558, 0xfc3f000c, 0x00000000}},  //   nför_, _اش_, _þín_,
  { {0x391401f9, 0x395f0016, 0x6123006c, 0x00000000}},  //   рмир, glus_, _kõla,
  { {0x68e001d6, 0x629c22ac, 0x00000000, 0x00000000}},  //   remd, kbro,   ,
  { {0x47340265, 0x68e022ad, 0x75240020, 0x00000000}},  //   рнос, semd, _aliz,
  { {0x75240119, 0x629c032e, 0x0f5700b3, 0x00000000}},  //   _bliz, dbro, ריים_,
  { {0x64750081, 0x395f10ff, 0x6aaa22ae, 0x00000000}},  //   игну, clus_, laff,
  { {0xb796012b, 0x658800b9, 0x7bc200ab, 0x00000000}},  //   _срећ, _těho, nuou,
  { {0x75241cc0, 0x6aaa02e5, 0x629c22af, 0x00000000}},  //   _eliz, naff, gbro,
  { {0x673a00d4, 0x2259007c, 0x00000000, 0x00000000}},  //   mitj, тивы_,   ,
  { {0x6aaa010f, 0x31601d69, 0x6360010f, 0x00000000}},  //   haff, gliz_, hönh,
  { {0x6aaa22b0, 0x629c0376, 0xf1b8002b, 0x00000000}},  // [57f0] kaff, bbro, ġġa_,
  { {0x656d1346, 0x673a0009, 0x78a90095, 0x00000000}},  //   _hhah, nitj, zaev,
  { {0x395f0016, 0x6aaa00ea, 0xddc70089, 0x00000000}},  //   ylus_, daff, _izjū,
  { {0x61fa000c, 0x8d741289, 0xdb02004a, 0x00000000}},  //   ætle, مانا, droñ,
  { {0xd7e60025, 0x63af0051, 0x673a0d61, 0x00000000}},  //   _بك_, nscn, kitj,
  { {0x645a001a, 0x6aaa0203, 0x673a0023, 0x00000000}},  //   ştig, gaff, jitj,
  { {0x395f006c, 0x2f160698, 0xaa49005e, 0x00000000}},  //   tlus_, _vægt_, ъпка_,
  { {0xe8f900ed, 0xc27c0049, 0x63bd0243, 0x00000000}},  //   тли_, ערהי, krsn,
  { {0x629c0145, 0x7bdb00e7, 0x395f010e, 0x00000000}},  //   ybro, _upuu, rlus_,
  { {0x656d011c, 0x6aaa00ea, 0xaa880025, 0x00000000}},  //   _ahah, caff, _منكم_,
  { {0x395f00b0, 0x75240263, 0xf506003b, 0x00000000}},  //   plus_, _pliz, азно,
  { {0x7ae30047, 0x69c3018e, 0x696706dd, 0x00000000}},  //   lent, mune, _صداق,
  { {0x289a0049, 0x656d0020, 0x69c30052, 0x00000000}},  //   _סיסא, _dhah, lune,
  { {0x661a08e2, 0x68440088, 0x8c1a0097, 0x00000000}},  //   bytk, _уніа, דושי,
  { {0x69c30c51, 0x63bd22b1, 0x7ae3005b, 0x00000000}},  //   nune, arsn, ient,
  { {0xe45f0073, 0x752422b2, 0x291f0d17, 0x00000000}},  //   rför_, _uliz, nkua_,

  { {0x7ae3021e, 0x69c308b5, 0x27290d09, 0x00000000}},  // [5800] kent, hune, _cúng_,
  { {0x7ae30d6b, 0x69c30358, 0x6d5b01a3, 0x00000000}},  //   jent, kune, _akua,
  { {0x7208026c, 0x69c3006c, 0x291f00b0, 0x00000000}},  //   _صفحہ_, june, kkua_,
  { {0xeb9a00e3, 0x47dc0044, 0x69c3002d, 0x00000000}},  //   вид_, বিতী, dune,
  { {0x7ae3001f, 0x6aaa1864, 0xb92a001d, 0x00000000}},  //   fent, taff, _thuế_,
  { {0x7ae322b3, 0x63a4000b, 0x6d5b1d35, 0x00000000}},  //   gent, _mwin, _ekua,
  { {0x69c322b4, 0x888400a6, 0x673a0065, 0x00000000}},  //   gune, میان, vitj,
  { {0x21200e0d, 0x6aaa21ba, 0x7ae30026, 0x00000000}},  //   nkih_, saff, aent,
  { {0x673a0065, 0x00000000, 0x00000000, 0x00000000}},  //   titj,   ,   ,
  { {0x656d1bd2, 0x69c30b50, 0x63bd0091, 0x00000000}},  //   _shah, bune, vrsn,
  { {0x673a0065, 0x6d9301d5, 0xceb3009b, 0x00000000}},  //   ritj, _għad, חית_,
  { {0x673a0129, 0x63a40009, 0x6aa80016, 0x00000000}},  //   sitj, _bwin, _hedf,
  { {0xd7940025, 0x673a00d4, 0x21200059, 0x00000000}},  //   _التخ, pitj, dkih_,
  { {0x63a400c7, 0x186700ed, 0x673a0065, 0x00000000}},  //   _dwin, _тачи_, qitj,
  { {0x6aa805fe, 0x27290011, 0x5187013b, 0x00000000}},  //   _medf, _súng_, руга,
  { {0xdb1901aa, 0xd3a70b52, 0x767b009b, 0x00000000}},  //   ntwò, _кроп, _בטוח,
  { {0xc05b01fb, 0x7ae3011c, 0x6448005f, 0x00000000}},  // [5810] тів_, yent, şdir,
  { {0x7ae3027b, 0x332a0061, 0x6d5b22b5, 0x00000000}},  //   xent, chbx_, _skua,
  { {0x7ae322b6, 0xe2a7000c, 0x63a422b7, 0x00000000}},  //   vent, íður_, _zwin,
  { {0x2120037e, 0x7ae3006a, 0x753d0047, 0x00000000}},  //   ckih_, went, nisz,
  { {0x2d9a0026, 0x06ac0044, 0x6aa80133, 0x00000000}},  //   appe_, _খানি, _bedf,
  { {0x69c300b0, 0x8ccc013d, 0x62850066, 0x00000000}},  //   tune, _हाथो, _jgho,
  { {0xd2b8009b, 0x6aa822b8, 0xdb0900c4, 0x00000000}},  //   בלות_, _dedf, _uveí,
  { {0x69c31cc7, 0xe0df01aa, 0x6d5b0020, 0x00000000}},  //   rune, _akòz_, _ukua,
  { {0x7ae304cb, 0x6d590046, 0x69c3022b, 0x00000000}},  //   pent, mowa, sune,
  { {0x69c3001a, 0x291f0e33, 0x62850016, 0x00000000}},  //   pune, skua_, _ngho,
  { {0x99850054, 0xa2ce0061, 0x63a4112b, 0x00000000}},  //   _الصو, _ताब्, _swin,
  { {0x753d0047, 0x6d590046, 0x6b810f30, 0x00000000}},  //   gisz, nowa, _hilg,
  { {0x6b890219, 0xdcf5001e, 0x6b81017b, 0x00000000}},  //   _jueg, _atzī, _kilg,
  { {0x6b8101d5, 0xe69501b7, 0x6d930066, 0x00000000}},  //   _jilg, _الغد, _mħab,
  { {0x6d590046, 0x6b890219, 0x2120092f, 0x00000000}},  //   kowa, _lueg, tkih_,
  { {0x63a40168, 0x62850190, 0x753d2258, 0x00000000}},  //   _twin, _egho, cisz,
  { {0x6d590046, 0x2120050f, 0x612a000c, 0x00000000}},  // [5820] dowa, rkih_, _nýle,
  { {0x21200f3a, 0xbeaa0014, 0x2fd20039, 0x00000000}},  //   skih_, اهان_, rtyg_,
  { {0xc333007b, 0x248d0161, 0x21200fd0, 0x00000000}},  //   _מוז_, žeme_, pkih_,
  { {0x2d5c027b, 0x6d590046, 0x6b810016, 0x00000000}},  //   víes_, gowa, _ailg,
  { {0x6b811355, 0x4c560025, 0xdcfc0089, 0x00000000}},  //   _bilg, حضار, _strē,
  { {0x6b8100a4, 0x79a619a2, 0x00000000, 0x00000000}},  //   _cilg, брие,   ,
  { {0x3eaa049a, 0xbea3005e, 0x6d590036, 0x00000000}},  //   _iebt_, _хаск, bowa,
  { {0x3eaa02ae, 0x6d590046, 0x6b890211, 0x00000000}},  //   _hebt_, cowa, _fueg,
  { {0x6b81002b, 0x3eb80093, 0x5ecf0044, 0x00000000}},  //   _filg, _kdrt_, _হোটে,
  { {0x95d801f9, 0x6b810173, 0x35b422b9, 0x00000000}},  //   адот_, _gilg, обор,
  { {0x9f400211, 0x2f5b00a3, 0x753d0010, 0x00000000}},  //   lvió_, רדינ, tisz,
  { {0x5559007e, 0x38cb0014, 0x2fc02141, 0x00000000}},  //   рамя_, _ماهی_, krig_,
  { {0x48e3013d, 0x6d43009d, 0x753d0010, 0x00000000}},  //   _फ़ोटो_, énai, risz,
  { {0x2fc0033d, 0x6d5922ba, 0xa5f822bb, 0x00000000}},  //   drig_, zowa, _веку_,
  { {0x2d8a0211, 0x6d590020, 0x6f1513c2, 0x00000000}},  //   _nube_, yowa, _rozc,
  { {0x2fc01e28, 0x9099005e, 0x00000000, 0x00000000}},  //   frig_, рват_,   ,
  { {0x2d8a009d, 0x2d9800f6, 0x12e701e1, 0x00000000}},  // [5830] _aube_, _atre_, _лінг,
  { {0x6b89008e, 0x6d590036, 0x6d4a01e5, 0x00000000}},  //   _rueg, wowa, éfan,
  { {0x6d590046, 0xa2ce01f5, 0xe7ea013d, 0x00000000}},  //   towa, _तात्, _जैसा_,
  { {0x20c700ed, 0x2fc00090, 0x2d8a1080, 0x00000000}},  //   _усог, brig_, _dube_,
  { {0x6d590046, 0x2d9800f4, 0x6b890197, 0x00000000}},  //   rowa, _etre_, _queg,
  { {0x6d590046, 0x612a01ca, 0x6ed8006e, 0x00000000}},  //   sowa, _výle, न्दु,
  { {0x80ac0055, 0x6d590036, 0x2d8a0ecc, 0x00000000}},  //   _ছাত্, powa, _gube_,
  { {0x3f8b037e, 0x6b8122bc, 0xf41f00b0, 0x00000000}},  //   _kucu_, _wilg, kyä_,
  { {0x6b8122bd, 0x2d8a0091, 0xe0df000a, 0x00000000}},  //   _tilg, _zube_, _ajòk_,
  { {0x2caf01c9, 0xeab100a1, 0x2d980374, 0x00000000}},  //   lagd_, _آٹا_, _ytre_,
  { {0x36690517, 0x3f8b10ed, 0x61230004, 0x00000000}},  //   рано_, _lucu_, _põll,
  { {0x27e0001a, 0xe0df000a, 0x00000000, 0x00000000}},  //   _ţine_, _djòk_,   ,
  { {0x442422be, 0xe4570088, 0x9cd6009b, 0x00000000}},  //   ám_, жжя_, חורה_,
  { {0x59dd024c, 0x60dd001c, 0x60cf00f6, 0x00000000}},  //   _महार, _absm, _accm,
  { {0x63720030, 0x63600010, 0xdddc0087, 0x00000000}},  //   hæng, dönt, _ogrš,
  { {0x09be0044, 0x2fc022bf, 0x602600ed, 0x00000000}},  //   _আহমা, trig_, одба,
  { {0x78ab0047, 0x2fc00cac, 0x2d8a0211, 0x00000000}},  // [5840] _megv, urig_, _sube_,
  { {0xe6b702fb, 0x2fc01915, 0xdfcf0426, 0x00000000}},  //   _आयोज, rrig_, ئيل_,
  { {0xee3a003b, 0x00000000, 0x00000000, 0x00000000}},  //   јне_,   ,   ,
  { {0xed5a007c, 0x3f8b016c, 0xdca3003b, 0x00000000}},  //   шое_, _fucu_, даци,
  { {0xed4f00a1, 0xfbcf023c, 0x0b930688, 0x00000000}},  //   ڑھے_, نتو_, وجود,
  { {0xada622c0, 0x0efa007e, 0x2d8a028a, 0x00000000}},  //   _магл, _тэмы_, _tube_,
  { {0xcebf00b9, 0xdd920167, 0x63720190, 0x00000000}},  //   _úřad_, _آور_, mænd,
  { {0x4814092b, 0x63720030, 0x14c60061, 0x00000000}},  //   змис, lænd, _वागण,
  { {0xc17300b3, 0x78ab0089, 0xeb97017f, 0x00000000}},  //   וחה_, _degv, _мит_,
  { {0xf41f0052, 0x00000000, 0x00000000, 0x00000000}},  //   vyä_,   ,   ,
  { {0x7bc20270, 0x2d850010, 0x6123006c, 0x00000000}},  //   lrou, _élet_, _sõlm,
  { {0xe4e701fb, 0xf41f00b0, 0xd7fa003b, 0x00000000}},  //   ціон, tyä_, _вук_,
  { {0x636022c1, 0x39490ecc, 0x00000000, 0x00000000}},  //   yönt, čast_,   ,
  { {0x7c2f011f, 0x2d840322, 0xe1f300a1, 0x00000000}},  //   _ücre, _lime_, وسز_,
  { {0xd13b0265, 0x3f83016c, 0xf41f00b0, 0x00000000}},  //   аха_, _riju_, syä_,
  { {0x2d840004, 0x3f830107, 0x7bc2013e, 0x00000000}},  //   _nime_, _siju_, krou,
  { {0x63600c94, 0x3f8304eb, 0x00000000, 0x00000000}},  // [5850] tönt, _piju_,   ,
  { {0x2d8400f4, 0x7bc222c2, 0x26cc016b, 0x00000000}},  //   _aime_, drou, ngdo_,
  { {0x8c3d22c3, 0x27290142, 0xb4db00f6, 0x00000000}},  //   _ieşi, _júna_, ciàc,
  { {0x2d84016c, 0x62950036, 0x7bc2005b, 0x00000000}},  //   _cime_, lczo, frou,
  { {0x7bc20541, 0x799a002b, 0x78ab22c4, 0x00000000}},  //   grou, _attw, _regv,
  { {0xdefb008b, 0x60cd22c5, 0x63720030, 0x00000000}},  //   _тым_, lgam, ræng,
  { {0x2729009f, 0x13e40044, 0x8a02005e, 0x00000000}},  //   _núna_, মিয়, езще,
  { {0x60cd020c, 0x7bc2009d, 0x63720190, 0x00000000}},  //   ngam, brou, mæne,
  { {0xd90c007a, 0x853d010a, 0x7bc20035, 0x00000000}},  //   شیو_, ipėd, crou,
  { {0x2489002a, 0x78ab0116, 0xaad201f5, 0x00000000}},  //   _agam_, _wegv, _सायक,
  { {0xf9f904e8, 0x63600010, 0x6d4b0082, 0x00000000}},  //   _دفاع_, zöns, onga,
  { {0x60cd0065, 0x01d10044, 0x691c22c6, 0x00000000}},  //   jgam, াবাদ, _dées,
  { {0x60cd16f8, 0x8c3d01df, 0x2cad0606, 0x00000000}},  //   dgam, _beşi, _meed_,
  { {0xe297026b, 0x2cad22c7, 0x27ed01aa, 0x00000000}},  //   зар_, _leed_, mwen_,
  { {0xc692007b, 0x11d5007e, 0x61312229, 0x00000000}},  //   _טאג_, мітр, _målf,
  { {0x399122c8, 0x2cad1eed, 0x55ba00b6, 0x00000000}},  //   _más_, _need_, _המקו,
  { {0x63720030, 0x69c301a2, 0x27ed005b, 0x00000000}},  // [5860] tænd, hrne, nwen_,
  { {0x93fb0097, 0x7bc200b5, 0x6d4b186c, 0x00000000}},  //   _פליי, vrou, enga,
  { {0x39910428, 0x44220007, 0x0d8600ed, 0x00000000}},  //   _nás_, lyk_, член,
  { {0x7bc222c9, 0x6d4b0058, 0x60cd0253, 0x00000000}},  //   trou, gnga, cgam,
  { {0x8c3d014a, 0x27ed01aa, 0x4422007f, 0x00000000}},  //   _yeşi, jwen_, nyk_,
  { {0x6d4b0475, 0xf767025a, 0x6b9b0051, 0x00000000}},  //   anga, _سا_, _dtug,
  { {0x2d8408ef, 0xdca60072, 0x39910051, 0x00000000}},  //   _time_, _нави, _cás_,
  { {0x0798012b, 0x442222c4, 0x7bc2009d, 0x00000000}},  //   овић_, kyk_, prou,
  { {0x6d42001a, 0xba3c0006, 0xb8d400e8, 0x00000000}},  //   mioa, _neįv, _जज_,
  { {0x6d4222ca, 0x39910051, 0x103700b3, 0x00000000}},  //   lioa, _fás_, פטים_,
  { {0x7c2201aa, 0x39910b0c, 0xba9b009b, 0x00000000}},  //   lyor, _gás_, _הסבי,
  { {0x68e900ab, 0x7aea22cb, 0x6d421b90, 0x00000000}},  //   ceed, left, nioa,
  { {0x7c220129, 0x645a22cc, 0xf76f0014, 0x00000000}},  //   nyor, ştin, ضای_,
  { {0x6123006c, 0x6d4200e5, 0x00000000, 0x00000000}},  //   _tõlk, hioa,   ,
  { {0xe9ff00ad, 0x69d80039, 0x41e401e1, 0x00000000}},  //   _phẩm_, ntve, ніта,
  { {0x6131044f, 0x6d420032, 0x60cd007f, 0x00000000}},  //   _målg, jioa, ugam,
  { {0x2cad020f, 0x6d42002d, 0x60cd0207, 0x00000000}},  // [5870] _reed_, dioa, rgam,
  { {0x5187008b, 0x7aea0107, 0x60cd01e5, 0x00000000}},  //   _нума, jeft, sgam,
  { {0x27ed0263, 0xe9ff0011, 0x6b9b0039, 0x00000000}},  //   zwen_, _thẩm_, _stug,
  { {0x6d4222cd, 0x399122ce, 0x6d4b00e7, 0x00000000}},  //   gioa, _rás_, unga,
  { {0x6d930f68, 0x68e90211, 0x6d4b04be, 0x00000000}},  //   _għan, veed, rnga,
  { {0x69d80010, 0x7aea0030, 0x68e90068, 0x00000000}},  //   ftve, geft, weed,
  { {0x44220a32, 0x68e922cf, 0x2cad006c, 0x00000000}},  //   zyk_, teed, _teed_,
  { {0x3991004f, 0x6d42001a, 0xc2e90044, 0x00000000}},  //   _vás_, cioa, খাটি_,
  { {0x68e900c7, 0x27ed02ae, 0xf1b801d5, 0x00000000}},  //   reed, uwen_, ġġi_,
  { {0x7d1b0038, 0x752d0061, 0x7bcb0058, 0x00000000}},  //   _hous, _alaz, mugu,
  { {0x752d0d0a, 0x7d1b00b9, 0x7bcb01e5, 0x00000000}},  //   _blaz, _kous, lugu,
  { {0xc329061e, 0x7d1b0128, 0x44221091, 0x00000000}},  //   _דו_, _jous, tyk_,
  { {0x394d04bd, 0xd90f026c, 0x395f00ab, 0x00000000}},  //   mnes_, _لیں_, mous_,
  { {0x395f22d0, 0x6d42022b, 0x4422018d, 0x00000000}},  //   lous_, zioa, ryk_,
  { {0x394d0219, 0x7d0922d1, 0x7bcb22d2, 0x00000000}},  //   ones_, _ones, hugu,
  { {0x394d22d3, 0x752d0209, 0x7d1b021e, 0x00000000}},  //   nnes_, _glaz, _nous,
  { {0xef1a012b, 0x394d22d4, 0xa0670113, 0x00000000}},  // [5880] ома_, ines_, дата_,
  { {0xe7e503d7, 0x7bcb014a, 0xe9ff0011, 0x00000000}},  //   _कहना_, dugu, _nhắm_,
  { {0x7d1b1e83, 0x2d9c008d, 0x394d0089, 0x00000000}},  //   _bous, ëve_, knes_,
  { {0x7d1b00f4, 0x395f04bd, 0x2d9c0089, 0x00000000}},  //   _cous, jous_, īve_,
  { {0x6d4222d5, 0x7d1b01aa, 0x7bcb0760, 0x00000000}},  //   rioa, _dous, gugu,
  { {0x394d0211, 0x7d0922d6, 0x6d42002d, 0x00000000}},  //   enes_, _enes, sioa,
  { {0x7aea0193, 0x7bcb0089, 0x6d420a51, 0x00000000}},  //   reft, augu, pioa,
  { {0x394d02b6, 0x69d80343, 0x69ca010f, 0x00000000}},  //   gnes_, rtve, rufe,
  { {0x6d400409, 0x6f1c0065, 0x2ca612e8, 0x00000000}},  //   _imma, _korc, mbod_,
  { {0x752d05fa, 0x394d00f6, 0x65640020, 0x00000000}},  //   _slaz, anes_, _akih,
  { {0x7d1b22d7, 0x6f1c00f4, 0x395f22d8, 0x00000000}},  //   _yous, _morc, bous_,
  { {0x2ca60250, 0x394d0107, 0x6f1c008e, 0x00000000}},  //   nbod_, cnes_, _lorc,
  { {0x248d0ce4, 0x2732001d, 0x6d40012d, 0x00000000}},  //   žemo_, _nâng_, _mmma,
  { {0x6d930f68, 0x6f1c00ca, 0x6131044f, 0x00000000}},  //   _bħal, _norc, _måle,
  { {0x7bcb0032, 0x200200b0, 0x9294007e, 0x00000000}},  //   zugu, _arki_, тасц,
  { {0x752d0119, 0x39442273, 0x645a009d, 0x00000000}},  //   _ulaz, nims_, écié,
  { {0x6f1c22d9, 0x5184007e, 0x7d1b00f4, 0x00000000}},  // [5890] _borc, тура, _rous,
  { {0xce6b0a94, 0x7d1b00b9, 0x6d40021e, 0x00000000}},  //   оред_, _sous, _amma,
  { {0x7d1b0e6d, 0x6d930f68, 0x394d0675, 0x00000000}},  //   _pous, _għal, ynes_,
  { {0x63ad000b, 0x7bcb22da, 0x6d5a000c, 0x00000000}},  //   _kwan, tugu, _ítal,
  { {0x6f1c22db, 0xbbeb002c, 0x61310039, 0x00000000}},  //   _forc, ترام_, _våld,
  { {0x63ad0be3, 0x26e30055, 0x7bcb0311, 0x00000000}},  //   _mwan, _কোনো_, rugu,
  { {0x7d1b1e83, 0x394d001e, 0x7bcb0004, 0x00000000}},  //   _tous, tnes_, sugu,
  { {0x394d00f4, 0x7bcb22dc, 0x2129033b, 0x00000000}},  //   unes_, pugu, nkah_,
  { {0x394d068f, 0x8b6701b7, 0x395f22dd, 0x00000000}},  //   rnes_, _قائم, rous_,
  { {0x395f22de, 0x394d1419, 0x25720051, 0x00000000}},  //   sous_, snes_, dála_,
  { {0x63ad22df, 0x21290085, 0x394d01c5, 0x00000000}},  //   _awan, kkah_, pnes_,
  { {0x63ad1e5d, 0x2d9122e0, 0x67b90d0b, 0x00000000}},  //   _bwan, _muze_, _فاتح_,
  { {0x78270644, 0x25720051, 0x2d91002d, 0x00000000}},  //   _تعال, gála_, _luze_,
  { {0x2732000d, 0x68f90016, 0x63ad22e1, 0x00000000}},  //   _când_, _hawd, _dwan,
  { {0x2ca6018e, 0xc7b90047, 0xc0e60077, 0x00000000}},  //   ybod_, lső_, новк,
  { {0x68fb020c, 0x6f1c0c3c, 0xe9ff0082, 0x00000000}},  //   ndud, _sorc, _nhậm_,
  { {0x63ad0016, 0xdb0b000c, 0x291d0036, 0x00000000}},  // [58a0] _gwan, yrgð, _mowa_,
  { {0x2d91031a, 0x68fb006b, 0x273222e2, 0x00000000}},  //   _buze_, hdud, _vâng_,
  { {0xaac90201, 0x63ad22e3, 0x61312141, 0x00000000}},  //   _राजक, _zwan, _såle,
  { {0x8fa6008b, 0x6f1c0436, 0x2d91099b, 0x00000000}},  //   _паме, _worc, _duze_,
  { {0x6f1c22e4, 0xdb97008b, 0xead416c1, 0x00000000}},  //   _torc, евіч_, воль,
  { {0x45160044, 0xdd92023c, 0x5ec70044, 0x00000000}},  //   াসিক_, _موس_, র্বে,
  { {0x39440129, 0x27e60093, 0x63bb002b, 0x00000000}},  //   tims_, _spon_, ġuni,
  { {0x4ddb0097, 0x6d4001a3, 0x8c3d1f4a, 0x00000000}},  //   _מחלו, _umma, _peşt,
  { {0x39440006, 0x20000026, 0x6b8801f3, 0x00000000}},  //   rims_, nvii_, _tidg,
  { {0x63ad22e5, 0x3f8a000b, 0x394400d4, 0x00000000}},  //   _rwan, _jibu_, sims_,
  { {0x63ad0007, 0x68e2001c, 0x18a617be, 0x00000000}},  //   _swan, _tbod, _заем,
  { {0x80e008b7, 0x7afa22e6, 0x63ad0d16, 0x00000000}},  //   _পোস্, _hatt, _pwan,
  { {0x7afa0047, 0x27e600ab, 0x657d22e7, 0x00000000}},  //   _katt, _upon_, rmsh,
  { {0x257222e8, 0x7afa002b, 0x9388007c, 0x00000000}},  //   rála_, _jatt, есса_,
  { {0x31c400e3, 0x0697009b, 0x5ec70044, 0x00000000}},  //   лств, _אדום_, র্ডে,
  { {0x3f8a0020, 0x7afa191c, 0x212909e4, 0x00000000}},  //   _aibu_, _latt, ukah_,
  { {0x6d9301d5, 0x63ad000b, 0x2d910091, 0x00000000}},  // [58b0] _għaj, _uwan, _suze_,
  { {0x7afa0239, 0x212922e9, 0xa857009b, 0x00000000}},  //   _natt, skah_, תימה_,
  { {0x7e28007e, 0xbf9b01c3, 0x443901c5, 0x00000000}},  //   ніца_, _grên, lzs_,
  { {0x7afa0052, 0x00000000, 0x00000000, 0x00000000}},  //   _aatt,   ,   ,
  { {0x25560089, 0x00000000, 0x00000000, 0x00000000}},  //   nāla_,   ,   ,
  { {0xbbd102d2, 0x68f9002b, 0x0c24007e, 0x00000000}},  //   _समीक, _sawd, ымін,
  { {0xbe650076, 0x7afa068f, 0xe9ff0011, 0x00000000}},  //   _شهري, _datt, _thậm_,
  { {0xdb0b00f8, 0x00000000, 0x00000000, 0x00000000}},  //   dsgå,   ,   ,
  { {0x7afa0198, 0x68fb22ea, 0x69ce0030, 0x00000000}},  //   _fatt, rdud, _åben,
  { {0x7afa0207, 0x00000000, 0x00000000, 0x00000000}},  //   _gatt,   ,   ,
  { {0x64a6008b, 0x68f90544, 0x00000000, 0x00000000}},  //   кана, _tawd,   ,
  { {0xe894008b, 0x7afa0026, 0x2fc90007, 0x00000000}},  //   _баць, _zatt, krag_,
  { {0x78a922eb, 0x20000288, 0x7afa0095, 0x00000000}},  //   mbev, xvii_, _yatt,
  { {0x03a30057, 0x2b4708f0, 0x20000026, 0x00000000}},  //   риро, ninc_, vvii_,
  { {0x80e00055, 0x3f8a0169, 0xe2970545, 0x00000000}},  //   _পোষ্, _ribu_, тас_,
  { {0x2fc921b3, 0x78a90250, 0x3f8a01a3, 0x00000000}},  //   frag_, nbev, _sibu_,
  { {0xf8b20476, 0x21670407, 0x54a50025, 0x00000000}},  // [58c0] ישן_, тити_, _صحيف,
  { {0x6123006c, 0x6d930066, 0x798b01d6, 0x00000000}},  //   _sõlt, _għak, _ligw,
  { {0x7afa006c, 0x4256025f, 0xb606008e, 0x00000000}},  //   _ratt, _штит, _ibáñ,
  { {0x7afa0d3c, 0x80e00044, 0x00000000, 0x00000000}},  //   _satt, _পোর্,   ,
  { {0xeb97004c, 0x7afa00ab, 0x78a917f1, 0x00000000}},  //   вич_, _patt, dbev,
  { {0x7afa002b, 0x00000000, 0x00000000, 0x00000000}},  //   _qatt,   ,   ,
  { {0x7afa0073, 0x798b0173, 0xe45f22ae, 0x00000000}},  //   _vatt, _bigw, ngör_,
  { {0x7afa0343, 0x5ec70044, 0x1bea00e2, 0x00000000}},  //   _watt, র্দে, _одби_,
  { {0x798b018e, 0x7afa086a, 0x8c6612c0, 0x00000000}},  //   _digw, _tatt, _شطرن,
  { {0x6131093b, 0x25560089, 0x00000000, 0x00000000}},  //   _måla, vāla_,   ,
  { {0xa37b00c4, 0x2d8c0010, 0x00000000, 0x00000000}},  //   ntõe, _édes_,   ,
  { {0x77920123, 0x25560089, 0x18a6025f, 0x00000000}},  //   _پیدا, tāla_, _радм,
  { {0xd6d200a2, 0xe9ff0011, 0x00000000, 0x00000000}},  //   _نقش_, _thảm_,   ,
  { {0x2d870779, 0x5693007e, 0x443922ec, 0x00000000}},  //   ínez_, _кашт, rzs_,
  { {0x442d01cd, 0x673d0023, 0x3205013e, 0x00000000}},  //   še_, ësje, íly_,
  { {0x2fc922ed, 0x3998120d, 0x69ca22ee, 0x00000000}},  //   trag_, _més_, irfe,
  { {0xaad203d7, 0xa075003b, 0x6d930066, 0x00000000}},  // [58d0] _सांक, угач, _tħak,
  { {0x61f9007e, 0x9855006b, 0xa2f522ef, 0x00000000}},  //   _зноў_, _ləğv_, _споч,
  { {0x3998009d, 0x656f22f0, 0xe8df0082, 0x00000000}},  //   _nés_, olch, hiền_,
  { {0xdcfc006b, 0xf653009b, 0xd01000a1, 0x00000000}},  //   _vurğ, בצע_, حلے_,
  { {0x798b002b, 0xc05b0088, 0xfc30006d, 0x00000000}},  //   _rigw, _цін_, يحه_,
  { {0xab64008b, 0xc5e90044, 0x798b00e0, 0x00000000}},  //   авіл, গিতা_, _sigw,
  { {0xa96902e9, 0x2b470232, 0x00000000, 0x00000000}},  //   ника_, rinc_,   ,
  { {0x6c8500f3, 0xe9ff0011, 0x2b4700ea, 0x00000000}},  //   _ملزم, _chạm_, sinc_,
  { {0x78a90030, 0x2b490051, 0xc6200044, 0x00000000}},  //   rbev, éacs_, _ফেলা_,
  { {0x46f5007c, 0x39980129, 0x78a901bf, 0x00000000}},  //   учит, _fés_, sbev,
  { {0x45861663, 0x2b4500f6, 0x78a906ec, 0x00000000}},  //   лгов, _imlc_, pbev,
  { {0xaadf0164, 0x03a6013b, 0x629c0009, 0x00000000}},  //   प्रक, лимо, wcro,
  { {0x290f0073, 0xc3d6007e, 0x00000000, 0x00000000}},  //   _inga_, ыўны,   ,
  { {0xcc3a007b, 0xdc3a0049, 0xe3e700a1, 0x00000000}},  //   געשט, געשר, اکين_,
  { {0x6d9301f3, 0x00000000, 0x00000000, 0x00000000}},  //   _iħaw,   ,   ,
  { {0x629c009d, 0x217600ed, 0x255601c5, 0x00000000}},  //   scro, ѓувр, mālo_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [58e0]   ,   ,   ,
  { {0x63a4006a, 0xd2aa007e, 0xbf9b0181, 0x00000000}},  //   _itin, _якое_, _grêm,
  { {0x25560089, 0x290f0058, 0x6d930066, 0x00000000}},  //   nālo_, _onga_, _mħaw,
  { {0xa37b0181, 0x3998060d, 0xac970014, 0x00000000}},  //   rtõe, _rés_, هنما_,
  { {0x77f2024c, 0xa37b0181, 0x60d60016, 0x00000000}},  //   _अनेक_, stõe, mgym,
  { {0x81c90055, 0x63a40020, 0x39980181, 0x00000000}},  //   োবর_, _mtin, _pés_,
  { {0xe9ff001d, 0x829700b6, 0x656f0016, 0x00000000}},  //   _phạm_, נדקס_, ylch,
  { {0xa96701fc, 0x69ca01f3, 0x399800d4, 0x00000000}},  //   лија_, rrfe, _vés_,
  { {0x3d11001c, 0xfaa6109f, 0x4734013b, 0x00000000}},  //   णारे_, _базо, инис,
  { {0x5837007c, 0x290f22f1, 0x26d801a2, 0x00000000}},  //   узья_, _enga_, üro_,
  { {0x63a422f2, 0x49ca0113, 0xa2ce0204, 0x00000000}},  //   _atin, _член_, _ताज्,
  { {0x9f49009f, 0xd6ac0044, 0x7bcd000c, 0x00000000}},  //   hvað_, _খাওয, áaug,
  { {0xbf9b0181, 0x78bd01e5, 0xe72a22f3, 0x00000000}},  //   _prêm, ðsve, _подд_,
  { {0x6d93002b, 0x00000000, 0x00000000, 0x00000000}},  //   _għaw,   ,   ,
  { {0x2d9c02d5, 0x5fc70061, 0x63a4049d, 0x00000000}},  //   ível_, _लिहल, _etin,
  { {0xddcb01d5, 0x00000000, 0x00000000, 0x00000000}},  //   ċiżj,   ,   ,
  { {0x3ecb003b, 0x00000000, 0x00000000, 0x00000000}},  // [58f0] ећем_,   ,   ,
  { {0x63600010, 0x00000000, 0x00000000, 0x00000000}},  //   köny,   ,   ,
  { {0x442b004a, 0x60ce1d83, 0x00000000, 0x00000000}},  //   lyc_, _şimş,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfe7000a1, 0x7bcb01c3, 0x8d740025, 0x00000000}},  //   _ہدف_, urgu, حالا,
  { {0xa3d6024c, 0x3eba22f4, 0xeb9600c0, 0x00000000}},  //   ांत_, capt_, шиш_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa925013b, 0x5ec70044, 0x61311bea, 0x00000000}},  //   рдил, র্শে, _målo,
  { {0x6d4b011c, 0xead50783, 0x64c80006, 0x00000000}},  //   miga, _возь, nčių,
  { {0x57450245, 0xe9ff0011, 0x3946008e, 0x00000000}},  //   рноб, _nhầm_, _emos_,
  { {0xbb840054, 0x65660010, 0x7ae5006c, 0x00000000}},  //   _اللي, tokh, õhtu,
  { {0x6d4b13b1, 0x290f22f5, 0xe9d0006d, 0x00000000}},  //   niga, _unga_, _رغم_,
  { {0xe72e01fb, 0x7c2b005b, 0x6d930066, 0x00000000}},  //   _де_, nygr, _tħaw,
  { {0x46a502a8, 0x05160044, 0x6d4b1b85, 0x00000000}},  //   _такв, াসের_, higa,
  { {0x6d4b22f6, 0xa2d70309, 0x00000000, 0x00000000}},  //   kiga, _बार्,   ,
  { {0x6d4b00ee, 0x10a60242, 0x00000000, 0x00000000}},  //   jiga, риан,   ,
  { {0x6d4b1568, 0x672322f7, 0xdfa50025, 0x00000000}},  // [5900] diga, _konj, محلي,
  { {0x61310073, 0x3f8e000c, 0x60d622f8, 0x00000000}},  //   _håll, öfu_, sgym,
  { {0x67230b32, 0x6138008e, 0x75241293, 0x00000000}},  //   _monj, _píld, _koiz,
  { {0xb64c007b, 0x672301aa, 0x4d66007e, 0x00000000}},  //   עגאָ, _lonj, шкев,
  { {0x2ca90211, 0x613800b9, 0x69c11ab8, 0x00000000}},  //   ñada_, _cíle, _avle,
  { {0x613822f9, 0xa9c60d15, 0xf7670025, 0x00000000}},  //   _díle, асик, _ذا_,
  { {0x6d4b22fa, 0xd6bb0055, 0xd90d02fd, 0x00000000}},  //   biga, ংলায, کین_,
  { {0x6d4b106f, 0x7524002d, 0x7c2b22fb, 0x00000000}},  //   ciga, _noiz, bygr,
  { {0x6723028c, 0x14a701f5, 0x69c1014a, 0x00000000}},  //   _bonj, _क्षण, _evle,
  { {0x672306c0, 0x7d00002b, 0x473400da, 0x00000000}},  //   _conj, _hams, снос,
  { {0x3eb80047, 0x67230166, 0x2d980059, 0x00000000}},  //   _mert_, _donj, _jure_,
  { {0x7d02008d, 0x2d980160, 0x35470088, 0x00000000}},  //   ndos, _mure_, рхов,
  { {0xb796012b, 0x7d020052, 0xe9ff0082, 0x00000000}},  //   _трећ, idos, _phầm_,
  { {0x6d4b0e49, 0x7d0200b0, 0x2fc00146, 0x00000000}},  //   ziga, hdos, dsig_,
  { {0x6d4b0009, 0x2fc001c3, 0x00000000, 0x00000000}},  //   yiga, esig_,   ,
  { {0x7524002d, 0x44b501fc, 0x67230065, 0x00000000}},  //   _goiz, _убис, _zonj,
  { {0x6d4b10f0, 0x3eb800b5, 0xe9ff0011, 0x00000000}},  // [5910] viga, _bert_, _thầm_,
  { {0x3eb80129, 0x2d9822fc, 0x6d4b22fd, 0x00000000}},  //   _cert_, _bure_, wiga,
  { {0x7d000190, 0x6d4b22fe, 0x2d9806da, 0x00000000}},  //   _bams, tiga, _cure_,
  { {0xe1f000e9, 0x7d000fc1, 0x2d9805f2, 0x00000000}},  //   _کسی_, _cams, _dure_,
  { {0x6d4b02d5, 0xfc050517, 0x2d9822ff, 0x00000000}},  //   riga, спло, _eure_,
  { {0x3eb82300, 0x6d4b2301, 0x3da700ed, 0x00000000}},  //   _gert_, siga, _враб,
  { {0x2d98022b, 0x6d4b0020, 0xdef8008b, 0x00000000}},  //   _gure_, piga, _тыя_,
  { {0x672301aa, 0xe9a80054, 0x200b0022, 0x00000000}},  //   _sonj, جدون_, _krci_,
  { {0x6d492302, 0xb8ff0201, 0x2d98022b, 0x00000000}},  //   _imea, _ता_, _zure_,
  { {0x49b800a1, 0x3f990006, 0x2572000c, 0x00000000}},  //   _چاند_, _musu_, máli_,
  { {0x3ea1001f, 0x67230880, 0x1e3a0049, 0x00000000}},  //   icht_, _vonj, ָגרא,
  { {0xc32900b6, 0xb8950054, 0x2fc0018e, 0x00000000}},  //   _או_, _الإع, ysig_,
  { {0x394d1d2c, 0x3f990020, 0x291f0d16, 0x00000000}},  //   mies_, _nusu_, mjua_,
  { {0x673a00b5, 0x3f9110ec, 0x6d930066, 0x00000000}},  //   chtj, _nizu_, _jħas,
  { {0x4343026b, 0x200b2303, 0x2bd1013d, 0x00000000}},  //   черв, _arci_, _समझा,
  { {0x3eb80670, 0x394d12a0, 0x3f4f0089, 0x00000000}},  //   _sert_, nies_, kļus_,
  { {0x4e9606ea, 0x2d982304, 0xb4b4007d, 0x00000000}},  // [5920] مشار, _sure_, टरी_,
  { {0x2d980207, 0x3f99037e, 0x6d4901d7, 0x00000000}},  //   _pure_, _dusu_, _amea,
  { {0x394d22b0, 0x3eb80292, 0x2fc004b2, 0x00000000}},  //   kies_, _vert_, ssig_,
  { {0x3ea1002a, 0x394d2305, 0x7d020066, 0x00000000}},  //   acht_, jies_, udos,
  { {0x394d0038, 0x7d022306, 0xe6070167, 0x00000000}},  //   dies_, rdos, _کش_,
  { {0x8fa30265, 0x2d981d2f, 0x63b6018e, 0x00000000}},  //   _харе, _ture_, _mwyn,
  { {0x394d2307, 0x79a3008b, 0x7d000006, 0x00000000}},  //   fies_, прые, _tams,
  { {0x212001ae, 0x6d5b0065, 0xfce301ab, 0x00000000}},  //   njih_, _gjua, _носо,
  { {0x98a3003b, 0x00000000, 0x00000000, 0x00000000}},  //   чиње,   ,   ,
  { {0x19ba2308, 0xfe6f026c, 0x7bc20173, 0x00000000}},  //   _будь_, _آگے_, msou,
  { {0x394d002b, 0xb9960d75, 0x7bc22309, 0x00000000}},  //   bies_, _الصب, lsou,
  { {0x673a008d, 0x394d01cb, 0x26c7016c, 0x00000000}},  //   shtj, cies_, _edno_,
  { {0xdb09009f, 0x21200e00, 0x63b60016, 0x00000000}},  //   _kveð, djih_, _cwyn,
  { {0x6aba00eb, 0x799a0020, 0x3f9913bd, 0x00000000}},  //   _jetf, _kutw, _rusu_,
  { {0x6aba0066, 0x4177023c, 0x3f9904cb, 0x00000000}},  //   _metf, مارس, _susu_,
  { {0x2904006c, 0x3f99014a, 0x799a230a, 0x00000000}},  //   ndma_, _pusu_, _mutw,
  { {0x645a011f, 0x63b6018e, 0x61fe1733, 0x00000000}},  // [5930] ştir, _gwyn, _espl,
  { {0x394d21bf, 0x3ea1010f, 0x6d49230b, 0x00000000}},  //   zies_, ucht_, _smea,
  { {0x2ca90211, 0x3f910107, 0xcc9903e0, 0x00000000}},  //   ñado_, _vizu_, авец_,
  { {0x394d1a86, 0x3ea1010f, 0x200b0107, 0x00000000}},  //   xies_, scht_, _trci_,
  { {0x394d0fe8, 0xb6070428, 0xeab90ae0, 0x00000000}},  //   vies_, _koší, айл_,
  { {0x9abc0066, 0x2009230c, 0xc9a90cee, 0x00000000}},  //   _doċo, mvai_, авке_,
  { {0x394d230d, 0xf2d40049, 0x6d5b00ea, 0x00000000}},  //   ties_, לעס_, _tjua,
  { {0x5d5400d7, 0x6d49117b, 0x9ce700a1, 0x00000000}},  //   _екст, _umea, _دورے_,
  { {0xf719008b, 0xe8df0011, 0xdcff007f, 0x00000000}},  //   аіны_, hiện_, _žvėr,
  { {0x394d230e, 0x6aba0061, 0x6d93230f, 0x00000000}},  //   sies_, _getf, _għar,
  { {0xab84008b, 0x799a0009, 0x394d00fe, 0x00000000}},  //   _хутк, _gutw, pies_,
  { {0x2903001e, 0x6b9b2134, 0x63b60016, 0x00000000}},  //   ējas_, _kuug, _pwyn,
  { {0x69c30030, 0x25560089, 0x6d5901a2, 0x00000000}},  //   lsne, nāli_, inwa,
  { {0x68e92310, 0x6b9b2134, 0xcb9a0049, 0x00000000}},  //   lfed, _muug, יסשט,
  { {0xcb12019b, 0x21200059, 0x320c0802, 0x00000000}},  //   ולם_, tjih_, ídy_,
  { {0x6138000c, 0x236a0045, 0x69c30094, 0x00000000}},  //   _bíla, sobj_, isne,
  { {0xfe78010a, 0x21200059, 0x69c30240, 0x00000000}},  // [5940] _šį_, rjih_, hsne,
  { {0xef170373, 0x6d590253, 0x69c306ed, 0x00000000}},  //   ому_, enwa, ksne,
  { {0x6aba2311, 0xe4d30167, 0x7bc2000a, 0x00000000}},  //   _retf, _عقید, wsou,
  { {0x7bc20403, 0x69c3000c, 0x6aba0019, 0x00000000}},  //   tsou, dsne, _setf,
  { {0x2d8601d6, 0x68e92312, 0x00000000, 0x00000000}},  //   rmoe_, dfed,   ,
  { {0xaff90049, 0x39a6007c, 0x79a60326, 0x00000000}},  //   _פּרי, ошив, орие,
  { {0x7bc2032c, 0x68e90190, 0x69c32313, 0x00000000}},  //   ssou, ffed, gsne,
  { {0x7bc200d4, 0x63a9001a, 0x20070036, 0x00000000}},  //   psou, ţeni, łnie_,
  { {0x29040b1b, 0x6d93002b, 0x320a0045, 0x00000000}},  //   rdma_, _għaq, hvby_,
  { {0x29020165, 0x6a1601b7, 0xf7720d3a, 0x00000000}},  //   žka_, _وبار, باع_,
  { {0xff7b0049, 0x5ec70044, 0x7e9b009b, 0x00000000}},  //   שטימ, র্কে, יסיו,
  { {0x20090006, 0x00000000, 0x00000000, 0x00000000}},  //   yvai_,   ,   ,
  { {0x69d8000c, 0x2bd2006e, 0x6933007e, 0x00000000}},  //   luve, _सिफा, _іншу,
  { {0xdcfc010a, 0x2fd201c3, 0x00000000, 0x00000000}},  //   _turė, dryg_,   ,
  { {0xf5b30025, 0x929400ed, 0x61380325, 0x00000000}},  //   _قصيد, дарц, _síla,
  { {0x6edd0061, 0x9099005e, 0x00000000, 0x00000000}},  //   _पाहु, сват_,   ,
  { {0xe57200bd, 0x442f0637, 0xa49b0026, 0x00000000}},  // [5950] _אַז_, _æg_, ndòm,
  { {0xeeab003b, 0x61312314, 0x69d8000c, 0x00000000}},  //   ртак_, _måli, kuve,
  { {0x69d8000c, 0x68e90016, 0x20090006, 0x00000000}},  //   juve, yfed, svai_,
  { {0x69c30146, 0x6b9b010e, 0x00000000, 0x00000000}},  //   vsne, _puug,   ,
  { {0x69c30016, 0xeb990a1e, 0xfaa5007e, 0x00000000}},  //   wsne, щил_, пало,
  { {0x69c32315, 0x25720010, 0x68e9005b, 0x00000000}},  //   tsne, lált_, wfed,
  { {0x69d801c5, 0x69c30133, 0x28dc0061, 0x00000000}},  //   guve, usne, _याशि,
  { {0x69c300b5, 0x25720010, 0x79820075, 0x00000000}},  //   rsne, nált_, _chow,
  { {0x69c3000c, 0x1bd5007c, 0x68e9005b, 0x00000000}},  //   ssne, _хозя, rfed,
  { {0x61310039, 0x28ab006e, 0x7af800ca, 0x00000000}},  //   _dåli, _ट्रि, cevt,
  { {0xb9e701fb, 0xa50a1281, 0x366902b8, 0x00000000}},  //   _фізи, бена_, сано_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc952009b, 0x889a009b, 0x6138000c, 0x00000000}},  //   _אמא_, _הבני, _bíln,
  { {0x443e0036, 0x00000000, 0x00000000, 0x00000000}},  //   ąt_,   ,   ,
  { {0xd252025a, 0x613801dc, 0x661c09b0, 0x00000000}},  //   رنر_, _díln, ärkt,
  { {0x25aa008e, 0x3f83010e, 0x00000000, 0x00000000}},  //   íble_, _ahju_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [5960]   ,   ,   ,
  { {0x37bd0055, 0xdfcf0380, 0x2fd20190, 0x00000000}},  //   _আমার, ايل_, rryg_,
  { {0x6edd0164, 0xe29b009b, 0x2d9c0068, 0x00000000}},  //   _पारु, _לשיר, êve_,
  { {0xbf9b00f4, 0xdca3025f, 0xdd8f006d, 0x00000000}},  //   _prêt, еаци, هول_,
  { {0x79820016, 0x628300b9, 0x00000000, 0x00000000}},  //   _rhow, _únor,   ,
  { {0x79820038, 0x69d80089, 0x20022316, 0x00000000}},  //   _show, tuve, _iski_,
  { {0x7d7a0014, 0xdce90066, 0x00000000, 0x00000000}},  //   _همسر_, _wieġ,   ,
  { {0x61310cb2, 0x00000000, 0x00000000, 0x00000000}},  //   _påli,   ,   ,
  { {0x25560089, 0x7af800ca, 0x2d8400b0, 0x00000000}},  //   nālu_, pevt, _ihme_,
  { {0x6b660147, 0x9b46023c, 0x25720010, 0x00000000}},  //   _экза, _عناو, zált_,
  { {0x3d110061, 0x46dd0061, 0x2572000c, 0x00000000}},  //   णाचे_, _मारह, jáls_,
  { {0x4a7b007b, 0xa806008e, 0xda650025, 0x00000000}},  //   _פראב, _cañó, _غالي,
  { {0x5ec70044, 0x25720010, 0x00000000, 0x00000000}},  //   র্টে, vált_,   ,
  { {0x3b05005f, 0x661c0a5d, 0x9abc01d5, 0x00000000}},  //   _xalq_, ärks, _soċj,
  { {0x2002002d, 0x61310479, 0x6138013e, 0x00000000}},  //   _aski_, _målv, _cílo,
  { {0x59dd0061, 0x672a00d9, 0x00000000, 0x00000000}},  //   नंतर, _hofj,   ,
  { {0xb4d90164, 0x656f0046, 0x5f9501e0, 0x00000000}},  // [5970] ाली_, moch, диат,
  { {0xd24e026c, 0x63ad011c, 0x09b20055, 0x00000000}},  //   اچی_, _itan, _ঘটনা,
  { {0x2002011f, 0xdce901d5, 0x00000000, 0x00000000}},  //   _eski_, _jieħ,   ,
  { {0x23610082, 0x00000000, 0x00000000, 0x00000000}},  //   _hjhj_,   ,   ,
  { {0x69c801c9, 0xc1720123, 0x220700b9, 0x00000000}},  //   _avde, _شگفت, bíhá_,
  { {0x63ad000b, 0x212b010f, 0x68e22317, 0x00000000}},  //   _mtan, _hoch_, _acod,
  { {0x656f1dff, 0x2bc9007d, 0x212b010f, 0x00000000}},  //   koch, _रिका, _koch_,
  { {0x63ad0d2a, 0x26de0089, 0xf1c0013e, 0x00000000}},  //   _otan, egto_, ýšit_,
  { {0x63ad0117, 0x1bd4004c, 0x212b0016, 0x00000000}},  //   _ntan, _потя, _moch_,
  { {0x68e200d4, 0x212b0e93, 0x2bd2013d, 0x00000000}},  //   _ecod, _loch_, _सिता,
  { {0x63ad0263, 0x7a350025, 0x6f070091, 0x00000000}},  //   _atan, _تفاص, _majc,
  { {0x212b001f, 0x656f00bb, 0xdce9002b, 0x00000000}},  //   _noch_, goch, _dieħ,
  { {0x394f0061, 0x68fb0190, 0xa2b2013d, 0x00000000}},  //   _imgs_, meud, _अभद्,
  { {0x6f070036, 0x68fb0190, 0x25560089, 0x00000000}},  //   _najc, leud, vālu_,
  { {0xe2970269, 0x63ad0056, 0x656f0173, 0x00000000}},  //   дар_, _etan, boch,
  { {0x656f2318, 0x2ca60061, 0x212b0016, 0x00000000}},  //   coch, xcod_, _coch_,
  { {0x212b001f, 0xa494007a, 0x1b040044, 0x00000000}},  // [5980] _doch_, _سیست, লাতে_,
  { {0x03d701ce, 0x638605b8, 0x394f01f3, 0x00000000}},  //   _קוים_, _ігна, _lmgs_,
  { {0x614600aa, 0x831b0049, 0x68fb021e, 0x00000000}},  //   _жена, _וויז, keud,
  { {0x212b2319, 0xec7a0140, 0x20070036, 0x00000000}},  //   _goch_, опе_, łnia_,
  { {0x0b8a00ed, 0x68fb0f03, 0x2cbf0016, 0x00000000}},  //   оски_, deud, _deud_,
  { {0x656f00b5, 0x8f75007e, 0x68e2231a, 0x00000000}},  //   zoch, _зусі, _scod,
  { {0x62980161, 0x656f0020, 0x68fb00f6, 0x00000000}},  //   _úvod, yoch, feud,
  { {0x3f98022b, 0x60c40051, 0x6f0700ca, 0x00000000}},  //   _hiru_, naim, _zajc,
  { {0x656f00d9, 0x3f98231b, 0xdce9002b, 0x00000000}},  //   voch, _kiru_, _sieħ,
  { {0x64460036, 0x60c40085, 0x63ad016c, 0x00000000}},  //   dzki, haim, _rtan,
  { {0x656f0036, 0xd5b70783, 0x3f980c1e, 0x00000000}},  //   toch, мся_, _miru_,
  { {0xb4d902d2, 0x2bd20061, 0x63ad0d9b, 0x00000000}},  //   ाले_, सळपा, _ptan,
  { {0xdce901d5, 0x656f010f, 0x212b0173, 0x00000000}},  //   _wieħ, roch, _roch_,
  { {0xf64f04e1, 0xc87f010f, 0xdce9002b, 0x00000000}},  //   ائی_, üße_, _tieħ,
  { {0x656f0161, 0x4394007e, 0x6f070062, 0x00000000}},  //   poch, тарс, _rajc,
  { {0x60c4231c, 0x613806c2, 0x777a0009, 0x00000000}},  //   gaim, _fílm, lltx,
  { {0x3f9804cb, 0xbf9b009d, 0xe811007d, 0x00000000}},  // [5990] _biru_, _crêp, ़िया_,
  { {0xc808001d, 0xfd64001d, 0x63ad0089, 0x00000000}},  //   _mở_, _thuộ, ķinā,
  { {0x212b02ae, 0x3f98022b, 0x7bc90a1c, 0x00000000}},  //   _toch_, _diru_, _sveu,
  { {0xd9f80061, 0x27ff0016, 0x60c4231d, 0x00000000}},  //   ंबईत_, ywun_, caim,
  { {0xc8080011, 0x6f070107, 0x60cf00f6, 0x00000000}},  //   _nở_, _tajc, _idcm,
  { {0xfbd00a90, 0x394f01f3, 0x3f980087, 0x00000000}},  //   شته_, _smgs_, _giru_,
  { {0x644600d9, 0x00000000, 0x00000000, 0x00000000}},  //   zzki,   ,   ,
  { {0x6d42231e, 0xb4d90164, 0xc8080082, 0x00000000}},  //   choa, ालो_, _bở_,
  { {0x68fb0c53, 0x0bd50025, 0x2919006b, 0x00000000}},  //   reud, _سياح, ısa_,
  { {0xc8080011, 0x68fb00b0, 0x7c84231f, 0x00000000}},  //   _dở_, seud, _русе,
  { {0x752d2320, 0x7d1b0374, 0x68fb0bac, 0x00000000}},  //   _boaz, _knus, peud,
  { {0x6131044f, 0x25560089, 0x752d0026, 0x00000000}},  //   _måls, vāls_, _coaz,
  { {0xd90f024a, 0x7d090e1d, 0x752d2321, 0x00000000}},  //   _میں_, _maes, _doaz,
  { {0xa856009b, 0x78a901ee, 0xd34200a1, 0x00000000}},  //   _אינה_, lcev, اہدی,
  { {0x26c50091, 0x60c40ac2, 0x64460ef2, 0x00000000}},  //   malo_, taim, szki,
  { {0x395f021e, 0x752d002d, 0x7d090146, 0x00000000}},  //   nnus_, _goaz, _naes,
  { {0x60c42322, 0x03960735, 0x01630404, 0x00000000}},  // [59a0] raim, _проя, укто,
  { {0x26c5011c, 0x60c40089, 0x752d0032, 0x00000000}},  //   nalo_, saim, _zoaz,
  { {0x3f98006c, 0xb3450065, 0x3ce40146, 0x00000000}},  //   _viru_, saçë, _pcmv_,
  { {0xdd11006b, 0x9f400129, 0x7c22002d, 0x00000000}},  //   rüşd, stià_, txor,
  { {0x7d090c3b, 0xe0df0173, 0x3f980145, 0x00000000}},  //   _daes, _blòf_, _tiru_,
  { {0xdd31005f, 0x06d50044, 0x26c50340, 0x00000000}},  //   _təşk, ত্তি, jalo_,
  { {0xc808001d, 0x26c5049c, 0x7d092323, 0x00000000}},  //   _sở_, dalo_, _faes,
  { {0x65640213, 0x395f0039, 0x7d1b01ee, 0x00000000}},  //   _njih, gnus_, _gnus,
  { {0xb9080183, 0x6d400b3e, 0x9a6a0167, 0x00000000}},  //   _बा_, _ilma, _کمال_,
  { {0x26c51a16, 0x78a90197, 0xc8080011, 0x00000000}},  //   galo_, acev, _vở_,
  { {0x0f5700b6, 0x61311367, 0xf5210451, 0x00000000}},  //   תיים_, _målr, аннi_,
  { {0x07a60242, 0x69ca01e5, 0x26c5016c, 0x00000000}},  //   _задн, msfe, aalo_,
  { {0x26c5016c, 0x2957007b, 0xdb000065, 0x00000000}},  //   balo_, _אסאך_, _numë,
  { {0xdb000039, 0x6b9a002b, 0x26c50091, 0x00000000}},  //   _utmä, _jitg, calo_,
  { {0x6d4001f6, 0x6b9a001f, 0x9268005e, 0x00000000}},  //   _olma, _mitg, ерта_,
  { {0x867b009b, 0x6f1c00e5, 0xab6600b4, 0x00000000}},  //   _מרוו, _anrc, leżą,
  { {0x629e0061, 0x7d0900f6, 0x69d801a2, 0x00000000}},  // [59b0] _fgpo, _raes, hrve,
  { {0x6d402324, 0x7d09018e, 0x657d2325, 0x00000000}},  //   _alma, _saes, llsh,
  { {0x7d090198, 0x2fc90190, 0x69ca01ee, 0x00000000}},  //   _paes, ssag_, jsfe,
  { {0x26c50059, 0x69ca032e, 0x62850059, 0x00000000}},  //   zalo_, dsfe, _izho,
  { {0x69d800bb, 0x78a9016c, 0x7d09006c, 0x00000000}},  //   erve, vcev, _vaes,
  { {0x6d400994, 0xdf47007e, 0x212900ca, 0x00000000}},  //   _elma, _чэмп, ljah_,
  { {0x78a9001a, 0x6b9a0085, 0x00000000, 0x00000000}},  //   tcev, _ditg,   ,
  { {0x212900ca, 0x7d1b109b, 0x6d580299, 0x00000000}},  //   njah_, _unus, évat,
  { {0x26c501d9, 0x395f1be3, 0x78a90370, 0x00000000}},  //   talo_, rnus_, rcev,
  { {0x78a90197, 0x657600f8, 0xdb0000d4, 0x00000000}},  //   scev, _skyh, _numè,
  { {0x99d4002c, 0x26c50091, 0x78a9012d, 0x00000000}},  //   _متنا, ralo_, pcev,
  { {0x21291b28, 0x26c50091, 0xf09f0082, 0x00000000}},  //   jjah_, salo_, _ngà_,
  { {0x26c50091, 0x21292326, 0x7bcb00f8, 0x00000000}},  //   palo_, djah_, nsgu,
  { {0xc7d6012f, 0x290d022b, 0x4375007c, 0x00000000}},  //   _יוני_, ldea_, густ,
  { {0x27ed001f, 0x27320035, 0x11d5013a, 0x00000000}},  //   lten_, _vânt_, літр,
  { {0x290d2327, 0x27ed0f30, 0x6285012d, 0x00000000}},  //   ndea_, oten_, _dzho,
  { {0x27ed2328, 0xd5ac00a1, 0x31600885, 0x00000000}},  // [59c0] nten_, _وہی_, rniz_,
  { {0x27ed1626, 0x127a0025, 0x45240044, 0x00000000}},  //   iten_, _يحدث_, _পতিক_,
  { {0x200d001e, 0x27ed010f, 0x333b0104, 0x00000000}},  //   _šeit_, hten_, _חתימ,
  { {0x63a4094d, 0x6b9a0129, 0x6dac0279, 0x00000000}},  //   _kuin, _sitg, _ağac,
  { {0x27ed0f86, 0x69ca01a3, 0xead42329, 0x00000000}},  //   jten_, wsfe, голь,
  { {0x63a40ddc, 0x27ed01e3, 0x6ec501d8, 0x00000000}},  //   _muin, dten_, _متفق,
  { {0x27ed18a6, 0x61ee00d4, 0x69d80112, 0x00000000}},  //   eten_, ntbl, urve,
  { {0x27ed0109, 0x69ca0007, 0x69d8232a, 0x00000000}},  //   ften_, rsfe, rrve,
  { {0x27ed232b, 0x1be7007c, 0xd7c70439, 0x00000000}},  //   gten_, _идти_, نويه_,
  { {0x6b9a049b, 0x77910167, 0x77920014, 0x00000000}},  //   _uitg, مینا, جیتا,
  { {0xdb00028c, 0x27ed010f, 0x2cad0016, 0x00000000}},  //   _numé, aten_, _yfed_,
  { {0xa9270006, 0x27ed010f, 0x291d0058, 0x00000000}},  //   gužė, bten_, _gnwa_,
  { {0x27ed02ae, 0x63a40129, 0x67d40ceb, 0x00000000}},  //   cten_, _cuin, _солу,
  { {0x63a4002a, 0x61ee232c, 0x00000000, 0x00000000}},  //   _duin, ftbl,   ,
  { {0x35a300ed, 0x61310146, 0x00000000, 0x00000000}},  //   _кајг, _bålp,   ,
  { {0x63a40051, 0x12e30044, 0xe8070061, 0x00000000}},  //   _fuin, য়েদ, वटचा_,
  { {0x40340057, 0x212901a3, 0xc05b0088, 0x00000000}},  // [59d0] аетс, rjah_, фів_,
  { {0x443900b0, 0xdb00009d, 0x02b7007d, 0x00000000}},  //   mys_, _fumé, _अभिभ,
  { {0x27ed022b, 0x4439010a, 0xb05b010f, 0x00000000}},  //   zten_, lys_, _geän,
  { {0xc5f30452, 0x27ed0007, 0x7bcb00f8, 0x00000000}},  //   ידע_, yten_, tsgu,
  { {0x4439232d, 0x27ed03a2, 0x50da009b, 0x00000000}},  //   nys_, xten_, _אקרא,
  { {0x7bcb0203, 0xc43c0049, 0x00000000, 0x00000000}},  //   rsgu, ותדי,   ,
  { {0x2b890027, 0x61380051, 0x7bcb06d3, 0x00000000}},  //   júce_, _síli, ssgu,
  { {0x09f60054, 0x44390006, 0x68480089, 0x00000000}},  //   افية_, kys_, kūdī,
  { {0x290d002d, 0x6d590058, 0x27ed232e, 0x00000000}},  //   rdea_, miwa, uten_,
  { {0x27ed001f, 0x6d5911ad, 0x44390006, 0x00000000}},  //   rten_, liwa, dys_,
  { {0x63a40d96, 0xa01b00b0, 0x61ee0009, 0x00000000}},  //   _suin, _hyöd, xtbl,
  { {0x6d59006a, 0x6e210129, 0x4439232f, 0x00000000}},  //   niwa, _àlbu, fys_,
  { {0x63a40a15, 0xd4560088, 0x44392330, 0x00000000}},  //   _quin, утнь, gys_,
  { {0x6d59011c, 0x03a32331, 0x91e60256, 0x00000000}},  //   hiwa, сиро, логе,
  { {0x6d590046, 0xc5d5111f, 0x00000000, 0x00000000}},  //   kiwa, _сіль,   ,
  { {0x63a401b5, 0x6d5904be, 0x78bb0006, 0x00000000}},  //   _tuin, jiwa, nbuv,
  { {0x61ee0a5e, 0x6d590020, 0xe816007d, 0x00000000}},  // [59e0] stbl, diwa, तिया_,
  { {0x06d50044, 0x7306003b, 0x61ee0203, 0x00000000}},  //   ত্রি, _споз, ptbl,
  { {0x6d59004a, 0x00000000, 0x00000000, 0x00000000}},  //   fiwa,   ,   ,
  { {0x869a0049, 0x6d590036, 0xa37b006c, 0x00000000}},  //   גיעז, giwa, stõt,
  { {0x9f4000b0, 0xafe30581, 0x00000000, 0x00000000}},  //   ttiä_, _лоял,   ,
  { {0x60c62332, 0x69c10016, 0xe0df0173, 0x00000000}},  //   _hekm, _bwle, _glòb_,
  { {0x4439007f, 0x7ec80089, 0x00000000, 0x00000000}},  //   zys_, rūpē,   ,
  { {0x9f4000b0, 0xaea10279, 0x443900b0, 0x00000000}},  //   stiä_, ğışl, yys_,
  { {0x3b8600c0, 0xbc66012b, 0x6b46009f, 0x00000000}},  //   _благ, _свак, _aðge,
  { {0x17f70054, 0x37060f98, 0xbb76007c, 0x00000000}},  //   ارية_, учив, _субъ,
  { {0x44392333, 0xab930054, 0xb52102d2, 0x00000000}},  //   wys_, _اللغ, यालय_,
  { {0x44392334, 0x98a6022a, 0xd1bb00a1, 0x00000000}},  //   tys_, _сиде, ہارا_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4439010a, 0x6d5900e7, 0x237a0066, 0x00000000}},  //   rys_, ziwa, _ckpj_,
  { {0x443f001e, 0x44390006, 0xa29505b8, 0x00000000}},  //   šu_, sys_, раві,
  { {0x4439007f, 0xb35700a1, 0x00000000, 0x00000000}},  //   pys_, ئیگا_,   ,
  { {0x7d02014a, 0x9f5500e3, 0x9099005e, 0x00000000}},  // [59f0] deos, авач, тват_,
  { {0x3e6b005e, 0x00000000, 0x00000000, 0x00000000}},  //   ншен_,   ,   ,
  { {0x6d59011c, 0x539a009b, 0xa01b00b0, 0x00000000}},  //   tiwa, _שיתו, _syöd,
  { {0x61382335, 0x7d020146, 0x55bb00b3, 0x00000000}},  //   _sílv, geos, גמאו,
  { {0x9f49002a, 0x6d590fe7, 0x6f0e09e0, 0x00000000}},  //   ltaí_, riwa, _fabc,
  { {0x6d590e1a, 0xbe0500a1, 0x78a200bb, 0x00000000}},  //   siwa, _پورٹ, _agov,
  { {0xdea400d3, 0x2d870129, 0x69251548, 0x00000000}},  //   _ایمی, ïnes_, имка,
  { {0x7c392336, 0x8cc803ec, 0x2019016c, 0x00000000}},  //   pywr, _موفق_, _krsi_,
  { {0x9f49002a, 0xaae70151, 0x78a2016c, 0x00000000}},  //   htaí_, _مساو, _dgov,
  { {0x7a1c0035, 0xdceb0035, 0xe7392337, 0x00000000}},  //   _bătă, bogă, тео_,
  { {0x3669003b, 0x24892338, 0x8af7006b, 0x00000000}},  //   тано_, _azam_, şəsi,
  { {0xf8b000a1, 0x20192339, 0x7a1c00e5, 0x00000000}},  //   _ٹکٹ_, _orsi_, _dătă,
  { {0x5ed00055, 0x61380051, 0x03a602ea, 0x00000000}},  //   স্টে, _mílt, риго,
  { {0x290f0211, 0x60c6233a, 0x66e2003b, 0x00000000}},  //   _haga_, _sekm, _доша,
  { {0x290f0093, 0xf6790049, 0xd75602fd, 0x00000000}},  //   _kaga_, _באַמ, _خلوت_,
  { {0x290f01a3, 0x2bc60204, 0x26c70016, 0x00000000}},  //   _jaga_, रीडा, _heno_,
  { {0x290f0010, 0x26c707e7, 0xa49b00f6, 0x00000000}},  // [5a00] _maga_, _keno_, leòn,
  { {0x290f0635, 0xdce90142, 0x20190087, 0x00000000}},  //   _laga_, _cieľ, _drsi_,
  { {0x26c7233b, 0x3869009f, 0x60c601d9, 0x00000000}},  //   _meno_, _þarf_, _tekm,
  { {0x290f1577, 0xe5f60049, 0x2d8d0145, 0x00000000}},  //   _naga_, יזער_, _chee_,
  { {0x7d0213d8, 0x6f0e0009, 0x2d9f00f6, 0x00000000}},  //   reos, _tabc, _diue_,
  { {0x26c70020, 0xc60c0044, 0x7d021389, 0x00000000}},  //   _neno_, ষমতা_, seos,
  { {0xe60700f3, 0x290f233c, 0xf2d3009b, 0x00000000}},  //   _بش_, _baga_, קעה_,
  { {0x2d8d0203, 0x290f0919, 0xf98f0380, 0x00000000}},  //   _ghee_, _caga_, وبي_,
  { {0x1ae60057, 0x8ad60b03, 0x8c431023, 0x00000000}},  //   _возм, _نتائ, _дете,
  { {0xaae00164, 0x26c70059, 0x61fe0292, 0x00000000}},  //   _नाटक, _ceno_, _oppl,
  { {0x3333233d, 0x63b6233e, 0x290f00ea, 0x00000000}},  //   _roxx_, _atyn, _faga_,
  { {0x78a20ce4, 0xd5b80089, 0xa37b00fa, 0x00000000}},  //   _ugov, rpā_, irõe,
  { {0x290400f6, 0x7d1d00c4, 0x25720161, 0x00000000}},  //   mema_, _ósse, nály_,
  { {0x2904006c, 0x21221a3a, 0x290f00c4, 0x00000000}},  //   lema_, _ankh_, _zaga_,
  { {0x26cc0489, 0x27e400ab, 0x25720344, 0x00000000}},  //   mado_, lumn_, hály_,
  { {0x26cc0682, 0xa37b0181, 0x9f490051, 0x00000000}},  //   lado_, drõe, rtaí_,
  { {0x9f490051, 0x83870147, 0x2d8d02c2, 0x00000000}},  // [5a10] staí_, _выне, _rhee_,
  { {0x26cc0977, 0x20190107, 0x26c70197, 0x00000000}},  //   nado_, _vrsi_, _xeno_,
  { {0x2904002b, 0xadf502b0, 0x394601ee, 0x00000000}},  //   kema_, спеш, _olos_,
  { {0x2904233f, 0x26cc0325, 0x12160049, 0x00000000}},  //   jema_, hado_, _פֿיר_,
  { {0x26cc011c, 0x29042340, 0x290f023a, 0x00000000}},  //   kado_, dema_, _raga_,
  { {0x290f000c, 0x26cc0b76, 0x394601aa, 0x00000000}},  //   _saga_, jado_, _alos_,
  { {0x290f002b, 0x26cc0489, 0xd20a0049, 0x00000000}},  //   _paga_, dado_, ָלפֿ,
  { {0x26c7086f, 0x2904006c, 0x3946009d, 0x00000000}},  //   _seno_, gema_, _clos_,
  { {0x290f153d, 0x26cc0285, 0x25a009e4, 0x00000000}},  //   _vaga_, fado_, _riil_,
  { {0x26cc2341, 0xbb850054, 0x60cd2342, 0x00000000}},  //   gado_, _الطي, haam,
  { {0x290f14f7, 0x60cd03b6, 0x49da00a1, 0x00000000}},  //   _taga_, kaam, _مانگ_,
  { {0x60cd03b6, 0x26c70efe, 0x29042343, 0x00000000}},  //   jaam, _weno_, cema_,
  { {0xe72e0057, 0x68e90b36, 0x6dac1a6f, 0x00000000}},  //   _ее_, mged, _ağal,
  { {0x26cc16be, 0x9f400051, 0x26c70022, 0x00000000}},  //   cado_, stiú_, _ueno_,
  { {0x5ede0044, 0x9f4000c4, 0x60cd17e3, 0x00000000}},  //   ন্ডে, quié_, faam,
  { {0x661c0030, 0xa37b00c4, 0x60cd007f, 0x00000000}},  //   ærke, vrõe, gaam,
  { {0x75242344, 0x20090085, 0x644f00b4, 0x00000000}},  // [5a20] _iniz, gwai_, czci,
  { {0x32460088, 0x290400b4, 0x2bab013d, 0x00000000}},  //   _геог, zema_, _चढ़ा,
  { {0xa75a007b, 0x61fe05ce, 0x75240062, 0x00000000}},  //   נדער, _uppl, _kniz,
  { {0x26cc0df9, 0x0c2601e1, 0xeabf0011, 0x00000000}},  //   zado_, ймен, _đùa_,
  { {0x26cc2345, 0x6b46000c, 0x68e90116, 0x00000000}},  //   yado_, _aðga, dged,
  { {0xf7670014, 0x26cc2346, 0x2572139d, 0x00000000}},  //   _را_, xado_, rály_,
  { {0x26cc0977, 0x29040066, 0x68e9021f, 0x00000000}},  //   vado_, tema_, fged,
  { {0x68e905b7, 0x57b40088, 0x6d4b2347, 0x00000000}},  //   gged, обит, chga,
  { {0x26cc0df9, 0x290401d9, 0xdb0100c4, 0x00000000}},  //   tado_, rema_, _milê,
  { {0x29040be3, 0x3ae8007a, 0x60cd00b5, 0x00000000}},  //   sema_, _خبری_, zaam,
  { {0x26cc0977, 0x290406cc, 0x60cd00e7, 0x00000000}},  //   rado_, pema_, yaam,
  { {0x26cc2348, 0x6d42002d, 0x394600b0, 0x00000000}},  //   sado_, nkoa, _ulos_,
  { {0xb8960054, 0x26cc0489, 0x6d42002d, 0x00000000}},  //   _الشع, pado_, ikoa,
  { {0x60cd0020, 0x5ede0044, 0x16590014, 0x00000000}},  //   waam, ন্তে, اسیک_,
  { {0x60cd2349, 0x644f1072, 0xdce90089, 0x00000000}},  //   taam, szci, _pieļ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60cd01c2, 0x00000000, 0x00000000, 0x00000000}},  // [5a30] raam,   ,   ,
  { {0x60cd234a, 0x9f5201aa, 0x0cba0044, 0x00000000}},  //   saam, ntyè_, ুলোত,
  { {0x6d4b0016, 0x60cd234b, 0x2bc60067, 0x00000000}},  //   thga, paam, रीसा,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x777a002d, 0x00000000, 0x00000000, 0x00000000}},  //   kotx,   ,   ,
  { {0xeb99234c, 0x7ae70245, 0x6ef2000c, 0x00000000}},  //   шил_, сюдж, rðbó,
  { {0x68e90b10, 0xdb00008e, 0x00000000, 0x00000000}},  //   tged, _atmó,   ,
  { {0x5ede0044, 0x05240044, 0x00000000, 0x00000000}},  //   ন্দে, _পত্র_,   ,
  { {0x68e90016, 0x6d491b90, 0xfbe00309, 0x00000000}},  //   rged, _ilea, _नियम,
  { {0xf7710355, 0x68e90090, 0x777a0032, 0x00000000}},  //   باب_, sged, gotx,
  { {0xa2ba0309, 0x68e900d9, 0x00000000, 0x00000000}},  //   ्रस्, pged,   ,
  { {0xc32900b6, 0x2f0a0036, 0x2bc6007d, 0x00000000}},  //   _בו_, mógł_, रीवा,
  { {0x395f007f, 0x656d0022, 0x00000000, 0x00000000}},  //   mius_, _djah,   ,
  { {0x395f07bc, 0x394d0181, 0x6d42022b, 0x00000000}},  //   lius_, lhes_, zkoa,
  { {0xe29a02e9, 0x69dc05cb, 0x2be0006e, 0x00000000}},  //   рав_, _året, _निभा,
  { {0x395f234d, 0x656d0023, 0x00000000, 0x00000000}},  //   nius_, _gjah,   ,
  { {0xdb01008d, 0x00000000, 0x00000000, 0x00000000}},  // [5a40] _cilë,   ,   ,
  { {0x6d49049a, 0x6d5b1126, 0xe3b200a1, 0x00000000}},  //   _alea, _amua, _ٹرک_,
  { {0x395f010a, 0x6d490133, 0x10a6004d, 0x00000000}},  //   kius_, _blea, _минн,
  { {0x6d490038, 0x4c86013b, 0x395f0022, 0x00000000}},  //   _clea, олев, jius_,
  { {0xa01b234e, 0xdb0101aa, 0x6d42002d, 0x00000000}},  //   _szöv, _kilè, rkoa,
  { {0x6d42002d, 0x6d49234f, 0xdb01000a, 0x00000000}},  //   skoa, _elea, _jilè,
  { {0x8fa301c0, 0x6d491c7e, 0xc3330104, 0x00000000}},  //   _царе, _flea, ווג_,
  { {0x394d0016, 0x6d490051, 0x68400051, 0x00000000}},  //   ghes_, _glea, _nádú,
  { {0xdb02049a, 0xd7c40061, 0x870602dc, 0x00000000}},  //   spoñ, लींच, ояне,
  { {0x656d0093, 0x9abc01f3, 0x2d860288, 0x00000000}},  //   _sjah, _inċo, lloe_,
  { {0x395f01a3, 0xd0130044, 0xceb300b3, 0x00000000}},  //   bius_, সময়_, וית_,
  { {0x395f1be5, 0xe9b7026c, 0xd90e00e9, 0x00000000}},  //   cius_, _بچوں_, _شیخ_,
  { {0xd7ef0054, 0xb7180aa2, 0x00000000, 0x00000000}},  //   _لكن_, _голф_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x656d2350, 0xdb01000a, 0x00000000, 0x00000000}},  //   _tjah, _dilè,   ,
  { {0x61f52351, 0x656d0a6e, 0x00000000, 0x00000000}},  //   rtzl, _ujah,   ,
  { {0x657d0e06, 0x9055007e, 0x00000000, 0x00000000}},  // [5a50] mosh, чвац,   ,
  { {0xa29502f0, 0x657d0065, 0x6d490051, 0x00000000}},  //   _напі, losh, _slea,
  { {0x6d490038, 0x63ad0020, 0xa01b0010, 0x00000000}},  //   _plea, _huan, _gyön,
  { {0x63ad000b, 0x395f0129, 0xd5fb0049, 0x00000000}},  //   _kuan, xius_, שפאר,
  { {0x63ad2352, 0x395f0006, 0xdb0012dd, 0x00000000}},  //   _juan, vius_, _sumá,
  { {0x657d070d, 0x63ad0020, 0xdb010010, 0x00000000}},  //   hosh, _muan, _kilé,
  { {0x2bd7024c, 0x395f04bd, 0xeaf80054, 0x00000000}},  //   _ठिका, tius_, ترنت_,
  { {0x2139003b, 0x628501a3, 0x657d2353, 0x00000000}},  //   _josh_, _myho, josh,
  { {0x395f1b18, 0x657d0023, 0x21390f77, 0x00000000}},  //   rius_, dosh, _mosh_,
  { {0x395f010a, 0x67380166, 0x394d166d, 0x00000000}},  //   sius_, _covj, shes_,
  { {0x394d00f4, 0x657d0190, 0x395f007f, 0x00000000}},  //   phes_, fosh, pius_,
  { {0xa3d703d7, 0x63ad0085, 0x657d0023, 0x00000000}},  //   ाओं_, _buan, gosh,
  { {0x63ad0219, 0x9fd60055, 0x00000000, 0x00000000}},  //   _cuan, _সঙ্গ,   ,
  { {0x63ad01a3, 0x7bc90020, 0x6f15004a, 0x00000000}},  //   _duan, _mweu, _nazc,
  { {0x6285018e, 0x21390023, 0x3cff0161, 0x00000000}},  //   _cyho, _bosh_, _obuv_,
  { {0x55da007b, 0x25e0001c, 0x63ad229c, 0x00000000}},  //   _פֿונ, _किती_, _fuan,
  { {0x63ad04bd, 0x2139034a, 0xb4d80309, 0x00000000}},  // [5a60] _guan, _dosh_, ाणी_,
  { {0x4420006b, 0xdce90209, 0xa01b021e, 0x00000000}},  //   _iri_, _dječ, _työn,
  { {0x6285018e, 0x44200c8a, 0x76410544, 0x00000000}},  //   _gyho, _hri_, nyly,
  { {0x21390058, 0x44200059, 0x63ad0022, 0x00000000}},  //   _gosh_, _kri_, _yuan,
  { {0x60c42354, 0x7c26050f, 0x63ad0082, 0x00000000}},  //   mbim, _škrb, _xuan,
  { {0x60c4010a, 0x7bc9018e, 0x657d00e7, 0x00000000}},  //   lbim, _dweu, zosh,
  { {0x657d0020, 0x68fb005b, 0x60c4012d, 0x00000000}},  //   yosh, ffud, obim,
  { {0x4420000d, 0x67380056, 0x4ddb009b, 0x00000000}},  //   _ori_, _sovj, _לחלו,
  { {0xebe302a8, 0x67380243, 0x44201f66, 0x00000000}},  //   _потп, _povj, _nri_,
  { {0x4427001d, 0x63ad020c, 0x95d800ed, 0x00000000}},  //   _ăn_, _ruan, одот_,
  { {0x44202355, 0x657d000b, 0x63ad2356, 0x00000000}},  //   _ari_, tosh, _suan,
  { {0x63ad011f, 0x44201987, 0xe0df000a, 0x00000000}},  //   _puan, _bri_, _elòj_,
  { {0x44200e4b, 0x9f40008e, 0x4ad0006e, 0x00000000}},  //   _cri_, ntió_, _सजाव,
  { {0x44200016, 0xa3a401fc, 0xdce90243, 0x00000000}},  //   _dri_, ејск, _rječ,
  { {0x44200f80, 0xb909001d, 0x21392357, 0x00000000}},  //   _eri_, _nghề_, _posh_,
  { {0x44200030, 0x60f9008b, 0x63ad1d2a, 0x00000000}},  //   _fri_, ўная_, _tuan,
  { {0xf48502fd, 0x63a500e5, 0x628500b4, 0x00000000}},  // [5a70] _تاثی, _tihn, _wyho,
  { {0xdce91a84, 0xeeab16b6, 0x26ce0173, 0x00000000}},  //   _vječ, стак_, _jefo_,
  { {0x8cf5008b, 0x7c200190, 0x21390675, 0x00000000}},  //   дзец, _armr, _tosh_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfc460011, 0x1be90088, 0x6dac0035, 0x00000000}},  //   _đích_, ідки_, _aşad,
  { {0xdb09005a, 0x4ad700a1, 0x00000000, 0x00000000}},  //   _önün, ساتھ_,   ,
  { {0xa3b40164, 0x60cf2358, 0x6b4f0190, 0x00000000}},  //   _जून_, _kecm, _nøge,
  { {0x3a3a0039, 0x673c00f8, 0x00000000, 0x00000000}},  //   äppa_, örjn,   ,
  { {0x24c50055, 0x3eaa0045, 0x25ae01a2, 0x00000000}},  //   ্লাহ, _ygbt_, _aufl_,
  { {0x6b4f0018, 0xb4e6007d, 0x44201d5b, 0x00000000}},  //   _bøge, कल्प_, _rri_,
  { {0x442001a3, 0x26ce0173, 0x6ad30044, 0x00000000}},  //   _sri_, _defo_, _সাপো,
  { {0x44200cce, 0xb4d8001c, 0x637f013e, 0x00000000}},  //   _pri_, ाणे_, háně,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x79890016, 0x889a009b, 0x9f40009d, 0x00000000}},  //   llew, _ובני, prié_,
  { {0x03a30057, 0x26c51e2d, 0x798900e7, 0x00000000}},  //   тиро, mblo_, olew,
  { {0x61e10010, 0xa01b00b0, 0x00000000, 0x00000000}},  //   álla, _työl,   ,
  { {0x4420006a, 0x7d0b001c, 0x60c408c0, 0x00000000}},  // [5a80] _uri_, degs, rbim,
  { {0x25790010, 0x2fc00a5e, 0x00000000, 0x00000000}},  //   dély_, rpig_,   ,
  { {0xe29a00da, 0x25bc00f6, 0x00000000, 0x00000000}},  //   _фан_, _xtvl_,   ,
  { {0x25e003d7, 0x7d0b001c, 0xe8df0011, 0x00000000}},  //   _किसी_, gegs, _trộm_,
  { {0xdca3007c, 0x798900b4, 0x00000000, 0x00000000}},  //   ваци, dlew,   ,
  { {0x9f400211, 0x79890020, 0xe4570049, 0x00000000}},  //   rtió_, elew, וינט_,
  { {0x9f402359, 0x2be0007d, 0xdee3025f, 0x00000000}},  //   stió_, _निवा, _јоси,
  { {0xa8141364, 0xb81400ec, 0x5fb50061, 0x00000000}},  //   едиш, едиј, _अंमल,
  { {0x6b4f0018, 0x36d40920, 0x1b030044, 0x00000000}},  //   _søge, нопр, লয়ে_,
  { {0x4b260076, 0xeeeb001d, 0x7bc2235a, 0x00000000}},  //   _تعرف, _đừng_, mpou,
  { {0x7989235b, 0x7bc20173, 0x00000000, 0x00000000}},  //   blew, lpou,   ,
  { {0xc8660680, 0xc5f80089, 0x69d81652, 0x00000000}},  //   _отли, rtē_, msve,
  { {0x69d806a1, 0x24920036, 0x7bc20e6d, 0x00000000}},  //   lsve, _czym_, npou,
  { {0x69d8016c, 0x6b4f0190, 0x00000000, 0x00000000}},  //   osve, _tøge,   ,
  { {0x69d8037d, 0xd13b005e, 0xf1a70545, 0x00000000}},  //   nsve, оха_, дран,
  { {0x5ec80055, 0x69d8010f, 0x00000000, 0x00000000}},  //   _লাগে, isve,   ,
  { {0xa01b00b0, 0x60cf0089, 0x25a9010e, 0x00000000}},  // [5a90] _työm, _vecm, _iial_,
  { {0xa91d0059, 0x64400cba, 0x69d80056, 0x00000000}},  //   može, ämie, ksve,
  { {0xa91d004f, 0x69d800b5, 0x7d0b235c, 0x00000000}},  //   lože, jsve, tegs,
  { {0x69d8093b, 0x656f235d, 0x2be0006e, 0x00000000}},  //   dsve, nnch, _निशा,
  { {0x7bc4000d, 0x656f235e, 0x7d0b0007, 0x00000000}},  //   ţiun, inch, regs,
  { {0x98af0046, 0x2be00309, 0x69d81642, 0x00000000}},  //   _mogą_, _निरा, fsve,
  { {0x53380049, 0x798901d6, 0xbdc700a1, 0x00000000}},  //   ונגן_, tlew, _آگئے_,
  { {0x6e941523, 0x25a9098e, 0x9f4001e5, 0x00000000}},  //   _рису, _nial_, ltið_,
  { {0x7989235f, 0x2d9d0009, 0xa0e30089, 0x00000000}},  //   rlew, mmwe_, dēļā_,
  { {0x656f0181, 0xe7310025, 0x05d30164, 0x00000000}},  //   ench, اصة_, _दबदब,
  { {0x248904cb, 0x2b890027, 0x25a900fa, 0x00000000}},  //   _ayam_, júci_, _bial_,
  { {0x92c10055, 0xdb010285, 0x69c301a2, 0x00000000}},  //   ুলো_, _milí, mpne,
  { {0xf99200a3, 0x3f810065, 0xab5d0066, 0x00000000}},  //   _ערד_, kohu_, _awżi,
  { {0x212b0207, 0x883a00b3, 0x656f0048, 0x00000000}},  //   _anch_, _מתנו, anch,
  { {0x27ed002d, 0x25a90048, 0x00000000, 0x00000000}},  //   luen_, _fial_,   ,
  { {0xa91d2360, 0x290d0035, 0xa01b0010, 0x00000000}},  //   ložb, neea_, _gyök,
  { {0xd007017f, 0x27ed2361, 0x69c30061, 0x00000000}},  // [5aa0] нете_, nuen_, hpne,
  { {0xe1fa0057, 0x65662362, 0xa01b00b0, 0x00000000}},  //   _его_, likh, _myöh,
  { {0xb6410009, 0x64461ec2, 0xdb010919, 0x00000000}},  //   _ｍｓ_, lyki, _cilí,
  { {0x7bc201d6, 0x27ed002d, 0xa2ba0164, 0x00000000}},  //   tpou, kuen_, ्रक्,
  { {0x61ee000c, 0xdb012363, 0x60d600e0, 0x00000000}},  //   lubl, _eilí, maym,
  { {0x69d8010f, 0x27ed002d, 0xdb012364, 0x00000000}},  //   tsve, duen_, _filí,
  { {0xfce60175, 0x7bc2115e, 0x61ee013f, 0x00000000}},  //   _пово, spou, nubl,
  { {0xeeeb001d, 0x69d82315, 0x64460006, 0x00000000}},  //   _đứng_, rsve, kyki,
  { {0x27ed029a, 0x69d8030e, 0x7980002b, 0x00000000}},  //   guen_, ssve, romw,
  { {0xd6da0242, 0x64462365, 0xa91d089f, 0x00000000}},  //   чти_, dyki, vože,
  { {0x79801725, 0x24892366, 0xa3d30309, 0x00000000}},  //   pomw, _syam_, हीन_,
  { {0xb4eb03d7, 0x656f0c6a, 0xf992004b, 0x00000000}},  //   मले_, unch, _صبا_,
  { {0x25a90efe, 0xd4040581, 0x9f40000c, 0x00000000}},  //   _vial_, ляри, ytið_,
  { {0x61e10010, 0x00000000, 0x00000000, 0x00000000}},  //   állo,   ,   ,
  { {0x61ee0295, 0xa01b00b0, 0x41e40245, 0x00000000}},  //   gubl, _työk, літа,
  { {0xfc460011, 0x8ecd0044, 0xa91d11af, 0x00000000}},  //   _đính_, _লাইগ, pože,
  { {0x7a13005f, 0x752d2367, 0x9f40000c, 0x00000000}},  // [5ab0] _vətə, _inaz, ttið_,
  { {0x20e10011, 0xdb0100c4, 0x6d910056, 0x00000000}},  //   ỗi_, _milã, gåan,
  { {0x3f810065, 0x27ed002d, 0x9f40000c, 0x00000000}},  //   rohu_, zuen_, rtið_,
  { {0x9f40000c, 0x3f812368, 0x6dac1a6f, 0x00000000}},  //   stið_, sohu_, _ağas,
  { {0x752d0020, 0x9f40000c, 0x27ed0032, 0x00000000}},  //   _mnaz, ptið_, xuen_,
  { {0x7bc00061, 0x8c4200da, 0x6d4a0023, 0x00000000}},  //   _dtmu, реше, ëfar,
  { {0x7ceb2369, 0x64460036, 0xdb010048, 0x00000000}},  //   görü, zyki, _uilí,
  { {0x27ed022b, 0xdb080173, 0x00000000, 0x00000000}},  //   tuen_, _lidè,   ,
  { {0x5b15137c, 0x69c3121e, 0xa91d0059, 0x00000000}},  //   _имат, spne, tožb,
  { {0x7d1b0109, 0x7c8416b6, 0x752d0020, 0x00000000}},  //   _haus, _сусе, _anaz,
  { {0x7d1b236a, 0x6b83023a, 0x27ed0032, 0x00000000}},  //   _kaus, mong, suen_,
  { {0x7d1b0006, 0x6446236b, 0xd46a00ed, 0x00000000}},  //   _jaus, tyki, диме_,
  { {0x27ed16f9, 0x7d1b0706, 0x65660fc1, 0x00000000}},  //   quen_, _maus, rikh,
  { {0x7d1b00cd, 0x6566032e, 0x6b830145, 0x00000000}},  //   _laus, sikh, nong,
  { {0x6446236c, 0xd6ce0025, 0x6b8300e7, 0x00000000}},  //   syki, _بقى_, iong,
  { {0x6b83236d, 0x00000000, 0x00000000, 0x00000000}},  //   hong,   ,   ,
  { {0xa0670a94, 0x6b830127, 0xef1a007c, 0x00000000}},  // [5ac0] вата_, kong, мма_,
  { {0x6b830010, 0x03a6013b, 0xdb08000a, 0x00000000}},  //   jong, _шипо, _gidè,
  { {0x7d1b236e, 0xf2d30104, 0x6b83236f, 0x00000000}},  //   _baus, _דעת_, dong,
  { {0xfce6004c, 0xdb000637, 0x61460364, 0x00000000}},  //   тодо, _humø, _рема,
  { {0x7d1b19be, 0x3f980133, 0x6d98004a, 0x00000000}},  //   _daus, _thru_, víad,
  { {0x6b830020, 0x7ceb014a, 0xef1f00b4, 0x00000000}},  //   gong, törü, ążce_,
  { {0x6f1c0048, 0x2b890142, 0xdce2012d, 0x00000000}},  //   _iarc, júcu_, lioč,
  { {0x6f1c165e, 0x7d1b0006, 0xdce20091, 0x00000000}},  //   _harc, _gaus, dnoć,
  { {0x6d400051, 0x6f1c108d, 0x3d170061, 0x00000000}},  //   _ioma, _karc, _नसते_,
  { {0x6d400e0a, 0x7d1b0ce4, 0x98af0036, 0x00000000}},  //   _homa, _zaus, _mogę_,
  { {0xd00b0055, 0xa4d501e1, 0x00000000, 0x00000000}},  //   রিয়_, лоні,   ,
  { {0x7d022370, 0x6d400089, 0xdb080173, 0x00000000}},  //   nfos, _joma, _sidè,
  { {0x6d402371, 0x1836023c, 0x7c222372, 0x00000000}},  //   _moma, _جراح, nvor,
  { {0x52bf0201, 0x6d4000b0, 0x36d416c4, 0x00000000}},  //   ्रेस, _loma, _сокр,
  { {0xa91d0f3a, 0x96f701f7, 0x7c2201e5, 0x00000000}},  //   loža, _شعور_, hvor,
  { {0x6d400089, 0x6b8300bb, 0xdb010161, 0x00000000}},  //   _noma, zong, _milá,
  { {0x6f1c04bd, 0x7d1b010f, 0x6b830ea6, 0x00000000}},  // [5ad0] _barc, _raus, yong,
  { {0x6f1c1f5a, 0x7d1b030b, 0xdb082373, 0x00000000}},  //   _carc, _saus, _fidé,
  { {0x3ea70073, 0x6f1c0142, 0x6b832374, 0x00000000}},  //   änt_, _darc, vong,
  { {0x6d4004bd, 0x68e2008d, 0x6b830390, 0x00000000}},  //   _coma, _ndod, wong,
  { {0x6f1c0016, 0x6b832375, 0x7c222376, 0x00000000}},  //   _farc, tong, gvor,
  { {0x6f1c0779, 0x68e200e0, 0x7d1b0048, 0x00000000}},  //   _garc, _adod, _waus,
  { {0x7d1b00f2, 0xa3d3001c, 0x6d4001aa, 0x00000000}},  //   _taus, हीत_, _foma,
  { {0x6d401cfa, 0x31692377, 0xe8f91c31, 0x00000000}},  //   _goma, niaz_, хли_,
  { {0x6b832378, 0x5c75025f, 0x68e2005b, 0x00000000}},  //   pong, _слат, _ddod,
  { {0xdce20521, 0x6d4000b5, 0x6f1c00f6, 0x00000000}},  //   tnoć, _zoma, _xarc,
  { {0x8c42011f, 0x69c110e9, 0x6d401fb8, 0x00000000}},  //   _öğre, _utle, _yoma,
  { {0x20190052, 0x6b5400f6, 0x673a0023, 0x00000000}},  //   _ossi_, _vàge, ajtj,
  { {0x2d8f002a, 0x5ede0044, 0x6d98004a, 0x00000000}},  //   ilge_, ন্টে, líac,
  { {0x291d2379, 0x291f002d, 0x6d5a0006, 0x00000000}},  //   _hawa_, ldua_, _įtam,
  { {0x20190766, 0xc0e6237a, 0x291d00b4, 0x00000000}},  //   _assi_, ловк, _kawa_,
  { {0xdb08237b, 0x291f2128, 0x291d0390, 0x00000000}},  //   _vidé, ndua_, _jawa_,
  { {0x6d40000d, 0x27ff01a3, 0xe0df237c, 0x00000000}},  // [5ae0] _roma, ntun_, _alòs_,
  { {0x6d4000e4, 0x6b4f0018, 0xdfcf05f3, 0x00000000}},  //   _soma, _søgn, سيم_,
  { {0x20190207, 0x6f1c237d, 0x63b60011, 0x00000000}},  //   _essi_, _varc, _huyn,
  { {0x7c2204a3, 0x6f1c0cb4, 0x291d011c, 0x00000000}},  //   tvor, _warc, _nawa_,
  { {0x0b8a0794, 0x7d02027b, 0x6f1c120c, 0x00000000}},  //   нски_, rfos, _tarc,
  { {0x7c220e42, 0x6d400339, 0x256b01aa, 0x00000000}},  //   rvor, _woma, _kòlè_,
  { {0x2be002fb, 0x7c22010f, 0x274100b9, 0x00000000}},  //   _निका, svor, _méně_,
  { {0xdb010047, 0xdca6003b, 0x2120237e, 0x00000000}},  //   _vilá, _баби, ndih_,
  { {0xcaf60076, 0x2000000d, 0x291d0020, 0x00000000}},  //   _مساب, ntii_, _dawa_,
  { {0x3169002d, 0xa01b00b0, 0xb4bf0061, 0x00000000}},  //   ziaz_, _työv, ेर्_,
  { {0xd5b70057, 0xa37b0181, 0x6440021e, 0x00000000}},  //   лся_, nsõe, ämin,
  { {0xa91d0268, 0x291d011c, 0x63b6237f, 0x00000000}},  //   ložn, _gawa_, _buyn,
  { {0x765a2380, 0x00000000, 0x00000000, 0x00000000}},  //   szty,   ,   ,
  { {0x77f700b6, 0x6b4f0030, 0xa01b00b0, 0x00000000}},  //   _עמוד_, _nøgl, _myöt,
  { {0x31c401be, 0xf3ff00c4, 0x6595007c, 0x00000000}},  //   йств, stã_, _каку,
  { {0x3869050f, 0x20190093, 0x9f5200b0, 0x00000000}},  //   _žari_, _pssi_, htyä_,
  { {0xc05b01fb, 0x3169002d, 0xceeb0f8b, 0x00000000}},  // [5af0] хів_, riaz_, فران_,
  { {0x7a0a005f, 0x31690032, 0x00000000, 0x00000000}},  //   _mətb, siaz_,   ,
  { {0xc33200bd, 0xc20804e1, 0x442901ca, 0x00000000}},  //   _ווי_, _یقین_, _hra_,
  { {0x442900c4, 0xdb2600a6, 0xa37b006c, 0x00000000}},  //   _kra_, یونی, ssõd,
  { {0x2000001a, 0x60cd0020, 0x291d2381, 0x00000000}},  //   ctii_, mbam, _rawa_,
  { {0x291d000b, 0x60cd0006, 0x2fc900e0, 0x00000000}},  //   _sawa_, lbam, mpag_,
  { {0xba770014, 0x442911c2, 0x394d06aa, 0x00000000}},  //   داشت, _lra_, tkes_,
  { {0x4429139c, 0x27ff014a, 0x6d9800d6, 0x00000000}},  //   _ora_, ttun_, ríac,
  { {0x394d014a, 0x44290089, 0x291f01a3, 0x00000000}},  //   rkes_, _nra_, rdua_,
  { {0x753d0046, 0x27ff023a, 0x394d0030, 0x00000000}},  //   ejsz, rtun_, skes_,
  { {0x44292382, 0x27ff2383, 0x291d2384, 0x00000000}},  //   _ara_, stun_, _tawa_,
  { {0x44290073, 0x6e21029d, 0x27ff0035, 0x00000000}},  //   _bra_, _álbu, ptun_,
  { {0x99840054, 0x7d090065, 0xa01b00b0, 0x00000000}},  //   _النو, _mbes, _myös,
  { {0x3319008b, 0x44291aef, 0x27ed0065, 0x00000000}},  //   ліся_, _dra_, mren_,
  { {0x29d3000d, 0xc5d501fb, 0x82a60088, 0x00000000}},  //   nţa_, _тіль, равж,
  { {0x44292385, 0x92d60055, 0x256b01aa, 0x00000000}},  //   _fra_, হলে_, _vòlè_,
  { {0x44290036, 0x657d0047, 0x1f66007e, 0x00000000}},  // [5b00] _gra_, érhe, акам,
  { {0x20002386, 0x7d09002d, 0x862200a1, 0x00000000}},  //   rtii_, _abes, _اکیل,
  { {0x27ed001f, 0x20002387, 0xa01b00b0, 0x00000000}},  //   hren_, stii_, _syöt,
  { {0x44290736, 0x0c260057, 0xa37b0181, 0x00000000}},  //   _yra_, имен, rsõe,
  { {0xa37b0181, 0x9f5200b0, 0x27ed15a9, 0x00000000}},  //   ssõe, ttyä_, jren_,
  { {0xe9e601be, 0x27ed05a6, 0xd90d00a1, 0x00000000}},  //   ацио, dren_, ہیم_,
  { {0x27ed001f, 0x12e90049, 0xa91d0059, 0x00000000}},  //   eren_, אַפּ, rožn,
  { {0xa01b00b0, 0x7c29147f, 0x7d0900ea, 0x00000000}},  //   _työt, _frer, _gbes,
  { {0x7afa001c, 0x27ed0039, 0xdce90182, 0x00000000}},  //   _tctt, gren_, _sjeć,
  { {0x44292388, 0x9abc0066, 0x957d00b4, 0x00000000}},  //   _rra_, _baċe, zsąd,
  { {0xe8fa0822, 0x27ed15cd, 0x442900d6, 0x00000000}},  //   _але_, aren_, _sra_,
  { {0x44292389, 0x99750057, 0x27ed0b32, 0x00000000}},  //   _pra_, _лучш, bren_,
  { {0x75c10089, 0x53470605, 0x27ed0288, 0x00000000}},  //   _rēze, ахва, cren_,
  { {0x4429238a, 0x389b00a3, 0x00000000, 0x00000000}},  //   _vra_, _סיגנ,   ,
  { {0xe167012b, 0x6dac014a, 0xdcfb04eb, 0x00000000}},  //   ађан, _aşam, _ukuć,
  { {0x4429238b, 0x76570104, 0x74f902b3, 0x00000000}},  //   _tra_, _כבוד_, _сеир_,
  { {0x60cd0006, 0x4429238c, 0x909908f3, 0x00000000}},  // [5b10] rbam, _ura_, уват_,
  { {0x7d090796, 0xa49b0173, 0xbf02013d, 0x00000000}},  //   _sbes, nfòm, र्लभ_,
  { {0xa3d3001c, 0x2d7800ca, 0x27ed0065, 0x00000000}},  //   हीर_, rčen_, zren_,
  { {0x27ed0016, 0x00000000, 0x00000000, 0x00000000}},  //   yren_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d59238d, 0x27ed0b79, 0xab6403e8, 0x00000000}},  //   shwa, vren_, овіл,
  { {0xa01b0ae4, 0x27ed01f3, 0x00000000, 0x00000000}},  //   _työs, wren_,   ,
  { {0x27ed0ab3, 0x991501fb, 0x7d090030, 0x00000000}},  //   tren_, ські, _ubes,
  { {0x27ed095d, 0xccf2009b, 0x2d8d025e, 0x00000000}},  //   uren_, _מכן_, _ikee_,
  { {0x27ed022b, 0x9abc0066, 0x6d5a007f, 0x00000000}},  //   rren_, _paċe, _įtai,
  { {0xaa950025, 0xe81c013d, 0x27ed238e, 0x00000000}},  //   _الاث, _बैठा_, sren_,
  { {0x05560242, 0x27ed0023, 0x61f5006b, 0x00000000}},  //   стоя, pren_, duzl,
  { {0x6c79007b, 0xa3d301f5, 0x00000000, 0x00000000}},  //   ראָפ, हील_,   ,
  { {0x2be00061, 0x1c1e0061, 0x61f5006b, 0x00000000}},  //   _निघा, _मैफल_, fuzl,
  { {0x450d0044, 0x1546004d, 0x661c0190, 0x00000000}},  //   ষয়ক_, _гейм, ærkt,
  { {0xdb0810af, 0x31bc0344, 0x216700e2, 0x00000000}},  //   _ridí, _víz_, биси_,
  { {0x41270265, 0x6143238f, 0x7d010010, 0x00000000}},  // [5b20] щото_, чета, záró,
  { {0xa01b021e, 0x798901bb, 0x31bc0010, 0x00000000}},  //   _pyör, hoew, _tíz_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d9f228b, 0xd5fa0049, 0xb5fa0049, 0x00000000}},  //   _chue_, טפער, טלעכ,
  { {0xdd8f0439, 0x9f4000b0, 0x1ab40e1b, 0x00000000}},  //   روه_, triä_, обля,
  { {0xdfcf0379, 0xa01b00b0, 0x00000000, 0x00000000}},  //   _سيف_, _työr,   ,
  { {0x0f5701ce, 0x00000000, 0x00000000, 0x00000000}},  //   _פילם_,   ,   ,
  { {0xa517001c, 0xed570517, 0xa3d801f5, 0x00000000}},  //   _तसेच_, _лос_, ाठा_,
  { {0xeafa0025, 0x64a70164, 0x37aa00ed, 0x00000000}},  //   _مرات_, _गणेश, лтон_,
  { {0x501b009b, 0x25a02390, 0x9f49000c, 0x00000000}},  //   נויו, _ahil_, ntað_,
  { {0x248000d2, 0x15150930, 0x00000000, 0x00000000}},  //   _axim_, одня,   ,
  { {0x9f4706b8, 0x61f51d83, 0x00000000, 0x00000000}},  //   čné_, vuzl,   ,
  { {0x5896035b, 0xa3d301f5, 0x25a00058, 0x00000000}},  //   _اجاز, हीं_, _dhil_,
  { {0x96ba2391, 0x661c0030, 0x9f4000c4, 0x00000000}},  //   _суду_, ærks, ssiê_,
  { {0x26de06bd, 0x39461db7, 0x6d98008e, 0x00000000}},  //   mato_, _koos_, vían,
  { {0x26de0198, 0x7a0a006b, 0x394601c3, 0x00000000}},  //   lato_, _xəta, _joos_,
  { {0x656f1425, 0x9ed909da, 0x39460cba, 0x00000000}},  // [5b30] mich, имат_, _moos_,
  { {0x656f08ba, 0x26de0198, 0x3946095c, 0x00000000}},  //   lich, nato_, _loos_,
  { {0x644f007f, 0x26de0026, 0x00000000, 0x00000000}},  //   lyci, iato_,   ,
  { {0x7ae80f60, 0x656f0207, 0x9f490051, 0x00000000}},  //   _addt, nich, mraí_,
  { {0x26de0020, 0x69c801c5, 0x00000000, 0x00000000}},  //   kato_, _atde,   ,
  { {0x656f001f, 0xdea400a6, 0x26de013e, 0x00000000}},  //   hich, _کیمی, jato_,
  { {0x9f49002a, 0x2d9f0011, 0x656f0e74, 0x00000000}},  //   nraí_, _thue_, kich,
  { {0x656f2392, 0x47c500d7, 0x39460b3d, 0x00000000}},  //   jich, обив, _coos_,
  { {0x5fe203d7, 0xf8ae007a, 0xc8b300a1, 0x00000000}},  //   _पिछल, نکه_, _ہلاک,
  { {0x26de0198, 0x060900ed, 0x7b770070, 0x00000000}},  //   gato_, анок_, _اطرا,
  { {0xb8ff0055, 0x656f2393, 0xe57a005e, 0x00000000}},  //   _তা_, fich, изо_,
  { {0x656f0207, 0x9f490051, 0x394600d9, 0x00000000}},  //   gich, draí_, _goos_,
  { {0x66e5012b, 0x26de0207, 0x00000000, 0x00000000}},  //   _дола, bato_,   ,
  { {0x26de0198, 0x7a0a005f, 0x16390025, 0x00000000}},  //   cato_, _mətn, _نسبة_,
  { {0x9f49002a, 0x656f2394, 0xe77800a1, 0x00000000}},  //   graí_, bich, _دلوں_,
  { {0x68fb01b9, 0x644f0036, 0x67232395, 0x00000000}},  //   ngud, byci, _hanj,
  { {0x0fda007c, 0x9f492396, 0x00000000, 0x00000000}},  // [5b40] рьбы_, araí_,   ,
  { {0x44201c56, 0xb358026c, 0x67232397, 0x00000000}},  //   _isi_, _ایسا_, _janj,
  { {0x67230263, 0x614601f9, 0x44200145, 0x00000000}},  //   _manj, _дена, _hsi_,
  { {0x6723020c, 0x629e01d9, 0xa01b00b0, 0x00000000}},  //   _lanj, _izpo, _työp,
  { {0x60c4037e, 0x75241f2e, 0x39460168, 0x00000000}},  //   mcim, _maiz, _roos_,
  { {0x39461273, 0x656f2398, 0x67230059, 0x00000000}},  //   _soos_, zich, _nanj,
  { {0x26de0198, 0x2d781a2d, 0x644f0036, 0x00000000}},  //   vato_, nček_, zyci,
  { {0x75242399, 0xdb08029d, 0x60c40091, 0x00000000}},  //   _naiz, _didá, ncim,
  { {0x6723023a, 0x656f01aa, 0x44201a9b, 0x00000000}},  //   _banj, vich, _nsi_,
  { {0x656f05c6, 0x67231aa3, 0x1037009b, 0x00000000}},  //   wich, _canj, קטים_,
  { {0x26de0198, 0x6723239a, 0x656f1f55, 0x00000000}},  //   rato_, _danj, tich,
  { {0x26de0207, 0xe7f30061, 0x6d420035, 0x00000000}},  //   sato_, _आमचा_, njoa,
  { {0x656f15a6, 0x26de1c5e, 0x6d98008e, 0x00000000}},  //   rich, pato_, víal,
  { {0x656f239b, 0x672304cb, 0x60c400c4, 0x00000000}},  //   sich, _ganj, ecim,
  { {0x44200dec, 0x75240b1e, 0x9f400051, 0x00000000}},  //   _esi_, _faiz, briú_,
  { {0x9f49002a, 0x67230059, 0x7524002d, 0x00000000}},  //   rraí_, _zanj, _gaiz,
  { {0x67230009, 0x656d011c, 0x26dc016c, 0x00000000}},  // [5b50] _yanj, _imah, _kevo_,
  { {0x7524022b, 0x68e0003f, 0x3dd80016, 0x00000000}},  //   _zaiz, hamd, _bwrw_,
  { {0x7bc9239c, 0xe135007c, 0x777a0032, 0x00000000}},  //   _steu, _енны, intx,
  { {0x26dc239d, 0x6d980f08, 0x00000000, 0x00000000}},  //   _levo_, bíam,   ,
  { {0x9f40008e, 0x44200009, 0x7a0a006b, 0x00000000}},  //   guió_, _xsi_, _qətn,
  { {0x8b22022a, 0x3dd8005b, 0x4fd6009b, 0x00000000}},  //   едше, _fwrw_, _מושב_,
  { {0xa91d0161, 0x656d0275, 0x7de00047, 0x00000000}},  //   loži, _omah, _vásá,
  { {0x67230e00, 0x627c0476, 0x777a002d, 0x00000000}},  //   _sanj, ינונ, entx,
  { {0x60dd239e, 0x67232375, 0x7bc90020, 0x00000000}},  //   _mesm, _panj, _uteu,
  { {0x656d1dc0, 0x442000ca, 0x75241126, 0x00000000}},  //   _amah, _rsi_, _saiz,
  { {0x26dc239f, 0x672323a0, 0x4420156f, 0x00000000}},  //   _devo_, _vanj, _ssi_,
  { {0x60dd0161, 0x4420016e, 0x2d781cfb, 0x00000000}},  //   _nesm, _psi_, vček_,
  { {0x7524010a, 0x60c40091, 0x395f0039, 0x00000000}},  //   _vaiz, vcim, mhus_,
  { {0x442001d9, 0x395f07c4, 0x6d980325, 0x00000000}},  //   _vsi_, lhus_, víam,
  { {0x60dd037e, 0x75240089, 0xe29a0088, 0x00000000}},  //   _besm, _taiz, сав_,
  { {0x4420002b, 0x2167007c, 0x27e601aa, 0x00000000}},  //   _tsi_, писи_, _yvon_,
  { {0x60dd1e8f, 0x55770049, 0x442004b4, 0x00000000}},  // [5b60] _desm, _מעקן_, _usi_,
  { {0x60c40181, 0xc2ea025a, 0x60dd0004, 0x00000000}},  //   scim, _اعظم_, _eesm,
  { {0x395f0d32, 0x60c40091, 0x6d420009, 0x00000000}},  //   khus_, pcim, tjoa,
  { {0x60dd00c7, 0x6d5b0051, 0xeeeb0011, 0x00000000}},  //   _gesm, _clua, _đụng_,
  { {0x6d4200b0, 0x395f02e7, 0x6d490abb, 0x00000000}},  //   rjoa, dhus_, _doea,
  { {0x6d5b006c, 0x6f0e00f6, 0xa09b00a3, 0x00000000}},  //   _elua, _ubbc, _ליכט,
  { {0x26dc0093, 0x68e0014a, 0x6d5b0048, 0x00000000}},  //   _revo_, tamd, _flua,
  { {0x6d5b002a, 0x6d490066, 0xd91a0088, 0x00000000}},  //   _glua, _goea, ськ_,
  { {0x68e0006a, 0x7c200253, 0xf803007e, 0x00000000}},  //   ramd, _usmr, нчэн,
  { {0x68e023a1, 0x00000000, 0x00000000, 0x00000000}},  //   samd,   ,   ,
  { {0x26dc004a, 0xd6d7007c, 0xe7e80061, 0x00000000}},  //   _vevo_, чты_, _टटका_,
  { {0x395f005b, 0xd5b7007c, 0xc7c6007c, 0x00000000}},  //   chus_, ясь_, _ески,
  { {0x60dd05fb, 0x1b1f0055, 0x5454007e, 0x00000000}},  //   _resm, পারে_, евят,
  { {0xda20001c, 0x7c2d006b, 0x60dd00ca, 0x00000000}},  //   _मनात_, çirə, _sesm,
  { {0x60dd23a2, 0xa1950088, 0x5693007e, 0x00000000}},  //   _pesm, давч, _пашт,
  { {0x9f4713c7, 0xf67b009b, 0x6b4f0056, 0x00000000}},  //   ční_, _לאומ, _høgt,
  { {0x60dd0161, 0x00000000, 0x00000000, 0x00000000}},  // [5b70] _vesm,   ,   ,
  { {0x6d5b23a3, 0xa91d1238, 0x00000000, 0x00000000}},  //   _slua, roži,   ,
  { {0xe0d000a1, 0x7a0a006b, 0x6d5a0006, 0x00000000}},  //   ئزہ_, _qətl, _įtar,
  { {0x657d0292, 0xcc990745, 0xd01000a1, 0x00000000}},  //   nnsh, овец_, خلے_,
  { {0x45270044, 0x69da002b, 0x7d191459, 0x00000000}},  //   যাপক_, _awte, rews,
  { {0x20090006, 0x657d01f3, 0x6d9100ea, 0x00000000}},  //   mtai_, hnsh, tåas,
  { {0x395f0bd8, 0xf4130044, 0x20090006, 0x00000000}},  //   thus_, িটির_, ltai_,
  { {0x17c90589, 0x2129020c, 0xdce90059, 0x00000000}},  //   огии_, ndah_, _kmeč,
  { {0x395f0030, 0xf53f23a4, 0x98bd0036, 0x00000000}},  //   rhus_, rmål_, _nową_,
  { {0x2d8f0059, 0x20090006, 0x21290093, 0x00000000}},  //   loge_, itai_, hdah_,
  { {0x7ae3191c, 0x395f00ea, 0xdb030048, 0x00000000}},  //   mant, phus_, nmní,
  { {0x2009010a, 0x61f5016c, 0x2d8f089f, 0x00000000}},  //   ktai_, drzl, noge_,
  { {0x26c7049a, 0x21290145, 0xc9740647, 0x00000000}},  //   _tfno_, ddah_, _ثالث,
  { {0x7ae323a5, 0x657d23a6, 0x629700f8, 0x00000000}},  //   nant, ansh, _byxo,
  { {0xa2b30061, 0xdb010399, 0x6dbe0027, 0x00000000}},  //   _आणण्, _chlé, _vďak,
  { {0x7ae30127, 0x2d1c0061, 0x63bf0066, 0x00000000}},  //   hant, _नसेल_, _fuqn,
  { {0x7ae323a7, 0x6285038e, 0xd007003b, 0x00000000}},  // [5b80] kant, _exho, мете_,
  { {0x7ae3010a, 0xef17007c, 0x3ced00e5, 0x00000000}},  //   jant, мму_, _adev_,
  { {0x7ae30181, 0x44320428, 0xdb010048, 0x00000000}},  //   dant, _hry_, _ghlé,
  { {0x44320343, 0x2d8f037f, 0x61fc005d, 0x00000000}},  //   _kry_, goge_, murl,
  { {0x6c1a06dd, 0x7ae323a8, 0x9abc002b, 0x00000000}},  //   تتاح_, fant, _faċl,
  { {0xd04f006b, 0x00000000, 0x00000000, 0x00000000}},  //   _necə,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbea3008b, 0x2d8f008e, 0x6b540129, 0x00000000}},  //   _раск, coge_, _màgi,
  { {0x7ae31577, 0xdb0800b0, 0x79a3005e, 0x00000000}},  //   bant, _pidä, ърше,
  { {0xddc9001a, 0x61fc002d, 0x212900ca, 0x00000000}},  //   _înţe, kurl, zdah_,
  { {0x7bc00058, 0x443223a9, 0xdceb0089, 0x00000000}},  //   _humu, _ary_, ligā,
  { {0x7bc01bc6, 0x61f50107, 0x443200f8, 0x00000000}},  //   _kumu, vrzl, _bry_,
  { {0x7bc00020, 0x21290107, 0xdb0123aa, 0x00000000}},  //   _jumu, vdah_, _shlé,
  { {0x289b00b6, 0x7bc00058, 0xd04f006b, 0x00000000}},  //   _וידא, _mumu, _gecə,
  { {0x7bc00760, 0xa2940088, 0xdce90e83, 0x00000000}},  //   _lumu, варі, _smeč,
  { {0x7ae323ab, 0x20090232, 0x443202f1, 0x00000000}},  //   zant, ttai_, _fry_,
  { {0x44320046, 0x7ae3023a, 0x7bc0001e, 0x00000000}},  // [5b90] _gry_, yant, _numu,
  { {0x7ae30fdb, 0x200923ac, 0xdce901ed, 0x00000000}},  //   xant, rtai_, _rjeđ,
  { {0x2009010a, 0x8af7006b, 0xa2b00061, 0x00000000}},  //   stai_, şəki, ंधण्,
  { {0xe5100011, 0x7bc0011c, 0x20090006, 0x00000000}},  //   _lặng_, _bumu, ptai_,
  { {0x7ae31596, 0xa3d30061, 0x515a00a0, 0x00000000}},  //   tant, हीच_, _זכרו,
  { {0xe5100011, 0xfaa501e0, 0x7bc0011c, 0x00000000}},  //   _nặng_, нало, _dumu,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd2b8019b, 0xa49b01aa, 0x7bc00035, 0x00000000}},  //   ולות_, nfòs, _fumu,
  { {0x7bc0011c, 0x6d590969, 0x00000000, 0x00000000}},  //   _gumu, mkwa,   ,
  { {0xd7090057, 0x6d590082, 0x399a0065, 0x00000000}},  //   чное_, lkwa, hësh_,
  { {0xcf9200b3, 0x6dac005a, 0x7ae10011, 0x00000000}},  //   רטי_, _işar, _ielt,
  { {0x6d59054e, 0x7bc023ad, 0x443223ae, 0x00000000}},  //   nkwa, _yumu, _pry_,
  { {0x7ae10ff8, 0x69c1170e, 0x44320045, 0x00000000}},  //   _kelt, _hule, _qry_,
  { {0x69c106d0, 0x61fc00eb, 0x6b5404bd, 0x00000000}},  //   _kule, turl, _pàgi,
  { {0x69c101e3, 0xf6790049, 0xa59610f3, 0x00000000}},  //   _jule, _מאַמ, _прищ,
  { {0x64400bac, 0x44320838, 0x69c102c0, 0x00000000}},  //   ämis, _try_, _mule,
  { {0x69c123af, 0x61fc014a, 0x320a23b0, 0x00000000}},  // [5ba0] _lule, surl, stby_,
  { {0x6d590116, 0xdceb0089, 0x7ae10810, 0x00000000}},  //   ekwa, vigā, _nelt,
  { {0x7bc0006a, 0x17560049, 0x69c10006, 0x00000000}},  //   _sumu, עסער_, _nule,
  { {0x9f4706b8, 0x7bc0006a, 0xedd30014, 0x00000000}},  //   čná_, _pumu, ايند,
  { {0xdca300d7, 0x7ae115cd, 0x69c1202d, 0x00000000}},  //   гаци, _belt, _aule,
  { {0x69c1065c, 0xbb43034b, 0x7ae1191c, 0x00000000}},  //   _bule, лечк, _celt,
  { {0x7ae100eb, 0x69c1001a, 0x399a0065, 0x00000000}},  //   _delt, _cule, lësi_,
  { {0x7bc0006a, 0xd90e00a6, 0x69c123b1, 0x00000000}},  //   _tumu, صیت_, _dule,
  { {0x7ae10047, 0x7c240279, 0x69c10065, 0x00000000}},  //   _felt, çird, _eule,
  { {0x7c2201d0, 0x7a0a006b, 0x999c007f, 0x00000000}},  //   mwor, _ləti, tyvų_,
  { {0x69c10193, 0xa4d50088, 0x399a0023, 0x00000000}},  //   _gule, коні, hësi_,
  { {0x7a0a005f, 0x7d02018e, 0x7ae123b2, 0x00000000}},  //   _nəti, ngos, _zelt,
  { {0xf4840954, 0xe510001d, 0x69c1010f, 0x00000000}},  //   гурн, _tặng_, _zule,
  { {0xdbc70004, 0xb4bb02fd, 0x69c10258, 0x00000000}},  //   _tööt, _کاغذ_, _yule,
  { {0xd056005f, 0x399a0065, 0x225801dc, 0x00000000}},  //   mayə, tësh_, _čeká_,
  { {0xd056006b, 0x00000000, 0x00000000, 0x00000000}},  //   layə,   ,   ,
  { {0x442f0359, 0x7d020036, 0x399a0065, 0x00000000}},  // [5bb0] _ég_, dgos, rësh_,
  { {0xd056005f, 0x2d840243, 0x399a0023, 0x00000000}},  //   nayə, _ajme_, sësh_,
  { {0x7c2201c3, 0xf7730049, 0x399a0023, 0x00000000}},  //   ewor, נקע_, pësh_,
  { {0x7ae123b3, 0x7a0a005f, 0x69c100ab, 0x00000000}},  //   _selt, _gəti, _rule,
  { {0x6d5900c7, 0x69c1006c, 0xd056006b, 0x00000000}},  //   rkwa, _sule, kayə,
  { {0x6f1e0779, 0x69c1013f, 0x20190022, 0x00000000}},  //   cepc, _pule, _ipsi_,
  { {0x7ae108d5, 0xda620077, 0xc33400b3, 0x00000000}},  //   _velt, ивши, טוס_,
  { {0x7ae1001f, 0x7c220061, 0x99150088, 0x00000000}},  //   _welt, bwor, тькі,
  { {0x68e223b4, 0x7ae123b5, 0x212b010f, 0x00000000}},  //   _deod, _telt, _mach_,
  { {0x69c108b2, 0x25a9022b, 0x7c24014a, 0x00000000}},  //   _tule, _ahal_, çire,
  { {0xdb0123b6, 0x39150014, 0x25a9002b, 0x00000000}},  //   _filò, _لواز, _bhal_,
  { {0x212b23b7, 0x25a90173, 0x20190093, 0x00000000}},  //   _nach_, _chal_, _opsi_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x987a0049, 0x03a60081, 0x2d7800d0, 0x00000000}},  //   _קאסט, тиго, nčer_,
  { {0xe297025f, 0x212b018e, 0xf796031d, 0x00000000}},  //   вар_, _bach_, _جنوب_,
  { {0x7c220866, 0x25a901d5, 0x399a0065, 0x00000000}},  //   ywor, _ghal_, tësi_,
  { {0xf5770054, 0x7c2223b8, 0x212b06f2, 0x00000000}},  // [5bc0] _جميع_, xwor, _dach_,
  { {0x93fb061e, 0x212b0038, 0xd36f0054, 0x00000000}},  //   _קליי, _each_, _وهي_,
  { {0x212b0abe, 0x7d020093, 0x7a0a013f, 0x00000000}},  //   _fach_, tgos, _təti,
  { {0x212b0195, 0x7c2223b9, 0x27ff021e, 0x00000000}},  //   _gach_, twor, kuun_,
  { {0x0b8a09ae, 0x7d020065, 0x399a0065, 0x00000000}},  //   мски_, rgos, qësi_,
  { {0x9f400211, 0x7d0200d6, 0x6713007d, 0x00000000}},  //   rrió_, sgos, त्मक_,
  { {0x212b0093, 0x394f0606, 0x7db6007e, 0x00000000}},  //   _yach_, _bogs_, _асац,
  { {0xdb090211, 0xf98f0379, 0x2d95007e, 0x00000000}},  //   _dueñ, يبي_, _брус,
  { {0xc173019b, 0x6dac005f, 0x394f00ab, 0x00000000}},  //   יחה_, _uşaq, _dogs_,
  { {0x95d800ed, 0x394f0190, 0x00000000, 0x00000000}},  //   ндот_, _eogs_,   ,
  { {0xb9080055, 0x68e2001a, 0x0f57009b, 0x00000000}},  //   _বা_, _teod, דיים_,
  { {0xd6da0044, 0x8a790049, 0x00000000, 0x00000000}},  //   _দাওয, _אָנק,   ,
  { {0x212b0173, 0x161e013d, 0x00000000, 0x00000000}},  //   _rach_, _बनकर_,   ,
  { {0x212b23ba, 0x98a3022a, 0x6b5400f6, 0x00000000}},  //   _sach_, _тиче, _tàgu,
  { {0x31c4092b, 0xab5d002b, 0x9abc0066, 0x00000000}},  //   иств, _juża, _baċi,
  { {0xfba90061, 0xf3ff00c4, 0x65660082, 0x00000000}},  //   _चीनम, puã_, chkh,
  { {0x212b135a, 0x20000026, 0xf3ff00fa, 0x00000000}},  // [5bd0] _vach_, guii_, quã_,
  { {0x4429006a, 0xdb1a008d, 0x2ee30065, 0x00000000}},  //   _isa_, _ditë, _qejf_,
  { {0x733a007b, 0x212b0016, 0x9abc002b, 0x00000000}},  //   _װערס, _tach_, _faċi,
  { {0x442900e0, 0xff5f0035, 0x212b004a, 0x00000000}},  //   _ksa_, _atît_, _uach_,
  { {0xdb090211, 0xed59066c, 0x752d00e7, 0x00000000}},  //   _sueñ, _niže_, _maaz,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x442901c5, 0x291f0020, 0x00000000, 0x00000000}},  //   _lsa_, teua_,   ,
  { {0x442908b2, 0xa9250175, 0xc879001a, 0x00000000}},  //   _osa_, удил, laşi_,
  { {0x44290058, 0x7d0900d9, 0x60cd01c5, 0x00000000}},  //   _nsa_, _ices, icam,
  { {0x7c2916df, 0xed5904eb, 0x75c800b9, 0x00000000}},  //   _iser, _diže_, _vězn,
  { {0x4429000d, 0xa50a0c4e, 0x394f0039, 0x00000000}},  //   _asa_, нена_, _togs_,
  { {0x442905ae, 0xd76300a6, 0x7c2900b4, 0x00000000}},  //   _bsa_, انگی, _kser,
  { {0x7c29002b, 0xe72e0545, 0xd90f00a1, 0x00000000}},  //   _jser, _ле_, _هیں_,
  { {0x27ed0240, 0x752f0046, 0x4429211e, 0x00000000}},  //   msen_, adcz, _dsa_,
  { {0x44290219, 0x27ed0374, 0x6b5d0e16, 0x00000000}},  //   _esa_, lsen_, _règl,
  { {0x442923bb, 0x7c2900f8, 0xc879001a, 0x00000000}},  //   _fsa_, _oser, eaşi_,
  { {0x27ed1dc6, 0xa067026b, 0x7a0a006b, 0x00000000}},  // [5be0] nsen_, гата_, _hətt,
  { {0x7d0923bc, 0x27ed0e53, 0x3246012b, 0x00000000}},  //   _aces, isen_, _беог,
  { {0x2776007b, 0x60cd0129, 0x68e923bd, 0x00000000}},  //   נגען_, bcam, kaed,
  { {0x27ed23be, 0xc27b00a0, 0x60cd0197, 0x00000000}},  //   ksen_, _טריי, ccam,
  { {0x5ee30055, 0x7c290047, 0x67210065, 0x00000000}},  //   _পারে, _cser, kelj,
  { {0x27ed0018, 0x6be30025, 0x67210091, 0x00000000}},  //   dsen_, حكوم, jelj,
  { {0x672123bf, 0x7c2923c0, 0xa3b503d7, 0x00000000}},  //   delj, _eser, जगत_,
  { {0x68e9001c, 0x6374006b, 0x61ee0007, 0x00000000}},  //   gaed, _dünə, isbl,
  { {0x6d40001a, 0x27ed0190, 0x31570049, 0x00000000}},  //   _inma, gsen_, טיקן_,
  { {0x44291c83, 0x656416c3, 0x25620010, 0x00000000}},  //   _rsa_, _alih, _róla_,
  { {0x49060647, 0x44290943, 0x27ed0190, 0x00000000}},  //   _مواق, _ssa_, asen_,
  { {0x44290142, 0x27ed01e3, 0xc5f80089, 0x00000000}},  //   _psa_, bsen_, dzēt_,
  { {0xb99301b7, 0xc9930054, 0xc7c80011, 0x00000000}},  //   _النب, _النظ, _dốc_,
  { {0x442923c1, 0x67210107, 0x660100b9, 0x00000000}},  //   _vsa_, celj, bulk,
  { {0xdb1a023f, 0x6d400168, 0xd627003b, 0x00000000}},  //   _cité, _onma, _боје_,
  { {0x7aea001f, 0x29ca001d, 0xc7c8001d, 0x00000000}},  //   haft, _mùa_, _gốc_,
  { {0x60cd0211, 0x9f4023c2, 0x765a00b0, 0x00000000}},  // [5bf0] rcam, ksiä_, lyty,
  { {0x60cd008e, 0x7d090ec0, 0xb2750478, 0x00000000}},  //   scam, _sces, _влош,
  { {0x7a0a006b, 0x7c290066, 0x539c009b, 0x00000000}},  //   _xətt, _sser, _איזו,
  { {0x7c290032, 0x67212012, 0x00000000, 0x00000000}},  //   _pser, zelj,   ,
  { {0x1aee0055, 0x8c450081, 0x777a0032, 0x00000000}},  //   চ্ছে_, реле, kitx,
  { {0x6d40008e, 0x29ca0082, 0x27ed0190, 0x00000000}},  //   _enma, _bùa_, vsen_,
  { {0xdb010051, 0x67210059, 0x06e30044, 0x00000000}},  //   _chlá, velj, _মালি,
  { {0x27ed23c3, 0x7d09003b, 0x7c29010e, 0x00000000}},  //   tsen_, _uces, _tser,
  { {0x67210e3b, 0x7c290038, 0x27ed010f, 0x00000000}},  //   telj, _user, usen_,
  { {0x27ed23c4, 0xf7710879, 0xc7c80011, 0x00000000}},  //   rsen_, تاب_, _sốc_,
  { {0x27ed1e7e, 0x672112ac, 0xcb6803ec, 0x00000000}},  //   ssen_, relj, _حمله_,
  { {0x67210340, 0x27ed00b0, 0x66010066, 0x00000000}},  //   selj, psen_, rulk,
  { {0x67210059, 0xa3b10061, 0x6601023a, 0x00000000}},  //   pelj, _ओळख_, sulk,
  { {0x394d23c5, 0x395f007f, 0x61ee01a2, 0x00000000}},  //   ljes_, lkus_, tsbl,
  { {0xe29a0407, 0xc7c8001d, 0x386d01a2, 0x00000000}},  //   тав_, _tốc_, lzer_,
  { {0x395f0006, 0x394d23c6, 0x629e0161, 0x00000000}},  //   nkus_, njes_, _vypo,

  { {0x629e0046, 0x386d23c7, 0x3fc8025a, 0x00000000}},  // [5c00] _wypo, nzer_, ادری_,
  { {0x629e05fd, 0x386d010f, 0x394d0065, 0x00000000}},  //   _typo, izer_, hjes_,
  { {0x394d23c8, 0x395f0004, 0xdd8f00a1, 0x00000000}},  //   kjes_, kkus_, ڈول_,
  { {0xf1bf00ad, 0x29ca0011, 0x394d002b, 0x00000000}},  //   _giá_, _rùa_, jjes_,
  { {0x394d23c9, 0xead41001, 0x386d00b5, 0x00000000}},  //   djes_, боль, jzer_,
  { {0xdce6005d, 0x395f0089, 0x386d0790, 0x00000000}},  //   ımın, ekus_, dzer_,
  { {0x7aea014a, 0xca480014, 0x394d0a5b, 0x00000000}},  //   raft, العه_, fjes_,
  { {0x7aea0030, 0xb4b60061, 0x394d0ca5, 0x00000000}},  //   saft, _जणू_, gjes_,
  { {0xed57007c, 0x777a05b3, 0x3160002d, 0x00000000}},  //   _тот_, titx, ikiz_,
  { {0xab5c0089, 0x394d008e, 0x765a0052, 0x00000000}},  //   _biļe, ajes_, tyty,
  { {0x5694003b, 0x777a23ca, 0xf76f023c, 0x00000000}},  //   сант, ritx, باي_,
  { {0x395f0d94, 0x69c80035, 0x6b9806ec, 0x00000000}},  //   ckus_, _iude, lovg,
  { {0xb7d40b03, 0x69c800b9, 0x636b23cb, 0x00000000}},  //   _اقتب, _hude, _jüng,
  { {0x69c8022b, 0x9388007c, 0x23650010, 0x00000000}},  //   _kude, асса_, ólj_,
  { {0x69c8000d, 0x7ae80059, 0x96b7003b, 0x00000000}},  //   _jude, _medt, _кућу_,
  { {0x69c823cc, 0xeeeb0011, 0x7ae8032e, 0x00000000}},  //   _mude, _đựng_, _ledt,
  { {0x657d000b, 0x69c80302, 0xb4e3007d, 0x00000000}},  // [5c10] mish, _lude, धरी_,
  { {0x69c8015c, 0x657d23cd, 0x394d0065, 0x00000000}},  //   _oude, lish, zjes_,
  { {0x645d0038, 0x69c80c3f, 0x75d3001a, 0x00000000}},  //   lysi, _nude, _găzd,
  { {0x657d23ce, 0x386d23cf, 0x00000000, 0x00000000}},  //   nish, yzer_,   ,
  { {0xac27005e, 0x69c814ac, 0x013600a0, 0x00000000}},  //   рфек, _aude, _פרשת_,
  { {0x657d0020, 0x7dd3002b, 0x636b01a2, 0x00000000}},  //   hish, _aħse, _düng,
  { {0x657d1ea5, 0x394d07fa, 0x9f490051, 0x00000000}},  //   kish, tjes_, nsaí_,
  { {0x386d1359, 0x248d0036, 0x636b23d0, 0x00000000}},  //   tzer_, żemy_, _hünd,
  { {0x25620219, 0x657d000b, 0x394d0065, 0x00000000}},  //   _sólo_, dish, rjes_,
  { {0x395f0368, 0x394d23c8, 0x386d010f, 0x00000000}},  //   skus_, sjes_, rzer_,
  { {0x69c80190, 0x386d0047, 0x394d23d1, 0x00000000}},  //   _gude, szer_, pjes_,
  { {0x7a7a007b, 0x657d0061, 0x645d01aa, 0x00000000}},  //   _גרעס, gish, fysi,
  { {0x7bc113b1, 0x7d1b0065, 0x69c8010f, 0x00000000}},  //   _kilu, _mbus, _zude,
  { {0x27ff0066, 0xd88600a1, 0x04fa0044, 0x00000000}},  //   mrun_, _چھین_, েজের_,
  { {0x657d000b, 0x7bc1099d, 0xf53f032e, 0x00000000}},  //   bish, _milu, rmår_,
  { {0x657d0009, 0x7bc10032, 0x7c3b23d2, 0x00000000}},  //   cish, _lilu, _orur,
  { {0xef1a044b, 0x80aa1534, 0x9f400051, 0x00000000}},  // [5c20] лма_, ував_, msiú_,
  { {0x9f400051, 0x7306003b, 0x7bc1011c, 0x00000000}},  //   lsiú_, _упоз, _nilu,
  { {0xb3bb00b6, 0x7ae814c6, 0xb7ff0044, 0x00000000}},  //   _תמיכ, _redt, ্বিত_,
  { {0x69c80995, 0xdb1b009f, 0x442004d4, 0x00000000}},  //   _rude, _stuð, _kpi_,
  { {0x69c80006, 0x9f400051, 0x75260032, 0x00000000}},  //   _sude, isiú_, iekz,
  { {0x636b01f6, 0x7d1b0066, 0x657d1b1c, 0x00000000}},  //   _günd, _ebus, zish,
  { {0x7bc104cb, 0x442000d4, 0x7ae801e3, 0x00000000}},  //   _dilu, _lpi_, _vedt,
  { {0x44200052, 0x636b010f, 0xafdb01e3, 0x00000000}},  //   _opi_, _zünd, _drøf,
  { {0x96ea00c2, 0x657d1ac5, 0x7bc900f4, 0x00000000}},  //   льна_, vish, _gueu,
  { {0x657d09df, 0x35f4019d, 0x69c8006c, 0x00000000}},  //   wish, опор, _tude,
  { {0x657d1ea5, 0x442004cb, 0x69c8021e, 0x00000000}},  //   tish, _api_, _uude,
  { {0xd567107f, 0x6b5d0129, 0x443b0c61, 0x00000000}},  //   стоп, _règi, _prq_,
  { {0x657d0714, 0x4420204f, 0x636b01a2, 0x00000000}},  //   rish, _cpi_, _lüne,
  { {0x657d23d3, 0x645d0006, 0xdb0801aa, 0x00000000}},  //   sish, rysi, _zidò,
  { {0x44200607, 0x657d000b, 0xdce90107, 0x00000000}},  //   _epi_, pish, _umeć,
  { {0x636b0004, 0x657d0065, 0x9f490051, 0x00000000}},  //   _sünd, qish, rsaí_,
  { {0x9f550216, 0xd32702d3, 0x2d8700b9, 0x00000000}},  // [5c30] овач, _льни, énem_,
  { {0x80d90316, 0x00000000, 0x00000000, 0x00000000}},  //   _फ्रे,   ,   ,
  { {0x7bc10026, 0xeeab0c27, 0x20000035, 0x00000000}},  //   _rilu, утак_, arii_,
  { {0x9c3900d7, 0xa69b0049, 0x7c3b1c28, 0x00000000}},  //   ипет_, נשאפ, _prur,
  { {0x7bc923d4, 0x6aa10016, 0xfe9300a1, 0x00000000}},  //   _queu, _sylf, _کیاج,
  { {0x7645000c, 0xc1ed0164, 0x00000000, 0x00000000}},  //   _áhyg, _जबाब_,   ,
  { {0x636b047f, 0x81cb0055, 0x27e60058, 0x00000000}},  //   _güne, রীর_, _awon_,
  { {0x7d1b1dc0, 0xc7c8001d, 0x7c3b0065, 0x00000000}},  //   _ubus, _vốn_, _trur,
  { {0x7d040051, 0x69c2002d, 0x7c3b0d3f, 0x00000000}},  //   óise, _dioe, _urur,
  { {0xe61900ed, 0xc7c80011, 0x27ff002d, 0x00000000}},  //   адо_, _tốn_, rrun_,
  { {0x44200059, 0xaa670184, 0xc7c80082, 0x00000000}},  //   _spi_, _утак, _uốn_,
  { {0x69c20026, 0x27e60173, 0x7d0b0082, 0x00000000}},  //   _gioe, _fwon_, nggs,
  { {0x333301d5, 0x78a200e5, 0x00000000, 0x00000000}},  //   _baxx_, _gyov,   ,
  { {0x437502b8, 0x442001c3, 0x69c2002d, 0x00000000}},  //   пуст, _vpi_, _zioe,
  { {0x6b840051, 0x44200145, 0x798923d5, 0x00000000}},  //   éigi, _wpi_, onew,
  { {0xe0da00e3, 0x20000035, 0x4420008a, 0x00000000}},  //   рва_, trii_, _tpi_,
  { {0x88bd0046, 0x291d0020, 0x3f9a00ca, 0x00000000}},  // [5c40] ześn, _mbwa_, topu_,
  { {0x7c24038c, 0x799b00b5, 0x2d8d23d6, 0x00000000}},  //   çirm, houw, _ajee_,
  { {0x79890093, 0x4e2a09da, 0x64410089, 0x00000000}},  //   knew, роен_, ālie,
  { {0x68eb0119, 0xcbd50055, 0x2000001a, 0x00000000}},  //   _negd, _হয়েছ, prii_,
  { {0xead41280, 0x09d20061, 0x79890554, 0x00000000}},  //   поль, सऱ्य, dnew,
  { {0x798923d7, 0x636b0cca, 0x69c2005b, 0x00000000}},  //   enew, _tüne, _sioe,
  { {0xbea30175, 0x79890016, 0x6b8d0051, 0x00000000}},  //   _жарк, fnew, éaga,
  { {0xfafa00a6, 0xa37b00c4, 0x1d070478, 0x00000000}},  //   _چراغ_, mpõe, _меси_,
  { {0x6da301be, 0x274a004c, 0x0d7700a1, 0x00000000}},  //   _цита, ачно_, _بینک_,
  { {0x2562009f, 0x636b010f, 0x798906b1, 0x00000000}},  //   _fólk_, _münc, anew,
  { {0x799b00c1, 0x798901a2, 0xdb1a00fa, 0x00000000}},  //   bouw, bnew, _titâ,
  { {0x69da002b, 0x44391325, 0xe45f00b0, 0x00000000}},  //   _itte, tvs_, työ_,
  { {0xd5b80194, 0xccf3009b, 0x94ab0745, 0x00000000}},  //   юсь_, וכר_, ртна_,
  { {0x44390190, 0x79800020, 0x39461aa3, 0x00000000}},  //   rvs_, limw, _hnos_,
  { {0x672823d8, 0x2d870047, 0x623400e2, 0x00000000}},  //   medj, ének_, меру,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x656f002a, 0x660823d9, 0x50670c18, 0x00000000}},  // [5c50] mhch, ludk, цтва,
  { {0x67280209, 0x69da1015, 0x64400030, 0x00000000}},  //   nedj, _otte, æmie,
  { {0x798923da, 0x6608006c, 0x5f740025, 0x00000000}},  //   ynew, nudk, ذاكر,
  { {0x8d7405f3, 0xf65300b3, 0x656f0082, 0x00000000}},  //   وانا, וצע_, nhch,
  { {0x636b011f, 0x60d60049, 0x68eb01d6, 0x00000000}},  //   _günc, _מורא_, _regd,
  { {0x39461160, 0xab2900e3, 0x21290b3d, 0x00000000}},  //   _anos_, сока_, leah_,
  { {0x7989001a, 0x1df80147, 0x660804cb, 0x00000000}},  //   tnew, _меры_, judk,
  { {0xab5d01d5, 0x00000000, 0x00000000, 0x00000000}},  //   _mużi,   ,   ,
  { {0x69da23db, 0x02a8007d, 0xa91d0ce4, 0x00000000}},  //   _ette, _गर्न, jiže,
  { {0x79890016, 0x25a0021a, 0x2d9d23dc, 0x00000000}},  //   snew, _skil_, lowe_,
  { {0x63700002, 0xe5a602dc, 0x00000000, 0x00000000}},  //   _häng, зини,   ,
  { {0x2d9d0036, 0x63701e6c, 0x291d0dfc, 0x00000000}},  //   nowe_, _käng, _ubwa_,
  { {0x672801a1, 0xed590059, 0x33d50088, 0x00000000}},  //   bedj, _mož_, діст,
  { {0x63700dac, 0x69da093b, 0x69d6000c, 0x00000000}},  //   _mäng, _ytte, _ógeð,
  { {0x6370127c, 0x2d9d0036, 0x61460175, 0x00000000}},  //   _läng, kowe_, пева,
  { {0x9f4706b8, 0x290d1423, 0xc692009b, 0x00000000}},  //   čný_, ngea_, _ראה_,
  { {0x2d9d0046, 0x20090181, 0xdb010048, 0x00000000}},  // [5c60] dowe_, guai_, _dhlú,
  { {0x161f007d, 0x798000e7, 0x00000000, 0x00000000}},  //   _बहार_, zimw,   ,
  { {0x7bdb00e5, 0xed59016c, 0x00000000, 0x00000000}},  //   _atuu, _bož_,   ,
  { {0xed5900b9, 0x1d0a0517, 0x2d9d0036, 0x00000000}},  //   _což_, седи_, gowe_,
  { {0x3218042e, 0x850a0061, 0xa37b00c4, 0x00000000}},  //   ltry_, _वाईट_, spõe,
  { {0x88bd0046, 0xdb1a008e, 0x6c830025, 0x00000000}},  //   reśl, _bitá, علوم,
  { {0xfce60057, 0x32180038, 0x2d9d23dd, 0x00000000}},  //   _ново, ntry_, bowe_,
  { {0x637023de, 0x636b005f, 0x660802e1, 0x00000000}},  //   _händ, _müna, vudk,
  { {0x637023df, 0x39460059, 0x79800e9c, 0x00000000}},  //   _gäng, _vnos_, rimw,
  { {0xa7730f62, 0x00000000, 0x00000000, 0x00000000}},  //   ельч,   ,   ,
  { {0xaadb00b6, 0x672805fa, 0x656f0051, 0x00000000}},  //   _החבר, redj, thch,
  { {0x39460219, 0x2c2003d7, 0x637003a9, 0x00000000}},  //   _unos_, _यहां_, _länd,
  { {0x3218184d, 0x9f52004a, 0x637000f8, 0x00000000}},  //   etry_, nuyó_, _oänd,
  { {0x656f1706, 0x4acc0164, 0xa91d00ca, 0x00000000}},  //   shch, ाशिव, riže,
  { {0x656f0026, 0x321800e0, 0x171b009b, 0x00000000}},  //   phch, gtry_, _הווע,
  { {0x2009003f, 0x63a7012d, 0x636b010e, 0x00000000}},  //   tuai_, sljn, _düna,
  { {0x637023e0, 0x656d049d, 0xed5900ca, 0x00000000}},  // [5c70] _bänd, _ilah, _rož_,
  { {0xfe7100a1, 0x2d9d0036, 0x29030006, 0x00000000}},  //   نگز_, wowe_, ėjai_,
  { {0x7bdb049b, 0x20090149, 0x637017c4, 0x00000000}},  //   _stuu, suai_, _säng,
  { {0x6b5d0068, 0x00000000, 0x00000000, 0x00000000}},  //   _nègr,   ,   ,
  { {0xa15601f8, 0x2d9d0046, 0xac090cf2, 0x00000000}},  //   _חברה_, rowe_, інка_,
  { {0x656d23e1, 0x7c94007a, 0x2d9d0036, 0x00000000}},  //   _llah, رشنا, sowe_,
  { {0x656d04fa, 0x89d60025, 0x80c20044, 0x00000000}},  //   _olah, ووور_, ষুদ্,
  { {0x7d55007e, 0x9f52008e, 0xdb1a0a50, 0x00000000}},  //   _ўвах, buyó_, _vitá,
  { {0x6370021e, 0xdd94007e, 0x290d0035, 0x00000000}},  //   _häne, _чаты, rgea_,
  { {0x656d0760, 0x636200fa, 0x668300a1, 0x00000000}},  //   _alah, _tôni, ٹیبل,
  { {0x6d490c0d, 0x656d23e2, 0x6370006c, 0x00000000}},  //   _knea, _blah, _jäne,
  { {0x44321712, 0x6d5b009d, 0x00000000, 0x00000000}},  //   _psy_, _joua,   ,
  { {0x75360009, 0x2eaa0309, 0x63700039, 0x00000000}},  //   _vayz, _कर्त, _läne,
  { {0x7c2402b9, 0x3669005c, 0x6d5b009d, 0x00000000}},  //   çiri, _мало_, _loua,
  { {0x656d0066, 0xc7b2009b, 0x6d490032, 0x00000000}},  //   _flah, _שבו_, _onea,
  { {0x6b830475, 0x63700039, 0x321801c3, 0x00000000}},  //   hing, _sänd, rtry_,
  { {0x32180038, 0xb4ea006e, 0x3a250022, 0x00000000}},  // [5c80] stry_, यरी_, _lplp_,
  { {0x6b8304a5, 0xf09f00f6, 0x656d1a7d, 0x00000000}},  //   jing, _acàs_, _zlah,
  { {0x6b8323e3, 0x63700274, 0xf2d300a0, 0x00000000}},  //   ding, _vänd, _בעת_,
  { {0xbc6a006d, 0x9f52008e, 0x637001a2, 0x00000000}},  //   يمان_, tuyó_, _wänd,
  { {0x6b8300db, 0x6370152c, 0x6d5b23e4, 0x00000000}},  //   fing, _tänd, _doua,
  { {0x6b83177d, 0x7c2d23e5, 0x6d4915cd, 0x00000000}},  //   ging, çara, _enea,
  { {0xfb1900a1, 0x7f5c00c4, 0x3a2500c4, 0x00000000}},  //   سروں_, _iorq, _cplp_,
  { {0x38340256, 0xed4301fc, 0xc7c80011, 0x00000000}},  //   енир, _инсп, _hối_,
  { {0xc2f40055, 0x3ce61332, 0x872a007e, 0x00000000}},  //   _জানি_, mbov_, оўна_,
  { {0xf4140055, 0x7f5c23e6, 0xb905013d, 0x00000000}},  //   িবার_, _jorq, _ब्_,
  { {0x656d1609, 0xc7c80011, 0xc956007c, 0x00000000}},  //   _plah, _mối_, _отды,
  { {0x7bc8020c, 0xc7c80011, 0x7f5c0068, 0x00000000}},  //   _hidu, _lối_, _lorq,
  { {0x9f400129, 0xe73a005e, 0x7bc80020, 0x00000000}},  //   nsió_, _мед_, _kidu,
  { {0xb4af01f5, 0x7f5c1fec, 0xa91d00d0, 0x00000000}},  //   _करी_, _norq, miža,
  { {0xc7c8001d, 0x7bc8107e, 0x656d218e, 0x00000000}},  //   _nối_, _midu, _tlah,
  { {0x6b83000b, 0xdb010173, 0x26180a39, 0x00000000}},  //   zing, _eklè, méo_,
  { {0xa29f0164, 0xfe700014, 0x6d5b15a3, 0x00000000}},  // [5c90] _खुर्, یدم_, _roua,
  { {0x6d491b82, 0xc7c80011, 0x2fc70538, 0x00000000}},  //   _snea, _bối_, öng_,
  { {0x6b830292, 0xdb1a021e, 0xc33201ce, 0x00000000}},  //   ving, _mitä, _גוי_,
  { {0x6b830007, 0xc7c80011, 0x63700a3c, 0x00000000}},  //   wing, _dối_, _väne,
  { {0x7f5c1052, 0xdce9014a, 0xa91d0091, 0x00000000}},  //   _forq, _emeğ, jiža,
  { {0x7bc80022, 0x6b8301d6, 0x3a250022, 0x00000000}},  //   _cidu, uing, _pplp_,
  { {0x6b830c64, 0x7bc8023a, 0x21390f65, 0x00000000}},  //   ring, _didu, _kash_,
  { {0x2618028c, 0xb4af0183, 0xdb1a006c, 0x00000000}},  //   déo_, _करू_, _aitä,
  { {0x6b8323e7, 0x7bc801bc, 0x21390023, 0x00000000}},  //   ping, _fidu, _mash_,
  { {0x636b23e8, 0xdce9089f, 0x81e50044, 0x00000000}},  //   _sünn, _mleč, _নিন_,
  { {0xa29f0164, 0xb81c0044, 0x00000000, 0x00000000}},  //   _खुल्, তিগত_,   ,
  { {0x213901a3, 0x7bc80035, 0xe9190088, 0x00000000}},  //   _nash_, _zidu, _ході_,
  { {0x2d8f0048, 0x00000000, 0x00000000, 0x00000000}},  //   inge_,   ,   ,
  { {0x29030006, 0x00000000, 0x00000000, 0x00000000}},  //   ėjau_,   ,   ,
  { {0xdce9012d, 0x41b602dc, 0x213923e9, 0x00000000}},  //   _aleč, есат, _bash_,
  { {0xc7c80011, 0x67380243, 0x213900ab, 0x00000000}},  //   _rối_, _zavj, _cash_,
  { {0x7f5c23ea, 0x75241068, 0x600a0cab, 0x00000000}},  // [5ca0] _porq, _ibiz, янам_,
  { {0xe3b20025, 0x31690032, 0x395d0133, 0x00000000}},  //   _حرب_, akaz_, _lows_,
  { {0xe8ac0201, 0xdce20209, 0x7bc80207, 0x00000000}},  //   _चर्च, skoč, _ridu,
  { {0x644403b6, 0x7bc8006c, 0xafe600ed, 0x00000000}},  //   _krii, _sidu, _помл,
  { {0x7bc8006c, 0x752423eb, 0x6aa80190, 0x00000000}},  //   _pidu, _mbiz, _sydf,
  { {0xc7c8001d, 0x9f4004bd, 0xafdb06ec, 0x00000000}},  //   _tối_, rsió_, _krøn,
  { {0x7bc80a5c, 0x9f4004bd, 0xf9c605c7, 0x00000000}},  //   _vidu, ssió_, нщин,
  { {0x67380363, 0xdca6041f, 0x2d870010, 0x00000000}},  //   _savj, _заби, énet_,
  { {0xdb1a021e, 0xb4af02fb, 0x7bc804cb, 0x00000000}},  //   _pitä, _करे_, _tidu,
  { {0x261800f4, 0x752423ec, 0x7bdf004a, 0x00000000}},  //   téo_, _abiz, íque,
  { {0x5694003b, 0x644423ed, 0xa91d007f, 0x00000000}},  //   тант, _arii, siža,
  { {0xe4a723ee, 0xa91d0091, 0x644401c5, 0x00000000}},  //   ерго, ližn, _brii,
  { {0xe7860184, 0x21390133, 0x00000000, 0x00000000}},  //   _пуко, _rash_,   ,
  { {0x636b01f6, 0xafdb0737, 0x65b600b9, 0x00000000}},  //   _günl, _brøn, váhe,
  { {0xb5a723ef, 0xa5d70025, 0xdcfb0059, 0x00000000}},  //   _прий, _كبير_, _smuč,
  { {0x644405ad, 0xdce92066, 0xafdb0190, 0x00000000}},  //   _frii, _pleč, _drøn,
  { {0xc05b0088, 0xaf0700ed, 0x5ee20044, 0x00000000}},  // [5cb0] чів_, ечек, _পয়ে,
  { {0x44290b9a, 0xa91d0059, 0xdce90d0a, 0x00000000}},  //   _ipa_, jižn, _vleč,
  { {0x21390065, 0xafdb02cc, 0x442901a3, 0x00000000}},  //   _tash_, _grøn, _hpa_,
  { {0x753d0047, 0x44290093, 0x2d8f0197, 0x00000000}},  //   ndsz, _kpa_, unge_,
  { {0xb4af013d, 0x442901a3, 0xc2f40044, 0x00000000}},  //   _करो_, _jpa_, _জাতি_,
  { {0x996c00b9, 0x98ad002b, 0x6f1500b4, 0x00000000}},  //   měř_, jjeġ_, _uczc,
  { {0x2d870211, 0x5338009b, 0x6995005e, 0x00000000}},  //   énes_, גנון_, крих,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44290f91, 0x00000000, 0x00000000, 0x00000000}},  //   _npa_,   ,   ,
  { {0x7c290207, 0x75240026, 0xe645005e, 0x00000000}},  //   _iper, _sbiz, веоп,
  { {0x391501f9, 0x442904be, 0xa50a013b, 0x00000000}},  //   _амер, _apa_, мена_,
  { {0x644423f0, 0x2009010a, 0x29030006, 0x00000000}},  //   _prii, krai_, ėjas_,
  { {0x442900ca, 0xe72e00ed, 0x68e904cb, 0x00000000}},  //   _cpa_, _ке_, mbed,
  { {0x20090006, 0x4429010f, 0x7c290009, 0x00000000}},  //   drai_, _dpa_, _mper,
  { {0x44290020, 0x69cb09df, 0xcb120097, 0x00000000}},  //   _epa_, _kige, ילם_,
  { {0x6444006c, 0x00000000, 0x00000000, 0x00000000}},  //   _trii,   ,   ,
  { {0x69cb0032, 0x64440be4, 0x64a6003b, 0x00000000}},  // [5cc0] _mige, _urii, _јапа,
  { {0x69cb0018, 0xafdb0056, 0xdee601ab, 0x00000000}},  //   _lige, _trøn, тожи,
  { {0x7c291f55, 0x81dc0055, 0xd3570097, 0x00000000}},  //   _aper, _ঠিক_, _סיטי_,
  { {0x69cb0020, 0xc7c80082, 0xafdb0190, 0x00000000}},  //   _nige, _hốt_, _krøl,
  { {0x0ffa004b, 0x68e923f1, 0x00000000, 0x00000000}},  //   _تعجب_, dbed,   ,
  { {0x752f0046, 0x68e9054e, 0x7c290022, 0x00000000}},  //   zecz, ebed, _dper,
  { {0x69cb1ce1, 0x7c290145, 0xc7c80011, 0x00000000}},  //   _bige, _eper, _mốt_,
  { {0x68e923f2, 0xd90e00a6, 0x583805bb, 0x00000000}},  //   gbed, زیت_, езия_,
  { {0x69cb04cb, 0x36d402e9, 0xdb0123f3, 0x00000000}},  //   _dige, лопр, _chló,
  { {0x69cb23f4, 0xdb1a1b0f, 0xc7c80011, 0x00000000}},  //   _eige, _litú, _nốt_,
  { {0x752f0046, 0x68e90bc7, 0x69cb0253, 0x00000000}},  //   tecz, bbed, _fige,
  { {0x79820046, 0x7c2923f5, 0x69cb0035, 0x00000000}},  //   _umow, _yper, _gige,
  { {0x69c001ee, 0xc458007c, 0x94a8041f, 0x00000000}},  //   mmme, виях_, втра_,
  { {0xd90e009c, 0x4429049a, 0xa5c7000c, 0x00000000}},  //   _ایک_, _vpa_, _bjóð,
  { {0x44290145, 0x69cb23f6, 0x2d840190, 0x00000000}},  //   _wpa_, _yige, _omme_,
  { {0x44290093, 0x2009086f, 0x0eeb007d, 0x00000000}},  //   _tpa_, trai_, टर्स_,
  { {0x7ff40a4f, 0x442923f7, 0x909923f8, 0x00000000}},  // [5cd0] لسلا, _upa_, хват_,
  { {0x637023f9, 0x68e9003b, 0x20090e46, 0x00000000}},  //   _täna, zbed, rrai_,
  { {0x63700a3c, 0xf41f021e, 0x4fc4013b, 0x00000000}},  //   _känn, ltä_, рста,
  { {0x637023fa, 0x7c290066, 0x20090026, 0x00000000}},  //   _jänn, _pper, prai_,
  { {0x6370127c, 0x69cb23fb, 0xf41f021e, 0x00000000}},  //   _männ, _rige, ntä_,
  { {0x69cb068f, 0xf41f021e, 0x2d840103, 0x00000000}},  //   _sige, itä_, _emme_,
  { {0x69cb23fc, 0xdb030023, 0xdcfb0089, 0x00000000}},  //   _pige, lonë, _emuā,
  { {0x64410089, 0xe9a900a2, 0xba22007e, 0x00000000}},  //   ālij, رگان_, ёдык,
  { {0x68e923fd, 0xccf2009b, 0x9c640014, 0x00000000}},  //   rbed, _לכן_, _پهلو,
  { {0x68e90c0c, 0xc2e90044, 0x69cb23fe, 0x00000000}},  //   sbed, কৃতি_, _wige,
  { {0xcb68007a, 0x8f9c009b, 0x391506dd, 0x00000000}},  //   _جمله_, ויזי, _مواز,
  { {0xc7c80011, 0x973c0521, 0xc98400ed, 0x00000000}},  //   _sốt_, roća, _кучи,
  { {0xa5c7000c, 0x973c0091, 0x394f1a90, 0x00000000}},  //   _sjóð, moćn, _ings_,
  { {0xdb1a008e, 0x79890116, 0x66e22180, 0x00000000}},  //   _sitú, liew, _лоша,
  { {0x412a017f, 0xafdb0737, 0x679a0049, 0x00000000}},  //   ново_, _drøm, _אױסג,
  { {0x79890036, 0x00e40014, 0x973c04eb, 0x00000000}},  //   niew, شتری, noćn,
  { {0xc7c8001d, 0xafdb0146, 0x00000000, 0x00000000}},  // [5ce0] _tốt_, _frøm,   ,
  { {0xe0df01aa, 0xdb03000c, 0x00000000, 0x00000000}},  //   _efò_, llnæ,   ,
  { {0x69c01382, 0x9d46005e, 0xdb0300c4, 0x00000000}},  //   ymme, лежд, ponê,
  { {0xdb031d81, 0x0cd20044, 0x00000000, 0x00000000}},  //   lonè, ার্ত,   ,
  { {0x2d9e19bf, 0x79890168, 0x1af401e1, 0x00000000}},  //   _ítem_, diew, апля,
  { {0x394f01d6, 0x00000000, 0x00000000, 0x00000000}},  //   _angs_,   ,   ,
  { {0xbf100309, 0x2cad0133, 0x39a602dc, 0x00000000}},  //   ालीन_, _eyed_, лшив,
  { {0xdd92024a, 0x6e930a4f, 0xf41f021e, 0x00000000}},  //   _اور_, _الفا, ytä_,
  { {0xd6d00054, 0xa774017f, 0xdb0301aa, 0x00000000}},  //   يقة_, илич, konè,
  { {0x25a92165, 0x1037009b, 0x61e200ca, 0x00000000}},  //   _skal_, נטים_, _čoln,
  { {0xdb0300f6, 0x0f57009b, 0x00000000, 0x00000000}},  //   donè, איים_,   ,
  { {0x1a9b00bd, 0xf41f021e, 0xafdb0146, 0x00000000}},  //   _איבע, ttä_, _drøj,
  { {0x63700039, 0x69da0061, 0xf76f0014, 0x00000000}},  //   _vänn, _पंडी, زای_,
  { {0xa66601fa, 0xdb030129, 0xd6cf0076, 0x00000000}},  //   _مطبو, gonè, _فقه_,
  { {0xf41f0f3c, 0x637000b0, 0x5f1a0044, 0x00000000}},  //   stä_, _tänn, ড়াও_,
  { {0x3f98002b, 0x65b6000c, 0x3981007f, 0x00000000}},  //   _ajru_, páha, tųsi_,
  { {0x2ef500e2, 0xdb010861, 0xdb0300f6, 0x00000000}},  // [5cf0] изар, _sklí, bonè,
  { {0x20071032, 0xdb030129, 0x3dcd0145, 0x00000000}},  //   čni_, conè, _siew_,
  { {0x2cad01a3, 0x63a70065, 0xa7fd0010, 0x00000000}},  //   _syed_, mojn, gyűj,
  { {0x656f23ff, 0x63a70065, 0x973c11af, 0x00000000}},  //   nkch, lojn, koćo,
  { {0x3dcd0038, 0x79892400, 0xdca5025f, 0x00000000}},  //   _view_, view, јали,
  { {0x63a70065, 0xfbd003ec, 0xab29013b, 0x00000000}},  //   nojn, سته_, тока_,
  { {0x79891f4b, 0xdd9b008b, 0xc33400b3, 0x00000000}},  //   tiew, _зша_, מוס_,
  { {0xa805003b, 0x7c3e0036, 0x63a70065, 0x00000000}},  //   азил, łpra, hojn,
  { {0x63a703c4, 0x23a502fb, 0x79890007, 0x00000000}},  //   kojn, ओवाद, riew,
  { {0x79890a77, 0x63a70065, 0x7c3b002d, 0x00000000}},  //   siew, jojn, _isur,
  { {0x63a70065, 0x61e2016c, 0x7bc301f3, 0x00000000}},  //   dojn, _čolo, mmnu,
  { {0xe5a60216, 0xdb030387, 0xd46a00ed, 0x00000000}},  //   рими, doné, виме_,
  { {0x7d040051, 0x68fb2401, 0x3775007e, 0x00000000}},  //   óisi, maud, _выйс,
  { {0x63a72402, 0x27ff014a, 0xafdb0030, 0x00000000}},  //   gojn, msun_, _trøj,
  { {0x0cb20316, 0xdb1a008d, 0x443b05f0, 0x00000000}},  //   _जर्म, _shtë, _esq_,
  { {0x00e600c0, 0x68fb010a, 0xdb032403, 0x00000000}},  //   ржан, naud, sonè,
  { {0x63a70627, 0x27ff01e5, 0x7c3b00e5, 0x00000000}},  // [5d00] bojn, nsun_, _nsur,
  { {0x7d1b00d6, 0xc3fb00b3, 0xfe720025, 0x00000000}},  //   _acus, _שליש, يدا_,
  { {0x7c3b023a, 0x68fb00b0, 0x1fb50147, 0x00000000}},  //   _asur, kaud, сстр,
  { {0x61460265, 0xe29b00b6, 0x27ff115d, 0x00000000}},  //   _тема, _ישיר, ksun_,
  { {0x68fb1f2e, 0x442200ca, 0x20da00ca, 0x00000000}},  //   daud, ntk_, ršič_,
  { {0xc5eb0044, 0x7d1b2404, 0x00000000, 0x00000000}},  //   _কিনা_, _ecus,   ,
  { {0x6b8a01d6, 0x3f8f009d, 0xa3dd0061, 0x00000000}},  //   rifg, ègue_, _तून_,
  { {0xada3008b, 0x63a70065, 0x7d1b0051, 0x00000000}},  //   _дасл, zojn, _gcus,
  { {0xa3b60164, 0x4973111f, 0x2000001a, 0x00000000}},  //   जता_, ільс, nsii_,
  { {0xe56800bd, 0x6d40022b, 0x7763049a, 0x00000000}},  //   _אַ_, _hama, _conx,
  { {0x6d40006a, 0x2d9e028c, 0x7c22029d, 0x00000000}},  //   _kama, _êtes_, ltor,
  { {0x6d402405, 0x6d422406, 0x68fb008e, 0x00000000}},  //   _jama, ndoa, caud,
  { {0x6d4003b0, 0x7c220292, 0x63a7008d, 0x00000000}},  //   _mama, ntor, tojn,
  { {0x6d401312, 0x7c2208e1, 0xd6d00076, 0x00000000}},  //   _lama, itor, _عقب_,
  { {0x63a71e8d, 0x60cc006b, 0x92680256, 0x00000000}},  //   rojn, ənmə, арта_,
  { {0x6d400811, 0x63a70065, 0x44f50184, 0x00000000}},  //   _nama, sojn, _упис,
  { {0xdefb0057, 0x7c220065, 0xdfd10025, 0x00000000}},  // [5d10] вые_, jtor, سيا_,
  { {0x7d1b0207, 0xdb032407, 0xd9d70044, 0x00000000}},  //   _scus, poné, _সবসম,
  { {0x6d40006b, 0x7c220951, 0x2ef8004a, 0x00000000}},  //   _bama, etor, _derf_,
  { {0x6d40049a, 0x29060020, 0xbd180088, 0x00000000}},  //   _cama, _ndoa_, иції_,
  { {0x8d74026c, 0x8c4501fb, 0x92d90055, 0x00000000}},  //   غاما, селе, ারী_,
  { {0xa03a0049, 0x6d400f2f, 0xdf47007e, 0x00000000}},  //   _געשפ, _eama, _тэмп,
  { {0x7c220d60, 0xf1bf001d, 0x6d40002d, 0x00000000}},  //   ator, _khá_, _fama,
  { {0x6d40009f, 0x27ff0052, 0x7c3b004a, 0x00000000}},  //   _gama, tsun_, _tsur,
  { {0x68fb11e8, 0x67550025, 0x00000000, 0x00000000}},  //   raud, مخدر,   ,
  { {0x6d402408, 0x8aa701fb, 0xfbd00188, 0x00000000}},  //   _zama, _кред, _قتل_,
  { {0x6d40163c, 0x4439084d, 0x27ff2409, 0x00000000}},  //   _yama, ews_, ssun_,
  { {0xf1bf0011, 0x29020010, 0x6d4005aa, 0x00000000}},  //   _nhá_, ókat_, _xama,
  { {0xc8da0049, 0x65b60010, 0x63be240a, 0x00000000}},  //   _עקסט, sáho, _phpn,
  { {0x43750264, 0x395f240b, 0x386d006b, 0x00000000}},  //   оуст, ljus_, myer_,
  { {0x386d0023, 0x442200ca, 0xf6750049, 0x00000000}},  //   lyer_, stk_, _לײַט_,
  { {0x659301fc, 0xf1bf0181, 0x44220093, 0x00000000}},  //   _нају, _chá_, ptk_,
  { {0x6d400127, 0xf1bf002a, 0x75d3001a, 0x00000000}},  // [5d20] _rama, _dhá_, _văzu,
  { {0x395f0004, 0x65bd0353, 0x7c2200ca, 0x00000000}},  //   hjus_, réhe, vtor,
  { {0x6d400811, 0x63700073, 0x386d0065, 0x00000000}},  //   _pama, _länk, hyer_,
  { {0x7c22240c, 0x2ef80007, 0x68f90009, 0x00000000}},  //   ttor, _werf_, _newd,
  { {0x0b8a064b, 0xdb0101ca, 0x6d40001a, 0x00000000}},  //   лски_, _sklá, _vama,
  { {0x6d400020, 0x68e20026, 0x386d0058, 0x00000000}},  //   _wama, _sfod, dyer_,
  { {0x5a340088, 0xba2a0014, 0x27e60203, 0x00000000}},  //   інит, استم_, _ston_,
  { {0x7c220129, 0x637004ce, 0x8d9601b7, 0x00000000}},  //   ptor, _bänk, _الرش,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8b6506ea, 0xdce00166, 0x7d04000c, 0x00000000}},  //   _والم, _momč, ðisf,
  { {0x4a9a007e, 0xdb0101dc, 0x636b006b, 0x00000000}},  //   _стаў_, _uklá, _münt,
  { {0x68e00061, 0x7afa0039, 0xd5b81fea, 0x00000000}},  //   qcmd, _hett, йся_,
  { {0x7afa0010, 0x44390376, 0x69da0020, 0x00000000}},  //   _kett, uws_, _hute,
  { {0x7afa22d7, 0x69da04ff, 0x3255005e, 0x00000000}},  //   _jett, _kute, овгр,
  { {0x7afa0e8d, 0xf1bf001d, 0x69da02c8, 0x00000000}},  //   _mett, _phá_, _jute,
  { {0x7afa0198, 0x92d90055, 0x69da01c5, 0x00000000}},  //   _lett, ারে_, _mute,
  { {0x69da0c01, 0x657d002a, 0x7ff70025, 0x00000000}},  // [5d30] _lute, mhsh, إسرا,
  { {0x7afa0292, 0x644d022b, 0x69da112b, 0x00000000}},  //   _nett, _irai, _oute,
  { {0x69da0006, 0x2eff009d, 0xa91d0006, 0x00000000}},  //   _nute, _œufs_, siži,
  { {0x3f8a1335, 0x644d0036, 0xd5b90089, 0x00000000}},  //   _embu_, _krai, ktām_,
  { {0x69da0602, 0x7afa0038, 0x752d1d7c, 0x00000000}},  //   _aute, _bett, _mbaz,
  { {0x7afa028c, 0x69da0bd7, 0x661d0046, 0x00000000}},  //   _cett, _bute, ński,
  { {0x7afa067e, 0x63700a3c, 0x2e48005e, 0x00000000}},  //   _dett, _sänk, _лято_,
  { {0x69da022b, 0x644d022b, 0x636b010f, 0x00000000}},  //   _dute, _orai, _küns,
  { {0x7d09145d, 0xb90100e8, 0x657d0065, 0x00000000}},  //   _ides, _दल_, dhsh,
  { {0x2d8f0018, 0x69da240d, 0x7afa00ab, 0x00000000}},  //   lige_, _fute, _gett,
  { {0x69da001f, 0x644d0051, 0x386d1089, 0x00000000}},  //   _gute, _arai, syer_,
  { {0x63700073, 0x2d8f001f, 0x7afa00b5, 0x00000000}},  //   _tänk, nige_, _zett,
  { {0x69da022b, 0x644d240e, 0x798b0009, 0x00000000}},  //   _zute, _crai, _imgw,
  { {0x752d002d, 0x7bdb0325, 0x644d00ab, 0x00000000}},  //   _ebaz, _muuu, _drai,
  { {0x644d0c54, 0x27ed02ae, 0x7d0900b9, 0x00000000}},  //   _erai, lpen_, _odes,
  { {0x644d028c, 0x7d090065, 0x2d8f01d9, 0x00000000}},  //   _frai, _ndes, jige_,
  { {0x42d60ee0, 0x644d240f, 0x27ed0288, 0x00000000}},  // [5d40] _міну, _grai, npen_,
  { {0x7d092410, 0xdb030211, 0x27ed2411, 0x00000000}},  //   _ades, foní, ipen_,
  { {0x7afa02cc, 0xee3a02e9, 0x2d8f0e93, 0x00000000}},  //   _rett, рне_, fige_,
  { {0x7afa0198, 0x69da2412, 0x7bc10697, 0x00000000}},  //   _sett, _rute, _ahlu,
  { {0x69da010a, 0x636b1582, 0x27ed00b5, 0x00000000}},  //   _sute, _güns, jpen_,
  { {0x69da12e9, 0x7bc12413, 0x09b40183, 0x00000000}},  //   _pute, _chlu, ुष्य,
  { {0x7e2302a8, 0x7afa0010, 0x27ed00b5, 0x00000000}},  //   _одрж, _vett, epen_,
  { {0x7afa001f, 0x63701ff7, 0xb4db00f6, 0x00000000}},  //   _wett, _däni, gdàl,
  { {0x7afa2414, 0xfc032415, 0xbdc900a1, 0x00000000}},  //   _tett, _опто, _اگلے_,
  { {0xd6da2416, 0x69da0207, 0xdb1a0181, 0x00000000}},  //   шти_, _tute, _vitó,
  { {0x657d008d, 0x644d2417, 0x69da003c, 0x00000000}},  //   thsh, _srai, _uute,
  { {0x644d0181, 0x758b007c, 0x7bdb0022, 0x00000000}},  //   _prai, рсов_, _yuuu,
  { {0xdb03004a, 0x00000000, 0x00000000, 0x00000000}},  //   zoní,   ,   ,
  { {0x644d028c, 0xe73700ed, 0x2d8f095d, 0x00000000}},  //   _vrai, _меч_, zige_,
  { {0x644d0016, 0xdce9012d, 0x44320026, 0x00000000}},  //   _wrai, _uleć, _epy_,
  { {0x59ca0204, 0xab5d0036, 0xa91d0006, 0x00000000}},  //   ागिर, _duży, sižv,
  { {0x644d1f0f, 0x2d8f2418, 0x6441001e, 0x00000000}},  // [5d50] _urai, vige_, ālis,
  { {0x2d8f0007, 0xdb030861, 0x9f49000c, 0x00000000}},  //   wige_, toní, gsað_,
  { {0x2d8f1440, 0x636b010f, 0x27ed002d, 0x00000000}},  //   tige_, _wüns, zpen_,
  { {0xb23a007b, 0xf5380049, 0x27ed0c7a, 0x00000000}},  //   _פערז, ַטור_, ypen_,
  { {0x2d8f2419, 0x7d090065, 0x515a009b, 0x00000000}},  //   rige_, _vdes, _הכרו,
  { {0x2d8f0240, 0xdb030919, 0x69c213d2, 0x00000000}},  //   sige_, poní, _ahoe,
  { {0xef230089, 0x69c200d9, 0x00000000, 0x00000000}},  //   _ceļš_, _bhoe,   ,
  { {0x7d090496, 0x9d1801fc, 0x69c20016, 0x00000000}},  //   _udes, _мост_, _choe,
  { {0x2d8d1449, 0x27ed0032, 0xafdb0056, 0x00000000}},  //   _imee_, upen_, _grøt,
  { {0x27ed241a, 0x63700039, 0x06850641, 0x00000000}},  //   rpen_, _hänv, згон,
  { {0x27ed002d, 0x3ce00b54, 0x29d10091, 0x00000000}},  //   spen_, žive_, _ušao_,
  { {0x7aba009b, 0x24820009, 0x69c20168, 0x00000000}},  //   _הצעו, tzkm_, _ghoe,
  { {0x69c9224a, 0x7d1d000c, 0x2d9f00e7, 0x00000000}},  //   mmee, _össu, _mjue_,
  { {0x3218241b, 0xe820007d, 0x00000000, 0x00000000}},  //   tury_, _ममता_,   ,
  { {0xaacb007d, 0x00000000, 0x00000000, 0x00000000}},  //   ाधिक,   ,   ,
  { {0xe0da005e, 0x69c901d6, 0xe2970b81, 0x00000000}},  //   сва_, nmee, час_,
  { {0x2167019d, 0x33382077, 0x00000000, 0x00000000}},  // [5d60] чити_, perx_,   ,
  { {0x2d9f00e7, 0x00000000, 0x00000000, 0x00000000}},  //   _ajue_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c900d9, 0x2d9f00e5, 0x00000000, 0x00000000}},  //   jmee, _cjue_,   ,
  { {0x69c2005b, 0x00000000, 0x00000000, 0x00000000}},  //   _rhoe,   ,   ,
  { {0x2b4514c7, 0xdce0001e, 0x69c200ab, 0x00000000}},  //   _calc_, _domā, _shoe,
  { {0x7c2d00fa, 0xafdb0190, 0x00000000, 0x00000000}},  //   çarr, _frøs,   ,
  { {0xd90d00e9, 0x69c912e8, 0x7c2d002b, 0x00000000}},  //   لیم_, gmee, ħarr,
  { {0xd823003b, 0xec7a0088, 0x00000000, 0x00000000}},  //   едњи, _упа_,   ,
  { {0x25a00f65, 0x69c20a6b, 0x7d02241c, 0x00000000}},  //   _ajil_, _whoe, laos,
  { {0x69c901d6, 0x00000000, 0x00000000, 0x00000000}},  //   bmee,   ,   ,
  { {0x7d020020, 0x3ce60027, 0x21220082, 0x00000000}},  //   naos, ncov_, _nckh_,
  { {0x94ab0ae0, 0x63ae013e, 0x00000000, 0x00000000}},  //   стна_, fobn,   ,
  { {0x63ae0c29, 0x7bdf06f4, 0x3946241d, 0x00000000}},  //   gobn, íqui, _haos_,
  { {0x39460390, 0x82a4098c, 0xf64f00a1, 0x00000000}},  //   _kaos_, еште, _مئي_,
  { {0x673a241e, 0xb5a4008b, 0xdb0a0039, 0x00000000}},  //   letj, _прый, llfä,
  { {0x661a241f, 0xa06800ed, 0x8c3d006b, 0x00000000}},  // [5d70] lutk, паѓа_, _oxşa,
  { {0x3946160f, 0xdb0306b8, 0x673a1aef, 0x00000000}},  //   _laos_, koná, netj,
  { {0x661a00ee, 0xb4bd006e, 0x00000000, 0x00000000}},  //   nutk, _अरु_,   ,
  { {0x8c3d006b, 0x9f490051, 0xac95007c, 0x00000000}},  //   _axşa, mpaí_, маеш,
  { {0x673a2420, 0xcb6900ec, 0xbb4516c4, 0x00000000}},  //   ketj, жале_, делк,
  { {0x673a00ca, 0x661a01a3, 0x65bd015f, 0x00000000}},  //   jetj, kutk, kého,
  { {0x673a2421, 0x69c9006c, 0x661a003f, 0x00000000}},  //   detj, tmee, jutk,
  { {0xeeeb00ad, 0x637000b0, 0x2d9f00e7, 0x00000000}},  //   _động_, _hänt, _ujue_,
  { {0xfc3001fa, 0x69c90277, 0x799b0007, 0x00000000}},  //   _محل_, rmee, rnuw,
  { {0x69c9006c, 0xeaf80014, 0x37890088, 0x00000000}},  //   smee, _فرمت_, ібно_,
  { {0xe5a6012b, 0xf1bf0061, 0x637000b0, 0x00000000}},  //   дини, ्षान, _mänt,
  { {0x2d9d2422, 0x201b0023, 0x6abe01a2, 0x00000000}},  //   nnwe_, kuqi_, üpfe,
  { {0x673a0637, 0xc3270044, 0x186900e2, 0x00000000}},  //   betj, য়নি_, _фали_,
  { {0x661a10ed, 0x81e50044, 0x291f0032, 0x00000000}},  //   butk, _নিজ_, lgua_,
  { {0x63ae047c, 0x232702dc, 0x00000000, 0x00000000}},  //   robn, ьори_,   ,
  { {0x291f081d, 0x00000000, 0x00000000, 0x00000000}},  //   ngua_,   ,   ,
  { {0x291f000a, 0x3ce60142, 0x6fd80316, 0x00000000}},  // [5d80] igua_, vcov_, _भूखं,
  { {0x2be1006e, 0x00000000, 0x00000000, 0x00000000}},  //   _पढ़ा,   ,   ,
  { {0xdb1a0010, 0x7d020c43, 0x67230085, 0x00000000}},  //   _kitö, taos, _mcnj,
  { {0x6d910161, 0xdb030010, 0x00000000, 0x00000000}},  //   sťan, voná,   ,
  { {0x67230645, 0x7d0200b0, 0xdd8f006d, 0x00000000}},  //   _ocnj, raos, جون_,
  { {0x3ce60d0a, 0x39460022, 0x6370006c, 0x00000000}},  //   scov_, _saos_, _tänu,
  { {0x63700039, 0x673a0059, 0x7d0200e0, 0x00000000}},  //   _häns, vetj, paos,
  { {0xd910007a, 0x63700039, 0xdb031c3e, 0x00000000}},  //   ایش_, _käns, roná,
  { {0xb4bd0309, 0x673a0065, 0x00000000, 0x00000000}},  //   _अरे_, tetj,   ,
  { {0x7d000073, 0x661a00b0, 0x63700039, 0x00000000}},  //   _hems, tutk, _mäns,
  { {0x637009f0, 0x39462423, 0x7d00000c, 0x00000000}},  //   _läns, _taos_, _kems,
  { {0x673a2424, 0x661a2425, 0x00000000, 0x00000000}},  //   setj, rutk,   ,
  { {0x7d0000fa, 0x661a08f8, 0x00000000, 0x00000000}},  //   _mems, sutk,   ,
  { {0x661a2426, 0xf77200a1, 0x7d000023, 0x00000000}},  //   putk, _جاؤ_, _lems,
  { {0xd848001d, 0x6595008b, 0x64442427, 0x00000000}},  //   _họ_, _паку, _esii,
  { {0x29040119, 0x200f00c4, 0x7d000232, 0x00000000}},  //   nama_, ágio_, _nems,
  { {0x03c700ed, 0x6ab90044, 0x00000000, 0x00000000}},  // [5d90] _осом, েখযো,   ,
  { {0x29040020, 0x753d0010, 0xcebb003b, 0x00000000}},  //   hama_, lesz, оље_,
  { {0x2904000b, 0x63700073, 0xd8480082, 0x00000000}},  //   kama_, _vänt, _lọ_,
  { {0x29d1004f, 0x29040213, 0x3eb80c7b, 0x00000000}},  //   _však_, jama_, _dyrt_,
  { {0x201b006b, 0xed580088, 0x7d001a92, 0x00000000}},  //   quqi_, ьої_, _dems,
  { {0x7d0000d9, 0x44290145, 0x00000000, 0x00000000}},  //   _eems, _mqa_,   ,
  { {0x628701d5, 0x2d8700f4, 0x7d0000eb, 0x00000000}},  //   nzjo, ènes_, _fems,
  { {0x29040091, 0xd8480082, 0x291f00e7, 0x00000000}},  //   gama_, _bọ_, ugua_,
  { {0xb4ae0067, 0xc7951001, 0x753d115b, 0x00000000}},  //   _कडे_, ерны, desz,
  { {0x6d4b02e7, 0x6d490016, 0x7d000387, 0x00000000}},  //   ldga, _haea, _zems,
  { {0x290418a7, 0x7de50006, 0x00000000, 0x00000000}},  //   bama_, _mėso,   ,
  { {0xc32900b6, 0x29040119, 0x753d1297, 0x00000000}},  //   _לו_, cama_, gesz,
  { {0x7c2b0129, 0x200f0285, 0x6d4900e0, 0x00000000}},  //   ntgr, ágil_, _maea,
  { {0x68e9008e, 0x6b830011, 0x76430022, 0x00000000}},  //   lced, nhng, _tsny,
  { {0x69d900e7, 0x753d0010, 0x069400a1, 0x00000000}},  //   _kiwe, besz, _لاٹھ,
  { {0x68e91f5b, 0x69d900e7, 0x4fea00e2, 0x00000000}},  //   nced, _jiwe, зман_,
  { {0x7d000c4c, 0x644400e7, 0x69d90146, 0x00000000}},  // [5da0] _rems, _usii, _miwe,
  { {0x29040a6e, 0x63700039, 0x7d00000c, 0x00000000}},  //   zama_, _väns, _sems,
  { {0x29040453, 0x200904cb, 0x27760049, 0x00000000}},  //   yama_, asai_, עגען_,
  { {0x69d92428, 0x2ac600b9, 0xfce6007c, 0x00000000}},  //   _niwe, _líbí_, ходо,
  { {0x29040091, 0x4f3400a1, 0x320a0c2d, 0x00000000}},  //   vama_, _لڑائ, lsby_,
  { {0x753d0036, 0x290400f0, 0x6d491e59, 0x00000000}},  //   zesz, wama_, _eaea,
  { {0x29041be1, 0x3ebe009f, 0x81e20055, 0x00000000}},  //   tama_, _átt_, নীর_,
  { {0x6d490016, 0xb4db00f6, 0x00000000, 0x00000000}},  //   _gaea, ldàv,   ,
  { {0x62870f68, 0x69d9018e, 0x753d0010, 0x00000000}},  //   zzjo, _diwe, vesz,
  { {0x2904006a, 0x6d620107, 0x69d901a2, 0x00000000}},  //   sama_, štač, _eiwe,
  { {0x29042429, 0x753d0010, 0x00000000, 0x00000000}},  //   pama_, tesz,   ,
  { {0x442b001c, 0x68e90207, 0x7bda023a, 0x00000000}},  //   ttc_, cced, _hitu,
  { {0x753d0047, 0x7bda242a, 0x321800f4, 0x00000000}},  //   resz, _kitu, erry_,
  { {0x442b01c5, 0x644f0089, 0x69d900e7, 0x00000000}},  //   rtc_, rvci, _ziwe,
  { {0x7bda0bd5, 0x320a00f8, 0x4789007e, 0x00000000}},  //   _mitu, gsby_, _ўсім_,
  { {0xb6bb00b6, 0x61d80783, 0x05770379, 0x00000000}},  //   _מצוי, емся_, _ساعد,
  { {0x7c2b0c3f, 0x2009007f, 0x00000000, 0x00000000}},  // [5db0] xtgr, usai_,   ,
  { {0xa309026c, 0x2009010a, 0x7bda002d, 0x00000000}},  //   _کرکے_, rsai_, _nitu,
  { {0x20090232, 0xe71700b3, 0xcfa400e2, 0x00000000}},  //   ssai_, תחבר_, ушти,
  { {0x5c7500c0, 0x7c2b0635, 0x7bda0bb2, 0x00000000}},  //   клет, ttgr, _aitu,
  { {0x8c450057, 0x7bda011c, 0x6d4b0116, 0x00000000}},  //   теле, _bitu, rdga,
  { {0x7bda0dec, 0x9f94010f, 0x69d90020, 0x00000000}},  //   _citu, mäß_, _siwe,
  { {0x7bda0756, 0x7c2b0129, 0x3da7008b, 0x00000000}},  //   _ditu, stgr, _зраб,
  { {0x7bda242b, 0x00000000, 0x00000000, 0x00000000}},  //   _eitu,   ,   ,
  { {0x7bda242c, 0xf7710137, 0xdb030961, 0x00000000}},  //   _fitu, لاد_, tonä,
  { {0x7bda188a, 0xd5b90089, 0x1a6500a1, 0x00000000}},  //   _gitu, ktās_, _لیتی_,
  { {0xcfe80044, 0xab840783, 0x6721242d, 0x00000000}},  //   _পিছন, _сутк, rglj,
  { {0xa3e602fb, 0x7bda022b, 0x7bc80065, 0x00000000}},  //   _बंद_, _zitu, _zhdu,
  { {0xe81803d7, 0x394d0a74, 0x00000000, 0x00000000}},  //   _दिया_, mdes_,   ,
  { {0xc88301f6, 0x394d1a3a, 0x97240076, 0x00000000}},  //   ığı_, ldes_, _مفهو,
  { {0x69dc0010, 0x00000000, 0x00000000, 0x00000000}},  //   _éret,   ,   ,
  { {0x320a00f8, 0x00000000, 0x00000000, 0x00000000}},  //   rsby_,   ,   ,
  { {0x394d0089, 0xdb1a00b0, 0xd0070aed, 0x00000000}},  // [5dc0] ides_, _yhtä, кете_,
  { {0xef1700ed, 0xd5b90089, 0x13a80014, 0x00000000}},  //   кму_, stāt_, _سنجی_,
  { {0x7bda0b25, 0x394d0022, 0x00000000, 0x00000000}},  //   _ritu, kdes_,   ,
  { {0x6b81001f, 0x394d242e, 0xdb0a0056, 0x00000000}},  //   _allg, jdes_, llfø,
  { {0x3d07001c, 0x7bda00b0, 0x394d0039, 0x00000000}},  //   हणजे_, _pitu, ddes_,
  { {0xdee6012b, 0x394d01c5, 0x00000000, 0x00000000}},  //   _јови, edes_,   ,
  { {0x7bda242f, 0x79a60893, 0x394d0007, 0x00000000}},  //   _vitu, крие, fdes_,
  { {0x2902000c, 0x394d04d1, 0x00000000, 0x00000000}},  //   úka_, gdes_,   ,
  { {0xebe601fb, 0xa3b20164, 0x57b40478, 0x00000000}},  //   _розп, टका_, лбит,
  { {0x394d0129, 0x00000000, 0x00000000, 0x00000000}},  //   ades_,   ,   ,
  { {0xf53f0039, 0x6ad00044, 0xb763007e, 0x00000000}},  //   teå_, _স্রো, ртый,
  { {0xceb300b6, 0xd946012b, 0x9f420023, 0x00000000}},  //   יית_, _једи, _bukë_,
  { {0x48130088, 0x64560133, 0x89d70014, 0x00000000}},  //   _вміс, _cryi, _شوهر_,
  { {0x64560133, 0x00000000, 0x00000000, 0x00000000}},  //   _dryi,   ,   ,
  { {0xdcfb0119, 0x79820173, 0xd5b90089, 0x00000000}},  //   _sluč, _klow, utās_,
  { {0xc6d90049, 0xd5b90089, 0x00000000, 0x00000000}},  //   _אַפר, rtās_,   ,
  { {0xd5b90089, 0x2d8600d9, 0x636b01a2, 0x00000000}},  // [5dd0] stās_, dhoe_, _münz,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x394d0030, 0x645a0089, 0x79820146, 0x00000000}},  //   ydes_, ātie, _olow,
  { {0x63b50107, 0xd25600a0, 0x96240044, 0x00000000}},  //   lozn, _עשרה_, _বনাম_,
  { {0xe4ff00b9, 0x394d00f8, 0x00000000, 0x00000000}},  //   _štěň, vdes_,   ,
  { {0x447c0049, 0x399a0089, 0x1a2910dc, 0x00000000}},  //   ונדע, zīst_, ежки_,
  { {0x61e500b0, 0x79820339, 0x00000000, 0x00000000}},  //   _juhl, _blow,   ,
  { {0x394d2430, 0x2b4c0009, 0x63b50010, 0x00000000}},  //   udes_, _eadc_, hozn,
  { {0x63b50010, 0x66e50930, 0x00000000, 0x00000000}},  //   kozn, лопа,   ,
  { {0x394d0b36, 0x7c3b2431, 0x79820022, 0x00000000}},  //   sdes_, _ipur, _elow,
  { {0xf771007a, 0x63b5037e, 0x798200ab, 0x00000000}},  //   لاگ_, dozn, _flow,
  { {0x78a4037a, 0x7a7a0049, 0xda7a0049, 0x00000000}},  //   _žive, _ארעס, _אנער,
  { {0x68fb04d4, 0x1b060044, 0x81ac0044, 0x00000000}},  //   mbud, _রাতে_, গতম_,
  { {0x68fb0637, 0x289a0049, 0x636b014a, 0x00000000}},  //   lbud, _אינא, _küny,
  { {0xafdb00ea, 0xdb0a0325, 0x00000000, 0x00000000}},  //   _esøk, nofá,   ,
  { {0x645600ab, 0x68fb0093, 0x7c3b00e0, 0x00000000}},  //   _tryi, nbud, _opur,
  { {0xefca007c, 0x7dda00b9, 0x7d04000c, 0x00000000}},  // [5de0] елал_, _důsl, ðism,
  { {0x44220390, 0x7dda00b9, 0x7dec013f, 0x00000000}},  //   muk_, _půso, _ağsa,
  { {0x442215df, 0x7c3b1983, 0x7e56007e, 0x00000000}},  //   luk_, _apur, ытац,
  { {0xac0a007c, 0x2b4c00e7, 0x3f830066, 0x00000000}},  //   енда_, _sadc_, _elju_,
  { {0xdca3003b, 0x44222432, 0x68fb0059, 0x00000000}},  //   баци, nuk_, dbud,
  { {0xdee3005e, 0x636b005a, 0x0eba0641, 0x00000000}},  //   _гори, _büny, _зубы_,
  { {0xb4db0129, 0x7ed50088, 0x7c3b2433, 0x00000000}},  //   ndàr, _вітч, _epur,
  { {0x636b038c, 0x44220357, 0xd7fa003b, 0x00000000}},  //   _düny, kuk_, нуо_,
  { {0x44221211, 0xc1730104, 0xba180014, 0x00000000}},  //   juk_, מחה_, ريکا_,
  { {0x44220149, 0x9f400b32, 0x3f9a003f, 0x00000000}},  //   duk_, mpió_, nipu_,
  { {0x63b5018b, 0x06d70055, 0x3ce901d9, 0x00000000}},  //   vozn, _দ্বি, žave_,
  { {0x61e50279, 0x44220062, 0x6d420032, 0x00000000}},  //   _ruhl, fuk_, neoa,
  { {0xa877031d, 0x44222434, 0x7c220052, 0x00000000}},  //   _محور_, guk_, nuor,
  { {0xb8650167, 0x69cb0065, 0x69c02435, 0x00000000}},  //   _خامو, _zhge, llme,
  { {0x63b511b7, 0xd5bb2436, 0x27e600e5, 0x00000000}},  //   rozn, _пси_, _huon_,
  { {0x44220085, 0xeeeb0011, 0x50f50893, 0x00000000}},  //   buk_, _đống_, рзат,
  { {0x63b50119, 0x44222437, 0x6d420347, 0x00000000}},  // [5df0] pozn, cuk_, deoa,
  { {0x27e60011, 0x68fb1091, 0x2d840026, 0x00000000}},  //   _muon_, zbud, _alme_,
  { {0x4fc41001, 0x68fb0016, 0x7c3b124c, 0x00000000}},  //   сста, ybud, _spur,
  { {0x7147004c, 0x7c220026, 0x69c02438, 0x00000000}},  //   _схож, fuor, jlme,
  { {0x27e62439, 0x7c220026, 0xab29243a, 0x00000000}},  //   _nuon_, guor, вола_,
  { {0xaa15025f, 0x447c0049, 0xab62005d, 0x00000000}},  //   афиј, ענגע, şünm,
  { {0x4422002d, 0x68fb1a85, 0x25a9004a, 0x00000000}},  //   zuk_, tbud, _ojal_,
  { {0x27e60207, 0x4422049d, 0xfaf80089, 0x00000000}},  //   _buon_, yuk_, _vnīa_,
  { {0x778500da, 0x4b270084, 0x7d0b011c, 0x00000000}},  //   илиз, _معاف, mags,
  { {0x7d0b009f, 0x6c840054, 0x78a40209, 0x00000000}},  //   lags, _الكم, _živc,
  { {0x39150167, 0x44220093, 0xc796009e, 0x00000000}},  //   _نواز, wuk_, جھنا_,
  { {0x44220149, 0x7d0b011c, 0x38600091, 0x00000000}},  //   tuk_, nags, _šire_,
  { {0x25a90023, 0x660b007f, 0x00000000, 0x00000000}},  //   _djal_, _šokė,   ,
  { {0x68e20305, 0x4422020c, 0x7d0b000c, 0x00000000}},  //   _zgod, ruk_, hags,
  { {0xd19601f9, 0x4422020c, 0x25a90065, 0x00000000}},  //   ашањ, suk_, _fjal_,
  { {0x44220169, 0x394f01d6, 0x27e600e0, 0x00000000}},  //   puk_, _jags_, _yuon_,
  { {0x55bb00b6, 0x394f00d4, 0x7d0b141a, 0x00000000}},  // [5e00] _במקו, _mags_, dags,
  { {0x7c2200b0, 0xa3ba0647, 0x00000000, 0x00000000}},  //   vuor, _جابر_,   ,
  { {0xcd060fa0, 0xdcfb0066, 0x00000000, 0x00000000}},  //   ачли, _xjuħ,   ,
  { {0x1636007b, 0x3dcd0784, 0x7c221449, 0x00000000}},  //   ינער_, _chew_, tuor,
  { {0xcb6a00ed, 0x6c54026b, 0xdca6243b, 0x00000000}},  //   каде_, склу, шади,
  { {0xe45701ce, 0x6d420e3a, 0x7c22002d, 0x00000000}},  //   יינט_, seoa, ruor,
  { {0x80db0055, 0xbea30545, 0x7d0b011c, 0x00000000}},  //   যুদ্, _дарк, bags,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xab660a30, 0x394f03ed, 0xad1b0104, 0x00000000}},  //   _квал, _dags_, _שומר,
  { {0x1037009b, 0x27e60082, 0x00000000, 0x00000000}},  //   סטים_, _vuon_,   ,
  { {0x9a6a00f9, 0x394f243c, 0x0f57009b, 0x00000000}},  //   _جمال_, _fags_, ביים_,
  { {0xd5b801fb, 0x68e20627, 0x27e600b0, 0x00000000}},  //   ися_, _ugod, _tuon_,
  { {0x0f110044, 0x28d2007d, 0x00000000, 0x00000000}},  //   স্টঃ_, देशि,   ,
  { {0xf7430153, 0x394401c5, 0x00000000, 0x00000000}},  //   _мечо, lems_,   ,
  { {0xdce000b9, 0x56930816, 0x41e70088, 0x00000000}},  //   _pomě, _машт, ріга,
  { {0x3f980697, 0x3944007f, 0x26db009b, 0x00000000}},  //   _amru_, nems_, _בקומ,
  { {0x752d006b, 0xc31c0044, 0x0f1501e1, 0x00000000}},  // [5e10] _icaz, দ্ধি_, ймаю,
  { {0x7d1d0047, 0xeeeb00ad, 0x644d0058, 0x00000000}},  //   _össz, _đồng_, _isai,
  { {0x7d0b0a5d, 0xdfd8005e, 0xe3b00257, 0x00000000}},  //   tags, рът_, _تري_,
  { {0xb6d90049, 0x644d0022, 0x8d740379, 0x00000000}},  //   אַנט, _ksai, يانا,
  { {0x394400bb, 0xa3ae006e, 0x7d0b0304, 0x00000000}},  //   dems_, _कदम_, rags,
  { {0x7f850054, 0xdb0300f4, 0x3dcd243d, 0x00000000}},  //   _السن, onné, _whew_,
  { {0x752d001a, 0x394f008e, 0x7d0b011c, 0x00000000}},  //   _ocaz, _pags_, pags,
  { {0x78a401d9, 0x21290149, 0xe818007d, 0x00000000}},  //   _živa, ngah_, _दिशा_,
  { {0x798918b7, 0x2d9d047b, 0x74220044, 0x00000000}},  //   rhew, miwe_, _ফন্ট_,
  { {0xab740054, 0x9b740054, 0x2d9d0e74, 0x00000000}},  //   _والإ, _والص, liwe_,
  { {0xd90f009c, 0xf1c7007d, 0x7d0901a3, 0x00000000}},  //   _ہیں_, लतान, _kees,
  { {0xaca30011, 0x7bc304f2, 0x7d09003c, 0x00000000}},  //   _ngừn, llnu, _jees,
  { {0x7d09243e, 0x3f810093, 0xe7391abd, 0x00000000}},  //   _mees, kkhu_, _бел_,
  { {0x7d0901b5, 0xafdb00ea, 0xd8d600b3, 0x00000000}},  //   _lees, _trøy, _פוסט_,
  { {0xa2bb0164, 0x15f501f7, 0x27ed0065, 0x00000000}},  //   _शुद्, _استح, lqen_,
  { {0x7d09001e, 0x21290173, 0x2d9d00e7, 0x00000000}},  //   _nees, ggah_, jiwe_,
  { {0xa0670113, 0xa3d8007d, 0x6564011c, 0x00000000}},  // [5e20] бата_, िषद_, _inih,
  { {0xdfcf0379, 0x00000000, 0x00000000, 0x00000000}},  //   فيق_,   ,   ,
  { {0x65640428, 0x7d0900c7, 0xa91d0006, 0x00000000}},  //   _knih, _bees, sižy,
  { {0xe818024c, 0x10a6003b, 0x2d9d0117, 0x00000000}},  //   _दिला_, _гимн, giwe_,
  { {0x7d090007, 0xe3bf0211, 0xdca30517, 0x00000000}},  //   _dees, luña_, паци,
  { {0xdd920167, 0x543b0049, 0xe9f80451, 0x00000000}},  //   _کور_, רעסא, анкі_,
  { {0x3ce90295, 0x7d0901b5, 0x8e860025, 0x00000000}},  //   žava_, _fees, _الأه,
  { {0x7d0906b2, 0x2d9d04c4, 0x57f4005c, 0x00000000}},  //   _gees, ciwe_, опит,
  { {0x39441a35, 0xdb180023, 0x4c86004d, 0x00000000}},  //   rems_, novë, _улав,
  { {0x5eab0044, 0x752d001a, 0xd90c00a1, 0x00000000}},  //   _করতে, _scaz, ریڈ_,
  { {0x6ac60318, 0x657602d4, 0xe3bf004a, 0x00000000}},  //   _اقام, _boyh, juña_,
  { {0x26c20089, 0x6576004a, 0xdb180023, 0x00000000}},  //   āko_, _coyh, kovë,
  { {0x32110036, 0xd49b00e2, 0x00000000, 0x00000000}},  //   wszy_, урн_,   ,
  { {0xf41f00b0, 0x2d9d0036, 0x00000000, 0x00000000}},  //   rrä_, ziwe_,   ,
  { {0x1b7b0049, 0x43940072, 0x00000000, 0x00000000}},  //   נטלע, чарс,   ,
  { {0x35a400e1, 0x60f90783, 0x32110036, 0x00000000}},  //   _најг, рная_, rszy_,
  { {0x7d0900d6, 0x644d2367, 0xdb180023, 0x00000000}},  // [5e30] _rees, _usai, govë,
  { {0x7d09006c, 0x32110036, 0x9f40000c, 0x00000000}},  //   _sees, pszy_, upið_,
  { {0x9f40000c, 0xf3eb0044, 0x2d9d047b, 0x00000000}},  //   rpið_, _কবির_, tiwe_,
  { {0xa159243f, 0x05c9007d, 0xeeeb0082, 0x00000000}},  //   _таму_, रतिब, _đổng_,
  { {0x2d9d0cd1, 0x78a40161, 0x7d09006c, 0x00000000}},  //   riwe_, _živn, _vees,
  { {0x7d090112, 0x2d9d0020, 0x00000000, 0x00000000}},  //   _wees, siwe_,   ,
  { {0x7d092440, 0x00000000, 0x00000000, 0x00000000}},  //   _tees,   ,   ,
  { {0xa3e90201, 0x09e201e0, 0x7de50006, 0x00000000}},  //   यदा_, мощн, _dėst,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbca4057d, 0x00000000, 0x00000000, 0x00000000}},  //   _عملي,   ,   ,
  { {0x2b472044, 0x65bd01dc, 0x05aa007c, 0x00000000}},  //   menc_, véhr, ивой_,
  { {0xe8210061, 0x959603e8, 0x2b471686, 0x00000000}},  //   _मिपा_, ішні, lenc_,
  { {0x98c70054, 0x2ec6007d, 0x00000000, 0x00000000}},  //   _اغان, _वर्त,   ,
  { {0xd3ba0088, 0x2b4700d4, 0x7e7e0052, 0x00000000}},  //   румі_, nenc_, yypp,
  { {0xe7960014, 0x2b4700f6, 0x00000000, 0x00000000}},  //   _بانک, ienc_,   ,
  { {0xe3bf0c34, 0x649a00ed, 0x65c3022a, 0x00000000}},  //   ruña_, _втор_, _обща,
  { {0x387f04be, 0x00000000, 0x00000000, 0x00000000}},  // [5e40] nyur_,   ,   ,
  { {0xbc6a00a6, 0x386d00f6, 0x00000000, 0x00000000}},  //   یمان_, ixer_,   ,
  { {0xdb18008d, 0x2b472044, 0x63bc016e, 0x00000000}},  //   sovë, denc_, morn,
  { {0x63bc22a5, 0x302a004c, 0xa63a0049, 0x00000000}},  //   lorn, _комп_, יגער,
  { {0xdb181539, 0x973c0091, 0x00000000, 0x00000000}},  //   lové, liće,   ,
  { {0x63bc00f8, 0xdb97007e, 0x5fc50061, 0x00000000}},  //   norn, овіч_, वतःल,
  { {0xdb182441, 0x973c04eb, 0xdd920257, 0x00000000}},  //   nové, niće, _قوس_,
  { {0x63bc000c, 0xdb030ef2, 0x00000000, 0x00000000}},  //   horn, fonó,   ,
  { {0x7d02008a, 0xd90d0014, 0xdb030253, 0x00000000}},  //   mbos, ایه_, gonó,
  { {0x3dc60038, 0xdb1801ca, 0x63bc2442, 0x00000000}},  //   llow_, kové, jorn,
  { {0x63bc0039, 0x2956005e, 0x00000000, 0x00000000}},  //   dorn, _мъдр,   ,
  { {0x973c0107, 0x7d0201bb, 0xdb180161, 0x00000000}},  //   diće, nbos, dové,
  { {0x63bc00ab, 0x3dc600e0, 0x27f80014, 0x00000000}},  //   forn, ilow_, _افتد_,
  { {0x63bc0039, 0x00000000, 0x00000000, 0x00000000}},  //   gorn,   ,   ,
  { {0x44220056, 0x00000000, 0x00000000, 0x00000000}},  //   ark_,   ,   ,
  { {0xdb180039, 0x3f8a2443, 0x35f703ec, 0x00000000}},  //   llvä, _albu_, _برود_,
  { {0x63bc0428, 0x6aa601f5, 0x00000000, 0x00000000}},  // [5e50] born, गपुर,   ,
  { {0x973c0107, 0x24840637, 0xa3b70061, 0x00000000}},  //   biće, ømme_, जवळ_,
  { {0x78a401d9, 0xdea1026c, 0xc3320097, 0x00000000}},  //   _živl, ریری, _אוי_,
  { {0xf1a7007e, 0x7c2201a2, 0x00000000, 0x00000000}},  //   _фрон, fror,   ,
  { {0xdfdb0265, 0xe3b001ef, 0x661d0046, 0x00000000}},  //   _във_, _سری_, ąski,
  { {0x9f430065, 0x92bf0044, 0x50da009b, 0x00000000}},  //   _mijë_, েশী_, _לקרא,
  { {0x2b470010, 0x7d02001b, 0x31791072, 0x00000000}},  //   renc_, bbos, _kosz_,
  { {0xdb032444, 0x63bc0428, 0x386d0129, 0x00000000}},  //   tonó, zorn, txer_,
  { {0x7c2200c4, 0xdb180062, 0x00000000, 0x00000000}},  //   cror, zové,   ,
  { {0xdb032445, 0x6a6701b7, 0x00000000, 0x00000000}},  //   ronó, _وطال,   ,
  { {0x63bc00ee, 0x98ab005a, 0xa2bb006e, 0x00000000}},  //   vorn, ıcı_, _शुल्,
  { {0x973c037e, 0x7c240051, 0xdb030051, 0x00000000}},  //   viće, áirg, inní,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27ff206c, 0x4422130e, 0xdb180161, 0x00000000}},  //   mpun_, rrk_, tové,
  { {0x7d1b0091, 0x63bc0039, 0x7d022446, 0x00000000}},  //   _odus, rorn, ybos,
  { {0x63bc00f8, 0x31660553, 0xdb180161, 0x00000000}},  //   sorn, ñoz_, rové,
  { {0x53a6007c, 0x1423007e, 0xa0671281, 0x00000000}},  // [5e60] _наиб, _здым, пата_,
  { {0x7d1b001a, 0xdb0a0039, 0x7c220328, 0x00000000}},  //   _adus, llfö, vror,
  { {0xee3a012d, 0xdd8f00a2, 0x8a590089, 0x00000000}},  //   сне_, گون_, šējā,
  { {0x7c220307, 0xdd990088, 0x932500a1, 0x00000000}},  //   tror, оші_, _ٹرین,
  { {0x7d020181, 0xdd8f0380, 0x7c22109a, 0x00000000}},  //   rbos, دون_, uror,
  { {0x7d1b00b0, 0x69dc0010, 0x7d0213ea, 0x00000000}},  //   _edus, _érez, sbos,
  { {0xdb030129, 0xed5a08fc, 0x00000000, 0x00000000}},  //   tonò, _лов_,   ,
  { {0x7bc100f8, 0x7c22129e, 0x645a0089, 0x00000000}},  //   _eklu, pror, ātij,
  { {0x61e6009f, 0xdb032447, 0x7dda013e, 0x00000000}},  //   _mikl, ronò, _důst,
  { {0x1b0f0055, 0xdcfb0166, 0x9ac30009, 0x00000000}},  //   _সাথে_, _pluć, ŋŋaa,
  { {0xb34700c4, 0x7bdf009d, 0x7c240006, 0x00000000}},  //   _liçõ, ïque, šird,
  { {0xb7d7026c, 0x61e6083f, 0xc7b90010, 0x00000000}},  //   _ہونا_, _nikl, lről_,
  { {0x6fbe0164, 0x00000000, 0x00000000, 0x00000000}},  //   ्तां,   ,   ,
  { {0x7dda00b9, 0x9f430065, 0x466a005e, 0x00000000}},  //   _zůst, _vijë_, _грим_,
  { {0x6d400107, 0x200704eb, 0x00000000, 0x00000000}},  //   _obma, ćnim_,   ,
  { {0x5eab0055, 0x31c400ed, 0x59dc0061, 0x00000000}},  //   _করলে, есув, मगिर,
  { {0x92bf0055, 0x78a40bd9, 0x61e6023a, 0x00000000}},  // [5e70] েশে_, _živj, _dikl,
  { {0x44390089, 0x7dca000c, 0x442b0e98, 0x00000000}},  //   mts_, sýsl, muc_,
  { {0x443903db, 0xa195007e, 0x59dc01f5, 0x00000000}},  //   lts_, _жанч, मगार,
  { {0x7bc10a14, 0x7d1b0066, 0x00000000, 0x00000000}},  //   _sklu, _qdus,   ,
  { {0x4439028a, 0x657d0065, 0x442b0095, 0x00000000}},  //   nts_, ërhy, nuc_,
  { {0x44392448, 0x61e6002d, 0xbb42005e, 0x00000000}},  //   its_, _zikl, вешк,
  { {0x4439192b, 0x1b060044, 0xdce8014a, 0x00000000}},  //   hts_, _রাখে_, _çoğa,
  { {0x4439001e, 0x9f4301aa, 0xe818013d, 0x00000000}},  //   kts_, _sijè_, _दिखा_,
  { {0x6d4b04cb, 0x4439002b, 0x27ff04cb, 0x00000000}},  //   mega, jts_, upun_,
  { {0x442b0bc0, 0x443902e7, 0x27ff01a3, 0x00000000}},  //   duc_, dts_, rpun_,
  { {0x27ff175f, 0x442b009d, 0x25a2016e, 0x00000000}},  //   spun_, euc_, tikl_,
  { {0x6d4b2449, 0x6d59010f, 0x443900ab, 0x00000000}},  //   nega, ndwa, fts_,
  { {0x61e601d5, 0x7c2b244a, 0x44391120, 0x00000000}},  //   _rikl, nugr, gts_,
  { {0x69c9021e, 0x61e61987, 0x6d4b00c4, 0x00000000}},  //   llee, _sikl, hega,
  { {0x0caa03d7, 0x6d4b00ea, 0x44390f12, 0x00000000}},  //   _कश्म, kega, ats_,
  { {0x6d4b244b, 0x27e70c8d, 0x69c9002d, 0x00000000}},  //   jega, _hinn_, nlee,
  { {0x44390038, 0x6d4b0016, 0x69c9002d, 0x00000000}},  // [5e80] cts_, dega, ilee,
  { {0x6d590190, 0x78a41c3a, 0x290f20fc, 0x00000000}},  //   edwa, _živk, _lega_,
  { {0x27e7244c, 0x61e6014a, 0x27ef0039, 0x00000000}},  //   _minn_, _tikl, _lugn_,
  { {0x27e7244d, 0x3ea7002a, 0x6d4b22d8, 0x00000000}},  //   _linn_, únta_, gega,
  { {0x69c901c3, 0xc7b90010, 0x25a0010e, 0x00000000}},  //   dlee, tről_, _mmil_,
  { {0x290f0004, 0xaa58244e, 0x69c2244f, 0x00000000}},  //   _aega_, зику_, _skoe,
  { {0x6d4b0079, 0x6da60175, 0x69c90168, 0x00000000}},  //   bega, _жива, flee,
  { {0x2d8d011c, 0xd90d00a6, 0x6d4b1b00, 0x00000000}},  //   _glee_, میم_, cega,
  { {0x274a0057, 0x290f000a, 0x6da30072, 0x00000000}},  //   очно_, _dega_, _рита,
  { {0x27e7002a, 0xf69806e3, 0x80db0044, 0x00000000}},  //   _cinn_, звој_, যুক্,
  { {0x69c90b20, 0xdce0001e, 0xe5351734, 0x00000000}},  //   blee, _tomē, нень,
  { {0x7bca0c0d, 0x27e7009f, 0x443901a6, 0x00000000}},  //   llfu, _einn_, tts_,
  { {0x443908f7, 0x27e70056, 0x200711af, 0x00000000}},  //   uts_, _finn_, ćnik_,
  { {0x25a01a3d, 0xf8ad00a1, 0x27e704a5, 0x00000000}},  //   _emil_, _چکی_, _ginn_,
  { {0x44391da6, 0xeb91007b, 0x26c70740, 0x00000000}},  //   sts_, אָן_, _gyno_,
  { {0x69c00f12, 0x44390339, 0xd5b90089, 0x00000000}},  //   nome, pts_, irāk_,
  { {0x6d4b049a, 0x4fd500d7, 0x9099005e, 0x00000000}},  // [5e90] vega, ежат, чват_,
  { {0x32550793, 0x69c9002d, 0x2d8d123b, 0x00000000}},  //   _звор, zlee, _slee_,
  { {0x6d4b0016, 0x6fcb01a2, 0x69c90943, 0x00000000}},  //   tega, lück, ylee,
  { {0x69c00036, 0x00000000, 0x00000000, 0x00000000}},  //   jome,   ,   ,
  { {0x69c0066e, 0x6d4b0219, 0x290f0145, 0x00000000}},  //   dome, rega, _rega_,
  { {0x6d4b0059, 0x290f010e, 0x7c2b046a, 0x00000000}},  //   sega, _sega_, rugr,
  { {0x290f029d, 0x69c900c7, 0x6d4b04d4, 0x00000000}},  //   _pega_, tlee, pega,
  { {0x27e7009f, 0x69c02450, 0x26c701d6, 0x00000000}},  //   _sinn_, gome, _ryno_,
  { {0x290f16b9, 0x69c90168, 0xb7bd001a, 0x00000000}},  //   _vega_, rlee, luţi,
  { {0x69c9022b, 0xe739003b, 0x25a0068f, 0x00000000}},  //   slee, чео_, _smil_,
  { {0x290f01d9, 0x27e71ce3, 0xaa950025, 0x00000000}},  //   _tega_, _vinn_, _ثلاث,
  { {0x69c02451, 0x6a53005f, 0xceb200a0, 0x00000000}},  //   come, _nəfə, ריט_,
  { {0x394d0004, 0x61fe016c, 0x27e72452, 0x00000000}},  //   mees_, _stpl, _tinn_,
  { {0x394d0343, 0x33d50245, 0x987a0049, 0x00000000}},  //   lees_, віст, _מאנט,
  { {0x3243007c, 0x61460930, 0x00000000, 0x00000000}},  //   лерг, нева,   ,
  { {0x394d0007, 0x78a40340, 0x6a53006b, 0x00000000}},  //   nees_, _živi, _cəfə,
  { {0xf992007b, 0xe3b201ef, 0x8c9f013d, 0x00000000}},  // [5ea0] ארן_, _مرد_, _खेलो,
  { {0xa2bb02fb, 0x6fb60025, 0x69c000e7, 0x00000000}},  //   _शुक्, رمضا, zome,
  { {0xdb0301aa, 0xd3370104, 0x7dca000c, 0x00000000}},  //   minè, _אריה_, lýsi,
  { {0xdb0300f6, 0x00000000, 0x00000000, 0x00000000}},  //   linè,   ,   ,
  { {0x8ba6005e, 0x6fcb01a2, 0x7dec013f, 0x00000000}},  //   нидж, küch, _ağst,
  { {0x69c00e9e, 0xdb1801dc, 0xb7bd001a, 0x00000000}},  //   wome, poví, buţi,
  { {0x394d0007, 0xc33301ce, 0x1c1c006e, 0x00000000}},  //   fees_, אוו_, _निकल_,
  { {0x394d0436, 0x00000000, 0x00000000, 0x00000000}},  //   gees_,   ,   ,
  { {0xdcef0091, 0x57a600e3, 0x00000000, 0x00000000}},  //   _šeće, ешна,   ,
  { {0x69c0238d, 0x5a9600ed, 0x65ab00b0, 0x00000000}},  //   some, _преф, köhä,
  { {0x69c00a14, 0x394d01c3, 0x6456003f, 0x00000000}},  //   pome, bees_, _asyi,
  { {0xceb300b6, 0x394d0145, 0x6fcb01a2, 0x00000000}},  //   טית_, cees_, tück,
  { {0x6fcb010f, 0x1754237a, 0xa3bd013d, 0x00000000}},  //   büch, _авля, इकल_,
  { {0x6a53005f, 0x6fcb001f, 0xdb030023, 0x00000000}},  //   _səfə, rück, vinë,
  { {0x0d1001f5, 0x21670216, 0xf7730049, 0x00000000}},  //   ाराष_, нтаг, _תקצ_,
  { {0xdb030065, 0x3ce90e3b, 0xf1a401e1, 0x00000000}},  //   tinë, žavi_, грун,
  { {0x656d09bd, 0xd6df00b4, 0x00000000, 0x00000000}},  // [5eb0] _inah, ąłem_,   ,
  { {0xb7bd001a, 0xdb030023, 0x00000000, 0x00000000}},  //   tuţi, rinë,   ,
  { {0x1b0f0055, 0xa2950245, 0x394d00ab, 0x00000000}},  //   _সালে_, _рані, yees_,
  { {0xe82103d7, 0xdb032453, 0x63a710ae, 0x00000000}},  //   _मिला_, miné, lijn,
  { {0x2fd90025, 0xd116009b, 0x394d14ac, 0x00000000}},  //   _يوجد_, _בקרה_, vees_,
  { {0x394d0007, 0x63a71dff, 0xc4d400a3, 0x00000000}},  //   wees_, nijn, נגס_,
  { {0xbd0500f4, 0x00000000, 0x00000000, 0x00000000}},  //   _créé,   ,   ,
  { {0x63a700b5, 0x7c2411cc, 0x00000000, 0x00000000}},  //   hijn, šira,   ,
  { {0x79890093, 0x394d0133, 0x6fcb01a2, 0x00000000}},  //   rkew, rees_, tüch,
  { {0xfd4d001d, 0x656d1102, 0x6f170061, 0x00000000}},  //   _ngoạ, _anah, naxc,
  { {0x394d2157, 0x6d5b0103, 0x6fcb010f, 0x00000000}},  //   pees_, _kaua, rüch,
  { {0x7bc32005, 0x81b60044, 0xdb032454, 0x00000000}},  //   lonu, _চীন_, diné,
  { {0x6d5b000b, 0x399a007b, 0xdb181580, 0x00000000}},  //   _maua, _קינד, lová,
  { {0x6d5b2455, 0x7bc30052, 0x8c130044, 0x00000000}},  //   _laua, nonu, _সমান_,
  { {0xdb1800b9, 0x45d60478, 0x7dd81122, 0x00000000}},  //   nová, _ицит, líse,
  { {0x38600825, 0xfe7200a6, 0x6d5b19be, 0x00000000}},  //   _širi_, یدا_, _naua,
  { {0xdb1801ca, 0x7bc31091, 0x91e30264, 0x00000000}},  // [5ec0] hová, konu, роте,
  { {0xe0d7012b, 0xcfb50055, 0xdb1800b9, 0x00000000}},  //   тву_, _জীবন, ková,
  { {0xe3b200a2, 0x7bc3007f, 0x6d5b010f, 0x00000000}},  //   _مرگ_, donu, _baua,
  { {0xdb1801dc, 0x68fb016c, 0x5bca01f5, 0x00000000}},  //   dová, jcud, ित्व,
  { {0x6d5b0032, 0xa3e60061, 0x9f4901e5, 0x00000000}},  //   _daua, _फळा_, ppað_,
  { {0x7bc30951, 0x661a1938, 0xdb18013e, 0x00000000}},  //   gonu, ystk, fová,
  { {0x5ee00055, 0xcb67003b, 0xdb182456, 0x00000000}},  //   _প্রে, таје_, gová,
  { {0x69d9018e, 0x63a72457, 0x6d5b2458, 0x00000000}},  //   _chwe, zijn, _gaua,
  { {0xdb3400e9, 0x2e3c000c, 0x4813007e, 0x00000000}},  //   _مذاک, líf_, амыс,
  { {0x81d80055, 0x7f5c06c2, 0x656d0161, 0x00000000}},  //   াদি_, _jarq, _snah,
  { {0x7f5c028c, 0xdb180802, 0xdce00006, 0x00000000}},  //   _marq, cová, _pomė,
  { {0x891a06c6, 0x661a10ae, 0x63a700b5, 0x00000000}},  //   _آغاز_, rstk, wijn,
  { {0x81d80044, 0x6dbc016e, 0x26c20036, 0x00000000}},  //   াদা_, mčad, łko_,
  { {0x62352459, 0xdb03009d, 0x39460544, 0x00000000}},  //   легу, tiné, _hbos_,
  { {0x63a70dc1, 0x20020022, 0x00000000, 0x00000000}},  //   rijn, _atki_,   ,
  { {0x7bc3149f, 0xe5c40088, 0x656d09bd, 0x00000000}},  //   zonu, _всьо, _unah,
  { {0x7bc3027d, 0xdb1800b9, 0xdb030ea5, 0x00000000}},  // [5ed0] yonu, zová, siné,
  { {0x2fc700ad, 0x24840c94, 0x442b245a, 0x00000000}},  //   ông_, ämme_, mrc_,
  { {0x7f5c02d0, 0x7bc30992, 0x2002014a, 0x00000000}},  //   _darq, vonu, _etki_,
  { {0xdb18093f, 0x9f4a0173, 0x00000000, 0x00000000}},  //   vová, _libè_,   ,
  { {0xa3b8007a, 0x7c2410ec, 0x68fb0477, 0x00000000}},  //   _سایر_, širn, vcud,
  { {0x442b0051, 0xdb18245b, 0x3946245c, 0x00000000}},  //   irc_, tová, _abos_,
  { {0x7bc3013f, 0xa9a5245d, 0x6d5b00fa, 0x00000000}},  //   ronu, ликд, _taua,
  { {0xdb180224, 0x38661aec, 0x7f5c00d9, 0x00000000}},  //   rová, _bror_, _zarq,
  { {0x7bc30036, 0xf771031d, 0xdb1800b9, 0x00000000}},  //   ponu, ماد_, sová,
  { {0x68fb00d4, 0xdb1801dc, 0xdcfb013e, 0x00000000}},  //   scud, pová, _mouč,
  { {0x6f15245e, 0x38661886, 0x00000000, 0x00000000}},  //   _mezc, _eror_,   ,
  { {0x3ce9037e, 0x6b8105b4, 0x6f1505d2, 0x00000000}},  //   žavu_, _holg, _lezc,
  { {0xf745007c, 0x28f8007c, 0xaaa70204, 0x00000000}},  //   _бело, _речь_, _केतक,
  { {0xf7731095, 0x395f245f, 0x6dbc016c, 0x00000000}},  //   _خاص_, ldus_, pčag,
  { {0x442b0048, 0xe29a16e8, 0x00000000, 0x00000000}},  //   arc_, хав_,   ,
  { {0x395f0004, 0x7d190036, 0x442b0087, 0x00000000}},  //   ndus_, jaws, brc_,
  { {0x7f5c0489, 0xdb010047, 0xdfd201af, 0x00000000}},  // [5ee0] _parq, _emlé, مير_,
  { {0xe3b2023c, 0x395d00ab, 0x7f5c08b6, 0x00000000}},  //   _درب_, _laws_, _qarq,
  { {0x11d60123, 0x6fd00039, 0x44200d22, 0x00000000}},  //   _متحد, läck, _hvi_,
  { {0x7bda0065, 0x427b0049, 0x51560478, 0x00000000}},  //   _shtu, _נאכג, _стоу,
  { {0x395f018e, 0x6b812460, 0x7f5c0197, 0x00000000}},  //   ddus_, _bolg, _tarq,
  { {0x6b810211, 0x8f760c50, 0x31602461, 0x00000000}},  //   _colg, _сумі, ldiz_,
  { {0x6b812462, 0x2d9c00f4, 0x26110059, 0x00000000}},  //   _dolg, èves_, jšo_,
  { {0x316009ac, 0x7d0d009f, 0x44200052, 0x00000000}},  //   ndiz_, ðast, _ovi_,
  { {0x6b81001f, 0x5b360d3a, 0x442000fa, 0x00000000}},  //   _folg, _معار, _nvi_,
  { {0x6aba0009, 0x2ca7003b, 0x75240032, 0x00000000}},  //   _txtf, _скуп_, _adiz,
  { {0x9f4a0051, 0xd6d00380, 0x35b50f13, 0x00000000}},  //   _cibé_, تقد_, ибор,
  { {0x38660cb2, 0xd6d70147, 0x4420018d, 0x00000000}},  //   _tror_, ыты_, _bvi_,
  { {0x5eab0044, 0x00000000, 0x00000000, 0x00000000}},  //   _করছে,   ,   ,
  { {0x75242463, 0x44200006, 0x7d190036, 0x00000000}},  //   _ediz, _dvi_, zaws,
  { {0xdcfb0224, 0x442b0009, 0x44200279, 0x00000000}},  //   _souč, src_, _evi_,
  { {0x442b0061, 0x6fd02464, 0x00000000, 0x00000000}},  //   prc_, läch,   ,
  { {0x0f150077, 0x7ff70355, 0x00000000, 0x00000000}},  // [5ef0] имаю, اسرا,   ,
  { {0x6fd0010f, 0x98af016c, 0x644d0058, 0x00000000}},  //   näch, šaće_, _ipai,
  { {0x644e0059, 0x442000d2, 0x98af0066, 0x00000000}},  //   čniš, _zvi_, _tagħ_,
  { {0x6b81068f, 0x7d0e0082, 0x644d0022, 0x00000000}},  //   _solg, _đbsc, _kpai,
  { {0xf41f021e, 0x6b810010, 0x61f700ea, 0x00000000}},  //   nsä_, _polg, _huxl,
  { {0x2009020c, 0x395d0bd8, 0xda65023c, 0x00000000}},  //   mpai_, _saws_, لاعي,
  { {0x6b81049b, 0x83380049, 0x6fd001a2, 0x00000000}},  //   _volg, טאגס_, däch,
  { {0x395f0995, 0x9f4a00f6, 0x00000000, 0x00000000}},  //   udus_, _ribé_,   ,
  { {0x395f0089, 0x5d8401b7, 0x6604200c, 0x00000000}},  //   rdus_, _القل, _čika,
  { {0x44202465, 0x00000000, 0x00000000, 0x00000000}},  //   _rvi_,   ,   ,
  { {0x44200119, 0x644d1983, 0xe8150316, 0x00000000}},  //   _svi_, _apai, _दौरा_,
  { {0x657d0065, 0x629c0059, 0x8afc0036, 0x00000000}},  //   gjsh, vzro, _wnęt,
  { {0x6d49002a, 0x290d000b, 0xdb031c37, 0x00000000}},  //   _mbea, mbea_, minâ,
  { {0x66e52466, 0x6fd00039, 0x889a009b, 0x00000000}},  //   _кола, räck, _בבני,
  { {0x644d022b, 0xf53f0030, 0x629c04eb, 0x00000000}},  //   _epai, rnår_, uzro,
  { {0x61ef04bd, 0xd1320379, 0x60260088, 0x00000000}},  //   _cicl, تمر_, идба,
  { {0xcef601fc, 0x20870088, 0x3f830247, 0x00000000}},  // [5f00] ачењ, айти_, _boju_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xed5a01fb, 0xee3a012b, 0x76412467, 0x00000000}},  //   кож_, тне_, ntly,
  { {0x61ef009d, 0x2b5e0203, 0x00000000, 0x00000000}},  //   _gicl, _satc_,   ,
  { {0x61e42468, 0xdb0300c4, 0x798200d9, 0x00000000}},  //   mmil, dinâ, _roow,
  { {0x61e400b0, 0xca2602b3, 0x8c43003b, 0x00000000}},  //   lmil, афии, цеље,
  { {0xdce90066, 0x00000000, 0x00000000, 0x00000000}},  //   _vleġ,   ,   ,
  { {0x61e405eb, 0x6fd001a2, 0x66080045, 0x00000000}},  //   nmil, wäch, vpdk,
  { {0x61e4000c, 0x5817007e, 0x00000000, 0x00000000}},  //   imil, ажыў_,   ,
  { {0x2d840038, 0x61e42469, 0x00000000, 0x00000000}},  //   _home_, hmil,   ,
  { {0x6fd0010f, 0x2d840056, 0x61e4246a, 0x00000000}},  //   räch, _kome_, kmil,
  { {0x6fd001a2, 0x61e40466, 0xf41f00b0, 0x00000000}},  //   säch, jmil, tsä_,
  { {0xb447008b, 0x61e4099d, 0x94a8246b, 0x00000000}},  //   шэнк, dmil, атра_,
  { {0x24840039, 0xa5c7000c, 0x61e4010e, 0x00000000}},  //   ämma_, _blóð, emil,
  { {0xf41f0f3c, 0xf1a7007e, 0x3f83016c, 0x00000000}},  //   ssä_, аран, _roju_,
  { {0x2d84220a, 0x3d1003d7, 0xdb03246c, 0x00000000}},  //   _nome_, ारों_, viní,
  { {0xc1040054, 0x69c70061, 0x533501ee, 0x00000000}},  // [5f10] توقي, ावती, _лепт,
  { {0x68f500b9, 0x6e67005e, 0x99510161, 0x00000000}},  //   ězdi, итеж, _máš_,
  { {0x2d84246d, 0xede7007e, 0x61ef246e, 0x00000000}},  //   _bome_, аўдн, _ticl,
  { {0x2d84085d, 0x61e40bd3, 0xdb0a246f, 0x00000000}},  //   _come_, cmil, lifè,
  { {0x99510161, 0x2d842470, 0xab2900e2, 0x00000000}},  //   _náš_, _dome_, гола_,
  { {0x2bbb0054, 0xdb0a156c, 0x09af0061, 0x00000000}},  //   خاصة_, nifè, जच्य,
  { {0xfee50055, 0x5e950025, 0xb222000c, 0x00000000}},  //   _প্রধ, _الأط, _áætl,
  { {0xd2b8019b, 0x7dd80027, 0x7e620036, 0x00000000}},  //   ילות_, písa, łopc,
  { {0xf8a9007a, 0x290d1b90, 0xf719007e, 0x00000000}},  //   دگاه_, rbea_, ліны_,
  { {0x25a9003f, 0x61e421ff, 0x00000000, 0x00000000}},  //   _amal_, zmil,   ,
  { {0x61e409c8, 0x00000000, 0x00000000, 0x00000000}},  //   ymil,   ,   ,
  { {0xceb20097, 0x857a00ed, 0x764101d6, 0x00000000}},  //   ליי_, усот_, rtly,
  { {0xa5c7000c, 0xc79800a1, 0x7641005b, 0x00000000}},  //   _slóð, _چھپا_, stly,
  { {0x25a92471, 0x00000000, 0x00000000, 0x00000000}},  //   _emal_,   ,   ,
  { {0xe2972472, 0x412a005e, 0x61e40232, 0x00000000}},  //   бар_, лово_, tmil,
  { {0xc2432473, 0x973c0107, 0x61e4182d, 0x00000000}},  //   янск, vići, umil,
  { {0xe0da01b3, 0x2d841e3c, 0x61e420a0, 0x00000000}},  // [5f20] ува_, _rome_, rmil,
  { {0x2d840038, 0xe47b00b6, 0x442204d3, 0x00000000}},  //   _some_, _עריכ, msk_,
  { {0x442201e3, 0xc7d6009b, 0xdb030129, 0x00000000}},  //   lsk_, צועי_, dinà,
  { {0x628e0006, 0x4422141a, 0x00000000, 0x00000000}},  //   mybo, osk_,   ,
  { {0x44220374, 0x996c00b9, 0x653b0049, 0x00000000}},  //   nsk_, těž_, רענד,
  { {0x44220056, 0xd00f03e6, 0xdb0300d4, 0x00000000}},  //   isk_, _سلف_, ginà,
  { {0x2d840119, 0x628e007f, 0x7d0d004a, 0x00000000}},  //   _tome_, nybo, ñasc,
  { {0xed5a01fb, 0xd90d02fd, 0x6f1e04bb, 0x00000000}},  //   _щоб_, نیم_, lapc,
  { {0x628e0161, 0x00000000, 0x00000000, 0x00000000}},  //   hybo,   ,   ,
  { {0x7d020207, 0x99510428, 0x7c2d0107, 0x00000000}},  //   lcos, _váš_, šarc,
  { {0x7c220010, 0x9f9400b0, 0x00000000, 0x00000000}},  //   lsor, mää_,   ,
  { {0xdb032474, 0x628e0006, 0x7d020059, 0x00000000}},  //   miná, dybo, ncos,
  { {0xdb0310d3, 0x6f1e0010, 0x94ab0545, 0x00000000}},  //   liná, kapc, утна_,
  { {0x569410d8, 0x7bca0c7d, 0x63ae0e0d, 0x00000000}},  //   _малт, nofu, gibn,
  { {0x1b1d0055, 0xdb0a2475, 0x7c2222cb, 0x00000000}},  //   _নামে_, rifè, hsor,
  { {0x44220179, 0x7c220f3f, 0x25a9012d, 0x00000000}},  //   bsk_, ksor, _umal_,
  { {0x9f9400b0, 0x7c2200eb, 0x69ab013d, 0x00000000}},  // [5f30] kää_, jsor, _जगसी,
  { {0x3255003b, 0x7c22032e, 0x628e0a75, 0x00000000}},  //   _двор, dsor, bybo,
  { {0xdfd8005e, 0x7c220146, 0x2bdc013d, 0x00000000}},  //   сът_, esor, यतना,
  { {0xfe700054, 0xdb032474, 0x3cd50242, 0x00000000}},  //   عدل_, diná, ожес,
  { {0x913a0049, 0x7c2201e3, 0xcfc30044, 0x00000000}},  //   _דערק, gsor, ্গবন,
  { {0x7e620036, 0x7bca0b69, 0xeb96017f, 0x00000000}},  //   łopa, gofu, жиш_,
  { {0x4999022a, 0xdb030161, 0xfbd00379, 0x00000000}},  //   ития_, giná, رته_,
  { {0xe8f90f13, 0xe9d900ec, 0x7d02001b, 0x00000000}},  //   шли_, јки_, ccos,
  { {0x6a4a006b, 0x7c2208a4, 0x628e00b4, 0x00000000}},  //   _vəfa, csor, zybo,
  { {0x6dbc0209, 0x799b0e9c, 0x99800213, 0x00000000}},  //   nčan, shuw, čiš_,
  { {0x98b901f6, 0x7d1b0935, 0xcb1200b3, 0x00000000}},  //   ısı_, _keus, _חלב_,
  { {0x4422068f, 0x24ea2476, 0x00000000, 0x00000000}},  //   tsk_, имни_,   ,
  { {0x44240978, 0x628e1496, 0x7d1b009d, 0x00000000}},  //   ém_, wybo, _meus,
  { {0x44220292, 0x628e0006, 0x7d1b046a, 0x00000000}},  //   rsk_, tybo, _leus,
  { {0x6d93014a, 0x63ae0145, 0x7d020133, 0x00000000}},  //   _açam, ribn, ycos,
  { {0x7c221e3d, 0x7c240166, 0x628e046e, 0x00000000}},  //   ysor, širi, rybo,
  { {0xef1a045e, 0xc9520104, 0xdb0300b9, 0x00000000}},  // [5f40] има_, ומן_, ziná,
  { {0xafdb0378, 0x59b00061, 0x65640052, 0x00000000}},  //   _spør, _जगभर, _haih,
  { {0xa2e601fb, 0x9f94021e, 0x9f5101aa, 0x00000000}},  //   _фонд, vää_, _mizè_,
  { {0x7c22010f, 0xdb030161, 0x6446016c, 0x00000000}},  //   tsor, viná, otki,
  { {0x9f94021e, 0x7d020d87, 0x7d1b2477, 0x00000000}},  //   tää_, rcos, _deus,
  { {0x7c222478, 0x7d020207, 0x656400b0, 0x00000000}},  //   rsor, scos, _laih,
  { {0x6446006c, 0x7bca03d1, 0x9f9400b0, 0x00000000}},  //   htki, rofu, rää_,
  { {0x9f94021e, 0x6f1c0466, 0xdb030387, 0x00000000}},  //   sää_, _herc, riná,
  { {0x6f1c0065, 0xa3da013d, 0x9f94003c, 0x00000000}},  //   _kerc, ़ता_, pää_,
  { {0x6c330014, 0x77630082, 0x5edd0044, 0x00000000}},  //   _آفلا, _canx, _বলতে,
  { {0x4efb007b, 0x65641307, 0x9f51000a, 0x00000000}},  //   יליג, _baih, _dizè_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x656404e9, 0x6d400784, 0x69c70061, 0x00000000}},  //   _daih, _mcma, ावरी,
  { {0x77630129, 0x8c480477, 0x65760010, 0x00000000}},  //   _ganx, mağı, _enyh,
  { {0x6dbc2479, 0x92681023, 0x8c480279, 0x00000000}},  //   včan, орта_, lağı,
  { {0x65c402a8, 0x60f90147, 0x6b8800ab, 0x00000000}},  //   _обја, сная_, _lodg,
  { {0x7d1b0956, 0x6f1c0127, 0x8c48019a, 0x00000000}},  // [5f50] _reus, _berc, nağı,
  { {0x44390995, 0x6f1c108c, 0xdfd10054, 0x00000000}},  //   mus_, _cerc, ريا_,
  { {0x4439247a, 0x7d1b247b, 0xdb03014a, 0x00000000}},  //   lus_, _peus, linç,
  { {0x753d1582, 0xdce0005d, 0x443900ab, 0x00000000}},  //   ngsz, _almı, ous_,
  { {0x6f1c0016, 0x6dbc016e, 0x6b9a0009, 0x00000000}},  //   _ferc, pčan, _bltg,
  { {0xf1bf009f, 0x2d9d14a5, 0x291f0020, 0x00000000}},  //   _hjá_, shwe_, waua_,
  { {0x44390018, 0x69c42198, 0x776300f6, 0x00000000}},  //   hus_, čien, _ranx,
  { {0x6dbc0059, 0x7763247c, 0x00000000, 0x00000000}},  //   nčal, _sanx,   ,
  { {0x44390995, 0x7763247d, 0x291f002d, 0x00000000}},  //   jus_, _panx, raua_,
  { {0x44390f81, 0x6d4b010f, 0x6f050009, 0x00000000}},  //   dus_, lfga, nchc,
  { {0x443901d6, 0xb9010055, 0x6dbc012d, 0x00000000}},  //   eus_, _দল_, kčal,
  { {0x44390670, 0x8c480477, 0x6d590a6b, 0x00000000}},  //   fus_, bağı, newa,
  { {0x8c4801f6, 0x6564021e, 0xe72e003b, 0x00000000}},  //   cağı, _vaih, _пе_,
  { {0x2444247e, 0x291d0020, 0xd7590a4f, 0x00000000}},  //   röm_, _hewa_, _طلعت_,
  { {0x64460046, 0xf770035b, 0x4439010a, 0x00000000}},  //   stki, _جان_, aus_,
  { {0x6f1c0036, 0xdb0301b1, 0x00000000, 0x00000000}},  //   _serc, linä,   ,
  { {0x6f1c247f, 0x6d590ea4, 0x21200169, 0x00000000}},  // [5f60] _perc, dewa, raih_,
  { {0x672116eb, 0x00000000, 0x00000000, 0x00000000}},  //   nalj,   ,   ,
  { {0x6f1c0197, 0x5ee10061, 0xa13700a1, 0x00000000}},  //   _verc, _करण्_, _کرپش,
  { {0x6d59063c, 0x7e620036, 0x0d86007e, 0x00000000}},  //   gewa, łopo, ялен,
  { {0x0b8a0265, 0x6b9a0022, 0x25fd013d, 0x00000000}},  //   йски_, _pltg, _रूसी_,
  { {0x67210645, 0xa1360014, 0x2c5d000a, 0x00000000}},  //   jalj, _برگش, _dňd_,
  { {0x672100bf, 0x9ea701f9, 0x6d590168, 0x00000000}},  //   dalj, _евра_, bewa,
  { {0x8c460407, 0x44390093, 0x6d59003f, 0x00000000}},  //   _небе, yus_, cewa,
  { {0x44391962, 0xdb0a0051, 0xdca3012b, 0x00000000}},  //   xus_, lifí, _зати,
  { {0x44391d36, 0x67210066, 0x8c480276, 0x00000000}},  //   vus_, galj, rağı,
  { {0x4439123d, 0xe53507d0, 0x9f4b0026, 0x00000000}},  //   wus_, мень, _cucù_,
  { {0x4439061f, 0xdb0300c4, 0xa2cd0309, 0x00000000}},  //   tus_, tinç, _दुष्,
  { {0x67212480, 0x00000000, 0x00000000, 0x00000000}},  //   balj,   ,   ,
  { {0x44390149, 0xf1bf009f, 0x6d590036, 0x00000000}},  //   rus_, _sjá_, zewa,
  { {0x61fe001a, 0xf2c40069, 0x6d590d16, 0x00000000}},  //   _cupl, естн, yewa,
  { {0x443904bd, 0x59cc0061, 0xdb1a014a, 0x00000000}},  //   pus_, ाविर, _aktü,
  { {0xa2cd02fb, 0x752d022b, 0x3f8a050f, 0x00000000}},  // [5f70] _दुर्, _idaz, _bobu_,
  { {0x442901bc, 0xa857009b, 0x6d590045, 0x00000000}},  //   _iva_, הימה_, wewa,
  { {0x3f8a01ca, 0xb81e013d, 0x6f050061, 0x00000000}},  //   _dobu_, _मौसम_, rchc,
  { {0xf1a700ed, 0xdb1a2481, 0x44290292, 0x00000000}},  //   _хрон, _októ, _kva_,
  { {0x6b650088, 0x5067007e, 0x6c85009e, 0x00000000}},  //   дкла, _этна, بلشم,
  { {0x6d5904be, 0x291d003f, 0x9f8f010e, 0x00000000}},  //   sewa, _sewa_, nüü_,
  { {0x67210091, 0x752d0166, 0x44291478, 0x00000000}},  //   valj, _odaz, _lva_,
  { {0x442901ee, 0x3f8a0089, 0x7d04004a, 0x00000000}},  //   _ova_, _zobu_, ñist,
  { {0x7c24002a, 0xf53f0737, 0xf7710879, 0x00000000}},  //   áirt, dgå_, ناد_,
  { {0x386f00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _vrgr_,   ,   ,
  { {0x672101d5, 0x7c29191d, 0x4429006c, 0x00000000}},  //   ralj, _hver, _ava_,
  { {0x6721037e, 0x44290946, 0x2627016c, 0x00000000}},  //   salj, _bva_, rđo_,
  { {0x61fe2482, 0x6fbf04da, 0x89340025, 0x00000000}},  //   _supl, ्वां, _أعما,
  { {0x44290387, 0x61fe0ea9, 0x99800027, 0x00000000}},  //   _dva_, _pupl, čiť_,
  { {0x44290142, 0x386d0781, 0x61460ab7, 0x00000000}},  //   _eva_, lver_, мева,
  { {0x7c290c95, 0x386d0061, 0xdb1801ca, 0x00000000}},  //   _over, over_, dový,
  { {0x798b00e0, 0x4429177d, 0x386d0133, 0x00000000}},  // [5f80] _mogw, _gva_, nver_,
  { {0x61fe00b0, 0x386d00d9, 0xdb0a0285, 0x00000000}},  //   _tupl, iver_, tifí,
  { {0xdfcf06ea, 0x7c29051b, 0xdb1a01aa, 0x00000000}},  //   جيل_, _aver, _oktò,
  { {0x386d012d, 0x7bc100e5, 0x7c2901a2, 0x00000000}},  //   kver_, _ajlu, _bver,
  { {0x386d00b5, 0x7dd81261, 0x41970014, 0x00000000}},  //   jver_, nísi, _آشپز,
  { {0x7d0901d6, 0xdb1801ca, 0x7c290027, 0x00000000}},  //   _efes, bový, _dver,
  { {0x7c290038, 0x394d03be, 0x7d090016, 0x00000000}},  //   _ever, ffes_, _ffes,
  { {0xd91a0088, 0x3942006c, 0xdee302dc, 0x00000000}},  //   цьк_, üks_, _роси,
  { {0x7c2901d5, 0x660d0235, 0x386d00ca, 0x00000000}},  //   _gver, _čaka, gver_,
  { {0x7dd811c4, 0x00000000, 0x00000000, 0x00000000}},  //   dísi,   ,   ,
  { {0x44290059, 0x7c290027, 0xe5b50147, 0x00000000}},  //   _sva_, _zver, ейны,
  { {0x7dd80325, 0x5693041f, 0x7c2903be, 0x00000000}},  //   físi, тают, _yver,
  { {0xf8e2013d, 0x2edb013d, 0x9abc0066, 0x00000000}},  //   _परिय, _भर्त, _deċe,
  { {0x237a00c4, 0x442900f6, 0x75fe0089, 0x00000000}},  //   _cnpj_, _vva_, _līzi,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44291b0a, 0x5edd0044, 0x6448001a, 0x00000000}},  //   _tva_, _বললে, ădir,
  { {0x44290851, 0x3169004a, 0x00000000, 0x00000000}},  // [5f90] _uva_, rdaz_,   ,
  { {0xdb180161, 0x00000000, 0x00000000, 0x00000000}},  //   tový,   ,   ,
  { {0x7c2902e1, 0x63b5133f, 0x00000000, 0x00000000}},  //   _sver, mizn,   ,
  { {0x386d0190, 0x63b50036, 0xdb180161, 0x00000000}},  //   yver_, lizn, rový,
  { {0x61ed00b0, 0x8027002c, 0x3b0901ee, 0x00000000}},  //   mmal, _ترجم, пело_,
  { {0x61ed049d, 0x63b52483, 0x69c200fa, 0x00000000}},  //   lmal, nizn, _ajoe,
  { {0xd90f0167, 0x69c20056, 0x61ed00b0, 0x00000000}},  //   لیا_, _bjoe, omal,
  { {0x9f59004f, 0x61ed005d, 0xa2d6013d, 0x00000000}},  //   _musí_, nmal, _मुफ्,
  { {0x386d028c, 0xa3df0164, 0x7c292484, 0x00000000}},  //   uver_, तता_, _uver,
  { {0x61ed01a2, 0x7dd805a3, 0xa68502ea, 0x00000000}},  //   hmal, vísi, елод,
  { {0x61ed08a9, 0x7d0400ca, 0x81d60044, 0x00000000}},  //   kmal, žise, িগত_,
  { {0xb8e508b7, 0x7dd8008e, 0x386d0009, 0x00000000}},  //   _এর_, tísi, pver_,
  { {0x61ed0089, 0x00000000, 0x00000000, 0x00000000}},  //   dmal,   ,   ,
  { {0x69db0065, 0xf74500ed, 0x7dd80f3b, 0x00000000}},  //   llue, _чеко, rísi,
  { {0x217601fc, 0x7dd8008e, 0x9f5900f6, 0x00000000}},  //   нуар, sísi, _cusí_,
  { {0x61ed011c, 0x600a09ae, 0x7dd8004a, 0x00000000}},  //   gmal, знам_, písi,
  { {0x3fe601c0, 0x69db02f6, 0x63b50142, 0x00000000}},  // [5fa0] ежав, ilue, bizn,
  { {0x2d9f00b0, 0x63b50091, 0x61ed00b0, 0x00000000}},  //   _alue_, cizn, amal,
  { {0x2d9f00ab, 0xdee62485, 0x00000000, 0x00000000}},  //   _blue_, хожи,   ,
  { {0xbd670088, 0xd2b701ce, 0x2d9f0133, 0x00000000}},  //   ерше_, _טלית_, _clue_,
  { {0x2004001a, 0x7f1a007e, 0x9ac30066, 0x00000000}},  //   _îmi_, _ніву_, _ċċar,
  { {0x9f58008d, 0xaa660364, 0x69c200bb, 0x00000000}},  //   _mirë_, етик, _sjoe,
  { {0xdee31ef9, 0x9f580065, 0x2d9f2486, 0x00000000}},  //   _бори, _lirë_, _flue_,
  { {0x20020202, 0x2122012d, 0x2d9f0322, 0x00000000}},  //   _kuki_, _jekh_, _glue_,
  { {0xa3c00183, 0x6bda00a1, 0x75260032, 0x00000000}},  //   ंचा_, _فورس_, dakz,
  { {0x27f806a1, 0x999f0089, 0x61ed019a, 0x00000000}},  //   örn_, ārši_, zmal,
  { {0x63b500b9, 0x69db0009, 0x61ed0036, 0x00000000}},  //   vizn, blue, ymal,
  { {0x6d42022b, 0xba9b00a0, 0x69db15a3, 0x00000000}},  //   ngoa, _מסבי, clue,
  { {0x19b70049, 0x58930167, 0x00000000, 0x00000000}},  //   _אפאר_, _مجوز,   ,
  { {0x386600f6, 0x00000000, 0x00000000, 0x00000000}},  //   _isor_,   ,   ,
  { {0x667300b8, 0x7cf6005a, 0x20021f47, 0x00000000}},  //   _مدير, _yürü, _auki_,
  { {0x26db019b, 0x25090014, 0x62950832, 0x00000000}},  //   _מקומ, _غربی_, ryzo,
  { {0x69c000ab, 0x403402ea, 0x00000000, 0x00000000}},  // [5fb0] inme, летс,   ,
  { {0x7c2d092f, 0x61ed00b0, 0x200f001e, 0x00000000}},  //   šark, smal, īgi_,
  { {0x4fc4003b, 0x44390009, 0x88bd0036, 0x00000000}},  //   уста, lrs_, jaśn,
  { {0x442b0129, 0x386600f6, 0x4439112b, 0x00000000}},  //   osc_, _osor_, ors_,
  { {0x442b01ee, 0xdce00089, 0xcb690545, 0x00000000}},  //   nsc_, _pamā, дале_,
  { {0x7cf601f6, 0x6d42002d, 0x44390549, 0x00000000}},  //   _sürü, agoa, irs_,
  { {0xdb0a000c, 0xab2801b7, 0xdddc0010, 0x00000000}},  //   kifæ, رسول_, _errő,
  { {0x20020ca9, 0x44390166, 0x69c02304, 0x00000000}},  //   _yuki_, krs_, gnme,
  { {0x442b2487, 0x00000000, 0x00000000, 0x00000000}},  //   jsc_,   ,   ,
  { {0x44390089, 0x39460b33, 0xfaa72488, 0x00000000}},  //   drs_, _ecos_, _пшен,
  { {0x443900cc, 0xe5a6026b, 0x442b001a, 0x00000000}},  //   ers_, вини, esc_,
  { {0x383502be, 0x9f580023, 0x442b00d2, 0x00000000}},  //   _андр, _pirë_, fsc_,
  { {0x395f1566, 0x7dd800b9, 0x6fd10061, 0x00000000}},  //   meus_, míst, तकां,
  { {0x33d502f0, 0x6a4a005f, 0x7dd80285, 0x00000000}},  //   гіст, _səfi, líst,
  { {0x25e3013d, 0x20020058, 0x442b0051, 0x00000000}},  //   _टीवी_, _suki_, asc_,
  { {0x7dd82489, 0x395f010d, 0x2002011c, 0x00000000}},  //   níst, neus_, _puki_,
  { {0x66030215, 0x000400a1, 0xf5930025, 0x00000000}},  // [5fc0] _hunk, اثری, _خليج,
  { {0x6723023a, 0x395f005b, 0x7524010f, 0x00000000}},  //   _jenj, heus_, _heiz,
  { {0x6723020c, 0x752400bb, 0x395f00b0, 0x00000000}},  //   _menj, _keiz, keus_,
  { {0x6603121b, 0x44200036, 0x200200b0, 0x00000000}},  //   _munk, _kwi_, _tuki_,
  { {0x7dd8248a, 0x442001aa, 0x66030190, 0x00000000}},  //   díst, _jwi_, _lunk,
  { {0x3946001a, 0x44200022, 0x75240032, 0x00000000}},  //   _scos_, _mwi_, _leiz,
  { {0x39460066, 0x26060061, 0x395f00d4, 0x00000000}},  //   _pcos_, _संधी_, feus_,
  { {0x7524001e, 0x7dd80b76, 0x443901d6, 0x00000000}},  //   _neiz, gíst, yrs_,
  { {0x6723248b, 0xf1b3019b, 0x69c0248c, 0x00000000}},  //   _benj, יסה_, rnme,
  { {0x66030142, 0x6723248d, 0xdb1a22ae, 0x00000000}},  //   _bunk, _cenj, _aktö,
  { {0xa3d60164, 0x4420248e, 0x44390016, 0x00000000}},  //   िकन_, _awi_, wrs_,
  { {0x9f580b32, 0x44390089, 0x6603010f, 0x00000000}},  //   _diré_, trs_, _dunk,
  { {0x4439028c, 0x442d00f4, 0x3866001a, 0x00000000}},  //   urs_, ée_, _usor_,
  { {0x4420018e, 0x67230065, 0x225a0093, 0x00000000}},  //   _dwi_, _genj, _bppk_,
  { {0xa2d602fb, 0xf77200a1, 0x7dd81374, 0x00000000}},  //   _मुद्, _ماں_, níss,
  { {0x7c2d0627, 0x442001aa, 0x672821ff, 0x00000000}},  //   šari, _fwi_, ladj,
  { {0x10750930, 0x225a0288, 0x00000000, 0x00000000}},  // [5fd0] ылаю, _eppk_,   ,
  { {0x6728037e, 0xcebb012b, 0x656d03b0, 0x00000000}},  //   nadj, мље_, _haah,
  { {0xdfd80265, 0xa29503e8, 0x229504dd, 0x00000000}},  //   тът_, _сані, _синя,
  { {0x7c2b06d3, 0xf6530097, 0x656f05af, 0x00000000}},  //   tsgr, יצע_, ndch,
  { {0x656d00b0, 0x395f00d4, 0x212904cb, 0x00000000}},  //   _maah, veus_, maah_,
  { {0xdd03038c, 0x21290557, 0x61fd019a, 0x00000000}},  //   ırıl, laah_, _hisl,
  { {0x7dd82444, 0x61fd02bb, 0x6723002b, 0x00000000}},  //   tíst, _kisl, _renj,
  { {0x672304cb, 0x656d248f, 0x660300b0, 0x00000000}},  //   _senj, _naah, _runk,
  { {0x61fd0213, 0x75242490, 0x6723020c, 0x00000000}},  //   _misl, _reiz, _penj,
  { {0x67282491, 0x395f0a0a, 0x656d0058, 0x00000000}},  //   gadj, seus_, _aaah,
  { {0x6723000c, 0x44200e9e, 0xcb12009b, 0x00000000}},  //   _venj, _swi_, _הלב_,
  { {0x2d9d01d5, 0x44202492, 0xe81e006e, 0x00000000}},  //   nkwe_, _pwi_, _मौका_,
  { {0x67282493, 0xd6d40044, 0x69d92494, 0x00000000}},  //   badj, _হৃদয, _ikwe,
  { {0x61fd2495, 0x290d001a, 0x9f582496, 0x00000000}},  //   _aisl, lcea_, _tiré_,
  { {0x61fd010f, 0xdb030051, 0x00000000, 0x00000000}},  //   _bisl, ghné,   ,
  { {0x290d001a, 0x442000ea, 0x76412497, 0x00000000}},  //   ncea_, _twi_, muly,
  { {0x6a4a005f, 0x31600089, 0x4420011c, 0x00000000}},  // [5fe0] _həft, reiz_, _uwi_,
  { {0x6d49000d, 0x3366019d, 0x6aa90044, 0x00000000}},  //   _acea, _свог, _কখনো,
  { {0x3f910bbb, 0x69d90009, 0x656d0020, 0x00000000}},  //   _dozu_, _okwe, _yaah,
  { {0x69d92498, 0x7dd81396, 0x67282499, 0x00000000}},  //   _nkwe, víss, zadj,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4376007b, 0x0a6a0797, 0x09cc0061, 0x00000000}},  //   רײַן_, ерии_, ाव्य,
  { {0x6728249a, 0xad5a02dc, 0x00000000, 0x00000000}},  //   vadj, _прах_,   ,
  { {0x6d49002a, 0x7bc3249b, 0x7dd81396, 0x00000000}},  //   _gcea, annu, ríss,
  { {0xa2d6007d, 0x6728002b, 0x656d00b0, 0x00000000}},  //   _मुस्, tadj, _raah,
  { {0x38570025, 0x69d90066, 0x656d07a4, 0x00000000}},  //   اشيد_, _ekwe, _saah,
  { {0x6728249c, 0x7fd70049, 0x00000000, 0x00000000}},  //   radj, רויס_,   ,
  { {0xceb300b6, 0x6728249d, 0xdb01009d, 0x00000000}},  //   מית_, sadj, _allè,
  { {0xa3c00061, 0x589601f7, 0xdb1800c4, 0x00000000}},  //   ंचं_, _حجاز, vivê,
  { {0x656d249e, 0x644f0d9f, 0x00000000, 0x00000000}},  //   _waah, rtci,   ,
  { {0x61fd006b, 0xc677023c, 0xdb970049, 0x00000000}},  //   _pisl, _محيط_, נדלט_,
  { {0x80d30055, 0x00000000, 0x00000000, 0x00000000}},  //   _দৃষ্,   ,   ,
  { {0x60f90a78, 0x61fd0089, 0x7bda011c, 0x00000000}},  // [5ff0] тная_, _visl, _oktu,
  { {0x9f410051, 0x6d4907cd, 0x2fc70082, 0x00000000}},  //   lmhú_, _scea, õng_,
  { {0x62670774, 0x61fd0ba0, 0x80d30044, 0x00000000}},  //   _صادق, _tisl, _দৃশ্,
  { {0x61fd0020, 0x531400d3, 0xac19007c, 0x00000000}},  //   _uisl, _پذیر, воду_,
  { {0x8b250242, 0x7a110089, 0x6dbc0f6c, 0x00000000}},  //   адле, _māte, včat,
  { {0x69d913a7, 0x0ed00061, 0x764106ec, 0x00000000}},  //   _skwe, _तुकड, yuly,
  { {0xf9910025, 0x00000000, 0x00000000, 0x00000000}},  //   قبة_,   ,   ,
  { {0x7a0a0036, 0x00000000, 0x00000000, 0x00000000}},  //   _tętn,   ,   ,
  { {0xf092007b, 0x290d001a, 0x0fb90164, 0x00000000}},  //   ַנט_, rcea_, _आषाढ,
  { {0x998500a1, 0xe1ff00d4, 0x00000000, 0x00000000}},  //   الکو, _lió_,   ,
  { {0x66e50139, 0xdb18000c, 0x00000000, 0x00000000}},  //   рона, fnvæ,   ,
  { {0x58d50265, 0x69d9000b, 0x28750147, 0x00000000}},  //   _коет, _ukwe, _выкр,
  { {0xdb01249f, 0x61e9002b, 0xdd140142, 0x00000000}},  //   _allé, ċell, núši,
  { {0x7641006b, 0xe73902b0, 0x6dbc016e, 0x00000000}},  //   puly, _рек_, nčar,
  { {0x412a0088, 0xa2d6006e, 0x41b602b0, 0x00000000}},  //   ково_, _मुश्, асат,
  { {0xe1ff00d4, 0xdb180023, 0x00000000, 0x00000000}},  //   _ció_, tivë,   ,

  { {0x2167019d, 0xe1ff077b, 0x02db013d, 0x00000000}},  // [6000] шити_, _dió_, _मुठभ,
  { {0x44320784, 0xef1724a0, 0x2d800089, 0x00000000}},  //   _ivy_, иму_, ķiem_,
  { {0x63bc0166, 0x433b0097, 0x00000000, 0x00000000}},  //   mirn, _בעיב,   ,
  { {0xe1ff001d, 0x6b81000a, 0x63bc24a1, 0x00000000}},  //   _gió_, _anlg, lirn,
  { {0x2ca0002a, 0x7d040089, 0x93cb00a1, 0x00000000}},  //   áid_, žiso, _سایہ_,
  { {0x63bc000c, 0xc477009b, 0x399801e5, 0x00000000}},  //   nirn, יתנו_, _lést_,
  { {0xead8007e, 0xeb971e8a, 0x00000000, 0x00000000}},  //   ымкі_, риј_,   ,
  { {0x7c6604e1, 0x63bc020c, 0xdce0012d, 0x00000000}},  //   _پارل, hirn, _namć,
  { {0xa3d602fb, 0xbee6001c, 0x629c005b, 0x00000000}},  //   िका_, _करुन_, hyro,
  { {0x473401e0, 0x3dc601f3, 0x7bc8016c, 0x00000000}},  //   щнос, lnow_, _ujdu,
  { {0xeb97012b, 0xc9860088, 0x6f790049, 0x00000000}},  //   _њих_, _вули, אָרג,
  { {0x9980010a, 0x629c0145, 0x7bd808f4, 0x00000000}},  //   čių_, dyro, lovu,
  { {0x5edd0044, 0xdb0300d6, 0xe1ff004a, 0x00000000}},  //   _বলছে, cinó, _rió_,
  { {0xbee6001c, 0x7bd82142, 0xe1ff24a2, 0x00000000}},  //   _करून_, novu, _sió_,
  { {0x79820038, 0xe5c7007c, 0x3dc601d0, 0x00000000}},  //   _know, _вспо, know_,
  { {0x200f00c4, 0x7bd80387, 0x00000000, 0x00000000}},  //   ígio_, hovu,   ,
  { {0x20980783, 0x644004bd, 0x88d80044, 0x00000000}},  // [6010] акты_, àmit, দেরক,
  { {0x63bc24a3, 0x00000000, 0x00000000, 0x00000000}},  //   cirn,   ,   ,
  { {0x6dbc050f, 0xdb1800b0, 0x7bd809ab, 0x00000000}},  //   včar, invä, dovu,
  { {0x7db4007e, 0x00000000, 0x00000000, 0x00000000}},  //   осіц,   ,   ,
  { {0x65a6000c, 0x6dbc012d, 0x8d7404b1, 0x00000000}},  //   _jóha, tčar, تالا,
  { {0xda650379, 0x1b49007c, 0x3e170014, 0x00000000}},  //   ماعي, узки_, _نظرس,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26c90107, 0x63bc016e, 0xdb0324a4, 0x00000000}},  //   _ćao_, zirn, tinó,
  { {0x629c0036, 0xe8f9007c, 0x6d5b0022, 0x00000000}},  //   zyro, ыли_, _ibua,
  { {0x3998000c, 0xf745003b, 0x00000000, 0x00000000}},  //   _sést_, љено,   ,
  { {0x63bc0059, 0xb8fe0164, 0xdce00243, 0x00000000}},  //   virn, _दु_, _pamć,
  { {0xdb0300f6, 0x00000000, 0x00000000, 0x00000000}},  //   cinò,   ,   ,
  { {0x291f000b, 0x63bc000c, 0x7ae10203, 0x00000000}},  //   mbua_, tirn, _hylt,
  { {0x629c0065, 0xa01b000c, 0xdb1800f4, 0x00000000}},  //   tyro, _kröf, tivé,
  { {0xd29901fb, 0x3dc60009, 0x63bc24a5, 0x00000000}},  //   атті_, ynow_, rirn,
  { {0xdb1800f4, 0x7bd824a6, 0xa06a00e2, 0x00000000}},  //   rivé, zovu, лаба_,
  { {0x351b009b, 0x7bd824a7, 0x629c00f8, 0x00000000}},  // [6020] _גופנ, yovu, syro,
  { {0x64460b9a, 0x6d5b0022, 0x4477009b, 0x00000000}},  //   muki, _abua, _פעיל_,
  { {0x3dc60066, 0xe29a00ed, 0x6446206c, 0x00000000}},  //   tnow_, _сан_, luki,
  { {0x60c90006, 0x00000000, 0x00000000, 0x00000000}},  //   _žeme,   ,   ,
  { {0x98a40089, 0x64460020, 0x61e40095, 0x00000000}},  //   kamā_, nuki, mlil,
  { {0x2a6c0181, 0x798207fc, 0x6d5b0022, 0x00000000}},  //   _psdb_, _snow, _ebua,
  { {0x6e9601f7, 0x7bd80a89, 0x64460020, 0x00000000}},  //   _الزا, rovu, huki,
  { {0xd90e00e9, 0x481401fb, 0xa8140216, 0x00000000}},  //   ریت_, омис, одиш,
  { {0xc1730104, 0xa01b010f, 0x644600bf, 0x00000000}},  //   לחה_, _eröf, juki,
  { {0x6446006c, 0x61e4104a, 0xc3010044, 0x00000000}},  //   duki, hlil, ্রতি_,
  { {0xdb180039, 0x61e4014a, 0x9f5800f6, 0x00000000}},  //   rnvä, klil, _mirà_,
  { {0x6f011261, 0x758b007c, 0x644600e7, 0x00000000}},  //   _úlce, усов_, fuki,
  { {0xe894132a, 0x88940b86, 0x644600e7, 0x00000000}},  //   _фаль, _филх, guki,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf1a7017a, 0xb284007c, 0xa01b0210, 0x00000000}},  //   бран, пытк, _krög,
  { {0x61f60061, 0x6446011c, 0x61e4006a, 0x00000000}},  //   gmyl, buki, glil,
  { {0x752f0036, 0x644624a8, 0x32020062, 0x00000000}},  // [6030] macz, cuki, _diky_,
  { {0xdb030051, 0xb17b0039, 0x752f0036, 0x00000000}},  //   thní, _skåd, lacz,
  { {0x9f580c42, 0x00000000, 0x00000000, 0x00000000}},  //   _dirà_,   ,   ,
  { {0x752f0046, 0xcd2b007a, 0x61e4004a, 0x00000000}},  //   nacz, اسان_, clil,
  { {0x6738016e, 0x7ae105d5, 0x660a0b14, 0x00000000}},  //   _odvj, _sylt, _lufk,
  { {0x7ae101c3, 0xc5cf0044, 0x29060258, 0x00000000}},  //   _pylt, রতিপ, _agoa_,
  { {0x6446002d, 0x68e20300, 0x1989007c, 0x00000000}},  //   zuki, _ayod, ибки_,
  { {0x200b037e, 0x4859008b, 0x00000000, 0x00000000}},  //   _kuci_, ароў_,   ,
  { {0x9f470011, 0x660a010f, 0x212b0324, 0x00000000}},  //   _điên_, _aufk, _mech_,
  { {0x61e4011f, 0x6d4a005d, 0x20030020, 0x00000000}},  //   zlil, ılaş, _jiji_,
  { {0x200b0e1c, 0x8aa70c27, 0x20030020, 0x00000000}},  //   _luci_, _урад, _miji_,
  { {0x6d4b24a9, 0x6446000b, 0x20190004, 0x00000000}},  //   ngga, tuki, _otsi_,
  { {0x92e60055, 0x69c90944, 0xdb0a0210, 0x00000000}},  //   _ফলে_, mnee, rnfö,
  { {0xb6a5007c, 0x69c907a5, 0x20030022, 0x00000000}},  //   _милл, lnee, _niji_,
  { {0x752f0036, 0x64462301, 0x61e4014a, 0x00000000}},  //   bacz, suki, tlil,
  { {0x69c924aa, 0x64460020, 0xa3ba00a6, 0x00000000}},  //   nnee, puki, _چادر_,
  { {0x69c900b0, 0xa3ba06dd, 0xb886000c, 0x00000000}},  // [6040] inee, _نادر_, mtíð,
  { {0x200305fa, 0x61e40213, 0x69db07f3, 0x00000000}},  //   _ciji_, slil, houe,
  { {0x201900b0, 0x66040ac2, 0x00000000, 0x00000000}},  //   _etsi_, _kiik,   ,
  { {0xed5a04af, 0x6d4b001c, 0xec7a24ab, 0x00000000}},  //   род_, ggga, ипе_,
  { {0x0b8a1079, 0x200b1c70, 0x66040052, 0x00000000}},  //   иски_, _guci_, _miik,
  { {0x660408b2, 0xdce00224, 0x212b0c10, 0x00000000}},  //   _liik, _zamě, _zech_,
  { {0xada6007c, 0xee3700ed, 0x387d005b, 0x00000000}},  //   _давл, _мнр_, _arwr_,
  { {0x8c4609da, 0xa9c30088, 0xd90d0014, 0x00000000}},  //   _мебе, дськ, هیم_,
  { {0x80dc0055, 0x995800b9, 0x3f9824ac, 0x00000000}},  //   _মৃত্, _též_, _koru_,
  { {0x81d00044, 0x752f0036, 0x00000000, 0x00000000}},  //   ষতি_, wacz,   ,
  { {0xf09f0011, 0x3f982479, 0x7a110089, 0x00000000}},  //   _ngàn_, _moru_, _tāta,
  { {0x69db009d, 0x00000000, 0x00000000, 0x00000000}},  //   coue,   ,   ,
  { {0xf76f007a, 0x69c000b0, 0x212b01ee, 0x00000000}},  //   رای_, mime, _rech_,
  { {0x67ef0030, 0x200b0091, 0x212b061d, 0x00000000}},  //   tøje, _ruci_, _sech_,
  { {0x200b24ad, 0x212b054e, 0xdce000b9, 0x00000000}},  //   _suci_, _pech_, _pamě,
  { {0xdb1824ae, 0x660400e0, 0x76480022, 0x00000000}},  //   diví, _giik, mudy,
  { {0x9abc01d5, 0x3f9822d9, 0x859c009b, 0x00000000}},  // [6050] _deċi, _boru_, _כשהו,
  { {0xa2d602fb, 0x4429107e, 0x69c00715, 0x00000000}},  //   _मुक्, _iwa_, hime,
  { {0x69c00065, 0x69c900b0, 0x442924af, 0x00000000}},  //   kime, ynee, _hwa_,
  { {0x44290be3, 0xdd9100a1, 0x200b0107, 0x00000000}},  //   _kwa_, رڈز_, _tuci_,
  { {0x3f98022b, 0x0c2401fb, 0x800900a1, 0x00000000}},  //   _foru_, дмін, _درجہ_,
  { {0x44290f59, 0xb09a00b6, 0x3f980107, 0x00000000}},  //   _mwa_, _הישר, _goru_,
  { {0x44290263, 0x69c024b0, 0x69c9040f, 0x00000000}},  //   _lwa_, fime, tnee,
  { {0x69c00238, 0xdb030051, 0x3f9804eb, 0x00000000}},  //   gime, ghná, _zoru_,
  { {0x69c90007, 0x44290263, 0x66040004, 0x00000000}},  //   rnee, _nwa_, _riik,
  { {0x7c290016, 0x69c924b1, 0x660424b2, 0x00000000}},  //   _iwer, snee, _siik,
  { {0x4429011c, 0x69c00ab1, 0x672102aa, 0x00000000}},  //   _awa_, bime, rblj,
  { {0x69c002d5, 0x44290263, 0x7c290009, 0x00000000}},  //   cime, _bwa_, _kwer,
  { {0x6604021e, 0x31690032, 0xd4da007e, 0x00000000}},  //   _viik, deaz_, сьні_,
  { {0x442924b3, 0x394d0030, 0xf7710b03, 0x00000000}},  //   _dwa_, lges_, _سات_,
  { {0xa2d60201, 0x66e2012b, 0x386d1ffe, 0x00000000}},  //   _मुख्, _поша, lwer_,
  { {0x44290263, 0x394d0038, 0x3f98011f, 0x00000000}},  //   _fwa_, nges_, _soru_,
  { {0x442924a8, 0x799901c3, 0x6ed4006e, 0x00000000}},  // [6060] _gwa_, _moww, _बुजु,
  { {0xe457007b, 0x69c024b4, 0xe3b200a6, 0x00000000}},  //   _צייט_, zime, _سرخ_,
  { {0x3f98009f, 0xdfcf0379, 0x386d010f, 0x00000000}},  //   _voru_, ديل_, hwer_,
  { {0x24801097, 0x69c01a50, 0x21020006, 0x00000000}},  //   _krim_, xime, _ačiū_,
  { {0xdca3025f, 0x69c00851, 0x3f9824b5, 0x00000000}},  //   наци, vime, _toru_,
  { {0x7fd601ff, 0x7c290112, 0x69c001c3, 0x00000000}},  //   _хімі, _dwer, wime,
  { {0x89d80076, 0x386d10c5, 0x7c290168, 0x00000000}},  //   يوتر_, ewer_, _ewer,
  { {0x394d01e3, 0x00000000, 0x00000000, 0x00000000}},  //   gges_,   ,   ,
  { {0x7c29056a, 0x8c43007c, 0xbb46005e, 0x00000000}},  //   _gwer, _пете, _неак,
  { {0x69c00993, 0x44290045, 0x6c330025, 0x00000000}},  //   sime, _rwa_, _أفلا,
  { {0x45d501f9, 0x442901aa, 0x6b880030, 0x00000000}},  //   донс, _swa_, _indg,
  { {0x2480088f, 0x442901aa, 0x6b9a1820, 0x00000000}},  //   _brim_, _pwa_, _hotg,
  { {0x248000d4, 0xd7fa01c0, 0x18670256, 0x00000000}},  //   _crim_, _лук_, _наци_,
  { {0x083b00b6, 0x75ff001e, 0xb4bd0164, 0x00000000}},  //   _פעול, _mūzi, _आधी_,
  { {0xcfc40044, 0xd6cf005c, 0x3169002d, 0x00000000}},  //   ্তান, _чт_, teaz_,
  { {0x44290263, 0x6b9a24b6, 0x24800145, 0x00000000}},  //   _twa_, _lotg, _frim_,
  { {0x24800875, 0x442921a4, 0x31691424, 0x00000000}},  // [6070] _grim_, _uwa_, reaz_,
  { {0xdefb007c, 0x7c290045, 0x06fd013e, 0x00000000}},  //   бые_, _rwer, čívá_,
  { {0x7c29095b, 0x3ea70010, 0xc7d7009b, 0x00000000}},  //   _swer, ánt_, לומי_,
  { {0x23490123, 0x386d0007, 0x7c291a62, 0x00000000}},  //   _اسکی_, ywer_, _pwer,
  { {0x7c290082, 0xeb9910f2, 0x799901d6, 0x00000000}},  //   _qwer, жил_, _roww,
  { {0x1af10044, 0x92580123, 0x00000000, 0x00000000}},  //   _চলবে_, _بشیر_,   ,
  { {0x394d04bd, 0x00000000, 0x00000000, 0x00000000}},  //   tges_,   ,   ,
  { {0xcda9007a, 0x394d2271, 0x7c290066, 0x00000000}},  //   _بهره_, uges_, _twer,
  { {0x386d00bb, 0x65760145, 0x6b9a0203, 0x00000000}},  //   uwer_, _rayh, _fotg,
  { {0xdb010010, 0x394d009d, 0x79990085, 0x00000000}},  //   _ellá, sges_, _woww,
  { {0x386d00ab, 0x0f5800a3, 0xc9870216, 0x00000000}},  //   swer_, ליזם_, _нуди,
  { {0x248023b4, 0x63be0022, 0x00000000, 0x00000000}},  //   _prim_, _smpn,   ,
  { {0xe7390423, 0x00000000, 0x00000000, 0x00000000}},  //   _дел_,   ,   ,
  { {0xdb0a1889, 0x7bc3006c, 0x98140025, 0x00000000}},  //   lifò, ninu, _أبنا,
  { {0x91e6005e, 0x98a40006, 0x21760878, 0x00000000}},  //   дове, ramą_, муар,
  { {0x24800bd3, 0x7bc30058, 0xf8e10061, 0x00000000}},  //   _trim_, hinu, _पडाय,
  { {0x91e3003b, 0x7bc3179b, 0x6283004a, 0x00000000}},  // [6080] тоте, kinu, _ánon,
  { {0xdfcf0054, 0x7bc30704, 0x249f010f, 0x00000000}},  //   ليق_, jinu, äume_,
  { {0x7bc324b7, 0x7e562329, 0xe12600e2, 0x00000000}},  //   dinu, ьтац, _омни,
  { {0x26130181, 0x00000000, 0x00000000, 0x00000000}},  //   _mão_,   ,   ,
  { {0x3ea6001e, 0x26130011, 0x6b9a0007, 0x00000000}},  //   ņot_, _lão_, _potg,
  { {0x7bc30004, 0xbf9b009d, 0x09d60061, 0x00000000}},  //   ginu, _quêt, डक्य,
  { {0x261302d5, 0x00000000, 0x00000000, 0x00000000}},  //   _não_,   ,   ,
  { {0xc8080082, 0xa8a610f3, 0x00000000, 0x00000000}},  //   _hởi_, дрок,   ,
  { {0x7bc3006c, 0x00000000, 0x00000000, 0x00000000}},  //   binu,   ,   ,
  { {0x26130011, 0x6b881c8c, 0x7bc30035, 0x00000000}},  //   _bão_, _undg, cinu,
  { {0x7c220051, 0x26130181, 0x00000000, 0x00000000}},  //   lpor, _cão_,   ,
  { {0xf64f026c, 0x26130181, 0xfaa30072, 0x00000000}},  //   گئی_, _dão_, _шахо,
  { {0x7c22002d, 0x79fb009b, 0xe4e40088, 0x00000000}},  //   npor, _ולאח, вірн,
  { {0xf1bf009f, 0x29020006, 0x1af10044, 0x00000000}},  //   _smá_, žkas_, _চলতে_,
  { {0x644606d5, 0xdce20095, 0x00000000, 0x00000000}},  //   arki, ydoğ,   ,
  { {0x260703d7, 0x250900a6, 0x7bc309e3, 0x00000000}},  //   _सूची_, _عربی_, zinu,
  { {0x765a24b8, 0x00000000, 0x00000000, 0x00000000}},  // [6090] ltty,   ,   ,
  { {0xc808001d, 0x7c220387, 0x44391b5a, 0x00000000}},  //   _bởi_, dpor, mss_,
  { {0x4439001e, 0x7c2224b9, 0x2bdd0309, 0x00000000}},  //   lss_, epor, यवसा,
  { {0x386624ba, 0x7c2201c3, 0x4439004a, 0x00000000}},  //   _opor_, fpor, oss_,
  { {0x44391263, 0x7bc324bb, 0x7c22118a, 0x00000000}},  //   nss_, tinu, gpor,
  { {0xdb1807fd, 0x765a0109, 0x5ba90204, 0x00000000}},  //   tivá, ktty, कसेव,
  { {0xc808001d, 0x7bc3127b, 0xbed5003b, 0x00000000}},  //   _gởi_, rinu, _човј,
  { {0x4439001e, 0x7bc30b1a, 0xceb20104, 0x00000000}},  //   kss_, sinu, _עין_,
  { {0x26130fb3, 0x31790046, 0xf77100b8, 0x00000000}},  //   _são_, _masz_, هاد_,
  { {0x26130181, 0x44390087, 0x765a068f, 0x00000000}},  //   _pão_, dss_, ftty,
  { {0x65c600d7, 0x443b006b, 0x60c90c8a, 0x00000000}},  //   ебна, _avq_, _žeml,
  { {0x26130181, 0xb17b0d32, 0x99840025, 0x00000000}},  //   _vão_, _skån, _للمو,
  { {0xa8a701ef, 0x798b06be, 0x160b013d, 0x00000000}},  //   _تصاو, _ingw, _संकर_,
  { {0x26130181, 0x889a009b, 0x00000000, 0x00000000}},  //   _tão_, _מבני,   ,
  { {0x36660265, 0x80ec0044, 0x765a24bc, 0x00000000}},  //   _защо_, _কলেজ_, ctty,
  { {0x7d1b002b, 0x395f0068, 0x443906ed, 0x00000000}},  //   _nfus, nfus_, bss_,
  { {0xa0670200, 0x65640061, 0x44392123, 0x00000000}},  // [60a0] ната_, _ibih, css_,
  { {0x4420000d, 0x7d1b24bd, 0x00000000, 0x00000000}},  //   _iti_, _afus,   ,
  { {0x44200093, 0x6da6017f, 0x2f150010, 0x00000000}},  //   _hti_, нижа, _súgó_,
  { {0x442004d4, 0x7c22016e, 0xd1ba00a1, 0x00000000}},  //   _kti_, tpor, _راجا_,
  { {0x61e601d5, 0x442000e5, 0x00000000, 0x00000000}},  //   _ikkl, _jti_,   ,
  { {0x442013df, 0xa01b03a2, 0x798b0173, 0x00000000}},  //   _mti_, _krön, _angw,
  { {0x3866011f, 0x6905005f, 0xed6301dc, 0x00000000}},  //   _spor_, ərdə, íží_,
  { {0x443902e1, 0xfce60088, 0xdbd2006c, 0x00000000}},  //   yss_, _зобо, lüüs,
  { {0x6d40005f, 0xc7c6025f, 0x442024be, 0x00000000}},  //   _idma, есни, _nti_,
  { {0x67e6000c, 0x65640c4a, 0x7ae801c3, 0x00000000}},  //   yðju, _abih, _tydt,
  { {0x44201567, 0xffb7007b, 0xa9260216, 0x00000000}},  //   _ati_, גליש_, _здел,
  { {0x7bc10027, 0x200a24bf, 0x798b00e0, 0x00000000}},  //   _zmlu, _libi_, _gngw,
  { {0x443901c5, 0x765a24c0, 0x69c20022, 0x00000000}},  //   uss_, stty, _imoe,
  { {0x443911ef, 0x44200253, 0x75f6013e, 0x00000000}},  //   rss_, _dti_, váze,
  { {0x6d400119, 0x442024c1, 0xa785007a, 0x00000000}},  //   _odma, _eti_, _جشنو,
  { {0x44200fa2, 0x44390145, 0xdb180103, 0x00000000}},  //   _fti_, pss_, livä,
  { {0x656f0020, 0x200a0020, 0x00000000, 0x00000000}},  // [60b0] mech, _bibi_,   ,
  { {0xdb01021e, 0x6d4000b5, 0x75f600b9, 0x00000000}},  //   _yllä, _adma, ráze,
  { {0x644f0c2e, 0xa01b0039, 0x645d006c, 0x00000000}},  //   luci, _grön, ltsi,
  { {0x657d008d, 0x656f0161, 0x7bc100b9, 0x00000000}},  //   ndsh, nech, _smlu,
  { {0x644f24c2, 0x645d24c3, 0x2129020c, 0x00000000}},  //   nuci, ntsi, mbah_,
  { {0x61ed0047, 0x200a011f, 0xcb660794, 0x00000000}},  //   llal, _gibi_, ваше_,
  { {0x9e350088, 0x645d006c, 0x656f00e7, 0x00000000}},  //   _шевч, htsi, kech,
  { {0x645d0004, 0x9f410065, 0x644f007f, 0x00000000}},  //   ktsi, kohë_, kuci,
  { {0x644f041a, 0x656f137e, 0x61ed0fd5, 0x00000000}},  //   juci, dech, ilal,
  { {0x644f20e8, 0x81d70044, 0xb17b1a96, 0x00000000}},  //   duci, িতি_, _skål,
  { {0x4420001a, 0x61ed01ee, 0x2d9f0007, 0x00000000}},  //   _sti_, klal, _koue_,
  { {0x644f027b, 0x2d9f0e16, 0x4420009d, 0x00000000}},  //   fuci, _joue_, _pti_,
  { {0x81d70055, 0x644f0107, 0xe4e5007e, 0x00000000}},  //   িতা_, guci, гіён,
  { {0xf74508d6, 0xf8b6009b, 0x2d9f009d, 0x00000000}},  //   _реко, _בפני_, _loue_,
  { {0x645d17c6, 0xf770002c, 0x39980010, 0x00000000}},  //   atsi, _دان_, _rész_,
  { {0x644f049a, 0x61ed24c4, 0x200a01aa, 0x00000000}},  //   buci, glal, _sibi_,
  { {0x644f24c5, 0x44201335, 0x6285010f, 0x00000000}},  // [60c0] cuci, _uti_, _erho,
  { {0x61ed011c, 0x00000000, 0x00000000, 0x00000000}},  //   alal,   ,   ,
  { {0x25a00022, 0xdb1802e1, 0x21290145, 0x00000000}},  //   _koil_, nivå, bbah_,
  { {0x90c6008b, 0x290f10ed, 0x00000000, 0x00000000}},  //   _абме, _ngga_,   ,
  { {0x61e400b0, 0x2d9f00d4, 0x200a20e3, 0x00000000}},  //   moil, _doue_, _tibi_,
  { {0x656f0046, 0x69c200bb, 0x61e400b0, 0x00000000}},  //   zech, _smoe, loil,
  { {0x644f0036, 0x656f00e7, 0xdce00089, 0x00000000}},  //   zuci, yech, _pamē,
  { {0xf2d3009b, 0x497417da, 0x61e400b0, 0x00000000}},  //   יעו_, улис, noil,
  { {0x656f0211, 0x645d0203, 0xdb180bac, 0x00000000}},  //   vech, xtsi, tivä,
  { {0x656f12dc, 0x644f016e, 0x61e40c7f, 0x00000000}},  //   wech, vuci, hoil,
  { {0xe5350eec, 0x61e400b0, 0x8f370049, 0x00000000}},  //   лень, koil, כטיג_,
  { {0x644f049a, 0xa01b0039, 0xb5a70242, 0x00000000}},  //   tuci, _bröl, трой,
  { {0x656f24c6, 0x657d0ff3, 0x645d0009, 0x00000000}},  //   rech, rdsh, utsi,
  { {0x645d022b, 0x656f0211, 0xc7b000a1, 0x00000000}},  //   rtsi, sech, _چڑھ_,
  { {0x645d24c7, 0x656f2061, 0x764f0036, 0x00000000}},  //   stsi, pech, ącyc,
  { {0x628500ee, 0x644f24c8, 0x645d050d, 0x00000000}},  //   _vrho, puci, ptsi,
  { {0x61ed0149, 0x2d9f009d, 0x21291087, 0x00000000}},  // [60d0] rlal, _roue_, rbah_,
  { {0x21290145, 0x4ea70216, 0x2d8d00d9, 0x00000000}},  //   sbah_, креа, _snee_,
  { {0xdbdc000c, 0x660d1658, 0xe45f00b0, 0x00000000}},  //   _ráðh, _kiak, ltö_,
  { {0x61e40051, 0x9c5924c9, 0x1c391001, 0x00000000}},  //   coil, ешку_, езды_,
  { {0x660d000b, 0xfeb80014, 0x60090006, 0x00000000}},  //   _miak, _یافت_, _užmo,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68eb0030, 0x75f60010, 0xaa56003b, 0x00000000}},  //   _sygd, háza, гију_,
  { {0x1619006e, 0x75f606b8, 0x99f5007e, 0x00000000}},  //   _नंबर_, káza, ыялі,
  { {0x76b3006b, 0xf1b400a0, 0x00000000, 0x00000000}},  //   məyə, יסק_,   ,
  { {0x76b3006b, 0x25a024ca, 0x660d1968, 0x00000000}},  //   ləyə, _soil_, _aiak,
  { {0xadc30011, 0x25a0009d, 0x660d0022, 0x00000000}},  //   _giản, _poil_, _biak,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x660d0169, 0xa7850318, 0x61e424cb, 0x00000000}},  //   _diak, _مشغو, voil,
  { {0xb88201ca, 0x69c90abf, 0x00000000, 0x00000000}},  //   čítk, liee,   ,
  { {0x614600da, 0xa01b0039, 0x61e400b0, 0x00000000}},  //   лева, _dröm, toil,
  { {0x69c90116, 0xa01b01e5, 0x00000000, 0x00000000}},  //   niee, _tröl,   ,
  { {0x61e400b0, 0x75f6004a, 0x1f660888, 0x00000000}},  // [60e0] roil, cáza, лкам,
  { {0xb35800a1, 0x6497009b, 0x61e40358, 0x00000000}},  //   _جیسا_, _עדיף_, soil,
  { {0x443224cc, 0x4d4a0aa2, 0x69c924cd, 0x00000000}},  //   _hwy_, епен_, kiee,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xac9402ea, 0x00000000, 0x00000000, 0x00000000}},  //   ралш,   ,   ,
  { {0x4432018e, 0xeb970264, 0x9bc80025, 0x00000000}},  //   _mwy_, лич_, ضوعك_,
  { {0x69c90328, 0x00000000, 0x00000000, 0x00000000}},  //   fiee,   ,   ,
  { {0xdb080039, 0x69c9006c, 0x60c90006, 0x00000000}},  //   _omdö, giee, _žemi,
  { {0x44320016, 0x660d1166, 0x00000000, 0x00000000}},  //   _nwy_, _riak,   ,
  { {0x473400ed, 0x660d05cd, 0x75f61f92, 0x00000000}},  //   шнос, _siak, váza,
  { {0x80cb01f5, 0x17f70025, 0x7bca0203, 0x00000000}},  //   _सेने, درية_, mifu,
  { {0xe9da0088, 0x7bca0020, 0x69c900bb, 0x00000000}},  //   _яке_, lifu, ciee,
  { {0xe973007a, 0x2bdb013d, 0x81ab0044, 0x00000000}},  //   _دهند, _बदमा, কোড_,
  { {0x44320016, 0x7bca24ce, 0x75f60010, 0x00000000}},  //   _dwy_, nifu, ráza,
  { {0x171b007b, 0x62351534, 0xe45f00b0, 0x00000000}},  //   _אווע, ребу, stö_,
  { {0x1619001c, 0x4432018e, 0x27fc0082, 0x00000000}},  //   _नंतर_, _fwy_, _hhvn_,
  { {0x7bca0020, 0x2a6c0022, 0x2f1901ab, 0x00000000}},  // [60f0] kifu, _lpdb_, возь_,
  { {0x7bca000b, 0x24890173, 0x673a24cf, 0x00000000}},  //   jifu, _iram_, natj,
  { {0x76b3006b, 0x0dcb00ec, 0x248904eb, 0x00000000}},  //   təyə, нуди_, _hram_,
  { {0x24890039, 0x673a0010, 0xd657009b, 0x00000000}},  //   _kram_, hatj, ריאת_,
  { {0xa91d07a6, 0x00000000, 0x00000000, 0x00000000}},  //   ndže,   ,   ,
  { {0x673a0023, 0x7bca1233, 0x00000000, 0x00000000}},  //   jatj, gifu,   ,
  { {0x3f910009, 0x69c914e0, 0x00000000, 0x00000000}},  //   _inzu_, tiee,   ,
  { {0x629a00b0, 0x395902fa, 0x24890048, 0x00000000}},  //   ätoi, üss_, _oram_,
  { {0xc7950147, 0x69c900b5, 0xa91d04eb, 0x00000000}},  //   арны, riee, jdže,
  { {0x3f8124d0, 0x44320016, 0x69c901d6, 0x00000000}},  //   ndhu_, _rwy_, siee,
  { {0x7bfa007b, 0x2c1d0044, 0x69c900b5, 0x00000000}},  //   _ספעצ, _নিয়ে_, piee,
  { {0x4432018e, 0x69330167, 0x248910ae, 0x00000000}},  //   _pwy_, _اکثر, _bram_,
  { {0x673a01d6, 0x27e500ca, 0xb4c20316, 0x00000000}},  //   batj, poln_, ्पे_,
  { {0xf7710644, 0xa01b0039, 0xd3480014, 0x00000000}},  //   _ذات_, _tröj, دیده_,
  { {0x24891f5b, 0xa01b18f7, 0x75360095, 0x00000000}},  //   _eram_, _frök, _teyz,
  { {0x248924d1, 0xdb010181, 0x2b45009d, 0x00000000}},  //   _fram_, _polê, _ldlc_,
  { {0x7bca0009, 0x00000000, 0x00000000, 0x00000000}},  // [6100] yifu,   ,   ,
  { {0x6d5b24d2, 0xee0e0309, 0xc43b009b, 0x00000000}},  //   _acua, िद्ध_, _שתיי,
  { {0xdb010023, 0x00000000, 0x00000000, 0x00000000}},  //   _dolë,   ,   ,
  { {0x93250014, 0x4c860081, 0x22db08cd, 0x00000000}},  //   _پرین, илев, _יחיא,
  { {0x272200b9, 0x7bca0197, 0x6e290059, 0x00000000}},  //   nční_, tifu, _čebe,
  { {0x6d5b0211, 0xdb0101aa, 0x2a6c0093, 0x00000000}},  //   _ecua, _kolè, _ppdb_,
  { {0x2d960121, 0x7bca000c, 0x00000000, 0x00000000}},  //   _крас, rifu,   ,
  { {0xdca60069, 0x272201dc, 0x3869001a, 0x00000000}},  //   _каби, kční_, _ţara_,
  { {0x673a0010, 0xb997007c, 0x1d0700ed, 0x00000000}},  //   tatj, рвых_, _вети_,
  { {0x07b806ea, 0x2c600173, 0x00000000, 0x00000000}},  //   اهدة_, mòd_,   ,
  { {0x673a00d4, 0x24890213, 0xdce0007f, 0x00000000}},  //   ratj, _sram_, _pamė,
  { {0x5886008b, 0xa01b01a2, 0xc8c700a2, 0x00000000}},  //   _выка, _fröh, اوین_,
  { {0x5454007c, 0x39460978, 0x00000000, 0x00000000}},  //   овят, _idos_,   ,
  { {0x9f580b32, 0x533424d3, 0x60c9013f, 0x00000000}},  //   _miró_, жерт, _ümmə,
  { {0x31c7008b, 0xdb01009d, 0x2722093f, 0x00000000}},  //   асав, _colè, ační_,
  { {0x24890129, 0xa535007c, 0x00000000, 0x00000000}},  //   _tram_, _унич,   ,
  { {0x753d115b, 0x40590070, 0x00000000, 0x00000000}},  // [6110] masz, طلاح_,   ,
  { {0x753d0047, 0x2fc7001d, 0xdf390054, 0x00000000}},  //   lasz, òng_, اكات_,
  { {0x39460006, 0x3ea71a5e, 0x3f810145, 0x00000000}},  //   _odos_, ânt_, rdhu_,
  { {0x753d0010, 0x2b450022, 0xac190131, 0x00000000}},  //   nasz, _sdlc_, году_,
  { {0xbc4800ed, 0x442b0082, 0x63a50994, 0x00000000}},  //   ачје_, npc_, _kohn,
  { {0x67380243, 0x394624d4, 0x753d0010, 0x00000000}},  //   _nevj, _ados_, hasz,
  { {0xe1ff001d, 0x21390065, 0x753d0c59, 0x00000000}},  //   _khó_, _kesh_, kasz,
  { {0x2011000b, 0x21390065, 0x63a5010f, 0x00000000}},  //   _hizi_, _jesh_, _lohn,
  { {0xdb0124d5, 0x39460082, 0x213900ab, 0x00000000}},  //   _molé, _ddos_, _mesh_,
  { {0x20190036, 0x2795007c, 0xdcfb0006, 0x00000000}},  //   _musi_, сшир, _jauč,
  { {0x6b9c0129, 0x201100ca, 0x67380066, 0x00000000}},  //   _òrga, _mizi_, _devj,
  { {0x6d590503, 0x21390065, 0x753d0010, 0x00000000}},  //   ngwa, _nesh_, gasz,
  { {0xdb010263, 0x6b810058, 0xdd7a0049, 0x00000000}},  //   _solè, _kalg, נטשל,
  { {0x6b810004, 0xdcfb0119, 0x272200b9, 0x00000000}},  //   _jalg, _nauč, rční_,
  { {0x6b810e6d, 0x213924d6, 0x2c6001aa, 0x00000000}},  //   _malg, _besh_, zòd_,
  { {0xdb010181, 0xe1ff0011, 0x20191750, 0x00000000}},  //   _colé, _chó_, _busi_,
  { {0x2011022b, 0x2120014a, 0x3ff60025, 0x00000000}},  // [6120] _bizi_, rcih_, مكرر,
  { {0x6b81008e, 0xc49b009b, 0x2a690036, 0x00000000}},  //   _nalg, _עשית, łaby_,
  { {0x2011011f, 0x764102b4, 0x91e60517, 0x00000000}},  //   _dizi_, nsly, _гоне,
  { {0x7e4b00a1, 0x20190197, 0x2c6001aa, 0x00000000}},  //   اسلہ_, _fusi_, tòd_,
  { {0x20110173, 0x9f580197, 0x2019008a, 0x00000000}},  //   _fizi_, _dirò_, _gusi_,
  { {0x6b8124d7, 0x6fb61019, 0x09d00061, 0x00000000}},  //   _calg, _امسا, तच्य,
  { {0x7524022b, 0x37cd0044, 0xdce8006b, 0x00000000}},  //   _ofiz, রকার, ılıq,
  { {0x9f5808d3, 0x00000000, 0x00000000, 0x00000000}},  //   _tiró_,   ,   ,
  { {0xa3c903d7, 0x6b8100d4, 0x753d0010, 0x00000000}},  //   लोड_, _falg, vasz,
  { {0xbb430140, 0xe7d60044, 0x907b00a0, 0x00000000}},  //   _неук, হত্য, נטיי,
  { {0x7bdf00f4, 0x753d0c59, 0x63a507e7, 0x00000000}},  //   éque, tasz, _rohn,
  { {0xd6d707ca, 0xceb300a0, 0x644f016c, 0x00000000}},  //   сть_, פיר_, trci,
  { {0x753d108d, 0x8b0300b9, 0xe4e703e8, 0x00000000}},  //   rasz, ěřen, сінн,
  { {0x9f580051, 0x38cb0167, 0xdb0324d8, 0x00000000}},  //   _bhrí_, _حامی_, chnó,
  { {0xdb0124d9, 0x2019011c, 0xe1ff0011, 0x00000000}},  //   _polé, _susi_, _phó_,
  { {0x63a5001f, 0x2011005d, 0xdcfb0521, 0x00000000}},  //   _wohn, _sizi_, _sauč,
  { {0x270e005f, 0x64400841, 0xa91d016c, 0x00000000}},  // [6130] lən_, ámit, ndža,
  { {0x44290197, 0x201901c3, 0x00000000, 0x00000000}},  //   _ita_, _vusi_,   ,
  { {0x270e005f, 0x201124da, 0xdb01009d, 0x00000000}},  //   nən_, _vizi_, _tolé,
  { {0x6b810030, 0x4ac30061, 0x20110020, 0x00000000}},  //   _salg, _वेगव, _wizi_,
  { {0xa3bd024c, 0x64440129, 0x20190368, 0x00000000}},  //   _आता_, _xvii, _uusi_,
  { {0x1ae20055, 0x270e006b, 0x44290232, 0x00000000}},  //   গেছে_, kən_, _mta_,
  { {0xb16e000c, 0x44290052, 0x9f580026, 0x00000000}},  //   _þýði, _lta_, _tirò_,
  { {0x270e005f, 0x6b810007, 0x442900b0, 0x00000000}},  //   dən_, _walg, _ota_,
  { {0x44290061, 0x6b8112e8, 0x2b5e0022, 0x00000000}},  //   _nta_, _talg, _fctc_,
  { {0x656d0061, 0x75240197, 0x7c2924db, 0x00000000}},  //   _abah, _sfiz, _iter,
  { {0x4429008d, 0x69e7008b, 0x366901f9, 0x00000000}},  //   _ata_, _людз, шано_,
  { {0x7c29101c, 0xc329012f, 0x3f8301a3, 0x00000000}},  //   _kter, _יו_, _laju_,
  { {0xf74503f3, 0x7641093b, 0x69cb0095, 0x00000000}},  //   _дело, ssly, _imge,
  { {0x3f8300ca, 0x270e006b, 0x7c2900e7, 0x00000000}},  //   _naju_, bən_, _mter,
  { {0x442924dc, 0x613a24dd, 0x7c2900ea, 0x00000000}},  //   _eta_, ичар_, _lter,
  { {0x7c2901ee, 0x6d490051, 0x00000000, 0x00000000}},  //   _oter, _ndea,   ,
  { {0x3f830d7e, 0x20870077, 0x4dcf0044, 0x00000000}},  // [6140] _baju_, ойти_, িকাং,
  { {0x2480014a, 0x75f601dc, 0x3f831690, 0x00000000}},  //   _isim_, kázk, _caju_,
  { {0x3f8310b5, 0x7c29022b, 0x69cb01b5, 0x00000000}},  //   _daju_, _ater, _omge,
  { {0xf53f05b7, 0x442924de, 0x80cb0061, 0x00000000}},  //   lkår_, _yta_, _सेवे,
  { {0xdca301fc, 0x270e006b, 0x6d490016, 0x00000000}},  //   маци, zən_, _ddea,
  { {0x270e005f, 0x1c3901e1, 0xa01b0039, 0x00000000}},  //   yən_, сяць_, _pröv,
  { {0x0ef9008b, 0x6d490009, 0x2258006c, 0x00000000}},  //   _гэты_, _fdea, nurk_,
  { {0x24800119, 0x298a09bb, 0xdd920014, 0x00000000}},  //   _osim_, рско_, _تور_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x270e006b, 0x37aa00d7, 0x2d840f82, 0x00000000}},  //   tən_, ртин_, _hame_,
  { {0x44291dae, 0x2d84070d, 0x24800583, 0x00000000}},  //   _sta_, _kame_, _asim_,
  { {0x270e005f, 0x2d8624df, 0x2d840006, 0x00000000}},  //   rən_, ndoe_, _jame_,
  { {0x270e005f, 0x2d8409fc, 0xf9d90049, 0x00000000}},  //   sən_, _mame_, _פֿעל,
  { {0x98a3003b, 0x442902d4, 0x2d84060b, 0x00000000}},  //   _циље, _vta_, _lame_,
  { {0xf1a70256, 0xd13b0265, 0x2480021e, 0x00000000}},  //   оран, иха_, _esim_,
  { {0x2d840866, 0x224d1504, 0x44291978, 0x00000000}},  //   _name_, ček_, _tta_,
  { {0x44290035, 0x2bdb007d, 0x1af10044, 0x00000000}},  // [6150] _uta_, _बदला, _চলছে_,
  { {0x4e8b0131, 0x316900fa, 0x00000000, 0x00000000}},  //   ищем_, sfaz_,   ,
  { {0x7c290168, 0xdb0724e0, 0x00000000, 0x00000000}},  //   _ster, ülün,   ,
  { {0x427a007b, 0x127a007b, 0x2d8400ab, 0x00000000}},  //   _פארג, _פארע, _came_,
  { {0x50640242, 0xdce90066, 0xf41f00f8, 0x00000000}},  //   _отра, _mneħ, kväm_,
  { {0x447c007b, 0x61ed06d5, 0x32090173, 0x00000000}},  //   ינדע, loal, lmay_,
  { {0x8d7701f7, 0x2d84051b, 0x00000000, 0x00000000}},  //   _وارا, _fame_,   ,
  { {0x2d841b2a, 0x75f60428, 0xd90f00a6, 0x00000000}},  //   _game_, rázk, نیا_,
  { {0x7c29175b, 0x00000000, 0x00000000, 0x00000000}},  //   _uter,   ,   ,
  { {0x2d840059, 0x61ed0032, 0xdb010142, 0x00000000}},  //   _zame_, hoal, _holí,
  { {0xdb0101ca, 0x2c0a00a1, 0x61ed0052, 0x00000000}},  //   _kolí, _اٹلی_, koal,
  { {0x69cb084a, 0x67ef0030, 0x25a924e1, 0x00000000}},  //   _umge, tøjs, _coal_,
  { {0x60020181, 0x61ed00fa, 0xa3e80164, 0x00000000}},  //   lôme, doal, यकल_,
  { {0x2258014a, 0x23270745, 0x00000000, 0x00000000}},  //   turk_, зори_,   ,
  { {0x60020181, 0x41b6005e, 0x69db24e2, 0x00000000}},  //   nôme, псат, onue,
  { {0xd5b90089, 0x61ed002d, 0x25a900ab, 0x00000000}},  //   spār_, goal, _goal_,
  { {0x55bb009b, 0x2d840213, 0x248001a3, 0x00000000}},  // [6160] _למקו, _rame_, _usim_,
  { {0x2d8424e3, 0xdee6004c, 0x27460048, 0x00000000}},  //   _same_, пози, míní_,
  { {0x64460046, 0xdb010489, 0xa01b0039, 0x00000000}},  //   lski, _bolí, _brös,
  { {0x61ed24e4, 0xdb0100c4, 0x1ea90025, 0x00000000}},  //   coal, _colí, غالي_,
  { {0x644600ee, 0x27460048, 0x2d8600fa, 0x00000000}},  //   nski, níní_, rdoe_,
  { {0x64460006, 0x1af40069, 0x600200fa, 0x00000000}},  //   iski, мпля, fôme,
  { {0xd357007b, 0x6604002d, 0xa01b04ce, 0x00000000}},  //   ליסי_, _ohik, _frös,
  { {0xa01b0002, 0xa9c30088, 0x6446010e, 0x00000000}},  //   _tröt, еськ, kski,
  { {0x60c424e5, 0xf98f0025, 0xa3dc0061, 0x00000000}},  //   nzim, طبي_, ढचा_,
  { {0x25a90169, 0x600200c4, 0x644618a7, 0x00000000}},  //   _soal_, lômb, dski,
  { {0xb8f30183, 0x66040093, 0x32090058, 0x00000000}},  //   _हे_, _bhik, ymay_,
  { {0x66041560, 0x18a6005e, 0x1a9b0049, 0x00000000}},  //   _chik, _наем, _ליבע,
  { {0xafdb0737, 0x64462008, 0x66040162, 0x00000000}},  //   _svøm, gski, _dhik,
  { {0x60c424e6, 0x07a3007e, 0xc7a32337, 0x00000000}},  //   dzim, _пачн, _пичк,
  { {0x61ed0027, 0xdce9002b, 0xd3780088, 0x00000000}},  //   toal, _tneħ, ччя_,
  { {0x521401be, 0x65bf008d, 0x777a002d, 0x00000000}},  //   едст, _bëhe, letx,
  { {0x765a1570, 0x3209014a, 0x27460048, 0x00000000}},  // [6170] luty, rmay_, cíní_,
  { {0x32091904, 0xdb0119d5, 0x61ed0c79, 0x00000000}},  //   smay_, _solí, soal,
  { {0xdb0103d1, 0x4fc4007c, 0x3d0f0061, 0x00000000}},  //   _polí, хста, तेने_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c004ea, 0x8ccd013d, 0xf3ff0181, 0x00000000}},  //   dhme, _देशो, ntão_,
  { {0xeb96017f, 0x6002009d, 0xdb0100fa, 0x00000000}},  //   диш_, tôme, _rolâ,
  { {0xa01b04ce, 0x00000000, 0x00000000, 0x00000000}},  //   _trös,   ,   ,
  { {0xdb08023f, 0x69c0002b, 0x3eae010f, 0x00000000}},  //   _modè, ghme, äfte_,
  { {0xdb0100c4, 0x69db0032, 0x00000000, 0x00000000}},  //   _bolã, rnue,   ,
  { {0x6604008d, 0x69c0012d, 0x00000000, 0x00000000}},  //   _shik, ahme,   ,
  { {0x64460046, 0x60c40026, 0x9be40088, 0x00000000}},  //   wski, zzim, _чітк,
  { {0x69c00c0d, 0x64460091, 0xd7f8001a, 0x00000000}},  //   chme, tski, ală_,
  { {0xb4b8006e, 0x64460006, 0x777a002d, 0x00000000}},  //   चने_, uski, betx,
  { {0x64460046, 0x765a1b27, 0x395f006c, 0x00000000}},  //   rski, buty, lgus_,
  { {0x6446000c, 0xe2f800a1, 0x66040023, 0x00000000}},  //   sski, سورڈ_, _thik,
  { {0x6446037e, 0x395f24e7, 0x7d1b0065, 0x00000000}},  //   pski, ngus_, _ngus,
  { {0xa0670200, 0xa7c60014, 0x60c40091, 0x00000000}},  // [6180] мата_, _رژیم_, uzim,
  { {0x7d1b023a, 0x60c40440, 0xe4570097, 0x00000000}},  //   _agus, rzim, _קייט_,
  { {0x4420028c, 0xa2060088, 0x21490051, 0x00000000}},  //   _hui_, _опод, áthú_,
  { {0x4420061f, 0x602607d8, 0x00000000, 0x00000000}},  //   _kui_, _одма,   ,
  { {0x75e8005d, 0x442000f4, 0x0c7a0076, 0x00000000}},  //   mızd, _jui_, تصاب_,
  { {0x442024e8, 0x6fc0014a, 0x7d1b0288, 0x00000000}},  //   _mui_, _böce, _egus,
  { {0x442024e9, 0x69c008ea, 0x7c3b00e7, 0x00000000}},  //   _lui_, thme, _ewur,
  { {0x4420028c, 0x75e8005a, 0x201824ea, 0x00000000}},  //   _oui_, nızd, _hiri_,
  { {0xf4d90055, 0x6d4024eb, 0xdb0800f4, 0x00000000}},  //   _সর্ব, _iema, _modé,
  { {0x69c021b4, 0x909b00a3, 0xa09b01ce, 0x00000000}},  //   shme, קסיק, קייט,
  { {0x6d4024ec, 0x0f5700b6, 0x201810c3, 0x00000000}},  //   _kema, ויים_, _miri_,
  { {0x6d4024ed, 0xadc30011, 0x201824ee, 0x00000000}},  //   _jema, _miến, _liri_,
  { {0x44200198, 0x6d40020c, 0xf9c700a2, 0x00000000}},  //   _cui_, _mema, _تحلی,
  { {0xa3c903d7, 0x44200007, 0x6d400169, 0x00000000}},  //   लों_, _dui_, _lema,
  { {0xf3ff02d5, 0x442000f6, 0xe1f3002c, 0x00000000}},  //   stão_, _eui_, نسر_,
  { {0x6d4001cd, 0x4420029d, 0x3944008f, 0x00000000}},  //   _nema, _fui_, nams_,
  { {0x7c2024ef, 0x2018038c, 0xdbd617f9, 0x00000000}},  // [6190] _numr, _biri_, _kään,
  { {0x657d0065, 0x645d24f0, 0x6b8800d0, 0x00000000}},  //   lesh, musi, _nadg,
  { {0x6d400007, 0x2018027e, 0x39440964, 0x00000000}},  //   _bema, _diri_, kams_,
  { {0x657d0020, 0x3944030b, 0xdbd60cfc, 0x00000000}},  //   nesh, jams_, _lään,
  { {0x6d40032c, 0x394408ad, 0x7c200051, 0x00000000}},  //   _dema, dams_, _cumr,
  { {0x657d23d3, 0x20180207, 0x6d40006c, 0x00000000}},  //   hesh, _giri_, _eema,
  { {0x645d000b, 0x6d4024f1, 0xadc30082, 0x00000000}},  //   husi, _fema, _giến,
  { {0x6d40046a, 0x657d0714, 0x645d24f2, 0x00000000}},  //   _gema, jesh, kusi,
  { {0x395f24f3, 0x657d238d, 0x645d0d90, 0x00000000}},  //   rgus_, desh, jusi,
  { {0x6b880056, 0x645d0a0e, 0x44200559, 0x00000000}},  //   _gadg, dusi, _rui_,
  { {0x44200198, 0xf1bf0181, 0x62850020, 0x00000000}},  //   _sui_, _olá_, _nsho,
  { {0x3944136b, 0x4420001a, 0x657d016e, 0x00000000}},  //   cams_, _pui_, gesh,
  { {0x44200a8d, 0x645d022b, 0x62851bb7, 0x00000000}},  //   _qui_, gusi, _asho,
  { {0x4420001d, 0x66e505a4, 0x43750954, 0x00000000}},  //   _vui_, _пола, куст,
  { {0xf770025a, 0x645d010a, 0xdb0824f4, 0x00000000}},  //   _خان_, ausi, _podé,
  { {0x20180518, 0x442024f5, 0x62851add, 0x00000000}},  //   _siri_, _tui_, _dsho,
  { {0x6d4024f6, 0x62850161, 0x394f0093, 0x00000000}},  // [61a0] _rema, _esho, _mdgs_,
  { {0x6d40020c, 0x0479007a, 0x628501cf, 0x00000000}},  //   _sema, _کلیک_, _fsho,
  { {0x6d40020c, 0x20180059, 0x6b880c8a, 0x00000000}},  //   _pema, _viri_, _radg,
  { {0x10a601e0, 0x2018002b, 0x6d400065, 0x00000000}},  //   _зимн, _wiri_, _qema,
  { {0x6b8801d6, 0x39440006, 0x201816d5, 0x00000000}},  //   _padg, vams_, _tiri_,
  { {0xf09f00ad, 0xadc3001d, 0xdb0124f7, 0x00000000}},  //   _ngày_, _tiến, _solá,
  { {0x6d4024f8, 0x6b8a001c, 0x657d1ea5, 0x00000000}},  //   _tema, rdfg, yesh,
  { {0xdbd6021e, 0xc5f90089, 0x75fd0010, 0x00000000}},  //   _sään, ntēt_, tézm,
  { {0x39440d90, 0x657d0065, 0xdb0105d2, 0x00000000}},  //   rams_, vesh, _volá,
  { {0x7bc3001f, 0x645d0006, 0x76480039, 0x00000000}},  //   chnu, vusi, tsdy,
  { {0x657d0065, 0xd6da0152, 0xab690076, 0x00000000}},  //   tesh, яти_, _تحقق_,
  { {0x645d24f9, 0x3f8a24fa, 0x76480022, 0x00000000}},  //   tusi, _labu_, rsdy,
  { {0x657d24fb, 0x7afa113b, 0xc8b30014, 0x00000000}},  //   resh, _hytt, _مصوب,
  { {0x5ea60055, 0x645d24e7, 0x657d0e06, 0x00000000}},  //   _গেছে, rusi, sesh,
  { {0x645d1544, 0x657d0a9e, 0x61e1004a, 0x00000000}},  //   susi, pesh, éllo,
  { {0x645d13b1, 0x657d0065, 0x61e90c8a, 0x00000000}},  //   pusi, qesh, čelo,
  { {0x7afa0637, 0x3f8a24fc, 0x62850009, 0x00000000}},  // [61b0] _lytt, _babu_, _wsho,
  { {0x644d0006, 0x628501c3, 0x600200c4, 0x00000000}},  //   _ivai, _tsho, tôma,
  { {0x7afa198e, 0x62850ea6, 0x8e990025, 0x00000000}},  //   _nytt, _usho, بناء_,
  { {0x644d0006, 0x3eae00f8, 0x00000000, 0x00000000}},  //   _kvai, äfta_,   ,
  { {0x628a01e5, 0x00000000, 0x00000000, 0x00000000}},  //   _áfor,   ,   ,
  { {0x7afa24fd, 0x82340014, 0x3f8a0ea9, 0x00000000}},  //   _bytt, _جریا, _gabu_,
  { {0xa91d0006, 0x68fc006b, 0xf9910025, 0x00000000}},  //   ldži, ərdi, لبة_,
  { {0x5975008b, 0x644d1003, 0xa91d0006, 0x00000000}},  //   тыку, _ovai, odži,
  { {0xa91d010a, 0x3f8a00e0, 0x00000000, 0x00000000}},  //   ndži, _yabu_,   ,
  { {0xa91d0006, 0xd047006b, 0xd7ee0025, 0x00000000}},  //   idži, çməs, يكي_,
  { {0x644d24fe, 0xd7090057, 0x7bc12293, 0x00000000}},  //   _avai, ьное_, _illu,
  { {0x2b470048, 0x00000000, 0x00000000, 0x00000000}},  //   lanc_,   ,   ,
  { {0x81d70044, 0xa91d003b, 0x00000000, 0x00000000}},  //   াকা_, jdži,   ,
  { {0x2b47133d, 0xa6950184, 0x386d05b4, 0x00000000}},  //   nanc_, _ариј, mter_,
  { {0x3f8a0169, 0x386d03a1, 0x4343005e, 0x00000000}},  //   _rabu_, lter_, ресв,
  { {0x3f8a24ff, 0x75f60010, 0x26880025, 0x00000000}},  //   _sabu_, rázs, _أخوي_,
  { {0x386d2500, 0x7bc1021e, 0xc5f90089, 0x00000000}},  // [61c0] nter_, _ollu, rtēt_,
  { {0x386d010f, 0x798b2501, 0xe29a003b, 0x00000000}},  //   iter_, _lagw, _жао_,
  { {0x386d02ae, 0x644d0e3f, 0x75f6008e, 0x00000000}},  //   hter_, _zvai, lázq,
  { {0x7bc101d5, 0x0696007b, 0x7afa0193, 0x00000000}},  //   _allu, כדעם_, _rytt,
  { {0x386d0039, 0xdb01006b, 0xa3c9007d, 0x00000000}},  //   jter_, _yolç, लोक_,
  { {0x4432004a, 0x75fd0010, 0x386d0287, 0x00000000}},  //   _mty_, tézk, dter_,
  { {0xe9e601e0, 0x0a6a00ed, 0x29000006, 0x00000000}},  //   кцио, фрли_, _šia_,
  { {0x386d00eb, 0xa967012b, 0x7bc1006c, 0x00000000}},  //   fter_, вића_, _ellu,
  { {0xbc6a03ec, 0x386d2502, 0xa3c2006e, 0x00000000}},  //   _زمان_, gter_, ंसा_,
  { {0x2cc40279, 0x7afa00b0, 0xdb080142, 0x00000000}},  //   ırdı_, _tytt, _hodí,
  { {0x4432008d, 0x06d50055, 0x386d00ab, 0x00000000}},  //   _aty_, _সুবি, ater_,
  { {0x443200e0, 0x386d01a2, 0x00000000, 0x00000000}},  //   _bty_, bter_,   ,
  { {0x386d028c, 0x44320011, 0xdb18006c, 0x00000000}},  //   cter_, _cty_, rivõ,
  { {0x9f9a0004, 0xa91d016c, 0x7bd80883, 0x00000000}},  //   _jääb_, vdži, nivu,
  { {0x24180783, 0x69c20112, 0x26da006c, 0x00000000}},  //   торы_, _kloe, _äpo_,
  { {0x11d90054, 0x31c40918, 0xe7170097, 0x00000000}},  //   روءة_, асув, _בחור_,
  { {0x3495008b, 0x7bd82503, 0xa91d0006, 0x00000000}},  // [61d0] _сапр, kivu, udži,
  { {0xa91d2029, 0x69c2018e, 0xa28300a6, 0x00000000}},  //   rdži, _lloe, _پیرو,
  { {0xa91d2504, 0x7e2805b8, 0x386d0e49, 0x00000000}},  //   leže, віча_, zter_,
  { {0x386d01c9, 0x1eea0167, 0xdb03010f, 0x00000000}},  //   yter_, رونی_, rknü,
  { {0x386d0039, 0xf1a4007e, 0x6adb0164, 0x00000000}},  //   xter_, _трэн, यप्र,
  { {0xadc3001d, 0x7aed0279, 0x8f6700a1, 0x00000000}},  //   _thắn, şatm, _جلسے_,
  { {0x69c20100, 0x2b4700ca, 0x798b011c, 0x00000000}},  //   _bloe, ranc_, _pagw,
  { {0xceb2052f, 0x69c22505, 0x24890091, 0x00000000}},  //   _פין_, _cloe, _osam_,
  { {0x386d028c, 0x5c99008b, 0x7bd82506, 0x00000000}},  //   uter_, _якая_, bivu,
  { {0x798b0343, 0x1db90061, 0xa91d0059, 0x00000000}},  //   _wagw, _आवडत, deže,
  { {0x24890169, 0x44320036, 0xb8fa007d, 0x00000000}},  //   _asam_, _sty_, _डे_,
  { {0x386d0549, 0xf41f021e, 0x69c20116, 0x00000000}},  //   pter_, yvät_, _gloe,
  { {0x3a2501b5, 0xa01b0047, 0x44240011, 0x00000000}},  //   _hulp_, _csök, êm_,
  { {0xf74501f9, 0x4852025a, 0x3f811a84, 0x00000000}},  //   _секо, _اپوز, jehu_,
  { {0x24890089, 0x00000000, 0x00000000, 0x00000000}},  //   _esam_,   ,   ,
  { {0x44320052, 0xa3c20061, 0x63bc012d, 0x00000000}},  //   _tty_, ंसह_, skrn,
  { {0x10a301fc, 0x7bd80009, 0x91061001, 0x00000000}},  // [61e0] битн, yivu, упае,
  { {0x351b00b6, 0x728a012b, 0xf2a60326, 0x00000000}},  //   _אופנ, _због_, _биоп,
  { {0xdb082507, 0x79801519, 0x7a27013f, 0x00000000}},  //   _podí, yemw, _qıtl,
  { {0x65662508, 0x2b4500f6, 0xddc8012d, 0x00000000}},  //   ngkh, _aelc_, šožd,
  { {0x7bd8001a, 0x61e42509, 0x653b0049, 0x00000000}},  //   tivu, mnil, גענד,
  { {0x61e4250a, 0x69c20328, 0xa91d01ed, 0x00000000}},  //   lnil, _sloe, ndžu,
  { {0xed5a01fb, 0x69c200b5, 0x79800dfc, 0x00000000}},  //   _пов_, _ploe, temw,
  { {0x48aa0902, 0x61e4250b, 0x7bd8021e, 0x00000000}},  //   етом_, nnil, sivu,
  { {0x69c200c7, 0x61e41041, 0x76aa006b, 0x00000000}},  //   _vloe, inil, məyi,
  { {0x2bf6008b, 0x76aa005f, 0x61e4006c, 0x00000000}},  //   _сябр, ləyi, hnil,
  { {0xa91d0e0f, 0x61e42014, 0x00000000, 0x00000000}},  //   veže, knil,   ,
  { {0x25a0009d, 0x9f5f000c, 0x00000000, 0x00000000}},  //   _cnil_, ðrún_,   ,
  { {0x61e40471, 0x2fda00e0, 0xa91d1032, 0x00000000}},  //   dnil, kipg_, teže,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa91d1332, 0x61e4000c, 0x7bdf009d, 0x00000000}},  //   reže, fnil, équi,
  { {0xa91d0059, 0x61e40059, 0x11d40025, 0x00000000}},  //   seže, gnil, متقد,
  { {0x4fd5250c, 0x248900c4, 0x2d8d0026, 0x00000000}},  // [61f0] ажат, _usam_, _raee_,
  { {0xb4c10365, 0x443923a8, 0x600b014a, 0x00000000}},  //   ंनी_, mps_, küme,
  { {0x660d0640, 0x443900ab, 0xa3c2013d, 0x00000000}},  //   _khak, lps_, ंसर_,
  { {0xf653009b, 0x2b450126, 0x44390aba, 0x00000000}},  //   מצע_, _selc_, ops_,
  { {0xdca500ed, 0xcb6901fc, 0x6e2900ca, 0x00000000}},  //   рали, вале_, _čebu,
  { {0x44390129, 0x644f0051, 0x645d0048, 0x00000000}},  //   ips_, isci, irsi,
  { {0xdce90091, 0xadc30082, 0x00000000, 0x00000000}},  //   _obeć, _chản,   ,
  { {0x76aa006b, 0x645d0521, 0x644f0006, 0x00000000}},  //   cəyi, krsi, ksci,
  { {0x6d4b0a71, 0x60cd0211, 0xc9a6007c, 0x00000000}},  //   maga, nzam, рвые_,
  { {0x6d4b1084, 0x443904a5, 0x7c390016, 0x00000000}},  //   laga, dps_, mpwr,
  { {0x6b830982, 0x660d0093, 0x61e4011c, 0x00000000}},  //   meng, _bhak, ynil,
  { {0x6d4b250d, 0x6b8304d4, 0x660d000b, 0x00000000}},  //   naga, leng, _chak,
  { {0xe72e0f97, 0x660d0066, 0xdb080051, 0x00000000}},  //   _ме_, _dhak, _iodá,
  { {0x6b830288, 0x60cd0089, 0x6d4b250e, 0x00000000}},  //   neng, dzam, haga,
  { {0x6d4b149a, 0x67230521, 0x61e40b4a, 0x00000000}},  //   kaga, _ignj, tnil,
  { {0x6b83250f, 0x61e4001a, 0x6d4b01a3, 0x00000000}},  //   heng, unil, jaga,
  { {0x61e42510, 0x6b830052, 0x44390146, 0x00000000}},  // [6200] rnil, keng, cps_,
  { {0x6b832511, 0x61e400ee, 0xe80b006e, 0x00000000}},  //   jeng, snil, _सीमा_,
  { {0x76aa005f, 0x6b830643, 0x6d4b11c3, 0x00000000}},  //   təyi, deng, faga,
  { {0x6d4b006a, 0xed5a0264, 0x3e6e00b9, 0x00000000}},  //   gaga, тод_, rýt_,
  { {0x7d090036, 0x4c940d11, 0x6b8304f2, 0x00000000}},  //   _czes, силс, feng,
  { {0x6b83000c, 0x78bb004a, 0xdb1a22be, 0x00000000}},  //   geng, dyuv, _altá,
  { {0x6d4b0149, 0x2fd80022, 0x7d092512, 0x00000000}},  //   baga, _imrg_, _ezes,
  { {0x6d4b001c, 0x69c900d9, 0x644f0a62, 0x00000000}},  //   caga, ghee, ysci,
  { {0xdb080428, 0x57a600ed, 0x2d99008e, 0x00000000}},  //   _dodá, ашна, _ósea_,
  { {0x645d037e, 0x6b8312fe, 0x6e200433, 0x00000000}},  //   vrsi, ceng, _himb,
  { {0x6e20000b, 0x60cd17f4, 0x7bdf009d, 0x00000000}},  //   _kimb, zzam, èque,
  { {0x44392513, 0x6e200020, 0x69c900bb, 0x00000000}},  //   tps_, _jimb, chee,
  { {0xb4c103d7, 0x443900ab, 0x6e200020, 0x00000000}},  //   ंने_, ups_, _mimb,
  { {0x443900f4, 0x13a7026c, 0x6d4b002d, 0x00000000}},  //   rps_, جنسی_, zaga,
  { {0xd627045e, 0x6d4b011c, 0x88e80044, 0x00000000}},  //   _које_, yaga, _পরিক,
  { {0x4439001f, 0xa91d041a, 0x660d0020, 0x00000000}},  //   pps_, leža, _uhak,
  { {0x6d4b00b0, 0x6b830065, 0x00000000, 0x00000000}},  // [6210] vaga, yeng,   ,
  { {0x60cd00b5, 0x6d4b011c, 0x6671007a, 0x00000000}},  //   rzam, waga, _بگیر,
  { {0x6d4b006a, 0x6b8305fc, 0x6e202514, 0x00000000}},  //   taga, veng, _bimb,
  { {0x6b83008a, 0x6e200145, 0x44290020, 0x00000000}},  //   weng, _cimb, _kua_,
  { {0x6b831cce, 0x44292515, 0x442112cc, 0x00000000}},  //   teng, _jua_, _kih_,
  { {0x44292516, 0x442118e1, 0x69c90c0d, 0x00000000}},  //   _mua_, _jih_, whee,
  { {0x0d670265, 0x442903c7, 0x69c900b5, 0x00000000}},  //   _възм, _lua_, thee,
  { {0x2bd9007d, 0x4998007c, 0x44290035, 0x00000000}},  //   _भगवा, атья_, _oua_,
  { {0x4429002a, 0x3f91037e, 0x69c92517, 0x00000000}},  //   _nua_, _kazu_, rhee,
  { {0x6e20050c, 0x69c9001c, 0x442104cb, 0x00000000}},  //   _zimb, shee, _nih_,
  { {0x7c29008e, 0xe61a0893, 0x3f910089, 0x00000000}},  //   _huer, лдо_, _mazu_,
  { {0xc9840902, 0xc3290097, 0x44290051, 0x00000000}},  //   _мучи, _טו_, _bua_,
  { {0x442101cd, 0x44292518, 0x69d9002b, 0x00000000}},  //   _bih_, _cua_, _imwe,
  { {0x44290281, 0x7c290219, 0xf77100f3, 0x00000000}},  //   _dua_, _muer, _رات_,
  { {0x44292519, 0x4421251a, 0x21a600e2, 0x00000000}},  //   _eua_, _dih_, бивм,
  { {0x7c290343, 0xafdb00ea, 0x394d0810, 0x00000000}},  //   _ouer, _svøp, naes_,
  { {0x0ce20055, 0x6e2020fc, 0x4421002b, 0x00000000}},  // [6220] _বর্ত, _rimb, _fih_,
  { {0x43860025, 0x31690032, 0x61fd104e, 0x00000000}},  //   _الدق, agaz_, _eksl,
  { {0x3f91001f, 0x60020181, 0x69d901aa, 0x00000000}},  //   _dazu_, nômi, _omwe,
  { {0x237f0091, 0x44290022, 0xa3be0061, 0x00000000}},  //   đuje_, _yua_, _आवड_,
  { {0x7c290219, 0x89d8007a, 0x6e20251b, 0x00000000}},  //   _cuer, یوتر_, _vimb,
  { {0x6e200020, 0xac2501e1, 0x69d9065e, 0x00000000}},  //   _wimb, іфік, _amwe,
  { {0x6e200127, 0xc33300b6, 0xa91d251c, 0x00000000}},  //   _timb, לוג_, veža,
  { {0x7c290219, 0x383400d7, 0xadc30011, 0x00000000}},  //   _fuer, онир, _thạn,
  { {0x69c0014a, 0x7c2100ea, 0x00000000, 0x00000000}},  //   rkme, _filr,   ,
  { {0x442902d5, 0x7c2f00f4, 0x75e8019a, 0x00000000}},  //   _rua_, _écra, sızl,
  { {0x4429251d, 0x7c29010f, 0x44211347, 0x00000000}},  //   _sua_, _zuer, _rih_,
  { {0xceb300b6, 0x6fc00039, 0x4421023a, 0x00000000}},  //   לית_, _böck, _sih_,
  { {0x4429001d, 0xa91d251e, 0xdb01000a, 0x00000000}},  //   _qua_, ležn, _anlè,
  { {0x44290011, 0x600b014a, 0x24800145, 0x00000000}},  //   _vua_, küma, _dpim_,
  { {0x442101aa, 0x69d9018e, 0x3f910036, 0x00000000}},  //   _vih_, _ymwe, _razu_,
  { {0x44290198, 0x463b007b, 0x6fc0010f, 0x00000000}},  //   _tua_, _געהע, _höch,
  { {0x7bc801f6, 0xc60502fb, 0xb3eb0054, 0x00000000}},  // [6230] _oldu, रतीय_, _معدل_,
  { {0x2fc7001d, 0x00000000, 0x00000000, 0x00000000}},  //   óng_,   ,   ,
  { {0x6fc0001f, 0x7c2904a8, 0xa91d0243, 0x00000000}},  //   _möch, _suer, ježn,
  { {0x7c290219, 0x7bc8251f, 0x29d3001a, 0x00000000}},  //   _puer, _aldu, nţat_,
  { {0x7c290576, 0x6d490abf, 0x7bc60006, 0x00000000}},  //   _quer, _veea, _įkur,
  { {0x403416e8, 0xeb990069, 0x00000000, 0x00000000}},  //   _херс, рик_,   ,
  { {0x7c2901a2, 0x2d99004a, 0x00000000, 0x00000000}},  //   _wuer, _óseo_,   ,
  { {0x08c50999, 0x7c290249, 0x7bc82520, 0x00000000}},  //   жбин, _tuer, _eldu,
  { {0x394d0181, 0x7c212521, 0x48c70044, 0x00000000}},  //   raes_, _tilr, শপ্র,
  { {0xeb9b0167, 0x29030089, 0xaa59007c, 0x00000000}},  //   _حضرت_, āja_, _вижу_,
  { {0x6b9c0211, 0x95860326, 0x6d5e0006, 0x00000000}},  //   _órga, олне, ėpav,
  { {0x69d9010f, 0x7bc300ea, 0x78a4012d, 0x00000000}},  //   _umwe, lknu, _šive,
  { {0xb8fe0055, 0xe9190088, 0xf795007e, 0x00000000}},  //   _দু_, _тоді_, _мадэ,
  { {0xe73900ed, 0x7d06068f, 0x7bc32315, 0x00000000}},  //   _тек_, _økse, nknu,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf8c9006e, 0x7bc3000c, 0xe1f70245, 0x00000000}},  // [6240] िनिय, kknu, ігу_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd37b0049, 0x00000000, 0x00000000, 0x00000000}},  //   _דריט,   ,   ,
  { {0x2c720016, 0xa3c2013d, 0x600b014a, 0x00000000}},  //   tâd_, ंसक_, rüma,
  { {0xf1b300b3, 0x00000000, 0x00000000, 0x00000000}},  //   _חסר_,   ,   ,
  { {0xa91d00ee, 0x68e4047c, 0x2ac6003b, 0x00000000}},  //   težn, _žido, жљив,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa91d0059, 0xea95007e, 0x6e3e0022, 0x00000000}},  //   režn, яшчэ, mppb,
  { {0xa91d00ee, 0xc213009b, 0x6d420035, 0x00000000}},  //   sežn, והה_, mboa,
  { {0xc07b0049, 0x7bc8006b, 0x6d420403, 0x00000000}},  //   סטיש, _uldu, lboa,
  { {0xa91d0089, 0x600b006c, 0x00000000, 0x00000000}},  //   bežo, kümn,   ,
  { {0x6d422085, 0x6fc001a2, 0xe4a70131, 0x00000000}},  //   nboa, _wöch, орго,
  { {0x629e0052, 0x6fc001a2, 0x00000000, 0x00000000}},  //   _arpo, _töch,   ,
  { {0xbf0a0061, 0x00000000, 0x00000000, 0x00000000}},  //   _वरून_,   ,   ,
  { {0x623400ed, 0x00000000, 0x00000000, 0x00000000}},  //   десу,   ,   ,
  { {0x225e01ca, 0xc0350184, 0x600b010e, 0x00000000}},  //   átka_, знај, gümn,
  { {0x6d420319, 0x00000000, 0x00000000, 0x00000000}},  // [6250] dboa,   ,   ,
  { {0xdb18009f, 0xdb2101ca, 0x6d420062, 0x00000000}},  //   mkvæ, _štít, eboa,
  { {0x68e400b9, 0x00000000, 0x00000000, 0x00000000}},  //   _židl,   ,   ,
  { {0x6d421588, 0xb17b1fbf, 0x12fa009b, 0x00000000}},  //   gboa, _småf, _להתב,
  { {0xd59c007b, 0xa1360097, 0x1c4401e1, 0x00000000}},  //   יבאל, _מארק_, днім,
  { {0x443b00f6, 0x00ba009b, 0x2005000c, 0x00000000}},  //   _mtq_, _המשמ, _óli_,
  { {0xf1bf0011, 0x6d420c10, 0x00000000, 0x00000000}},  //   _giác_, bboa,   ,
  { {0x3e750039, 0x7bc305d2, 0x7c2f009d, 0x00000000}},  //   måt_, sknu, _écro,
  { {0x443b0009, 0x00000000, 0x00000000, 0x00000000}},  //   _ntq_,   ,   ,
  { {0x7c3b022b, 0x77f70061, 0xf77109b9, 0x00000000}},  //   _itur, ुतेक_, راخ_,
  { {0x38ca0014, 0x443b2522, 0x3a2c0146, 0x00000000}},  //   لایی_, _atq_, _gudp_,
  { {0xca96009b, 0x69dc0006, 0x00000000, 0x00000000}},  //   _מדעי_, _įreg,   ,
  { {0xe8ee0265, 0x69cb12ca, 0x3d0f0061, 0x00000000}},  //   _чл_, _ilge, तेचे_,
  { {0x9f5a0065, 0xf8b6009b, 0x889a009b, 0x00000000}},  //   ropë_, _מפני_, _לבני,
  { {0x515a007e, 0x00000000, 0x00000000, 0x00000000}},  //   йшаў_,   ,   ,
  { {0x7c3b047f, 0x3e7500f8, 0x6d5b0048, 0x00000000}},  //   _otur, dåt_, _ndua,
  { {0x7c3b0c99, 0x3cdb006e, 0x00000000, 0x00000000}},  // [6260] _ntur, _खेले_,   ,
  { {0x6d420161, 0x6d5b01a3, 0x629e0087, 0x00000000}},  //   wboa, _adua, _trpo,
  { {0x7c3b15ee, 0x20e2002b, 0x03bb009b, 0x00000000}},  //   _atur, _sħiħ_, _הציל,
  { {0x600b014a, 0xf09f0026, 0x16360049, 0x00000000}},  //   lüml, _frà_, לנער_,
  { {0x6d420133, 0x629c01d6, 0x00000000, 0x00000000}},  //   rboa, lvro,   ,
  { {0x69cb02ae, 0x6d5b029d, 0x6d420f30, 0x00000000}},  //   _alge, _edua, sboa,
  { {0x6d420133, 0x7c3b0052, 0x9d460088, 0x00000000}},  //   pboa, _etur, _невд,
  { {0x89d80b03, 0x3e5801aa, 0x9e770104, 0x00000000}},  //   توبر_, mčt_, _מגלה_,
  { {0x6e2e01a3, 0xe8b80061, 0x600b014a, 0x00000000}},  //   _hubb, ेनेच, küml,
  { {0x69c5008d, 0x37aa189f, 0xdb010b33, 0x00000000}},  //   ëher, стин_, _coló,
  { {0xb886000c, 0x3e5801aa, 0x32020093, 0x00000000}},  //   fsíð, nčt_, _okky_,
  { {0xd6d700a5, 0x3dc62523, 0x00000000, 0x00000000}},  //   яты_, nkow_,   ,
  { {0x6e2e00bb, 0x629c01ee, 0x07a602dc, 0x00000000}},  //   _lubb, evro, _надн,
  { {0x649205fa, 0x481301fb, 0x3e580173, 0x00000000}},  //   džić, _зміс, kčt_,
  { {0xa77b009b, 0x6e2e0203, 0x3a26000a, 0x00000000}},  //   _הרופ, _nubb, _kiop_,
  { {0xf09f0026, 0xdb010173, 0x00000000, 0x00000000}},  //   _prà_, _kolò,   ,
  { {0x600b014a, 0x81c10044, 0x00000000, 0x00000000}},  // [6270] büml, ্চল_,   ,
  { {0x32020022, 0xdb012524, 0xa2b50316, 0x00000000}},  //   _ekky_, _polü, _उपप्,
  { {0x7c3b00b5, 0x6e2e2525, 0x51f9060e, 0x00000000}},  //   _stur, _cubb, _мною_,
  { {0x21670057, 0x62850a60, 0xf09f0011, 0x00000000}},  //   _этог, _ipho, _trà_,
  { {0x61ed001a, 0xf09f00f6, 0x32090058, 0x00000000}},  //   mnal, _urà_, mlay_,
  { {0x3e750039, 0x61ff006b, 0x2ade0061, 0x00000000}},  //   påt_, loql, _केहु_,
  { {0x61ed0198, 0x6e2e0039, 0x62850009, 0x00000000}},  //   onal, _gubb, _jpho,
  { {0x61ed110a, 0x78a4050f, 0x3dc62526, 0x00000000}},  //   nnal, _šiva, ckow_,
  { {0x7c3b14a5, 0xdb012527, 0x3a2607c9, 0x00000000}},  //   _utur, _colò, _diop_,
  { {0x25a9001c, 0x62850286, 0x600b050d, 0x00000000}},  //   _anal_, _opho, kümm,
  { {0x32090058, 0x00000000, 0x00000000, 0x00000000}},  //   klay_,   ,   ,
  { {0xceb2009b, 0xdbd701b1, 0x61ed0010, 0x00000000}},  //   דיט_, sääs, jnal,
  { {0xb886009f, 0x395d2528, 0xdbd703b6, 0x00000000}},  //   rsíð, _idws_, pääs,
  { {0x660e0027, 0x629c01d6, 0x3dcd005b, 0x00000000}},  //   _ďaku, tvro, _llew_,
  { {0xe297007e, 0xe1c90061, 0x628e00b5, 0x00000000}},  //   мар_, रसंघ, uwbo,
  { {0x61ed2529, 0xb686026c, 0x629c252a, 0x00000000}},  //   gnal, _کھیل_, rvro,
  { {0x41df0061, 0x629c0116, 0xe45f0010, 0x00000000}},  // [6280] _नगरस, svro, ször_,
  { {0x6e2e0409, 0x4095008b, 0x25a900d0, 0x00000000}},  //   _pubb, эрст, _znal_,
  { {0x3dcd0ca4, 0x32090058, 0x412a013b, 0x00000000}},  //   _blew_, blay_, _моно_,
  { {0x7f4e0c2f, 0xa91d0059, 0x3e5801aa, 0x00000000}},  //   _webq, režj, rčt_,
  { {0x61e4001a, 0x361b01ce, 0x6604252b, 0x00000000}},  //   miil, קונד, _mkik,
  { {0xdb210027, 0x6e2e0fd5, 0x3dc6252c, 0x00000000}},  //   _štát, _tubb, skow_,
  { {0xa9340783, 0x3dcd0133, 0x3f98252d, 0x00000000}},  //   нейш, _flew_, _iaru_,
  { {0xa9c301fb, 0x61e4001a, 0x66040922, 0x00000000}},  //   вськ, niil, _nkik,
  { {0x60c4252e, 0x3f98006c, 0x00000000, 0x00000000}},  //   nyim, _karu_,   ,
  { {0x8c430264, 0x660413df, 0x61ed0091, 0x00000000}},  //   _рефе, _akik, znal,
  { {0x61ed252f, 0x32091544, 0xdb1a0023, 0x00000000}},  //   ynal, ylay_, _motë,
  { {0x2bbe0061, 0xdb1a0023, 0xdb1800f8, 0x00000000}},  //   ्सवा, _lotë, rkvä,
  { {0x3a3e0365, 0x657d12e6, 0x61e4001a, 0x00000000}},  //   _http_, rfsh, diil,
  { {0x7c282530, 0x660411a8, 0x2ba40164, 0x00000000}},  //   _jidr, _ekik, _गोमा,
  { {0x61e42531, 0x7c2801d6, 0x53340242, 0x00000000}},  //   fiil, _midr, тест,
  { {0x78a20006, 0xdb1a0181, 0x61e4001a, 0x00000000}},  //   _krov, _potê, giil,
  { {0x3f98020c, 0x752d0047, 0xdb1a008d, 0x00000000}},  // [6290] _baru_, _igaz, _botë,
  { {0xed590119, 0x3f98005b, 0xf1bf0011, 0x00000000}},  //   _može_, _caru_, _gián_,
  { {0x61e40cfc, 0x79820036, 0x3f98002b, 0x00000000}},  //   biil, _obow, _daru_,
  { {0x61e4001a, 0xafdb0030, 0x699e0204, 0x00000000}},  //   ciil, _stød, _खोली,
  { {0x7c2805cb, 0x394f0007, 0x60d60036, 0x00000000}},  //   _bidr, _regs_, czym,
  { {0x644d0020, 0x394f0b33, 0x3f9821bc, 0x00000000}},  //   _mwai, _segs_, _garu_,
  { {0x7c2800ea, 0x37e40044, 0x00000000, 0x00000000}},  //   _didr, নকার,   ,
  { {0x752d2532, 0xa91d0428, 0xed590091, 0x00000000}},  //   _ngaz, leži, _bože_,
  { {0xb4be001c, 0xdb1a01aa, 0x78a20026, 0x00000000}},  //   _इथे_, _lotè, _crov,
  { {0xdce905fa, 0x660400ea, 0x61e4001a, 0x00000000}},  //   _ubeđ, _skik, ziil,
  { {0x2bac01f5, 0xd5e600ed, 0x78a200bb, 0x00000000}},  //   चारा, ежни, _erov,
  { {0x58d50920, 0xaa640986, 0x5a44007e, 0x00000000}},  //   _поет, _штук, _рэфа,
  { {0x61e4003c, 0x69c92533, 0xdb08000a, 0x00000000}},  //   viil, mkee, _andè,
  { {0x6e29001f, 0x69c9021e, 0x764101c9, 0x00000000}},  //   _lieb, lkee, pply,
  { {0x61e42534, 0x386d00f4, 0x9694007e, 0x00000000}},  //   tiil, luer_, _арыш,
  { {0x6e290036, 0x3f98002b, 0xdb1a0065, 0x00000000}},  //   _nieb, _saru_, _sotë,
  { {0x644d018e, 0x61e4000d, 0xe0da0265, 0x00000000}},  // [62a0] _gwai, riil, чва_,
  { {0x60d60046, 0xe47b00b6, 0x61e410fb, 0x00000000}},  //   rzym, _צריכ, siil,
  { {0xf1bf001d, 0x4432001d, 0x61e4001a, 0x00000000}},  //   _giáo_, _huy_, piil,
  { {0x6e290036, 0x3f980093, 0x7c282535, 0x00000000}},  //   _cieb, _waru_, _sidr,
  { {0xdb0800f4, 0xdca309ae, 0x6e2901a2, 0x00000000}},  //   _indé, лаци, _dieb,
  { {0x44320219, 0xdb1a0181, 0x7d090058, 0x00000000}},  //   _muy_, _hoté, _dyes,
  { {0x7c2800d6, 0x78a22536, 0x6e2924c6, 0x00000000}},  //   _vidr, _srov, _fieb,
  { {0x69c900c7, 0x68ed24f2, 0x799b00e0, 0x00000000}},  //   gkee, _žada, gduw,
  { {0x386d1e3b, 0xdb1a00c4, 0x3b86007c, 0x00000000}},  //   guer_, _moté, _плаг,
  { {0x8b26007e, 0x6e2904a5, 0xdb1a0cd3, 0x00000000}},  //   _здзе, _zieb, _loté,
  { {0xa5f90bff, 0x00000000, 0x00000000, 0x00000000}},  //   дену_,   ,   ,
  { {0x78a20198, 0x44320866, 0xdce0005f, 0x00000000}},  //   _trov, _buy_, _hamı,
  { {0xb4cb03d7, 0xc458007c, 0x94a80783, 0x00000000}},  //   लने_, ниях_, нтра_,
  { {0x7bca010f, 0x4432001d, 0x26c500b9, 0x00000000}},  //   nkfu, _duy_, bylo_,
  { {0xd6cf01fb, 0xa91d09f4, 0x44320093, 0x00000000}},  //   _ст_, veži, _euy_,
  { {0x6b9a0089, 0x9b17009b, 0x752d0892, 0x00000000}},  //   _latg, תחלה_, _ugaz,
  { {0x765a010a, 0x6e292537, 0xdb1a009d, 0x00000000}},  // [62b0] lsty, _rieb, _doté,
  { {0x7c2f028c, 0x6e292538, 0x69c9002d, 0x00000000}},  //   _écri, _sieb, zkee,
  { {0x69c90007, 0x6e290089, 0x765a2539, 0x00000000}},  //   ykee, _pieb, nsty,
  { {0x7d090065, 0x765a253a, 0xa2b600b3, 0x00000000}},  //   _pyes, isty, _ספרד_,
  { {0xeb990769, 0x24890145, 0x00000000, 0x00000000}},  //   дил_, _jpam_,   ,
  { {0xf1bf001d, 0x765a0006, 0xf3ff00c4, 0x00000000}},  //   _hoá_, ksty, irão_,
  { {0x6b9a018e, 0x6e2909d0, 0xc334009b, 0x00000000}},  //   _datg, _tieb, נוק_,
  { {0x765a0030, 0x799901d5, 0x386d253b, 0x00000000}},  //   dsty, _qaww, tuer_,
  { {0x69c9049b, 0x780c0061, 0x87f9007e, 0x00000000}},  //   rkee, हतूक_, дэнт_,
  { {0x2d8f0292, 0x765a253c, 0xf3ff0181, 0x00000000}},  //   lege_, fsty, drão_,
  { {0x44320011, 0x4975007e, 0x24891659, 0x00000000}},  //   _suy_, _алес, _apam_,
  { {0x89370025, 0x2d8f015b, 0x4432009d, 0x00000000}},  //   _أعضا, nege_, _puy_,
  { {0x386d0be0, 0x4432001d, 0x88c403ec, 0x00000000}},  //   quer_, _quy_, _متول,
  { {0xd705005e, 0x44320009, 0x00000000, 0x00000000}},  //   _изли, _vuy_,   ,
  { {0x765a0009, 0x63be000c, 0xf3ff00fa, 0x00000000}},  //   csty, _vopn, arão_,
  { {0x20180719, 0x4432001d, 0x01630d51, 0x00000000}},  //   _shri_, _tuy_, иксо,
  { {0xe45a008b, 0x63be1375, 0xf1bf001d, 0x00000000}},  // [62c0] _ўжо_, _topn, _giám_,
  { {0x64460133, 0x00000000, 0x00000000, 0x00000000}},  //   mpki,   ,   ,
  { {0x6b9a010f, 0x661600b9, 0xdb1a013e, 0x00000000}},  //   _ratg, ůzku, _toté,
  { {0x6b9a0093, 0x1ea90379, 0x6b4e0036, 0x00000000}},  //   _satg, عالي_, _mógł,
  { {0x2c0e0061, 0x6b9a00d4, 0x6c330025, 0x00000000}},  //   ितलं_, _patg, لفنا,
  { {0x765a0036, 0x64460006, 0x7bca0045, 0x00000000}},  //   ysty, ipki, ukfu,
  { {0x6b9a0011, 0xa50f006e, 0x00000000, 0x00000000}},  //   _vatg, _सर्च_,   ,
  { {0x1e970452, 0xa2b50164, 0xf1bf0011, 0x00000000}},  //   _בכלל_, _उपस्, _xoá_,
  { {0x0c26025f, 0x3e7c1c59, 0x60100203, 0x00000000}},  //   _аман, lít_, hämm,
  { {0x765a0056, 0xf3ff00fa, 0x00000000, 0x00000000}},  //   tsty, vrão_,   ,
  { {0x6ae00044, 0xdb010030, 0xa01b00f8, 0x00000000}},  //   _পুরো, _anlæ, _spök,
  { {0xd946005e, 0x3ce70061, 0xed590733, 0x00000000}},  //   _реди, जपचे_, _koža_,
  { {0x765a0193, 0xe0df0045, 0x66cb0010, 0x00000000}},  //   ssty, _leòr_, tökö,
  { {0xf3ff00c4, 0x765a0a59, 0xed5900ca, 0x00000000}},  //   rrão_, psty, _moža_,
  { {0xf2c401be, 0x3e7c0224, 0xed5900ca, 0x00000000}},  //   астн, jít_, _loža_,
  { {0x6440253d, 0xa3cf0316, 0x00000000, 0x00000000}},  //   ímic, _शतक_,   ,
  { {0x21f701d5, 0x24890059, 0x2d8f253e, 0x00000000}},  // [62d0] għha_, _upam_, vege_,
  { {0xceeb0070, 0x2d8f01a2, 0x645d00f8, 0x00000000}},  //   وران_, wege_, mssi,
  { {0xc3320104, 0x69dc010a, 0x2d8f0b33, 0x00000000}},  //   _לוי_, _įren, tege_,
  { {0xdb080036, 0xed590087, 0x00000000, 0x00000000}},  //   _lodó, _boža_,   ,
  { {0x645d021e, 0x50f4041f, 0x2d8f002d, 0x00000000}},  //   nssi, _взят, rege_,
  { {0x645d1684, 0x2d8f253f, 0x3e7c013e, 0x00000000}},  //   issi, sege_, bít_,
  { {0x09e52540, 0x2d8f0190, 0xbed5003b, 0x00000000}},  //   локн, pege_, _совј,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d59011c, 0x6ce70088, 0x00000000, 0x00000000}},  //   mawa, _ріве,   ,
  { {0x6d590831, 0x645d0190, 0xe45f00b0, 0x00000000}},  //   lawa, dssi, työn_,
  { {0x645d00d4, 0xdb010181, 0x7f55008e, 0x00000000}},  //   essi, _colô, _mezq,
  { {0x6d59008a, 0x04460920, 0x7bc10387, 0x00000000}},  //   nawa, лемн, _holu,
  { {0x645d00ea, 0x98790049, 0xa8790049, 0x00000000}},  //   gssi, _נאַט, _נאַר,
  { {0xadc30011, 0x387f0065, 0x6d592541, 0x00000000}},  //   _khẳn, mtur_, hawa,
  { {0x6d5909f3, 0x7bc10058, 0x29c3008e, 0x00000000}},  //   kawa, _molu, _uñas_,
  { {0xdb010901, 0x6d592542, 0x601000f8, 0x00000000}},  //   _inlä, jawa, rämm,
  { {0xa0670200, 0x6d590046, 0x387f010f, 0x00000000}},  // [62e0] лата_, dawa, ntur_,
  { {0x6606009f, 0xa4b700b3, 0x3e7c245b, 0x00000000}},  //   lokk, _עליה_, tít_,
  { {0x6da6013b, 0x25b70014, 0x91e60918, 0x00000000}},  //   лижа, _شهید_, _боне,
  { {0x6d592543, 0x660619ae, 0x00000000, 0x00000000}},  //   gawa, nokk,   ,
  { {0x7bc1009f, 0x387f008d, 0xf64700a1, 0x00000000}},  //   _bolu, jtur_, _گئ_,
  { {0xafe60f40, 0x660600b0, 0x6e35089f, 0x00000000}},  //   _согл, hokk, _fuzb,
  { {0xadc3001d, 0x6d592544, 0x6564001a, 0x00000000}},  //   _chẳn, bawa, _odih,
  { {0x6564008d, 0x387f000c, 0xd90d00a1, 0x00000000}},  //   _ndih, ftur_, ڈیم_,
  { {0xdb082545, 0xdb010a5d, 0xdca3003b, 0x00000000}},  //   _indí, _anlä, _лати,
  { {0x7bc1016c, 0xa0970049, 0x807b0049, 0x00000000}},  //   _golu, נדיק_, עניצ,
  { {0xe5b50147, 0x387f06be, 0x3c3901aa, 0x00000000}},  //   айны, atur_, _zèv_,
  { {0xd6d7004c, 0x645d0c7a, 0xceb3009b, 0x00000000}},  //   уть_, tssi, ציר_,
  { {0x7bc1038c, 0xdb1a1c59, 0xdb080048, 0x00000000}},  //   _yolu, _motí, _todó,
  { {0x645d021e, 0x6d5909cc, 0x00000000, 0x00000000}},  //   rssi, zawa,   ,
  { {0x45d52546, 0x6d590058, 0xcb37009b, 0x00000000}},  //   _войс, yawa, ראלי_,
  { {0xdb1a0ca7, 0x29d80051, 0x66060f4c, 0x00000000}},  //   _notí, _déag_, cokk,
  { {0x9f552547, 0x6d592548, 0x6e220082, 0x00000000}},  // [62f0] ивач, vawa, dmob,
  { {0xdefb222e, 0x6d59011c, 0x6aa817db, 0x00000000}},  //   ные_, wawa, _ordf,
  { {0x6d591084, 0x7bc11aba, 0x93150014, 0x00000000}},  //   tawa, _rolu, _خودش,
  { {0x387f12e2, 0x00000000, 0x00000000, 0x00000000}},  //   ytur_,   ,   ,
  { {0x7bc10119, 0x6d59027c, 0x6aa80048, 0x00000000}},  //   _polu, rawa, _ardf,
  { {0x6d5904d4, 0x6e350064, 0xadc30011, 0x00000000}},  //   sawa, _tuzb, _phẳn,
  { {0x6d590058, 0x6e220026, 0x00000000, 0x00000000}},  //   pawa, bmob,   ,
  { {0x387f03da, 0xc9a90242, 0xdb1a00c4, 0x00000000}},  //   ttur_, твие_, _botâ,
  { {0xa9220265, 0x7bc1008e, 0x66060052, 0x00000000}},  //   одъл, _tolu, vokk,
  { {0xadc30011, 0x387f000c, 0x7782007c, 0x00000000}},  //   _thẳn, rtur_, ольз,
  { {0x387f2549, 0x644410fb, 0x66060010, 0x00000000}},  //   stur_, _stii, tokk,
  { {0x29d80051, 0x387f01e5, 0x7d160036, 0x00000000}},  //   _céad_, ptur_, żyse,
  { {0x893406dd, 0x660600b5, 0x394d00f4, 0x00000000}},  //   _اعما, rokk, mbes_,
  { {0x394d06be, 0xb6a501fb, 0x46a500ed, 0x00000000}},  //   lbes_, _викл, _вакв,
  { {0x764301c9, 0x00000000, 0x00000000, 0x00000000}},  //   _utny,   ,   ,
  { {0xb14602be, 0x386d00f4, 0x78a400ca, 0x00000000}},  //   рнал, orer_, _šivi,
  { {0x3fe60726, 0x386d032e, 0x200a0022, 0x00000000}},  // [6300] ажав, nrer_, _pkbi_,
  { {0x8236007a, 0x25a00a18, 0xb4c20204, 0x00000000}},  //   _پردا, _hail_, ंही_,
  { {0x386d010f, 0xed5a1001, 0x6e2200f8, 0x00000000}},  //   hrer_, вое_, tmob,
  { {0x386d0637, 0x25a00133, 0x7bc5254a, 0x00000000}},  //   krer_, _jail_, öhun,
  { {0x6e22254b, 0x386d0190, 0xadc30082, 0x00000000}},  //   rmob, jrer_, _chằn,
  { {0x386d254c, 0x6e2200ca, 0x764800ea, 0x00000000}},  //   drer_, smob, ypdy,
  { {0x160603d7, 0x386d254d, 0xf1ca007d, 0x00000000}},  //   रवार_, erer_, _रवान,
  { {0x298a0072, 0x386d0181, 0xdea400a6, 0x00000000}},  //   тско_, frer_, _پیچی,
  { {0xb9c30054, 0xdb1a0181, 0x386d14b3, 0x00000000}},  //   تقيي, _botã, grer_,
  { {0x1ae608f3, 0xc6a6005e, 0xf7b8003b, 0x00000000}},  //   _козм, арми, угој_,
  { {0x25a008f7, 0x386d0186, 0x00000000, 0x00000000}},  //   _bail_, arer_,   ,
  { {0x386d04bd, 0x2918006b, 0x998c0087, 0x00000000}},  //   brer_, əran_, _fudš_,
  { {0x25a0254e, 0x386d009d, 0x2246016c, 0x00000000}},  //   _dail_, crer_, _čoka_,
  { {0x3f8a00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _nbbu_,   ,   ,
  { {0x29d80051, 0x25a00a6b, 0x00000000, 0x00000000}},  //   _téad_, _fail_,   ,
  { {0x3ead0de0, 0xdce0000a, 0x25a00322, 0x00000000}},  //   _čet_, _admč, _gail_,
  { {0x660d0213, 0x7a350006, 0x00000000, 0x00000000}},  // [6310] _ikak, _ište,   ,
  { {0x53991192, 0x33750088, 0x25a00032, 0x00000000}},  //   _своя_, _угор, _zail_,
  { {0x394d0006, 0xa195017f, 0x00000000, 0x00000000}},  //   ybes_, _ланч,   ,
  { {0xf2d2007b, 0x237f0091, 0x386d043e, 0x00000000}},  //   _זעט_, đuju_, yrer_,
  { {0x61ed00b0, 0xdca5003b, 0x660d254f, 0x00000000}},  //   mial, сали, _mkak,
  { {0x823401ef, 0xf77801d5, 0x386d009d, 0x00000000}},  //   _دریا, jgħ_, vrer_,
  { {0x60cd0047, 0xaa56012b, 0x7a35016e, 0x00000000}},  //   lyam, бију_, _ošte,
  { {0x61ed0e68, 0xadc30011, 0x386d19a3, 0x00000000}},  //   nial, _thằn, trer_,
  { {0x60cd020c, 0x394d00f4, 0x3cd51023, 0x00000000}},  //   nyam, rbes_, _ужас,
  { {0x386d04bd, 0x25a00016, 0x61ed08a6, 0x00000000}},  //   rrer_, _sail_, hial,
  { {0x61ed0dc7, 0x8698004d, 0x60cd0009, 0x00000000}},  //   kial, атят_, hyam,
  { {0x60cd00e0, 0xed5900b9, 0x00000000, 0x00000000}},  //   kyam, _jež_,   ,
  { {0x61ed0142, 0x60cd0061, 0x18690eaf, 0x00000000}},  //   dial, jyam, _сали_,
  { {0x60cd163c, 0xa5bb004a, 0x00000000, 0x00000000}},  //   dyam, lmól,   ,
  { {0xa3e9006e, 0x216a026b, 0x2ca60142, 0x00000000}},  //   _मगर_, ливи_, zvod_,
  { {0xed5901c8, 0x463a007b, 0x61ed0197, 0x00000000}},  //   _než_, _געקע, gial,
  { {0xe3b20070, 0xc2e60044, 0x60cd2119, 0x00000000}},  // [6320] _فرد_, _খুশি_, gyam,
  { {0xdd8f00a1, 0x00000000, 0x00000000, 0x00000000}},  //   ہوم_,   ,   ,
  { {0x61ed0303, 0x7d1b1575, 0x00000000, 0x00000000}},  //   bial, _azus,   ,
  { {0x629e0119, 0xed5a006d, 0xdb1a2550, 0x00000000}},  //   _ispo, اشات_, _notá,
  { {0x69db0065, 0x447b0049, 0xed5900ca, 0x00000000}},  //   dhue, ָנצע, _dež_,
  { {0x8f75007e, 0x629e00ea, 0xdb1a00f6, 0x00000000}},  //   _мусі, _kspo, _potà,
  { {0x6da6142c, 0xdb1a02f9, 0x7d1b0032, 0x00000000}},  //   _лива, _botá, _ezus,
  { {0x26cc007f, 0x00000000, 0x00000000, 0x00000000}},  //   vydo_,   ,   ,
  { {0x660d0022, 0x6d4200d9, 0xb17b1afa, 0x00000000}},  //   _rkak, mcoa, _småk,
  { {0x61ed2551, 0x660d0343, 0x6d420035, 0x00000000}},  //   zial, _skak, lcoa,
  { {0xadc30082, 0x5986007e, 0x4fbb0049, 0x00000000}},  //   _chặn, _глеб, אזיצ,
  { {0xca370097, 0x69db008e, 0x61ed0668, 0x00000000}},  //   _הנאה_, chue, xial,
  { {0x629e0027, 0x5fb90061, 0x7a351a7d, 0x00000000}},  //   _aspo, _उचलल, _všte,
  { {0x07a30783, 0x64560016, 0xc7a301ee, 0x00000000}},  //   _начн, _dwyi, _ничк,
  { {0xd7f8001a, 0xd9ec0061, 0x98a4014a, 0x00000000}},  //   mnă_, _जगात_, mamı_,
  { {0x98a4005d, 0x7a350091, 0x521503e8, 0x00000000}},  //   lamı_, _ušte, ідат,
  { {0x629e06c0, 0xa2b501f5, 0x35f80167, 0x00000000}},  // [6330] _espo, _उपक्, _درود_,
  { {0x60cd2552, 0xdb1f0010, 0x00000000, 0x00000000}},  //   ryam, űvés,   ,
  { {0x6e99007c, 0x629e0320, 0x61ed13db, 0x00000000}},  //   рвер_, _gspo, pial,
  { {0x443b0065, 0x44332553, 0xdb0100c4, 0x00000000}},  //   _kuq_, _hix_, _falê,
  { {0xe0e4007e, 0x4433109a, 0x61fd00bb, 0x00000000}},  //   _еўро, _kix_, _ijsl,
  { {0xaa4900ed, 0x00000000, 0x00000000, 0x00000000}},  //   апка_,   ,   ,
  { {0xdab9007e, 0x69db0023, 0xdb1a2554, 0x00000000}},  //   рылі_, thue, _potá,
  { {0x44332555, 0x49c9026b, 0x3eae0030, 0x00000000}},  //   _lix_, рлин_, æfte_,
  { {0x44210525, 0xf771006d, 0xc7950783, 0x00000000}},  //   _ohh_, واد_, орны,
  { {0x4433010f, 0x166502d3, 0xf1bf0051, 0x00000000}},  //   _nix_, овом, _fhág_,
  { {0x6d5b0390, 0x7c3b0250, 0xdb010065, 0x00000000}},  //   _keua, _huur, _malë,
  { {0x44210487, 0x8c3d011f, 0x4433009d, 0x00000000}},  //   _ahh_, _arşi, _aix_,
  { {0x7c3b08b2, 0x395f0be1, 0xdffb0164, 0x00000000}},  //   _juur, maus_, ्वाद_,
  { {0x395f025c, 0x7c3b2556, 0x6d420d48, 0x00000000}},  //   laus_, _muur, zcoa,
  { {0x443300f4, 0x232a017a, 0xe29a034b, 0x00000000}},  //   _dix_, рови_, шав_,
  { {0x443b0f68, 0x395f021e, 0x6d5b068a, 0x00000000}},  //   _fuq_, naus_, _neua,
  { {0xdfd20379, 0x6ab602d2, 0x629e0036, 0x00000000}},  // [6340] وير_, _अप्र, _wspo,
  { {0x395f010f, 0xdb0100c4, 0x00000000, 0x00000000}},  //   haus_, _valê,   ,
  { {0x35af03d7, 0x629e0466, 0x6d42062c, 0x00000000}},  //   _जोड़, _uspo, tcoa,
  { {0x7c3b0250, 0x2cad05fe, 0x395f2557, 0x00000000}},  //   _buur, _bred_, jaus_,
  { {0x2cad000d, 0x395f0006, 0xdb010065, 0x00000000}},  //   _cred_, daus_, _falë,
  { {0xe0fb00b6, 0x7c3b00b5, 0x6d421541, 0x00000000}},  //   _כלכל, _duur, scoa,
  { {0x98a4038c, 0x69d90022, 0x8e8301ee, 0x00000000}},  //   vamı_, _blwe, _огре,
  { {0x395f010a, 0x31600032, 0x6e3c0032, 0x00000000}},  //   gaus_, naiz_, _iurb,
  { {0x6e3c2558, 0x61410010, 0x2cad01a3, 0x00000000}},  //   _hurb, _háló, _gred_,
  { {0x6e3c014a, 0xd7f8001a, 0xa5bb008e, 0x00000000}},  //   _kurb, ună_, rmóm,
  { {0x443b01d5, 0x21270011, 0x4433002b, 0x00000000}},  //   _suq_, ̀nh_, _rix_,
  { {0x44330549, 0x395f0a16, 0x6e3c2559, 0x00000000}},  //   _six_, caus_, _murb,
  { {0x7bc80004, 0x4433255a, 0x6fda0061, 0x00000000}},  //   _kodu, _pix_, णसां,
  { {0xdb011259, 0x6e3c1f4e, 0x00000000, 0x00000000}},  //   _balè, _ourb,   ,
  { {0x7bc8022b, 0x3866068f, 0x6e3c0ec1, 0x00000000}},  //   _modu, _hvor_, _nurb,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb010065, 0x7f5c0066, 0x41b500a1, 0x00000000}},  // [6350] _palë, _berq, _ہمدر,
  { {0x6e3c1f51, 0x7bc80035, 0x7f5c0a0a, 0x00000000}},  //   _burb, _nodu, _cerq,
  { {0x7c3b08b2, 0x2cad12d6, 0x6e3c0035, 0x00000000}},  //   _suur, _sred_, _curb,
  { {0x6e3c0007, 0x2cad0cce, 0x4035005e, 0x00000000}},  //   _durb, _pred_, _немс,
  { {0x2fc7001d, 0x395f042c, 0x6e3c0145, 0x00000000}},  //   ưng_, vaus_, _eurb,
  { {0x7bc8001a, 0x7c3b00c7, 0x6e3c0197, 0x00000000}},  //   _codu, _vuur, _furb,
  { {0x7bc8037e, 0x63a5006b, 0x395f0ecb, 0x00000000}},  //   _dodu, _mahn, taus_,
  { {0x63a50cba, 0x7c3b255b, 0x7e650023, 0x00000000}},  //   _lahn, _tuur, mshp,
  { {0x395f255c, 0xb4ea0061, 0x6e3c0032, 0x00000000}},  //   raus_, _मधे_, _zurb,
  { {0x7bc81875, 0x7afc0059, 0x395f0d96, 0x00000000}},  //   _godu, _žrte, saus_,
  { {0x395f255d, 0xe5a60088, 0x78a90056, 0x00000000}},  //   paus_, пини, svev,
  { {0xdb0100b9, 0x7bc3012d, 0x69d901c3, 0x00000000}},  //   _nalé, ljnu, _ulwe,
  { {0x63a5010f, 0x993a00b3, 0xb9c40025, 0x00000000}},  //   _bahn, _התנה, _تقني,
  { {0xc879005d, 0x63a50022, 0xdb0100f6, 0x00000000}},  //   muş_, _cahn, _palè,
  { {0x63a5255e, 0xc879255f, 0x8c1a009b, 0x00000000}},  //   _dahn, luş_, מושי,
  { {0xdb012560, 0x0563005e, 0x629c0b04, 0x00000000}},  //   _valè, _звън, rwro,
  { {0x7f5c04bd, 0x63a501a2, 0x31600032, 0x00000000}},  // [6360] _perq, _fahn, raiz_,
  { {0x2b8f011f, 0x6e3c0169, 0xdb1801e5, 0x00000000}},  //   nıcı_, _purb, mkvö,
  { {0x6e3c006b, 0xe3570097, 0x7bc80052, 0x00000000}},  //   _qurb, _משיח_, _rodu,
  { {0x63a52561, 0xdb011b6d, 0x568c0049, 0x00000000}},  //   _zahn, _galé, שטאַ,
  { {0x7bc8154d, 0xc17300b6, 0xa1160014, 0x00000000}},  //   _podu, _אחר_, _روست,
  { {0x6e3c2562, 0x442a000a, 0x00000000, 0x00000000}},  //   _turb, nmb_,   ,
  { {0x80d10055, 0x29d8002a, 0x7e650061, 0x00000000}},  //   _সেপ্, _déan_, cshp,
  { {0xada3008b, 0x6da301fe, 0x3f9a0036, 0x00000000}},  //   _пасл, _писа, lepu_,
  { {0x29022563, 0x7bc80022, 0xeb3600a2, 0x00000000}},  //   çka_, _todu, _فراخ,
  { {0xf1bf00ad, 0xfaa606b6, 0x442a0022, 0x00000000}},  //   _khác_, _назо, jmb_,
  { {0xf119013d, 0xadf3007d, 0x04f90044, 0x00000000}},  //   _दर्द_, _आगमन_, _ঘরের_,
  { {0x63a5085e, 0x39461b34, 0xaa3b0097, 0x00000000}},  //   _sahn, _ufos_, _התאח,
  { {0x80d10044, 0x7df50006, 0x63a50087, 0x00000000}},  //   _সেন্, mąst, _pahn,
  { {0x78a200b0, 0x3f9a0166, 0xdb01009d, 0x00000000}},  //   _isov, jepu_, _salé,
  { {0x61e10065, 0xdb01009d, 0x7a010089, 0x00000000}},  //   ëllo, _palé, lēta,
  { {0xc2c40025, 0x067b0104, 0x63a501a2, 0x00000000}},  //   ريقي, _הנהל, _wahn,
  { {0x628701d5, 0xdb01009d, 0x7a010089, 0x00000000}},  // [6370] stjo, _valé, nēta,
  { {0x644d2564, 0xe9e20036, 0x78a20045, 0x00000000}},  //   _itai, leźć_, _msov,
  { {0x7f450c3f, 0x3a3e0145, 0x00000000, 0x00000000}},  //   rchq, _nutp_,   ,
  { {0xfe700076, 0xf1bf0011, 0x7e650023, 0x00000000}},  //   ادل_, _giáp_, rshp,
  { {0x0db80025, 0x2b8f005a, 0x656d00e7, 0x00000000}},  //   ثالث_, yıcı_, _mdah,
  { {0x660f06d3, 0xc8790276, 0x3f9a0035, 0x00000000}},  //   hock, vuş_, cepu_,
  { {0x78a20107, 0xfaa2005e, 0xf41f00b0, 0x00000000}},  //   _asov, ващо, ytän_,
  { {0x656d0065, 0xfaf003ec, 0x660f141b, 0x00000000}},  //   _ndah, دثه_, jock,
  { {0x2b8f01df, 0xc8c90014, 0x6d490c97, 0x00000000}},  //   tıcı_, زودن_, _ifea,
  { {0xe6450ae0, 0x656d0009, 0xc879026d, 0x00000000}},  //   меоп, _adah, ruş_,
  { {0x9f840004, 0x38ca007a, 0x2b8f0180, 0x00000000}},  //   _töö_, مایی_, rıcı_,
  { {0xb8f30044, 0x00000000, 0x00000000, 0x00000000}},  //   _হই_,   ,   ,
  { {0x45d3007e, 0x60102565, 0x7a010089, 0x00000000}},  //   тоўс, kämp, cēta,
  { {0xe787081e, 0x69cb2566, 0x644d0051, 0x00000000}},  //   _худо, _hoge, _dtai,
  { {0x69cb006c, 0x644d00f4, 0x601009b0, 0x00000000}},  //   _koge, _etai, dämp,
  { {0xed592567, 0x3f9a0020, 0xe45f00b0, 0x00000000}},  //   _kožu_, wepu_, työt_,
  { {0x69cb0376, 0x3eb12568, 0x20070059, 0x00000000}},  // [6380] _moge, _arzt_, čnin_,
  { {0x2497007a, 0x6f1a2569, 0x69cb00f4, 0x00000000}},  //   _کنید_, оцес_, _loge,
  { {0x29d80051, 0x7a010089, 0x0d86007c, 0x00000000}},  //   _béal_, zēta, длен,
  { {0x69cb0018, 0x00000000, 0x00000000, 0x00000000}},  //   _noge,   ,   ,
  { {0xdca303f3, 0x8c4301e0, 0x95880006, 0x00000000}},  //   каци, вече, _grąž,
  { {0xdb08153d, 0xf1bf0011, 0xa91d0006, 0x00000000}},  //   _indú, _thác_, igžd,
  { {0x69cb256a, 0xb17b06d9, 0x00000000, 0x00000000}},  //   _boge, _flåd,   ,
  { {0x78a2037e, 0x69cb1965, 0x1d0a00e2, 0x00000000}},  //   _psov, _coge, _деби_,
  { {0xfcaa0167, 0x7a35251b, 0x00000000, 0x00000000}},  //   _بازو_, _ešto,   ,
  { {0x7a010089, 0x29180089, 0x6d440027, 0x00000000}},  //   rēta, āra_, žiad,
  { {0x644d002a, 0x69cb00eb, 0x656d0022, 0x00000000}},  //   _stai, _foge, _pdah,
  { {0xafdb0056, 0x644d0022, 0x00000000, 0x00000000}},  //   _utøv, _ptai,   ,
  { {0xd943025f, 0x443f001d, 0x3a260039, 0x00000000}},  //   _речи, êu_, _ihop_,
  { {0x69cb111d, 0xacd90049, 0x00000000, 0x00000000}},  //   _zoge, פֿרי,   ,
  { {0x2607025f, 0xa1950088, 0xdb082396, 0x00000000}},  //   _очиг, навч, _andú,
  { {0x656d0166, 0xdb1a0051, 0x00000000, 0x00000000}},  //   _udah, _botú,   ,
  { {0x92c10055, 0x644d12bd, 0xb17b256b, 0x00000000}},  // [6390] ্ছে_, _utai, _smås,
  { {0x25a901bb, 0x7a25256c, 0x00000000, 0x00000000}},  //   _haal_, móte,   ,
  { {0x25a9256d, 0xd356009b, 0xf3ff00c4, 0x00000000}},  //   _kaal_, _איתי_, lsão_,
  { {0x41d30061, 0x201a0026, 0xc05b03e8, 0x00000000}},  //   _सविस, alpi_, _міг_,
  { {0xf3ff0181, 0x25a9256e, 0x644b0068, 0x00000000}},  //   nsão_, _maal_, _égid,
  { {0x7afc037e, 0x69cb0dcc, 0x6a8500e3, 0x00000000}},  //   _žrta, _soge, елка,
  { {0xb6060802, 0x69c00061, 0x8d770439, 0x00000000}},  //   _hláš, वाढी, _يارا,
  { {0x3a260133, 0xb6060161, 0xb17b0146, 0x00000000}},  //   _chop_, _kláš, _flåe,
  { {0x69cb060f, 0xe8f90764, 0x2d9d09df, 0x00000000}},  //   _voge, яли_, mewe_,
  { {0x2d9d14d2, 0xeb90002c, 0x612a0010, 0x00000000}},  //   lewe_, _نظم_, lölé,
  { {0x25a901aa, 0x69cb00ab, 0x7ac4256f, 0x00000000}},  //   _baal_, _toge, _исце,
  { {0xa95401fb, 0x2d9d0117, 0xa50a00e2, 0x00000000}},  //   _акці, newe_, зема_,
  { {0x67d5007c, 0xdb010062, 0x25a901d6, 0x00000000}},  //   _поду, _malí, _daal_,
  { {0xbf1f0061, 0x3dcd02d4, 0xa91d0006, 0x00000000}},  //   _भरून_, _loew_, rgžd,
  { {0xcb120049, 0xb7da009b, 0x2d9d00e7, 0x00000000}},  //   ָלן_, _מקסי, kewe_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c00061, 0x34b30025, 0x602600ed, 0x00000000}},  // [63a0] वाती, _مميز, едаа,
  { {0x65660058, 0xdee60c96, 0x25a900bb, 0x00000000}},  //   lakh, нози, _zaal_,
  { {0xee3a0407, 0x2446001d, 0xb17b011b, 0x00000000}},  //   чне_, _hôm_, _slåe,
  { {0xafdb02cc, 0x2d9d0007, 0x65660145, 0x00000000}},  //   _støt, gewe_, nakh,
  { {0xf1bf0011, 0x61f601df, 0x443a2570, 0x00000000}},  //   _khán_, miyl, _kip_,
  { {0x443a01d6, 0xfaa60216, 0x61f62571, 0x00000000}},  //   _jip_, ешин, liyl,
  { {0xed5a0113, 0x7980049a, 0x2d96008b, 0x00000000}},  //   _нов_, tgmw, _прас,
  { {0x61f6014a, 0xdb0100d4, 0x61e40da6, 0x00000000}},  //   niyl, _galí, nhil,
  { {0x7e7e13f0, 0x75240009, 0x6566008a, 0x00000000}},  //   lupp, _nziz, dakh,
  { {0x25a92572, 0x443a2573, 0x7a0101c5, 0x00000000}},  //   _saal_, _nip_, bēto,
  { {0xd6d70e85, 0x752412d9, 0x9f5a0d62, 0x00000000}},  //   етя_, _aziz, lopó_,
  { {0x7c3a01d9, 0xaadb0104, 0x48e6026b, 0x00000000}},  //   _hitr, _מחבר, _поев,
  { {0x99e91826, 0x61e40020, 0x25a90007, 0x00000000}},  //   _تعلق_, dhil, _vaal_,
  { {0xf3ff02d5, 0xf8b3012f, 0xf1bf0011, 0x00000000}},  //   rsão_, _תשס_, _chán_,
  { {0xf3ff02d5, 0x25a90100, 0xdce90059, 0x00000000}},  //   ssão_, _taal_, _rdeč,
  { {0x20070295, 0xda10006e, 0x7a2500f7, 0x00000000}},  //   čnim_, ावित_, póte,
  { {0x20980930, 0x24890068, 0x00000000, 0x00000000}},  // [63b0] нкты_, _uqam_,   ,
  { {0x7c3a0027, 0x251c007b, 0x661d0039, 0x00000000}},  //   _nitr, _צוזא, llsk,
  { {0x2d9d2574, 0x63ad0089, 0x61f601df, 0x00000000}},  //   tewe_, ļinā, biyl,
  { {0x61e402ae, 0xdb1a2575, 0x00000000, 0x00000000}},  //   chil, _intè,   ,
  { {0xdca5013b, 0x2d9d2576, 0x7c3a0253, 0x00000000}},  //   тали, rewe_, _bitr,
  { {0xeb960331, 0x443a00d4, 0xdb080173, 0x00000000}},  //   виш_, _xip_, _kadè,
  { {0x7c3a04be, 0x2fc7000c, 0x2d9d00e7, 0x00000000}},  //   _ditr, öngu_, pewe_,
  { {0x7c3a2313, 0x00000000, 0x00000000, 0x00000000}},  //   _eitr,   ,   ,
  { {0x7c3a0169, 0xdb0100c4, 0x6d5900e7, 0x00000000}},  //   _fitr, _balã, mbwa,
  { {0x61e401ee, 0x7dfc01aa, 0xdb0100c4, 0x00000000}},  //   zhil, včsi, _calã,
  { {0x65660169, 0xba74035b, 0xe73900ed, 0x00000000}},  //   takh, _مانت, ќен_,
  { {0x7c3a01a2, 0xdd990173, 0x75e60036, 0x00000000}},  //   _zitr, _akňz_, _mózg,
  { {0x65660149, 0xf1bf0011, 0x60c40066, 0x00000000}},  //   rakh, _phán_, xxim,
  { {0x6b832577, 0x65660056, 0x6e3b007f, 0x00000000}},  //   ngng, sakh, _liub,
  { {0x443a001d, 0x61e4010f, 0xf1bf0082, 0x00000000}},  //   _vip_, thil, _cháo_,
  { {0x443a01d6, 0x69c900ea, 0x24460011, 0x00000000}},  //   _wip_, njee, _tôm_,
  { {0xa0670113, 0xdb1a0263, 0x61f6014a, 0x00000000}},  // [63c0] ката_, _entè, riyl,
  { {0x61e42578, 0x3fe30457, 0xafdb02cc, 0x00000000}},  //   shil, ажув, _stør,
  { {0x7c3a2579, 0x7d1b011c, 0x69db00b0, 0x00000000}},  //   _ritr, _ayus, kkue,
  { {0x7e7e0292, 0x76430020, 0x6e29257a, 0x00000000}},  //   rupp, _muny, _cheb,
  { {0xdb1a257b, 0xdd8f06dd, 0x7e7e0039, 0x00000000}},  //   _inté, تون_, supp,
  { {0x6564257c, 0x387f108a, 0xdb0100f6, 0x00000000}},  //   _leih, duur_, _balà,
  { {0x7c3a00f4, 0x628e1b0d, 0x7d0906c2, 0x00000000}},  //   _vitr, ntbo, _exes,
  { {0xdb010181, 0x225e01ca, 0x6e3b0197, 0x00000000}},  //   _salã, átky_, _giub,
  { {0x7c3a028c, 0x387f257d, 0x61e10023, 0x00000000}},  //   _titr, guur_, ëlli,
  { {0x7c3a00c7, 0x764301a3, 0x00000000, 0x00000000}},  //   _uitr, _buny,   ,
  { {0xdce90089, 0x69c6003c, 0x973c0166, 0x00000000}},  //   _ideā, ökes, jeće,
  { {0x973c0091, 0x7a250036, 0x764306df, 0x00000000}},  //   deće, rótc, _duny,
  { {0x661d0039, 0x628e008e, 0x2955005e, 0x00000000}},  //   rlsk, etbo, _съхр,
  { {0x200702aa, 0xdb1a257e, 0x628e0d33, 0x00000000}},  //   čnik_, _anté, ftbo,
  { {0x56940057, 0x6d4001aa, 0x179b009b, 0x00000000}},  //   _сайт, _ogma, _חיוב,
  { {0x2918257f, 0xd6d90088, 0x6d400058, 0x00000000}},  //   ğraf_, _яті_, _ngma,
  { {0xdb010253, 0xa5bb2285, 0x00000000, 0x00000000}},  // [63d0] _malá, rlód,   ,
  { {0xa5bb002a, 0xdefb0057, 0xdb1a2580, 0x00000000}},  //   slód, мые_, _enté,
  { {0x6d4b001c, 0xf7730097, 0x6d400022, 0x00000000}},  //   tcga, שקע_, _bgma,
  { {0x20180263, 0xf1bf0011, 0x44310146, 0x00000000}},  //   _ekri_, _khám_, lmz_,
  { {0xbc19008b, 0x6d4000d4, 0x7a25000c, 0x00000000}},  //   нікі_, _dgma, jóta,
  { {0xe504013d, 0x7a350006, 0x387f01bb, 0x00000000}},  //   रपति_, _išti, vuur_,
  { {0xfb84008b, 0xbe88003b, 0xab84012c, 0x00000000}},  //   рычн, _исте_, ручк,
  { {0x387f1787, 0xc3340104, 0x76430541, 0x00000000}},  //   tuur_, סוק_, _runy,
  { {0x6564010f, 0xf1bf2581, 0x69c900b0, 0x00000000}},  //   _reih, _mná_, rjee,
  { {0x68e90046, 0x7643020c, 0x47c500aa, 0x00000000}},  //   rzed, _puny, убов,
  { {0x2007092f, 0x628e0857, 0xaa550098, 0x00000000}},  //   čnih_, xtbo, _свеш,
  { {0x2619028c, 0xdb012582, 0x7a25000c, 0x00000000}},  //   déos_, _galá, bóta,
  { {0x973c0107, 0x69c00204, 0x6444004a, 0x00000000}},  //   veće, वारी, _quii,
  { {0x6564010f, 0x394d12b9, 0x628e00ea, 0x00000000}},  //   _weih, lces_, ttbo,
  { {0x386d2141, 0xb80500a1, 0x973c0166, 0x00000000}},  //   lser_, _لکھے_, teće,
  { {0x394d032c, 0x386d05af, 0x00000000, 0x00000000}},  //   nces_, oser_,   ,
  { {0x628e0039, 0x386d067e, 0x973c0091, 0x00000000}},  // [63e0] stbo, nser_, reće,
  { {0xd84800ad, 0x973c0107, 0x53a6003b, 0x00000000}},  //   _học_, seće, _саоб,
  { {0x973c016c, 0x6d4000e0, 0x394d0036, 0x00000000}},  //   peće, _pgma, kces_,
  { {0xc27b007b, 0x386d01e3, 0xa155005e, 0x00000000}},  //   _ארטי, kser_, _върш,
  { {0x386d0018, 0xd8480011, 0x291d00e7, 0x00000000}},  //   jser_, _mọc_, _nywa_,
  { {0xdb012583, 0x394d01c5, 0x386d0030, 0x00000000}},  //   _salá, eces_, dser_,
  { {0xdb0114aa, 0x386d0240, 0x3f98016c, 0x00000000}},  //   _palá, eser_, _ibru_,
  { {0xdd920151, 0x98740072, 0xef17007c, 0x00000000}},  //   _دور_, алиц, _смс_,
  { {0x443123cf, 0xcd06004d, 0x00000000, 0x00000000}},  //   ymz_, _спай,   ,
  { {0x089706ea, 0x18970025, 0x97a6013b, 0x00000000}},  //   اضيع_, اضية_, урил,
  { {0xdb010047, 0x6c330025, 0x386d00d2, 0x00000000}},  //   _talá, _افلا, aser_,
  { {0x394d0382, 0xd94601fc, 0xd8480011, 0x00000000}},  //   cces_, _седи, _cọc_,
  { {0xd8480011, 0xa8560143, 0x00000000, 0x00000000}},  //   _dọc_, _стеј,   ,
  { {0x25ad00b9, 0xdce00235, 0x6036000a, 0x00000000}},  //   žel_, _nemč, _fņmi,
  { {0x268a0025, 0x752800b4, 0x00000000, 0x00000000}},  //   _أختي_, ędza,   ,
  { {0xf1bf0011, 0x7a010089, 0x3f9801f3, 0x00000000}},  //   _thám_, vētk, _abru_,
  { {0x3f9801c3, 0xb17b0146, 0x00000000, 0x00000000}},  // [63f0] _bbru_, _flån,   ,
  { {0x1e0d013d, 0x00000000, 0x00000000, 0x00000000}},  //   िक्ष_,   ,   ,
  { {0x7a35007f, 0xa195007e, 0xb5c80014, 0x00000000}},  //   _ištv, _канч, _شویم_,
  { {0x386d0007, 0x0dc81666, 0x6d442198, 0x00000000}},  //   yser_, лучи_, žian,
  { {0xd264001e, 0x55780049, 0xdb08014a, 0x00000000}},  //   _viņš_, רעדן_, _endü,
  { {0xeb99005c, 0x207a0049, 0xdb1a00c4, 0x00000000}},  //   тик_, _באשא, _notó,
  { {0x7a010089, 0x543c0049, 0x2bc70316, 0x00000000}},  //   lēti, געגא, लाबा,
  { {0x386d2584, 0x00000000, 0x00000000, 0x00000000}},  //   tser_,   ,   ,
  { {0x394d030a, 0xdb1a0211, 0x386d068d, 0x00000000}},  //   rces_, _botó, user_,
  { {0x386d01bf, 0x2cb8004b, 0xa76501e1, 0x00000000}},  //   rser_, _حافظ_, шкод,
  { {0x7bc10336, 0xe9750014, 0x7d1600b4, 0x00000000}},  //   _inlu, _نهاد, żyst,
  { {0x195900a5, 0x386d0302, 0xdb0800d6, 0x00000000}},  //   _рады_, pser_, _endó,
  { {0xdb1a0047, 0xb17b00f8, 0xa5bb00fa, 0x00000000}},  //   _fotó, _plån, rmóp,
  { {0xdb01153d, 0xa4060044, 0xdb1a0036, 0x00000000}},  //   _calç, োগ্য_, _gotó,
  { {0x98140025, 0xdce00173, 0x00000000, 0x00000000}},  //   _ابنا, _remč,   ,
  { {0x65bb021e, 0xd848001d, 0x24f60088, 0x00000000}},  //   _vähä, _họa_, _вчор,

  { {0x1f660b9d, 0x7bc10197, 0x973c0166, 0x00000000}},  // [6400] икам, _onlu, meća,
  { {0x65bb021e, 0x7a350391, 0x00000000, 0x00000000}},  //   _tähä, _ištu,   ,
  { {0xd37b012f, 0xe37b00a0, 0x1eca005e, 0x00000000}},  //   _בריט, _בריר, ължи_,
  { {0x629e17f4, 0x06960049, 0x7a010089, 0x00000000}},  //   _ippo, ידעם_, bēti,
  { {0xf3c90014, 0x9cf6003b, 0xdb1a00f6, 0x00000000}},  //   _شبیه_, јчеш, _notò,
  { {0x629e0022, 0x635300b9, 0xdb01006b, 0x00000000}},  //   _kppo, mění, _xalç,
  { {0x6da60140, 0x09af0044, 0x00000000, 0x00000000}},  //   _кива, কানা,   ,
  { {0x973c0182, 0xf41f04ec, 0x7bc10068, 0x00000000}},  //   jeća, ltät_, _enlu,
  { {0xc7c6058f, 0xfce30478, 0x629e0022, 0x00000000}},  //   асни, _дото, _lppo,
  { {0x5fc901f5, 0x38790010, 0x2ca9009d, 0x00000000}},  //   रायल, ásra_, çade_,
  { {0x09e60822, 0xd8480011, 0x8c1b009b, 0x00000000}},  //   _кожн, _dọa_, _יומי,
  { {0xdb1a00d4, 0x00000000, 0x00000000, 0x00000000}},  //   _fotò,   ,   ,
  { {0x629e16df, 0x5347012b, 0x4dc80044, 0x00000000}},  //   _appo, ихва, _শতাং,
  { {0x26f70123, 0x61e601c3, 0xdb1a00e5, 0x00000000}},  //   اریخ_, _alkl, _intâ,
  { {0x69c20112, 0x61e60022, 0x25b000b0, 0x00000000}},  //   _knoe, _blkl, öllä_,
  { {0x31c401fb, 0x518700ed, 0xf1bf0011, 0x00000000}},  //   осув, јува, _khái_,
  { {0x629e0026, 0x00000000, 0x00000000, 0x00000000}},  // [6410] _eppo,   ,   ,
  { {0x7a01001e, 0x3d1a03d7, 0xdb1a06c2, 0x00000000}},  //   rēti, _बड़े_, _antí,
  { {0x442300d0, 0x98bd0066, 0x00000000, 0x00000000}},  //   mlj_, _mewġ_,   ,
  { {0x6e22027b, 0x442301e5, 0x7a0101c5, 0x00000000}},  //   glob, llj_, pēti,
  { {0x6aba0253, 0xf1bf0011, 0xf3f00014, 0x00000000}},  //   _artf, _nhái_, _رأی_,
  { {0x69c2044a, 0x3b091867, 0x92b401b2, 0x00000000}},  //   _anoe, лело_, _احیا,
  { {0x6e221ec6, 0x7eb00010, 0xddab01ee, 0x00000000}},  //   blob, rópá, _итал_,
  { {0xf9910025, 0x3ebe000c, 0xf53f03b1, 0x00000000}},  //   سبب_, _átta_, ndås_,
  { {0x973c0091, 0x5ef90044, 0x68f6007f, 0x00000000}},  //   veća, _অডিও_, _žydr,
  { {0x7d040051, 0x7d1e0036, 0xdb0101a2, 0x00000000}},  //   úise, ępst, _palä,
  { {0x38ca007a, 0x7cfd08c8, 0xdce00089, 0x00000000}},  //   نایی_, _færø, _iemā,
  { {0x1a6400a1, 0x8afa0049, 0x00000000, 0x00000000}},  //   _بیٹی_, _גלעז,   ,
  { {0x49b80a4f, 0xd8480011, 0x79890bed, 0x00000000}},  //   _خالد_, _tọa_, mgew,
  { {0xf8b600b6, 0x973c0521, 0xb05b03a9, 0x00000000}},  //   _לפני_, seća, _kräf,
  { {0xd5ad026c, 0x12b80044, 0x973c2585, 0x00000000}},  //   رہی_, ীন্দ, lećn,
  { {0xa5bb027b, 0x68ec005d, 0x395f00bb, 0x00000000}},  //   llón, _öldü, nbus_,
  { {0xb4db0129, 0x25fd013d, 0x44230087, 0x00000000}},  // [6420] scàr, _लगती_, blj_,
  { {0xe0df0173, 0x6d56014a, 0x798901a2, 0x00000000}},  //   _afòs_, ıyam, hgew,
  { {0x6e220059, 0x6d440006, 0xa1360014, 0x00000000}},  //   tlob, žiam, _گردش,
  { {0x798900b5, 0xf41f0844, 0x49180061, 0x00000000}},  //   jgew, stät_, _पडलो_,
  { {0x798901d6, 0xa1360025, 0x395f00d9, 0x00000000}},  //   dgew, _دردش, dbus_,
  { {0x62810682, 0x69c200c7, 0xd8480011, 0x00000000}},  //   álog, _snoe, _bọn_,
  { {0x224205ed, 0x79892586, 0x200f009d, 0x00000000}},  //   _kikk_, fgew, égie_,
  { {0xf1bf0011, 0x7989172d, 0x201a00ca, 0x00000000}},  //   _phái_, ggew, lopi_,
  { {0xdd8f0752, 0x2242006c, 0x8b96189c, 0x00000000}},  //   _سول_, _mikk_, _греч,
  { {0x22420056, 0x201a0145, 0x37aa01ee, 0x00000000}},  //   _likk_, nopi_, утин_,
  { {0xd8480011, 0x501b009b, 0x4423050f, 0x00000000}},  //   _gọn_, רויו, vlj_,
  { {0xdb1a02d5, 0xf1bf001d, 0x35e7008b, 0x00000000}},  //   _entã, _thái_, сцов,
  { {0x999f005d, 0x81de0044, 0x3946020e, 0x00000000}},  //   lmuş_, তফা_, _igos_,
  { {0xf64f00a1, 0x29d80048, 0x22420085, 0x00000000}},  //   بئی_, _géar_, _aikk_,
  { {0x999f027d, 0x201a2587, 0x7a350006, 0x00000000}},  //   nmuş_, dopi_, _ištr,
  { {0x22420047, 0x2a8e006b, 0x3ebf0e3d, 0x00000000}},  //   _cikk_, _həbs_, _čut_,
  { {0x656f001f, 0x7a0800b9, 0x2fc30085, 0x00000000}},  // [6430] mach, větl, _pnjg_,
  { {0x656f002a, 0x752d0091, 0x53990d99, 0x00000000}},  //   lach, _izaz, _твоя_,
  { {0x543c007b, 0x61e3001a, 0x22420056, 0x00000000}},  //   _געזא, _înlo, _fikk_,
  { {0x656f0b0e, 0x63a70046, 0x645d00d9, 0x00000000}},  //   nach, lejn, opsi,
  { {0x61ed0a96, 0x6295002d, 0x7a352588, 0x00000000}},  //   mhal, ltzo, _oštr,
  { {0x656f0051, 0x61ed23c5, 0xdb032589, 0x00000000}},  //   hach, lhal, lené,
  { {0x7989172d, 0xdce901a8, 0x656f0020, 0x00000000}},  //   tgew, _odeć, kach,
  { {0x61ed0292, 0x32090bf2, 0x656f00e7, 0x00000000}},  //   nhal, nnay_, jach,
  { {0x656f07eb, 0x798915d0, 0x2cad0038, 0x00000000}},  //   dach, rgew, _used_,
  { {0xb05b0073, 0x660d0004, 0x7989258a, 0x00000000}},  //   _träf, _ajak, sgew,
  { {0x63a7258b, 0x060a1320, 0x7afc0825, 0x00000000}},  //   dejn, инок_, _žrtv,
  { {0x656f0051, 0x62871013, 0x67e40173, 0x00000000}},  //   gach, dujo, _fòjo,
  { {0x61ed000b, 0x3e48011f, 0x660d01aa, 0x00000000}},  //   dhal, _işte_, _djak,
  { {0x66e5258c, 0x316007e7, 0x682f06ec, 0x00000000}},  //   _мола, wbiz_, føde,
  { {0xc74406f1, 0x656f1af8, 0x752d002d, 0x00000000}},  //   _عضوي, bach, _ezaz,
  { {0x61ed258d, 0x660d0065, 0x3209011c, 0x00000000}},  //   ghal, _gjak, gnay_,
  { {0x201a00ca, 0x31600032, 0x63a70023, 0x00000000}},  // [6440] topi_, rbiz_, bejn,
  { {0xb4e602d2, 0x62870211, 0x63a700b9, 0x00000000}},  //   पनी_, bujo, cejn,
  { {0x6146258e, 0x5ea6023c, 0x201a02db, 0x00000000}},  //   _мена, تمال, ropi_,
  { {0x4444120d, 0x61ed0fd6, 0xdb0801ca, 0x00000000}},  //   _hi_, chal, _nadá,
  { {0x4444258f, 0xf1bf0011, 0xa6de0011, 0x00000000}},  //   _ki_, _cháu_, _ngưn,
  { {0x4444257a, 0x2ca90a0a, 0x61e40fa8, 0x00000000}},  //   _ji_, çada_, lkil,
  { {0x44440119, 0xb05b0210, 0x656f1519, 0x00000000}},  //   _mi_, _präg, yach,
  { {0x44442590, 0xdb082591, 0x7a250051, 0x00000000}},  //   _li_, _cadá, nóth,
  { {0x44440181, 0x656f2592, 0x2fd82593, 0x00000000}},  //   _oi_, vach, _korg_,
  { {0x44440be3, 0xc7b805fa, 0x656f2594, 0x00000000}},  //   _ni_, kođe_, wach,
  { {0x656f038f, 0xb05b0788, 0xf1bf0011, 0x00000000}},  //   tach, _träg, _khát_,
  { {0x2fd8223d, 0x75240009, 0x61ed2595, 0x00000000}},  //   _lorg_, _byiz, xhal,
  { {0x44440213, 0x656f0270, 0xf772026c, 0x00000000}},  //   _bi_, rach, _ہاں_,
  { {0x44442596, 0x656f0a48, 0xdb0801ca, 0x00000000}},  //   _ci_, sach, _zadá,
  { {0x44440026, 0x61ed2597, 0x63b52598, 0x00000000}},  //   _di_, thal, rdzn,
  { {0x44440ac2, 0x244f011f, 0x533400ed, 0x00000000}},  //   _ei_, _tüm_, фест,
  { {0x44441254, 0x61ed0125, 0x05960014, 0x00000000}},  // [6450] _fi_, rhal, _رايگ,
  { {0x44440292, 0x661d037e, 0x61ed001f, 0x00000000}},  //   _gi_, losk, shal,
  { {0x644d0051, 0x656d04cb, 0xaad90061, 0x00000000}},  //   _huai, _keah, _बॅंक,
  { {0x44442599, 0x6445259a, 0xdb010051, 0x00000000}},  //   _zi_, _hihi, _talú,
  { {0x4444014a, 0x69ce03d7, 0x6445259b, 0x00000000}},  //   _yi_, थानी, _kihi,
  { {0x44440f68, 0x2fd8259c, 0x7a2505a3, 0x00000000}},  //   _xi_, _gorg_, móti,
  { {0x4cd30055, 0x644d002a, 0x644500b0, 0x00000000}},  //   _দেখু, _luai, _mihi,
  { {0xb05b0073, 0x2fd800b5, 0x6445011c, 0x00000000}},  //   _träd, _zorg_, _lihi,
  { {0x644d002a, 0xdb080010, 0xafdb00ea, 0x00000000}},  //   _nuai, _vadá, _støy,
  { {0x61e4002d, 0x6d49006b, 0xe8f6007e, 0x00000000}},  //   zkil, şmağ, ялы_,
  { {0x4444259d, 0x98ab005d, 0x78a2016c, 0x00000000}},  //   _ri_, ımız_, _epov,
  { {0x44441305, 0x20010020, 0x644d0051, 0x00000000}},  //   _si_, hihi_, _buai,
  { {0x44440607, 0x644d002a, 0x6445011c, 0x00000000}},  //   _pi_, _cuai, _bihi,
  { {0x69d90038, 0x44440065, 0x644d0051, 0x00000000}},  //   _howe, _qi_, _duai,
  { {0x444400eb, 0x61e4011f, 0x6445259e, 0x00000000}},  //   _vi_, tkil, _dihi,
  { {0x44440263, 0x644d002a, 0x2fd80007, 0x00000000}},  //   _wi_, _fuai, _sorg_,
  { {0x61e4259f, 0x644d0a47, 0x44210022, 0x00000000}},  // [6460] rkil, _guai, _fkh_,
  { {0x61e400eb, 0x69d900ab, 0x644525a0, 0x00000000}},  //   skil, _lowe, _gihi,
  { {0xf1bf25a1, 0x61e40095, 0x00000000, 0x00000000}},  //   _phát_, pkil,   ,
  { {0x69d90036, 0x2cbf25a2, 0x5edb0044, 0x00000000}},  //   _nowe, _brud_, _যেহে,
  { {0x91bb009b, 0xc1bb009b, 0x2cbf25a3, 0x00000000}},  //   _המכי, _המכש, _crud_,
  { {0xf1bf0048, 0xf0930049, 0x2cbf005b, 0x00000000}},  //   _fhás_, _אנש_, _drud_,
  { {0xa3cd001c, 0x6fc9007d, 0x69d91e67, 0x00000000}},  //   ळात_, रारं, _bowe,
  { {0xe0df000a, 0x69d90d29, 0x00000000, 0x00000000}},  //   _ogòl_, _cowe,   ,
  { {0x69d91eb0, 0x00000000, 0x00000000, 0x00000000}},  //   _dowe,   ,   ,
  { {0x25a0006c, 0x644d0051, 0x7b070010, 0x00000000}},  //   _abil_, _ruai, ártá,
  { {0x47340373, 0x661d00b0, 0xdc3b0049, 0x00000000}},  //   ьнос, tosk, _פעבר,
  { {0x7bda0020, 0x644525a4, 0xa5bb25a5, 0x00000000}},  //   _hotu, _sihi, plóm,
  { {0x644d0181, 0xd7e60822, 0x44210093, 0x00000000}},  //   _quai, _ніко, _pkh_,
  { {0x493b019b, 0x69d900b5, 0x7bda01c5, 0x00000000}},  //   _הגדו, _zowe, _jotu,
  { {0x7bda0058, 0x644525a6, 0x35f500e2, 0x00000000}},  //   _motu, _vihi, _опкр,
  { {0x644d002a, 0x823403ab, 0xd01100a1, 0x00000000}},  //   _tuai, فرقا, ھلا_,
  { {0x64450107, 0x7bda006c, 0xc05b0088, 0x00000000}},  // [6470] _tihi, _ootu, сіб_,
  { {0x4427002a, 0x7bda0a58, 0x09c90061, 0x00000000}},  //   _ón_, _notu, _ाच्य,
  { {0x2001011f, 0xce5900e2, 0xb05b0a2f, 0x00000000}},  //   rihi_, цаец_, _bräc,
  { {0x7bc80058, 0x2ca90181, 0x200100f0, 0x00000000}},  //   _andu, çado_, sihi_,
  { {0xee3801fb, 0x7bda0065, 0x69d90036, 0x00000000}},  //   їні_, _botu, _rowe,
  { {0x69d9063c, 0x7bda0adb, 0xfaa50269, 0x00000000}},  //   _sowe, _cotu, дако,
  { {0x69d90038, 0x75280046, 0xb05b00f8, 0x00000000}},  //   _powe, ędzi, _fräc,
  { {0x08c5025f, 0x6d490030, 0xceb20097, 0x00000000}},  //   дбин, _ugea, _ביל_,
  { {0xf8a9007a, 0x7bda00d4, 0x80df0044, 0x00000000}},  //   تگاه_, _fotu, _নেত্,
  { {0xdb0313a5, 0xd709007c, 0xcb68003b, 0x00000000}},  //   lení, жное_, _нађе_,
  { {0x69d900ab, 0xff56009b, 0x00000000, 0x00000000}},  //   _towe, ובתך_,   ,
  { {0xf3e9019b, 0xfb1a0049, 0x2d8f0fe7, 0x00000000}},  //   _דף_, _וועמ, ngge_,
  { {0x7bda0061, 0x6d440dc6, 0xdb1a0052, 0x00000000}},  //   _yotu, žiav, _entä,
  { {0x33d50099, 0x67d40088, 0xf7710025, 0x00000000}},  //   ніст, _почу, _شات_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb0301ca, 0x00000000, 0x00000000, 0x00000000}},  //   jení,   ,   ,
  { {0xdb030161, 0x41270745, 0x63b725a7, 0x00000000}},  // [6480] dení, дото_, _faxn,
  { {0xdfa60025, 0x7a25000c, 0x00000000, 0x00000000}},  //   بحري, mótu,   ,
  { {0x60c90066, 0x00000000, 0x00000000, 0x00000000}},  //   _ġeme,   ,   ,
  { {0x7bda001a, 0x00000000, 0x00000000, 0x00000000}},  //   _sotu,   ,   ,
  { {0xa3b203d7, 0x3ead0363, 0x68ed0046, 0x00000000}},  //   _ऐसा_, _ćete_, _żadn,
  { {0x2d8f0197, 0x2ac6012b, 0x00000000, 0x00000000}},  //   agge_, дљив,   ,
  { {0x160e02d2, 0x7bda2599, 0xc6e80055, 0x00000000}},  //   ाचार_, _votu, _পশ্চ,
  { {0x80b5013d, 0xdb0300b9, 0x2d950930, 0x00000000}},  //   _उनमे, cení, _прус,
  { {0x7bda25a8, 0xad2600a2, 0x973c0521, 0x00000000}},  //   _totu, _آرزو, meći,
  { {0x7bc80093, 0xdb180023, 0x00000000, 0x00000000}},  //   _undu, ndvë,   ,
  { {0xd848001d, 0xeb9701fb, 0xcb0a0464, 0x00000000}},  //   _mọi_, _цих_, _بيان_,
  { {0x7c2a0039, 0x6d440006, 0xf1bf0082, 0x00000000}},  //   llfr, žiau, _nháp_,
  { {0xdb010161, 0x00000000, 0x00000000, 0x00000000}},  //   _malý,   ,   ,
  { {0xdb030802, 0x7a13001a, 0xd7c80025, 0x00000000}},  //   zení, măta, _روعه_,
  { {0x2d8f0c88, 0x7c2a0009, 0xa2940088, 0x00000000}},  //   ygge_, ilfr, карі,
  { {0x973c0166, 0x00000000, 0x00000000, 0x00000000}},  //   jeći,   ,   ,
  { {0xc34b008b, 0x60f90147, 0x7a13001a, 0x00000000}},  // [6490] _мяне_, чная_, năta,
  { {0xceeb0076, 0x7ae300b0, 0x00000000, 0x00000000}},  //   يران_, yynt,   ,
  { {0xb17b1fbf, 0x00000000, 0x00000000, 0x00000000}},  //   _blåt,   ,   ,
  { {0x7bde000c, 0x00000000, 0x00000000, 0x00000000}},  //   öpun,   ,   ,
  { {0x7ae30016, 0x415a0104, 0x61ef0022, 0x00000000}},  //   wynt, _מדרג, _ilcl,
  { {0xdb0301ca, 0x9f5a00f6, 0x00000000, 0x00000000}},  //   sení, cipà_,   ,
  { {0xd848001d, 0xd7d20061, 0xb17b06ec, 0x00000000}},  //   _gọi_, तानच, _flåt,
  { {0xfe430123, 0x7c2a0009, 0xa5bb25a9, 0x00000000}},  //   _شکای, alfr, blói,
  { {0x7ae300b0, 0x7a25009f, 0xa5bb002a, 0x00000000}},  //   synt, dótt, clói,
  { {0xb7bf0044, 0x5fd20061, 0x00000000, 0x00000000}},  //   েস্ট, सायल,   ,
  { {0xd62a25aa, 0x7a08013e, 0x00000000, 0x00000000}},  //   зоне_, větv,   ,
  { {0x98a0010a, 0x2bc7006e, 0x00000000, 0x00000000}},  //   _šią_, लाका,   ,
  { {0xe8ee025f, 0x8cc2013d, 0x6d5b00e7, 0x00000000}},  //   _сл_, लियो, _mfua,
  { {0xe787007e, 0xb60200b9, 0xdd0c00b4, 0x00000000}},  //   _цудо, _žáda, _różo,
  { {0xf1bf001d, 0x12ce0044, 0x00000000, 0x00000000}},  //   _pháp_, রন্দ,   ,
  { {0x3ebe009f, 0xdb01004a, 0xd8480082, 0x00000000}},  //   _átti_, _haló, _rọi_,
  { {0x04570025, 0xbf080164, 0x660605e0, 0x00000000}},  // [64a0] _كلية_, वप्न_, mikk,
  { {0x660608b2, 0xb17b25ab, 0x61ef004a, 0x00000000}},  //   likk, _blås, _elcl,
  { {0x69cb046a, 0x0d860256, 0xf1bf0011, 0x00000000}},  //   _onge, елен, _tháp_,
  { {0x63ae25ac, 0x6606044e, 0x7c2a018e, 0x00000000}},  //   lebn, nikk, wlfr,
  { {0x629c049a, 0x628e011c, 0xfa150044, 0x00000000}},  //   ltro, lubo, াতাল_,
  { {0x69cb25ad, 0x660625ae, 0x973c0107, 0x00000000}},  //   _ange, hikk, seći,
  { {0x628e10e0, 0x69cb0022, 0x7c2a0133, 0x00000000}},  //   nubo, _bnge, rlfr,
  { {0x7e9b009b, 0xf2d300b3, 0x00000000, 0x00000000}},  //   _מסלו, רעה_,   ,
  { {0x8c950099, 0x6c86004b, 0x629c0065, 0x00000000}},  //   _архі, _سلام, htro,
  { {0xdb0100fa, 0x6e2225af, 0x628e05e1, 0x00000000}},  //   _caló, loob, kubo,
  { {0x660601e3, 0x63ae00b9, 0x031f013d, 0x00000000}},  //   fikk, debn, _मुंह_,
  { {0xba8b00a1, 0x6606068f, 0x628e01ed, 0x00000000}},  //   _رحمۃ_, gikk, dubo,
  { {0x37e60081, 0x7a25009f, 0x6fb20061, 0x00000000}},  //   _подг, rótt, ीयां,
  { {0x63ae001f, 0xb05b0039, 0x629c00ea, 0x00000000}},  //   gebn, _brän, ftro,
  { {0xdbc7006c, 0x17570104, 0x31c7007e, 0x00000000}},  //   _töös, _אסור_, нсав,
  { {0xb05b0210, 0xdb010173, 0x6aa800fa, 0x00000000}},  //   _drän, _kalò, _mpdf,
  { {0xb17b0c73, 0x00000000, 0x00000000, 0x00000000}},  // [64b0] _slås,   ,   ,
  { {0xa0c40025, 0xb05b09b0, 0x00000000, 0x00000000}},  //   ديكو, _frän,   ,
  { {0x44230119, 0x63a90091, 0xb05b0039, 0x00000000}},  //   moj_, đend, _grän,
  { {0x44230091, 0xaf340025, 0x127a0049, 0x00000000}},  //   loj_, اركت, _קארע,
  { {0x672a000c, 0x973c0521, 0x7e7c012d, 0x00000000}},  //   _lyfj, meću, _evrp,
  { {0xed15026c, 0x44230119, 0xeab10025, 0x00000000}},  //   _یہاں_, noj_, لعب_,
  { {0x3da7008b, 0xdea4007a, 0x224b25b0, 0x00000000}},  //   _праб, _میلی, _kick_,
  { {0x442325b1, 0xdb01113f, 0x63ae0036, 0x00000000}},  //   hoj_, _saló, zebn,
  { {0x44230119, 0x224b1575, 0x660603b6, 0x00000000}},  //   koj_, _mick_, vikk,
  { {0x44230119, 0x660601b5, 0x629c013e, 0x00000000}},  //   joj_, wikk, ytro,
  { {0xdb0125b2, 0x63ae004f, 0x44230c33, 0x00000000}},  //   _való, vebn, doj_,
  { {0x3ddf02ae, 0x7a13001a, 0xdce000b9, 0x00000000}},  //   _jouw_, măto, _nemě,
  { {0x660600b0, 0x63ae00b9, 0x7a13001a, 0x00000000}},  //   rikk, tebn, lăto,
  { {0x629c13f0, 0x6606021e, 0x44230091, 0x00000000}},  //   ttro, sikk, goj_,
  { {0x23270200, 0xe297005e, 0x7a13001a, 0x00000000}},  //   вори_, кар_, năto,
  { {0x63ae01ae, 0x629c046a, 0x212b0224, 0x00000000}},  //   sebn, rtro, _bych_,
  { {0x629c0428, 0x44230059, 0xa3ba0318, 0x00000000}},  // [64c0] stro, boj_, _قادر_,
  { {0xb05b03a2, 0x4423016c, 0x629c013f, 0x00000000}},  //   _trän, coj_, ptro,
  { {0x224b0073, 0x6e2225b3, 0x3ddf00b5, 0x00000000}},  //   _fick_, toob, _bouw_,
  { {0x224b0073, 0x98b100b9, 0x91e602dc, 0x00000000}},  //   _gick_, íběh_, _роме,
  { {0x2240006c, 0x6fc9013d, 0x6e22010e, 0x00000000}},  //   mmik_, राखं, roob,
  { {0xdce000b9, 0x224025b4, 0x3a262299, 0x00000000}},  //   _země, lmik_, _skop_,
  { {0x443a014a, 0x7a13001a, 0x63a30010, 0x00000000}},  //   _mhp_, găto, _önne,
  { {0x44230065, 0xa93400a5, 0xd8480011, 0x00000000}},  //   zoj_, лейш, _lọt_,
  { {0xdca601f9, 0xdb1a0065, 0x1c4602e9, 0x00000000}},  //   _јази, _katë, _анам,
  { {0x66040047, 0x44230065, 0x2240146c, 0x00000000}},  //   _amik, xoj_, hmik_,
  { {0x44230119, 0x7a13001a, 0xdb1a0023, 0x00000000}},  //   voj_, căto, _matë,
  { {0x6f0302d5, 0x3ebe000c, 0x672a01c3, 0x00000000}},  //   únci, _áttu_, _vyfj,
  { {0x442325b5, 0x973c0107, 0x443a0036, 0x00000000}},  //   toj_, veću, _bhp_,
  { {0x443a014a, 0xdb1a0065, 0x66040009, 0x00000000}},  //   _chp_, _natë, _emik,
  { {0x44230428, 0xf837009b, 0x224b00ab, 0x00000000}},  //   roj_, _שנות_, _pick_,
  { {0x5214008b, 0x442325b6, 0xed590825, 0x00000000}},  //   адст, soj_, _kaže_,
  { {0x443a012d, 0x7a130035, 0x973c04eb, 0x00000000}},  // [64d0] _fhp_, zăto, reću,
  { {0x973c0645, 0xd8480082, 0xdb080190, 0x00000000}},  //   seću, _gọt_, _fadø,
  { {0xdb0304bd, 0xdb1a0065, 0x212b0016, 0x00000000}},  //   menç, _datë, _wych_,
  { {0x212b0832, 0xed5801fb, 0x7c3a25b7, 0x00000000}},  //   _tych_, вої_, _ahtr,
  { {0x61ed02e7, 0xb05b0210, 0xab07000c, 0x00000000}},  //   mkal, _kräm, _íbúð_,
  { {0x61ed0148, 0x7a13001a, 0x2b5e0068, 0x00000000}},  //   lkal, tăto, _cftc_,
  { {0x7c230725, 0x61ed0943, 0xab262337, 0x00000000}},  //   ronr, okal, лоша_,
  { {0x61ed08af, 0xdb1a25b8, 0x5f7400a1, 0x00000000}},  //   nkal, _matè, _ماہر,
  { {0x7a13001a, 0x61ed16a6, 0xdb1a000a, 0x00000000}},  //   săto, ikal, _latè,
  { {0xa7b5098c, 0x61ed25b9, 0x7a130035, 0x00000000}},  //   усиј, hkal, păto,
  { {0x764d0390, 0x61ed1047, 0xb9950025, 0x00000000}},  //   _biay, kkal, _ملاب,
  { {0x443a0061, 0x394f00d9, 0x61ed0c55, 0x00000000}},  //   _shp_, _uggs_, jkal,
  { {0x443a001c, 0x61ed0190, 0xf778002b, 0x00000000}},  //   _php_, dkal, baħ_,
  { {0xec350049, 0xdb1a01aa, 0xdc350049, 0x00000000}},  //   טאָר_, _batè, טאָט_,
  { {0x61f600ab, 0xd8480082, 0x443a08f4, 0x00000000}},  //   thyl, _vọt_, _vhp_,
  { {0x61ed011c, 0x660425ba, 0x69db008e, 0x00000000}},  //   gkal, _umik, njue,
  { {0xb05b0039, 0x68e9020c, 0xdb1a0065, 0x00000000}},  // [64e0] _främ, nyed, _patë,
  { {0x6e3b0061, 0xdb030181, 0x61ed25bb, 0x00000000}},  //   _ahub, cenç, akal,
  { {0xbd8a0025, 0x61f603a1, 0x139b0097, 0x00000000}},  //   فنان_, phyl, _אביע,
  { {0x8d760025, 0x7c3a008d, 0xed5a0121, 0x00000000}},  //   اااا, _shtr, ход_,
  { {0x63be0010, 0xa075007c, 0x5c060b52, 0x00000000}},  //   _kapn, _высш, ляка,
  { {0xdb1a0010, 0x64560009, 0x69a10316, 0x00000000}},  //   _haté, _muyi, क्सी,
  { {0x60c402d5, 0x66f3006b, 0x75e625bc, 0x00000000}},  //   lvim, bəkə, _józs,
  { {0x248001cd, 0x5a3400ed, 0x2c7600a1, 0x00000000}},  //   _ovim_, јнит, _مُرس,
  { {0xdb1a128c, 0x26c70016, 0x68e90010, 0x00000000}},  //   _maté, _arno_, gyed,
  { {0x26c713c7, 0xed590107, 0xca76007e, 0x00000000}},  //   _brno_, _važe_, _буды,
  { {0xdb0325bd, 0x26c70091, 0x7fd70049, 0x00000000}},  //   venç, _crno_, אויס_,
  { {0xdb0a0181, 0x60c405f9, 0x645625be, 0x00000000}},  //   nefí, kvim, _buyi,
  { {0xdb030181, 0x55070930, 0xb05b01a2, 0x00000000}},  //   tenç, учна, _präm,
  { {0xe4540147, 0xdb1a25bf, 0x8937007e, 0x00000000}},  //   скры, _patè, _спіс_,
  { {0xdb030181, 0x61ed1cdb, 0xd6cf003b, 0x00000000}},  //   renç, tkal, _ут_,
  { {0xdb1a028c, 0xdb030181, 0x67380166, 0x00000000}},  //   _caté, senç, _izvj,
  { {0x6e3b0f75, 0x9f4a00f6, 0x623400ed, 0x00000000}},  // [64f0] _rhub, _albà_, сету,
  { {0x61ed119a, 0x6e3b0048, 0xf3ff00c4, 0x00000000}},  //   skal, _shub, mpão_,
  { {0x60c40006, 0xf3ff00c4, 0x6e990088, 0x00000000}},  //   avim, lpão_, твер_,
  { {0x63be0161, 0x4431009d, 0x777a002d, 0x00000000}},  //   _zapn, llz_, hatx,
  { {0x6aba000d, 0xeb9910f2, 0x66f3006b, 0x00000000}},  //   _astf, вил_, rəkə,
  { {0x3f830107, 0x68fb006b, 0xda6519ea, 0x00000000}},  //   _udju_, vzud, авки,
  { {0x69c000b5, 0x777a0032, 0x6e3b120e, 0x00000000}},  //   fdme, datx, _thub,
  { {0x09e50081, 0x6e2900ea, 0x6f0300fa, 0x00000000}},  //   роин, _ukeb, úncu,
  { {0xf771031d, 0x69a101f5, 0x777a00f6, 0x00000000}},  //   ياد_, क्षी, fatx,
  { {0xdb0303b6, 0x25a90093, 0x999e0006, 0x00000000}},  //   tenä, _abal_, _butų_,
  { {0x24800119, 0x68e90173, 0xc30a0044, 0x00000000}},  //   _svim_, syed, _শুনি_,
  { {0x63be0d90, 0x75e607fd, 0x00000000, 0x00000000}},  //   _sapn, _rózs,   ,
  { {0xdb030bf4, 0xdb1a009d, 0xf8a90316, 0x00000000}},  //   senä, _raté, _कहिय,
  { {0xdb1a25c0, 0x44310061, 0x69a10309, 0x00000000}},  //   _saté, glz_, क्री,
  { {0xdb010224, 0x232a04f9, 0x63be25c1, 0x00000000}},  //   _oblí, тови_, _vapn,
  { {0xd8480011, 0xe29700ec, 0x71660025, 0x00000000}},  //   _họp_, јат_, شارك,
  { {0xdfd20380, 0x387f01a3, 0x42230088, 0x00000000}},  // [6500] يير_, nsur_, ідув,
  { {0x44310061, 0x38600051, 0x60c4010e, 0x00000000}},  //   clz_, _éire_, rvim,
  { {0xdfcf0464, 0x60c40778, 0x00000000, 0x00000000}},  //   ظيم_, svim,   ,
  { {0x777a0032, 0x127b0049, 0x00000000, 0x00000000}},  //   zatx, _באטע,   ,
  { {0xa3cb007d, 0x1c460216, 0xf1bf0082, 0x00000000}},  //   _रोड_, андм, _nháy_,
  { {0x22b8000a, 0xbd0501c3, 0x9e6602fd, 0x00000000}},  //   _kōk_, _stéé, _نارن,
  { {0x81b90055, 0x00000000, 0x00000000, 0x00000000}},  //   চার_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x25a90061, 0xf1bf0011, 0x69c00056, 0x00000000}},  //   _rbal_, _cháy_, rdme,
  { {0x57f40216, 0xd8480082, 0xdcfb002b, 0x00000000}},  //   спот, _cọp_, _sbuħ,
  { {0xcf57009b, 0x8f7b0097, 0xdb0100c4, 0x00000000}},  //   יבית_, כניק, _balõ,
  { {0x777a0032, 0x395f0133, 0x00000000, 0x00000000}},  //   satx, ccus_,   ,
  { {0x69fb0049, 0x628e00d9, 0xb05b00f8, 0x00000000}},  //   _בלאק, erbo, _vräk,
  { {0x779200a6, 0x74250044, 0xed590006, 0x00000000}},  //   _بیدا, পষ্ট_, _maža_,
  { {0xa5c40036, 0xf8b6006e, 0x3e48001a, 0x00000000}},  //   _spół, _अनुप, _eşti_,
  { {0x33f40039, 0xd4b900c0, 0x11550b21, 0x00000000}},  //   _växa_, _блиц_, скаю,
  { {0xc058008b, 0x657d0020, 0x628e00d9, 0x00000000}},  // [6510] аіх_, mash, arbo,
  { {0x657d22cb, 0x908a00a1, 0x1e1f0309, 0x00000000}},  //   lash, املے_, यक्ष_,
  { {0x63b501d9, 0x656f0161, 0x2cad051b, 0x00000000}},  //   mezn, obch, _sped_,
  { {0x63b525c2, 0x657d0020, 0x66ea006b, 0x00000000}},  //   lezn, nash, məkd,
  { {0xfd100380, 0x62950667, 0x71d6009b, 0x00000000}},  //   وجه_, luzo, _הורד_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd90f026c, 0x657d0020, 0x38660181, 0x00000000}},  //   ڈیا_, kash, _ator_,
  { {0x657d0065, 0xdb1a0181, 0x9f430065, 0x00000000}},  //   jash, _antó, _lojë_,
  { {0xd7d20061, 0x657d0065, 0x63b50010, 0x00000000}},  //   तांच, dash, kezn,
  { {0x31790047, 0x387f25c3, 0xdb0100c4, 0x00000000}},  //   _lesz_, rsur_, _salõ,
  { {0x387f002b, 0x657d0061, 0x5b3500a1, 0x00000000}},  //   ssur_, fash, _اٹار,
  { {0x7bc1021e, 0xf3e9019b, 0xd46a00ed, 0x00000000}},  //   _halu, _אף_, лиме_,
  { {0x7bc125c4, 0x5a0a0049, 0xb343013f, 0x00000000}},  //   _kalu, _גלײַ, əçis,
  { {0xe70804e1, 0x7bc114f0, 0xe3631662, 0x00000000}},  //   اتین_, _jalu, зкри,
  { {0x2ba9001c, 0x7bc10b9a, 0xe6950054, 0x00000000}},  //   च्या, _malu, _العد,
  { {0x628e0039, 0x7bc101a3, 0xf53f0056, 0x00000000}},  //   rrbo, _lalu, reår_,
  { {0x63b50059, 0x7a13001a, 0x317900d9, 0x00000000}},  // [6520] bezn, găti, _desz_,
  { {0x7bc1011c, 0x2f561948, 0x9f430023, 0x00000000}},  //   _nalu, стас, _gojë_,
  { {0x66ea006b, 0x442a00c4, 0x683d009d, 0x00000000}},  //   cəkd, mob_, cède,
  { {0x442a00d0, 0x7e630010, 0xdb0a1465, 0x00000000}},  //   lob_, ínpa, ánít,
  { {0x7bc125c5, 0x628101c8, 0x7c83041f, 0x00000000}},  //   _balu, álov, пуще,
  { {0x7bc1001a, 0x442a0061, 0x657d0b1b, 0x00000000}},  //   _calu, nob_, zash,
  { {0x3866004e, 0x7bc125c6, 0xdb1a00d4, 0x00000000}},  //   _stor_, _dalu, _antò,
  { {0xada302a8, 0x6da3012b, 0x63b525c7, 0x00000000}},  //   _насл, _ниса, zezn,
  { {0x7bc123c5, 0x657d0010, 0xcb6a25c8, 0x00000000}},  //   _falu, vash, _базе_,
  { {0x442a0c53, 0x657d0020, 0x7bc10006, 0x00000000}},  //   job_, wash, _galu,
  { {0x63b5016c, 0x657d0727, 0xe5b50783, 0x00000000}},  //   vezn, tash, ойны,
  { {0xbb3b0049, 0x61e60089, 0xa2cc0164, 0x00000000}},  //   _געבי, _nokl, हिन्,
  { {0x657d0065, 0xd90e089d, 0x63b50232, 0x00000000}},  //   rash, _سید_, tezn,
  { {0xb05b0073, 0x67d4005e, 0x63a90091, 0x00000000}},  //   _kräv, _фоку, đeno,
  { {0xa77b007b, 0x657d25c9, 0x63b520a0, 0x00000000}},  //   _גרופ, pash, rezn,
  { {0x245d00ad, 0x61e604cb, 0x200a0026, 0x00000000}},  //   _tìm_, _cokl, _ambi_,
  { {0x660f2041, 0x645d0009, 0x6295013e, 0x00000000}},  // [6530] mick, qqsi, suzo,
  { {0x660f0161, 0x6009005f, 0xd5a50204, 0x00000000}},  //   lick, _kömə, ग्रज,
  { {0x41c402f4, 0x7bc1001a, 0x7c2a00ea, 0x00000000}},  //   _लोकस, _ralu, dofr,
  { {0x7bc102e2, 0x660f0428, 0xa69b0049, 0x00000000}},  //   _salu, nick, רשאפ,
  { {0x7bc11c0b, 0xdb180030, 0x00000000, 0x00000000}},  //   _palu, ndvæ,   ,
  { {0xdfdb0265, 0x660f001f, 0x57b70061, 0x00000000}},  //   _съм_, hick, _असेह,
  { {0x7bc125ca, 0x7bc3010f, 0x660f06d3, 0x00000000}},  //   _valu, rdnu, kick,
  { {0x7bc10036, 0xf86500ed, 0x2aa10036, 0x00000000}},  //   _walu, овио, rób_,
  { {0x7bc11d2e, 0x2aa10046, 0x660f0161, 0x00000000}},  //   _talu, sób_, dick,
  { {0xdb1a25cb, 0x6e2b00ea, 0xa6850152, 0x00000000}},  //   _zatí, logb, олод,
  { {0xe73900d7, 0x660f0428, 0x38ca007a, 0x00000000}},  //   рен_, fick, هایی_,
  { {0x660f0428, 0x58d500e3, 0x6e2b012d, 0x00000000}},  //   gick, _моет, nogb,
  { {0x442a0c2d, 0xb05b01a2, 0x628502e1, 0x00000000}},  //   tob_, _kräu, _avho,
  { {0x386d0030, 0x2b4000b9, 0x61e60145, 0x00000000}},  //   mper_, řice_, _sokl,
  { {0x660f00b9, 0xfbd2009b, 0x386d0322, 0x00000000}},  //   bick, ותם_, lper_,
  { {0x799b25cc, 0x26880025, 0x442a0387, 0x00000000}},  //   nguw, _اخوي_, sob_,
  { {0x27e70263, 0x3fe613e7, 0x600a007e, 0x00000000}},  // [6540] _konn_, ожав, анам_,
  { {0x27e725cd, 0x386d009d, 0xdb1a004a, 0x00000000}},  //   _jonn_, iper_, _satí,
  { {0x91e60072, 0x27e70173, 0x25a00022, 0x00000000}},  //   _доне, _monn_, _kcil_,
  { {0x5eac0044, 0x27e7000a, 0x00000000, 0x00000000}},  //   ছিলে, _lonn_,   ,
  { {0xa01b009f, 0x203400a1, 0x7c2a07ec, 0x00000000}},  //   _kvöl, _فہرس, tofr,
  { {0x660f061b, 0xaa66005c, 0x200a25ce, 0x00000000}},  //   zick, отик, _umbi_,
  { {0x05ca013d, 0xaab70025, 0x386d0133, 0x00000000}},  //   ियाब, قدير_, eper_,
  { {0x48aa16e0, 0xab5c001e, 0x7c2a109a, 0x00000000}},  //   атом_, _daļa, sofr,
  { {0xb7bc001e, 0x27e71274, 0x59a60164, 0x00000000}},  //   loģi, _bonn_, क्षर,
  { {0x274a017f, 0x27f8009f, 0x660f03de, 0x00000000}},  //   ично_, órn_, wick,
  { {0x660f0428, 0x1f5b0097, 0x27e725cf, 0x00000000}},  //   tick, ידיא, _donn_,
  { {0x3dc60866, 0xdb0a0190, 0x00000000, 0x00000000}},  //   ndow_, tefæ,   ,
  { {0x660f0428, 0xf8ad007a, 0x38cb026c, 0x00000000}},  //   rick, _یکی_, _پانی_,
  { {0x660f0161, 0x27e70173, 0x798025d0, 0x00000000}},  //   sick, _gonn_, lamw,
  { {0x3d1103d7, 0x660f0161, 0x03c8007e, 0x00000000}},  //   _देने_, pick, цыяй_,
  { {0x798000e7, 0xb05b00f8, 0x00000000, 0x00000000}},  //   namw, _orät,   ,
  { {0xf8bc03d7, 0x27e70263, 0xdcfb0166, 0x00000000}},  // [6550] ्टिय, _yonn_, _iduć,
  { {0x79800cd1, 0x628101dc, 0x2cbf0093, 0x00000000}},  //   hamw, álos, _rsud_,
  { {0x798025d1, 0xdd910025, 0xdb180e2b, 0x00000000}},  //   kamw, فوا_, ndvä,
  { {0x62810091, 0x386d04d3, 0xa91d0091, 0x00000000}},  //   šlos, yper_, laže,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa91d00b9, 0x224925d2, 0x00000000, 0x00000000}},  //   naže, lmak_,   ,
  { {0x660d003c, 0xdb1a0129, 0x27e7000a, 0x00000000}},  //   _omak, _catà, _ronn_,
  { {0xe9d90113, 0xa2cc0201, 0x3f810065, 0x00000000}},  //   ски_, हित्, lahu_,
  { {0x63a90119, 0xa91d0a0f, 0x2cbf25d3, 0x00000000}},  //   đenj, kaže, _usud_,
  { {0x660d0061, 0x386d010f, 0x3f81008a, 0x00000000}},  //   _amak, rper_, nahu_,
  { {0x386d0030, 0xdb0a0002, 0xf52900b3, 0x00000000}},  //   sper_, gefä, _עץ_,
  { {0x2d9d0020, 0x386d25d4, 0x22490107, 0x00000000}},  //   ngwe_, pper_, jmak_,
  { {0x27e7000c, 0x22491332, 0xdb1a0048, 0x00000000}},  //   _tonn_, dmak_, _iatá,
  { {0xdb1a0047, 0x660d25d5, 0x5f010044, 0x00000000}},  //   _hatá, _emak, _এখনও_,
  { {0x7d020026, 0x3f8e000c, 0x60cf04e7, 0x00000000}},  //   zzos, ófum_, _arcm,
  { {0x806601e1, 0x7a130035, 0x00000000, 0x00000000}},  //   зваж, pătu,   ,
  { {0xdb1a0048, 0x00000000, 0x00000000, 0x00000000}},  // [6560] _matá,   ,   ,
  { {0xd9b8013d, 0x798000e7, 0xa856009b, 0x00000000}},  //   _आस्ट, zamw, פיעה_,
  { {0x44440119, 0x2ec60054, 0x59bd006e, 0x00000000}},  //   _ih_, ثقاف, ्यार,
  { {0xdb1a25d6, 0x656600bb, 0xdca60545, 0x00000000}},  //   _natá, nckh, зади,
  { {0x44440011, 0xdb0a25d7, 0x3f8116c3, 0x00000000}},  //   _kh_, ndfö, bahu_,
  { {0x444403e1, 0x0fda0025, 0x61f600f8, 0x00000000}},  //   _jh_, _ابحث_, lkyl,
  { {0x80c402fb, 0x4444000b, 0xb05b0a5d, 0x00000000}},  //   रिके, _mh_, _fräs,
  { {0xdb1a0489, 0xdca60256, 0x44440011, 0x00000000}},  //   _catá, _наби, _lh_,
  { {0x444425d8, 0xfc64007a, 0x6b56039d, 0x00000000}},  //   _oh_, _آخری, _فضائ,
  { {0x6d40001e, 0x660d0ae1, 0x44440011, 0x00000000}},  //   _izma, _smak, _nh_,
  { {0x660d0022, 0x2249014a, 0xa5bb0048, 0x00000000}},  //   _pmak, ymak_, nnóg,
  { {0xaadb00b6, 0x76440173, 0xaac20164, 0x00000000}},  //   _לחבר, _chiy, _वैयक,
  { {0x444425d9, 0x3f8101c3, 0xa91d00b9, 0x00000000}},  //   _bh_, yahu_, taže,
  { {0x4444018e, 0x69a20061, 0x248d0295, 0x00000000}},  //   _ch_, _गाडी, šemo_,
  { {0x883b00b6, 0x444401a3, 0xa91d0091, 0x00000000}},  //   _התגו, _dh_, raže,
  { {0x4444006a, 0xa91d00b9, 0x61e40065, 0x00000000}},  //   _eh_, saže, gjil,
  { {0x4444000b, 0x2249014a, 0x3f810127, 0x00000000}},  // [6570] _fh_, rmak_, tahu_,
  { {0xd37b1666, 0x248900f6, 0x61e40883, 0x00000000}},  //   _учи_, _ivam_, ajil,
  { {0xb05b0a35, 0x2249014a, 0xdddc0c1d, 0x00000000}},  //   _präs, pmak_, _svrš,
  { {0x661d05c8, 0x3f810161, 0x62950910, 0x00000000}},  //   nnsk, sahu_, mrzo,
  { {0x444425da, 0x661d0635, 0x62871742, 0x00000000}},  //   _yh_, insk, lsjo,
  { {0x44440cb5, 0x3d110061, 0xdb1a004a, 0x00000000}},  //   _xh_, _देणे_, _satá,
  { {0x628725db, 0x60cd006c, 0xdb030161, 0x00000000}},  //   nsjo, lvam, bený,
  { {0x64570288, 0xdb0325dc, 0xdce0007f, 0x00000000}},  //   _lixi, cený, _nemė,
  { {0x3a2d01b5, 0xdddc1034, 0x9f5a008e, 0x00000000}},  //   roep_, _uvrš, cipó_,
  { {0x62870292, 0x64571a7b, 0x661d01d6, 0x00000000}},  //   ksjo, _nixi, ensk,
  { {0x6b83027c, 0x4ac102fb, 0x3d11006e, 0x00000000}},  //   mang, _शनिव, _देते_,
  { {0x6b831312, 0x44441b1c, 0x661d0030, 0x00000000}},  //   lang, _sh_, gnsk,
  { {0x69d90036, 0x66ea006b, 0x65660270, 0x00000000}},  //   _inwe, rəka, rckh,
  { {0x6b83027c, 0x69c9002d, 0x661d0027, 0x00000000}},  //   nang, ldee, ansk,
  { {0x444425dd, 0x78a90232, 0x69c900fa, 0x00000000}},  //   _vh_, ltev, odee,
  { {0x69c925de, 0x645f008d, 0x44440253, 0x00000000}},  //   ndee, _fuqi, _wh_,
  { {0x78a9049a, 0x44440038, 0x6b83033b, 0x00000000}},  // [6580] ntev, _th_, kang,
  { {0x4444037e, 0x6d5b0489, 0x61f625df, 0x00000000}},  //   _uh_, _agua, skyl,
  { {0x6b83033b, 0x78a901d9, 0x63bc0cce, 0x00000000}},  //   dang, htev, mern,
  { {0x63bc0030, 0xdd8f0d0b, 0x78a90065, 0x00000000}},  //   lern, لوم_, ktev,
  { {0x6b83010f, 0x629c005b, 0xdbc6006c, 0x00000000}},  //   fang, luro, _mööb,
  { {0x63bc04d7, 0x69d912dc, 0x0a6a170a, 0x00000000}},  //   nern, _anwe, ории_,
  { {0xa3df0061, 0x8fa31123, 0x661d0142, 0x00000000}},  //   णात_, _шаре, ynsk,
  { {0x63a90091, 0x78a925e0, 0x6b8325e1, 0x00000000}},  //   đeni, ftev, aang,
  { {0x6b832543, 0x63bc01c4, 0xdb1a0181, 0x00000000}},  //   bang, kern, _antô,
  { {0x63bc0030, 0x629c008d, 0x6b830016, 0x00000000}},  //   jern, kuro, cang,
  { {0x7bda0657, 0x78a91a48, 0x7bc80035, 0x00000000}},  //   _intu, atev, _iadu,
  { {0x629c018e, 0xb495003b, 0x645725e2, 0x00000000}},  //   duro, нимљ, _sixi,
  { {0xe9f701fb, 0x7bc8006c, 0x661d25e3, 0x00000000}},  //   _інші_, _kadu, rnsk,
  { {0x63bc0018, 0x7bca01a2, 0x62870cfd, 0x00000000}},  //   gern, ndfu, tsjo,
  { {0x629c0252, 0x5454025f, 0x7a3e0065, 0x00000000}},  //   guro, тврт, nëto,
  { {0xa91d0107, 0xf1bf0047, 0x7bc80c75, 0x00000000}},  //   laža, _akár_, _ladu,
  { {0x63bc25e4, 0x628701d5, 0x6b83020c, 0x00000000}},  // [6590] bern, ssjo, yang,
  { {0x60cd006c, 0x7bc80036, 0x6d5b0207, 0x00000000}},  //   rvam, _nadu, _sgua,
  { {0x2013005f, 0x629c001a, 0x4431002d, 0x00000000}},  //   rixi_, curo, moz_,
  { {0x6b831bd2, 0x7bda006c, 0x4431002b, 0x00000000}},  //   wang, _antu, loz_,
  { {0x7bc825e5, 0xcb690216, 0x00000000, 0x00000000}},  //   _badu, пале_,   ,
  { {0x7bc80207, 0x6cd200a1, 0x44311b01, 0x00000000}},  //   _cadu, اقوا, noz_,
  { {0x6b83020c, 0xeab1025a, 0xfb84008b, 0x00000000}},  //   rang, اعت_, тычн,
  { {0x6b83027c, 0x44310047, 0x78a9006c, 0x00000000}},  //   sang, hoz_, ttev,
  { {0x6b831bc6, 0x69c9049b, 0xf8c8001d, 0x00000000}},  //   pang, rdee, _cứ_,
  { {0x7bc80089, 0x78a916b3, 0x44310211, 0x00000000}},  //   _gadu, rtev, joz_,
  { {0x26d125e6, 0x78a915d6, 0x68110224, 0x00000000}},  //   ízo_, stev, vědě,
  { {0x6b81009f, 0x7bc8037e, 0x63bc25e7, 0x00000000}},  //   _helg, _zadu, wern,
  { {0x7bc80009, 0x66ea006b, 0x44310023, 0x00000000}},  //   _yadu, ləkl, foz_,
  { {0x629c25e8, 0x6b81001e, 0x4431002d, 0x00000000}},  //   turo, _jelg, goz_,
  { {0x63bc01bf, 0xed590089, 0x044302dc, 0x00000000}},  //   rern, _daži_, уерн,
  { {0x63bc0193, 0x629c0032, 0xe1ff0051, 0x00000000}},  //   sern, ruro, _cló_,
  { {0xf8c80011, 0xa3cb013d, 0x629c21ae, 0x00000000}},  // [65a0] _xứ_, _रोक_, suro,
  { {0x4431008e, 0x7e7c0016, 0xdb0100fa, 0x00000000}},  //   coz_, _pwrp, _eclé,
  { {0x7bc8016c, 0x22590193, 0x539b00b6, 0x00000000}},  //   _radu, _fisk_, _ציטו,
  { {0x9cca0783, 0x7bc825e9, 0x9f4a00f6, 0x00000000}},  //   зыка_, _sadu, _jobé_,
  { {0x6b8108a5, 0x3ebf0521, 0xdce00089, 0x00000000}},  //   _belg, _ćute_, _iemī,
  { {0x6b810af3, 0x6a670095, 0x00000000, 0x00000000}},  //   _celg, _sıfa,   ,
  { {0x6b810211, 0xf8c80011, 0x644e25ea, 0x00000000}},  //   _delg, _sứ_, imbi,
  { {0x7bc825eb, 0x4431057e, 0x225900f6, 0x00000000}},  //   _wadu, zoz_, _xisk_,
  { {0x0c3a0025, 0xd7db0061, 0x00000000, 0x00000000}},  //   _فكرة_, बांच,   ,
  { {0x7bda0149, 0x7a3e0065, 0x7bc800e7, 0x00000000}},  //   _untu, pëto, _uadu,
  { {0x44310c76, 0x290b029d, 0x66ea006b, 0x00000000}},  //   voz_, úcar_, cəkl,
  { {0x63a5001f, 0xf8c80011, 0xa91d007f, 0x00000000}},  //   _schn, _tứ_, saža,
  { {0xa91d25ec, 0x22591f59, 0x4431002d, 0x00000000}},  //   paža, _risk_, toz_,
  { {0xdb011059, 0xe1ff01e5, 0x00000000, 0x00000000}},  //   _sclé, _sló_,   ,
  { {0xed5905fa, 0x60c6098e, 0x44310091, 0x00000000}},  //   _važi_, _askm, roz_,
  { {0x644e2378, 0x443125ed, 0x7522012d, 0x00000000}},  //   ambi, soz_, _žoze,
  { {0x21390065, 0x64a40098, 0x656d00e7, 0x00000000}},  // [65b0] _qysh_, _бања, _ifah,
  { {0x25df0061, 0x00000000, 0x00000000, 0x00000000}},  //   गावी_,   ,   ,
  { {0x225925ee, 0xa91d089f, 0x93f4007e, 0x00000000}},  //   _tisk_, jažn, _спэц,
  { {0x6b8124c7, 0x2eee0039, 0x7982164f, 0x00000000}},  //   _selg, äffa_, _neow,
  { {0x6b81195d, 0x00000000, 0x00000000, 0x00000000}},  //   _pelg,   ,   ,
  { {0x52740014, 0xd116009b, 0x261225ef, 0x00000000}},  //   _جایز, _יקרה_, všom_,
  { {0xe9d10054, 0x63a3009f, 0x6b810292, 0x00000000}},  //   لغة_, _önnu, _velg,
  { {0x6b810828, 0x9f3401e1, 0x2b5e0066, 0x00000000}},  //   _welg, _сесі, _egtc_,
  { {0x6c55005e, 0x6b8125f0, 0x3f8325f1, 0x00000000}},  //   _акау, _telg, _keju_,
  { {0x399a014a, 0x29030006, 0x66050066, 0x00000000}},  //   tüsü_, ąja_, _ċika,
  { {0xfdf5013d, 0x00000000, 0x00000000, 0x00000000}},  //   _आवास_,   ,   ,
  { {0x61ef0036, 0x2bd90061, 0x244400f8, 0x00000000}},  //   _nocl, ढाका, döma_,
  { {0xa91d007f, 0x00000000, 0x00000000, 0x00000000}},  //   mažo,   ,   ,
  { {0xd3720076, 0xe7870088, 0x69cb0da6, 0x00000000}},  //   شهر_, _чудо, _hage,
  { {0xa82300a1, 0x644e0056, 0x60c90e54, 0x00000000}},  //   _لکھن, rmbi, _šemp,
  { {0x61ef0f6a, 0xdb0a068f, 0x00000000, 0x00000000}},  //   _cocl, refø,   ,
  { {0x69cb154f, 0xed590091, 0x59a60309, 0x00000000}},  // [65c0] _mage, _kažu_, क्टर,
  { {0x09cd0055, 0x26c70087, 0x00000000, 0x00000000}},  //   িউটা, _ksno_,   ,
  { {0x0d860764, 0xa3df001c, 0x61ef0051, 0x00000000}},  //   влен, णार_, _focl,
  { {0x69cb046a, 0xa91d0142, 0xbf22006e, 0x00000000}},  //   _nage, važn, _मशीन_,
  { {0x6da3137c, 0xdca301e0, 0x38ab00ea, 0x00000000}},  //   рича, иаци, jør_,
  { {0x26c7016c, 0x38ab08e0, 0x69cb0146, 0x00000000}},  //   _osno_, dør_, _aage,
  { {0xdee30072, 0x69cb25f2, 0x39400ebc, 0x00000000}},  //   _кори, _bage, _šis_,
  { {0xa91d25f3, 0xddc90036, 0x69d501f5, 0x00000000}},  //   gažo, _mieś, _मोदी,
  { {0x7e690fda, 0x38ab0030, 0x81cc0044, 0x00000000}},  //   _čepi, gør_, লাপ_,
  { {0xdb181db8, 0xa91d01dc, 0x69cb0133, 0x00000000}},  //   leví, mažl, _eage,
  { {0x69cb0ccc, 0x60c4010f, 0x656d25f4, 0x00000000}},  //   _fage, hwim, _pfah,
  { {0x60c40020, 0xa3cb0309, 0x69cb009d, 0x00000000}},  //   kwim, _रोज_, _gage,
  { {0x2d8400f4, 0x69c0014a, 0x39400051, 0x00000000}},  //   _meme_, meme, _áis_,
  { {0x69c025f5, 0x69cb00bb, 0x2d8425f6, 0x00000000}},  //   leme, _zage, _leme_,
  { {0xe8e0001d, 0x69cb0009, 0xdb1800c4, 0x00000000}},  //   _đội_, _yage, levâ,
  { {0xd9e5013d, 0x69c025f7, 0x656d0020, 0x00000000}},  //   कायत_, neme, _ufah,
  { {0x5184008b, 0x25a910f8, 0x69c00fe4, 0x00000000}},  // [65d0] руса, _ical_, ieme,
  { {0xcbbd0055, 0x69c0032c, 0x7538009b, 0x00000000}},  //   _ইচ্ছ, heme, _באחד_,
  { {0x69c001c9, 0x33f400f8, 0x81b80044, 0x00000000}},  //   keme, _växt_, চয়_,
  { {0x69c00390, 0x78a025f8, 0x6e22009d, 0x00000000}},  //   jeme, kumv, gnob,
  { {0x69c019cd, 0x69cb002b, 0x66ea006b, 0x00000000}},  //   deme, _rage, fəkk,
  { {0x69cb04fb, 0x30da0049, 0x60da0049, 0x00000000}},  //   _sage, _אַלע, _אַלג,
  { {0x69c00299, 0x00000000, 0x00000000, 0x00000000}},  //   feme,   ,   ,
  { {0x69c002ae, 0x683d0129, 0xb05b0039, 0x00000000}},  //   geme, mèdi, _osäk,
  { {0xa91d1a0a, 0xdd030089, 0x683d00f6, 0x00000000}},  //   ražo, ārēj, lèdi,
  { {0x69cb25f9, 0x2d8425fa, 0x38ab08c8, 0x00000000}},  //   _wage, _zeme_, rør_,
  { {0x69cb1390, 0x69c00c75, 0x38ab0030, 0x00000000}},  //   _tage, beme, sør_,
  { {0x69c0049a, 0x8afa0097, 0x78a00045, 0x00000000}},  //   ceme, _אלעז, bumv,
  { {0x81cc08b7, 0xb908023c, 0x20030087, 0x00000000}},  //   লাম_, _لزوم_, _olji_,
  { {0x3a3f006c, 0xb8920025, 0xd91a0104, 0x00000000}},  //   llup_, _الوع, _אונל,
  { {0x3ea1006c, 0x75ff0065, 0x23270088, 0x00000000}},  //   juht_, _gëzo, гори_,
  { {0x60db05c5, 0x25a900e5, 0x00000000, 0x00000000}},  //   _šuma, _gcal_,   ,
  { {0xc0e3047d, 0x6604000b, 0xb146013b, 0x00000000}},  // [65e0] ботк, _ilik, унал,
  { {0x69c014a0, 0x2d84002d, 0xdee6031b, 0x00000000}},  //   zeme, _seme_, лози,
  { {0x660425fb, 0x69c0014a, 0x6e22016c, 0x00000000}},  //   _klik, yeme, tnob,
  { {0x831b007b, 0x0caa0256, 0x69c004bd, 0x00000000}},  //   _טויז, етки_, xeme,
  { {0x645e000b, 0x69c0030a, 0x628e0193, 0x00000000}},  //   _kipi, veme, lsbo,
  { {0x2240005d, 0x2a65122b, 0x3e860025, 0x00000000}},  //   llik_, _bulb_, _مشرف,
  { {0x660404ee, 0x2d8401d9, 0x628e0030, 0x00000000}},  //   _olik, _teme_, nsbo,
  { {0x224025fc, 0x200f0089, 0x645e0652, 0x00000000}},  //   nlik_, īgie_, _lipi,
  { {0x69c001d9, 0x22400007, 0x2df7009b, 0x00000000}},  //   reme, ilik_, _עצמך_,
  { {0x660403ef, 0x78a0141a, 0x628e018d, 0x00000000}},  //   _alik, rumv, ksbo,
  { {0x103700b6, 0x224025fd, 0x66040725, 0x00000000}},  //   רטים_, klik_, _blik,
  { {0x0f57009b, 0x443a014a, 0x628e0239, 0x00000000}},  //   טיים_, _akp_, dsbo,
  { {0x22401c82, 0x629c2032, 0x645e064e, 0x00000000}},  //   dlik_, erro, _bipi,
  { {0x22400ff4, 0x6604002d, 0x36d4007c, 0x00000000}},  //   elik_, _elik, _вокр,
  { {0x224025fe, 0x645e25ff, 0x443a04be, 0x00000000}},  //   flik_, _dipi, _dkp_,
  { {0xdb0a2600, 0x22401f8c, 0x44f50d99, 0x00000000}},  //   lefó, glik_, _впис,
  { {0x3015008b, 0x657d0065, 0x4395004d, 0x00000000}},  // [65f0] адар, mbsh, _капс,
  { {0x645e2601, 0x38660145, 0x48b50049, 0x00000000}},  //   _gipi, _muor_, יִען_,
  { {0x22402602, 0xdb0a010f, 0x764d0145, 0x00000000}},  //   blik_, gefü, _khay,
  { {0x7c3a011c, 0x248d1504, 0x443a00ca, 0x00000000}},  //   _aktr, šemu_, _zkp_,
  { {0xfce500ed, 0x645e0022, 0x764d00e0, 0x00000000}},  //   роло, _yipi, _mhay,
  { {0xb09a00b6, 0x201a0129, 0x683d04bd, 0x00000000}},  //   _בישר, cipi_, pèdi,
  { {0x764d1544, 0x66ea006b, 0x61ed2603, 0x00000000}},  //   _ohay, bəki, ojal,
  { {0xe9d9005c, 0x61ed020c, 0x5c7506e3, 0x00000000}},  //   тки_, njal, _влат,
  { {0xdb03009d, 0x79890016, 0x38660026, 0x00000000}},  //   igné, raew, _cuor_,
  { {0x66042604, 0x2240038c, 0x61ed003c, 0x00000000}},  //   _slik, zlik_, hjal,
  { {0x66040046, 0xd5e602e9, 0x645e0197, 0x00000000}},  //   _plik, ажни, _ripi,
  { {0x645e023a, 0x7bc3006c, 0x2c6b0030, 0x00000000}},  //   _sipi, lenu, _kød_,
  { {0x6e3b000b, 0x61ed0107, 0x60db00ca, 0x00000000}},  //   _mkub, djal, _šumn,
  { {0x7bc3006c, 0x656f0207, 0x46f50088, 0x00000000}},  //   nenu, acch, _вчит,
  { {0x6e3b0061, 0x645e0020, 0xdb0a10cf, 0x00000000}},  //   _okub, _vipi, lefò,
  { {0x66042605, 0x628e0039, 0x224001d6, 0x00000000}},  //   _ulik, rsbo, ulik_,
  { {0x22402606, 0x65642607, 0x628e00f8, 0x00000000}},  // [6600] rlik_, _igih, ssbo,
  { {0x22401462, 0x6aa3010f, 0x15e40061, 0x00000000}},  //   slik_, kunf, गावर_,
  { {0x44380390, 0x201a0059, 0x68fb0093, 0x00000000}},  //   mor_, ripi_, hyud,
  { {0x44381e47, 0x61ed2608, 0x320901aa, 0x00000000}},  //   lor_, cjal, chay_,
  { {0x0cd4053f, 0xdb0a01a2, 0x7bc300e5, 0x00000000}},  //   солю, sefü, fenu,
  { {0x7bc3006c, 0x44380aa4, 0x2c6b068f, 0x00000000}},  //   genu, nor_, _død_,
  { {0x6b8a00b5, 0x443800f6, 0x6d49002d, 0x00000000}},  //   rafg, ior_, _ezea,
  { {0xada301e0, 0x44380127, 0x6000000c, 0x00000000}},  //   _масл, hor_, _mömm,
  { {0x44381bc0, 0xed570057, 0x7e600058, 0x00000000}},  //   kor_, _вот_, _iimp,
  { {0x61ed1a79, 0x44381468, 0x764d00e7, 0x00000000}},  //   zjal, jor_, _shay,
  { {0x443800d6, 0x4fd90049, 0x7c381a2d, 0x00000000}},  //   dor_, אַרד, movr,
  { {0x7e60002b, 0xa5bb00fa, 0x7af700f8, 0x00000000}},  //   _jimp, cnól, äxte,
  { {0x44380056, 0x20180173, 0x7e6004cb, 0x00000000}},  //   for_, _omri_, _mimp,
  { {0x44380ffd, 0x7e600325, 0x7c380207, 0x00000000}},  //   gor_, _limp, novr,
  { {0xd83801d9, 0xe6940025, 0x764d2609, 0x00000000}},  //   moč_, _البد, _thay,
  { {0x7e60097e, 0x20180020, 0x6b880133, 0x00000000}},  //   _nimp, _amri_, _ledg,
  { {0xc9530049, 0x20180022, 0x2f8b003b, 0x00000000}},  // [6610] ַמע_, _bmri_, вљен_,
  { {0x661d260a, 0x6e3b0006, 0x61ed115f, 0x00000000}},  //   lisk, _skub, sjal,
  { {0xe8e0001d, 0x7c380030, 0x6d4000ea, 0x00000000}},  //   _đời_, dovr, _ayma,
  { {0x661d260b, 0x2018260c, 0x7e60260d, 0x00000000}},  //   nisk, _emri_, _cimp,
  { {0xbc19008b, 0x7e600035, 0x3d11006e, 0x00000000}},  //   лікі_, _dimp, _देखे_,
  { {0x7c380e00, 0x00f60104, 0xd8380059, 0x00000000}},  //   govr, _המשך_, joč_,
  { {0xa91d0006, 0x7bc3260e, 0x661d0981, 0x00000000}},  //   maži, renu, kisk,
  { {0x44380428, 0x290d022b, 0xa91d00d0, 0x00000000}},  //   zor_, tzea_, laži,
  { {0x661d09a9, 0x4438260f, 0x7bc3003f, 0x00000000}},  //   disk, yor_, penu,
  { {0x44380039, 0x30da0049, 0xa91d129d, 0x00000000}},  //   xor_, אַטע, naži,
  { {0x661d0056, 0x98b80089, 0x00000000, 0x00000000}},  //   fisk, ārā_,   ,
  { {0x661d04d3, 0xdb010051, 0x2cbf0093, 0x00000000}},  //   gisk, _gclá, _kpud_,
  { {0x5a0c0049, 0xe9450014, 0xdb180190, 0x00000000}},  //   _בלאַ, _ارای, gevæ,
  { {0xdd99000a, 0xec350049, 0x00000000, 0x00000000}},  //   _blňk_, מאָר_,   ,
  { {0x81cc0044, 0x09cb0061, 0x91e600d7, 0x00000000}},  //   লাস_, _ासाठ, бове,
  { {0x44380ce3, 0x63bb0091, 0x661d1031, 0x00000000}},  //   sor_, đuna, cisk,
  { {0x443808a9, 0x7e600197, 0x03a600c0, 0x00000000}},  // [6620] por_, _rimp, _липо,
  { {0x7e690059, 0xa91d016e, 0x600000f8, 0x00000000}},  //   _čepr, gaži, _tömm,
  { {0x7e60008a, 0x8d1a007a, 0x05dd0061, 0x00000000}},  //   _pimp, گزار_, याचब,
  { {0x81cc0044, 0x6da602dc, 0xa5bb060d, 0x00000000}},  //   লাহ_, сида, ciód,
  { {0x7c380091, 0x8c461f25, 0xc173009b, 0x00000000}},  //   tovr, беде, _מחר_,
  { {0x2018000b, 0xdee6007c, 0x661d2610, 0x00000000}},  //   _umri_, _логи, zisk,
  { {0x7e601cf1, 0x6d400046, 0x7c380190, 0x00000000}},  //   _timp, _wyma, rovr,
  { {0x98740920, 0x3f8a0020, 0x187401e0, 0x00000000}},  //   олиц, _hebu_, огия,
  { {0x661d1962, 0xd838016e, 0x050a0044, 0x00000000}},  //   visk, toč_, রপুর_,
  { {0x661d0046, 0x7cde001a, 0xdb180190, 0x00000000}},  //   wisk, _cărţ, vevæ,
  { {0x290201d9, 0x661d001e, 0x442701f6, 0x00000000}},  //   ška_, tisk, _ın_,
  { {0x6f0900b9, 0xd8380059, 0x3f8a2611, 0x00000000}},  //   _řeck, soč_, _lebu_,
  { {0x2ca6011c, 0x3f9800ca, 0x05aa0164, 0x00000000}},  //   nuod_, _odru_, _कारब,
  { {0x661d010a, 0x25ad2612, 0x3f8a0166, 0x00000000}},  //   sisk, żel_, _nebu_,
  { {0xdb1a001f, 0xa91d0006, 0x00000000, 0x00000000}},  //   _natü, važi,   ,
  { {0xdb1a0010, 0x7a3e0065, 0x00000000, 0x00000000}},  //   _ható, pëtu,   ,
  { {0xa5bb0211, 0xdb180bac, 0x609902fd, 0x00000000}},  // [6630] riód, levä, شناس_,
  { {0x3f6700ed, 0x2007000c, 0x3f8a0a6b, 0x00000000}},  //   стаб, óni_, _cebu_,
  { {0x2cbf01c3, 0x10480131, 0xdb1800b0, 0x00000000}},  //   _spud_, сяти_, nevä,
  { {0xdd94008b, 0x8d87007c, 0xa91d0089, 0x00000000}},  //   зацы, сужд, saži,
  { {0xa91d010a, 0x75ff0065, 0x3eb30009, 0x00000000}},  //   paži, _vëzh, stxt_,
  { {0x3eb30061, 0xdb1800b0, 0x3f8a0145, 0x00000000}},  //   ptxt_, kevä, _gebu_,
  { {0x81cc0055, 0x93fc0049, 0xfbd00380, 0x00000000}},  //   লার_, רלוי, عته_,
  { {0x60dd0521, 0x00000000, 0x00000000, 0x00000000}},  //   _krsm,   ,   ,
  { {0x2d8f0498, 0x26dc0103, 0x75ff0065, 0x00000000}},  //   mage_, _arvo_, _gëzi,
  { {0x2d8f2613, 0x2ca0002a, 0x115c007b, 0x00000000}},  //   lage_, áide_, נדזע,
  { {0x65c60147, 0x00000000, 0x00000000, 0x00000000}},  //   обна,   ,   ,
  { {0x361601fb, 0xd5aa0061, 0x2d8f0549, 0x00000000}},  //   ієнт, _काळज, nage_,
  { {0x893705f3, 0x1959008b, 0x67d50069, 0x00000000}},  //   _اعضا, _тады_, _моду,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d8f0030, 0xe36301fb, 0x3f8a134e, 0x00000000}},  //   kage_, дкри, _rebu_,
  { {0x21670931, 0x91e30081, 0xdb1a01aa, 0x00000000}},  //   жити_, мосе, _katò,
  { {0x2d8f0ba6, 0x81cc0044, 0x614300e2, 0x00000000}},  // [6640] dage_, লাল_, дета,
  { {0xdfa60025, 0x66ea006b, 0xbfc3004d, 0x00000000}},  //   تحري, cəks, мбук,
  { {0x2d8f00f4, 0x25df0061, 0x3f8a012d, 0x00000000}},  //   fage_, गाची_, _vebu_,
  { {0xee3a0269, 0x3f8a01c8, 0x2d8f0549, 0x00000000}},  //   шне_, _webu_, gage_,
  { {0x61e62614, 0x3f8a04be, 0xdb1801e5, 0x00000000}},  //   _inkl, _tebu_, ndvö,
  { {0xa91d1288, 0x7d06010e, 0x00000000, 0x00000000}},  //   nažu, _üksm,   ,
  { {0x3d1a03d7, 0xe8e0001d, 0xdb1a008e, 0x00000000}},  //   _मेरे_, _đối_, _rató,
  { {0x2d8f009d, 0x0d8602dc, 0x7e7e0058, 0x00000000}},  //   cage_, _флан, mppp,
  { {0x1d07007c, 0xc7c6005e, 0xdb1a07f0, 0x00000000}},  //   _дети_, осни, _catò,
  { {0x26dc1000, 0xdb181b97, 0x00000000, 0x00000000}},  //   _prvo_, tevä,   ,
  { {0xdb1a2615, 0x45d500ed, 0x61e61810, 0x00000000}},  //   _obté, понс, _onkl,
  { {0x1b130044, 0xa5bb2616, 0xdb182617, 0x00000000}},  //   _ঢুকে_, dióc, revä,
  { {0xdb181a17, 0x00000000, 0x00000000, 0x00000000}},  //   sevä,   ,   ,
  { {0x61e60240, 0x998d0036, 0xa91d144f, 0x00000000}},  //   _ankl, kieś_, gažu,
  { {0x2d8f028c, 0xf4850167, 0x72d40081, 0x00000000}},  //   yage_, _کابی, морф,
  { {0x200a0a86, 0xceeb0063, 0x96180025, 0x00000000}},  //   _albi_, یران_, _وغير_,
  { {0x200a0690, 0x2d8f032c, 0x3d1a006e, 0x00000000}},  // [6650] _blbi_, vage_, _मेले_,
  { {0x61e6093b, 0x2d8f0133, 0x00000000, 0x00000000}},  //   _enkl, wage_,   ,
  { {0x64470295, 0x9f510197, 0x00000000, 0x00000000}},  //   mlji, _alzò_,   ,
  { {0x248900b5, 0x7c2a00d9, 0x00000000, 0x00000000}},  //   _kwam_, enfr,   ,
  { {0x2d8f030a, 0x7c2a000c, 0x4c84007e, 0x00000000}},  //   rage_, fnfr, длів,
  { {0x798b120b, 0x2d8f00f4, 0x60cd0d16, 0x00000000}},  //   _segw, sage_, mwam,
  { {0x27e90011, 0x62950f88, 0x2c5d000a, 0x00000000}},  //   _đan_, nszo, _jňdi_,
  { {0x64470e54, 0x600001a2, 0x629500bb, 0x00000000}},  //   hlji, _römi, iszo,
  { {0x64470059, 0x60cd002b, 0x2d8d00ab, 0x00000000}},  //   klji, nwam, _ieee_,
  { {0x798b0cac, 0x62950c59, 0xb17b00f8, 0x00000000}},  //   _wegw, kszo, _snål,
  { {0xb8f203d7, 0xe7390113, 0x64470295, 0x00000000}},  //   _है_, сен_, dlji,
  { {0x60cd2618, 0x62952619, 0x2d8d0145, 0x00000000}},  //   kwam, dszo, _jeee_,
  { {0xa879007b, 0x5fac0061, 0x998d0036, 0x00000000}},  //   _פאַר, _चालल, zieś_,
  { {0x387f027e, 0x64470e0f, 0x987a0097, 0x00000000}},  //   mpur_, glji, _האסט,
  { {0x91e6017f, 0x387f000c, 0x824a01b7, 0x00000000}},  //   пове, lpur_, مشرف_,
  { {0x249f0089, 0xdb120010, 0x2489000a, 0x00000000}},  //   šuma_, égér, _fwam_,
  { {0x78a90211, 0xdb0a0181, 0x64470825, 0x00000000}},  // [6660] nuev, lefô, blji,
  { {0x81cc0055, 0x13a806c6, 0xa3d4006e, 0x00000000}},  //   লাই_, _بندی_, _सोच_,
  { {0x69c9261a, 0x387f01f3, 0x0eb9007e, 0x00000000}},  //   keee, hpur_, жучы_,
  { {0x7d06006c, 0xed5a0a78, 0x69c909fc, 0x00000000}},  //   _üksk, бое_, jeee,
  { {0xdd8f023c, 0x75ff0023, 0x1bd402dc, 0x00000000}},  //   اوه_, _gëzu, доля,
  { {0x6e2b0061, 0x69c9016e, 0x7e7e0011, 0x00000000}},  //   angb, eeee, pppp,
  { {0x6606101d, 0x7c2a0332, 0x224200c4, 0x00000000}},  //   kkkk, rnfr, _kkkk_,
  { {0x6447092f, 0x7e9b009b, 0x22420145, 0x00000000}},  //   zlji, _לסלו, _jkkk_,
  { {0x3ebf0521, 0xdca30072, 0xe8e00011, 0x00000000}},  //   _ćuti_, _пати, _đồi_,
  { {0x77920123, 0x6e220020, 0xed5f0006, 0x00000000}},  //   ریبا, liob, įžta_,
  { {0xbb4a0380, 0x64470f3a, 0x7bca0020, 0x00000000}},  //   _الان_, vlji, mefu,
  { {0x6a1605f3, 0x6aaa16df, 0x6e22008e, 0x00000000}},  //   _عبار, muff, niob,
  { {0x64470295, 0x7d020010, 0x63a10036, 0x00000000}},  //   tlji, nyos, ólno,
  { {0x7bca0146, 0x62950010, 0x625300fa, 0x00000000}},  //   nefu, tszo, içoe,
  { {0x9f580065, 0x64470295, 0xb35401fc, 0x00000000}},  //   _dorë_, rlji, екрш,
  { {0x64470e0f, 0xe1f300a1, 0xe0df0026, 0x00000000}},  //   slji, رسز_, _prò_,
  { {0x62950010, 0x64470295, 0x7bca00ea, 0x00000000}},  // [6670] sszo, plji, kefu,
  { {0x660d000c, 0x60cd261b, 0x6aaa06ec, 0x00000000}},  //   _hlak, rwam, kuff,
  { {0x660d01e5, 0xd34100a1, 0x4423261c, 0x00000000}},  //   _klak, _شہری, mij_,
  { {0xe0df001d, 0x442301d9, 0xb8120044, 0x00000000}},  //   _trò_, lij_, িচিত_,
  { {0x9c59261d, 0x660d016e, 0x23700023, 0x00000000}},  //   ошку_, _mlak, _çojë_,
  { {0xce6b0200, 0x44230aa9, 0x7bca0302, 0x00000000}},  //   _град_, nij_, gefu,
  { {0x3946011c, 0x660d0091, 0x6e220026, 0x00000000}},  //   _ayos_, _olak, biob,
  { {0x22492119, 0x6e2200fd, 0x2ca0012d, 0x00000000}},  //   nlak_, ciob, šida_,
  { {0x442300ea, 0x7bca0302, 0xdcfb0014, 0x00000000}},  //   kij_, befu, _ارزش_,
  { {0x660d261e, 0x387f01e5, 0x442300bb, 0x00000000}},  //   _alak, rpur_, jij_,
  { {0x660d0089, 0x44230627, 0xe5a60069, 0x00000000}},  //   _blak, dij_, мини,
  { {0x387f261f, 0x660d0022, 0x7c230052, 0x00000000}},  //   ppur_, _clak, linr,
  { {0x660d10f7, 0x44232620, 0x21010006, 0x00000000}},  //   _dlak, fij_, nčią_,
  { {0xb05b0039, 0x660d01a3, 0x4423050f, 0x00000000}},  //   _spän, _elak, gij_,
  { {0x660d2621, 0x7bc1002b, 0x2c7b00e5, 0x00000000}},  //   _flak, _mblu, _hâdă_,
  { {0x3cee001c, 0x3a2d177d, 0xa5bb0f6c, 0x00000000}},  //   _आपले_, nnep_, lión,
  { {0x442300b5, 0x7e7c0091, 0x2bae0061, 0x00000000}},  // [6680] bij_, _strp, _घाला,
  { {0xa5bb027b, 0x442301d9, 0x7d020020, 0x00000000}},  //   nión, cij_, vyos,
  { {0x44440662, 0x7bca000c, 0x216a0069, 0x00000000}},  //   _ik_, vefu, _мини_,
  { {0xe9d90046, 0x645c00ea, 0x00000000, 0x00000000}},  //   jdź_, lmri,   ,
  { {0x09bc0055, 0x444400b0, 0x6e22035e, 0x00000000}},  //   _অফলা, _kk_, riob,
  { {0x44440020, 0x6aaa0541, 0x7d022622, 0x00000000}},  //   _jk_, tuff, ryos,
  { {0x44440089, 0xa0670c27, 0x7bca24ca, 0x00000000}},  //   _mk_, _цара_, refu,
  { {0x44441287, 0x44232623, 0x6aaa2624, 0x00000000}},  //   _lk_, zij_, ruff,
  { {0xeb9a01f9, 0x6aaa1e5a, 0x2d861fac, 0x00000000}},  //   _миа_, suff, mboe_,
  { {0x44440127, 0x660d06a1, 0x31570049, 0x00000000}},  //   _nk_, _slak, ויפן_,
  { {0xe8e0001d, 0x660d0091, 0x442300ca, 0x00000000}},  //   _đổi_, _plak, vij_,
  { {0x44442625, 0x2fd82626, 0x3a3f2627, 0x00000000}},  //   _ak_, _larg_, coup_,
  { {0x44232628, 0x224901d6, 0x9f58009d, 0x00000000}},  //   tij_, vlak_, _doré_,
  { {0xa5bb081d, 0x3fd90055, 0x68e20047, 0x00000000}},  //   ción, _দক্ষ, _irod,
  { {0x444405ec, 0x44232629, 0x660d0161, 0x00000000}},  //   _dk_, rij_, _tlak,
  { {0x44441273, 0x442300ca, 0x35f80025, 0x00000000}},  //   _ek_, sij_, _يريد_,
  { {0x656d262a, 0x2249014a, 0xe7f50061, 0x00000000}},  // [6690] _igah, rlak_, ेसचा_,
  { {0x4444262b, 0x2fd80146, 0x00000000, 0x00000000}},  //   _gk_, _carg_,   ,
  { {0x7c2d0051, 0xa195003b, 0x2249014a, 0x00000000}},  //   éarm, _панч, plak_,
  { {0x68e2262c, 0x1cb90054, 0xa01b092e, 0x00000000}},  //   _orod, كاتب_, _stöd,
  { {0xdb0901c8, 0x44210145, 0x30790049, 0x00000000}},  //   čníc, _kmh_, _מאָנ,
  { {0xe9d90036, 0x4444262d, 0x2fd80fd1, 0x00000000}},  //   wdź_, _xk_, _garg_,
  { {0xbb421e6a, 0x68e20089, 0x6012000c, 0x00000000}},  //   лешк, _arod, _dæmd,
  { {0xe7d70183, 0x68e20209, 0x2ca6262e, 0x00000000}},  //   _भोजप, _brod, brod_,
  { {0x3a3f1e55, 0x00000000, 0x00000000, 0x00000000}},  //   roup_,   ,   ,
  { {0x61fd0506, 0x656d262f, 0x68e20036, 0x00000000}},  //   _losl, _agah, _drod,
  { {0xf62601f9, 0x3f91002d, 0x99910010, 0x00000000}},  //   едно, _mezu_, őző_,
  { {0x444413a1, 0x64450149, 0xa5bb049a, 0x00000000}},  //   _sk_, _akhi, sión,
  { {0x68e22539, 0x7e6900d9, 0x00000000, 0x00000000}},  //   _grod, _miep,   ,
  { {0x7e690a5c, 0x69d92630, 0x4444002b, 0x00000000}},  //   _liep, _hawe, _qk_,
  { {0xed45026c, 0x425600e3, 0xa5bb029d, 0x00000000}},  //   _چھ_, етат, gnós,
  { {0x7e690046, 0x444400b5, 0x69db2631, 0x00000000}},  //   _niep, _wk_, ndue,
  { {0x78bb2632, 0x44442633, 0x61fd0091, 0x00000000}},  // [66a0] ntuv, _tk_, _dosl,
  { {0x44441e55, 0x69d90016, 0x2480011c, 0x00000000}},  //   _uk_, _lawe, _itim_,
  { {0x78bb003c, 0x93b7009b, 0x2fd80f3f, 0x00000000}},  //   htuv, _אליו_, _varg_,
  { {0x69d92634, 0xa06a012b, 0x7e690036, 0x00000000}},  //   _nawe, _нама_, _ciep,
  { {0x7e6900c7, 0x1016007e, 0x2d862635, 0x00000000}},  //   _diep, _зьвя, rboe_,
  { {0x6281004a, 0x2ca60322, 0x2ca0012d, 0x00000000}},  //   ílog, rrod_, šido_,
  { {0x68e2106c, 0xaa66005c, 0x248000f6, 0x00000000}},  //   _srod, нтик, _ltim_,
  { {0x2ca60056, 0x6000006b, 0x48aa24a0, 0x00000000}},  //   prod_, _gömr, птом_,
  { {0x69d90016, 0x3f910009, 0x625300c4, 0x00000000}},  //   _dawe, _yezu_, nçoa,
  { {0x4c9b00b6, 0x25a004cb, 0x625300c4, 0x00000000}},  //   _משמע, _adil_, içoa,
  { {0x69db00d4, 0x69bd0061, 0xddc70059, 0x00000000}},  //   bdue, व्ही, _hujš,
  { {0x7bda000b, 0x68e205fe, 0x69d90007, 0x00000000}},  //   _hatu, _trod, _gawe,
  { {0x7bda006a, 0x68e20046, 0x61fd01a3, 0x00000000}},  //   _katu, _urod, _rosl,
  { {0x7c21041d, 0x7bda04cb, 0x69c0037f, 0x00000000}},  //   _xmlr, _jatu, lfme,
  { {0x7bda0503, 0x69d92636, 0x00000000, 0x00000000}},  //   _matu, _yawe,   ,
  { {0x7bda1759, 0x80ca0044, 0x656d0045, 0x00000000}},  //   _latu, রিন্, _ugah,
  { {0x7e690089, 0x1fa70088, 0x25d80049, 0x00000000}},  // [66b0] _riep, ерег, _טוהן_,
  { {0x320901aa, 0xa01b010f, 0x7e6920b0, 0x00000000}},  //   skay_, _stöb, _siep,
  { {0x7e69001e, 0x4fc4007e, 0x3f910091, 0x00000000}},  //   _piep, ыста, _vezu_,
  { {0x78bb0006, 0x7bda0058, 0x09c50044, 0x00000000}},  //   ytuv, _aatu, _শোনা,
  { {0x7bda0c35, 0x3f910107, 0xddc0001a, 0x00000000}},  //   _batu, _tezu_, _simţ,
  { {0x99dd00b9, 0x7bda008a, 0xfaa5132e, 0x00000000}},  //   plňk, _catu, вако,
  { {0xf771089d, 0x69d90036, 0x44310c30, 0x00000000}},  //   یاد_, _pawe, inz_,
  { {0x78bb00b0, 0x9f580197, 0x00000000, 0x00000000}},  //   ttuv, _morì_,   ,
  { {0x69db022b, 0x7bda0bf7, 0x290b0027, 0x00000000}},  //   rdue, _fatu, áca_,
  { {0x69d90e15, 0x78bb0d90, 0x7bda0b23, 0x00000000}},  //   _wawe, rtuv, _gatu,
  { {0x78bb06aa, 0x2480001a, 0x69d91496, 0x00000000}},  //   stuv, _stim_, _tawe,
  { {0x44312637, 0x7bda04eb, 0xc3250044, 0x00000000}},  //   enz_, _zatu, _মুভি_,
  { {0x7bda14a5, 0x59da007d, 0x7d06006c, 0x00000000}},  //   _yatu, _मोटर, _ükst,
  { {0x33d501e1, 0x2bc40061, 0xbf210061, 0x00000000}},  //   ліст, ल्पा, _मधून_,
  { {0x78a9121b, 0x41b602dc, 0xd4671649, 0x00000000}},  //   lrev, ксат, тире_,
  { {0x20110026, 0x7989147c, 0xd1322638, 0x00000000}},  //   _alzi_, nbew, لمز_,
  { {0xf9920476, 0x41270200, 0x78a900ea, 0x00000000}},  // [66c0] ירן_, вото_, nrev,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bda04d4, 0x78a900b5, 0x798900d9, 0x00000000}},  //   _ratu, hrev, kbew,
  { {0x7bda001e, 0x78a90056, 0xf53f0c88, 0x00000000}},  //   _satu, krev, mgår_,
  { {0x7bda17ca, 0x798900bb, 0x77f10164, 0x00000000}},  //   _patu, dbew, _अचूक_,
  { {0x6253153c, 0x78a900bb, 0x798900d9, 0x00000000}},  //   nçon, drev, ebew,
  { {0x3cee03d7, 0x629c00f8, 0x63a10036, 0x00000000}},  //   _आपके_, nsro, ólni,
  { {0x7bda000b, 0xc333007b, 0x58d801e0, 0x00000000}},  //   _watu, יוו_, едия_,
  { {0x78a90925, 0xbc660b81, 0x00000000, 0x00000000}},  //   grev, _авак,   ,
  { {0xad1b009b, 0xa5bb0010, 0x3f85010e, 0x00000000}},  //   _חומר, ciój, _õlut_,
  { {0xa3c8007d, 0x559500e2, 0x00000000, 0x00000000}},  //   ोजन_, ланѓ,   ,
  { {0x78a90030, 0xf53f0030, 0x2ca9016c, 0x00000000}},  //   brev, dgår_, šade_,
  { {0x78a902d5, 0x00000000, 0x00000000, 0x00000000}},  //   crev,   ,   ,
  { {0x3cf50061, 0xa3a4012b, 0xecc40044, 0x00000000}},  //   ्हते_, ијск, _এছাড,
  { {0x2bc40183, 0x07a3025f, 0x442d0091, 0x00000000}},  //   ल्या, _тајн, đe_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6b9800f8, 0x00000000, 0x00000000, 0x00000000}},  // [66d0] kavg,   ,   ,
  { {0x44271038, 0xa3d500ed, 0x629c01c3, 0x00000000}},  //   _ön_, _сооч, bsro,
  { {0x62670b03, 0x78a92639, 0xaca30082, 0x00000000}},  //   _لاحق, zrev, _trừn,
  { {0x6287002b, 0x78a90ede, 0x00000000, 0x00000000}},  //   mpjo, yrev,   ,
  { {0x61ef0b25, 0xfd100076, 0xada4007e, 0x00000000}},  //   _incl, يجه_, раіл,
  { {0x1c440451, 0xf09f00f6, 0x78a90146, 0x00000000}},  //   анім, _ivà_, vrev,
  { {0xe4580049, 0x63b50089, 0x6e94263a, 0x00000000}},  //   דיגט_, igzn, _вису,
  { {0x78a906c0, 0x7f5801ab, 0x00000000, 0x00000000}},  //   trev, _расс_,   ,
  { {0x79890597, 0x00000000, 0x00000000, 0x00000000}},  //   rbew,   ,   ,
  { {0x78a91c28, 0x7d04021e, 0x7989263b, 0x00000000}},  //   rrev, äise, sbew,
  { {0x61ef001c, 0x78a90190, 0x63b80039, 0x00000000}},  //   _oncl, srev, _övni,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe8ee0256, 0x98a5026b, 0xb05b00b0, 0x00000000}},  //   _ул_, _силе, _epäi,
  { {0x61ef008e, 0x629c1dcd, 0xe61202fd, 0x00000000}},  //   _ancl, tsro, _گشت_,
  { {0xdceb01d5, 0x6253263c, 0xe9ff0011, 0x00000000}},  //   bagħ, rçon, _ngẫm_,
  { {0xb5fb1db8, 0xf53f032e, 0xe61202fd, 0x00000000}},  //   rmác, rgår_, _دشت_,
  { {0x76460006, 0x6253009d, 0x629c00ab, 0x00000000}},  // [66e0] moky, pçon, ssro,
  { {0x61ef032c, 0xe0d707d0, 0xb686009e, 0x00000000}},  //   _encl, ыву_, _جھیل_,
  { {0x0d86005e, 0x442a010e, 0x03d70049, 0x00000000}},  //   глен, mib_, _גוים_,
  { {0x442a0163, 0xf2d300a3, 0x3ea7263d, 0x00000000}},  //   lib_, _פער_, ánta_,
  { {0x7bc3010f, 0x4095003b, 0xb6a30082, 0x00000000}},  //   ffnu, _врст, _suấ,
  { {0x442a1544, 0xd0120025, 0x00000000, 0x00000000}},  //   nib_, _الس_,   ,
  { {0x47dc0044, 0x00000000, 0x00000000, 0x00000000}},  //   বামী,   ,   ,
  { {0x442a263e, 0xaa54012b, 0x249f0089, 0x00000000}},  //   hib_, јвиш, šumi_,
  { {0x442a263f, 0x7e6200f2, 0xdb0800fa, 0x00000000}},  //   kib_, mmop, _abdô,
  { {0x442a04cb, 0x7e622640, 0x3f9a2641, 0x00000000}},  //   jib_, lmop, napu_,
  { {0x6fc6001c, 0x442a006b, 0x7c2a00f8, 0x00000000}},  //   र्यं, dib_, mifr,
  { {0x2456000c, 0x00000000, 0x00000000, 0x00000000}},  //   væma_,   ,   ,
  { {0x3f9a016a, 0xe8940b5f, 0x27f81fbc, 0x00000000}},  //   kapu_, _таль, örns_,
  { {0x7c2a00ea, 0x00000000, 0x00000000, 0x00000000}},  //   nifr,   ,   ,
  { {0x1797019b, 0xd25b0726, 0xa29505b8, 0x00000000}},  //   _גדול_, еца_, рабі,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x442a01d5, 0xaca30011, 0x746b0264, 0x00000000}},  // [66f0] bib_, _trứn, _пров_,
  { {0x442a006b, 0x2c7901aa, 0x7ae800ea, 0x00000000}},  //   cib_, _rèd_, _ordt,
  { {0x09ac0044, 0x7c2a2123, 0x2c790173, 0x00000000}},  //   ক্যা, difr, _sèd_,
  { {0x64472642, 0x7bc80127, 0x61ef00ab, 0x00000000}},  //   loji, _abdu, _uncl,
  { {0x56380049, 0x7ae80051, 0x9f5800fa, 0x00000000}},  //   נאדע_, _ardt, _porã_,
  { {0xab2901bd, 0x64470dec, 0xc31c0044, 0x00000000}},  //   кола_, noji, _দুটি_,
  { {0x3d950920, 0x2003163a, 0x00000000, 0x00000000}},  //   _вибр, _ioji_,   ,
  { {0x64470020, 0x442a2643, 0x6d57006b, 0x00000000}},  //   hoji, zib_, əxan,
  { {0x20030119, 0x442a2644, 0x64470dc6, 0x00000000}},  //   _koji_, yib_, koji,
  { {0x3ae3014a, 0x62852645, 0x442a013f, 0x00000000}},  //   _tıp_, _otho, xib_,
  { {0xe7390200, 0x99f5008b, 0x64472646, 0x00000000}},  //   тен_, _вялі, doji,
  { {0x25e60309, 0x22a10006, 0x20030145, 0x00000000}},  //   _जोशी_, dėk_, _loji_,
  { {0x62852647, 0x76460058, 0x442a200f, 0x00000000}},  //   _atho, roky, tib_,
  { {0x64470042, 0xa01b1fbc, 0xa6c900e2, 0x00000000}},  //   goji, _stön, _алка_,
  { {0x442a2648, 0x6e2b00e0, 0x00000000, 0x00000000}},  //   rib_, kigb,   ,
  { {0xcb120049, 0x799b00bb, 0xb5fb0010, 0x00000000}},  //   קלן_, nauw, lmán,
  { {0x6285018e, 0x64470006, 0x2003016e, 0x00000000}},  // [6700] _etho, boji, _boji_,
  { {0x8fa60057, 0x60d60016, 0x442a006b, 0x00000000}},  //   раже, rwym, qib_,
  { {0x23fb0104, 0x200300ee, 0x81cb0044, 0x00000000}},  //   _ספטמ, _doji_, লয়_,
  { {0x3f9a0329, 0x9f5800f6, 0x7c2a0544, 0x00000000}},  //   sapu_, _vorà_, wifr,
  { {0x2ca0002a, 0x66041256, 0x3ddf00d9, 0x00000000}},  //   éid_, _moik, _dauw_,
  { {0x20030145, 0xfaa6003b, 0x660400b0, 0x00000000}},  //   _goji_, ашин, _loik,
  { {0x7c2a0039, 0x6e2b0146, 0x443a00f6, 0x00000000}},  //   rifr, bigb, _mjp_,
  { {0x3f980093, 0xce340123, 0x7c2a012d, 0x00000000}},  //   _heru_, _اورک, sifr,
  { {0x9a670025, 0x64470020, 0xc7b8016c, 0x00000000}},  //   جميل_, yoji, ziđu_,
  { {0x9cd7009b, 0xf80602e9, 0x3f9801c3, 0x00000000}},  //   _דומה_, рчин, _jeru_,
  { {0x64470091, 0x12b10055, 0x3f9801ee, 0x00000000}},  //   voji, _চন্দ, _meru_,
  { {0x47dc0055, 0xa01b014a, 0xea62009e, 0x00000000}},  //   বাধী, _atöl, _بھتی,
  { {0x64470089, 0xd628007e, 0x66040288, 0x00000000}},  //   toji, роўе_, _doik,
  { {0x443a00d9, 0x224b0022, 0x00000000, 0x00000000}},  //   _cjp_, _skck_,   ,
  { {0x64472649, 0x443a0093, 0x661601c9, 0x00000000}},  //   roji, _djp_, _flyk,
  { {0x52140069, 0x6604002d, 0x64470059, 0x00000000}},  //   одст, _goik, soji,
  { {0x644701ca, 0xcf9b00ed, 0x3f981282, 0x00000000}},  // [6710] poji, вје_, _beru_,
  { {0x3ea7008e, 0xd3a70216, 0x96da006e, 0x00000000}},  //   ánto_, _трип, _बनाउ,
  { {0x2003016c, 0x628500ea, 0x3ddf00d9, 0x00000000}},  //   _voji_, _utho, _pauw_,
  { {0x7d0b0039, 0x09ac0044, 0x249f0089, 0x00000000}},  //   tygs, ক্তা, šumu_,
  { {0x2249002d, 0xfce5030d, 0x00000000, 0x00000000}},  //   moak_, соло,   ,
  { {0x60dd0009, 0x2249002d, 0x6e2b01d6, 0x00000000}},  //   _issm, loak_, sigb,
  { {0x764d264a, 0x9f58004a, 0x3e7701f3, 0x00000000}},  //   _okay, _torá_, _oħti_,
  { {0xe9d90373, 0x2249002d, 0x3f980032, 0x00000000}},  //   уки_, noak_, _zeru_,
  { {0x2bc40183, 0x9d15007c, 0x6e3b016c, 0x00000000}},  //   ल्हा, _удач, _ijub,
  { {0x764d0f65, 0x3f8100d4, 0x9610013d, 0x00000000}},  //   _akay, nchu_, ास्ट_,
  { {0x22490756, 0xb5fb0047, 0x6604021e, 0x00000000}},  //   koak_, rmán, _poik,
  { {0x645e008d, 0xf409061e, 0x2d9d264b, 0x00000000}},  //   _shpi, _אפ_, nawe_,
  { {0xb5fb000c, 0x7c280016, 0x2249002d, 0x00000000}},  //   mmál, _ymdr, doak_,
  { {0x6e3b0f3a, 0x6383005e, 0x2d9d0009, 0x00000000}},  //   _ljub, згра, hawe_,
  { {0x2d9d0036, 0x22490032, 0x00000000, 0x00000000}},  //   kawe_, foak_,   ,
  { {0x3f981c2b, 0x2249002d, 0x6616068f, 0x00000000}},  //   _seru_, goak_, _ulyk,
  { {0x515610a9, 0x3f980211, 0x287a0049, 0x00000000}},  // [6720] ству, _peru_, ָנעמ,
  { {0x3a2d0011, 0x6e2900e7, 0x799901c3, 0x00000000}},  //   hiep_, _ameb, _leww,
  { {0x3f98264c, 0xe9ff0011, 0x2249002d, 0x00000000}},  //   _veru_, _ngắm_, boak_,
  { {0xb05b0598, 0x79990807, 0x44380a5e, 0x00000000}},  //   _spät, _neww, lnr_,
  { {0x6e3b0521, 0xdd990027, 0xd47a0049, 0x00000000}},  //   _djub, _deň_, נאַל,
  { {0x69cb001f, 0x60c40065, 0x61e4264d, 0x00000000}},  //   _abge, mtim, ldil,
  { {0x78a2068f, 0xb05b00b0, 0x9ce800a1, 0x00000000}},  //   _svov, _epäs, _ھوئے_,
  { {0x61e408a7, 0xa5bb00f6, 0xb5fb000c, 0x00000000}},  //   ndil, niót, gmál,
  { {0xd90e01ef, 0x9f58014a, 0x26dc01c3, 0x00000000}},  //   عیت_, _borç_, _ssvo_,
  { {0x473401f9, 0x765f0065, 0x2249002d, 0x00000000}},  //   жнос, _shqy, zoak_,
  { {0x661d008d, 0x60c401c2, 0x443800e5, 0x00000000}},  //   ërko, htim, dnr_,
  { {0x60c4008d, 0x0f5700b6, 0x2249002d, 0x00000000}},  //   ktim, מיים_, xoak_,
  { {0x60c4008d, 0x61e40016, 0x3a5600a1, 0x00000000}},  //   jtim, ddil, _پیکج_,
  { {0x4438032e, 0x3959010f, 0x61e421de, 0x00000000}},  //   gnr_, üsse_, edil,
  { {0x60c40006, 0x6b9a0129, 0x9f410065, 0x00000000}},  //   etim, _metg, rdhë_,
  { {0x533410a9, 0x60c40065, 0x61e40058, 0x00000000}},  //   чест, ftim, gdil,
  { {0x2249022b, 0x625300f4, 0x60c400e0, 0x00000000}},  // [6730] roak_, nçoi, gtim,
  { {0x6b9a0006, 0x2249022b, 0x249f0089, 0x00000000}},  //   _netg, soak_, šums_,
  { {0x3f810016, 0xa5bb0285, 0x61e40066, 0x00000000}},  //   rchu_, biót, bdil,
  { {0x998d264e, 0x645501a2, 0x60c40045, 0x00000000}},  //   kneš_, llzi, btim,
  { {0x79990126, 0xfe700014, 0x2d9d264f, 0x00000000}},  //   _reww, ردم_, rawe_,
  { {0x7999002b, 0x998d09fc, 0x3ea10065, 0x00000000}},  //   _seww, dneš_, psht_,
  { {0xf9910025, 0xda65026b, 0x6e3b012d, 0x00000000}},  //   وبة_, овки, _tjub,
  { {0x291f002d, 0x6e291f3f, 0x25a91802, 0x00000000}},  //   tzua_, _umeb, _ndal_,
  { {0x6b9a00d4, 0x6d5b0035, 0x998d0c1e, 0x00000000}},  //   _fetg, _uzua, gneš_,
  { {0xd82501fb, 0xb5fb2650, 0xa7fc014a, 0x00000000}},  //   ідни, smál, smın,
  { {0x09c30055, 0x60c42651, 0x24892652, 0x00000000}},  //   ্যবা, ztim, _atam_,
  { {0x3ced2653, 0xe0df0173, 0x60c40133, 0x00000000}},  //   _krev_, _osò_, ytim,
  { {0x955606f1, 0x443806d3, 0x25a90016, 0x00000000}},  //   تخدا, tnr_, _ddal_,
  { {0xf1bf0211, 0x69c901a0, 0x44380009, 0x00000000}},  //   _acá_, lfee, unr_,
  { {0x68e90810, 0x443802a9, 0xe29a094b, 0x00000000}},  //   lved, rnr_, раб_,
  { {0x60c42654, 0x69c900bb, 0x61e41282, 0x00000000}},  //   ttim, nfee, udil,
  { {0x61e4006b, 0x68e90010, 0x60c4016c, 0x00000000}},  // [6740] rdil, nved, utim,
  { {0xe29a045e, 0x2f5601fc, 0xb05b04ce, 0x00000000}},  //   _као_, отес, _spär,
  { {0x69c9040f, 0x3e7701f3, 0x00000000, 0x00000000}},  //   kfee, _oħtu_,   ,
  { {0x60c40065, 0x6b9a2655, 0x3ced063b, 0x00000000}},  //   ptim, _setg, _brev_,
  { {0xce34026c, 0x69c9111b, 0x973c0091, 0x00000000}},  //   _ہوسک, dfee, maće,
  { {0x70d9007b, 0x7a3e0089, 0x3ced05fe, 0x00000000}},  //   _פֿרו, dīta, _drev_,
  { {0x69c9010f, 0x68e900d9, 0x6b9a0a5e, 0x00000000}},  //   ffee, eved, _vetg,
  { {0x6b9a00c7, 0xa8a6013b, 0xddc9001a, 0x00000000}},  //   _wetg, орок, _vieţ,
  { {0xdcf8026c, 0xd7fa00ed, 0x6d400066, 0x00000000}},  //   _دہشت_, аун_, _uxma,
  { {0x7e7c0089, 0xe1ff0051, 0x6253009d, 0x00000000}},  //   _kurp, _thóg_, rçoi,
  { {0xdb180004, 0x09ac0055, 0x8f7b00a3, 0x00000000}},  //   tevõ, ক্ষা, יניק,
  { {0x7e7c1fa8, 0x973c016c, 0x270e006b, 0x00000000}},  //   _murp, jaće, həng_,
  { {0xa9260025, 0x973c016c, 0x7e7c0032, 0x00000000}},  //   _بعضه, daće, _lurp,
  { {0x7bd80934, 0x25bf002b, 0x7e7c0253, 0x00000000}},  //   nevu, żul_, _ourp,
  { {0x7e7c0093, 0x00000000, 0x00000000, 0x00000000}},  //   _nurp,   ,   ,
  { {0x25a9022b, 0xd628012b, 0x09ac0044, 0x00000000}},  //   _udal_, _моје_, ক্রা,
  { {0x7e7c002d, 0x64402656, 0xa01b0039, 0x00000000}},  // [6750] _aurp, émic, _utök,
  { {0x2007000c, 0x7bd800b9, 0x74280025, 0x00000000}},  //   ðni_, jevu, _وكيف_,
  { {0x443101f6, 0x7bd82657, 0x68e90b41, 0x00000000}},  //   miz_, devu, zved,
  { {0x3ced00ab, 0xdb0301a2, 0x7c260006, 0x00000000}},  //   _prev_, rgnü, _įkra,
  { {0xe0df0026, 0xddc90089, 0x00000000, 0x00000000}},  //   _usò_, _cieš,   ,
  { {0x4431047f, 0x7bd82658, 0x69c90061, 0x00000000}},  //   niz_, gevu, wfee,
  { {0x60d9005a, 0x7e7c002d, 0xb5fb0010, 0x00000000}},  //   şamı, _gurp, rmáj,
  { {0xdce80036, 0x4431022b, 0x13e40044, 0x00000000}},  //   _śląs, hiz_, মায়,
  { {0x69c90116, 0x44312659, 0x7bd80026, 0x00000000}},  //   rfee, kiz_, bevu,
  { {0x87250242, 0x68e90030, 0x7bd80207, 0x00000000}},  //   змож, rved, cevu,
  { {0x6c6a009c, 0x4431265a, 0xe9450123, 0x00000000}},  //   _اللہ_, diz_, _کرای,
  { {0x3ebe0056, 0x00000000, 0x00000000, 0x00000000}},  //   _åtte_,   ,   ,
  { {0x4431013f, 0x973c0091, 0x00000000, 0x00000000}},  //   fiz_, vaće,   ,
  { {0x4431265b, 0x00000000, 0x00000000, 0x00000000}},  //   giz_,   ,   ,
  { {0x366a003b, 0x999f002b, 0x973c0521, 0x00000000}},  //   _лако_, kluż_, taće,
  { {0x05760445, 0x00000000, 0x00000000, 0x00000000}},  //   _عابد,   ,   ,
  { {0x443101a3, 0x55bb009b, 0x21670407, 0x00000000}},  // [6760] biz_, _המפו, зити_,
  { {0x7e7c00ab, 0xddc90027, 0x973c016c, 0x00000000}},  //   _purp, _rieš, saće,
  { {0x7ae1000a, 0x00000000, 0x00000000, 0x00000000}},  //   _nslt,   ,   ,
  { {0xddc9265c, 0x644e1b60, 0x7bc100f6, 0x00000000}},  //   _pieš, lobi, _aclu,
  { {0x20170047, 0x9f4301aa, 0x00000000, 0x00000000}},  //   áció_, _lajè_,   ,
  { {0x7e7c001e, 0xddc9010a, 0x61e6011f, 0x00000000}},  //   _turp, _vieš, _hakl,
  { {0x644e0032, 0x62530023, 0x9cfe0044, 0x00000000}},  //   iobi, rçov, ্ছেন_,
  { {0xddc9001e, 0x4431002d, 0xadb5007c, 0x00000000}},  //   _tieš, ziz_, _ощущ,
  { {0x61e60127, 0x4431265d, 0x0c2600c0, 0x00000000}},  //   _makl, yiz_, _еман,
  { {0x644e0107, 0xe1ff0011, 0x7bc10051, 0x00000000}},  //   jobi, _khóc_, _gclu,
  { {0x61e611d1, 0x644e0cce, 0x200a0011, 0x00000000}},  //   _oakl, dobi, _mobi_,
  { {0xcb13007b, 0x8afb00b6, 0xf76f0426, 0x00000000}},  //   _אלע_, _להבי, داً_,
  { {0x443101aa, 0xa9c5007a, 0x2ca60058, 0x00000000}},  //   tiz_, _آزمو, nsod_,
  { {0xb3470181, 0x68e20203, 0x644e005b, 0x00000000}},  //   _naçõ, _isod, gobi,
  { {0x61e6011c, 0x4431011f, 0x268a0025, 0x00000000}},  //   _bakl, riz_, _اختي_,
  { {0x44310497, 0x75480010, 0x69c201c3, 0x00000000}},  //   siz_, észé, _jcoe,
  { {0x61e60119, 0x4431008e, 0x764f0036, 0x00000000}},  // [6770] _dakl, piz_, mocy,
  { {0x764f1ee1, 0xdb1a00f6, 0x00000000, 0x00000000}},  //   locy, _actí,   ,
  { {0x3ea70047, 0x200a265e, 0xe1ff0082, 0x00000000}},  //   ént_, _dobi_, _chóc_,
  { {0x5d35026c, 0x9f4a00c4, 0x68e20016, 0x00000000}},  //   وفائ, _robô_, _osod,
  { {0x200a22ae, 0x00000000, 0x00000000, 0x00000000}},  //   _fobi_,   ,   ,
  { {0x200a0bd6, 0x764f0a88, 0x69c200fa, 0x00000000}},  //   _gobi_, hocy, _acoe,
  { {0x69c20061, 0x61e6014a, 0xcb6600e3, 0x00000000}},  //   _bcoe, _yakl, маше_,
  { {0x644e008e, 0x00000000, 0x00000000, 0x00000000}},  //   zobi,   ,   ,
  { {0x68e20010, 0x320b0036, 0x629a0010, 0x00000000}},  //   _csod, _mocy_, átoz,
  { {0xe630006b, 0x644e00fa, 0x7d1600ea, 0x00000000}},  //   _bəşə, xobi, øyse,
  { {0x644e0107, 0xfb150025, 0x366a072b, 0x00000000}},  //   vobi, _تواج, жано_,
  { {0xcb1200b6, 0x320b0036, 0xc915003b, 0x00000000}},  //   _שלא_, _nocy_, _одећ,
  { {0x644e2645, 0x3a2f04a5, 0x61e6265f, 0x00000000}},  //   tobi, _imgp_, _rakl,
  { {0xb4ce03d7, 0x61e6011f, 0xe45f00b0, 0x00000000}},  //   _रही_, _sakl, stön_,
  { {0x61e60006, 0x644e05fd, 0x200a0036, 0x00000000}},  //   _pakl, robi, _robi_,
  { {0x27e70359, 0x2d9f001f, 0x644e2660, 0x00000000}},  //   _hann_, _neue_, sobi,
  { {0x27e7001f, 0x644e0036, 0x6283009d, 0x00000000}},  // [6780] _kann_, pobi, _énon,
  { {0x25a001e5, 0x27e70173, 0x2ca60059, 0x00000000}},  //   _heil_, _jann_, vsod_,
  { {0x27e72661, 0x61e6083a, 0x00000000, 0x00000000}},  //   _mann_, _takl,   ,
  { {0x3eba2662, 0xa3c80164, 0x3ea70035, 0x00000000}},  //   rupt_, ोजक_, ânta_,
  { {0x3cfa03d7, 0xa06a04b6, 0x25a00004, 0x00000000}},  //   ्हें_, _мама_, _meil_,
  { {0xb5fb0a87, 0x2d9f0007, 0xa01b00f8, 0x00000000}},  //   rmái, _eeue_, _stöv,
  { {0xa6e1000c, 0x25a000f4, 0x69db01a2, 0x00000000}},  //   óðle, _oeil_, feue,
  { {0x25a0006c, 0xe1ff001d, 0xc7ce0011, 0x00000000}},  //   _neil_, _khóa_, _cống_,
  { {0x27e72663, 0x00000000, 0x00000000, 0x00000000}},  //   _bann_,   ,   ,
  { {0x3958001e, 0x00000000, 0x00000000, 0x00000000}},  //   ārs_,   ,   ,
  { {0x27e7001f, 0x764f0a32, 0x5c3700a3, 0x00000000}},  //   _dann_, tocy, _קרבן_,
  { {0xa01b0039, 0x6e220288, 0x6440009d, 0x00000000}},  //   _utöv, nhob, émin,
  { {0x764f013e, 0x27e7021a, 0xd90f00a1, 0x00000000}},  //   rocy, _fann_, _نیٹ_,
  { {0xe630005f, 0xe72f0014, 0x24800116, 0x00000000}},  //   _təşə, اصی_, _duim_,
  { {0x45070055, 0x6adc02fb, 0x25a00292, 0x00000000}},  //   _লেখক_, _मनोर, _feil_,
  { {0x69c02664, 0x25a005c6, 0x00000000, 0x00000000}},  //   ngme, _geil_,   ,
  { {0x48bc0044, 0x3134132e, 0x27e72665, 0x00000000}},  // [6790] _অনুর, ветр, _yann_,
  { {0x25a0095d, 0x00000000, 0x00000000, 0x00000000}},  //   _zeil_,   ,   ,
  { {0xb2751deb, 0x6e230007, 0x533500e2, 0x00000000}},  //   _плош, ënbo, _чент,
  { {0x660d00f8, 0x62531374, 0xf2d20049, 0x00000000}},  //   _joak, rços, _געט_,
  { {0x2ca9002a, 0x69c000ab, 0x656b0045, 0x00000000}},  //   éad_, dgme, _ùghd,
  { {0xc7ce001d, 0x2005010e, 0x69c001c3, 0x00000000}},  //   _sống_, _õli_, egme,
  { {0x27e701aa, 0xdb030065, 0x69db010f, 0x00000000}},  //   _rann_, manë, teue,
  { {0x3ebe0039, 0x660d01f3, 0x6e2201a2, 0x00000000}},  //   _åtta_, _noak, chob,
  { {0xb4ce02d2, 0x2919143a, 0x973c1a84, 0x00000000}},  //   _रहे_, ása_, vaća,
  { {0x24802666, 0x25a02667, 0xddc90027, 0x00000000}},  //   _ruim_, _seil_, _dieť,
  { {0x98ab011f, 0x27e72668, 0x24800051, 0x00000000}},  //   ğlık_, _vann_, _suim_,
  { {0xc7ce001d, 0x27e7010f, 0x98ab014a, 0x00000000}},  //   _uống_, _wann_, şlık_,
  { {0x973c037e, 0x27e70263, 0xdb030065, 0x00000000}},  //   raća, _tann_, kanë,
  { {0x25a0001f, 0x33d50cf2, 0x7d0400b0, 0x00000000}},  //   _weil_, кіст, äisi,
  { {0x25a02669, 0x78a904bd, 0x973c012d, 0x00000000}},  //   _teil_, lsev, paća,
  { {0x91e301bd, 0x79891091, 0x00000000, 0x00000000}},  //   лосе, ncew,   ,
  { {0x78a90056, 0xdb010030, 0x888c0049, 0x00000000}},  // [67a0] nsev, _udlæ, ַראַ,
  { {0x78a90052, 0xdb030023, 0x65640045, 0x00000000}},  //   isev, ganë, _izih,
  { {0x2cbd00bb, 0xdb1a1c8d, 0x7c230048, 0x00000000}},  //   euwd_, _octá, dhnr,
  { {0x444401a3, 0x645c02e1, 0x6fc20061, 0x00000000}},  //   _hj_, llri, _लावू,
  { {0x2240266a, 0x98b80089, 0x644101dc, 0x00000000}},  //   mnik_, ārī_, čliv,
  { {0x224001d9, 0x4444003b, 0x6e220061, 0x00000000}},  //   lnik_, _jj_, shob,
  { {0x6e220051, 0x63a30004, 0x4444266b, 0x00000000}},  //   phob, _õnne, _mj_,
  { {0x44440059, 0xfce60175, 0x22400036, 0x00000000}},  //   _lj_, _побо, nnik_,
  { {0x1c46013b, 0xdd8f05f3, 0xd7f00025, 0x00000000}},  //   _знам, _طول_, لكة_,
  { {0x2240266c, 0x645c0009, 0x3a3f2082, 0x00000000}},  //   hnik_, jlri, anup_,
  { {0x2cb00006, 0x659500da, 0xdb0600b0, 0x00000000}},  //   žodį_, кану, ämäl,
  { {0x444413a1, 0x5fc70061, 0xdb030023, 0x00000000}},  //   _aj_, _लाभल, zanë,
  { {0xba290025, 0x4444010f, 0x00000000, 0x00000000}},  //   _تسلم_, _bj_,   ,
  { {0x44440adb, 0xe45f000c, 0x6564016c, 0x00000000}},  //   _cj_, mtök_, _dzih,
  { {0x444404bd, 0x2456009f, 0x81c50055, 0x00000000}},  //   _dj_, væmt_, _এসব_,
  { {0x44440073, 0xb5fb0b33, 0x4423012d, 0x00000000}},  //   _ej_, gmát, shj_,
  { {0x4444107b, 0x661d0023, 0x00000000, 0x00000000}},  // [67b0] _fj_, ërku,   ,
  { {0x4444164d, 0x765d0039, 0xfd650082, 0x00000000}},  //   _gj_, llsy, _thuẫ,
  { {0x224001d9, 0xdd910025, 0xdb030065, 0x00000000}},  //   bnik_, لوا_, ranë,
  { {0x63a71457, 0x78a900d9, 0xfe700426, 0x00000000}},  //   lajn, ysev, مدن_,
  { {0x61fd22b0, 0x44211f0f, 0x4444016b, 0x00000000}},  //   _insl, _klh_, _yj_,
  { {0xa136007b, 0x61ed0010, 0x60cd09bd, 0x00000000}},  //   _יארק_, ldal, mtam,
  { {0x60cd00b0, 0x44210300, 0x9f350088, 0x00000000}},  //   ltam, _mlh_, _реві,
  { {0x32090e9e, 0x78a903b6, 0x63a70107, 0x00000000}},  //   njay_, tsev, hajn,
  { {0x9f430224, 0x5c7500ed, 0x60cd01cb, 0x00000000}},  //   _mají_, _алат, ntam,
  { {0x22400aa9, 0x60cd0181, 0x61ed266d, 0x00000000}},  //   znik_, itam, hdal,
  { {0x444402d5, 0x63a70465, 0xb5fb01dc, 0x00000000}},  //   _rj_, dajn, klád,
  { {0x61ed115b, 0x44440142, 0x19950088, 0x00000000}},  //   jdal, _sj_, _радя,
  { {0x224001d9, 0x61ed0016, 0x8884007e, 0x00000000}},  //   vnik_, ddal, _бліж,
  { {0x22400046, 0x61fd17db, 0x7bc3266e, 0x00000000}},  //   wnik_, _ansl, ngnu,
  { {0x224000ee, 0x03a301e0, 0x44330048, 0x00000000}},  //   tnik_, рисо, _dmx_,
  { {0xc24301f9, 0x61ed011c, 0xb5fb0285, 0x00000000}},  //   анск, gdal, umát,
  { {0x44440119, 0x22400209, 0xa0a6007e, 0x00000000}},  // [67c0] _tj_, rnik_, тазд,
  { {0x22400b54, 0xa01b266f, 0x63a70868, 0x00000000}},  //   snik_, _stör, cajn,
  { {0x4438049a, 0x60cd2670, 0x2240016e, 0x00000000}},  //   mir_, atam, pnik_,
  { {0x4438049d, 0x7c210538, 0x7e7b001a, 0x00000000}},  //   lir_, _allr, _ciup,
  { {0x60cd16ca, 0x4438002a, 0x7e7b04be, 0x00000000}},  //   ctam, oir_, _diup,
  { {0x44382671, 0x3e67006c, 0x1d07003b, 0x00000000}},  //   nir_, võte_, тељи_,
  { {0xaa582672, 0xbea3003b, 0x7a3e0089, 0x00000000}},  //   нику_, _васк, līti,
  { {0x443809d4, 0x63a709fc, 0x26140181, 0x00000000}},  //   hir_, zajn, _mãos_,
  { {0xfce3222e, 0x48c20055, 0x7a3e0089, 0x00000000}},  //   _кото, ্ট্র, nīti,
  { {0xd7f70783, 0x61ed0059, 0xb5fb0010, 0x00000000}},  //   вую_, zdal, ymás,
  { {0x44382673, 0x61ed038c, 0xe45f000c, 0x00000000}},  //   dir_, ydal, stök_,
  { {0x7c380377, 0x7e690023, 0x44380048, 0x00000000}},  //   livr, _xhep, eir_,
  { {0x4438000c, 0x44210022, 0xdb030161, 0x00000000}},  //   fir_, _plh_, vané,
  { {0x44382674, 0x9f470428, 0x7a3e0089, 0x00000000}},  //   gir_, žné_, dīti,
  { {0x7bc801e2, 0xd8380087, 0x682400f6, 0x00000000}},  //   _mcdu, mič_, _còde,
  { {0x60cd0dc9, 0xd8380059, 0x44380051, 0x00000000}},  //   ttam, lič_, air_,
  { {0x443802e2, 0x61ed2675, 0xe7cf006e, 0x00000000}},  // [67d0] bir_, rdal, त्वप,
  { {0x60cd0149, 0x44380845, 0xd8380235, 0x00000000}},  //   rtam, cir_, nič_,
  { {0x60cd0ac2, 0xd371007a, 0x64551b45, 0x00000000}},  //   stam, _دهد_, mozi,
  { {0x64550209, 0x60cd000d, 0x661d02e7, 0x00000000}},  //   lozi, ptam, nksk,
  { {0x91ba034e, 0xd8380059, 0x7a3e0089, 0x00000000}},  //   _אמרי, kič_, cīti,
  { {0xcb6900ed, 0xd8380059, 0xbfb8007a, 0x00000000}},  //   нале_, jič_, _لطفا_,
  { {0x49930014, 0x62850142, 0x7bc32676, 0x00000000}},  //   لیار, _juho, rgnu,
  { {0x44381812, 0x3eda0049, 0x62852677, 0x00000000}},  //   zir_, _אַמא, _muho,
  { {0x4438005f, 0xe1ff001d, 0x60120030, 0x00000000}},  //   yir_, _nhóm_, _kæmp,
  { {0x480501e1, 0x63a50027, 0xd8380059, 0x00000000}},  //   упов, _nehn, gič_,
  { {0x44380489, 0x645511b7, 0x7a3e0089, 0x00000000}},  //   vir_, dozi, zīti,
  { {0x4438018e, 0x20110107, 0xdb01009d, 0x00000000}},  //   wir_, _lozi_, _relè,
  { {0x44380fa2, 0xdb0101aa, 0xd8380059, 0x00000000}},  //   tir_, _selè, bič_,
  { {0x6455064c, 0xd91a007b, 0x6285011c, 0x00000000}},  //   gozi, _רוסל, _buho,
  { {0x44380359, 0xdb012678, 0x232a0184, 0x00000000}},  //   rir_, _belé, хови_,
  { {0xe7cf0183, 0x62850213, 0xdb0101ca, 0x00000000}},  //   त्रप, _duho, _celé,
  { {0x6455001a, 0x4127005e, 0x00000000, 0x00000000}},  // [67e0] bozi, гото_,   ,
  { {0xdb0104bd, 0x7a3e0089, 0x44380350, 0x00000000}},  //   _telè, rīti, qir_,
  { {0xdb010010, 0x62850009, 0x2d800089, 0x00000000}},  //   _felé, _guho, žiem_,
  { {0x1756007b, 0xe1ff002a, 0x52d7007b, 0x00000000}},  //   אסער_, _gnó_, _גוטע_,
  { {0x7a3e0089, 0x00000000, 0x00000000, 0x00000000}},  //   nūte,   ,   ,
  { {0x3f9a0123, 0x00000000, 0x00000000, 0x00000000}},  //   _سپرد_,   ,   ,
  { {0x81e70055, 0xd8380465, 0xdddc0035, 0x00000000}},  //   পার_, vič_, _curţ,
  { {0x611a001e, 0x64550020, 0x799b0058, 0x00000000}},  //   _tālā, zozi, gbuw,
  { {0x02e102d2, 0xd83800ca, 0x59d30025, 0x00000000}},  //   _पन्न, tič_, صغير,
  { {0x6a650d28, 0x00000000, 0x00000000, 0x00000000}},  //   rófa,   ,   ,
  { {0xd8380235, 0xeb97007c, 0x8c1b0104, 0x00000000}},  //   rič_, _сих_, _רובי,
  { {0x98a601f9, 0x63a5048e, 0x628518fb, 0x00000000}},  //   _биде, _sehn, _ruho,
  { {0x661d01c9, 0x64550232, 0xd8380c8a, 0x00000000}},  //   rksk, tozi, pič_,
  { {0x3cec0164, 0xa7fc1d83, 0x00000000, 0x00000000}},  //   _आईने_, rmıs,   ,
  { {0x443f0091, 0x2bd60061, 0xa7fc026d, 0x00000000}},  //   đu_, ढ्या, rlıd,
  { {0x855700a1, 0x64551a28, 0x00000000, 0x00000000}},  //   _میجر_, sozi,   ,
  { {0x64550704, 0xbf1d007d, 0x2fca18dc, 0x00000000}},  // [67f0] pozi, पन्न_, _bcbg_,
  { {0x27ee000c, 0x628518ec, 0xa7fc006b, 0x00000000}},  //   _jafn_, _tuho, qlıd,
  { {0xdb010845, 0x20110213, 0xdb1800f8, 0x00000000}},  //   _telé, _vozi_, ngvä,
  { {0x5fc70061, 0x6da40426, 0x798200e7, 0x00000000}},  //   _लावल, مممم, _ngow,
  { {0xfaf80580, 0x201101c3, 0x00000000, 0x00000000}},  //   _arī_, _tozi_,   ,
  { {0x27ee009f, 0x3dc901d5, 0x2fc500ea, 0x00000000}},  //   _nafn_, żaw_, _ølg_,
  { {0x1b490265, 0x44fd0044, 0x00000000, 0x00000000}},  //   ъзки_, ুনিক_,   ,
  { {0x61ef0145, 0x78bb092d, 0x00000000, 0x00000000}},  //   _jacl, truv,   ,
  { {0xdb0315e3, 0x2d9d21a4, 0xcbc70076, 0x00000000}},  //   maní, mbwe_, _مزاي,
  { {0x1bab00a1, 0x66db00b0, 0x5c7402dc, 0x00000000}},  //   _سائٹ_, _näkö, _глут,
  { {0xbb840054, 0x9f5e0011, 0x270f0061, 0x00000000}},  //   _المي, _ôtô_, ाहेर_,
  { {0xdddc2679, 0x6a65004a, 0x7afc13f5, 0x00000000}},  //   _kurš, mófo, _árta,
  { {0xe0c00055, 0x5967005e, 0x5a0a0049, 0x00000000}},  //   _উন্ন, _съжа, _בלײַ,
  { {0xe7870594, 0xdddc0087, 0x00000000, 0x00000000}},  //   _судо, _murš,   ,
  { {0x6a650325, 0x00000000, 0x00000000, 0x00000000}},  //   nófo,   ,   ,
  { {0xc486012b, 0x2fd80022, 0x00000000, 0x00000000}},  //   _клик, _sbrg_,   ,

  { {0xddc90089, 0xdb03267a, 0x69d900e7, 0x00000000}},  // [6800] _biež, daní, _mbwe,
  { {0xcef6003b, 0x9f58000c, 0xb5fb0161, 0x00000000}},  //   ичењ, _borð_, plác,
  { {0x0d860888, 0x61ef267b, 0x69d90009, 0x00000000}},  //   ален, _facl, _obwe,
  { {0x764601e5, 0x00000000, 0x00000000, 0x00000000}},  //   nnky,   ,   ,
  { {0x9d240055, 0x61e40cc7, 0xdb0a04ce, 0x00000000}},  //   বপ্ন_, meil, ngfö,
  { {0x61e4089e, 0x69d9010f, 0x3dc60133, 0x00000000}},  //   leil, _abwe, sgow_,
  { {0x7f432308, 0xdb030129, 0x7aed0036, 0x00000000}},  //   _держ, baní, łatn,
  { {0x78a20263, 0x61e400b0, 0xd90d0014, 0x00000000}},  //   _pwov, neil, کیه_,
  { {0x973c0091, 0x2d840058, 0x60c4267c, 0x00000000}},  //   maći, _igme_, nuim,
  { {0x61e4021e, 0x7d280279, 0x69d90045, 0x00000000}},  //   heil, ırsı, _ebwe,
  { {0x09e60d03, 0x442a002a, 0x61e4021e, 0x00000000}},  //   _воен, dhb_, keil,
  { {0x7e6200b0, 0x00000000, 0x00000000, 0x00000000}},  //   nlop,   ,   ,
  { {0xb8940054, 0x61e4267d, 0x61ef009d, 0x00000000}},  //   _التع, deil, _racl,
  { {0xb4d702d2, 0x6fc20061, 0x32020bca, 0x00000000}},  //   _सही_, _लागू, _anky_,
  { {0xf1a700d7, 0x61e4018e, 0x3a260007, 0x00000000}},  //   иран, feil, _klop_,
  { {0xe1ff0011, 0x61e40678, 0xd5e40082, 0x00000000}},  //   _khói_, geil, _thí,
  { {0x60c4029a, 0x60cf001c, 0x7bda008e, 0x00000000}},  // [6810] guim, _qqcm, _obtu,
  { {0x25a90c78, 0x9f4701c8, 0x3a2600d4, 0x00000000}},  //   _heal_, žní_, _llop_,
  { {0x6447037e, 0xa1870147, 0xdb010030, 0x00000000}},  //   mnji, _выгл, _udlø,
  { {0x7e621c83, 0x2bc90061, 0x60c4004a, 0x00000000}},  //   glop, _राहा, buim,
  { {0x7afa014a, 0x9ce708fc, 0xdb03267e, 0x00000000}},  //   _artt, рцел, raní,
  { {0x1ee7026c, 0x25a90285, 0xdb0315e3, 0x00000000}},  //   _پوری_, _leal_, saní,
  { {0x601300b9, 0x99840006, 0x7e62267f, 0x00000000}},  //   _výmě, jimų_, blop,
  { {0x09f90025, 0x39e9017f, 0x99840006, 0x00000000}},  //   افظة_, удио_, dimų_,
  { {0x64470bf8, 0xa5bb0051, 0xe1ff0082, 0x00000000}},  //   knji, chói, _chói_,
  { {0x08d4007e, 0x998d0027, 0x61e42680, 0x00000000}},  //   іцыя, dieť_, zeil,
  { {0x64470de0, 0x25a90048, 0x2003012d, 0x00000000}},  //   dnji, _beal_, _mnji_,
  { {0x08f904e8, 0x69d90117, 0x3a2600f6, 0x00000000}},  //   _مرتب_, _ubwe, _glop_,
  { {0x61e400b5, 0x25a900ab, 0x7a7a0049, 0x00000000}},  //   veil, _deal_, _ערנס,
  { {0x61e4001f, 0x24890065, 0x69c9046a, 0x00000000}},  //   weil, _duam_, lgee,
  { {0x61e42681, 0x68e9018e, 0x232701bd, 0x00000000}},  //   teil, lwed, бори_,
  { {0x69c900b5, 0x60c400b0, 0x20030022, 0x00000000}},  //   ngee, tuim, _anji_,
  { {0x61e4089e, 0x7e620263, 0x2489006b, 0x00000000}},  // [6820] reil, vlop, _guam_,
  { {0x61e4002d, 0x60c40250, 0x26c500fa, 0x00000000}},  //   seil, ruim, oulo_,
  { {0x443a0066, 0xd00f01b7, 0x68e9010f, 0x00000000}},  //   _imp_, علم_, hwed,
  { {0xa5bb0051, 0x443a0058, 0xd5ed0082, 0x00000000}},  //   thói, _hmp_, _phả,
  { {0x27e50a5d, 0x60c412b2, 0x629c0292, 0x00000000}},  //   keln_, quim, lpro,
  { {0x26c5006a, 0x68e90016, 0x7e6200ca, 0x00000000}},  //   kulo_, dwed, slop,
  { {0x629c1103, 0x3a2607b9, 0x7e6200f8, 0x00000000}},  //   npro, _plop_, plop,
  { {0x26c52682, 0xae0c02f4, 0x64470e00, 0x00000000}},  //   dulo_, _सचिन_, znji,
  { {0x25a90038, 0x270e005f, 0xdca31662, 0x00000000}},  //   _real_, məni_, _нати,
  { {0x27e52683, 0x629c0056, 0x66040010, 0x00000000}},  //   geln_, kpro, _anik,
  { {0x26c52684, 0x810402fb, 0xe45f145c, 0x00000000}},  //   gulo_, रमुख_, ktör_,
  { {0x99840006, 0xe1ff0011, 0x6e2200ea, 0x00000000}},  //   rimų_, _thói_, nkob,
  { {0x27e50002, 0x629c046a, 0xb8d30014, 0x00000000}},  //   beln_, epro, _فتوش,
  { {0x443a0061, 0x629c037f, 0x26c50006, 0x00000000}},  //   _cmp_, fpro, bulo_,
  { {0x752f0046, 0x26c5201f, 0x25a90541, 0x00000000}},  //   szcz, culo_, _teal_,
  { {0x6447037e, 0x9f5100c4, 0x06ae0044, 0x00000000}},  //   snji, _fazê_, _কমপি,
  { {0x30150920, 0x7c3a1aef, 0x764d0020, 0x00000000}},  // [6830] одар, _omtr, _ijay,
  { {0x443a0145, 0x66040036, 0x6440009d, 0x00000000}},  //   _gmp_, _znik, émit,
  { {0xdb012685, 0x629c0061, 0x4f6b0216, 0x00000000}},  //   _pelí, cpro, ушам_,
  { {0x7c28141a, 0x68e90016, 0x6e2200ea, 0x00000000}},  //   _aldr, ywed, gkob,
  { {0x067c0049, 0x22490010, 0x1d090242, 0x00000000}},  //   אנאל, mnak_, рели_,
  { {0x22490047, 0x27e50210, 0xdb0109af, 0x00000000}},  //   lnak_, xeln_, _relâ,
  { {0x69c900b5, 0x27e50210, 0x22490032, 0x00000000}},  //   tgee, veln_, onak_,
  { {0x22490047, 0x7c280d3e, 0x68e9010f, 0x00000000}},  //   nnak_, _eldr, twed,
  { {0x69c92686, 0x27e50210, 0x2249028d, 0x00000000}},  //   rgee, teln_, inak_,
  { {0x26c50325, 0x6e291dbe, 0x660401d6, 0x00000000}},  //   tulo_, _hleb, _snik,
  { {0x22492687, 0x6e29010f, 0x68e900bb, 0x00000000}},  //   knak_, _kleb, swed,
  { {0x443a023a, 0xb5fb2688, 0x27e52689, 0x00000000}},  //   _smp_, slán, seln_,
  { {0x2249268a, 0x629c0dd7, 0x9f510065, 0x00000000}},  //   dnak_, wpro, _bazë_,
  { {0x4add0164, 0x2249002d, 0x26c5011c, 0x00000000}},  //   _महाव, enak_, pulo_,
  { {0x366a01b3, 0x63ae01d9, 0x6e3b0009, 0x00000000}},  //   _како_, rabn, _omub,
  { {0x6604268b, 0x9fa3009f, 0x22490010, 0x00000000}},  //   _unik, _síðu_, gnak_,
  { {0x443a0857, 0x7bdc000c, 0x291f0020, 0x00000000}},  // [6840] _tmp_, _örug, nyua_,
  { {0x629c01d5, 0x6e2913a1, 0x2249023a, 0x00000000}},  //   ppro, _aleb, anak_,
  { {0x6e2200ea, 0x270e006b, 0x9f51000a, 0x00000000}},  //   tkob, təni_, _jazè_,
  { {0xcbc60055, 0x6e29268c, 0xdd9001af, 0x00000000}},  //   _এসেছ, _cleb, روت_,
  { {0x6e22023a, 0x9f5101aa, 0x9f470142, 0x00000000}},  //   rkob, _lazè_, ľná_,
  { {0x645c0006, 0x9f47004f, 0x628300f4, 0x00000000}},  //   nori, žná_, _énor,
  { {0xdb030010, 0x1b1d0044, 0x6e29268d, 0x00000000}},  //   taná, _ভেবে_, _fleb,
  { {0x2018022b, 0x645c0d97, 0xa2cb0309, 0x00000000}},  //   _hori_, hori, तंत्,
  { {0x201801c5, 0x60d6268e, 0x67d400e2, 0x00000000}},  //   _kori_, ntym, попу,
  { {0x22490010, 0x60d60006, 0x4734007c, 0x00000000}},  //   znak_, itym, знос,
  { {0x645c0c79, 0x2018090a, 0x2249268f, 0x00000000}},  //   dori, _mori_, ynak_,
  { {0x201801a3, 0x65640009, 0xe5a400e2, 0x00000000}},  //   _lori_, _byih, миџи,
  { {0x645c2690, 0x61f60016, 0x938b005e, 0x00000000}},  //   fori, ddyl, исва_,
  { {0x2018010a, 0x9faf0279, 0xd61b00a1, 0x00000000}},  //   _nori_, _işçi_, اتھا_,
  { {0x22490047, 0xb5fb0010, 0x9294007e, 0x00000000}},  //   tnak_, llám, дасц,
  { {0x786f0737, 0xdb080173, 0x6fd80061, 0x00000000}},  //   røve, _vedè, न्सू,
  { {0x645c1a7e, 0x22490010, 0x765d2691, 0x00000000}},  // [6850] bori, rnak_, mosy,
  { {0x22490ac3, 0x20180197, 0x765d2081, 0x00000000}},  //   snak_, _cori_, losy,
  { {0x161f0164, 0x2018001a, 0xdb03006b, 0x00000000}},  //   _पवार_, _dori_, manç,
  { {0xdb030181, 0x765d00f8, 0xfe7003ec, 0x00000000}},  //   lanç, nosy, ندن_,
  { {0xeb990517, 0x20180197, 0xd9c20044, 0x00000000}},  //   бил_, _fori_, ্জাম,
  { {0x20180e00, 0xdb030a0a, 0x9f430027, 0x00000000}},  //   _gori_, nanç, _majú_,
  { {0xfb8500a1, 0x68e2008e, 0x765d0fa8, 0x00000000}},  //   _ہدای, _apod, kosy,
  { {0x6e3b1bf2, 0x290d002d, 0x20180035, 0x00000000}},  //   _umub, txea_, _zori_,
  { {0x645c2692, 0xa3dc007d, 0x648b0066, 0x00000000}},  //   yori, ण्ड_, _jżid,
  { {0x645c0032, 0x68e2004a, 0xdb0306c0, 0x00000000}},  //   xori, _dpod, janç,
  { {0xdb030181, 0x765d005b, 0xb5fb0010, 0x00000000}},  //   danç, fosy, plál,
  { {0x765d2693, 0x645c2694, 0x60d600b0, 0x00000000}},  //   gosy, wori, ytym,
  { {0x645c2695, 0x2bd202fb, 0x280600b9, 0x00000000}},  //   tori, _सामा, ávní_,
  { {0x5fc7001c, 0xa7fc038c, 0xdb0300c4, 0x00000000}},  //   _लागल, nlıl, ganç,
  { {0x765d00e0, 0x232700ed, 0x32191163, 0x00000000}},  //   bosy, пори_, _bosy_,
  { {0x60d600b0, 0x239700b9, 0x3219062a, 0x00000000}},  //   ttym, tějí_, _cosy_,
  { {0x645c0142, 0x20182696, 0xd259007e, 0x00000000}},  // [6860] pori, _pori_, ццё_,
  { {0xdb032697, 0x60d60639, 0x645c006b, 0x00000000}},  //   canç, rtym, qori,
  { {0x60d60ecb, 0x20182698, 0xdfcf0076, 0x00000000}},  //   stym, _vori_, ايم_,
  { {0xdd8f0076, 0x201800e0, 0x00000000, 0x00000000}},  //   هوم_, _wori_,   ,
  { {0x20180103, 0x62860058, 0xdb010142, 0x00000000}},  //   _tori_, _iiko, _relá,
  { {0x28c20061, 0x62860052, 0xdb032699, 0x00000000}},  //   _शिबि, _hiko, kanä,
  { {0x68e201d9, 0x6286000b, 0xada600e3, 0x00000000}},  //   _spod, _kiko, _навл,
  { {0xa9c301fb, 0x8cc403d7, 0x6286269a, 0x00000000}},  //   нськ, _रिपो, _jiko,
  { {0x62861483, 0xdb01008e, 0x68fb0045, 0x00000000}},  //   _miko, _velá, gvud,
  { {0x62861a7e, 0x60c4002a, 0x2cb700b9, 0x00000000}},  //   _liko, irim, ředí_,
  { {0xfaa30500, 0xe1ff0051, 0x628600b0, 0x00000000}},  //   _захо, _mhór_, _oiko,
  { {0x62860119, 0x60c4008d, 0xae020316, 0x00000000}},  //   _niko, krim, _रोमन_,
  { {0xdb031052, 0x32191ff6, 0x765d013f, 0x00000000}},  //   tanç, _rosy_, rosy,
  { {0x628600b0, 0x765d224b, 0x60c4269b, 0x00000000}},  //   _aiko, sosy, drim,
  { {0xdb03269c, 0x6286002d, 0x60c40004, 0x00000000}},  //   ranç, _biko, erim,
  { {0x6286269d, 0x326417b9, 0x80e10044, 0x00000000}},  //   _ciko, етув, নিস্,
  { {0x60c40065, 0xdff501fc, 0xa6ae0044, 0x00000000}},  // [6870] grim, мпањ, _কমিট,
  { {0x44ef269e, 0xd7f8001a, 0x6a6510ef, 0x00000000}},  //   _iż_, ndă_, rófi,
  { {0x7d00269f, 0x60c40197, 0x6a650b33, 0x00000000}},  //   _arms, arim, sófi,
  { {0x628601dd, 0x6a650325, 0x00000000, 0x00000000}},  //   _giko, pófi,   ,
  { {0x60c40412, 0xa7fc026d, 0x00000000, 0x00000000}},  //   crim, tlıl,   ,
  { {0x62860a65, 0x6f010181, 0xdb060035, 0x00000000}},  //   _ziko, _álco, ămîn,
  { {0xa7fc005a, 0x6f6401ab, 0x62860045, 0x00000000}},  //   rlıl, _звёз, _yiko,
  { {0x09e00055, 0x7d000009, 0x68fb006c, 0x00000000}},  //   _মোবা, _frms, tvud,
  { {0xa7fc014a, 0x7d1600ea, 0x00000000, 0x00000000}},  //   lmıy, øyst,   ,
  { {0xb8d502d2, 0xa5bb009f, 0x8afc0046, 0x00000000}},  //   _जब_, skól, _częs,
  { {0x44ef0036, 0x2bd20204, 0xa7fc014a, 0x00000000}},  //   _aż_, _साता, nmıy,
  { {0x1b1608b7, 0xd7f8001a, 0x60c4131c, 0x00000000}},  //   _থেকে_, adă_, yrim,
  { {0x628626a0, 0xb8f20044, 0xdb010276, 0x00000000}},  //   _riko, _হৈ_, _belç,
  { {0x628601aa, 0x60c4014a, 0xa7fc0095, 0x00000000}},  //   _siko, vrim, kmıy,
  { {0x6286026a, 0x44ef002b, 0x232a0143, 0x00000000}},  //   _piko, _eż_, цови_,
  { {0x7aed0036, 0x00000000, 0x00000000, 0x00000000}},  //   łatw,   ,   ,
  { {0x21670bbd, 0x61430888, 0x75460088, 0x00000000}},  // [6880] дити_, вета, _іноз,
  { {0x60c426a1, 0x2bd20164, 0x443100d2, 0x00000000}},  //   rrim, _साधा, chz_,
  { {0xdb0a1505, 0x1b1d0044, 0x00000000, 0x00000000}},  //   tafí, _ভেসে_,   ,
  { {0x60c4049a, 0xf9870879, 0xd5ed0011, 0x00000000}},  //   prim, _لب_, _khá,
  { {0xa7fc005d, 0xdb0a008e, 0x1fb6025f, 0x00000000}},  //   rmız, rafí, _освр,
  { {0xdb0a008e, 0xdd990173, 0x00000000, 0x00000000}},  //   safí, _efň_,   ,
  { {0x15ee013d, 0xb5fb0b33, 0x644e0c4c, 0x00000000}},  //   ज़ार_, noác, inbi,
  { {0xf2d300b6, 0x80e10044, 0x7d1600ea, 0x00000000}},  //   דעה_, নির্, øyss,
  { {0x26c50e32, 0x8d6326a2, 0x81e00044, 0x00000000}},  //   erlo_, _авте, _দফা_,
  { {0xdb010002, 0x629e0091, 0xdca301ee, 0x00000000}},  //   _belä, _otpo, _рафи,
  { {0xb5fb0a87, 0xd7f8001a, 0x45d50216, 0x00000000}},  //   llái, rdă_, нонс,
  { {0xa5f90057, 0xa92624ab, 0xdb0126a3, 0x00000000}},  //   чему_, _одел, _selç,
  { {0x26c50e32, 0xdd31006b, 0x09d70044, 0x00000000}},  //   arlo_, _məşh, _দোকা,
  { {0xe9470167, 0x69d50010, 0x7d0400b0, 0x00000000}},  //   _ترمی, őzet, äisy,
  { {0xe7f30061, 0xb5fb0051, 0x98a30006, 0x00000000}},  //   _असता_, hlái, ąją_,
  { {0x9099005e, 0xa7fc014a, 0x644e00bb, 0x00000000}},  //   зват_, klık, anbi,
  { {0x26cc0211, 0x682d0051, 0x2284091b, 0x00000000}},  // [6890] ludo_, _húda, тург,
  { {0xe3c60055, 0x44270011, 0xa3d60309, 0x00000000}},  //   শ্বব, _ôn_, _हाय_,
  { {0x26cc0211, 0xd2510167, 0xfd100014, 0x00000000}},  //   nudo_, _مند_, یجه_,
  { {0x63b50091, 0xb425009e, 0x00000000, 0x00000000}},  //   lazn, _آٹھو,   ,
  { {0x343800a2, 0xeb990534, 0x61ed0048, 0x00000000}},  //   _رسید_, пил_, meal,
  { {0xeb990827, 0x60cd00e7, 0xdb03000c, 0x00000000}},  //   чик_, muam, manú,
  { {0x60cd00b0, 0x26cc04f3, 0x00000000, 0x00000000}},  //   luam, judo_,   ,
  { {0x61ed0122, 0x00000000, 0x00000000, 0x00000000}},  //   neal,   ,   ,
  { {0x63b50428, 0x60cd0555, 0xd825004d, 0x00000000}},  //   kazn, nuam, едпи,
  { {0x63b50305, 0x61ed0ba2, 0x699f007d, 0x00000000}},  //   jazn, heal, _ग्री,
  { {0x366a005e, 0x61ed2420, 0xadc30082, 0x00000000}},  //   зано_, keal, _hoằn,
  { {0x60cd26a4, 0xd5ed0082, 0x00000000, 0x00000000}},  //   kuam, _phá,   ,
  { {0x6faf0061, 0x68240173, 0x00000000, 0x00000000}},  //   टरां, _nòdw,   ,
  { {0x26cc00ca, 0x26c50618, 0xa922000c, 0x00000000}},  //   budo_, prlo_, _óþar,
  { {0x91e609da, 0x67d200ed, 0x26cc0b33, 0x00000000}},  //   нове, _соју, cudo_,
  { {0x61ed0e57, 0xd5ed0082, 0x68240173, 0x00000000}},  //   geal, _thá, _bòdw,
  { {0x60cd197d, 0x63b50091, 0x2bd2007d, 0x00000000}},  // [68a0] guam, bazn, सलमा,
  { {0x3c2b0637, 0x25dc006e, 0x682400f6, 0x00000000}},  //   _søvn_, ग्री_, _pòdi,
  { {0xdb08027b, 0xf09f01bc, 0x2bc90164, 0x00000000}},  //   _pedí, _età_, _राजा,
  { {0x76460a34, 0xe29b009b, 0x61ed26a5, 0x00000000}},  //   niky, _משטר, ceal,
  { {0x8c4600c0, 0xc3c90167, 0x60cd0026, 0x00000000}},  //   неде, _عظیم_, cuam,
  { {0xa7fc014a, 0x09c80061, 0x88bd0044, 0x00000000}},  //   rlık, ळल्य, _অহংক,
  { {0xb5fb0048, 0x00000000, 0x00000000, 0x00000000}},  //   slái,   ,   ,
  { {0x998d0036, 0x00000000, 0x00000000, 0x00000000}},  //   cież_,   ,   ,
  { {0x290226a6, 0x6824000a, 0x00000000, 0x00000000}},  //   íka_, _mòdv,   ,
  { {0x26cc0181, 0x81c90055, 0xdb06001a, 0x00000000}},  //   tudo_, ল্প_, ămân,
  { {0x63b500b9, 0x28c2013d, 0x00000000, 0x00000000}},  //   vazn, _शिवि,   ,
  { {0x26c20119, 0x0ae90025, 0x3e580173, 0x00000000}},  //   čko_, _تركي_, bčte_,
  { {0x61ed00ab, 0x28f8007c, 0x7a3e0006, 0x00000000}},  //   veal, _цель_, jūti,
  { {0x389b0097, 0x7e6200bb, 0xaad4013d, 0x00000000}},  //   _ציונ, hoop, _धमाक,
  { {0x63b50161, 0x61ed0035, 0x7e6200bb, 0x00000000}},  //   razn, teal, koop,
  { {0x60cd027b, 0xfd26001d, 0xa3d602d2, 0x00000000}},  //   tuam, _đình_, _हाथ_,
  { {0x61ed002d, 0x660d0020, 0x865c00b6, 0x00000000}},  // [68b0] real, _inak, _מדהי,
  { {0x61ed10fb, 0xc05801e1, 0x60cd26a7, 0x00000000}},  //   seal, ніх_, ruam,
  { {0xa3d6001c, 0x644701d5, 0x61ed26a8, 0x00000000}},  //   _हात_, miji, peal,
  { {0x644701d5, 0x09e00044, 0x7a3e008f, 0x00000000}},  //   liji, _মোসা, būti,
  { {0x60cd0026, 0x660d00e7, 0xdb0300ea, 0x00000000}},  //   quam, _mnak, lanø,
  { {0x64470f68, 0xb5fb00c4, 0xcb6900e2, 0x00000000}},  //   niji, cláv, мале_,
  { {0x660d0119, 0x00000000, 0x00000000, 0x00000000}},  //   _onak,   ,   ,
  { {0x68240129, 0x660d0dfc, 0x64470258, 0x00000000}},  //   _mòdu, _nnak, hiji,
  { {0x09e00055, 0x64470020, 0x0ec90061, 0x00000000}},  //   _মোহা, kiji, ांकड,
  { {0x660d0518, 0x64470020, 0x7c2a01a2, 0x00000000}},  //   _anak, jiji, ckfr,
  { {0xcf9200a0, 0x81c90044, 0x682400f6, 0x00000000}},  //   יטי_, ল্য_, _nòdu,
  { {0xeab00076, 0xddc2050f, 0x8be60044, 0x00000000}},  //   _طعم_, ološ, _গোপন_,
  { {0x9f58008d, 0x76460052, 0x00000000, 0x00000000}},  //   _parë_, riky,   ,
  { {0x660d26a9, 0x64a3007e, 0x2a6d0066, 0x00000000}},  //   _enak, рара, lleb_,
  { {0xc7d600b3, 0xfbd2009b, 0xb3d30061, 0x00000000}},  //   _יוסי_, יתם_, _तारख,
  { {0x05b60061, 0x29000006, 0xdb080142, 0x00000000}},  //   _अजिब, _šiai_, _jedá,
  { {0x7bc10119, 0x6447097f, 0x76440009, 0x00000000}},  // [68c0] _odlu, biji, _imiy,
  { {0x6447016c, 0x9f58008e, 0x70530025, 0x00000000}},  //   ciji, _haré_, لنقا,
  { {0x444408ba, 0x00000000, 0x00000000, 0x00000000}},  //   _im_,   ,   ,
  { {0x44440091, 0x471a0049, 0x78bb01c2, 0x00000000}},  //   _hm_, וועג, ksuv,
  { {0x7e620cfc, 0x9986016c, 0x9f43008e, 0x00000000}},  //   roop, _ološ_, _bajó_,
  { {0x4444006c, 0x9f430173, 0x8fa301ab, 0x00000000}},  //   _jm_, _objè_, _варе,
  { {0x7c2a000c, 0xdddc0066, 0x99d60a4f, 0x00000000}},  //   rkfr, _kurż, نتظا,
  { {0x64470066, 0xc986017f, 0xda09007d, 0x00000000}},  //   ziji, купи, वागत_,
  { {0x8e550088, 0x00000000, 0x00000000, 0x00000000}},  //   _стрі,   ,   ,
  { {0x6e200219, 0x660d01e3, 0x76440f65, 0x00000000}},  //   _homb, _snak, _amiy,
  { {0x6e20008d, 0x2a6d26aa, 0x64470091, 0x00000000}},  //   _komb, bleb_, viji,
  { {0x444426ab, 0x2911002a, 0x6e2004be, 0x00000000}},  //   _am_, ónaí_, _jomb,
  { {0x444426ac, 0xdd110180, 0xe1f3025a, 0x00000000}},  //   _bm_, _müşa, یسر_,
  { {0x6e2026ad, 0x2a64062a, 0xa5bb0036, 0x00000000}},  //   _lomb, lomb_, yków,
  { {0x644701d5, 0x44440129, 0x6e200343, 0x00000000}},  //   riji, _dm_, _oomb,
  { {0x444426ae, 0x6e2026af, 0x6447002b, 0x00000000}},  //   _em_, _nomb, siji,
  { {0x6447002b, 0x00000000, 0x00000000, 0x00000000}},  // [68d0] piji,   ,   ,
  { {0x2ca6103f, 0x7d020107, 0x26de0197, 0x00000000}},  //   dpod_, dvos, otto_,
  { {0x42550123, 0xdd910025, 0x26de0315, 0x00000000}},  //   _مندر, موا_, ntto_,
  { {0x13b80055, 0x44211449, 0x444418d5, 0x00000000}},  //   _জায়, _hoh_, _zm_,
  { {0x4444018e, 0x6e200687, 0x5187025f, 0x00000000}},  //   _ym_, _domb, _јуна,
  { {0x61fd0faa, 0x44210007, 0x27fc02cc, 0x00000000}},  //   _hasl, _joh_, _navn_,
  { {0xe8160183, 0x44211577, 0x2a6d006c, 0x00000000}},  //   ताना_, _moh_, tleb_,
  { {0xe8f90265, 0x61fd1c5d, 0x6e200010, 0x00000000}},  //   ели_, _jasl, _gomb,
  { {0xb5fb06b8, 0x61fd0213, 0x0e44008b, 0x00000000}},  //   hlás, _masl, _тэрм,
  { {0x44210013, 0x61fd01d6, 0x22490032, 0x00000000}},  //   _noh_, _lasl, hiak_,
  { {0x44440127, 0x2249022b, 0x6e200dfc, 0x00000000}},  //   _rm_, kiak_, _yomb,
  { {0x61fd01d9, 0x656d0922, 0xfbdf0061, 0x00000000}},  //   _nasl, _byah, प्रम,
  { {0x656d0009, 0x37e510f3, 0x7a3516de, 0x00000000}},  //   _cyah, _болг, _cáte,
  { {0xb744026c, 0x656d26b0, 0xdb0101e3, 0x00000000}},  //   ائیو, _dyah, _belø,
  { {0x44440193, 0x44210145, 0x61fd014a, 0x00000000}},  //   _vm_, _doh_, _basl,
  { {0x2249022b, 0x4444010f, 0x443300d4, 0x00000000}},  //   giak_, _wm_, _elx_,
  { {0x44440011, 0x6e2004cb, 0xb5fb0010, 0x00000000}},  // [68e0] _tm_, _romb, rlát,
  { {0x444426b1, 0x44210397, 0xb5fb26b2, 0x00000000}},  //   _um_, _goh_, slát,
  { {0x0dca0057, 0xa565025a, 0x61fd0093, 0x00000000}},  //   елей_, _مدین, _fasl,
  { {0xed5a0057, 0x7e7b0325, 0xe1f201f7, 0x00000000}},  //   ное_, _chup, _اسد_,
  { {0x61e403f1, 0x442100e7, 0xadb703ec, 0x00000000}},  //   mfil, _yoh_, اهها_,
  { {0x7d020010, 0x7c2126b3, 0x70560025, 0x00000000}},  //   rvos, _colr, _إنسا,
  { {0x78a21af5, 0xd6ae0055, 0x05d4001c, 0x00000000}},  //   _stov, _কম্প, _थांब,
  { {0x48aa17da, 0x290600d4, 0xdb180023, 0x00000000}},  //   нтом_, _proa_, lavë,
  { {0x38340517, 0x7c2100d4, 0x88bd00b4, 0x00000000}},  //   инир, _folr, byśm,
  { {0x2249022b, 0xe45f0039, 0x26de0026, 0x00000000}},  //   ziak_, tröm_, ttto_,
  { {0x9b930054, 0xab930054, 0x442101a3, 0x00000000}},  //   _المت, _المغ, _roh_,
  { {0x7a3500b9, 0x1a9b0049, 0x212900ef, 0x00000000}},  //   _páte, _נידע, yyah_,
  { {0x44210487, 0x78a20056, 0x3495094b, 0x00000000}},  //   _poh_, _utov, рагр,
  { {0xb4e503d7, 0x61e40b38, 0x224900b4, 0x00000000}},  //   _नही_, efil, wiak_,
  { {0x61fd010a, 0x0cd102d2, 0x629800f4, 0x00000000}},  //   _pasl, _सम्म, _évol,
  { {0x533401be, 0x44210487, 0xb5fb0010, 0x00000000}},  //   щест, _woh_, rlás,
  { {0x7bda16ca, 0x2249022b, 0x44210b9a, 0x00000000}},  // [68f0] _octu, riak_, _toh_,
  { {0x7e690007, 0xf1bf002a, 0x661d0f3a, 0x00000000}},  //   _skep, _clár_, ljsk,
  { {0xaca30011, 0x212904be, 0x8db501e1, 0x00000000}},  //   _trịn, syah_, аслі,
  { {0x661d1034, 0x61fd0051, 0x7c21032e, 0x00000000}},  //   njsk, _uasl, _solr,
  { {0xddc20046, 0x7c2126b4, 0xb21b0190, 0x00000000}},  //   lnoś, _polr, _diæt,
  { {0x60cd00d2, 0x00000000, 0x00000000, 0x00000000}},  //   mram,   ,   ,
  { {0xf9910054, 0x2cbd0c6a, 0x628f016c, 0x00000000}},  //   يبة_, sswd_, _kico,
  { {0x60cd0207, 0x645501a2, 0x7c2101c3, 0x00000000}},  //   oram, hnzi, _wolr,
  { {0x26cc0211, 0xa3d602d2, 0x629726b5, 0x00000000}},  //   erdo_, _हाल_, _luxo,
  { {0x3a2d0007, 0xaae70379, 0xd709007c, 0x00000000}},  //   skep_, _مسؤو, вное_,
  { {0x2bab001c, 0x60cd014a, 0x7d09000c, 0x00000000}},  //   _घ्या, hram, _hres,
  { {0x628f0a86, 0x7d090142, 0xddc20036, 0x00000000}},  //   _nico, _kres, dnoś,
  { {0x26cc0851, 0x60cd0065, 0x99830006, 0x00000000}},  //   ardo_, jram, ėjų_,
  { {0x61e40009, 0x7d090066, 0x96950b81, 0x00000000}},  //   wfil, _mres, _криш,
  { {0x61e426b6, 0x628f08eb, 0x41b602b8, 0x00000000}},  //   tfil, _bico, исат,
  { {0x60cd009f, 0x20110282, 0x98a20006, 0x00000000}},  //   fram, _anzi_, šką_,
  { {0x60cd26b7, 0x628f26ad, 0xdb030428, 0x00000000}},  // [6900] gram, _dico, vaný,
  { {0x61e4003a, 0xf09f0011, 0x628f005b, 0x00000000}},  //   sfil, _tràn_, _eico,
  { {0x91e60f40, 0x628f26b8, 0x60cd26b9, 0x00000000}},  //   _коне, _fico, aram,
  { {0x7d0903c5, 0x60cd041e, 0x20110020, 0x00000000}},  //   _bres, bram, _enzi_,
  { {0x7d0924bb, 0x7bda26ba, 0x6284044e, 0x00000000}},  //   _cres, _pctu, mmio,
  { {0x63bc020c, 0x7d091510, 0x628f0ed9, 0x00000000}},  //   narn, _dres, _zico,
  { {0x7d091067, 0x661d0036, 0x62840052, 0x00000000}},  //   _eres, yjsk, omio,
  { {0x628f00d4, 0x2bd20164, 0x63bc068d, 0x00000000}},  //   _xico, _साका, harn,
  { {0x7d0926bb, 0xdca3003b, 0xa3d626bc, 0x00000000}},  //   _gres, _мати, _हां_,
  { {0x63bc26bd, 0x29000006, 0x69a6007d, 0x00000000}},  //   jarn, _šias_, _ट्री,
  { {0x63bc1c95, 0xeb970088, 0xcfcc0044, 0x00000000}},  //   darn, _тих_, র্থন,
  { {0x60cd038c, 0xc9861023, 0xa7fc01df, 0x00000000}},  //   yram, _кули, tlıs,
  { {0x628f0198, 0x7af8001c, 0x62840046, 0x00000000}},  //   _rico, lwvt, dmio,
  { {0x63bc0203, 0xddc20046, 0xcfcc0055, 0x00000000}},  //   garn, tnoś, র্তন,
  { {0xe1ff00f6, 0x76560010, 0xdb0300f6, 0x00000000}},  //   _paó_, ógyá, lanò,
  { {0x60cd0207, 0x95cb003b, 0xddc20036, 0x00000000}},  //   tram, _рука_, rnoś,
  { {0x51871b67, 0x63b7005f, 0x628f0197, 0x00000000}},  // [6910] рува, _texn, _vico,
  { {0x60cd0682, 0x7d090065, 0x25e3007d, 0x00000000}},  //   rram, _rres, ट्री_,
  { {0x60cd00d0, 0x628f26be, 0xf09f0011, 0x00000000}},  //   sram, _tico, _trào_,
  { {0x60cd26bf, 0x7a3c0010, 0x9f5800f6, 0x00000000}},  //   pram, _hétf, _garí_,
  { {0xaca3001d, 0x60cd005f, 0x787d009d, 0x00000000}},  //   _trọn, qram, lève,
  { {0x7d0901b5, 0x3e7c0802, 0x8c6702ea, 0x00000000}},  //   _vres, víte_, штед,
  { {0xad9d0036, 0x7d09077a, 0x3c390173, 0x00000000}},  //   _paźd, _wres, _nève_,
  { {0x61e90004, 0xa7fc006b, 0x7d0905a9, 0x00000000}},  //   _öeld, dlıq, _tres,
  { {0x7d090059, 0x7a2e0009, 0x63bc008a, 0x00000000}},  //   _ures, _mùth, yarn,
  { {0xfc330647, 0x684507d0, 0x7a3526c0, 0x00000000}},  //   _بحر_, ённа, _dáta,
  { {0x63bc0119, 0x78a9221d, 0x3e7c0161, 0x00000000}},  //   varn, spev, síte_,
  { {0x80ad0055, 0xb9950025, 0x63bc0169, 0x00000000}},  //   _চিন্, _الإب, warn,
  { {0x63bc0209, 0x682d1a34, 0x99850025, 0x00000000}},  //   tarn, _lúdi, _الشو,
  { {0x03a326c1, 0x00000000, 0x00000000, 0x00000000}},  //   зиро,   ,   ,
  { {0x63bc0332, 0xf48600a1, 0x044308d6, 0x00000000}},  //   rarn, لاڑی, черн,
  { {0x63bc26c2, 0x984f006b, 0x00000000, 0x00000000}},  //   sarn, _işıq_,   ,
  { {0xdb1802d5, 0x63bc016e, 0x7a2e0009, 0x00000000}},  // [6920] ravé, parn, _dùth,
  { {0xdb010010, 0x95880036, 0x3ae10010, 0x00000000}},  //   _belü, _ciąż, kóp_,
  { {0xd9f9001c, 0x644e26c3, 0x93fb007b, 0x00000000}},  //   ्यात_, mibi, _גליי,
  { {0x0d86004c, 0x644e1c39, 0x6d03006e, 0x00000000}},  //   блен, libi, लिंग_,
  { {0xa7fc013f, 0x00000000, 0x00000000, 0x00000000}},  //   zlıq,   ,   ,
  { {0x644e0198, 0x6fd501fb, 0xdb010010, 0x00000000}},  //   nibi, _місц, _felü,
  { {0x7bd80250, 0xa3d6013d, 0x00000000, 0x00000000}},  //   rgvu, _हाई_,   ,
  { {0x3ea70051, 0x61f6019a, 0x648000b0, 0x00000000}},  //   ínte_, neyl, löid,
  { {0x261c0164, 0x644e0095, 0x2be00316, 0x00000000}},  //   यानी_, kibi, _नापा,
  { {0x644e0020, 0x74230044, 0xdb010036, 0x00000000}},  //   jibi, _নষ্ট_, _celó,
  { {0xb05b0039, 0x7bc80066, 0x00000000, 0x00000000}},  //   _ovän, _iddu,   ,
  { {0xa7fc006b, 0x98c40095, 0x00000000, 0x00000000}},  //   rlıq, ştık_,   ,
  { {0x644e0885, 0xda65006d, 0x9f5800d4, 0x00000000}},  //   fibi, _بالي, _larà_,
  { {0x3a260100, 0x644e26c4, 0x648000b0, 0x00000000}},  //   _hoop_, gibi, jöid,
  { {0x3a26049b, 0xcfde0044, 0x2be001f5, 0x00000000}},  //   _koop_, ড়ান, _नाना,
  { {0x3a2600bb, 0x7a35134d, 0x926b007c, 0x00000000}},  //   _joop_, _látn, урга_,
  { {0x644e011c, 0x320700b9, 0xf09f0082, 0x00000000}},  // [6930] bibi, ěny_, _tràm_,
  { {0x644e0219, 0x764f092c, 0x3a2626c5, 0x00000000}},  //   cibi, licy, _loop_,
  { {0xe7ea001c, 0xa19500ed, 0x3ea701b5, 0x00000000}},  //   ज्या_, _манч, ënt_,
  { {0x25e103d7, 0x7bc80016, 0xf1c301d5, 0x00000000}},  //   _काफी_, _addu, _diġà_,
  { {0x6fb50025, 0x9c7d000a, 0x00000000, 0x00000000}},  //   _ومحا, _opōt,   ,
  { {0x9f5801e8, 0x9f4a00f6, 0x00000000, 0x00000000}},  //   _farà_, _cabó_,   ,
  { {0xdb010181, 0x9e35007c, 0xa6fa0044, 0x00000000}},  //   _reló, _девч, ইমুম_,
  { {0xed15026c, 0x644e001a, 0x200304cb, 0x00000000}},  //   _وہاں_, zibi, _haji_,
  { {0x3a2607a5, 0x200321e6, 0x644e0101, 0x00000000}},  //   _doop_, _kaji_, yibi,
  { {0x20030020, 0x9f580211, 0x752f0036, 0x00000000}},  //   _jaji_, _hará_, dycz,
  { {0x2003000b, 0x869900ed, 0x644e0197, 0x00000000}},  //   _maji_, јтот_, vibi,
  { {0x366a003b, 0x29180048, 0x3a260203, 0x00000000}},  //   рамо_, ófaí_, _goop_,
  { {0xf77300a6, 0xdb011819, 0x2be0007d, 0x00000000}},  //   _کاش_, _teló, _नामा,
  { {0x69db06c0, 0xb05b0039, 0x20030087, 0x00000000}},  //   lgue, _svän, _naji_,
  { {0x644e1333, 0xe8160309, 0x09e00044, 0x00000000}},  //   ribi, तारा_, _মোটা,
  { {0x644e049a, 0x69db00f4, 0x3ebe009f, 0x00000000}},  //   sibi, ngue, _ætti_,
  { {0x9f580198, 0x7a3503b5, 0x80a60014, 0x00000000}},  // [6940] _sarà_, _láto, زمان,
  { {0x660403ef, 0x9f5816a3, 0x644e013f, 0x00000000}},  //   _haik, _parà_, qibi,
  { {0x66040f3c, 0x320201c8, 0x20070181, 0x00000000}},  //   _kaik, _taky_, ônia_,
  { {0x0caa0081, 0x66040032, 0x9f4a26c6, 0x00000000}},  //   атки_, _jaik, _babò_,
  { {0x6604011c, 0xb05b0073, 0x9f580b33, 0x00000000}},  //   _maik, _kväl, _dará_,
  { {0x66040ebc, 0x2003027e, 0x7a3c0010, 0x00000000}},  //   _laik, _gaji_, _méte,
  { {0x752f0046, 0x443a002b, 0x9f580181, 0x00000000}},  //   zycz, _mlp_, _fará_,
  { {0x1cba0b03, 0x66040728, 0x443a1904, 0x00000000}},  //   _نائب_, _naik, _llp_,
  { {0x60c40110, 0xe8160204, 0x00000000, 0x00000000}},  //   nsim, ताला_,   ,
  { {0x443a21b3, 0xdb1a008d, 0x59dc0061, 0x00000000}},  //   _nlp_, _jetë, _यावर,
  { {0x09e60057, 0x907b012f, 0x6fdd0061, 0x00000000}},  //   _можн, שטיי, _पासू,
  { {0x752f0046, 0xdb1a0065, 0x09b40044, 0x00000000}},  //   tycz, _letë, _টাকা,
  { {0x66040006, 0x08fa035b, 0x3ce60cce, 0x00000000}},  //   _daik, _خراب_, ntov_,
  { {0x7a3c00f4, 0x752f0046, 0xdb080030, 0x00000000}},  //   _déte, rycz, _bedø,
  { {0x7c280161, 0x43940057, 0x95cb0726, 0x00000000}},  //   _modr, дарс, _купа_,
  { {0xdb1811ea, 0x6fdd0061, 0x7c281beb, 0x00000000}},  //   javí, _पाहू, _lodr,
  { {0x7c3a0198, 0xdb180211, 0xcf9b012b, 0x00000000}},  // [6950] _oltr, daví, аје_,
  { {0x69c010c3, 0x7c28001e, 0x38a00009, 0x00000000}},  //   hame, _nodr, _mòr_,
  { {0x09e00055, 0x69c002c0, 0x9f580181, 0x00000000}},  //   _মোছা, kame, _pará_,
  { {0x7c3a108c, 0x69c00181, 0x6e220047, 0x00000000}},  //   _altr, jame, gjob,
  { {0x7c28014a, 0x43d402fd, 0x60c40232, 0x00000000}},  //   _bodr, _عزیز, csim,
  { {0xb09a009b, 0x7c28001a, 0x69c026c7, 0x00000000}},  //   _לישר, _codr, eame,
  { {0x69c020db, 0x7c2826c8, 0xdb1a000a, 0x00000000}},  //   fame, _dodr, _jetè,
  { {0x69c0220a, 0x6e220061, 0x69db13f6, 0x00000000}},  //   game, cjob, ugue,
  { {0x69db029a, 0xe8e00011, 0x66040052, 0x00000000}},  //   rgue, _đợi_, _raik,
  { {0x66040089, 0x7c28005b, 0x764d04f3, 0x00000000}},  //   _saik, _godr, _amay,
  { {0x6604021e, 0x69c00181, 0xdb230014, 0x00000000}},  //   _paik, bame, _توضی,
  { {0x7a3c0010, 0x7c2800b5, 0x443a0020, 0x00000000}},  //   _péte, _zodr, _slp_,
  { {0x660426c9, 0x4a44007e, 0x88de0044, 0x00000000}},  //   _vaik, _ўнів, _বৈঠক,
  { {0xdb1a01aa, 0x7a3c0010, 0x60c426ca, 0x00000000}},  //   _betè, _véte, vsim,
  { {0x66040f38, 0x6e3b26cb, 0x63830517, 0x00000000}},  //   _taik, _olub, егра,
  { {0xdb1a01aa, 0x60c4006c, 0x7a3c0010, 0x00000000}},  //   _detè, tsim, _téte,
  { {0xf1bf001d, 0x60c4010a, 0xb146026b, 0x00000000}},  // [6960] _toán_, usim, чнал,
  { {0x88bd0055, 0x61ef0009, 0x443a0022, 0x00000000}},  //   _আমাক, _ebcl, _ulp_,
  { {0x60c40198, 0xdb1a008d, 0x7c28029d, 0x00000000}},  //   ssim, _vetë, _rodr,
  { {0x6e3b02d5, 0x69c00a5e, 0x7c2826cc, 0x00000000}},  //   _club, xame, _sodr,
  { {0x60c4002b, 0x6e2200f8, 0x200c00c4, 0x00000000}},  //   qsim, rjob, _ódio_,
  { {0x629e0a6e, 0x68e4021e, 0x26c50006, 0x00000000}},  //   _kupo, _äidi, kslo_,
  { {0xd9f90183, 0x3ce60cce, 0x645c01a2, 0x00000000}},  //   ्यंत_, stov_, inri,
  { {0xaf5b009b, 0x5fe20061, 0x629e0085, 0x00000000}},  //   _הכלכ, _पाडल, _mupo,
  { {0xfe450167, 0xa3dd013d, 0x98a40006, 0x00000000}},  //   _تکلی, _डाल_, kymą_,
  { {0x4734058f, 0x7c3a0472, 0x787d01aa, 0x00000000}},  //   днос, _ultr, tèva,
  { {0x69c004bd, 0x290f1824, 0x98a40006, 0x00000000}},  //   pame, _erga_, dymą_,
  { {0x6b7b01ce, 0x0f5700b6, 0x3ebe000c, 0x00000000}},  //   _פראנ, ליים_, _ættu_,
  { {0xed590f3a, 0x787d01aa, 0xab630036, 0x00000000}},  //   _teže_, sèva, ężen,
  { {0xdb1a01aa, 0x00000000, 0x00000000, 0x00000000}},  //   _petè,   ,   ,
  { {0x63be0022, 0xdb1a0010, 0x00000000, 0x00000000}},  //   _depn, _beté,   ,
  { {0x629e009d, 0x764d0058, 0xeb3b0049, 0x00000000}},  //   _dupo, _umay, זעלש,
  { {0x236d0036, 0x6e290ace, 0xa3d60061, 0x00000000}},  // [6970] łej_, _roeb, _हाच_,
  { {0x638701cc, 0x6e2926cd, 0x25a90085, 0x00000000}},  //   géné, _soeb, _hfal_,
  { {0x02a4041f, 0xbf150025, 0x00000000, 0x00000000}},  //   _прям, بواب,   ,
  { {0xdd910426, 0x765d06d7, 0x20180617, 0x00000000}},  //   نوا_, nnsy, _enri_,
  { {0xdb010010, 0xfce50131, 0xb114007e, 0x00000000}},  //   _jelö, фоло, _змяш,
  { {0x320926ce, 0x61ed010f, 0x00000000, 0x00000000}},  //   lday_, lfal,   ,
  { {0x6e2901b5, 0x25a90016, 0x00000000, 0x00000000}},  //   _toeb, _ofal_,   ,
  { {0x61ed26cf, 0x6e3b0036, 0x320900ab, 0x00000000}},  //   nfal, _ulub, nday_,
  { {0xa3dd0204, 0x3dcd000a, 0xb5fb07fd, 0x00000000}},  //   डला_, _idew_, bláz,
  { {0x3a3f00ea, 0x320900ab, 0xb5fb008e, 0x00000000}},  //   shup_, hday_, zoát,
  { {0xfe7000a1, 0xf771083e, 0xe3e30044, 0x00000000}},  //   _شدہ_, ضاد_, য়াব,
  { {0xddc2167a, 0x7bc30e34, 0x26c5010a, 0x00000000}},  //   zlož, lanu, rslo_,
  { {0x629e04bd, 0x29030089, 0x61ed00eb, 0x00000000}},  //   _supo, ājas_, dfal,
  { {0x261c0164, 0xe29a26d0, 0x765d0093, 0x00000000}},  //   याही_, жав_, ansy,
  { {0xa2e30d68, 0x81e60044, 0x68e90190, 0x00000000}},  //   корд, _যোগ_, lted,
  { {0x7bc3010e, 0x11da0025, 0x00000000, 0x00000000}},  //   hanu, تورة_,   ,
  { {0x68e90030, 0xf77801d5, 0xdb01010f, 0x00000000}},  // [6980] nted, mgħa_, _gelö,
  { {0x7a3c00f4, 0x261c0204, 0x7bc326d1, 0x00000000}},  //   _méta, यावी_, janu,
  { {0x441b007b, 0x141b007b, 0x7bc3017b, 0x00000000}},  //   _וויס, _וויב, danu,
  { {0x68e9011f, 0xddc226d2, 0x00000000, 0x00000000}},  //   kted, slož,   ,
  { {0x7bc30020, 0x25e3007d, 0x8c46011e, 0x00000000}},  //   fanu, ट्टी_, меде,
  { {0x7bc326d3, 0x2ca926d4, 0x3dcd0173, 0x00000000}},  //   ganu, íada_, _edew_,
  { {0x5f030072, 0xddc601f9, 0x26ca01d5, 0x00000000}},  //   _изра, _обви, ġbok_,
  { {0x2be00183, 0x68e90637, 0x7a3c1152, 0x00000000}},  //   _नावा, fted, _béta,
  { {0x6b9a001c, 0x7bc309e7, 0xf967007e, 0x00000000}},  //   _tgtg, banu, дрэй_,
  { {0x25e10365, 0x7a3c028c, 0x7a3526d5, 0x00000000}},  //   _काही_, _déta, _láth,
  { {0x61ed014a, 0x7fd70097, 0x00000000, 0x00000000}},  //   yfal, וויס_,   ,
  { {0xa4d501ff, 0x68e926d6, 0x00000000, 0x00000000}},  //   номі, bted,   ,
  { {0x68e90857, 0x765d01e3, 0x61ed26d7, 0x00000000}},  //   cted, rnsy, vfal,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61ed00db, 0x25a901d5, 0x261c0061, 0x00000000}},  //   tfal, _tfal_, याशी_,
  { {0xc7ad00a1, 0xf09f0026, 0x7bc30035, 0x00000000}},  //   _پڑی_, _puà_, zanu,
  { {0xf09f001d, 0x320900ab, 0x261c006e, 0x00000000}},  // [6990] _quà_, rday_, यारी_,
  { {0x47d00044, 0x61ed010f, 0x443800ab, 0x00000000}},  //   ত্রী, sfal, ckr_,
  { {0x6455038c, 0x47c30055, 0x2cad01e3, 0x00000000}},  //   mizi, _শামী, _sted_,
  { {0x200700ee, 0x7bc300e7, 0x648b002b, 0x00000000}},  //   žni_, wanu, _gżir,
  { {0x7bc30ac2, 0x4fc70aed, 0x628d00d9, 0x00000000}},  //   tanu, _осва, mmao,
  { {0x09c70061, 0x629800c4, 0x7a3c009d, 0x00000000}},  //   ळण्य, _évor, _réta,
  { {0x7bc31e81, 0x2be00309, 0xdab9007e, 0x00000000}},  //   ranu, _नारा, чылі_,
  { {0x68e901e3, 0x6455001a, 0x7bc3006c, 0x00000000}},  //   tted, hizi, sanu,
  { {0xe8f60a78, 0x2d58007c, 0x7bc30503, 0x00000000}},  //   елы_, _жить_, panu,
  { {0x68e926d8, 0x6455016c, 0x9bf4007c, 0x00000000}},  //   rted, jizi, _изуч,
  { {0x645526d9, 0x7a35000c, 0xa7fc026d, 0x00000000}},  //   dizi, _láti, nlıy,
  { {0xdd12014a, 0x7a3c0068, 0x00000000, 0x00000000}},  //   nüşt, _téta,   ,
  { {0x6455001f, 0x7bc1020c, 0x7a3507da, 0x00000000}},  //   fizi, _kelu, _ráth,
  { {0x6286008d, 0xd8d60049, 0x7bc126da, 0x00000000}},  //   _shko, _נוצט_, _jelu,
  { {0x7bc104cb, 0x00000000, 0x00000000, 0x00000000}},  //   _melu,   ,   ,
  { {0x7bc116fe, 0x60d626db, 0xf778002b, 0x00000000}},  //   _lelu, trym, qgħa_,
  { {0xe0da26dc, 0x645526dd, 0xe8140164, 0x00000000}},  // [69a0] ява_, bizi, _थोडा_,
  { {0x6455001a, 0x3fe300e2, 0x00000000, 0x00000000}},  //   cizi, лжув,   ,
  { {0x7a350051, 0xa49b0173, 0x671f007d, 0x00000000}},  //   _táth, pwòc, यमिक_,
  { {0x4d66007e, 0x7a3516b5, 0x5fe20061, 0x00000000}},  //   нкев, _fáti, _पावल,
  { {0x7bc10149, 0x629800f4, 0x00000000, 0x00000000}},  //   _belu, _évoq,   ,
  { {0xdee60175, 0x9f580048, 0x6aa10d28, 0x00000000}},  //   _поги, _marú_, _bulf,
  { {0x7bc10059, 0x3e7501c9, 0x61ef0051, 0x00000000}},  //   _delu, tått_, _éilí,
  { {0x3f7b0049, 0x6aa100f6, 0x249a0022, 0x00000000}},  //   _זאלס, _dulf, _lipm_,
  { {0x0d86012b, 0x7bc126de, 0xfe1d0061, 0x00000000}},  //   _члан, _felu, फारस_,
  { {0x7bc10100, 0x6aa10133, 0x200a0032, 0x00000000}},  //   _gelu, _fulf, _jabi_,
  { {0x6aa100ea, 0x8ad603ab, 0x998d0087, 0x00000000}},  //   _gulf, _ستائ, rkeš_,
  { {0x200a13e6, 0x7bc1002d, 0x25e10061, 0x00000000}},  //   _labi_, _zelu, _काळी_,
  { {0x64550198, 0xda6f00a1, 0x6aa10085, 0x00000000}},  //   tizi, _اُن_, _zulf,
  { {0x200a04cb, 0xd49800ed, 0x61e6098e, 0x00000000}},  //   _nabi_, ерс_, _ackl,
  { {0x64550198, 0x7a3500fa, 0x27fe00ca, 0x00000000}},  //   rizi, _sáti, metn_,
  { {0x64550198, 0x7a3c0489, 0xa3dd013d, 0x00000000}},  //   sizi, _méto, _डाक_,
  { {0x26de26df, 0x200a01a3, 0x628d26e0, 0x00000000}},  // [69b0] luto_, _babi_, rmao,
  { {0xd25106c6, 0x78a20625, 0xb88100b9, 0x00000000}},  //   _چند_, _muov, _říze,
  { {0x26de0198, 0x7bc1001a, 0x78a200b0, 0x00000000}},  //   nuto_, _relu, _luov,
  { {0x7bc10149, 0x2906002d, 0x69c200f6, 0x00000000}},  //   _selu, _osoa_, _neoe,
  { {0x78a20198, 0x7bc1020c, 0x6aa10133, 0x00000000}},  //   _nuov, _pelu, _sulf,
  { {0x2ef506e1, 0x200a006a, 0x8d740084, 0x00000000}},  //   _изгр, _gabi_, داما,
  { {0x7bc102d8, 0x48bd0044, 0xcb660a94, 0x00000000}},  //   _velu, _আমের, каше_,
  { {0x26de26e1, 0x7a3c00f4, 0x7a350010, 0x00000000}},  //   duto_, _déto, _látv,
  { {0x7bc10281, 0xf86500ed, 0x9815025a, 0x00000000}},  //   _telu, квио, نبدا,
  { {0xe73901be, 0x5d540256, 0x3ea30065, 0x00000000}},  //   део_, _скут, _kujt_,
  { {0x366a0088, 0x41e1013d, 0xdbf900b4, 0x00000000}},  //   дано_, _फांस, _włók,
  { {0x69c201d6, 0x61ff0045, 0xe7360152, 0x00000000}},  //   _geoe, jeql, тею_,
  { {0x26de003c, 0xda1e013d, 0xa3dd0061, 0x00000000}},  //   auto_, भारत_, डलं_,
  { {0x9879007b, 0x26de0207, 0xa8790049, 0x00000000}},  //   _קאַט, buto_, _קאַר,
  { {0x200a12cc, 0x00000000, 0x00000000, 0x00000000}},  //   _rabi_,   ,   ,
  { {0x200a006a, 0xb5fb013e, 0x00000000, 0x00000000}},  //   _sabi_, rnác,   ,
  { {0x21a309de, 0x2fc30066, 0xdb1a00fa, 0x00000000}},  // [69c0] риум, _bejg_, _retí,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x03d701ce, 0x200a00ca, 0x036a0745, 0x00000000}},  //   _בוים_, _vabi_, _цинк_,
  { {0xee3a0451, 0xed5a007c, 0x200a05d2, 0x00000000}},  //   ьне_, мое_, _wabi_,
  { {0x200a1aa0, 0x5ce3007c, 0x442502fd, 0x00000000}},  //   _tabi_, ающа, _شریف,
  { {0x61e4011f, 0x5c730245, 0x8fa600ed, 0x00000000}},  //   lgil, аліт, _јаве,
  { {0x7a3505ee, 0xf1bf0082, 0x00000000, 0x00000000}},  //   _látu, _soái_,   ,
  { {0x61e4022b, 0x26de0207, 0xab5c0089, 0x00000000}},  //   ngil, vuto_, _ceļa,
  { {0x6c06003b, 0xdca61867, 0x2d840091, 0x00000000}},  //   _изаз, _рази, _uzme_,
  { {0x7a3c01e6, 0x00000000, 0x00000000, 0x00000000}},  //   _této,   ,   ,
  { {0xc0150049, 0x7e62055f, 0xdb010190, 0x00000000}},  //   אַרק_, onop, _aflæ,
  { {0xd00b0055, 0x25a00197, 0xf1e1013d, 0x00000000}},  //   রায়_, _cgil_, _फाइन,
  { {0x0fe20061, 0xdb18010e, 0x3e7c0010, 0x00000000}},  //   _पांढ, savä, gíti_,
  { {0x26de0207, 0x7a351b6d, 0x7e62003b, 0x00000000}},  //   puto_, _dátu, hnop,
  { {0x7e620168, 0x82a401fc, 0xe81f006e, 0x00000000}},  //   knop, иште, बारा_,
  { {0x454500a1, 0x53341e03, 0x61e4000c, 0x00000000}},  //   _منعق, шест, ggil,
  { {0x7e620253, 0xf5990088, 0xed590087, 0x00000000}},  // [69d0] dnop, _явищ_, _režo_,
  { {0x1621001c, 0x7a350092, 0x660d0cc0, 0x00000000}},  //   यावर_, _hátt, _haak,
  { {0x5335007c, 0x660d0dc7, 0x320b00b4, 0x00000000}},  //   _сент, _kaak, _tacy_,
  { {0x660d00b0, 0x2ca40093, 0x61e426e2, 0x00000000}},  //   _jaak, _bumd_, cgil,
  { {0x660d26e3, 0x7a35000c, 0x00000000, 0x00000000}},  //   _maak, _mátt,   ,
  { {0x7a35134d, 0x60cd010e, 0x660d00b0, 0x00000000}},  //   _látt, msam, _laak,
  { {0x629d00b0, 0xadbd0451, 0xed5900ca, 0x00000000}},  //   _kiso, _навi, _težo_,
  { {0x7a35009f, 0x660d00bb, 0x60cd1862, 0x00000000}},  //   _nátt, _naak, osam,
  { {0x3d9401fb, 0x629d0544, 0x68e026e4, 0x00000000}},  //   _витр, _miso, gumd,
  { {0x7b0800b0, 0x7d09006c, 0x629d0253, 0x00000000}},  //   ästä, _ises, _liso,
  { {0x660d26e5, 0x2bc800e2, 0xe73902dc, 0x00000000}},  //   _baak, _шуто_, хен_,
  { {0x20cf001e, 0x629d00b9, 0x2446009d, 0x00000000}},  //   kļi_, _niso, _môme_,
  { {0x7d090061, 0x61e4005a, 0x00000000, 0x00000000}},  //   _jses, vgil,   ,
  { {0x60cd05d5, 0x66e50930, 0x629d0943, 0x00000000}},  //   dsam, _бока, _aiso,
  { {0x629d26e6, 0x61e400f8, 0x3e7c0010, 0x00000000}},  //   _biso, tgil, síti_,
  { {0x96950a78, 0x00000000, 0x00000000, 0x00000000}},  //   _крыш,   ,   ,
  { {0x7644000b, 0x629d2179, 0x7e62041a, 0x00000000}},  // [69e0] _iliy, _diso, vnop,
  { {0x629d0016, 0x84060088, 0x660d0ae7, 0x00000000}},  //   _eiso, _спож, _zaak,
  { {0x4444054f, 0x7d0926e7, 0x2a7f26e8, 0x00000000}},  //   _il_, _ases, klub_,
  { {0x444401ca, 0x5d6a0057, 0x60cd26e9, 0x00000000}},  //   _hl_, нием_, bsam,
  { {0x444402d8, 0x7e6200ea, 0x5fe20061, 0x00000000}},  //   _kl_, rnop, _पाऊल,
  { {0x4444023a, 0x7e620052, 0x6a7e0023, 0x00000000}},  //   _jl_, snop, mëfi,
  { {0xb5fb0f49, 0xa3d50061, 0xa0671867, 0x00000000}},  //   dnán, हणत_, _сара_,
  { {0x5a3405b5, 0x44440038, 0xdd080027, 0x00000000}},  //   рнит, _ll_, môže,
  { {0x4444049d, 0x8cdb0164, 0xb05b0039, 0x00000000}},  //   _ol_, _नियो, _tvät,
  { {0x444402ae, 0x7644000b, 0x68e001f6, 0x00000000}},  //   _nl_, _aliy, rumd,
  { {0x76440263, 0x7bca0f18, 0x00000000, 0x00000000}},  //   _bliy, mafu,   ,
  { {0x2a7f0142, 0xdb080039, 0xd6d7007c, 0x00000000}},  //   club_, _bedö, ыть_,
  { {0x444401d5, 0xb4c1001c, 0x629d0198, 0x00000000}},  //   _bl_, ुळे_, _riso,
  { {0x7bca000b, 0x44440211, 0x660d26ea, 0x00000000}},  //   nafu, _cl_, _waak,
  { {0x444404bd, 0x629d029a, 0x4395138c, 0x00000000}},  //   _dl_, _piso, равс,
  { {0x4444095e, 0xf1270057, 0x60cd0056, 0x00000000}},  //   _el_, льзо, tsam,
  { {0x629d010a, 0xd49b0805, 0x44440f68, 0x00000000}},  // [69f0] _viso, _про_, _fl_,
  { {0x60cd020c, 0x7bca00e7, 0x00000000, 0x00000000}},  //   rsam, jafu,   ,
  { {0x629d1a2d, 0x200100ca, 0x442126eb, 0x00000000}},  //   _tiso, rehi_, _inh_,
  { {0x60cd014a, 0x44440036, 0xb5fb0f49, 0x00000000}},  //   psam, _zl_, znán,
  { {0x1d0909da, 0xb05b00f8, 0x644b007f, 0x00000000}},  //   тели_, _dvär, _įgij,
  { {0xab5c001e, 0xe29f000c, 0x787d01aa, 0x00000000}},  //   _ceļo, _hið_, pèvi,
  { {0xb5fb00b9, 0x443300d2, 0x44211a58, 0x00000000}},  //   vnán, _mox_, _mnh_,
  { {0x4df90049, 0x6e2b0045, 0x44210068, 0x00000000}},  //   _שפּא, qjgb, _lnh_,
  { {0x7a3c00f4, 0xe29f000c, 0x7d090087, 0x00000000}},  //   _méth, _mið_, _uses,
  { {0x443302a9, 0xe29f000c, 0x7bca0087, 0x00000000}},  //   _nox_, _lið_, cafu,
  { {0x4444013f, 0xb5fb0211, 0xf6260816, 0x00000000}},  //   _rl_, rnán, адно,
  { {0x442100ad, 0x7ae3006a, 0x64450020, 0x00000000}},  //   _anh_, munt, _alhi,
  { {0x44440df0, 0x44331b2a, 0x7ae303c1, 0x00000000}},  //   _pl_, _box_, lunt,
  { {0x4433006b, 0x7e690182, 0x99840054, 0x00000000}},  //   _cox_, _ljep, _الهو,
  { {0xb779007b, 0x366a01f9, 0xc5fb0055, 0x00000000}},  //   _באַש, _иако_, ইয়া_,
  { {0x444426ec, 0x76440020, 0x64450010, 0x00000000}},  //   _wl_, _uliy, _elhi,
  { {0xe2970265, 0x4444011f, 0x7ae3122b, 0x00000000}},  // [6a00] рат_, _tl_, hunt,
  { {0x4444000d, 0x7ae326ed, 0x7e7b02a9, 0x00000000}},  //   _ul_, kunt, _akup,
  { {0xeaf40365, 0x7ae30211, 0x645c0091, 0x00000000}},  //   _आहेत_, junt, miri,
  { {0x645c011f, 0x7bca09c7, 0x22491a7c, 0x00000000}},  //   liri, wafu, chak_,
  { {0xcfaa05f3, 0x7bca000b, 0x4433005f, 0x00000000}},  //   _لازم_, tafu, _yox_,
  { {0x645c26ee, 0x7ae30555, 0x394d0089, 0x00000000}},  //   niri, funt, dzes_,
  { {0x7ae326ef, 0xaa5826f0, 0x7bca20db, 0x00000000}},  //   gunt, лику_, rafu,
  { {0xfb19026c, 0x645c000b, 0x7bca0fd1, 0x00000000}},  //   اروں_, hiri, safu,
  { {0x645c061d, 0x7a350387, 0x8c3d014a, 0x00000000}},  //   kiri, _pátr, _kuşl,
  { {0x7ae3011c, 0x7a3c00f4, 0x3a3f103f, 0x00000000}},  //   bunt, _méti, akup_,
  { {0x645c005f, 0xcb6700d7, 0x7ae3004a, 0x00000000}},  //   diri, _кафе_, cunt,
  { {0x8c3c011f, 0x3a3f00ab, 0x645c00c4, 0x00000000}},  //   _diğe, ckup_, eiri,
  { {0x7bc80149, 0x645c0041, 0x442126f1, 0x00000000}},  //   _kedu, firi, _pnh_,
  { {0x645c002d, 0xd7ef0025, 0x00000000, 0x00000000}},  //   giri, _يكن_,   ,
  { {0xeaf40061, 0x7bc826f2, 0x61f60016, 0x00000000}},  //   _आहोत_, _medu, ffyl,
  { {0x645c0051, 0x7bc80089, 0x61d8007c, 0x00000000}},  //   airi, _ledu, имся_,
  { {0xe29f0359, 0x765d099e, 0x22490169, 0x00000000}},  // [6a10] _við_, misy, rhak_,
  { {0x7e7b01d9, 0x2fc7001d, 0x765d26f3, 0x00000000}},  //   _skup, úng_, lisy,
  { {0x261c0365, 0x753d0010, 0x394d0133, 0x00000000}},  //   याची_, lysz, zzes_,
  { {0x765d0263, 0xf1ab03ec, 0x7a3c009d, 0x00000000}},  //   nisy, _جاده_, _féti,
  { {0x7bc801d6, 0xe450025a, 0x753d0010, 0x00000000}},  //   _bedu, _رضی_, nysz,
  { {0x7ae300b0, 0xfaa50147, 0xec780088, 0x00000000}},  //   tunt, бако, апі_,
  { {0x25e8001c, 0x8b94005e, 0x547a0049, 0x00000000}},  //   _झाली_, оръч, נְננ,
  { {0x7ae30ea4, 0x645c177c, 0x7e7b0091, 0x00000000}},  //   runt, ziri, _ukup,
  { {0x2011000b, 0x7ae302d5, 0x26de0211, 0x00000000}},  //   _kazi_, sunt, erto_,
  { {0x7ae30fa1, 0x7bc826f4, 0x3a3f0142, 0x00000000}},  //   punt, _gedu, skup_,
  { {0x394d0047, 0x44260011, 0x765d01aa, 0x00000000}},  //   szes_, _đo_, fisy,
  { {0x7d1b1a3a, 0x20110107, 0x645c0016, 0x00000000}},  //   _krus, _lazi_, wiri,
  { {0x645c038c, 0xa8a726f5, 0xba740025, 0x00000000}},  //   tiri, _трек, _بالت,
  { {0x20111575, 0x7a3c009d, 0x628f01f3, 0x00000000}},  //   _nazi_, _réti, _ahco,
  { {0x645c011c, 0x765d110c, 0x7a3c13f6, 0x00000000}},  //   riri, bisy, _séti,
  { {0x645c010a, 0x7a3c009d, 0xa7fc006b, 0x00000000}},  //   siri, _péti, hnıl,
  { {0x645c1899, 0x412700ed, 0xda1e0061, 0x00000000}},  // [6a20] piri, бото_, _मोफत_,
  { {0x22400007, 0x66061267, 0x61f605d5, 0x00000000}},  //   skik_, lekk, sfyl,
  { {0x7d1b1a0c, 0xb5fb26f6, 0x25ad050f, 0x00000000}},  //   _arus, znám, žele_,
  { {0x7a3c26f7, 0x8c3d26f8, 0x66060516, 0x00000000}},  //   _hétv, _duşm, nekk,
  { {0x7bc80169, 0x27170011, 0xf1b300b3, 0x00000000}},  //   _pedu, _lăn_, _מסר_,
  { {0x7d1b0079, 0x765d0d5b, 0x2011014a, 0x00000000}},  //   _drus, zisy, _gazi_,
  { {0x753d0046, 0x2458006b, 0xdee30d51, 0x00000000}},  //   zysz, _cümə_, _нори,
  { {0x9f580197, 0x7f3b0049, 0x2618007d, 0x00000000}},  //   _farò_, _געלו, _बोली_,
  { {0x7d1b010f, 0xde7700a1, 0xed460098, 0x00000000}},  //   _grus, _اینڈ_, _унап,
  { {0x6b8122ad, 0x37c80044, 0x27170082, 0x00000000}},  //   _fylg, _শাহর, _băn_,
  { {0x765d0263, 0x2717001d, 0xbb860054, 0x00000000}},  //   tisy, _căn_, _الاي,
  { {0xdb1a00b0, 0x00000000, 0x00000000, 0x00000000}},  //   _vetä,   ,   ,
  { {0xb9960054, 0x765d0173, 0x4a7b0049, 0x00000000}},  //   _الشب, risy, _גראב,
  { {0x765d006a, 0x26de0059, 0x00000000, 0x00000000}},  //   sisy, prto_,   ,
  { {0x765d26f9, 0x660601e5, 0xed5916d0, 0x00000000}},  //   pisy, bekk, _veži_,
  { {0x62840198, 0x79820022, 0x2011229f, 0x00000000}},  //   glio, _kyow, _sazi_,
  { {0x51871b67, 0xc03500ed, 0x20110ecc, 0x00000000}},  // [6a30] сува, онај, _pazi_,
  { {0x7d1b0023, 0x62840997, 0x00000000, 0x00000000}},  //   _rrus, alio,   ,
  { {0x2011003b, 0x5e87008b, 0x9f580197, 0x00000000}},  //   _vazi_, будз, _sarò_,
  { {0x2011000b, 0x7d1b0036, 0xf1270147, 0x00000000}},  //   _wazi_, _prus, _льго,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3eb80009, 0x26c20fcd, 0x00000000, 0x00000000}},  //   _ftrt_, ćkoj_,   ,
  { {0x6aa226fa, 0x447c0049, 0x1a291a02, 0x00000000}},  //   _biof, אנגע, ижки_,
  { {0x8c090055, 0x7d1b00ab, 0x6aa2060c, 0x00000000}},  //   লাইন_, _trus, _ciof,
  { {0x7d1b105a, 0xaca30011, 0x27170011, 0x00000000}},  //   _urus, _trốn, _săn_,
  { {0x66060112, 0x79820058, 0x00000000, 0x00000000}},  //   wekk, _dyow,   ,
  { {0x1bb8023c, 0x628426fb, 0x61fd067f, 0x00000000}},  //   _طالع_, ylio, _obsl,
  { {0x271700ad, 0x28f90057, 0x78bb0103, 0x00000000}},  //   _văn_, _ведь_, ppuv,
  { {0xa5bb009f, 0x64400181, 0xdb010030, 0x00000000}},  //   tjór, êmio, _aflø,
  { {0x69cb0010, 0x2d8d0020, 0xf745007c, 0x00000000}},  //   _hege, _mzee_, _мело,
  { {0x69cb26fc, 0x04fa0044, 0x03a3007c, 0x00000000}},  //   _kege, ইটের_, диро,
  { {0x69cb26fd, 0xcb120104, 0x628404dc, 0x00000000}},  //   _jege, ולל_, ulio,
  { {0x69cb26fe, 0x62841ed6, 0x3eaa26ff, 0x00000000}},  // [6a40] _mege, rlio, _subt_,
  { {0x69cb0238, 0x61ef0197, 0x6fd5007e, 0x00000000}},  //   _lege, _eccl, зіцц,
  { {0x1eda0054, 0x232a00ed, 0xeda60679, 0x00000000}},  //   شباب_, _тони_, ошло,
  { {0x69cb2700, 0x0d8603e0, 0x9f5e000c, 0x00000000}},  //   _nege, олен, _útí_,
  { {0xc27b00b6, 0xf653009b, 0x6aa20325, 0x00000000}},  //   _כרטי, וצא_, _riof,
  { {0x8cdb0164, 0xdfd20014, 0x7a3c000c, 0x00000000}},  //   _निरो, _زير_, _létt,
  { {0x69cb1440, 0x9f58000c, 0x00000000, 0x00000000}},  //   _bege, _garð_,   ,
  { {0x69cb2701, 0x00000000, 0x00000000, 0x00000000}},  //   _cege,   ,   ,
  { {0xed5a01b3, 0x69cb2702, 0x69d90016, 0x00000000}},  //   _тоа_, _dege, _ddwe,
  { {0x290f0026, 0x291d000a, 0x00000000, 0x00000000}},  //   _dsga_, _drwa_,   ,
  { {0xd7f80035, 0x00000000, 0x00000000, 0x00000000}},  //   rfă_,   ,   ,
  { {0x69cb09d6, 0x8b65039d, 0x7a3c000c, 0x00000000}},  //   _gege, _عالم, _pétu,
  { {0xb5fb002a, 0x7e9b0104, 0xb86502fd, 0x00000000}},  //   nnái, יסטו, _کانو,
  { {0x69cb00bb, 0x3ea400ea, 0x00000000, 0x00000000}},  //   _zege, _limt_,   ,
  { {0xd25b2703, 0x2d8402c2, 0x3a2600b5, 0x00000000}},  //   аца_, _lyme_, _knop_,
  { {0xa2dc01f5, 0x78a300bb, 0xb21b0190, 0x00000000}},  //   _फिर्, _zinv, _skæb,
  { {0xc6940049, 0x25a9006c, 0x3fab012b, 0x00000000}},  // [6a50] _קאפ_, _igal_, ањем_,
  { {0x7a3c0010, 0x644e03a1, 0x00000000, 0x00000000}},  //   _kéts, chbi,   ,
  { {0x6480021e, 0xb5fb2704, 0x94740025, 0x00000000}},  //   röit, enái, _تديا,
  { {0x9f58009f, 0xf778002b, 0xa247009e, 0x00000000}},  //   _varð_, qgħu_, _بیرل_,
  { {0x61ed0089, 0xdb1a00c4, 0x5184078e, 0x00000000}},  //   mgal, _getú, _жура,
  { {0x69cb04d4, 0x61ed2222, 0xfaa5007e, 0x00000000}},  //   _sege, lgal, пако,
  { {0x81ce08b7, 0xfe73002c, 0x69cb0030, 0x00000000}},  //   _রাত_, _قدر_, _pege,
  { {0xf77100a1, 0xefc80011, 0x78a30007, 0x00000000}},  //   ہاج_, _đỉnh_, _sinv,
  { {0x7a3c009f, 0x386e0061, 0x69cb01cb, 0x00000000}},  //   _rétt, _bjfr_, _vege,
  { {0xa2dc02d2, 0x69cb2705, 0x1bf203d7, 0x00000000}},  //   _फिल्, _wege, _घायल_,
  { {0x69cb2706, 0x78a30203, 0xed590733, 0x00000000}},  //   _tege, _vinv, _vežu_,
  { {0x63b50036, 0xaca30011, 0xd0140044, 0x00000000}},  //   eczn, _trồn, সায়_,
  { {0x04b601e0, 0x61ed0190, 0x28f8007e, 0x00000000}},  //   ясня, dgal, _мець_,
  { {0x25a92707, 0x00000000, 0x00000000, 0x00000000}},  //   _egal_,   ,   ,
  { {0x25ad18e1, 0xdb1a00c4, 0x224b0009, 0x00000000}},  //   žela_, _setú, _blck_,
  { {0xcb12007b, 0x61ed1840, 0x5756009b, 0x00000000}},  //   עלן_, ggal, _מבצע_,
  { {0x9abc0066, 0x00000000, 0x00000000, 0x00000000}},  // [6a60] _irċe,   ,   ,
  { {0x3ea4001a, 0xe0d700c2, 0x6616014a, 0x00000000}},  //   _simt_, яву_, _hayk,
  { {0x645e2708, 0xe457007b, 0x7a3c00f4, 0x00000000}},  //   _impi, _זייט_, _métr,
  { {0x7a3c0047, 0x2d84008e, 0x290d1519, 0x00000000}},  //   _létr, _pyme_, kwea_,
  { {0x2ca5051d, 0x443a01bb, 0x6616028e, 0x00000000}},  //   _bild_, _kop_, _mayk,
  { {0xb5fb2709, 0xed4f00a1, 0x68e9005b, 0x00000000}},  //   rnái, چھے_, dued,
  { {0x443a0d0a, 0xaab800a6, 0x7f4a0025, 0x00000000}},  //   _mop_, زگار_, _الأق_,
  { {0x443a0082, 0x6616000a, 0x2d840041, 0x00000000}},  //   _lop_, _nayk, _tyme_,
  { {0xfce30057, 0x63b50046, 0x68e90016, 0x00000000}},  //   _пото, yczn, gued,
  { {0x443a01ee, 0x7e620020, 0x61ed016e, 0x00000000}},  //   _nop_, liop, zgal,
  { {0x7c280030, 0x7a3c00f4, 0x6616014a, 0x00000000}},  //   _indr, _détr, _bayk,
  { {0x645e270a, 0x60d6270b, 0x7c3a0082, 0x00000000}},  //   _ampi, ksym, _hotr,
  { {0x7aea01bf, 0xc983013b, 0xab5c0089, 0x00000000}},  //   luft, _пуши, _ceļv,
  { {0x443a04bd, 0x7e620020, 0xb86606dd, 0x00000000}},  //   _cop_, hiop, _عاشو,
  { {0x7c3a0065, 0x61ed0dec, 0x443a0007, 0x00000000}},  //   _motr, tgal, _dop_,
  { {0x623401f9, 0x7c3a0173, 0x645e0781, 0x00000000}},  //   несу, _lotr, _empi,
  { {0x61ed04e7, 0x764d0111, 0x443a01c3, 0x00000000}},  // [6a70] rgal, _ilay, _fop_,
  { {0x7c3a270c, 0x443a016b, 0xc879001a, 0x00000000}},  //   _notr, _gop_, tuşi_,
  { {0x61ed0010, 0x68e9270d, 0x2cad0133, 0x00000000}},  //   pgal, zued, _sued_,
  { {0x7c2804d3, 0xf2d201ce, 0x7e620253, 0x00000000}},  //   _andr, _בעט_, giop,
  { {0x2ab1029d, 0x7c3a0010, 0xd5fc0049, 0x00000000}},  //   _sáb_, _botr, מפאר,
  { {0x7c3a0035, 0xa0a4007e, 0x443a00f6, 0x00000000}},  //   _cotr, _паўд, _xop_,
  { {0xfbd00054, 0x764d047f, 0x09be0055, 0x00000000}},  //   اته_, _olay, _ইয়া,
  { {0x7c280c64, 0x2ca500ab, 0xca06005e, 0x00000000}},  //   _endr, _wild_, днъж_,
  { {0x2cad006c, 0x7a3c1776, 0x7c3a270e, 0x00000000}},  //   _uued_, _pétr, _fotr,
  { {0xefc8001d, 0x764d0c04, 0x7c3a0022, 0x00000000}},  //   _định_, _alay, _gotr,
  { {0x6e3b0341, 0x764d01aa, 0x443a00ca, 0x00000000}},  //   _koub, _blay, _rop_,
  { {0x443a067c, 0x6e3b0007, 0x2b4f014a, 0x00000000}},  //   _sop_, _joub, ımcı_,
  { {0x68e90555, 0x38b20016, 0x7a3c009d, 0x00000000}},  //   qued, _gâr_, _tétr,
  { {0x6e3b00cc, 0x7d040477, 0x7e620032, 0x00000000}},  //   _loub, çisi, ziop,
  { {0x64a3008b, 0x6383005e, 0x6e290056, 0x00000000}},  //   тара, вгра, _oneb,
  { {0xd048005f, 0xe1fa007e, 0x2a6d0ab5, 0x00000000}},  //   ələr, ўга_, nneb_,
  { {0x443a0866, 0x10a6004d, 0x321c013e, 0x00000000}},  // [6a80] _top_, диан, ěvy_,
  { {0x645e0dc7, 0x6d420020, 0x6e2900b9, 0x00000000}},  //   _umpi, vyoa, _aneb,
  { {0xdfcf023c, 0x60d604d3, 0x7e62078b, 0x00000000}},  //   شين_, ssym, tiop,
  { {0x7c3a00d4, 0x6e3b00c4, 0x93ee00e8, 0x00000000}},  //   _sotr, _coub, _जाँच_,
  { {0x7e62003b, 0x6e3b0549, 0x6da3005e, 0x00000000}},  //   riop, _doub, вица,
  { {0x6e2905fe, 0x7e6200e7, 0x7c83007c, 0x00000000}},  //   _eneb, siop, куще,
  { {0x7c3a0a8d, 0xce4a007e, 0x6e3b0173, 0x00000000}},  //   _votr, _дзве_, _foub,
  { {0x2018020c, 0x39141074, 0xb5fb000c, 0x00000000}},  //   _hari_, емир, nnát,
  { {0x93ee03d7, 0x201800b0, 0x3dc600e7, 0x00000000}},  //   _जांच_, _kari_, mbow_,
  { {0x47340072, 0x7c280203, 0x2018206c, 0x00000000}},  //   енос, _undr, _jari_,
  { {0x2018000d, 0x764d0038, 0x6e3b08ed, 0x00000000}},  //   _mari_, _play, _youb,
  { {0x81e40055, 0x2018270f, 0x3dc60133, 0x00000000}},  //   প্ত_, _lari_, nbow_,
  { {0x06ac0044, 0x25ad18e1, 0x00000000, 0x00000000}},  //   _কৌশি, želo_,   ,
  { {0x36d40088, 0x201814ad, 0x32bb0025, 0x00000000}},  //   _зокр, _nari_, قدرة_,
  { {0xddc20bf1, 0xd6cf041f, 0x02a70121, 0x00000000}},  //   znoš, _шт_, драм,
  { {0x764d000b, 0xd5b80152, 0x9294007e, 0x00000000}},  //   _ulay, _ось_, васц,
  { {0x20180207, 0x6e3b2710, 0x39442711, 0x00000000}},  // [6a90] _bari_, _roub, nyms_,
  { {0xdfd12712, 0x6e3b0224, 0x2018027e, 0x00000000}},  //   ايا_, _soub, _cari_,
  { {0x20180149, 0x6e3b009d, 0x2a6d005b, 0x00000000}},  //   _dari_, _poub, yneb_,
  { {0xb05b03a9, 0x11eb023c, 0x20180288, 0x00000000}},  //   _städ, _بعدي_, _eari_,
  { {0xe3a500a6, 0x20182713, 0xfce50081, 0x00000000}},  //   _تشکی, _fari_, холо,
  { {0x2018000b, 0x6b882714, 0x6e3b01aa, 0x00000000}},  //   _gari_, _bydg, _woub,
  { {0x6e3b1339, 0x45150044, 0x29061624, 0x00000000}},  //   _toub, ামিক_, _apoa_,
  { {0xe9d901f9, 0x5f9401bd, 0x20180c4b, 0x00000000}},  //   чки_, _рист, _zari_,
  { {0x5c750954, 0x20181dc0, 0x32190871, 0x00000000}},  //   _злат, _yari_, _masy_,
  { {0xc052007b, 0x2a6d006c, 0x9f5800fa, 0x00000000}},  //   ָזט_, sneb_, _tarô_,
  { {0x6fb20164, 0x22b811b9, 0xb5fb08aa, 0x00000000}},  //   _जलसं, _očka_, rián,
  { {0xf6520a4f, 0xb21b0190, 0xb5fb2715, 0x00000000}},  //   ائد_, _skæn, sián,
  { {0xe1ff000c, 0x00000000, 0x00000000, 0x00000000}},  //   _ljós_,   ,   ,
  { {0x6f150036, 0x291f00e7, 0xd5ed0082, 0x00000000}},  //   _oszc, mvua_, _phạ,
  { {0x20182716, 0xe29a0088, 0x00000000, 0x00000000}},  //   _rari_, зав_,   ,
  { {0x2cbf0107, 0xb5fb2717, 0x00000000, 0x00000000}},  //   _otud_, niál,   ,
  { {0x68fb2346, 0x20182718, 0x66040061, 0x00000000}},  // [6aa0] ntud, _pari_, _ibik,
  { {0xb4fb00b6, 0x321900ab, 0x7524002d, 0x00000000}},  //   _צפיי, _easy_, _iriz,
  { {0x20181bb6, 0x68fb006c, 0x7e2a007e, 0x00000000}},  //   _vari_, htud, зіла_,
  { {0xee3a005e, 0x20181dc0, 0x3ce62719, 0x00000000}},  //   яне_, _wari_, trov_,
  { {0xb5fb271a, 0x20181c56, 0xac18026b, 0x00000000}},  //   onár, _tari_, долу_,
  { {0x60c40625, 0x67230087, 0x00000000, 0x00000000}},  //   mpim, _ornj,   ,
  { {0x68fb06c2, 0x2cbf000a, 0x660400fa, 0x00000000}},  //   etud, _etud_, _obik,
  { {0x3ce600f8, 0x7524054f, 0xbea3005e, 0x00000000}},  //   prov_, _oriz, _баск,
  { {0xc8660216, 0x3f8a0016, 0x68fb271b, 0x00000000}},  //   етни, _hybu_, gtud,
  { {0x1bba0025, 0x6604006c, 0x2a6a0010, 0x00000000}},  //   _رائع_, _abik, őbb_,
  { {0x67230107, 0x7524271c, 0x442f0082, 0x00000000}},  //   _crnj, _ariz, _đg_,
  { {0xb5fb0d7f, 0x21200091, 0xd0190044, 0x00000000}},  //   ciál, kvih_, ঠায়_,
  { {0x7524001a, 0xdb080190, 0x3219271d, 0x00000000}},  //   _criz, _afdø, _rasy_,
  { {0x62860047, 0x3495008b, 0x6604271e, 0x00000000}},  //   _akko, тагр, _ebik,
  { {0xddc90209, 0x75240032, 0x00000000, 0x00000000}},  //   _lješ, _eriz,   ,
  { {0x998d0bf8, 0x7524016e, 0xdb1a0065, 0x00000000}},  //   lješ_, _friz, _aftë,
  { {0x60f903c8, 0x067c01f8, 0x660f0428, 0x00000000}},  // [6ab0] ьная_, _מנהל, meck,
  { {0x660f0142, 0xb4dd0061, 0x661d03b4, 0x00000000}},  //   leck, डळी_, ldsk,
  { {0x2cbf007f, 0xc885010f, 0x661d271f, 0x00000000}},  //   _stud_, äßig_, odsk,
  { {0x661d004e, 0x660f0161, 0x00000000, 0x00000000}},  //   ndsk, neck,   ,
  { {0xed58103e, 0x661d0168, 0x64480039, 0x00000000}},  //   ної_, idsk, ödig,
  { {0x660f1440, 0x628d00b0, 0xdb18010e, 0x00000000}},  //   heck, llao, havõ,
  { {0x998d0521, 0x6f150036, 0xa7fc006b, 0x00000000}},  //   dješ_, _uszc, hnıs,
  { {0x660f16d0, 0x25ad050f, 0x661d2720, 0x00000000}},  //   jeck, želj_, jdsk,
  { {0x660f05d2, 0xb5fb0161, 0x672300d0, 0x00000000}},  //   deck, riál, _srnj,
  { {0x68fb01a3, 0x661d01d6, 0xb21b1f7d, 0x00000000}},  //   rtud, edsk, _skæl,
  { {0x68fb009f, 0xdddb0224, 0xd90f00a1, 0x00000000}},  //   stud, _zkuš, شیں_,
  { {0x672310f5, 0xcb12009b, 0x00000000, 0x00000000}},  //   _vrnj, _כלב_,   ,
  { {0x69c901a2, 0x00000000, 0x00000000, 0x00000000}},  //   mbee,   ,   ,
  { {0xe731069f, 0xa2e6007c, 0x69c9046a, 0x00000000}},  //   _نصب_, когд, lbee,
  { {0xe73901fb, 0x660f0b77, 0x00000000, 0x00000000}},  //   _цей_, beck,   ,
  { {0x26c50325, 0x69c900bb, 0x628d2721, 0x00000000}},  //   mplo_, nbee, glao,
  { {0x21670407, 0x68e90213, 0x75240032, 0x00000000}},  // [6ac0] вити_, nred, _uriz,
  { {0xddc90363, 0xdb1a01aa, 0x68e900c4, 0x00000000}},  //   _rješ, _metò, ired,
  { {0x68e9018e, 0x7d090181, 0x26c501aa, 0x00000000}},  //   hred, _apes, nplo_,
  { {0x68e92722, 0xddc90243, 0x60c42723, 0x00000000}},  //   kred, _pješ, ppim,
  { {0x9cb30025, 0x68e90146, 0x69c901a2, 0x00000000}},  //   لمنت, jred, dbee,
  { {0xddc90209, 0x68e90030, 0x69c901d6, 0x00000000}},  //   _vješ, dred, ebee,
  { {0x661d0007, 0x501b0104, 0x67210521, 0x00000000}},  //   ydsk, _קולו, jvlj,
  { {0x68e91c95, 0xf2d3009b, 0xddc9016e, 0x00000000}},  //   fred, בעה_, _tješ,
  { {0x660f2724, 0x6da30242, 0x00000000, 0x00000000}},  //   veck, _вита,   ,
  { {0x63bc0107, 0x8d5b0097, 0x660f2725, 0x00000000}},  //   jcrn, _חכמי, weck,
  { {0x660f0161, 0x69c900d9, 0x6aab000a, 0x00000000}},  //   teck, bbee, _figf,
  { {0x68e9068f, 0x3ce9089f, 0x7bd82726, 0x00000000}},  //   bred, šave_, lavu,
  { {0x660f2727, 0x661d0056, 0x3dd70044, 0x00000000}},  //   reck, rdsk, _হামল,
  { {0x661d001c, 0x7bd8006c, 0x26d80010, 0x00000000}},  //   sdsk, navu, áros_,
  { {0xe5c721a6, 0x07f7089d, 0xa3d40061, 0x00000000}},  //   _испо, _شروع_, _हजर_,
  { {0x35f5005e, 0x3547007e, 0x31c410d6, 0x00000000}},  //   _спир, _ахов, исув,
  { {0x51871b67, 0x7bd800b0, 0x00000000, 0x00000000}},  // [6ad0] тува, kavu,   ,
  { {0x88c40044, 0x7bd80142, 0x25be013e, 0x00000000}},  //   _এটাক, javu, ětle_,
  { {0x1fa701fc, 0x68e9073a, 0xd251023c, 0x00000000}},  //   траг, zred, _هند_,
  { {0x6d1e007d, 0x68e92728, 0xcf9800e2, 0x00000000}},  //   पिंग_, yred, тју_,
  { {0xf1bf004a, 0x00000000, 0x00000000, 0x00000000}},  //   _ifá_,   ,   ,
  { {0x68e9037e, 0xeb99051f, 0x7bd804fe, 0x00000000}},  //   vred, нил_, gavu,
  { {0x9f3401fb, 0x8c4201e0, 0x69c90116, 0x00000000}},  //   _кері, сеще, tbee,
  { {0x68e92729, 0x69c90270, 0x00000000, 0x00000000}},  //   tred, ubee,   ,
  { {0x69c9049b, 0x8cbb007a, 0x7d09272a, 0x00000000}},  //   rbee, _آدرس_, _upes,
  { {0x3ead00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _hiet_,   ,   ,
  { {0x68e901d9, 0x69c901d6, 0x628400e7, 0x00000000}},  //   sred, pbee, yoio,
  { {0x68e90cce, 0x3ead0066, 0x2cac006b, 0x00000000}},  //   pred, _jiet_, _zidd_,
  { {0x3ead0bdf, 0x00000000, 0x00000000, 0x00000000}},  //   _miet_,   ,   ,
  { {0xfbe50055, 0x3ead00b5, 0x972513d9, 0x00000000}},  //   প্রত, _liet_, _مفتو,
  { {0x91e60057, 0xc8a8005e, 0x00000000, 0x00000000}},  //   лове, _ръце_,   ,
  { {0x3ead0662, 0x42550a27, 0x7bd8007f, 0x00000000}},  //   _niet_, атут, zavu,
  { {0x7bd8013f, 0x628400e5, 0x00000000, 0x00000000}},  // [6ae0] yavu, roio,   ,
  { {0x787d01aa, 0x3ead00f6, 0x00000000, 0x00000000}},  //   tèvy, _aiet_,   ,
  { {0x93fb0476, 0x3ead0011, 0xc3fb0097, 0x00000000}},  //   _אליי, _biet_, _אליש,
  { {0x221624d3, 0x7bd80020, 0x2d8d004a, 0x00000000}},  //   _сфор, wavu, _byee_,
  { {0x7bd80387, 0xa076007c, 0x3ead0edd, 0x00000000}},  //   tavu, _бывш, _diet_,
  { {0x61f60016, 0x644e0a5e, 0xcb1a00e2, 0x00000000}},  //   lgyl, nkbi, еќи_,
  { {0x7bd80387, 0x81d70044, 0x09c50044, 0x00000000}},  //   ravu, _সাত_, _এয়া,
  { {0x3ead0066, 0xcb070025, 0x61f6272b, 0x00000000}},  //   _giet_, ايين_, ngyl,
  { {0x286a0242, 0xc7b00025, 0x644e00ea, 0x00000000}},  //   ерно_, يّة_, kkbi,
  { {0x0d7504af, 0x3ead02ae, 0x224200ea, 0x00000000}},  //   _тыся, _ziet_, _lokk_,
  { {0xfd500082, 0x80370049, 0x00000000, 0x00000000}},  //   _nghẽ, אניע_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2a660bc0, 0x00000000, 0x00000000, 0x00000000}},  //   _imob_,   ,   ,
  { {0x81ce0044, 0x00000000, 0x00000000, 0x00000000}},  //   _রাগ_,   ,   ,
  { {0x56950265, 0x0464041f, 0x05150044, 0x00000000}},  //   _какт, стям, ামের_,
  { {0xea010082, 0x00000000, 0x00000000, 0x00000000}},  //   _đẫy_,   ,   ,
  { {0x3ead0116, 0x00000000, 0x00000000, 0x00000000}},  // [6af0] _riet_,   ,   ,
  { {0x26de0dc9, 0x5d35009e, 0x00000000, 0x00000000}},  //   osto_, یفائ,   ,
  { {0x3ead0168, 0x62580051, 0x22950088, 0x00000000}},  //   _piet_, _bíod, _виня,
  { {0x518700e1, 0x9f5c00b9, 0x26de00b0, 0x00000000}},  //   _буга, ývá_, isto_,
  { {0x3ead0011, 0x00000000, 0x00000000, 0x00000000}},  //   _viet_,   ,   ,
  { {0x26de2301, 0x13d90044, 0xcb6900ed, 0x00000000}},  //   ksto_, _তাড়, кале_,
  { {0x26de0e0d, 0x15e50061, 0x3ead272c, 0x00000000}},  //   jsto_, कणार_, _tiet_,
  { {0x2f180088, 0xdb240010, 0x22420066, 0x00000000}},  //   _щось_, ásáh, _xokk_,
  { {0x26de1ad2, 0x7e6b0058, 0x00000000, 0x00000000}},  //   esto_, migp,   ,
  { {0x7d1b272d, 0x786500ed, 0x6fe001dc, 0x00000000}},  //   _isus, ркоз, mácí,
  { {0x6d4b0006, 0xfb150167, 0xb064010f, 0x00000000}},  //   lyga, _خواج, lmäß,
  { {0x7e6b0058, 0x366a003b, 0x00000000, 0x00000000}},  //   nigp, тамо_,   ,
  { {0xb06401a2, 0x69db01a2, 0x00000000, 0x00000000}},  //   nmäß, maue,   ,
  { {0xb05b0b5b, 0x7e6b011c, 0xa8790049, 0x00000000}},  //   _stän, higp, _שאַר,
  { {0x7d1b0022, 0xb06401a2, 0x9676007e, 0x00000000}},  //   _lsus, hmäß, _выпі,
  { {0x69db010f, 0x877a0049, 0x7546189c, 0x00000000}},  //   naue, _באצי, _вниз,
  { {0x61f6032e, 0xe3b20464, 0x00000000, 0x00000000}},  // [6b00] rgyl, _ورد_,   ,
  { {0x69db010f, 0x7bc101f3, 0x629d0288, 0x00000000}},  //   haue, _nflu, _ehso,
  { {0x44440198, 0x7d1b0ac2, 0x2fd70014, 0x00000000}},  //   _io_, _asus, شوند_,
  { {0x7bc106c0, 0xcee7007c, 0x72db009b, 0x00000000}},  //   _aflu, рдце_, _בקטג,
  { {0x44440811, 0x69db010f, 0x55bb009b, 0x00000000}},  //   _ko_, daue, דמנו,
  { {0xf1150049, 0x00000000, 0x00000000, 0x00000000}},  //   _פֿרי_,   ,   ,
  { {0x44440811, 0xdb1a0047, 0xe3e9007b, 0x00000000}},  //   _mo_, _letö, אַפֿ,
  { {0x4444156d, 0x3ce90091, 0x6d4b0240, 0x00000000}},  //   _lo_, šava_, byga,
  { {0x4444272e, 0x3eb80133, 0x7bc1005b, 0x00000000}},  //   _oo_, _hurt_, _fflu,
  { {0x6e20010f, 0xb8fe02d2, 0x7d02272f, 0x00000000}},  //   _hamb, _तब_, mtos,
  { {0x6e20010a, 0x61e607ac, 0x69db010f, 0x00000000}},  //   _kamb, _odkl, baue,
  { {0x44440907, 0x6e2006fe, 0xf76f01f7, 0x00000000}},  //   _ao_, _jamb, باً_,
  { {0x444414d4, 0x7d020047, 0x6e20000b, 0x00000000}},  //   _bo_, ntos, _mamb,
  { {0x44442730, 0x6e2004cb, 0xea010011, 0x00000000}},  //   _co_, _lamb, _đẩy_,
  { {0x883b009b, 0x3267007e, 0x7d020052, 0x00000000}},  //   _בתגו, атав, htos,
  { {0x6e200020, 0x09aa0044, 0xd258007e, 0x00000000}},  //   _namb, _গ্যা, ацу_,
  { {0x44441cdf, 0x2fd80007, 0xdb1a01a2, 0x00000000}},  // [6b10] _fo_, _berg_, _getö,
  { {0x44440195, 0x3eb8000c, 0xd7f8001a, 0x00000000}},  //   _go_, _burt_, ngă_,
  { {0x6e201b3e, 0x3eb80129, 0x62580051, 0x00000000}},  //   _bamb, _curt_, _díob,
  { {0x444403a6, 0x6e202731, 0x442101a3, 0x00000000}},  //   _zo_, _camb, _hah_,
  { {0x44441631, 0x6e201f37, 0x442117f6, 0x00000000}},  //   _yo_, _damb, _kah_,
  { {0x44210004, 0x44440082, 0xb5fb00c4, 0x00000000}},  //   _jah_, _xo_, ciáv,
  { {0x64450023, 0x38bb0016, 0xb06401a2, 0x00000000}},  //   _mohi, _sêr_, smäß,
  { {0x6e20020c, 0xe8f9012b, 0x44210127, 0x00000000}},  //   _gamb, гли_, _lah_,
  { {0x7e690020, 0x69db0fa5, 0x97d90088, 0x00000000}},  //   _imep, raue, льну_,
  { {0x6e201111, 0x4421023a, 0x69db2732, 0x00000000}},  //   _zamb, _nah_, saue,
  { {0x4444000d, 0x9b950054, 0xab950054, 0x00000000}},  //   _ro_, _الات, _الاغ,
  { {0x44442256, 0xb05b0073, 0x0656008b, 0x00000000}},  //   _so_, _stäl, стоў,
  { {0x44212733, 0x69d90007, 0xc987003b, 0x00000000}},  //   _bah_, _iewe, _тужи,
  { {0x6e22016e, 0x44210022, 0x2a6d0142, 0x00000000}},  //   zdob, _cah_, lieb_,
  { {0x44440027, 0x7d020047, 0x44211444, 0x00000000}},  //   _vo_, ztos, _dah_,
  { {0x4444001f, 0x69d92734, 0x2fd8000a, 0x00000000}},  //   _wo_, _jewe, _serg_,
  { {0x44442735, 0x6e200149, 0x394d12c2, 0x00000000}},  // [6b20] _to_, _ramb, nyes_,
  { {0x69d90343, 0x6e202736, 0xd12f0647, 0x00000000}},  //   _lewe, _samb, عمل_,
  { {0x6e20006a, 0xb5fb03f0, 0x645c03df, 0x00000000}},  //   _pamb, riáv, mhri,
  { {0x291d0263, 0x7d0201bc, 0x69d900ab, 0x00000000}},  //   _oswa_, ttos, _newe,
  { {0x6e220211, 0x442110ed, 0x7e7b01c9, 0x00000000}},  //   rdob, _yah_, _djup,
  { {0x7056004b, 0x7d022737, 0x22402738, 0x00000000}},  //   _انسا, rtos, ljik_,
  { {0x6e2003d1, 0x69d909d6, 0xa6f20044, 0x00000000}},  //   _tamb, _bewe, _জন্ম_,
  { {0x7d020e0a, 0x69d90390, 0x22400e0d, 0x00000000}},  //   ptos, _cewe, njik_,
  { {0xed50009c, 0x3ebf0825, 0x69d900b4, 0x00000000}},  //   _تھا_, _čuti_, _dewe,
  { {0xd7f8001a, 0x7c212739, 0x711b0049, 0x00000000}},  //   ugă_, _galr, נויפ,
  { {0x4421273a, 0x3aeb0167, 0xd7f8001a, 0x00000000}},  //   _rah_, _مبنی_, rgă_,
  { {0x69d90b72, 0x291a0123, 0x44210ea4, 0x00000000}},  //   _gewe, _مقصد_, _sah_,
  { {0xa9670517, 0x7bda0734, 0xb05b0039, 0x00000000}},  //   _лица_, _ketu, _stäm,
  { {0xe947026c, 0x7bda0065, 0x645c01a3, 0x00000000}},  //   _درمی, _jetu, ghri,
  { {0x7bda010a, 0xb86501fa, 0x212b273b, 0x00000000}},  //   _metu, _بانو, _srch_,
  { {0x44210169, 0x7bda000c, 0x22400065, 0x00000000}},  //   _wah_, _letu, gjik_,
  { {0x313402d3, 0x62580051, 0x6445006c, 0x00000000}},  // [6b30] петр, _síoc, _tohi,
  { {0x645c001f, 0x7bda010a, 0x44210035, 0x00000000}},  //   chri, _netu, _uah_,
  { {0x6aba0022, 0x752d0062, 0x00000000, 0x00000000}},  //   _nutf, _hraz,   ,
  { {0x752d0263, 0x7bda010e, 0x00000000, 0x00000000}},  //   _kraz, _aetu,   ,
  { {0x7bda273c, 0x8c450aed, 0x69d90036, 0x00000000}},  //   _betu, желе, _rewe,
  { {0x69d90007, 0x60cd01a3, 0x752d0161, 0x00000000}},  //   _sewe, mpam, _mraz,
  { {0x7bda008e, 0x7c2100f8, 0x3cef0009, 0x00000000}},  //   _detu, _valr, srgv_,
  { {0x7c2100d9, 0x752d0197, 0x7e690e1a, 0x00000000}},  //   _walr, _oraz, _umep,
  { {0xa3d902fb, 0x2a6d0fd6, 0x60cd1eaf, 0x00000000}},  //   ारा_, rieb_, npam,
  { {0x7bda273d, 0x60cd273e, 0x660d273f, 0x00000000}},  //   _getu, ipam, _abak,
  { {0x752d2740, 0x69d90116, 0xa5bb03fd, 0x00000000}},  //   _araz, _tewe, rdón,
  { {0xd0220055, 0xf5062015, 0x68ee0279, 0x00000000}},  //   নায়_, озмо, ündü,
  { {0x645c018e, 0x37e50f40, 0x2bc602f4, 0x00000000}},  //   thri, _долг, रुवा,
  { {0x752d003b, 0x660d0d49, 0x2bcf007d, 0x00000000}},  //   _draz, _ebak, _स्मा,
  { {0x752d003b, 0x645c000c, 0x225201d6, 0x00000000}},  //   _eraz, rhri, tkyk_,
  { {0x752d0bd7, 0x645c2741, 0x3160002d, 0x00000000}},  //   _fraz, shri, tziz_,
  { {0x752d13f0, 0x645c0051, 0xa06a00c0, 0x00000000}},  // [6b40] _graz, phri, аааа_,
  { {0x22591f7d, 0x00000000, 0x00000000, 0x00000000}},  //   _elsk_,   ,   ,
  { {0x7bda0498, 0xef1a2742, 0x11d60025, 0x00000000}},  //   _retu, рме_, _وتحد,
  { {0x7bda04cb, 0xb5fb2743, 0x1ea90380, 0x00000000}},  //   _setu, liár, ماني_,
  { {0x7bda0169, 0x3ea60516, 0x00000000, 0x00000000}},  //   _petu, rmot_,   ,
  { {0x98a600b9, 0x3cd9007e, 0x8c43003b, 0x00000000}},  //   _proč_, сьцю_, деље,
  { {0x7bda000c, 0x2bc601f5, 0x629600e0, 0x00000000}},  //   _vetu, रुषा, olyo,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x998d014a, 0x4974041f, 0x00000000, 0x00000000}},  //   rdeş_, ялис,   ,
  { {0x31370104, 0x29040a3b, 0xa7fc014a, 0x00000000}},  //   קנים_, rtma_, lnız,
  { {0x752d2744, 0xb5fb0181, 0x2904010e, 0x00000000}},  //   _sraz, diár, stma_,
  { {0x752d1de1, 0xe6670088, 0x00000000, 0x00000000}},  //   _praz, ітно,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc1d3007d, 0xb5fb0e03, 0x752d0253, 0x00000000}},  //   तर्ग, giár, _vraz,
  { {0x9f47038c, 0x6aa21b87, 0x22b80087, 0x00000000}},  //   ünü_, _khof, _očku_,
  { {0x752d016c, 0x95cb053c, 0xa75b00b6, 0x00000000}},  //   _traz, _тука_, _כדור,
  { {0x50f50057, 0x04100044, 0x51f8007e, 0x00000000}},  // [6b50] язат, ায়ী_, ўную_,
  { {0xb5fb0181, 0x60cd008a, 0xea010082, 0x00000000}},  //   ciár, rpam, _đậy_,
  { {0xb5fb0a87, 0x60cd00b4, 0x43950140, 0x00000000}},  //   mháb, spam, _ханс,
  { {0x60cd044e, 0x6f0505ac, 0xa5bb000c, 0x00000000}},  //   ppam, rthc, kdóm,
  { {0x26000204, 0xddc20036, 0x823a00a3, 0x00000000}},  //   ष्टी_, lkoś, _הערצ,
  { {0x645500b5, 0x6aa20258, 0x00000000, 0x00000000}},  //   nkzi, _ahof,   ,
  { {0x62580051, 0x7bc319e4, 0x00000000, 0x00000000}},  //   _míon, rcnu,   ,
  { {0x6aa22745, 0x6258002a, 0x00000000, 0x00000000}},  //   _chof, _líon,   ,
  { {0x2bcf02fb, 0x38ca0014, 0x6e940088, 0x00000000}},  //   _स्था, یایی_, _циту,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb5fb0181, 0xdb1a0146, 0x00000000, 0x00000000}},  //   viár, _aftæ,   ,
  { {0x62580051, 0x6aa20022, 0x00000000, 0x00000000}},  //   _aíon, _ghof,   ,
  { {0x62580051, 0xdddb0059, 0x6aa90637, 0x00000000}},  //   _bíon, _okuž, mmef,
  { {0xddc90209, 0xb5fb0010, 0x00000000, 0x00000000}},  //   _njež, gháb,   ,
  { {0x4256004d, 0xa49b00f6, 0x00000000, 0x00000000}},  //   птат, ctòm,   ,
  { {0xb21b0698, 0x56930184, 0x00000000, 0x00000000}},  //   _skær, _пајт,   ,
  { {0xddc90243, 0x62580048, 0x00000000, 0x00000000}},  // [6b60] _bjež, _fíon,   ,
  { {0xb4d804da, 0x00000000, 0x00000000, 0x00000000}},  //   ाठी_,   ,   ,
  { {0x0dca0088, 0x389a0049, 0x00000000, 0x00000000}},  //   були_, ציענ,   ,
  { {0x9e65023c, 0x00000000, 0x00000000, 0x00000000}},  //   وانن,   ,   ,
  { {0xe3b200a6, 0xacf803e8, 0x00000000, 0x00000000}},  //   _ترک_, інку_,   ,
  { {0x6aa20065, 0x00000000, 0x00000000, 0x00000000}},  //   _shof,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x201a0de5, 0x0f7b00a0, 0x9f5800c4, 0x00000000}},  //   lepi_, _האלב, _ecrã_,
  { {0xd90e06c6, 0xbc660603, 0x15e3013d, 0x00000000}},  //   ایت_, _евак, _ख़बर_,
  { {0xe78602be, 0x201a0d88, 0xa5bb000c, 0x00000000}},  //   зумо, nepi_, rdóm,
  { {0x25a000af, 0x09db0044, 0x21270082, 0x00000000}},  //   _azil_, _ধারা, ̉nh_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x09aa0055, 0x3ce600ca, 0xb5fb0048, 0x00000000}},  //   _গ্রা, nsov_, tháb,
  { {0x201a1a84, 0x00000000, 0x00000000, 0x00000000}},  //   jepi_,   ,   ,
  { {0x92952746, 0xa295007e, 0xd25b1fa1, 0x00000000}},  //   давц, даві, бца_,
  { {0xdddb016e, 0x00000000, 0x00000000, 0x00000000}},  //   _skuž,   ,   ,
  { {0x64410934, 0x212f0048, 0x00000000, 0x00000000}},  // [6b70] ölis, ígh_,   ,
  { {0x2fc7001d, 0x1fa70954, 0x00000000, 0x00000000}},  //   ùng_, прег,   ,
  { {0xddc9016e, 0x7f19023c, 0xb5fb01ca, 0x00000000}},  //   _vjež, تياز_, chác,
  { {0x13e20044, 0x00000000, 0x00000000, 0x00000000}},  //   _বায়,   ,   ,
  { {0xf1ab007a, 0xece80088, 0x3ce6012d, 0x00000000}},  //   _داده_, зділ_, gsov_,
  { {0x5fe1013d, 0x201a0035, 0x224b0145, 0x00000000}},  //   _फ़िल, cepi_, _hock_,
  { {0x9aa500a1, 0x224b04d1, 0x6e67005e, 0x00000000}},  //   ومتو, _kock_, _етаж,
  { {0x3a2600d9, 0x88c9030d, 0x7ae81fcd, 0x00000000}},  //   _caop_, олив_, _dvdt,
  { {0x3a261856, 0x6aa9032e, 0x224b0a6b, 0x00000000}},  //   _daop_, rmef, _mock_,
  { {0x6fb10061, 0x224b0edd, 0x6fdd013d, 0x00000000}},  //   _जणां, _lock_, यरिं,
  { {0xcb5503ab, 0x00000000, 0x00000000, 0x00000000}},  //   _تناظ,   ,   ,
  { {0x2cbf006c, 0xf3e9009b, 0x81d30044, 0x00000000}},  //   _kuud_, _כף_, হৃত_,
  { {0x62580051, 0xb5fb00fa, 0x00000000, 0x00000000}},  //   _díol, riáp,   ,
  { {0x2cbf006c, 0x68fb2747, 0xe8d6009b, 0x00000000}},  //   _muud_, muud, _חוסר_,
  { {0x23270072, 0x224b01a2, 0x00000000, 0x00000000}},  //   мори_, _bock_,   ,
  { {0x09b10044, 0x224b0339, 0xcb12009b, 0x00000000}},  //   _ট্যা, _cock_, כלל_,
  { {0x201a0f7c, 0x998d002b, 0x224b0aa4, 0x00000000}},  // [6b80] tepi_, jjeż_, _dock_,
  { {0x394200b0, 0x2bcf0061, 0x752404a5, 0x00000000}},  //   äksi_, सुमा, _isiz,
  { {0x201a0059, 0x224b0203, 0x645e08a6, 0x00000000}},  //   repi_, _fock_, _ilpi,
  { {0x90c6081e, 0x64920030, 0xf2d30104, 0x00000000}},  //   _обме, pæis, _שער_,
  { {0x61e400b0, 0x60c9005f, 0x92d60044, 0x00000000}},  //   mail, _çemp, _সময়_,
  { {0x13e20055, 0x61e400b0, 0x3dc61575, 0x00000000}},  //   _বাড়, lail, scow_,
  { {0x443a07ec, 0x09e20044, 0x60c408b6, 0x00000000}},  //   _mnp_, _যাবা, lqim,
  { {0x8fa3008b, 0x61e40051, 0x00000000, 0x00000000}},  //   _расе, nail,   ,
  { {0x2bcf02fb, 0x60c2002a, 0x6723008d, 0x00000000}},  //   _स्वा, íomh, _asnj,
  { {0x61e42748, 0x0c2603e8, 0x62580051, 0x00000000}},  //   hail, _імен, _síol,
  { {0x7c3a0585, 0x61e4272e, 0x60c40065, 0x00000000}},  //   _intr, kail, hqim,
  { {0x7c282749, 0x443a0ffb, 0x7e620116, 0x00000000}},  //   _hadr, _anp_, nhop,
  { {0x61e40006, 0x443a274a, 0xb9560014, 0x00000000}},  //   dail, _bnp_, _تئات,
  { {0x7c281144, 0x443a0035, 0x7c2a010f, 0x00000000}},  //   _jadr, _cnp_, ndfr,
  { {0xc6140055, 0x61e40016, 0x7c280781, 0x00000000}},  //   িয়া_, fail, _madr,
  { {0x7c28027b, 0x61e40fec, 0x645e0093, 0x00000000}},  //   _ladr, gail, _elpi,
  { {0x7c3a274b, 0xa2940088, 0x7e6200f8, 0x00000000}},  // [6b90] _ontr, таті, dhop,
  { {0xcf9b012b, 0x443a274c, 0xc1040076, 0x00000000}},  //   оје_, _gnp_, ئولي,
  { {0x8335007b, 0x03d600b6, 0x61e40051, 0x00000000}},  //   _װאָס_, _אותם_, bail,
  { {0x7c3a274d, 0x61e4002a, 0x28df0309, 0x00000000}},  //   _antr, cail, पीडि,
  { {0x7c28274e, 0x644e0746, 0x6468006c, 0x00000000}},  //   _badr, žniš, _äriü,
  { {0x7c28274f, 0x68fb00b0, 0x661d0052, 0x00000000}},  //   _cadr, vuud, hesk,
  { {0x661d08b2, 0x60cf008e, 0x7c280678, 0x00000000}},  //   kesk, _htcm, _dadr,
  { {0xdd9503c8, 0x7e620161, 0xa925013b, 0x00000000}},  //   _забы, chop, едил,
  { {0x661d0056, 0x20010026, 0x6e3b0058, 0x00000000}},  //   desk, oghi_, _inub,
  { {0x6258002a, 0x61e4022b, 0x1cb80014, 0x00000000}},  //   _ríom, zail, _قالب_,
  { {0xe7390200, 0x68fb17f9, 0xd6ce089d, 0x00000000}},  //   чен_, suud, یقی_,
  { {0x661d0007, 0x7c280091, 0x443a0142, 0x00000000}},  //   gesk, _zadr, _snp_,
  { {0x61e42750, 0x443a0058, 0x668400a1, 0x00000000}},  //   vail, _pnp_, ٹیکل,
  { {0x61ef0009, 0x7c2800c4, 0x68e90095, 0x00000000}},  //   _adcl, _xadr, msed,
  { {0xa69602a8, 0x661d0209, 0x9696007c, 0x00000000}},  //   _приј, besk, _приш,
  { {0x69c900b5, 0x20010197, 0x661d10f0, 0x00000000}},  //   ncee, eghi_, cesk,
  { {0x61e4021e, 0x5f4600a1, 0x68e9068f, 0x00000000}},  // [6ba0] rail, کنال, nsed,
  { {0x61e4022b, 0x443a0093, 0x20010026, 0x00000000}},  //   sail, _unp_, gghi_,
  { {0x91e6017f, 0x61e400b0, 0x6e2919d2, 0x00000000}},  //   _поне, pail, _baeb,
  { {0x7c280119, 0x6146025f, 0x68e92370, 0x00000000}},  //   _sadr, _зема, ksed,
  { {0x7e620039, 0xd4690167, 0x60dd0016, 0x00000000}},  //   rhop, _رحیم_, _gwsm,
  { {0x69cb049b, 0x68e907ac, 0x8c430069, 0x00000000}},  //   _afge, dsed, лече,
  { {0x8fa300ed, 0x7e620471, 0x4f950888, 0x00000000}},  //   _баре, phop, _арту,
  { {0x5a3400e3, 0x89382751, 0x0dc90025, 0x00000000}},  //   тнит, дпис_, _يبقى_,
  { {0x81e50055, 0x27ee0032, 0x661d0deb, 0x00000000}},  //   _নাম_, _pdfn_, vesk,
  { {0x473401f9, 0xbc6a0426, 0x7c3a03a1, 0x00000000}},  //   внос, _عمان_, _untr,
  { {0x45d5189f, 0x661d002d, 0xa5f90269, 0x00000000}},  //   конс, tesk, мену_,
  { {0xea01001d, 0xa3d30061, 0x69c92752, 0x00000000}},  //   _đầy_, हुन_, ccee,
  { {0x661d0047, 0x94ab007e, 0x78b8002b, 0x00000000}},  //   resk, зтва_, _tivv,
  { {0x661d08e0, 0xb5fb2753, 0x00000000, 0x00000000}},  //   sesk, chán,   ,
  { {0x02a7005c, 0xb4b10061, 0xd25b01ee, 0x00000000}},  //   ерам, _ओळी_, пца_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7aea001c, 0x2cff02d2, 0xddc90035, 0x00000000}},  // [6bb0] hsft, _ईमेल_, _aleş,
  { {0x6e3b00f8, 0x6e290026, 0x7688026d, 0x00000000}},  //   _snub, _saeb, rıye,
  { {0x20010207, 0xf412009b, 0xddc900e5, 0x00000000}},  //   rghi_, _דפי_, _cleş,
  { {0xa3d90164, 0x68e90016, 0xd130009e, 0x00000000}},  //   ारक_, ysed, جمے_,
  { {0xddc92754, 0xdddb00e5, 0x7c2900e2, 0x00000000}},  //   _eleş, _ajuţ, долг_,
  { {0x22490209, 0x00f60104, 0xeb9900d7, 0x00000000}},  //   ljak_, _במשך_, мил_,
  { {0x7aea001c, 0x2bac0164, 0x00000000, 0x00000000}},  //   gsft, टेला,   ,
  { {0x5f940264, 0x22492755, 0xcd42026c, 0x00000000}},  //   _сист, njak_, _چھوٹ,
  { {0x69c900bb, 0x87f9007e, 0xee840a7c, 0x00000000}},  //   rcee, мэнт_, _сыро,
  { {0x69c9001c, 0x68e9020c, 0x245400f8, 0x00000000}},  //   scee, rsed, _jämt_,
  { {0xf7710084, 0x68e92756, 0x0a1503ab, 0x00000000}},  //   شاد_, ssed, _لواح,
  { {0x68e905ad, 0xf1bf0048, 0x00000000, 0x00000000}},  //   psed, _ngá_,   ,
  { {0xceb20476, 0x22492757, 0xb5fb0048, 0x00000000}},  //   ייט_, djak_, mhál,
  { {0x5ed20055, 0xdb0d000c, 0x290d0035, 0x00000000}},  //   _হিসে, _þjóf, mtea_,
  { {0x160a0061, 0xe29a0088, 0x91e60745, 0x00000000}},  //   _वापर_, дав_, кове,
  { {0x3a2d12aa, 0x00000000, 0x00000000, 0x00000000}},  //   ndep_,   ,   ,
  { {0xe2970265, 0x80c80055, 0x290d26c4, 0x00000000}},  // [6bc0] тат_, _লিঙ্, ntea_,
  { {0xb21b0018, 0xb05b03a9, 0x290d1b86, 0x00000000}},  //   _hjæl, _stär, itea_,
  { {0xe813001c, 0x52aa012b, 0x645c05d5, 0x00000000}},  //   त्या_, _овом_, mkri,
  { {0x75361f00, 0xedf40014, 0x81e50044, 0x00000000}},  //   _kryz, ايشگ, _নাথ_,
  { {0xb5fb0051, 0x00000000, 0x00000000, 0x00000000}},  //   dhál,   ,   ,
  { {0x201e11ea, 0xe813007d, 0x00000000, 0x00000000}},  //   _úti_, त्मा_,   ,
  { {0xbae3008b, 0xdee601ee, 0x00000000, 0x00000000}},  //   ацый, _шови,   ,
  { {0x645c0065, 0x290d0035, 0xc7b811af, 0x00000000}},  //   hkri, ftea_, jeđa_,
  { {0xfe91007a, 0x645c000c, 0xac0a00ed, 0x00000000}},  //   _اینج, kkri, _онаа_,
  { {0xea01001d, 0x2249050f, 0x645c01d6, 0x00000000}},  //   _đấy_, zjak_, jkri,
  { {0xb5fb0051, 0x3ffb009b, 0x645c17f1, 0x00000000}},  //   bhál, ופיע, dkri,
  { {0xcf93009b, 0x7b790049, 0x645c01d6, 0x00000000}},  //   יטת_, _אָנצ, ekri,
  { {0xd048005f, 0xda650379, 0x290d004a, 0x00000000}},  //   şlər, _حالي, ctea_,
  { {0x645c0116, 0x491700a3, 0x00000000, 0x00000000}},  //   gkri, _סקול_,   ,
  { {0xa2af0204, 0x20070129, 0x9484007e, 0x00000000}},  //   ंगल्, ònim_, рыяд,
  { {0x75360036, 0x32640457, 0x31690032, 0x00000000}},  //   _fryz, атув, tzaz_,
  { {0xe3e20044, 0xdddb0166, 0x75360a3d, 0x00000000}},  // [6bd0] _বারব, _njuš, _gryz,
  { {0xc058008b, 0x645c03ce, 0x00000000, 0x00000000}},  //   кіх_, ckri,   ,
  { {0x290d022b, 0x9df900ed, 0x76880276, 0x00000000}},  //   ztea_, енет_, lıya,
  { {0x765d0263, 0xe0df01aa, 0x20070036, 0x00000000}},  //   nksy, _twò_, żni_,
  { {0x7688005d, 0xa5bb004a, 0x00000000, 0x00000000}},  //   nıya, cdót,   ,
  { {0xc1b80245, 0x9f4100f6, 0x00000000, 0x00000000}},  //   _шлях_, lahí_,   ,
  { {0xeb961984, 0xb5fb0048, 0x00000000, 0x00000000}},  //   лиш_, thál,   ,
  { {0x645c1701, 0x0b160025, 0x290d0032, 0x00000000}},  //   zkri, اقية_, ttea_,
  { {0x3a2d0022, 0x00000000, 0x00000000, 0x00000000}},  //   rdep_,   ,   ,
  { {0x290d22d5, 0xb21b0030, 0xe8f60147, 0x00000000}},  //   rtea_, _sjæl, ыль_,
  { {0x290d22d5, 0xfc3003ab, 0xddc90235, 0x00000000}},  //   stea_, _بحق_, _zmeš,
  { {0x290d001a, 0x98ad0059, 0x786400f6, 0x00000000}},  //   ptea_, mveč_, _ròve,
  { {0x6d592758, 0x09b10044, 0x645c016e, 0x00000000}},  //   nywa, _ট্রা, tkri,
  { {0x69db002d, 0x68fb00e7, 0x98790049, 0x00000000}},  //   lbue, mrud, _ראַט,
  { {0x645c00b5, 0xe89800a1, 0x638600aa, 0x00000000}},  //   rkri, _جموں_, угва,
  { {0x645c0292, 0x68fb1dce, 0x98a601ed, 0x00000000}},  //   skri, orud, _proć_,
  { {0x645c0006, 0x614302dc, 0xa49b00f6, 0x00000000}},  // [6be0] pkri, бета, dròf,
  { {0xa5bb000c, 0x7bc10048, 0xf8c80082, 0x00000000}},  //   rdót, _nglu, _hức_,
  { {0xddc92759, 0xa5bb000c, 0x68fb0093, 0x00000000}},  //   _smeš, sdót, hrud,
  { {0xe813007d, 0x7bc100d4, 0xdee3007c, 0x00000000}},  //   त्ता_, _aglu, соци,
  { {0xf8c8001d, 0x68fb0190, 0x9f430173, 0x00000000}},  //   _mức_, jrud, _lejè_,
  { {0x61e60fd1, 0xac1802e9, 0x68fb02ef, 0x00000000}},  //   _hekl, току_, drud,
  { {0x260503d7, 0x1fb50057, 0x60c600e7, 0x00000000}},  //   _वाली_, _встр, _hukm,
  { {0x628400b0, 0x6d590036, 0x7bc104a2, 0x00000000}},  //   nnio, bywa, _eglu,
  { {0x61e6001e, 0x68fb0107, 0xddc908de, 0x00000000}},  //   _mekl, grud, _umeš,
  { {0xad1b0104, 0x7d02010a, 0x60c6008a, 0x00000000}},  //   _אומר, muos, _mukm,
  { {0xb8cb03d7, 0xf8c80011, 0x60c60093, 0x00000000}},  //   _की_, _bức_, _lukm,
  { {0x69dd000c, 0x68fb0374, 0x6296275a, 0x00000000}},  //   ðset, brud, joyo,
  { {0x55070642, 0x62840046, 0x4a7b0049, 0x00000000}},  //   ычна, dnio, _אראב,
  { {0xd7ef012b, 0x62840036, 0x200a275b, 0x00000000}},  //   _ћу_, enio, _ncbi_,
  { {0x61e6011f, 0x6d590036, 0x2cac0022, 0x00000000}},  //   _bekl, zywa, _mhdd_,
  { {0x2018009d, 0x7d020006, 0x61e60022, 0x00000000}},  //   _abri_, kuos, _cekl,
  { {0x61e623ab, 0x7d020006, 0xe6100025, 0x00000000}},  // [6bf0] _dekl, juos, _رشي_,
  { {0x7d02275c, 0xb604013e, 0x61e600d9, 0x00000000}},  //   duos, rkář, _eekl,
  { {0x7d1b0209, 0x6d59275d, 0x44230871, 0x00000000}},  //   _spus, wywa, mej_,
  { {0x61e6275e, 0x44230027, 0xcf98012b, 0x00000000}},  //   _gekl, lej_, ују_,
  { {0x7d02275f, 0x00000000, 0x00000000, 0x00000000}},  //   guos,   ,   ,
  { {0x44230620, 0xed56013b, 0x6d590036, 0x00000000}},  //   nej_, рош_, rywa,
  { {0x6d590036, 0x6e222760, 0x68e2000a, 0x00000000}},  //   sywa, beob, _awod,
  { {0x68fb2145, 0x7f840054, 0x442303c4, 0x00000000}},  //   trud, _الفن, hej_,
  { {0x442307e7, 0x0d67005e, 0xe40a006b, 0x00000000}},  //   kej_, _съвм, _çiçə,
  { {0x7ae701fb, 0xf8c8001d, 0x44230620, 0x00000000}},  //   _бюдж, _sức_, jej_,
  { {0x44230224, 0x366a004c, 0x62842761, 0x00000000}},  //   dej_, вано_, ynio,
  { {0x68fb06c2, 0x44310089, 0x212b00d9, 0x00000000}},  //   prud, edz_, _osch_,
  { {0x9f43008e, 0x249a0022, 0x00000000, 0x00000000}},  //   _dejé_, _pkpm_,   ,
  { {0x61e6002b, 0x052700ed, 0x38ab01e3, 0x00000000}},  //   _sekl, јорк_, føre_,
  { {0x46a61364, 0xf8c8001d, 0xf66a03ec, 0x00000000}},  //   _какв, _tức_, _لحظه_,
  { {0xb22600ed, 0x7688014a, 0xb3470181, 0x00000000}},  //   јмал, mıyo, _seçõ,

  { {0x7688011f, 0x44231a2d, 0x62840205, 0x00000000}},  // [6c00] lıyo, bej_, rnio,
  { {0x27e701aa, 0xa49b04bd, 0x44232762, 0x00000000}},  //   _jenn_, stòr, cej_,
  { {0x27e70fdc, 0x26c72467, 0x93fb0097, 0x00000000}},  //   _menn_, _juno_, _בליי,
  { {0xed5a2763, 0x7d020006, 0xf8c80011, 0x00000000}},  //   кое_, tuos, _lứa_,
  { {0x1bd4005e, 0x26c700ca, 0x6e220087, 0x00000000}},  //   боля, _luno_, reob,
  { {0x7c23068a, 0x7d02143d, 0x5c730088, 0x00000000}},  //   genr, ruos, оліт,
  { {0xb5fb015f, 0x26c700c4, 0x7d020ecb, 0x00000000}},  //   nkác, _nuno_, suos,
  { {0x44230046, 0x68e20263, 0xeb97003b, 0x00000000}},  //   zej_, _pwod, јић_,
  { {0x7c232764, 0x48aa0a33, 0x7d020026, 0x00000000}},  //   benr, ктом_, quos,
  { {0xb5fb0051, 0xe8060061, 0x26c70009, 0x00000000}},  //   mhái, _शाळा_, _buno_,
  { {0x27e7001f, 0x44230027, 0x2bcf02fb, 0x00000000}},  //   _denn_, vej_, _स्टा,
  { {0x44230046, 0x6f030129, 0x62580051, 0x00000000}},  //   wej_, ànci, _míos,
  { {0x44230027, 0x768801df, 0x27e70010, 0x00000000}},  //   tej_, mıyl, _fenn_,
  { {0x2904001e, 0x27e72765, 0x25a90062, 0x00000000}},  //   muma_, _genn_, _vzal_,
  { {0x44230cce, 0x29040459, 0x44310142, 0x00000000}},  //   rej_, luma_, rdz_,
  { {0xd7bb00b6, 0x442301a3, 0x7c2300d9, 0x00000000}},  //   _בצור, sej_, zenr,
  { {0x4423002b, 0x29042766, 0x00000000, 0x00000000}},  // [6c10] pej_, numa_,   ,
  { {0xb5fb0051, 0x44230065, 0x3ead18a4, 0x00000000}},  //   dhái, qej_, _shet_,
  { {0x2904000b, 0x7c2300bb, 0x62580051, 0x00000000}},  //   huma_, venr, _cíos,
  { {0x2904001e, 0xf2d2009b, 0x62580051, 0x00000000}},  //   kuma_, _מעט_, _díos,
  { {0x2904001e, 0x61ed0cfc, 0x7c23054e, 0x00000000}},  //   juma_, maal, tenr,
  { {0x2904000b, 0x61ed1fc7, 0xa3be006e, 0x00000000}},  //   duma_, laal, ुँच_,
  { {0x2a6621b3, 0x27e700ea, 0x7c2301a2, 0x00000000}},  //   _blob_, _renn_, renr,
  { {0xb5fb002a, 0x61ed0cfc, 0x3209011c, 0x00000000}},  //   bhái, naal, ngay_,
  { {0x29041e8f, 0xb5fb002a, 0x7c23021f, 0x00000000}},  //   guma_, chái, penr,
  { {0x26c7011c, 0x61ed00b5, 0x7688014a, 0x00000000}},  //   _puno_, haal, tıyo,
  { {0x2bdd02f4, 0x61ed2767, 0x24982768, 0x00000000}},  //   _न्या, kaal, vorm_,
  { {0x27e7001f, 0x6b7a0049, 0x2904016e, 0x00000000}},  //   _wenn_, _גרענ, buma_,
  { {0x1e3a007b, 0x29040089, 0x61ed044e, 0x00000000}},  //   אגרא, cuma_, daal,
  { {0xa3d3007d, 0x7688014a, 0x43f9007c, 0x00000000}},  //   हुल_, pıyo, ихся_,
  { {0xe79a00b9, 0x9359007e, 0x61ed0dd7, 0x00000000}},  //   _těší, арту_, faal,
  { {0xe81302d2, 0x5756009b, 0x61ed2769, 0x00000000}},  //   त्रा_, _לבצע_, gaal,
  { {0x41aa00e3, 0x61430867, 0xc69300a0, 0x00000000}},  // [6c20] уван_, пета, _מאה_,
  { {0x629d0089, 0x62580051, 0x00000000, 0x00000000}},  //   _ekso, _píos,   ,
  { {0x61ed05e0, 0x20b9007c, 0xa3b4007d, 0x00000000}},  //   baal, рыть_, जेश_,
  { {0x4444276a, 0x2904276b, 0xb5fb0051, 0x00000000}},  //   _hn_, yuma_, thái,
  { {0x44440209, 0x62580051, 0xfff802fd, 0x00000000}},  //   _kn_, _fíor, _نکات_,
  { {0x444409ac, 0x2904276c, 0x00000000, 0x00000000}},  //   _jn_, vuma_,   ,
  { {0x44440e6d, 0x907b007b, 0x3a240066, 0x00000000}},  //   _mn_, _עטלי, temp_,
  { {0x290412bd, 0xb5fb276d, 0x00000000, 0x00000000}},  //   tuma_, phái,   ,
  { {0x4444167c, 0x768801df, 0x7e620089, 0x00000000}},  //   _on_, rıyl, mkop,
  { {0x4444225f, 0x768801df, 0x7e620036, 0x00000000}},  //   _nn_, sıyl, lkop,
  { {0x2904002d, 0xa09b0097, 0xab960025, 0x00000000}},  //   suma_, רייט, _الضغ,
  { {0x4444276e, 0x656f01a2, 0x00000000, 0x00000000}},  //   _an_, tzch,   ,
  { {0x444401a3, 0x61ed115d, 0x2c6b0056, 0x00000000}},  //   _bn_, vaal, _fødd_,
  { {0x81e50055, 0x5ed90055, 0x4444276f, 0x00000000}},  //   _নাই_, _ডিসে, _cn_,
  { {0x44442770, 0x61ed02ae, 0xa3d800e8, 0x00000000}},  //   _dn_, taal, ाड़_,
  { {0xe5c7013b, 0x62580048, 0x7e6200bb, 0x00000000}},  //   _уско, _síor, jkop,
  { {0x61ed003c, 0x7e6200b5, 0x9055017f, 0x00000000}},  // [6c30] raal, dkop, овац,
  { {0x444414ad, 0x61ed00b0, 0x21290022, 0x00000000}},  //   _gn_, saal, rwah_,
  { {0x61ed02ae, 0x644500ab, 0x2c6b0056, 0x00000000}},  //   paal, _inhi, _jøde_,
  { {0x44440161, 0x2c6b0030, 0x443301f3, 0x00000000}},  //   _zn_, _møde_, _hax_,
  { {0x44442771, 0x62580051, 0xccfb003b, 0x00000000}},  //   _yn_, _tíor, уће_,
  { {0x443301d6, 0x351c009b, 0x44440082, 0x00000000}},  //   _jax_, טודנ, _xn_,
  { {0x645704d2, 0xb21b0190, 0x00000000, 0x00000000}},  //   _moxi, _djæv,   ,
  { {0x44330479, 0x9f430224, 0x7e622772, 0x00000000}},  //   _lax_, _její_, ckop,
  { {0x4433004a, 0x00000000, 0x00000000, 0x00000000}},  //   _oax_,   ,   ,
  { {0x64570719, 0xd83801aa, 0x386c0009, 0x00000000}},  //   _noxi, blčm_, ghdr_,
  { {0xf6260373, 0x44440181, 0x7e690059, 0x00000000}},  //   одно, _rn_, _klep,
  { {0xa3bf007d, 0x9f4a0181, 0x3cf0013d, 0x00000000}},  //   ेशन_, _bebê_, ुंचे_,
  { {0x4433006b, 0x1c1e013d, 0x645714f4, 0x00000000}},  //   _bax_, _मॉडल_, _boxi,
  { {0x66e50265, 0xe739026b, 0x81c10044, 0x00000000}},  //   _дока, _век_, ুরা_,
  { {0x444400ad, 0xa3b403d7, 0x42560256, 0x00000000}},  //   _vn_, जें_, отат,
  { {0x4444005b, 0x644500e0, 0xb5fb2773, 0x00000000}},  //   _wn_, _enhi, lkán,
  { {0x44441287, 0x394d00d4, 0x7e6200ca, 0x00000000}},  // [6c40] _tn_, nxes_, vkop,
  { {0xa3eb0316, 0x394d0129, 0x00000000, 0x00000000}},  //   मरण_, ixes_,   ,
  { {0x7e69098e, 0x00000000, 0x00000000, 0x00000000}},  //   _blep,   ,   ,
  { {0x614600ed, 0x44330035, 0xf3f10082, 0x00000000}},  //   _дема, _zax_, ực_,
  { {0x7e6200b5, 0xbc4a012b, 0xff0a0044, 0x00000000}},  //   rkop, ичке_, রবেশ_,
  { {0x7e622774, 0xdee60264, 0x653b0049, 0x00000000}},  //   skop, _моги, יענד,
  { {0x7e621a85, 0xbb4300e2, 0x00000000, 0x00000000}},  //   pkop, дејк,   ,
  { {0x2c6b01e3, 0x1fa70088, 0xdb01009d, 0x00000000}},  //   _røde_, _єкти_, _mylè,
  { {0xf98f00a1, 0x2c6b0030, 0xbe130355, 0x00000000}},  //   ہبی_, _søde_, _توقع,
  { {0x3ea62775, 0x7d020093, 0x7e690161, 0x00000000}},  //   llot_, mros, _zlep,
  { {0x7d0200f8, 0xd8380059, 0x7bc800e0, 0x00000000}},  //   lros, joče_, _igdu,
  { {0x3ea60093, 0x7d020275, 0x8f9b009b, 0x00000000}},  //   nlot_, oros, שיטי,
  { {0x7d02069a, 0x00000000, 0x00000000, 0x00000000}},  //   nros,   ,   ,
  { {0x7d0200fa, 0x00000000, 0x00000000, 0x00000000}},  //   iros,   ,   ,
  { {0xd83801d9, 0x443300f8, 0x23650010, 0x00000000}},  //   goče_, _vax_, álj_,
  { {0x44f5003b, 0x26de09fb, 0x47890451, 0x00000000}},  //   _епис, mpto_, _усім_,
  { {0x44331eef, 0x3ea62776, 0x1ad60044, 0x00000000}},  // [6c50] _tax_, dlot_, সওয়া,
  { {0x30a7007e, 0xd83800ca, 0xa25b0082, 0x00000000}},  //   ірав, ločb_, _giôn,
  { {0xd25000a1, 0x7d0208a6, 0xa2c40061, 0x00000000}},  //   رنے_, eros, _ांच्,
  { {0xb5fb0802, 0x3ea601c5, 0x05af0061, 0x00000000}},  //   chát, glot_, _घराब,
  { {0x7d022777, 0x61e20211, 0xb3bd0044, 0x00000000}},  //   gros, ñole, _অভিজ,
  { {0xc6270044, 0x00000000, 0x00000000, 0x00000000}},  //   যাটা_,   ,   ,
  { {0x3ea616cc, 0x7d020026, 0x00000000, 0x00000000}},  //   blot_, aros,   ,
  { {0x6d5c005f, 0x7e7b2778, 0x7e690c02, 0x00000000}},  //   _əraz, _umup, _ulep,
  { {0xb5fb245b, 0x13a8007d, 0x225900e0, 0x00000000}},  //   tkán, _गर्भ, _mosk_,
  { {0x394d0129, 0x9f4a0c42, 0x395f1d8b, 0x00000000}},  //   rxes_, _bebè_, ryus_,
  { {0xf7450088, 0x786d000c, 0x38ab0030, 0x00000000}},  //   чено, _núve, børn_,
  { {0xeaae0088, 0xb5fb00b9, 0x00000000, 0x00000000}},  //   _їй_, skán,   ,
  { {0xd94509bb, 0xe79a00b9, 0x09e20044, 0x00000000}},  //   _хели, _měří, _যাচা,
  { {0xa7fc014a, 0x00000000, 0x00000000, 0x00000000}},  //   lkın,   ,   ,
  { {0x69d2001c, 0xb5fb0051, 0x43430745, 0x00000000}},  //   णुकी, thát, нерв,
  { {0xa7fc0477, 0xb5fb0010, 0xcfe80044, 0x00000000}},  //   nkın, nkál, _পাইন,
  { {0xdfd20025, 0xf0ba00a1, 0xb5fb05ee, 0x00000000}},  // [6c60] فيذ_, مائش_, rhát,
  { {0xd3e402fd, 0xb5fb2779, 0x6281009d, 0x00000000}},  //   _تقدی, shát, élor,
  { {0xa7fc011f, 0xd00f01af, 0xef1a003b, 0x00000000}},  //   kkın, الم_, сме_,
  { {0x442a1c0b, 0x7d020059, 0x443821b3, 0x00000000}},  //   leb_, tros, ldr_,
  { {0x61e40145, 0x3ea600ea, 0xdca601fc, 0x00000000}},  //   mbil, rlot_, пади,
  { {0x7d0200b0, 0x61e4277a, 0x442a165a, 0x00000000}},  //   rros, lbil, neb_,
  { {0x3ea6277b, 0x7d02277c, 0xb21b00ea, 0x00000000}},  //   plot_, sros, _gjæs,
  { {0x7d020292, 0x442a277d, 0xdb0f000c, 0x00000000}},  //   pros, heb_, _ódýr,
  { {0x61e40197, 0xb21b043e, 0x442a0085, 0x00000000}},  //   ibil, _kjær, keb_,
  { {0x9873007c, 0x6d40065a, 0x645a00b0, 0x00000000}},  //   ельц, _irma, ötil,
  { {0x1faa03d7, 0x7c2a0606, 0x442a018e, 0x00000000}},  //   _करोड, mefr, deb_,
  { {0x7c2a0030, 0xfb87026c, 0x7c380116, 0x00000000}},  //   lefr, _عدلی, ldvr,
  { {0x442a005b, 0x00000000, 0x00000000, 0x00000000}},  //   feb_,   ,   ,
  { {0x27e900ad, 0x442a01f3, 0x7c2a0197, 0x00000000}},  //   _đang_, geb_, nefr,
  { {0x75240213, 0x85570014, 0xc5ec0044, 0x00000000}},  //   _epiz, زیگر_, _কারা_,
  { {0x6d40277e, 0xfbdf001d, 0x61e4011c, 0x00000000}},  //   _orma, _đêm_, gbil,
  { {0xd49b0805, 0x442a277f, 0x7c2a0190, 0x00000000}},  // [6c70] _грн_, beb_, kefr,
  { {0x61e40207, 0x81e50044, 0x661d01a2, 0x00000000}},  //   abil, _নাও_, lfsk,
  { {0x61e401d5, 0x06e00044, 0x7c2a0190, 0x00000000}},  //   bbil, _ভিডি, defr,
  { {0x8d7400a1, 0x6d400085, 0x00000000, 0x00000000}},  //   کاما, _brma,   ,
  { {0xc7b80119, 0x44210030, 0x2f150039, 0x00000000}},  //   među_, _kbh_, såg_,
  { {0x7c2a0c53, 0x60dd00d9, 0x2904016c, 0x00000000}},  //   gefr, _itsm, drma_,
  { {0xff040783, 0x44212780, 0x2c0e0061, 0x00000000}},  //   _пятн, _mbh_, _सारं_,
  { {0xac77007a, 0x442a2781, 0x628d006c, 0x00000000}},  //   _کارش, zeb_, nnao,
  { {0x61ef014a, 0x6d402782, 0xa7fc005a, 0x00000000}},  //   _mecl, _grma, rkın,
  { {0x60c701aa, 0xa3bf006e, 0x27ee0016, 0x00000000}},  //   _jijm, ेशा_, _cefn_,
  { {0x752f0046, 0x61e40030, 0x61fd0a0f, 0x00000000}},  //   ewcz, ybil, _odsl,
  { {0x442a0129, 0x61ef149f, 0x60c700bb, 0x00000000}},  //   web_, _necl, _lijm,
  { {0x442a2783, 0xe577007e, 0x6aa90009, 0x00000000}},  //   teb_, дзя_, mlef,
  { {0x6aa90039, 0x60c700b5, 0x61fd004a, 0x00000000}},  //   llef, _nijm, _adsl,
  { {0x61e42784, 0x44210032, 0x44380146, 0x00000000}},  //   tbil, _dbh_, rdr_,
  { {0x442a0ab5, 0x6aa90050, 0xd2aa007e, 0x00000000}},  //   seb_, nlef, ікае_,
  { {0x61e41103, 0x8ffa05d4, 0x61ef0585, 0x00000000}},  // [6c80] rbil, قرار_, _decl,
  { {0x61e4010f, 0x442100d2, 0x00000000, 0x00000000}},  //   sbil, _gbh_,   ,
  { {0x69cb2785, 0xee3a0407, 0x68e4002b, 0x00000000}},  //   _ogge, жне_, _ħidm,
  { {0x0d860425, 0xdee300ed, 0x7c2a0016, 0x00000000}},  //   млен, тоци, wefr,
  { {0x7c2a010f, 0xdddb012d, 0x6aa90045, 0x00000000}},  //   tefr, _fjuž, dlef,
  { {0x69cb0207, 0x69d901b5, 0x6aa201d6, 0x00000000}},  //   _agge, _afwe, _skof,
  { {0x7d0b0006, 0xd8380059, 0x2ea900a1, 0x00000000}},  //   augs, joča_, _کھلی_,
  { {0x6aa908e0, 0x7d0b149e, 0x26ce0249, 0x00000000}},  //   glef, bugs, _rufo_,
  { {0x6d402786, 0x00000000, 0x00000000, 0x00000000}},  //   _urma,   ,   ,
  { {0x69cb000c, 0x6c8604e8, 0x0c231281, 0x00000000}},  //   _egge, _غلام, _имун,
  { {0xd8380059, 0x6aa92787, 0x78a80145, 0x00000000}},  //   goča_, blef, rldv,
  { {0x6aa90045, 0x786400f6, 0x00000000, 0x00000000}},  //   clef, _mòvi,   ,
  { {0x9f410051, 0x661d000c, 0x442100fa, 0x00000000}},  //   rbhé_, rfsk, _pbh_,
  { {0x26ce0026, 0x61ef032c, 0x00000000, 0x00000000}},  //   _tufo_, _secl,   ,
  { {0x7d0b2788, 0xb8650426, 0x786400f6, 0x00000000}},  //   zugs, _ثانو, _nòvi,
  { {0x6aa00039, 0xe5c7025f, 0x96fb009b, 0x00000000}},  //   nomf, _оспо, _ולהת,
  { {0x61e2008e, 0x00000000, 0x00000000, 0x00000000}},  // [6c90] ñola,   ,   ,
  { {0xa7fc014a, 0x44212789, 0x00000000, 0x00000000}},  //   kkım, _ubh_,   ,
  { {0x61ef0325, 0x6aa001a2, 0x60c70023, 0x00000000}},  //   _tecl, komf, _vijm,
  { {0x7bda009f, 0xd13000a1, 0x61fd0190, 0x00000000}},  //   _aftu, دمے_, _udsl,
  { {0x26c90058, 0x6aa9000f, 0x60dd278a, 0x00000000}},  //   _miao_, vlef, _utsm,
  { {0x7d0b0bcb, 0x6aa90009, 0xc6230044, 0x00000000}},  //   rugs, wlef, _বোমা_,
  { {0x6aa9278b, 0xfaa5041f, 0xa7fc014a, 0x00000000}},  //   tlef, нако, rkıl,
  { {0xa49b00d4, 0x00000000, 0x00000000, 0x00000000}},  //   dròm,   ,   ,
  { {0x6aa90009, 0x6abb0146, 0x00000000, 0x00000000}},  //   rlef, rmuf,   ,
  { {0x6aa900f8, 0x44ed1238, 0x6d8a00a1, 0x00000000}},  //   slef, dž_, _عملہ_,
  { {0x6aa90061, 0x25a90022, 0x26c90288, 0x00000000}},  //   plef, _ayal_, _biao_,
  { {0x26c90198, 0x4975003b, 0xd8380059, 0x00000000}},  //   _ciao_, _плес, roča_,
  { {0x26c90203, 0x46cf0061, 0x6c760082, 0x00000000}},  //   _diao_, _सूरह, _hànộ,
  { {0xe1ff0010, 0x6c790049, 0x3a2d0aba, 0x00000000}},  //   _adó_, לאָפ, leep_,
  { {0xe0df01aa, 0xa49b00f6, 0x366a0140, 0x00000000}},  //   _atò_, cròm, _нако_,
  { {0x26c9001d, 0xe0da0265, 0x09c30044, 0x00000000}},  //   _giao_, зва_, _এ্যা,
  { {0x41270200, 0xd5b2006d, 0xd12f00a1, 0x00000000}},  // [6ca0] ното_, _حفظ_, یمہ_,
  { {0x80a60070, 0xfe0d013d, 0x00000000, 0x00000000}},  //   رمان, _हाउस_,   ,
  { {0xb4be0164, 0x656601d6, 0x6aa000e7, 0x00000000}},  //   ेदी_, lykh, yomf,
  { {0x2bdd0164, 0x443a278c, 0x35a5013d, 0x00000000}},  //   नुसा, _hap_, _गुड़,
  { {0x443a0263, 0x3a2d0719, 0xb7bc0089, 0x00000000}},  //   _kap_, deep_, reģi,
  { {0x443a24d6, 0x61f6014a, 0x645e00ca, 0x00000000}},  //   _jap_, layl, _jopi,
  { {0xa3b40061, 0x6aa000ea, 0x00000000, 0x00000000}},  //   जेच_, tomf,   ,
  { {0x443a278d, 0x645e01aa, 0x00000000, 0x00000000}},  //   _lap_, _lopi,   ,
  { {0x6aa0278e, 0x999800b9, 0xec7a02b3, 0x00000000}},  //   romf, ěrů_, _епа_,
  { {0x443a278d, 0x645e001e, 0x49730b5f, 0x00000000}},  //   _nap_, _nopi, ульс,
  { {0x7c3a00e0, 0x25a90093, 0x25ac006b, 0x00000000}},  //   _iatr, _syal_, ədli_,
  { {0x7c3a278f, 0x443a0116, 0x7688014a, 0x00000000}},  //   _hatr, _aap_, dıys,
  { {0x7c3a001e, 0xb1120044, 0x443a0093, 0x00000000}},  //   _katr, হবুব_, _bap_,
  { {0x443a04bd, 0x7c3a1e36, 0x69dc0036, 0x00000000}},  //   _cap_, _jatr, śred,
  { {0x645e0036, 0x083b00a3, 0x43940849, 0x00000000}},  //   _dopi, _מעגל, гарс,
  { {0x7c3a10d1, 0x443a2790, 0x32c70016, 0x00000000}},  //   _latr, _eap_, _gŵyl_,
  { {0x764d000b, 0x443a0f75, 0x9f4a004a, 0x00000000}},  // [6cb0] _inay, _fap_, _debí_,
  { {0x7c3a12da, 0x249700a1, 0x443a0a60, 0x00000000}},  //   _natr, _سمجھ_, _gap_,
  { {0xdea1025a, 0x61f60095, 0x00000000, 0x00000000}},  //   لیسی, bayl,   ,
  { {0xa2d602fb, 0x78a12791, 0x443a00c4, 0x00000000}},  //   _मंत्, zolv, _zap_,
  { {0x443a2792, 0x7c3a1567, 0x764d00e7, 0x00000000}},  //   _yap_, _batr, _mnay,
  { {0x7c3a2793, 0xc4d40049, 0x443a0009, 0x00000000}},  //   _catr, אגס_, _xap_,
  { {0x78a11044, 0x764d014a, 0x7c3a0016, 0x00000000}},  //   volv, _onay, _datr,
  { {0xcff60044, 0x0b880025, 0x7c3a0048, 0x00000000}},  //   _চায়_, عضوي_, _eatr,
  { {0x3a2d0116, 0x7c3a15d8, 0xdb0801dc, 0x00000000}},  //   reep_, _fatr, _vzdá,
  { {0x29032794, 0x764d187c, 0x20130066, 0x00000000}},  //   čja_, _anay, ngxi_,
  { {0x6e3b2795, 0x443a0011, 0x25c7005f, 0x00000000}},  //   _kaub, _rap_, ətlə_,
  { {0x443a0129, 0x7c3a2145, 0x645e021e, 0x00000000}},  //   _sap_, _zatr, _sopi,
  { {0x645e2796, 0x443a0263, 0x6e3b0f91, 0x00000000}},  //   _popi, _pap_, _maub,
  { {0x232a01fb, 0x68fb2797, 0x6e3b01a2, 0x00000000}},  //   моги_, msud, _laub,
  { {0x6383008b, 0xf8c8001d, 0x61f6011f, 0x00000000}},  //   агра, _cứu_, tayl,
  { {0x443a0263, 0x69db0211, 0x6e3b0058, 0x00000000}},  //   _wap_, ncue, _naub,
  { {0x443a0263, 0x68fb0190, 0x61f6014a, 0x00000000}},  // [6cc0] _tap_, nsud, rayl,
  { {0x443a0093, 0x3fe32798, 0xa5bb00c4, 0x00000000}},  //   _uap_, ижув, reót,
  { {0x7c3a0173, 0xdfcf0380, 0x6e3b1d93, 0x00000000}},  //   _ratr, زين_, _baub,
  { {0xfce6013b, 0x68fb033b, 0x9f510065, 0x00000000}},  //   водо, ksud, _zezë_,
  { {0xdd8f0054, 0x786d0129, 0x6e3b2799, 0x00000000}},  //   يوم_, _núvo, _daub,
  { {0x68fb279a, 0x7c3a002b, 0x00000000, 0x00000000}},  //   dsud, _qatr,   ,
  { {0x7c3a0363, 0x6e3b009d, 0xf8c80082, 0x00000000}},  //   _vatr, _faub, _mứt_,
  { {0x2bc101f5, 0x6e3b007f, 0x5a340745, 0x00000000}},  //   षेधा, _gaub, унит,
  { {0x7e60002a, 0x7c3a0027, 0x67d400e2, 0x00000000}},  //   _iomp, _tatr, лопу,
  { {0x6e3b010f, 0x3ce62782, 0xf8c80082, 0x00000000}},  //   _zaub, mpov_, _nứt_,
  { {0x81cb0055, 0x00000000, 0x00000000, 0x00000000}},  //   রুপ_,   ,   ,
  { {0x6489010a, 0x9f5101aa, 0x6b7b01ce, 0x00000000}},  //   džia, _dezè_, _קראנ,
  { {0x3940002a, 0x7e600129, 0xf8c80082, 0x00000000}},  //   _éis_, _momp, _bứt_,
  { {0xdddb011f, 0xd7ef0098, 0xf00b0011, 0x00000000}},  //   _oluş, _њу_, _đắng_,
  { {0x81e40055, 0x47c00044, 0x248d0091, 0x00000000}},  //   _নয়_, _শ্রী, đem_,
  { {0x764d0e1a, 0x2018060c, 0x39460253, 0x00000000}},  //   _unay, _acri_, _kros_,
  { {0x2ba903d7, 0xc05b0ee0, 0x81cb0044, 0x00000000}},  // [6cd0] _चुना, між_, রুন_,
  { {0x6e3b010f, 0x00000000, 0x00000000, 0x00000000}},  //   _saub,   ,   ,
  { {0x4431014a, 0x2fc70073, 0x7e600197, 0x00000000}},  //   mez_, äng_, _bomp,
  { {0x4431028c, 0x394600ea, 0xacf9080d, 0x00000000}},  //   lez_, _oros_, енду_,
  { {0x93c9026c, 0x7e60023a, 0x38b900f4, 0x00000000}},  //   _تاکہ_, _domp, lère_,
  { {0x4431022b, 0xa3b70309, 0x67380243, 0x00000000}},  //   nez_, _जरा_, _osvj,
  { {0x4fc40373, 0x3ec7008b, 0x3946018e, 0x00000000}},  //   _вста, _асаб, _aros_,
  { {0x4431279b, 0x3946023a, 0x68fb279c, 0x00000000}},  //   hez_, _bros_, tsud,
  { {0x394600d4, 0x38b900f4, 0x4431002d, 0x00000000}},  //   _cros_, hère_, kez_,
  { {0x3946018e, 0x46e9026b, 0x44310035, 0x00000000}},  //   _dros_, ндон_, jez_,
  { {0x4431022b, 0x68fb00d4, 0xb7c30044, 0x00000000}},  //   dez_, ssud, োর্ট,
  { {0x38b9009d, 0xa50a02dc, 0xddc201c5, 0x00000000}},  //   dère_, нема_, lkoš,
  { {0x394600f4, 0x69da007b, 0xa683279d, 0x00000000}},  //   _gros_, _אַוו, сляд,
  { {0x4431279e, 0x38b900f4, 0x26d100c4, 0x00000000}},  //   gez_, fère_, ízos_,
  { {0x38b900f4, 0xf8c80082, 0x291f00b0, 0x00000000}},  //   gère_, _vứt_, ltua_,
  { {0x20030022, 0x201800e5, 0x3a3f0133, 0x00000000}},  //   _adji_, _scri_, ndup_,
  { {0x7e601fe2, 0x291f022b, 0x31690061, 0x00000000}},  // [6ce0] _romp, ntua_, gyaz_,
  { {0x6489024f, 0x44310e5e, 0x291f0f45, 0x00000000}},  //   lžin, cez_, itua_,
  { {0x441b00bd, 0x141b061e, 0xe2ca142c, 0x00000000}},  //   _אויס, _אויב, _плод_,
  { {0x291f022b, 0xc60b0055, 0x23650039, 0x00000000}},  //   ktua_, ষ্ঠা_, älje_,
  { {0xaff800a1, 0x291f0065, 0x127b0049, 0x00000000}},  //   _لہذا_, jtua_, _טאטע,
  { {0x6d420035, 0xdca30152, 0x2240049d, 0x00000000}},  //   rvoa, бачи, ldik_,
  { {0x68e2039b, 0x7e6001a3, 0x291d002b, 0x00000000}},  //   _stod, _tomp, _aqwa_,
  { {0x44310046, 0x2240022b, 0x6604040c, 0x00000000}},  //   zez_, ndik_, _ndik,
  { {0xa9c301fb, 0x443100f4, 0x2120279f, 0x00000000}},  //   йськ, yez_, ntih_,
  { {0xb8dc0309, 0x3ea6108a, 0x443127a0, 0x00000000}},  //   _आठ_, loot_, xez_,
  { {0x4431028c, 0x628627a1, 0x291f002d, 0x00000000}},  //   vez_, _omko, atua_,
  { {0x1efb007b, 0x3ea600c7, 0x212000ca, 0x00000000}},  //   עלכע, noot_, ktih_,
  { {0x44311a2e, 0x333a001c, 0x394627a2, 0x00000000}},  //   tez_, _aspx_, _uros_,
  { {0x66040263, 0x3ea600bb, 0x38b9009d, 0x00000000}},  //   _edik, hoot_, tère_,
  { {0x4431028c, 0x3ea604fd, 0x2007004a, 0x00000000}},  //   rez_, koot_, ónim_,
  { {0x4431028c, 0x92b70d75, 0xe61f00fa, 0x00000000}},  //   sez_, احسا, rnôs_,
  { {0x7c281e34, 0x38b9009d, 0x7d040048, 0x00000000}},  // [6cf0] _obdr, sère_, áisl,
  { {0x38b900f4, 0x752d0026, 0x9d5500a1, 0x00000000}},  //   père_, _ipaz, ینات,
  { {0x6368005e, 0x291f002d, 0x63a901a2, 0x00000000}},  //   _бряг_, ztua_, ßend,
  { {0x63a9014a, 0xddc900ca, 0x4fc4007c, 0x00000000}},  //   ğend, _aleš, ссуа,
  { {0x61ed033b, 0x2902016c, 0xddc900ca, 0x00000000}},  //   mbal, škaj_, _bleš,
  { {0x6b6501fb, 0xa3d80061, 0x2003016c, 0x00000000}},  //   икла, िशय_, _udji_,
  { {0x5c041734, 0xb5fb0010, 0x00000000, 0x00000000}},  //   сяча, nkás,   ,
  { {0x291f27a3, 0x61ed013f, 0x752d0059, 0x00000000}},  //   ttua_, nbal, _opaz,
  { {0xe8f61036, 0xddc9016c, 0x6e2900e0, 0x00000000}},  //   алы_, _fleš, _ibeb,
  { {0xb5fb0224, 0x291f065c, 0x6489010a, 0x00000000}},  //   cház, rtua_, džio,
  { {0x291f0234, 0x2ca727a4, 0xd90f00a1, 0x00000000}},  //   stua_, mond_, زیں_,
  { {0x2ca727a5, 0xa6de0011, 0x291f1d35, 0x00000000}},  //   lond_, _trưn, ptua_,
  { {0x61ed003b, 0xe9ce003b, 0x81cb0044, 0x00000000}},  //   dbal, _фк_, রুত_,
  { {0x68e927a6, 0x18660bba, 0x61ed01c5, 0x00000000}},  //   mped, _ваши_, ebal,
  { {0xe36301ee, 0xf8360104, 0x68e90479, 0x00000000}},  //   окри, _כנסת_, lped,
  { {0x6d490190, 0x61ed011c, 0x2ca701bb, 0x00000000}},  //   _orea, gbal, hond_,
  { {0x2ca70004, 0x224003fe, 0xa2d6007d, 0x00000000}},  // [6d00] kond_, rdik_, _मूर्,
  { {0xf00b0011, 0xe0df0011, 0x22400563, 0x00000000}},  //   _đảng_, _tròn_, sdik_,
  { {0x212001ae, 0x6d4900ab, 0x61ed01e5, 0x00000000}},  //   stih_, _area, bbal,
  { {0x6d4921f3, 0xa1160014, 0x2120050f, 0x00000000}},  //   _brea, _پوست, ptih_,
  { {0x3ea62729, 0x2ca700bc, 0xddc9016e, 0x00000000}},  //   root_, fond_, _pleš,
  { {0x290d06ae, 0x6d490e5f, 0x6e290061, 0x00000000}},  //   drea_, _drea, _ebeb,
  { {0xe457007b, 0xb5fb0010, 0x290d22cd, 0x00000000}},  //   ייסט_, rház, erea_,
  { {0x6d49002a, 0x7f3b00b3, 0xd8380059, 0x00000000}},  //   _frea, _בעלו, moči_,
  { {0x6d4927a7, 0xd8380059, 0x629600f6, 0x00000000}},  //   _grea, loči_, inyo,
  { {0x2ca70038, 0x61ed04bb, 0xc8660893, 0x00000000}},  //   cond_, zbal, ртии,
  { {0x752d0198, 0xa2d602d2, 0x290d001a, 0x00000000}},  //   _spaz, _मूल्, area_,
  { {0x466b013b, 0x290d002d, 0xe818007d, 0x00000000}},  //   тром_, brea_, _दावा_,
  { {0x290d0048, 0x00000000, 0x00000000, 0x00000000}},  //   crea_,   ,   ,
  { {0xd8380bf8, 0xa78601b2, 0x00000000, 0x00000000}},  //   koči_, _پشتو,   ,
  { {0xe28701f9, 0xd8380059, 0x83f8007c, 0x00000000}},  //   аѓан, joči_, ресс_,
  { {0x2777009b, 0x2ca700b5, 0x78a8016e, 0x00000000}},  //   _כגון_, zond_, lodv,
  { {0x61ed049a, 0x2ca700ab, 0xd25100a1, 0x00000000}},  // [6d10] rbal, yond_, _ہند_,
  { {0x6d4927a8, 0x7eb8004a, 0x00000000, 0x00000000}},  //   _rrea, vípa,   ,
  { {0x2ca700b5, 0x6d490051, 0xd83800ca, 0x00000000}},  //   vond_, _srea, goči_,
  { {0x6d4927a9, 0x4255004b, 0x2ca70112, 0x00000000}},  //   _prea, _انحر, wond_,
  { {0x2ca727aa, 0x2cac0022, 0x2c79000a, 0x00000000}},  //   tond_, _bkdd_, _lède_,
  { {0x68e9001c, 0x6d49000d, 0x628d0026, 0x00000000}},  //   vped, _vrea, liao,
  { {0x2ca701b5, 0xa3d8013d, 0x6d490133, 0x00000000}},  //   rond_, िशत_, _wrea,
  { {0x6d490133, 0x2ca70007, 0x290d27ab, 0x00000000}},  //   _trea, sond_, trea_,
  { {0x2ca700f4, 0x6d99007e, 0xa2ba0164, 0x00000000}},  //   pond_, _сваё_, ्षत्,
  { {0x290d0f06, 0xa855025f, 0x64890861, 0x00000000}},  //   rrea_, стиј, užil,
  { {0x68e9029d, 0xa5bb000c, 0x2c1c0061, 0x00000000}},  //   sped, sfól, _नातं_,
  { {0x68e927ac, 0x60c500f6, 0x00000000, 0x00000000}},  //   pped, hmhm,   ,
  { {0xe9450014, 0x672127ad, 0x628d0052, 0x00000000}},  //   _درای, stlj, diao,
  { {0x81bd0044, 0x00000000, 0x00000000, 0x00000000}},  //   ইখা_,   ,   ,
  { {0x786d27ae, 0x00000000, 0x00000000, 0x00000000}},  //   _núvi,   ,   ,
  { {0x5693025f, 0xb5fb27af, 0x20cd012d, 0x00000000}},  //   _најт, skár, _džim_,
  { {0x62960010, 0x00000000, 0x00000000, 0x00000000}},  // [6d20] rnyo,   ,   ,
  { {0x26d20be3, 0x6aa900c7, 0x2f560077, 0x00000000}},  //   _hiyo_, hoef, йтес,
  { {0xdfcf0025, 0x00000000, 0x00000000, 0x00000000}},  //   فيك_,   ,   ,
  { {0x9f58008d, 0x2902010a, 0x786d02d5, 0x00000000}},  //   _herë_, škai_, _dúvi,
  { {0x6489016c, 0x3ebf0009, 0x26d20173, 0x00000000}},  //   džij, _dhut_, _miyo_,
  { {0x653b0049, 0x6a75004a, 0x26d2000a, 0x00000000}},  //   טענד, _ráfa, _liyo_,
  { {0x26c000ab, 0xbc190088, 0x6aa901c3, 0x00000000}},  //   _ohio_, річі_, foef,
  { {0x6e960054, 0x25ad0046, 0x26d2011c, 0x00000000}},  //   _الرا, żeli_, _niyo_,
  { {0x81aa0055, 0x6c1a0025, 0xd7fa026b, 0x00000000}},  //   গের_, _متاح_, лун_,
  { {0x7c650025, 0x96ea1280, 0x7d020093, 0x00000000}},  //   _والل, льма_, msos,
  { {0xcb090088, 0x7d0227b0, 0x8699012d, 0x00000000}},  //   _вхід_, lsos, икос_,
  { {0x64891878, 0x26c00145, 0x8f9b009b, 0x00000000}},  //   ržim, _chio_, ריטי,
  { {0x92d508b7, 0x98a601f9, 0x261a02d2, 0x00000000}},  //   _হবে_, _лиде, _भारी_,
  { {0xf484005e, 0xa7fc014a, 0x64890802, 0x00000000}},  //   пусн, rkıs, mžik,
  { {0x25a0220d, 0x9a290082, 0x9f580023, 0x00000000}},  //   _exil_, _hươu_, _derë_,
  { {0x9f5a009d, 0x7d0227b1, 0x200e01e5, 0x00000000}},  //   capé_, ksos, ófin_,
  { {0x786d0027, 0x628d044e, 0x81b10044, 0x00000000}},  // [6d30] _súvi, riao, টেন_,
  { {0x2a6627b2, 0x3ead0d8c, 0x3ebf0133, 0x00000000}},  //   _loob_, _sket_, _shut_,
  { {0x656f005b, 0x273a0089, 0x2c6b0030, 0x00000000}},  //   lych, _jūn_, _mødt_,
  { {0x66e10089, 0x81cb0044, 0xe787013e, 0x00000000}},  //   _jēka, রুষ_, náší,
  { {0xed5900e3, 0x61ff006b, 0x656f0016, 0x00000000}},  //   рол_, maql, nych,
  { {0x61ff27b3, 0xc05b0088, 0x2c6b0637, 0x00000000}},  //   laql, _сім_, _nødt_,
  { {0x2a66001c, 0x6aa90112, 0x16090061, 0x00000000}},  //   _boob_, toef, वणार_,
  { {0x61ff006b, 0x2c4f0089, 0x00000000, 0x00000000}},  //   naql, _sēdē_,   ,
  { {0x6aa9046a, 0x888200a1, 0x26d20022, 0x00000000}},  //   roef, ڈینن, _riyo_,
  { {0x26d20020, 0x7c9703e6, 0x26c00093, 0x00000000}},  //   _siyo_, _اشرا, _shio_,
  { {0x26d2000a, 0x2c6b068f, 0x2ca00048, 0x00000000}},  //   _piyo_, _dødt_, éide_,
  { {0xe7360088, 0x00000000, 0x00000000, 0x00000000}},  //   цею_,   ,   ,
  { {0x2c6b068f, 0x9f5a15a3, 0xe7f20061, 0x00000000}},  //   _født_, rapé_, _आजचा_,
  { {0x7d04002a, 0xb5fb000c, 0x98c70cb3, 0x00000000}},  //   áisi, skáp, _усел,
  { {0x81b10044, 0x26c00300, 0x3246005e, 0x00000000}},  //   টেম_, _thio_, оевг,
  { {0x66de0089, 0xd6d20025, 0x7d020052, 0x00000000}},  //   _mīkl, _تقع_, ysos,
  { {0x80660088, 0x9f410026, 0x25df007d, 0x00000000}},  // [6d40] оваж, lchè_, _गलती_,
  { {0x1fb60088, 0x6ecc005a, 0x76440085, 0x00000000}},  //   осер, _işbi, _haiy,
  { {0x4444020c, 0x81cb0055, 0x2242021a, 0x00000000}},  //   _ia_, রুল_, _takk_,
  { {0x444427b4, 0x61ff006b, 0x87ac0049, 0x00000000}},  //   _ha_, caql, נשאַ,
  { {0x8cf3008b, 0x76440c3b, 0x61e4014a, 0x00000000}},  //   дзіц, _maiy, mcil,
  { {0x44440368, 0x7d020065, 0x61e4014a, 0x00000000}},  //   _ja_, rsos, lcil,
  { {0x44441a64, 0x44380219, 0x7d02002b, 0x00000000}},  //   _ma_, ier_, ssos,
  { {0x44381e64, 0x61e427b5, 0xead3007c, 0x00000000}},  //   her_, ncil, мощь,
  { {0x9f5800d4, 0x00000000, 0x00000000, 0x00000000}},  //   _serè_,   ,   ,
  { {0x6d40005f, 0x44380292, 0x7e620091, 0x00000000}},  //   _isma, jer_, ljop,
  { {0x2a66006c, 0x673a00b5, 0x656f026e, 0x00000000}},  //   _toob_, uwtj, wych,
  { {0x444404d2, 0x443801d6, 0x7c3827b6, 0x00000000}},  //   _aa_, eer_, levr,
  { {0x44440811, 0x443802f1, 0x27fe0022, 0x00000000}},  //   _ba_, fer_, patn_,
  { {0x443805ec, 0x44441305, 0x6a7c00f4, 0x00000000}},  //   ger_, _ca_, _défe,
  { {0x444401cd, 0x9f410197, 0x61ff006b, 0x00000000}},  //   _da_, cchè_, taql,
  { {0x4444000d, 0x6d40011f, 0xd8380059, 0x00000000}},  //   _ea_, _osma, leč_,
  { {0x444415ae, 0x61ff005f, 0x142b01e1, 0x00000000}},  // [6d50] _fa_, raql, _кіно_,
  { {0x44440119, 0x661d27b7, 0x7c380ce4, 0x00000000}},  //   _ga_, lgsk, jevr,
  { {0x442127b8, 0x6d40034d, 0x1eea0167, 0x00000000}},  //   _ich_, _asma, مولی_,
  { {0x661d004e, 0x9f4127b9, 0x2904006c, 0x00000000}},  //   ngsk, nché_, ksma_,
  { {0x444427ba, 0x6445006a, 0x61fd0089, 0x00000000}},  //   _ya_, _kahi, _iesl,
  { {0x61fd004f, 0x4444116d, 0xd8380209, 0x00000000}},  //   _hesl, _xa_, ječ_,
  { {0x6445006a, 0x6d400004, 0x6d460c8a, 0x00000000}},  //   _mahi, _esma, _škat,
  { {0x44380978, 0x60d5011f, 0x644504cb, 0x00000000}},  //   zer_, _hizm, _lahi,
  { {0x442127bb, 0x4438032c, 0x61fd011f, 0x00000000}},  //   _och_, yer_, _mesl,
  { {0x443804bd, 0x26dc010a, 0x644527bc, 0x00000000}},  //   xer_, _buvo_, _nahi,
  { {0x443805ec, 0x444400ad, 0x66e80224, 0x00000000}},  //   ver_, _ra_, _někd,
  { {0x4444084e, 0x44210195, 0x443800fe, 0x00000000}},  //   _sa_, _ach_, wer_,
  { {0x4444258f, 0x644502d5, 0x200127bd, 0x00000000}},  //   _pa_, _bahi, kahi_,
  { {0x4438010f, 0x644511a1, 0x2a7f0022, 0x00000000}},  //   uer_, _cahi, lhub_,
  { {0x44441800, 0x61fd0af1, 0x64450811, 0x00000000}},  //   _va_, _besl, _dahi,
  { {0x444427ba, 0x60d5001e, 0x61fd0107, 0x00000000}},  //   _wa_, _aizm, _cesl,
  { {0x444427be, 0x61fd2346, 0x61e41c17, 0x00000000}},  // [6d60] _ta_, _desl, rcil,
  { {0x44440065, 0x60d51053, 0x8fa60265, 0x00000000}},  //   _ua_, _cizm, пазе,
  { {0x7e7b00d9, 0x7e6901d6, 0x69d9005b, 0x00000000}},  //   _blup, _boep, _ogwe,
  { {0x61fd27bf, 0x6445006b, 0x0dca007c, 0x00000000}},  //   _gesl, _zahi, блей_,
  { {0xa25b00ad, 0x7c3827c0, 0x64450ea6, 0x00000000}},  //   _khôn, tevr, _yahi,
  { {0x91bb00b6, 0x442127c1, 0x6445006b, 0x00000000}},  //   _למכי, _xch_, _xahi,
  { {0x8fa3237a, 0x5e960355, 0x394f27c2, 0x00000000}},  //   _заре, _فلسط, _args_,
  { {0x7e7b0119, 0xb95401fb, 0x26dc0026, 0x00000000}},  //   _glup, двищ, _ruvo_,
  { {0x6d40008a, 0xc6230044, 0x2d820039, 0x00000000}},  //   _usma, _বোঝা_, _åke_,
  { {0x6c86002c, 0xb80600a1, 0xf8060088, 0x00000000}},  //   _علام, سکتے_, ччин,
  { {0x64450518, 0x29040066, 0x394f00d9, 0x00000000}},  //   _rahi, ssma_, _ergs_,
  { {0x6445047f, 0xd6d707ca, 0xb5fb0010, 0x00000000}},  //   _sahi, ять_, aján,
  { {0x9f412529, 0x6445006a, 0x661d00f8, 0x00000000}},  //   rché_, _pahi, rgsk,
  { {0x753d0046, 0x26dc27c3, 0x2902010a, 0x00000000}},  //   rwsz, _tuvo_, škas_,
  { {0x6445104a, 0x2491005d, 0x64470007, 0x00000000}},  //   _vahi, rizm_, rdji,
  { {0x2001000b, 0x60f90147, 0x644527c4, 0x00000000}},  //   wahi_, жная_, _wahi,
  { {0xd250026c, 0x64451084, 0x7e6900c7, 0x00000000}},  // [6d70] ھنے_, _tahi, _roep,
  { {0x7e6927c5, 0x4421007f, 0xd25000a1, 0x00000000}},  //   _soep, _uch_, پنے_,
  { {0x61fd014a, 0x7e7b00f4, 0x200116c3, 0x00000000}},  //   _tesl, _plup, rahi_,
  { {0xddd00006, 0x7bda01c3, 0x20010145, 0x00000000}},  //   _šešt, _agtu, sahi_,
  { {0x8c450069, 0x6d460733, 0x628f00fa, 0x00000000}},  //   деле, _škar, _imco,
  { {0x2249014a, 0x69d90016, 0x7e6901c3, 0x00000000}},  //   ldak_, _sgwe, _woep,
  { {0x660d016c, 0x7e69015c, 0x9f3401fb, 0x00000000}},  //   _odak, _toep, _пері,
  { {0x2249033b, 0xcf9201ce, 0x660d0095, 0x00000000}},  //   ndak_, _סטן_, _ndak,
  { {0x2129020c, 0x7d04002a, 0x2a7f0300, 0x00000000}},  //   ntah_, áist, rhub_,
  { {0x7d0401d5, 0xa88903e8, 0x660d0127, 0x00000000}},  //   ġist, ійна_, _adak,
  { {0x7d04037e, 0xa25b00f4, 0xb21b158f, 0x00000000}},  //   šist, _rhôn, _klæd,
  { {0x497527c6, 0x7d09129d, 0x7bc10166, 0x00000000}},  //   _олес, _kves, _izlu,
  { {0xd94500e3, 0xddc005fa, 0x2902050f, 0x00000000}},  //   _цели, _komš, škar_,
  { {0x225902d8, 0x00000000, 0x00000000, 0x00000000}},  //   _ansk_,   ,   ,
  { {0x212901d6, 0x394d1044, 0x91e6005e, 0x00000000}},  //   etah_, lves_, добе,
  { {0x64890006, 0x7d09095f, 0x212913e1, 0x00000000}},  //   džiu, _oves, ftah_,
  { {0xa25b00ad, 0x412700e3, 0xad9d0036, 0x00000000}},  // [6d80] _thôn, мото_, _jeźd,
  { {0x394d0bd3, 0xb5fb000c, 0x00000000, 0x00000000}},  //   ives_, hjál,   ,
  { {0x7d090207, 0x72c60741, 0x628f0045, 0x00000000}},  //   _aves, _обоз, _fmco,
  { {0xdddb00b9, 0x11d60025, 0x00000000, 0x00000000}},  //   _kouř, _يتحد,   ,
  { {0xb21b0698, 0x98bd000a, 0x66e10089, 0x00000000}},  //   _slæg, _aswč_, _sēkl,
  { {0x394d0047, 0x00000000, 0x00000000, 0x00000000}},  //   dves_,   ,   ,
  { {0x2ac6003b, 0x64890161, 0x394d0133, 0x00000000}},  //   мљив, mžit, eves_,
  { {0xb21b0030, 0x2a7d0016, 0xf27b0049, 0x00000000}},  //   _glæd, _clwb_, ַריש,
  { {0xdb0800b0, 0x7bda0009, 0x00000000, 0x00000000}},  //   _sydä, _tgtu,   ,
  { {0x6a7c00f4, 0x6489012d, 0x81cb0044, 0x00000000}},  //   _défa, nžit, রুক_,
  { {0x7d091a2d, 0x00000000, 0x00000000, 0x00000000}},  //   _zves,   ,   ,
  { {0x787f00f4, 0xdddb00b9, 0x2a7d005b, 0x00000000}},  //   _rêve, _bouř, _glwb_,
  { {0x61f60009, 0xd05d006b, 0x63a9014a, 0x00000000}},  //   dbyl, _etsə, ğenm,
  { {0xe1ff0051, 0x6489012d, 0x00000000, 0x00000000}},  //   _seó_, jžit,   ,
  { {0xa4d401fb, 0x46a70057, 0xf837009b, 0x00000000}},  //   торі, _ошиб, _חנות_,
  { {0xe0df0198, 0x21290c08, 0x660d1242, 0x00000000}},  //   _può_, ttah_, _udak,
  { {0x7eb802d5, 0xf1940077, 0x22490095, 0x00000000}},  // [6d90] cípi, вить, rdak_,
  { {0x224900e0, 0x00000000, 0x00000000, 0x00000000}},  //   sdak_,   ,   ,
  { {0x7d09021d, 0x212927c7, 0x7a15006b, 0x00000000}},  //   _sves, stah_, nətç,
  { {0xc332007b, 0x6aa20065, 0x44330009, 0x00000000}},  //   _גוט_, _njof, _hbx_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x394d00eb, 0x6aa20035, 0x00000000, 0x00000000}},  //   vves_, _ajof,   ,
  { {0x1ee70063, 0x7e780089, 0x8f690025, 0x00000000}},  //   _آوری_, īvpr, _عمرك_,
  { {0xe8f90069, 0x394d27c8, 0x00000000, 0x00000000}},  //   пли_, tves_,   ,
  { {0x81b10055, 0x9f41002a, 0xfd1300a1, 0x00000000}},  //   টের_, ichí_, _ججز_,
  { {0x394d1a82, 0xb5fb0010, 0xe8f60930, 0x00000000}},  //   rves_, ckáz, эль_,
  { {0x47d20044, 0x394d174d, 0x69c200d9, 0x00000000}},  //   _দ্বী, sves_, _ezoe,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ae10039, 0xa25b00f4, 0x00000000, 0x00000000}},  //   _hult, _chôm,   ,
  { {0x443300fa, 0x6abb141a, 0x00000000, 0x00000000}},  //   _cbx_, lluf,   ,
  { {0x4256017a, 0x7ae10894, 0x7eb8004a, 0x00000000}},  //   нтат, _jult, sípi,
  { {0x7ae10585, 0x22150745, 0x00000000, 0x00000000}},  //   _mult, кфур,   ,
  { {0x5637007b, 0x6606178a, 0xa69b009b, 0x00000000}},  // [6da0] _טאקע_, makk, _משקפ,
  { {0x25d700a0, 0x66060127, 0x3e4c0011, 0x00000000}},  //   _אופן_, lakk, _ớt_,
  { {0xee3a0931, 0x44e60011, 0x64890c76, 0x00000000}},  //   зне_, _hô_, ržit,
  { {0x66061198, 0x44e60011, 0xe1f21739, 0x00000000}},  //   nakk, _kô_, _حسد_,
  { {0x6296011f, 0xdb01014a, 0x62840051, 0x00000000}},  //   miyo, _eylü, mhio,
  { {0x629627c9, 0x44e6001d, 0x7ae1002d, 0x00000000}},  //   liyo, _mô_, _bult,
  { {0xc60b0055, 0x44e60011, 0x66060943, 0x00000000}},  //   ষ্টা_, _lô_, kakk,
  { {0x6296011f, 0x9f5a00c4, 0x660603ba, 0x00000000}},  //   niyo, capá_, jakk,
  { {0x44e60082, 0x660601a3, 0x261a0204, 0x00000000}},  //   _nô_, dakk, _भाजी_,
  { {0xd7f70783, 0x6296006a, 0x89330379, 0x00000000}},  //   ную_, hiyo, اعيا,
  { {0x6296014a, 0x7ae10089, 0xe821007d, 0x00000000}},  //   kiyo, _gult, _मारा_,
  { {0x6e220d3b, 0x7a15006b, 0x660604cb, 0x00000000}},  //   ngob, rətç, gakk,
  { {0x44e6001d, 0x6296011f, 0x69c20020, 0x00000000}},  //   _cô_, diyo, _uzoe,
  { {0x44e60082, 0x00000000, 0x00000000, 0x00000000}},  //   _dô_,   ,   ,
  { {0xd7f8001a, 0x62840048, 0xa8470025, 0x00000000}},  //   mbă_, fhio, _سليم_,
  { {0x628427ca, 0xd7bb00b3, 0x67bb009b, 0x00000000}},  //   ghio, _מצור, _ממוק,
  { {0x51870cbc, 0x68e21b1b, 0x443327cb, 0x00000000}},  // [6db0] хува, _juod, _tbx_,
  { {0x68e200b0, 0x9f5800f6, 0x28c6013d, 0x00000000}},  //   _muod, _berà_, _रीमि,
  { {0x26c90011, 0x68e200b0, 0x44e60082, 0x00000000}},  //   _khao_, _luod, _zô_,
  { {0x62840016, 0x3946058b, 0x00000000, 0x00000000}},  //   chio, _osos_,   ,
  { {0x44e60011, 0x68e20006, 0x7ae127cc, 0x00000000}},  //   _xô_, _nuod, _sult,
  { {0xd1160104, 0x224b0a60, 0x00000000, 0x00000000}},  //   _בקשה_, _hack_,   ,
  { {0x394600f6, 0x0ebb04e8, 0x6abb1e19, 0x00000000}},  //   _asos_, _فارغ_, tluf,
  { {0x6a7c00f4, 0x3946004a, 0x7ae127cd, 0x00000000}},  //   _défo, _bsos_, _vult,
  { {0x6606002b, 0x39460022, 0x6abb02d8, 0x00000000}},  //   vakk, _csos_, rluf,
  { {0x68e20006, 0xeafb02fd, 0x6abb000c, 0x00000000}},  //   _duod, _فرصت_, sluf,
  { {0x07a50099, 0xf4270055, 0x39460211, 0x00000000}},  //   танн, য়ার_, _esos_,
  { {0x26c927ce, 0x44e627cf, 0xd7f80035, 0x00000000}},  //   _chao_, _pô_, abă_,
  { {0x660601a3, 0x6296014a, 0x7d190016, 0x00000000}},  //   rakk, viyo, nrws,
  { {0x44e6001d, 0x291f0020, 0x62962552, 0x00000000}},  //   _vô_, muua_, wiyo,
  { {0x6284018e, 0x224b0038, 0x6296011f, 0x00000000}},  //   thio, _back_, tiyo,
  { {0x44e627d0, 0xcfb70044, 0x25bf002b, 0x00000000}},  //   _tô_, জধান, żula_,
  { {0x6296011f, 0x9f5804bd, 0xe0da0f97, 0x00000000}},  // [6dc0] riyo, _serà_, два_,
  { {0x660427d1, 0x6296014a, 0x62841215, 0x00000000}},  //   _heik, siyo, shio,
  { {0x403301fb, 0x660427d2, 0x6284034a, 0x00000000}},  //   реєс, _keik, phio,
  { {0x644e000c, 0x6a7c00f4, 0x66040032, 0x00000000}},  //   ldbi, _réfo, _jeik,
  { {0x6e2201aa, 0x660400b0, 0x6a7c009d, 0x00000000}},  //   rgob, _meik, _défl,
  { {0x660425df, 0xdb1a0010, 0x3a26001a, 0x00000000}},  //   _leik, _aztá, _scop_,
  { {0xa03701f8, 0x68e227d3, 0x39460022, 0x00000000}},  //   _שאלה_, _suod, _ssos_,
  { {0xeaaf0b59, 0x60dc01c2, 0x2498010f, 0x00000000}},  //   يعي_, _hirm, hirm_,
  { {0x60dc002d, 0x58d80ae0, 0x63a9014a, 0x00000000}},  //   _kirm, ндия_, ğeni,
  { {0x68e2021e, 0x26c91575, 0x00000000, 0x00000000}},  //   _vuod, _shao_,   ,
  { {0x25be005f, 0xdc9b009b, 0xba260264, 0x00000000}},  //   ətli_, _קיבל, _адек,
  { {0x645e0607, 0x6f0327d4, 0xeb9700b3, 0x00000000}},  //   _anpi, ânci, _בדבר_,
  { {0x394627d5, 0x224b03ca, 0xceb300b3, 0x00000000}},  //   _usos_, _rack_, שיר_,
  { {0x60dc0022, 0xf7540025, 0x224b01a2, 0x00000000}},  //   _nirm, _منتج, _sack_,
  { {0x26c9001d, 0x44230065, 0x35c7013d, 0x00000000}},  //   _thao_, rgj_, रेज़,
  { {0x442d00b9, 0x60dc01a3, 0x645e27d6, 0x00000000}},  //   ře_, _airm, _enpi,
  { {0x60dc1352, 0x6a7c00f4, 0xd7ce0061, 0x00000000}},  // [6dd0] _birm, _réfl, हेरच,
  { {0x9f580df9, 0x660400bb, 0x764d0058, 0x00000000}},  //   _será_, _zeik, _haay,
  { {0x224b0073, 0x60dc0197, 0x764d011c, 0x00000000}},  //   _tack_, _dirm, _kaay,
  { {0xfe70023c, 0xed590062, 0x12790049, 0x00000000}},  //   يدن_, _lyže_, _נאָע,
  { {0xed5801fb, 0x764d011c, 0x9f580b33, 0x00000000}},  //   кої_, _maay, _verá_,
  { {0x66e80224, 0x61ed00d4, 0x60dc005a, 0x00000000}},  //   _něko, lcal, _girm,
  { {0x9f580181, 0xeb3500a6, 0x61ed0026, 0x00000000}},  //   _terá_, ارتخ, ocal,
  { {0x61ed014a, 0x66e800b9, 0x764d0058, 0x00000000}},  //   ncal, _pěkn, _naay,
  { {0x6604010a, 0x6e290190, 0x4c25026c, 0x00000000}},  //   _reik, _iceb, _مظاہ,
  { {0x6604003c, 0x3a3f077d, 0x79890036, 0x00000000}},  //   _seik, seup_, rzew,
  { {0xd709008b, 0x79890036, 0x66040056, 0x00000000}},  //   энне_, szew, _peik,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66040ebc, 0x22400006, 0xceb20097, 0x00000000}},  //   _veik, veik_, מיט_,
  { {0x399a0452, 0xd8790025, 0x00000000, 0x00000000}},  //   _אינד, _سمعت_,   ,
  { {0x38780073, 0x8883007a, 0x660420ea, 0x00000000}},  //   örre_, _میکن, _teik,
  { {0x6d4919ed, 0x61460245, 0x60dc0089, 0x00000000}},  //   _osea, леба, _sirm,
  { {0x60dc0ebc, 0x22400007, 0x6d4900e5, 0x00000000}},  // [6de0] _pirm, reik_, _nsea,
  { {0x6e290b32, 0x32090058, 0x61ed0026, 0x00000000}},  //   _aceb, aaay_, acal,
  { {0x629a01e6, 0x32091544, 0x28960049, 0x00000000}},  //   étos, baay_, נדען_,
  { {0xdfcf006d, 0x0dca1585, 0x61ed117e, 0x00000000}},  //   سين_, нули_, ccal,
  { {0x6d490009, 0x672127d7, 0x63a901a2, 0x00000000}},  //   _csea, hulj, ßenv,
  { {0x67211b03, 0x6d490050, 0xafe3005c, 0x00000000}},  //   kulj, _dsea, _горл,
  { {0x6d490009, 0x6e290045, 0x00000000, 0x00000000}},  //   _esea, _fceb,   ,
  { {0x6d490009, 0x3914026b, 0x672127d8, 0x00000000}},  //   _fsea, амир, dulj,
  { {0x9806008b, 0xf65f0030, 0x00000000, 0x00000000}},  //   лянд, llæg_,   ,
  { {0x47340a27, 0x7eb806f4, 0x764d01d6, 0x00000000}},  //   анос, cípr, _saay,
  { {0x290f00f8, 0x61ed077d, 0xf65f0698, 0x00000000}},  //   _evga_, ycal, nlæg_,
  { {0x7bc827d9, 0x45d500e3, 0x61ed008e, 0x00000000}},  //   _izdu, ионс, xcal,
  { {0xd90e0167, 0x94ab1281, 0xb21b0190, 0x00000000}},  //   _عید_, етва_, _blæn,
  { {0x2c790263, 0x67d401fc, 0x98a31666, 0x00000000}},  //   _pèdi_, _колу, _личе,
  { {0xd25b06b6, 0x02a7005e, 0xa3d50088, 0x00000000}},  //   нца_, грам, ровч,
  { {0xf65f0018, 0xb713221c, 0x09d80044, 0x00000000}},  //   dlæg_, _ابوش, _ধ্যা,
  { {0x940a006b, 0x05960014, 0xb21b0190, 0x00000000}},  // [6df0] hibə_, _پايگ, _flæn,
  { {0x61ed0207, 0xf00b0011, 0x629a009d, 0x00000000}},  //   scal, _đẳng_, étor,
  { {0x2fc70073, 0x61ed231b, 0x201c00fa, 0x00000000}},  //   ång_, pcal, óvia_,
  { {0x5d55005e, 0x6d490009, 0x00000000, 0x00000000}},  //   икет, _psea,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x1ee700a6, 0x7bc800b4, 0x00000000, 0x00000000}},  //   _موسی_, _bzdu,   ,
  { {0x290f1d21, 0x961d0044, 0x00000000, 0x00000000}},  //   _svga_, ধ্যম_,   ,
  { {0x6d49002a, 0x00000000, 0x00000000, 0x00000000}},  //   _tsea,   ,   ,
  { {0x6d4900b0, 0x290f0082, 0x7bc80288, 0x00000000}},  //   _usea, _qvga_, _ezdu,
  { {0x5d840054, 0xdd7400a1, 0x290d0145, 0x00000000}},  //   _الكل, _دھمک, rsea_,
  { {0x5ba70057, 0xf77104e8, 0x290d16a3, 0x00000000}},  //   _сраз, زاد_, ssea_,
  { {0xc4c9034e, 0x290d0035, 0x672101ed, 0x00000000}},  //   _חג_, psea_, rulj,
  { {0x05d00061, 0xb21b0190, 0x92080089, 0x00000000}},  //   सेंब, _plæn, ntāž,
  { {0xd547003b, 0x18690545, 0x67210213, 0x00000000}},  //   јпре_, _јаки_, pulj,
  { {0xe29a01fb, 0x00000000, 0x00000000, 0x00000000}},  //   вав_,   ,   ,
  { {0x63be01ca, 0xa802019a, 0x00000000, 0x00000000}},  //   _vypn, _çıra,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [6e00]   ,   ,   ,
  { {0x7e6027da, 0x2f56058e, 0x2a7f010e, 0x00000000}},  //   _snmp, итес, hkub_,
  { {0x443a27db, 0x661600b9, 0xd2aa094b, 0x00000000}},  //   _ibp_, _kdyk, _акне_,
  { {0xb17b0039, 0x2a6d01d5, 0x443a0c70, 0x00000000}},  //   _igån, jjeb_, _hbp_,
  { {0x9c7c00ca, 0xe3b20014, 0x62860095, 0x00000000}},  //   _liče, _درک_, _ilko,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d8027dc, 0xd90d00a1, 0x8fa3005e, 0x00000000}},  //   šie_, ہین_, _даре,
  { {0x940a006b, 0x7bc8031f, 0x443a1e16, 0x00000000}},  //   ribə_, _vzdu, _lbp_,
  { {0xc8660cb7, 0x5c160318, 0xd90d0167, 0x00000000}},  //   атни, _نظار, فین_,
  { {0x9da5007a, 0x6a7c009d, 0x98c60143, 0x00000000}},  //   _اصفه, _méfi, јсил,
  { {0x7d0d050f, 0xd838016c, 0x4adf0164, 0x00000000}},  //   šast, jiče_, _पंचव,
  { {0x3ea627dd, 0xd8380802, 0x443a0145, 0x00000000}},  //   nnot_, diče_, _abp_,
  { {0x443a24ac, 0xe5c70bff, 0x00000000, 0x00000000}},  //   _bbp_, рсно,   ,
  { {0xb8cb0055, 0x443a00bb, 0x68ed0051, 0x00000000}},  //   _কী_, _cbp_, _éada,
  { {0x443a0127, 0x3ea61016, 0x66e8013e, 0x00000000}},  //   _dbp_, knot_, _měkk,
  { {0x3264072b, 0xf00b0011, 0x443a062a, 0x00000000}},  //   отув, _đằng_, _ebp_,
  { {0x3ea6258b, 0x443a06ed, 0xdddb0087, 0x00000000}},  // [6e10] dnot_, _fbp_, _oluš,
  { {0x6a7c27de, 0x443a0142, 0x7ae801d6, 0x00000000}},  //   _défi, _gbp_, _oudt,
  { {0x2fca01ee, 0x657d27df, 0x3f670b52, 0x00000000}},  //   _czbg_, lysh, штаб,
  { {0xa28300a6, 0x4ea4008b, 0x63bb005d, 0x00000000}},  //   _بیرو, орча, ğund,
  { {0xefb100a1, 0x067c0049, 0x3e3209b9, 0x00000000}},  //   _کیاگ, כנאל, سفور,
  { {0x30850025, 0x20850b03, 0x7ae81962, 0x00000000}},  //   _السف, _السّ, _budt,
  { {0xa3d7006e, 0x2a7f006c, 0x92080089, 0x00000000}},  //   िधि_, tkub_, stāž,
  { {0x76960006, 0xdb0e013e, 0x00000000, 0x00000000}},  //   ršyk, ídán,   ,
  { {0xceb20097, 0x6e3b1aa1, 0xe9d9007c, 0x00000000}},  //   _זין_, _ibub, ыки_,
  { {0xac740054, 0x657d0065, 0x7c2d0091, 0x00000000}},  //   _والش, dysh, đars,
  { {0xe739003b, 0x00000000, 0x00000000, 0x00000000}},  //   ћем_,   ,   ,
  { {0x443a0145, 0x8b9a009b, 0x6d5b27e0, 0x00000000}},  //   _sbp_, _גבעת, _krua,
  { {0x443a0145, 0x69cd0061, 0x959901e1, 0x00000000}},  //   _pbp_, देखी, атру_,
  { {0xa956012f, 0xd8380091, 0x68fb23ff, 0x00000000}},  //   _לינק_, tiče_, mpud,
  { {0x6e3b27e1, 0x68fb0190, 0xf719007e, 0x00000000}},  //   _obub, lpud, _сілы_,
  { {0x27311db2, 0xd8382270, 0xe29701ee, 0x00000000}},  //   mán_, riče_, бас_,
  { {0x27310047, 0x21670407, 0x2b490036, 0x00000000}},  // [6e20] lán_, бити_, łach_,
  { {0x76460056, 0x6e3b0729, 0xd83818e2, 0x00000000}},  //   leky, _abub, piče_,
  { {0x5477009b, 0x3ea600f8, 0xef1a013b, 0x00000000}},  //   _הגיע_, tnot_, уме_,
  { {0xdddb0119, 0xe821001c, 0x6286021e, 0x00000000}},  //   _sluš, _माझा_, _ulko,
  { {0x2731002a, 0x6d5b07cb, 0x3ea6101a, 0x00000000}},  //   hán_, _crua, rnot_,
  { {0xf8a70025, 0x3ea601c5, 0x273127e2, 0x00000000}},  //   _رة_, snot_, kán_,
  { {0x7f860054, 0x27310092, 0x66df0006, 0x00000000}},  //   _الأن, ján_, _būkl,
  { {0x273127e3, 0x7bc10016, 0xc333009b, 0x00000000}},  //   dán_, _dylu, פוח_,
  { {0x6d5b04ea, 0xed570256, 0x00000000, 0x00000000}},  //   _grua, _лот_,   ,
  { {0x971400e3, 0x7ae80010, 0x7526002d, 0x00000000}},  //   омоц, _tudt, dukz,
  { {0x273127e4, 0xb8ef006e, 0xb21b000c, 0x00000000}},  //   gán_, _वी_, _slæm,
  { {0x249a0022, 0x7c2a043e, 0x291f15cd, 0x00000000}},  //   _ampm_, lgfr, brua_,
  { {0xb5fb000c, 0x00000000, 0x00000000, 0x00000000}},  //   fjár,   ,   ,
  { {0x657d008d, 0xc91700b6, 0x27310010, 0x00000000}},  //   rysh, _פחות_, bán_,
  { {0x273127e5, 0x7ae20eac, 0xd5ed0082, 0x00000000}},  //   cán_, _kiot, _toà,
  { {0x46a4098c, 0x6d4000b5, 0x201801a3, 0x00000000}},  //   _најв, _opma, _adri_,
  { {0x660f037e, 0x90990200, 0x200a0107, 0x00000000}},  // [6e30] mack, ават_, _bebi_,
  { {0x660f0142, 0x7ae20bfd, 0x6d5b0023, 0x00000000}},  //   lack, _liot, _rrua,
  { {0x64470020, 0x6d400e3f, 0x75280036, 0x00000000}},  //   meji, _apma, ądze,
  { {0x660f219c, 0x64470d48, 0xddc008fb, 0x00000000}},  //   nack, leji, _domž,
  { {0x628d0051, 0x27310010, 0x9f4106c2, 0x00000000}},  //   mhao, zán_, nchú_,
  { {0x64551669, 0xf00b0011, 0x64470416, 0x00000000}},  //   ndzi, _đặng_, neji,
  { {0xdea400a1, 0xb7b30044, 0x660f188c, 0x00000000}},  //   _کینی, _ঘণ্ট, kack,
  { {0x660f037e, 0x6d5b27e6, 0x27310224, 0x00000000}},  //   jack, _trua, ván_,
  { {0x7ae2022b, 0x4438018e, 0x3ebf04cb, 0x00000000}},  //   _diot, yfr_, _ikut_,
  { {0x27311ae2, 0x64550046, 0x48790242, 0x00000000}},  //   tán_, jdzi, рсия_,
  { {0xe739017a, 0x764604a5, 0x6447007f, 0x00000000}},  //   шен_, teky, deji,
  { {0x9f580211, 0x68fb010e, 0x7ae20051, 0x00000000}},  //   _perú_, ppud, _giot,
  { {0x44ef005f, 0x27311a43, 0x3ead27e7, 0x00000000}},  //   _cü_, sán_, _mjet_,
  { {0x27310010, 0x7ae2002d, 0x7526002d, 0x00000000}},  //   pán_, _ziot, rukz,
  { {0x660f01d5, 0x44ef0d88, 0x3ebf0022, 0x00000000}},  //   back, _eü_, _okut_,
  { {0x68e30811, 0x200a0059, 0x2120089f, 0x00000000}},  //   _hind, _sebi_, trih_,
  { {0xefea0025, 0x0ffa0025, 0x81e20044, 0x00000000}},  // [6e40] لعضو_, لعاب_, নুন_,
  { {0x4fa60069, 0x68e327e8, 0x3ebf02e7, 0x00000000}},  //   оизв, _jind, _akut_,
  { {0x68e31bc0, 0x6d4027e9, 0xe3b202fd, 0x00000000}},  //   _mind, _spma, _زرد_,
  { {0x68e327ea, 0x628d096a, 0x00000000, 0x00000000}},  //   _lind, chao,   ,
  { {0x7ae2027b, 0x200a0825, 0x2d580088, 0x00000000}},  //   _riot, _tebi_, силь_,
  { {0x68e3002d, 0x62840d96, 0x6721012d, 0x00000000}},  //   _nind, lkio, krlj,
  { {0x7ae20036, 0xaff500a1, 0x78ba049c, 0x00000000}},  //   _piot, _رہنا_, votv,
  { {0x68e302d5, 0x64550036, 0xd8381238, 0x00000000}},  //   _aind, zdzi, diča_,
  { {0xfe4301fb, 0x660f2270, 0xf2d3019b, 0x00000000}},  //   _інфо, vack, ועה_,
  { {0x26c005e6, 0xc19b0049, 0x6a7c009d, 0x00000000}},  //   _akio_, ישפי, _réfu,
  { {0x68e300ef, 0x67210091, 0x7ae200f8, 0x00000000}},  //   _dind, grlj, _tiot,
  { {0x68e30168, 0x64550046, 0x395d0009, 0x00000000}},  //   _eind, wdzi, _frws_,
  { {0xd6d801fb, 0x68e327eb, 0x660f0036, 0x00000000}},  //   ють_, _find, rack,
  { {0x67210107, 0x68e30035, 0xd8382782, 0x00000000}},  //   brlj, _gind, biča_,
  { {0x64550046, 0x644701aa, 0x628d27ec, 0x00000000}},  //   rdzi, reji, thao,
  { {0x44ef006c, 0x6aa00009, 0x6447013e, 0x00000000}},  //   _tü_, nimf, seji,
  { {0x628d160e, 0x67280c6c, 0x68e30009, 0x00000000}},  // [6e50] rhao, ludj, _yind,
  { {0x628d0060, 0x6ef301d5, 0x660d006c, 0x00000000}},  //   shao, _aħba, _heak,
  { {0x67280521, 0x660d09e4, 0x6aa027ed, 0x00000000}},  //   nudj, _keak, kimf,
  { {0x9c7c2679, 0x00000000, 0x00000000, 0x00000000}},  //   _riča,   ,   ,
  { {0x3ead008d, 0x63ad001e, 0x248c010a, 0x00000000}},  //   _vjet_, šinā, šimų_,
  { {0xe3df0055, 0x317a00b6, 0x2249022b, 0x00000000}},  //   _ব্যব, _הרשמ, leak_,
  { {0x68e3154c, 0x68eb0058, 0x6abb009d, 0x00000000}},  //   _rind, _sugd, touf,
  { {0xd83827dc, 0x2249002d, 0x660d0142, 0x00000000}},  //   viča_, neak_, _neak,
  { {0x6aa927ee, 0x00000000, 0x00000000, 0x00000000}},  //   rnef,   ,   ,
  { {0x6284002d, 0x68e30065, 0x6aa9000c, 0x00000000}},  //   zkio, _qind, snef,
  { {0x660d00f8, 0x629d03bd, 0x68e30f12, 0x00000000}},  //   _beak, _omso, _vind,
  { {0x7d0927ef, 0x9411006b, 0x6490006c, 0x00000000}},  //   _kwes, mizə_, _käig,
  { {0x2249022b, 0x660d122f, 0x21290022, 0x00000000}},  //   deak_, _deak, juah_,
  { {0x9c7c05fa, 0x629d0061, 0x672827f0, 0x00000000}},  //   _ličn, _amso, budj,
  { {0x93591969, 0x67280107, 0x87040379, 0x00000000}},  //   орту_, cudj, _قبيل,
  { {0xc7b2019b, 0x2249002d, 0x660d01d6, 0x00000000}},  //   _רבה_, geak_, _geak,
  { {0x66e800b9, 0x61430545, 0x21670088, 0x00000000}},  // [6e60] _děku, нета, пити_,
  { {0x823609bc, 0x90c3007c, 0x76561c39, 0x00000000}},  //   _کردا, ебуе, _hayy,
  { {0x2249002d, 0x7d0900ab, 0x00000000, 0x00000000}},  //   beak_, _awes,   ,
  { {0x21290149, 0xddcf1890, 0x442500a1, 0x00000000}},  //   buah_, _šeše, _ٹریف,
  { {0x78a1009f, 0x7d09018e, 0x7afa0093, 0x00000000}},  //   kilv, _cwes, _sttt,
  { {0x653b0049, 0x9411006b, 0x394d01d6, 0x00000000}},  //   מענד, fizə_, dwes_,
  { {0x5f27004c, 0x3af10011, 0xdd8f00a1, 0x00000000}},  //   _норм_, _cáp_, نڈے_,
  { {0x3a2d27f1, 0x00000000, 0x00000000, 0x00000000}},  //   ggep_,   ,   ,
  { {0x660d047c, 0x7d090016, 0x78a100ea, 0x00000000}},  //   _reak, _gwes, filv,
  { {0x2249002d, 0x6728002b, 0x8afc0036, 0x00000000}},  //   zeak_, tudj, _pręd,
  { {0x660d0004, 0x66e80224, 0x99e60242, 0x00000000}},  //   _peak, _někt, _ежед,
  { {0x2249002d, 0x2a6600e0, 0x394d27f2, 0x00000000}},  //   xeak_, _unob_, bwes_,
  { {0x67280107, 0x20be0164, 0x78a106d3, 0x00000000}},  //   sudj, ्ताध, bilv,
  { {0xb9db00b6, 0x649008b2, 0x176a27f3, 0x00000000}},  //   _החדש, _näid, _грип_,
  { {0x083b01f8, 0x2249022b, 0x883b009b, 0x00000000}},  //   _העול, teak_, _לתגו,
  { {0xe8df0011, 0x21290093, 0xd1bb0025, 0x00000000}},  //   ược_, tuah_, ماذا_,
  { {0x2249022b, 0x76960006, 0xe1f00025, 0x00000000}},  // [6e70] reak_, ršyt, اسف_,
  { {0x2249002d, 0x4f6b007c, 0x212901a3, 0x00000000}},  //   seak_, йшем_, ruah_,
  { {0x3f870161, 0x212901a3, 0x00000000, 0x00000000}},  //   ánu_, suah_,   ,
  { {0x3f8f0036, 0x3af10011, 0x645701f3, 0x00000000}},  //   ągu_, _ráp_, _haxi,
  { {0x3f870091, 0x3af10082, 0x3ce5010e, 0x00000000}},  //   šnu_, _sáp_, _pilv_,
  { {0xd7e60054, 0x645701c3, 0xea63009e, 0x00000000}},  //   _لك_, _jaxi, کھئی,
  { {0x6a7c009d, 0x443300d2, 0x999f012d, 0x00000000}},  //   _réfr, _mcx_, deuš_,
  { {0x9411005f, 0x7d090807, 0x64570068, 0x00000000}},  //   rizə_, _twes, _laxi,
  { {0x44330c0d, 0x6ba6006b, 0x7e69058b, 0x00000000}},  //   _ocx_, _əsgə, _inep,
  { {0x7e7b013e, 0x76560d92, 0x9f5a004a, 0x00000000}},  //   _houp, _sayy, capó_,
  { {0x7e7b1c5c, 0x7e6902e7, 0x00000000, 0x00000000}},  //   _koup, _knep,   ,
  { {0xe5a609f1, 0xd0160044, 0x7e7b21ab, 0x00000000}},  //   дими, ালয়_, _joup,
  { {0x6b8327f4, 0x6457006b, 0x7e7b000a, 0x00000000}},  //   lyng, _baxi, _moup,
  { {0xd9420057, 0x64570181, 0x98f40025, 0x00000000}},  //   _реши, _caxi, _أثنا,
  { {0x6457005f, 0xa3d803d7, 0x7656005a, 0x00000000}},  //   _daxi, ़ें_, _tayy,
  { {0x7e7b27f5, 0x00000000, 0x00000000, 0x00000000}},  //   _noup,   ,   ,
  { {0x00e6008b, 0x64571806, 0x8afc0036, 0x00000000}},  // [6e80] джан, _faxi, _kręc,
  { {0xf4250055, 0xeb0d013d, 0x00000000, 0x00000000}},  //   ম্বর_, _सबूत_,   ,
  { {0x6490006c, 0xdd8f02fd, 0x00000000, 0x00000000}},  //   _väid, یوم_,   ,
  { {0x7e7b030a, 0xdfcf0025, 0x00000000, 0x00000000}},  //   _coup, جيم_,   ,
  { {0x6490006c, 0x4103005e, 0x7e7b27f6, 0x00000000}},  //   _täid, _изяв, _doup,
  { {0x44f400b0, 0x6b830016, 0x6fd60309, 0x00000000}},  //   _mä_, fyng, _भरपू,
  { {0x6b83018e, 0x6490006c, 0x9057009b, 0x00000000}},  //   gyng, _käib, _קבלו_,
  { {0xf1bf002a, 0x5a34011e, 0x7e7b009d, 0x00000000}},  //   _gcás_, хнит, _goup,
  { {0x44f40c43, 0xcfb00044, 0xbea32337, 0x00000000}},  //   _nä_, _করিন, _ратк,
  { {0x7d0227f7, 0x6c3200a1, 0xd7f70454, 0x00000000}},  //   mpos, _شہبا, мую_,
  { {0x7d0200b0, 0x7e7b009d, 0x44330068, 0x00000000}},  //   lpos, _youp, _rcx_,
  { {0x64570c95, 0x44331fce, 0x79a600e2, 0x00000000}},  //   _saxi, _scx_, _орле,
  { {0x7d02002d, 0x64570061, 0xb4e90164, 0x00000000}},  //   npos, _paxi, यदे_,
  { {0xd7ef0098, 0x7d020087, 0x44f406d3, 0x00000000}},  //   _ју_, ipos, _dä_,
  { {0xf8b000a1, 0x18330025, 0x22420288, 0x00000000}},  //   _لکھ_, _شروح, _bbkk_,
  { {0x2738049a, 0x6457016b, 0x320f0010, 0x00000000}},  //   mén_, _waxi, úgy_,
  { {0x7e7b0181, 0x2738167d, 0x7d02049c, 0x00000000}},  // [6e90] _roup, lén_, jpos,
  { {0x7e7b27f8, 0x6fa0013d, 0xd011002c, 0x00000000}},  //   _soup, _गेहू, الا_,
  { {0x7e7b1729, 0x2fc70030, 0x39460009, 0x00000000}},  //   _poup, æng_, _lpos_,
  { {0x394600d4, 0x7d020240, 0x00000000, 0x00000000}},  //   _opos_, fpos,   ,
  { {0x7d020e95, 0x84980014, 0x1d0901c0, 0x00000000}},  //   gpos, _رئیس_, чели_,
  { {0x64900004, 0x443101d0, 0x27380010, 0x00000000}},  //   _täie, ngz_, kén_,
  { {0x7e7b0263, 0x4fc427f9, 0xce95005e, 0x00000000}},  //   _toup, _аста, _завъ,
  { {0x7d0200ea, 0x20110032, 0x273827fa, 0x00000000}},  //   bpos, _hezi_, dén_,
  { {0x7d0202a9, 0x39460085, 0x00000000, 0x00000000}},  //   cpos, _cpos_,   ,
  { {0x20110263, 0x81b10044, 0xf0920049, 0x00000000}},  //   _jezi_, _ওরা_, ָנט_,
  { {0x20110224, 0x39460007, 0x27380344, 0x00000000}},  //   _mezi_, _epos_, gén_,
  { {0x20110107, 0xa9090025, 0x63bb005d, 0x00000000}},  //   _lezi_, _فيصل_, ğunl,
  { {0x3eaf0051, 0x63bb006b, 0xd914007e, 0x00000000}},  //   ingt_, şunl, _адчы,
  { {0x2738008e, 0x9f41004a, 0x00000000, 0x00000000}},  //   bén_, nchó_,   ,
  { {0x22590066, 0x2738008e, 0x7d0227fb, 0x00000000}},  //   _bask_, cén_, zpos,
  { {0x22590606, 0x44f40bac, 0xd04a006b, 0x00000000}},  //   _cask_, _tä_, ənəv,
  { {0x95560054, 0x26c2002d, 0x76440009, 0x00000000}},  // [6ea0] _أخبا, moko_, _ibiy,
  { {0x26c20d58, 0x628f15e3, 0xb21b0030, 0x00000000}},  //   loko_, _elco, _blæs,
  { {0x03a60088, 0x644e0146, 0x7d1b27fc, 0x00000000}},  //   _чино, mebi, _avus,
  { {0x81e20055, 0x444401a3, 0x645c27fd, 0x00000000}},  //   নুষ_, _hb_, ldri,
  { {0x9f5800d4, 0x27380d7f, 0x127b0049, 0x00000000}},  //   _peró_, zén_, _זאכע,
  { {0xa802005f, 0x98a4001e, 0x7d0200ab, 0x00000000}},  //   _çıxa, kumā_, rpos,
  { {0x98a4001e, 0x26c202f6, 0x394601ee, 0x00000000}},  //   jumā_, koko_, _spos_,
  { {0x44441d9e, 0x6564011c, 0x7f3b00a0, 0x00000000}},  //   _lb_, _orih, _מעלו,
  { {0x444427fe, 0x644e0453, 0x26c2002d, 0x00000000}},  //   _ob_, kebi, doko_,
  { {0x27380047, 0x4444006c, 0x764404cd, 0x00000000}},  //   tén_, _nb_, _abiy,
  { {0x5695029b, 0x644e11bd, 0xd7f8001a, 0x00000000}},  //   вант, debi, rcă_,
  { {0x4444051d, 0x645c125b, 0x9bb7012e, 0x00000000}},  //   _ab_, edri, _אהבה_,
  { {0x225901e3, 0x656400e5, 0x27380232, 0x00000000}},  //   _rask_, _crih, sén_,
  { {0x44441134, 0x644e0f4f, 0x645c00d9, 0x00000000}},  //   _cb_, gebi, gdri,
  { {0x44441233, 0x3267008b, 0x26c20091, 0x00000000}},  //   _db_, нтав, boko_,
  { {0xd25827ff, 0x201101aa, 0x65640cb2, 0x00000000}},  //   нцу_, _sezi_, _frih,
  { {0x4444023a, 0x44310061, 0x2b520036, 0x00000000}},  // [6eb0] _fb_, pgz_, łych_,
  { {0x4444001d, 0x644e0181, 0xd91b00a3, 0x00000000}},  //   _gb_, cebi, פובל,
  { {0x2011000d, 0xceeb0167, 0x225900ab, 0x00000000}},  //   _vezi_, سران_, _task_,
  { {0x9f582800, 0x765d0030, 0x531a01ce, 0x00000000}},  //   _però_, ndsy, _קורצ,
  { {0x3209011c, 0x44442801, 0x760c0049, 0x00000000}},  //   mbay_, _yb_, פּאַ,
  { {0x7d1c0089, 0x26c21242, 0x21292802, 0x00000000}},  //   _ārst, zoko_, mrah_,
  { {0x5fc50061, 0x442100d9, 0x26c20020, 0x00000000}},  //   _वडिल, _mdh_, yoko_,
  { {0x644e2803, 0x98a40089, 0x395f010e, 0x00000000}},  //   zebi, vumā_, tvus_,
  { {0x6e940264, 0x644e011f, 0xb60400b9, 0x00000000}},  //   _ситу, yebi, ndář,
  { {0x644e002d, 0x26c22804, 0x6aa20026, 0x00000000}},  //   xebi, woko_, _emof,
  { {0x4444023a, 0x6c7a0049, 0x3209011c, 0x00000000}},  //   _rb_, _קרעד, kbay_,
  { {0x65640027, 0x444400b9, 0x2ca7000c, 0x00000000}},  //   _prih, _sb_, lind_,
  { {0x44440181, 0x26c2022b, 0x644e04db, 0x00000000}},  //   _pb_, roko_, tebi,
  { {0x61fd0030, 0x2ca7001a, 0x98a40089, 0x00000000}},  //   _afsl, nind_, pumā_,
  { {0x645c0030, 0x69cb1c83, 0x44210146, 0x00000000}},  //   rdri, _hyge, _ddh_,
  { {0x2ca72805, 0x644e2806, 0x7afc0047, 0x00000000}},  //   hind_, sebi, _érte,
  { {0x2ca7063c, 0x21290093, 0x656401f3, 0x00000000}},  // [6ec0] kind_, grah_, _urih,
  { {0x44440af0, 0x7aeb26c3, 0x42c40044, 0x00000000}},  //   _ub_, _ligt, ্দেশ,
  { {0xee3a012b, 0x6d49049a, 0xe29a0517, 0x00000000}},  //   дне_, _apea, _жан_,
  { {0x26c30119, 0x787e00b9, 0x32090082, 0x00000000}},  //   čkog_, _závě, cbay_,
  { {0x2ca70606, 0x3ea61689, 0x201c00c4, 0x00000000}},  //   find_, riot_, óvis_,
  { {0x9f58000c, 0x60c70022, 0x2ca72807, 0x00000000}},  //   _ferð_, _gkjm, gind_,
  { {0x7aeb0058, 0x9f58000c, 0x8fa6004d, 0x00000000}},  //   _bigt, _gerð_, _раве,
  { {0x69cb0343, 0x67280521, 0xab8300a8, 0x00000000}},  //   _byge, vrdj, рушк,
  { {0x7aeb2808, 0x2ca701d6, 0x764f00d2, 0x00000000}},  //   _digt, bind_, vecy,
  { {0x2ca72809, 0x2bbb013d, 0x00000000, 0x00000000}},  //   cind_, _ऊँचा,   ,
  { {0x3209011c, 0x7aeb0146, 0x9c7c0738, 0x00000000}},  //   ybay_, _figt, _niči,
  { {0x4421280a, 0x473300a1, 0x752f0036, 0x00000000}},  //   _sdh_, گریز, tucz,
  { {0x44210300, 0x385700a6, 0x68ea0066, 0x00000000}},  //   _pdh_, رشید_, _tifd,
  { {0x3af8280b, 0x98a300ed, 0x9c7c0006, 0x00000000}},  //   _kép_, _киче, _biči,
  { {0xa3dd03d7, 0x44210302, 0xd25b1076, 0x00000000}},  //   तें_, _vdh_, мца_,
  { {0xd83805d2, 0x212901a3, 0x44210240, 0x00000000}},  //   diči_, trah_, _wdh_,
  { {0xdddb0428, 0x320915dc, 0x3af8280c, 0x00000000}},  // [6ed0] _služ, rbay_, _lép_,
  { {0x9418005f, 0x66df0a5c, 0x44211c70, 0x00000000}},  //   kirə_, _tūks, _udh_,
  { {0x2ca7280d, 0x6d4900ab, 0xdb1e00f4, 0x00000000}},  //   vind_, _spea, _évèn,
  { {0x2ca70007, 0x9f58009f, 0x21290093, 0x00000000}},  //   wind_, _verð_, prah_,
  { {0x7aeb280e, 0x2ca7001a, 0x3cec0082, 0x00000000}},  //   _rigt, tind_, _bidv_,
  { {0x7aeb280f, 0x6490006c, 0x69cb0030, 0x00000000}},  //   _sigt, _läin, _ryge,
  { {0x447c007b, 0x2ca72810, 0x69cb0030, 0x00000000}},  //   ונגע, rind_, _syge,
  { {0x3af82811, 0x2ca71dd4, 0x649001c2, 0x00000000}},  //   _dép_, sind_, _näin,
  { {0x7aeb2812, 0x2ca72813, 0x6d4900b0, 0x00000000}},  //   _vigt, pind_, _upea,
  { {0xd7090057, 0x7aeb01c3, 0x2ca70023, 0x00000000}},  //   нное_, _wigt, qind_,
  { {0x16aa0b11, 0x3af80010, 0x69cb00b4, 0x00000000}},  //   евни_, _gép_, _wyge,
  { {0x69cb04d1, 0xd05c006b, 0xda67009e, 0x00000000}},  //   _tyge, _dirə, _جائي,
  { {0x5e560049, 0x6aa9095d, 0x07e800a1, 0x00000000}},  //   נישע_, mief, ٹریٹ_,
  { {0x2eed2814, 0x6aa90dcc, 0x92b00044, 0x00000000}},  //   _lief_, lief, _ওঠে_,
  { {0xd05c006b, 0x00000000, 0x00000000, 0x00000000}},  //   _girə,   ,   ,
  { {0xb295012b, 0x6aa90146, 0x628d0058, 0x00000000}},  //   ајућ, nief, gkao,
  { {0xe0da012b, 0x412703dc, 0x7989000b, 0x00000000}},  // [6ee0] ева_, лото_, nyew,
  { {0x459b0104, 0x0717007d, 0x6616005d, 0x00000000}},  //   _נסיע, _दबाव_, _heyk,
  { {0xe457007b, 0x443a0011, 0x9418006b, 0x00000000}},  //   _גייט_, _icp_, xirə_,
  { {0xdb1e00f4, 0x42560331, 0x443a00f8, 0x00000000}},  //   _évén, _стот, _hcp_,
  { {0x63b6001e, 0x2eed040f, 0x98a40006, 0x00000000}},  //   šanā, _dief_, lumą_,
  { {0x10a601e0, 0x6adc02d2, 0x645e0065, 0x00000000}},  //   _сигн, मग्र, _japi,
  { {0x645e15f4, 0x201a08e3, 0x2ba70164, 0x00000000}},  //   _mapi, mapi_, _केदा,
  { {0x201a2815, 0xdd1600a6, 0x6f0300d4, 0x00000000}},  //   lapi_, _مورخ, ínce,
  { {0x443a0048, 0xcc360355, 0x00000000, 0x00000000}},  //   _ocp_, _مراع,   ,
  { {0x315700b6, 0xfce6005e, 0x8d930025, 0x00000000}},  //   ניין_, _созо, _الكش,
  { {0xb8660014, 0xc6000044, 0x24810740, 0x00000000}},  //   ناگو, ্ণনা_, _rohm_,
  { {0x41b40061, 0x645e2816, 0x00000000, 0x00000000}},  //   ंपास, _aapi,   ,
  { {0x201a0169, 0x443a263c, 0x386e00f6, 0x00000000}},  //   kapi_, _bcp_, _tnfr_,
  { {0x645e2817, 0x66d611ea, 0x00000000, 0x00000000}},  //   _capi, ráka,   ,
  { {0x201a04cb, 0xf53f1861, 0x645e2818, 0x00000000}},  //   dapi_, stå_, _dapi,
  { {0x925803dc, 0x68ed002a, 0x661601c3, 0x00000000}},  //   ласт_, _éadr, _geyk,
  { {0x7c3a1de2, 0x645e2323, 0x2eed01a2, 0x00000000}},  // [6ef0] _octr, _fapi, _rief_,
  { {0x645e01d6, 0x201a2819, 0x00000000, 0x00000000}},  //   _gapi, gapi_,   ,
  { {0x23fa009b, 0x14b80426, 0x20d400b0, 0x00000000}},  //   _בהתא, _حديث_, päin_,
  { {0x645e281a, 0xed59012d, 0x00000000, 0x00000000}},  //   _zapi, _psž_,   ,
  { {0x645e055b, 0xed59003b, 0xddc5025f, 0x00000000}},  //   _yapi, тол_, јбли,
  { {0x99dd00b9, 0x64900bac, 0x201a0145, 0x00000000}},  //   zeňs, _näil, capi_,
  { {0x6aa907eb, 0x3f87006c, 0x2eed010f, 0x00000000}},  //   tief, änud_, _tief_,
  { {0xa92501c0, 0x00000000, 0x00000000, 0x00000000}},  //   адил,   ,   ,
  { {0x6616009f, 0xe9d9005e, 0x8e840025, 0x00000000}},  //   _reyk, ъки_, _القه,
  { {0xa3b503d7, 0x00000000, 0x00000000, 0x00000000}},  //   जपा_,   ,   ,
  { {0xe739012b, 0xf745003b, 0x81ce0044, 0x00000000}},  //   њем_, шено, ষেপ_,
  { {0x6b7a0476, 0x645e26df, 0xd5e60216, 0x00000000}},  //   _ברענ, _sapi, ижни,
  { {0x2d9d0061, 0x443a281b, 0xc8b40123, 0x00000000}},  //   nzwe_, _pcp_, _گلوک,
  { {0x2aba0089, 0x37e50131, 0x00000000, 0x00000000}},  //   mība_, _колг,   ,
  { {0x6383012b, 0x2aba0089, 0xc7a2005e, 0x00000000}},  //   огра, lība_, _мишк,
  { {0x645e000b, 0x98a40006, 0x60280089, 0x00000000}},  //   _wapi, rumą_, zīmē,
  { {0x201a027e, 0xe1f701e1, 0x2aba0089, 0x00000000}},  // [6f00] tapi_, ргу_, nība_,
  { {0x60260c4e, 0x6490006c, 0xa4940014, 0x00000000}},  //   рджа, _käim, _ایست,
  { {0x6d5b0144, 0xb4c4013d, 0x41d5013d, 0x00000000}},  //   _asua, ौती_, _दरअस,
  { {0x201a281c, 0xdfcf0054, 0xcd06092b, 0x00000000}},  //   sapi_, ذين_, ачки,
  { {0x201a010e, 0x00000000, 0x00000000, 0x00000000}},  //   papi_,   ,   ,
  { {0x2aba0089, 0x4438281d, 0x9b26004d, 0x00000000}},  //   dība_, ngr_, афил,
  { {0x2018061a, 0x92d80055, 0x66dd0010, 0x00000000}},  //   _ieri_, াদী_, léke,
  { {0xe8df001d, 0x6490003c, 0x20180258, 0x00000000}},  //   ước_, _säil, _heri_,
  { {0x7c3a00ea, 0xed570a78, 0x5ecc0044, 0x00000000}},  //   _tctr, _кот_, িষদে,
  { {0x7e620bc7, 0x7e600971, 0x47340a85, 0x00000000}},  //   ldop, _hamp, бнос,
  { {0xb8fd03d7, 0x501b00b6, 0x20181553, 0x00000000}},  //   _थी_, כויו, _meri_,
  { {0x4438018e, 0x7bda1e6b, 0x7e600145, 0x00000000}},  //   egr_, _iztu, _jamp,
  { {0x7e60020c, 0x2aba001e, 0x6d420e67, 0x00000000}},  //   _mamp, cība_, ntoa,
  { {0x442d001f, 0x2018064c, 0x7e6009d5, 0x00000000}},  //   ße_, _neri_, _lamp,
  { {0x93880081, 0x61ec006b, 0xa87b01ce, 0x00000000}},  //   аста_, ənlə, _באגר,
  { {0x7e600127, 0x2018281e, 0xa8030279, 0x00000000}},  //   _namp, _aeri_, _çırp,
  { {0x661d1dc7, 0x201814d7, 0x7e620197, 0x00000000}},  // [6f10] mask, _beri_, ddop,
  { {0xdb1a00f4, 0x6d42281f, 0x29060020, 0x00000000}},  //   _exté, dtoa, _mtoa_,
  { {0x2018008d, 0x46bb0309, 0x64551c5e, 0x00000000}},  //   _deri_, _उदाह, mezi,
  { {0x64552820, 0x44fd0011, 0x661d26bd, 0x00000000}},  //   lezi, _kì_, nask,
  { {0x7e60023a, 0x63bb005a, 0x4e180014, 0x00000000}},  //   _damp, ğunu, شتند_,
  { {0x64550207, 0x2018049d, 0xaf3700a6, 0x00000000}},  //   nezi, _geri_, _پرست,
  { {0x1fe50055, 0x2f18008b, 0x661d170d, 0x00000000}},  //   _প্রস, _вось_, kask,
  { {0x7e60023a, 0x291f002d, 0x13b8009b, 0x00000000}},  //   _gamp, tsua_, יהול_,
  { {0x6d5b201e, 0x20180279, 0xcaa40025, 0x00000000}},  //   _usua, _yeri_, تصوي,
  { {0x2001000b, 0x7e600197, 0x2aba0089, 0x00000000}},  //   nchi_, _zamp, rība_,
  { {0x66dd0010, 0x2aba0089, 0x291f0511, 0x00000000}},  //   zéke, sība_, ssua_,
  { {0xa50a2821, 0x661d04d4, 0x7e6000d4, 0x00000000}},  //   лема_, gask, _xamp,
  { {0x64550207, 0xddcb0036, 0x44382822, 0x00000000}},  //   fezi, legł, tgr_,
  { {0x2a7f003b, 0x66dd0010, 0x645500bb, 0x00000000}},  //   ljub_, véke, gezi,
  { {0x66e603f3, 0x661d04cb, 0x64a32823, 0x00000000}},  //   _лока, bask, чара,
  { {0x66dd0047, 0x272301f6, 0x20182824, 0x00000000}},  //   téke, mın_, _seri_,
  { {0x44fd001d, 0x2ef80142, 0x7e602397, 0x00000000}},  // [6f20] _gì_, _surf_, _ramp,
  { {0x7e600971, 0x21200169, 0x64550207, 0x00000000}},  //   _samp, rsih_, cezi,
  { {0x2723038c, 0x201814ce, 0x7e60066d, 0x00000000}},  //   nın_, _veri_, _pamp,
  { {0xc33300b6, 0x7e6200ea, 0x6d420dc9, 0x00000000}},  //   _צור_, udop, ttoa,
  { {0xf767009c, 0x7bda0046, 0x763b007b, 0x00000000}},  //   _کا_, _sztu, רענג,
  { {0x40960054, 0x20010198, 0x27230676, 0x00000000}},  //   _السر, cchi_, kın_,
  { {0x62860f80, 0xa3e0006e, 0x6d420315, 0x00000000}},  //   _koko, _तरफ_, stoa,
  { {0x272301f6, 0x6286002d, 0x6d420035, 0x00000000}},  //   dın_, _joko, ptoa,
  { {0x661d0030, 0x62860006, 0xdee32825, 0x00000000}},  //   vask, _moko, _хоти,
  { {0x415b0049, 0x09070044, 0x66042826, 0x00000000}},  //   נדיג, _শিশু_, _afik,
  { {0x661d000c, 0x44fd0438, 0x7bda0089, 0x00000000}},  //   task, _sì_, _uztu,
  { {0x62860056, 0x645500bb, 0x00000000, 0x00000000}},  //   _noko, wezi,   ,
  { {0x64550ef1, 0xf1bf008e, 0x66dd0010, 0x00000000}},  //   tezi, _adán_, tékb,
  { {0x44fd001d, 0x661d2827, 0x2723005d, 0x00000000}},  //   _vì_, sask, bın_,
  { {0x64552828, 0x7afa0943, 0x661d01a3, 0x00000000}},  //   rezi, _jutt, pask,
  { {0x7afa0e2d, 0x64552829, 0x44fd0082, 0x00000000}},  //   _mutt, sezi, _tì_,
  { {0x62860387, 0x6455002d, 0x7afa00f4, 0x00000000}},  // [6f30] _doko, pezi, _lutt,
  { {0x656d0009, 0x649000b0, 0x64550023, 0x00000000}},  //   _irah, _näih, qezi,
  { {0x7afa00d9, 0x20010207, 0x6286171f, 0x00000000}},  //   _nutt, rchi_, _foko,
  { {0x656d008d, 0x7c280038, 0x20010207, 0x00000000}},  //   _krah, _addr, schi_,
  { {0x823a007b, 0x272301f6, 0x764d000b, 0x00000000}},  //   _דערצ, zın_, _mbay,
  { {0x272301f6, 0xa3bd001c, 0x7afa0498, 0x00000000}},  //   yın_, _अशा_, _butt,
  { {0xeb990741, 0x2723005f, 0x543c0049, 0x00000000}},  //   рий_, xın_, טעגא,
  { {0x7afa0d1a, 0x6490006c, 0xf78a014a, 0x00000000}},  //   _dutt, _päik, _maçı_,
  { {0xe8f60783, 0xc9850025, 0x23640089, 0x00000000}},  //   олы_, تشغي, āmji_,
  { {0x3eaf04d7, 0x7d04001e, 0x64900004, 0x00000000}},  //   ligt_, ģist, _väik,
  { {0xa3a903d7, 0x75240207, 0x656d01a3, 0x00000000}},  //   _खेल_, _sviz, _arah,
  { {0x2723038c, 0x67210521, 0x3eaf01a2, 0x00000000}},  //   rın_, rslj, nigt_,
  { {0x62860027, 0x272301f6, 0xdce0000d, 0x00000000}},  //   _roko, sın_, _urmă,
  { {0x764d001c, 0x62860127, 0x2723014a, 0x00000000}},  //   _ebay, _soko, pın_,
  { {0x6e290c0f, 0x5ec90061, 0xaca30011, 0x00000000}},  //   _odeb, िकाऱ, _huỳn,
  { {0xa3a90061, 0xb5fb19ad, 0x6e29282a, 0x00000000}},  //   _खेळ_, ndál, _ndeb,
  { {0x3eaf033d, 0x61430072, 0xe8000204, 0x00000000}},  // [6f40] digt_, мета, लुका_,
  { {0x6286282b, 0x00000000, 0x00000000, 0x00000000}},  //   _woko,   ,   ,
  { {0x6e2900f6, 0x31690320, 0x00000000, 0x00000000}},  //   _bdeb, avaz_,   ,
  { {0x823602fd, 0x7afa010e, 0x3eaf282c, 0x00000000}},  //   _بردا, _rutt, gigt_,
  { {0x7afa02e7, 0x7d09282d, 0xdce9002b, 0x00000000}},  //   _sutt, _ctes, _greċ,
  { {0x6e29011f, 0x26cb004a, 0x00000000, 0x00000000}},  //   _edeb, zoco_,   ,
  { {0x46ca0164, 0x00000000, 0x00000000, 0x00000000}},  //   रवाह,   ,   ,
  { {0x7d090065, 0xee371769, 0x2c0a0044, 0x00000000}},  //   _ftes, _мнс_, রণেই_,
  { {0x26cb0cc2, 0x9c7c0173, 0x1d071534, 0x00000000}},  //   voco_, _chčc, _мети_,
  { {0x7afa05d3, 0xa49b0263, 0x656d0065, 0x00000000}},  //   _tutt, npòt, _rrah,
  { {0x7afa00b0, 0xe7580088, 0x00000000, 0x00000000}},  //   _uutt, щині_,   ,
  { {0x656d0224, 0x569402d3, 0xc7b80166, 0x00000000}},  //   _prah, дают, gađa_,
  { {0xfaf80089, 0x19b60025, 0x7ae20052, 0x00000000}},  //   _trīs_, _بحاج, _ihot,
  { {0xfbd100a1, 0x14cb007c, 0xb4db00f6, 0x00000000}},  //   _آتے_, рыми_, ctàl,
  { {0x7ae20093, 0x2249014a, 0x26cb0555, 0x00000000}},  //   _khot, tfak_, poco_,
  { {0x656d282e, 0xdce9002b, 0x764d1ff1, 0x00000000}},  //   _trah, _preċ, _ubay,
  { {0x656d0020, 0x7ae20051, 0x3eaf282f, 0x00000000}},  // [6f50] _urah, _mhot, vigt_,
  { {0x7ae2013e, 0x8078091b, 0xb5fb140f, 0x00000000}},  //   _lhot, обус_, zdál,
  { {0x7d092830, 0x3eaf2831, 0xa7fc026d, 0x00000000}},  //   _stes, tigt_, ydın,
  { {0xe0df01aa, 0x9258007c, 0x82f80123, 0x00000000}},  //   _apòt_, _дают_, _گریز_,
  { {0x41e70106, 0x3eaf033d, 0x427a0104, 0x00000000}},  //   _фіна, rigt_, _הארג,
  { {0x4c84008b, 0x3eaf0193, 0x7ae2002d, 0x00000000}},  //   млів, sigt_, _ahot,
  { {0x2b570014, 0x7ae20048, 0xb18600f8, 0x00000000}},  //   تیاد_, _bhot, _tvåå,
  { {0x6e292832, 0x7ae20051, 0x7d090066, 0x00000000}},  //   _udeb, _chot, _ttes,
  { {0xf2d40049, 0xaca30011, 0x7d0901c9, 0x00000000}},  //   ועק_, _quỳn, _utes,
  { {0x48790057, 0x290d0032, 0x00000000, 0x00000000}},  //   ссия_, rpea_,   ,
  { {0x7ae22833, 0x6490006c, 0x7b6400aa, 0x00000000}},  //   _fhot, _käiv, _отце,
  { {0x869a00ed, 0x98ad0059, 0x7ae222d1, 0x00000000}},  //   стот_, mreč_, _ghot,
  { {0x9f580056, 0x00000000, 0x00000000, 0x00000000}},  //   _ifrå_,   ,   ,
  { {0x7ae90010, 0x3ebf04eb, 0x07a5137c, 0x00000000}},  //   lmet, _ljut_, _налн,
  { {0x7ae9013f, 0xccf2009b, 0xe29600ed, 0x00000000}},  //   omet, תכם_, праќ,
  { {0xd5ad026c, 0x7afe12b2, 0x6abb2834, 0x00000000}},  //   اہی_, ípti, nnuf,
  { {0x27e20036, 0x7ae92835, 0x8ffa0025, 0x00000000}},  // [6f60] ękne_, imet, مرار_,
  { {0xd12f0d3a, 0x7ae914ce, 0x3ebf0dd5, 0x00000000}},  //   امل_, hmet, _ajut_,
  { {0x7ae9006c, 0xd4c50380, 0xe3b20070, 0x00000000}},  //   kmet, _تغيي, _سرد_,
  { {0xdfcf0380, 0x7ae90c8a, 0xde030589, 0x00000000}},  //   ديم_, jmet, епци,
  { {0x7ae92836, 0x9c7c0087, 0x00000000, 0x00000000}},  //   dmet, _ahča,   ,
  { {0xdca3019d, 0x3ead00d4, 0x7ae91768, 0x00000000}},  //   начи, _emet_, emet,
  { {0x7ae2030a, 0xe81f013d, 0x7ae92586, 0x00000000}},  //   _phot, _मज़ा_, fmet,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x81ce0055, 0x3ea72837, 0x00000000, 0x00000000}},  //   ষের_, ënte_,   ,
  { {0x26c30119, 0x2db701ce, 0x27f805b7, 0x00000000}},  //   čkom_, _זלמן_, ørn_,
  { {0x7ae2008d, 0x1635007c, 0x7ae92838, 0x00000000}},  //   _thot, меня, bmet,
  { {0xba170025, 0xfaa3007e, 0xeb970104, 0x00000000}},  //   _فيما_, _пахо, _מדבר_,
  { {0x628412d0, 0x00000000, 0x00000000, 0x00000000}},  //   djio,   ,   ,
  { {0x26d20009, 0x6fbe0061, 0x81e20044, 0x00000000}},  //   _ekyo_, ्थां, দশা_,
  { {0x67d30099, 0x2a66006c, 0x6e222839, 0x00000000}},  //   _пошу, _kaob_, kaob,
  { {0xd7bb009b, 0x62840065, 0x66060026, 0x00000000}},  //   _לצור, gjio, cckk,
  { {0x518701f9, 0xdce901d9, 0x66dd0010, 0x00000000}},  // [6f70] чува, _sreč, léko,
  { {0x7ae9283a, 0xdce909a9, 0x3ead0a75, 0x00000000}},  //   zmet, _preč, _smet_,
  { {0x6490021e, 0x44230381, 0x7ae9014a, 0x00000000}},  //   _päiv, maj_, ymet,
  { {0xdce907a0, 0xcf98003b, 0x00000000, 0x00000000}},  //   _vreč, чју_,   ,
  { {0xdd94007e, 0x629d0197, 0x00000000, 0x00000000}},  //   нацы, _ilso,   ,
  { {0x44230381, 0xdce9283b, 0x66dd00b9, 0x00000000}},  //   naj_, _treč, kéko,
  { {0x26c30363, 0x7ae9006c, 0x66dd0010, 0x00000000}},  //   čkoj_, tmet, jéko,
  { {0xb3aa0055, 0x68e30065, 0x66dd0010, 0x00000000}},  //   _খুঁজ, _shnd, déko,
  { {0x442314d4, 0x6efa00b9, 0x6abb004e, 0x00000000}},  //   kaj_, _vůbe, rnuf,
  { {0x7ae9283c, 0x290b0089, 0x44230213, 0x00000000}},  //   smet, īca_, jaj_,
  { {0xb90403d7, 0x442305e1, 0x229c009f, 0x00000000}},  //   _भी_, daj_, _líka_,
  { {0x7a36014a, 0x7c230145, 0x00000000, 0x00000000}},  //   rütü, lanr,   ,
  { {0xa3e003d7, 0x9583007c, 0x20bf007d, 0x00000000}},  //   _तरह_, вляе, ्वाध,
  { {0x64900cfc, 0x44230059, 0x629d00b5, 0x00000000}},  //   _näit, gaj_, _also,
  { {0x6e2200ea, 0x00000000, 0x00000000, 0x00000000}},  //   yaob,   ,   ,
  { {0x3a3f0145, 0x79960036, 0x7d1b000a, 0x00000000}},  //   ngup_, _żywi, _owus,
  { {0xd84e0082, 0x00000000, 0x00000000, 0x00000000}},  // [6f80] _mọng_,   ,   ,
  { {0x4423041a, 0x92be0055, 0x6564012d, 0x00000000}},  //   caj_, ইতে_, _isih,
  { {0x645c283d, 0xb4da013d, 0xdfcf0025, 0x00000000}},  //   meri, ़ती_, ليك_,
  { {0x645c1baf, 0x44440161, 0x00000000, 0x00000000}},  //   leri, _hc_,   ,
  { {0x4444013e, 0xfee90054, 0xfe7900b9, 0x00000000}},  //   _kc_, أعلى_, _dnů_,
  { {0x6490006c, 0x00000000, 0x00000000, 0x00000000}},  //   _täiu,   ,   ,
  { {0x444400eb, 0x645c283e, 0xdfd20f8b, 0x00000000}},  //   _mc_, ieri, _شير_,
  { {0x4423283f, 0x444401a3, 0xa7fc047f, 0x00000000}},  //   zaj_, _lc_, rdım,
  { {0x4444027b, 0xa802011f, 0x4423204d, 0x00000000}},  //   _oc_, _çıka, yaj_,
  { {0x6e202840, 0x66dd0010, 0x645c20a3, 0x00000000}},  //   _hemb, téko, jeri,
  { {0x6e202841, 0x2c140316, 0x44232842, 0x00000000}},  //   _kemb, _न्यू_, vaj_,
  { {0x44440bc4, 0x6e20023a, 0x7d000020, 0x00000000}},  //   _ac_, _jemb, _kums,
  { {0x6e20020c, 0x44231191, 0x44440011, 0x00000000}},  //   _memb, taj_, _bc_,
  { {0x44442843, 0x6e200475, 0x3a2400bb, 0x00000000}},  //   _cc_, _lemb, lamp_,
  { {0x44442844, 0x442301d9, 0x7d000146, 0x00000000}},  //   _dc_, raj_, _lums,
  { {0x4423011f, 0x44442845, 0x3867016c, 0x00000000}},  //   saj_, _ec_, _zanr_,
  { {0x7c230061, 0x442301d9, 0x7d0023bd, 0x00000000}},  // [6f90] yanr, paj_, _nums,
  { {0x645c062c, 0xfe700014, 0x44230023, 0x00000000}},  //   ceri, یدن_, qaj_,
  { {0x9f040076, 0x644500b5, 0x3a2418b1, 0x00000000}},  //   نولو, _ichi, kamp_,
  { {0x765d0016, 0x7d000302, 0x4421016e, 0x00000000}},  //   nesy, _bums, _heh_,
  { {0x7d000061, 0x64900004, 0x61ad0044, 0x00000000}},  //   _cums, _täit, _কুরআ,
  { {0xf41d0055, 0x649003b6, 0x8c43001a, 0x00000000}},  //   _তাঁর_, _häir, ăşoa,
  { {0x44212846, 0xa6d60044, 0x64450020, 0x00000000}},  //   _meh_, _সংঘট, _mchi,
  { {0xc334009b, 0xd0240044, 0x6e20003f, 0x00000000}},  //   דוק_, _পায়_, _gemb,
  { {0xd84e001d, 0x645c169c, 0x6445001a, 0x00000000}},  //   _vọng_, yeri, _ochi,
  { {0x6445000b, 0x645c0039, 0x442104cb, 0x00000000}},  //   _nchi, xeri, _neh_,
  { {0x765d04cd, 0x645c2847, 0x7e6900e0, 0x00000000}},  //   fesy, veri, _kaep,
  { {0x64450899, 0xeb96007b, 0x44440181, 0x00000000}},  //   _achi, _אדער_, _sc_,
  { {0x442106ae, 0x753d0010, 0x2d49008e, 0x00000000}},  //   _beh_, gusz, núe_,
  { {0x444400f4, 0x442112da, 0xb4da013d, 0x00000000}},  //   _qc_, _ceh_, ़ते_,
  { {0x444402d5, 0x645c0292, 0xe815001c, 0x00000000}},  //   _vc_, reri, _द्या_,
  { {0x645c209d, 0x6445000d, 0xdb1a00b0, 0x00000000}},  //   seri, _echi, _tytö,
  { {0x444402ad, 0x6e2000f4, 0x65640ab9, 0x00000000}},  // [6fa0] _tc_, _remb, _usih,
  { {0x7d0000eb, 0x645c0065, 0xe0d7003b, 0x00000000}},  //   _rums, qeri, еву_,
  { {0x6e200149, 0x7d002848, 0xe4c90025, 0x00000000}},  //   _pemb, _sums, _تبين_,
  { {0x6490006c, 0x1ea90379, 0x20d4003c, 0x00000000}},  //   _täis, واني_, täis_,
  { {0x3a242849, 0x44210784, 0x69d922fc, 0x00000000}},  //   vamp_, _yeh_, _nywe,
  { {0x765d0036, 0x6e2011c2, 0x7c2100d4, 0x00000000}},  //   zesy, _wemb, _celr,
  { {0x6e2004cb, 0x3a240087, 0x6d4b00d9, 0x00000000}},  //   _temb, tamp_, atga,
  { {0x7d000089, 0x7e7b00d2, 0x69d901c3, 0x00000000}},  //   _tums, _gnup, _bywe,
  { {0x3a2404d1, 0x7c2108fe, 0x6d4b0203, 0x00000000}},  //   ramp_, _felr, ctga,
  { {0x69d9018e, 0x3ae1284a, 0xb5fb284b, 0x00000000}},  //   _dywe, rópa_, ndáv,
  { {0x80370049, 0x21290161, 0x00000000, 0x00000000}},  //   ענטע_, zsah_,   ,
  { {0x6445284c, 0x6f030b33, 0x4421284d, 0x00000000}},  //   _schi, ínci, _seh_,
  { {0x765d0263, 0xba170025, 0x44210145, 0x00000000}},  //   resy, _أيها_, _peh_,
  { {0x753d0036, 0x765d1129, 0xb866284e, 0x00000000}},  //   rusz, sesy, _ساتو,
  { {0x765d110c, 0x00000000, 0x00000000, 0x00000000}},  //   pesy,   ,   ,
  { {0x44210ea4, 0x753d0ef2, 0x5575004d, 0x00000000}},  //   _weh_, pusz, _агит,
  { {0x25b7026c, 0x44210087, 0x60f90147, 0x00000000}},  // [6fb0] _سندھ_, _teh_, дная_,
  { {0x64450020, 0x2aba0089, 0x7e7b0190, 0x00000000}},  //   _uchi, mību_, _snup,
  { {0x2aba0089, 0x9c7c000a, 0x32090022, 0x00000000}},  //   lību_, _chčm, pcay_,
  { {0x752d0107, 0x6d4b010f, 0xb21b000c, 0x00000000}},  //   _kvaz, ttga, _snæf,
  { {0x2aba001e, 0x8d65007c, 0x660d0066, 0x00000000}},  //   nību_, твле, _mfak,
  { {0x013600b6, 0x6d4b00ab, 0x7bda0190, 0x00000000}},  //   _ברשת_, rtga, _bytu,
  { {0x7bda284f, 0x9f4700b0, 0xfaa500a8, 0x00000000}},  //   _cytu, änä_, како,
  { {0x6d4b001c, 0x6f0901ca, 0x628f0173, 0x00000000}},  //   ptga, _čech, _joco,
  { {0xfc330167, 0x628f14a6, 0xdce90035, 0x00000000}},  //   _محض_, _moco, _creă,
  { {0x5ba701fb, 0x628f008e, 0xb4bd0309, 0x00000000}},  //   _през, _loco, ेको_,
  { {0x7bda0016, 0xddc20089, 0x7af9005b, 0x00000000}},  //   _gytu, mdoš, _tiwt,
  { {0x969601fc, 0x628f0c8a, 0xe1ff0082, 0x00000000}},  //   трош, _noco, _ngó_,
  { {0x05630a12, 0x29d20014, 0x00000000, 0x00000000}},  //   авян, _پيوس,   ,
  { {0x2a6d018e, 0xf7700014, 0xddc00087, 0x00000000}},  //   ldeb_, _گاه_, _jamš,
  { {0x394d04bd, 0x628f008a, 0x752d001a, 0x00000000}},  //   ltes_, _boco, _evaz,
  { {0x628f0390, 0xf65f01aa, 0x2a6d0016, 0x00000000}},  //   _coco, ceæ_, ndeb_,
  { {0x394d2850, 0x41270113, 0x2aba001e, 0x00000000}},  // [6fc0] ntes_, кото_, cību_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x649b0476, 0x394d2851, 0x26c30235, 0x00000000}},  //   _חסיד, htes_, čkov_,
  { {0x394d063c, 0x65762852, 0x7bda0a62, 0x00000000}},  //   ktes_, _kryh, _rytu,
  { {0x7bda0036, 0x394d2853, 0x3f9c012d, 0x00000000}},  //   _sytu, jtes_, švu_,
  { {0x61e62854, 0xdd93007e, 0xb5fb0051, 0x00000000}},  //   _izkl, рашы, leác,
  { {0x2d80000d, 0x2aba0089, 0xfe460959, 0x00000000}},  //   ţie_, zību_, _инво,
  { {0x394d0007, 0xdee60088, 0x628f0129, 0x00000000}},  //   ftes_, _роби, _xoco,
  { {0x394d2855, 0x3ea600e0, 0x00000000, 0x00000000}},  //   gtes_, mhot_,   ,
  { {0x7bda0046, 0xa786007a, 0x2bc20061, 0x00000000}},  //   _tytu, نشجو, षपदा,
  { {0x69c40006, 0x752d00b9, 0x394d00ab, 0x00000000}},  //   _žied, _svaz, ates_,
  { {0x394d0129, 0xc7b8016e, 0x2aba0089, 0x00000000}},  //   btes_, nađi_, tību_,
  { {0x394d04bd, 0x98c600a8, 0x628f008e, 0x00000000}},  //   ctes_, _искл, _roco,
  { {0x09e30001, 0x628f0181, 0x2aba0089, 0x00000000}},  //   _точн, _soco, rību_,
  { {0x628f0211, 0x2aba001e, 0x3ea6033b, 0x00000000}},  //   _poco, sību_, khot_,
  { {0x752d004a, 0x00000000, 0x00000000, 0x00000000}},  //   _tvaz,   ,   ,
  { {0x752d14ba, 0x65760146, 0x00000000, 0x00000000}},  // [6fd0] _uvaz, _gryh,   ,
  { {0x6aa20016, 0x26c30161, 0x673a0112, 0x00000000}},  //   _llof, čkou_, ortj,
  { {0x25b700a1, 0x44332249, 0x628f00c4, 0x00000000}},  //   _سنگھ_, _idx_, _toco,
  { {0x394d1b18, 0xdbdc000c, 0x44332856, 0x00000000}},  //   ytes_, _ráði, _hdx_,
  { {0x394d2857, 0x5184007e, 0xfe7003e6, 0x00000000}},  //   xtes_, _кура, تدل_,
  { {0x9f0505f3, 0xb5fb0010, 0x00000000, 0x00000000}},  //   _موسو, ldás,   ,
  { {0xddc227dc, 0x6aa20173, 0xe0d20049, 0x00000000}},  //   rdoš, _blof, _הײם_,
  { {0x394d02b6, 0x3ea600bb, 0x6aa20ced, 0x00000000}},  //   ttes_, chot_, _clof,
  { {0x394d00f4, 0x6e940072, 0x2a6d0016, 0x00000000}},  //   utes_, _титу, rdeb_,
  { {0xddc91088, 0x6aa22858, 0x00000000, 0x00000000}},  //   _knež, _elof,   ,
  { {0x394d04bd, 0x5b150113, 0x00000000, 0x00000000}},  //   stes_, _смет,   ,
  { {0x394d1fcb, 0x44330033, 0x6aa2005b, 0x00000000}},  //   ptes_, _adx_, _glof,
  { {0x44332859, 0x673a0112, 0x00000000, 0x00000000}},  //   _bdx_, artj,   ,
  { {0x65760007, 0x44330253, 0x3f7311af, 0x00000000}},  //   _vryh, _cdx_, _oću_,
  { {0x42560113, 0x61e60036, 0x03a3138c, 0x00000000}},  //   лтат, _szkl, биро,
  { {0xc61e0055, 0x8646007c, 0xb7da01ce, 0x00000000}},  //   _থাকা_, _сниж, _אקצי,
  { {0x60ea004d, 0x44330133, 0x00000000, 0x00000000}},  // [6fe0] емам_, _fdx_,   ,
  { {0xb4660057, 0xa91b00e8, 0x00000000, 0x00000000}},  //   _скол, पीएफ_,   ,
  { {0xb4c0024c, 0xee3a1447, 0xef1a0265, 0x00000000}},  //   ंची_, ене_, хме_,
  { {0x442a01a3, 0xb4db0129, 0xcd2a007c, 0x00000000}},  //   lab_, gràf, ежде_,
  { {0x61e60e3f, 0xf653009b, 0x3ea60052, 0x00000000}},  //   _uzkl, מצא_, rhot_,
  { {0x442a0004, 0x4095025f, 0x6aa2005b, 0x00000000}},  //   nab_, _крст, _slof,
  { {0x8fa605a4, 0xb5fb285a, 0xddc9012d, 0x00000000}},  //   _саве, ndár, _gnež,
  { {0x442a006c, 0xbea302be, 0xd91a09f1, 0x00000000}},  //   hab_, _ласк, ньо_,
  { {0x6e930a4f, 0x442a0018, 0x5e930025, 0x00000000}},  //   _القا, kab_, _القط,
  { {0x7e620190, 0x442a03f2, 0x78740010, 0x00000000}},  //   leop, jab_, küvő,
  { {0x442a0004, 0xd7f7285b, 0xda6f007e, 0x00000000}},  //   dab_, лую_, _ля_,
  { {0x7c2a1182, 0x7e62113b, 0x59af0061, 0x00000000}},  //   lafr, neop, _जेकर,
  { {0x442a1c95, 0x9c7c0087, 0x00000000, 0x00000000}},  //   fab_, _ahči,   ,
  { {0x442a285c, 0x44250051, 0x7c2a01e5, 0x00000000}},  //   gab_, úl_, nafr,
  { {0x7e621a76, 0x78ba012d, 0x7c2a005b, 0x00000000}},  //   keop, mitv, iafr,
  { {0x78ba0ed8, 0xadf6013d, 0x29060020, 0x00000000}},  //   litv, ेशान_, _kuoa_,
  { {0x442a285d, 0xddc9179e, 0x443300d4, 0x00000000}},  // [6ff0] bab_, _snež, _tdx_,
  { {0xdddb0428, 0x78ba0059, 0x442a013f, 0x00000000}},  //   _použ, nitv, cab_,
  { {0x7ced0d7b, 0x7ae00009, 0x00000000, 0x00000000}},  //   lúrg, klmt,   ,
  { {0xdce90091, 0x644700ce, 0x7e62285e, 0x00000000}},  //   _kreć, lgji, geop,
  { {0x80bf08b7, 0x070b006e, 0xa0240044, 0x00000000}},  //   ্তব্, _संभव_, _পারব_,
  { {0x64470065, 0x78ba0059, 0x7c2a01e5, 0x00000000}},  //   ngji, jitv, gafr,
  { {0xd49800b6, 0x78ba01d9, 0xdb210279, 0x00000000}},  //   רכות_, ditv, _ötür,
  { {0x3eb900f8, 0x6d420058, 0x7e620146, 0x00000000}},  //   _öst_, buoa, ceop,
  { {0x442a130b, 0x6d5b011c, 0x3a2600e5, 0x00000000}},  //   yab_, _upua, _deop_,
  { {0xc6250055, 0xddc901f3, 0x661d01a2, 0x00000000}},  //   _ভাষা_, _mneż, ebsk,
  { {0x442a285f, 0x2902000c, 0x2bb80061, 0x00000000}},  //   vab_, íkar_, ेपणा,
  { {0xfd4c00ad, 0x442a020c, 0x64400006, 0x00000000}},  //   _nhiề, wab_, ėmim,
  { {0x442a0004, 0x5e560049, 0x78ba0059, 0x00000000}},  //   tab_, סישע_, bitv,
  { {0xb4c00183, 0x49b806b4, 0x741603e6, 0x00000000}},  //   ंचे_, _حامد_, شورا,
  { {0x66e60478, 0x6b7c00e5, 0x00000000, 0x00000000}},  //   _кока, _găgă,   ,
  { {0x442a2860, 0xfd4c001d, 0x9f580051, 0x00000000}},  //   sab_, _chiề, _ngrá_,

  { {0x442a0263, 0x6604169b, 0x799b0093, 0x00000000}},  // [7000] pab_, _igik, nyuw,
  { {0x7e620007, 0x442a0145, 0x130a007c, 0x00000000}},  //   weop, qab_, _иной_,
  { {0x09e202f4, 0xa7fc01f6, 0x7e6201a3, 0x00000000}},  //   _पर्य, ldır, teop,
  { {0x2eed00f4, 0x75242046, 0x17560049, 0x00000000}},  //   _chef_, _kwiz, יסער_,
  { {0xa7fc038c, 0x7e6207c5, 0x7c2a01e5, 0x00000000}},  //   ndır, reop, tafr,
  { {0x7524047b, 0x00000000, 0x00000000, 0x00000000}},  //   _mwiz,   ,   ,
  { {0xf7670014, 0x78ba01d9, 0x7e6206fa, 0x00000000}},  //   _با_, vitv, peop,
  { {0xf1bf002a, 0x660412eb, 0x7c2a2861, 0x00000000}},  //   _meán_, _ngik, safr,
  { {0x4c86007c, 0x752401aa, 0x78ba2862, 0x00000000}},  //   _клав, _nwiz, titv,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdce901cd, 0x78ba01d9, 0x6f000173, 0x00000000}},  //   _sreć, ritv, _kimc,
  { {0x6aa902e7, 0xdce90107, 0x7ced1b0f, 0x00000000}},  //   chef, _preć, túrg,
  { {0x2a640059, 0x09e300ec, 0x7c28007f, 0x00000000}},  //   memb_, _доцн, _kedr,
  { {0x66c8011f, 0x3944001e, 0x7ced1343, 0x00000000}},  //   lıkl, mums_, rúrg,
  { {0x6447008d, 0x7c280016, 0x53340242, 0x00000000}},  //   rgji, _medr, жест,
  { {0xdce90119, 0x26c90020, 0x66040093, 0x00000000}},  //   _treć, _ujao_, _ggik,
  { {0x26d908d3, 0xe4e703e8, 0x7c280016, 0x00000000}},  // [7010] moso_, _вінн, _oedr,
  { {0x7c280089, 0x26d90a15, 0x656d0058, 0x00000000}},  //   _nedr, loso_, _isah,
  { {0xfd4c0011, 0xddcb0010, 0x00000000, 0x00000000}},  //   _thiề, vegő,   ,
  { {0x3944001e, 0x26d90cdf, 0x63ad001e, 0x00000000}},  //   kums_, noso_, ģinā,
  { {0x7c2802ae, 0x3944001e, 0xee3801ff, 0x00000000}},  //   _bedr, jums_, рні_,
  { {0x39440089, 0x229c000c, 0x6f070059, 0x00000000}},  //   dums_, _ríki_, _tujc,
  { {0x6aa91ef7, 0xe4580049, 0x8f3400e3, 0x00000000}},  //   thef, ייגט_, _мерц,
  { {0x26d91cd9, 0x6f0000d4, 0x22491e3a, 0x00000000}},  //   joso_, _gimc, ngak_,
  { {0x3944001e, 0x7c280016, 0x26d90b33, 0x00000000}},  //   gums_, _fedr, doso_,
  { {0x7c280fe2, 0x6aa9164d, 0x75240045, 0x00000000}},  //   _gedr, shef, _rwiz,
  { {0x656d0058, 0x7d090211, 0x26d90197, 0x00000000}},  //   _asah, _hues, foso_,
  { {0x7d0105b7, 0xa7fc005f, 0xba740025, 0x00000000}},  //   _hils, tdır, _وانت,
  { {0x6e290209, 0xceb200a0, 0xf1bf0051, 0x00000000}},  //   _meeb, ליט_, _seán_,
  { {0x7d090211, 0xa50701ee, 0xb5fb102e, 0x00000000}},  //   _mues, сера_, rdáp,
  { {0x26d91ebf, 0x7d010048, 0x03a3007c, 0x00000000}},  //   boso_, _mils, пиро,
  { {0xa206008b, 0x7d0900f4, 0x26d92863, 0x00000000}},  //   спад, _oues, coso_,
  { {0x7d090219, 0x64412864, 0xb5fb0051, 0x00000000}},  // [7020] _nues, ólic, neál,
  { {0x7d010039, 0x00000000, 0x00000000, 0x00000000}},  //   _nils,   ,   ,
  { {0x6e29006c, 0x00000000, 0x00000000, 0x00000000}},  //   _beeb,   ,   ,
  { {0xdfcf0380, 0x52860054, 0xa3d50204, 0x00000000}},  //   رين_, _الحك, िअर_,
  { {0x7c2802d5, 0x7d090211, 0x7d012865, 0x00000000}},  //   _pedr, _cues, _bils,
  { {0xd47a0049, 0x39440089, 0xd5ed0082, 0x00000000}},  //   ראַל, vums_, _hoạ,
  { {0x7c282866, 0x7d010089, 0x26d908e3, 0x00000000}},  //   _vedr, _dils, yoso_,
  { {0x3944001e, 0x7d09008e, 0x8f9b009b, 0x00000000}},  //   tums_, _fues, _גילי,
  { {0x7d090038, 0x7d01216d, 0xd00f00a1, 0x00000000}},  //   _gues, _fils, _آلہ_,
  { {0xdb030047, 0x6e29016e, 0x7d0100c4, 0x00000000}},  //   szná, _zeeb, _gils,
  { {0x26d908d3, 0x39440089, 0xa7fc006b, 0x00000000}},  //   toso_, sums_, tdıq,
  { {0xaae60380, 0xcf93009b, 0x368b00e2, 0x00000000}},  //   _اسطو, לטת_, усон_,
  { {0x26d908d3, 0xe9ff0011, 0xb5fb0051, 0x00000000}},  //   roso_, _trạm_, ceál,
  { {0x26d90325, 0x00000000, 0x00000000, 0x00000000}},  //   soso_,   ,   ,
  { {0x26d9059a, 0x443f047f, 0x81b60044, 0x00000000}},  //   poso_, ğu_, _চুল_,
  { {0x764d004a, 0x443f2867, 0x00000000, 0x00000000}},  //   _ucay, şu_,   ,
  { {0x656d020c, 0x6e290471, 0x2249002d, 0x00000000}},  // [7030] _usah, _reeb, rgak_,
  { {0x7d0900f6, 0x6e2903e1, 0x51f80147, 0x00000000}},  //   _rues, _seeb, сную_,
  { {0xf709001d, 0x7d0906be, 0xde1900f3, 0x00000000}},  //   _lần_, _sues, لقات_,
  { {0x7d090211, 0x5187105c, 0x7d01013f, 0x00000000}},  //   _pues, _луга, _sils,
  { {0x7d09051b, 0x7d01001e, 0x6e290004, 0x00000000}},  //   _ques, _pils, _veeb,
  { {0xcc89007a, 0x7d090211, 0xa6cf0044, 0x00000000}},  //   شنبه_, _vues, রতিট,
  { {0x7d0100f8, 0x6e290d78, 0x00000000, 0x00000000}},  //   _vils, _teeb,   ,
  { {0xdce90521, 0xb5fb0051, 0x27170082, 0x00000000}},  //   _iseč, teál, _hăng_,
  { {0xf709001d, 0x7d012868, 0x7d09006c, 0x00000000}},  //   _cần_, _tils, _uues,
  { {0xf7090011, 0xd90c0014, 0xa3e90061, 0x00000000}},  //   _dần_, دیو_, _बरं_,
  { {0xe9a80167, 0x27170011, 0xb5fb0051, 0x00000000}},  //   لدین_, _măng_, seál,
  { {0x27170011, 0x1959007e, 0x00000000, 0x00000000}},  //   _lăng_, _вады_,   ,
  { {0xf709001d, 0xf8bf009d, 0x66dd0010, 0x00000000}},  //   _gần_, éés_, tékr,
  { {0x2717001d, 0x229c000c, 0xc7a5017f, 0x00000000}},  //   _năng_, _líkt_, _милк,
  { {0x232a0793, 0x6fd9013d, 0x00000000, 0x00000000}},  //   роби_, _बुलं,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2717001d, 0x00000000, 0x00000000, 0x00000000}},  // [7040] _băng_,   ,   ,
  { {0x27170011, 0x2056007e, 0x00000000, 0x00000000}},  //   _căng_, ўтар,   ,
  { {0xb4d602d2, 0x00000000, 0x00000000, 0x00000000}},  //   िकी_,   ,   ,
  { {0x7ce40129, 0xa75a0049, 0x443a0471, 0x00000000}},  //   mòri, ידער, _hdp_,
  { {0x82370014, 0x7ce400d4, 0x00000000, 0x00000000}},  //   _برپا, lòri,   ,
  { {0xccb701fb, 0x443a012d, 0x27170082, 0x00000000}},  //   огії_, _jdp_, _găng_,
  { {0x9e660123, 0xf7090082, 0x00000000, 0x00000000}},  //   _وارن, _sần_,   ,
  { {0x5a3400e3, 0x443a003b, 0x00000000, 0x00000000}},  //   чнит, _ldp_,   ,
  { {0x80bf0055, 0x6e220b9a, 0xc866004c, 0x00000000}},  //   ্তর্, mbob, отни,
  { {0x443a0061, 0x27170011, 0xa3bb0067, 0x00000000}},  //   _ndp_, _xăng_, _आइल_,
  { {0x62861414, 0x6d420133, 0xa714007e, 0x00000000}},  //   _onko, lroa, ямні,
  { {0x443a006b, 0xf7090011, 0x7ce400f6, 0x00000000}},  //   _adp_, _tần_, dòri,
  { {0x443a014a, 0x6d4200e7, 0x00000000, 0x00000000}},  //   _bdp_, nroa,   ,
  { {0x62861384, 0xdc080089, 0x7ce400d4, 0x00000000}},  //   _anko, rēķi, fòri,
  { {0x27172869, 0x443a0342, 0x7ce400f6, 0x00000000}},  //   _răng_, _ddp_, gòri,
  { {0x645e0061, 0x6d420006, 0xc1050025, 0x00000000}},  //   _ebpi, kroa, كوري,
  { {0x35b4005e, 0x20070825, 0x443a01a2, 0x00000000}},  // [7050] _обър, žnim_, _fdp_,
  { {0x628601aa, 0x6d420032, 0x7ced000c, 0x00000000}},  //   _enko, droa, kúra,
  { {0x4431286a, 0xdce20521, 0xe9ff0011, 0x00000000}},  //   maz_, jvođ, _trầm_,
  { {0x2ee6003b, 0x4431286b, 0x7c3a0009, 0x00000000}},  //   glof_, laz_, _adtr,
  { {0x2717001d, 0x6d420035, 0x6448286c, 0x00000000}},  //   _tăng_, groa, ódig,
  { {0x4431002d, 0x251c00a3, 0x98aa013e, 0x00000000}},  //   naz_, סווא, čbě_,
  { {0x7ced286d, 0xeb9919cc, 0x00000000, 0x00000000}},  //   gúra, сий_,   ,
  { {0x4431014a, 0x7f840014, 0xdcfb002b, 0x00000000}},  //   haz_, _تلفن, _kruċ,
  { {0x44310428, 0x8d7702fd, 0x6d420133, 0x00000000}},  //   kaz_, _بازا, croa,
  { {0x78a9012b, 0x29030039, 0x50db0061, 0x00000000}},  //   ског_, öja_, भविष,
  { {0xd90f026c, 0xbb480054, 0x66e600ed, 0x00000000}},  //   ریں_, _ولكن_, зона,
  { {0x6441000c, 0x443a286e, 0x00000000, 0x00000000}},  //   ólin, _sdp_,   ,
  { {0x443a286f, 0x44310181, 0x66dd0010, 0x00000000}},  //   _pdp_, faz_, rékp,
  { {0x4431002d, 0x7ce404bd, 0xf7090011, 0x00000000}},  //   gaz_, tòri, _hầm_,
  { {0x63830069, 0x07a502dc, 0x00000000, 0x00000000}},  //   нгра, _хайн,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb146008b, 0xe29700e3, 0x26c2117b, 0x00000000}},  // [7060] янал, чат_, miko_,
  { {0xf7090011, 0x6e3b2870, 0xb0630027, 0x00000000}},  //   _lầm_, _adub, jväč,
  { {0x9e660069, 0x7d1b00e7, 0x00000000, 0x00000000}},  //   звед, _atus,   ,
  { {0x645c0039, 0x26c2022b, 0x6d42002d, 0x00000000}},  //   lfri, niko_, troa,
  { {0x6da3026b, 0x2ee62871, 0x6e220537, 0x00000000}},  //   ница, rlof_, rbob,
  { {0x6d42022b, 0x26c2002d, 0x6e3b002d, 0x00000000}},  //   rroa, hiko_, _edub,
  { {0x26c2022b, 0x7d1b021e, 0xf7090082, 0x00000000}},  //   kiko_, _etus, _bầm_,
  { {0x60de0038, 0xf7090011, 0x6d4200ab, 0x00000000}},  //   lopm, _cầm_, proa,
  { {0xd90d01ef, 0x26c2022b, 0x4431014a, 0x00000000}},  //   لین_, diko_, yaz_,
  { {0x7c3a0030, 0xb19b0049, 0xe29f000c, 0x00000000}},  //   _udtr, צייכ, _miða_,
  { {0xf98f00a6, 0x645c1506, 0x26c2002d, 0x00000000}},  //   نبی_, dfri, fiko_,
  { {0x76ab007c, 0xb5fb0051, 0x26c2002d, 0x00000000}},  //   стов_, leái, giko_,
  { {0x645c16df, 0x20180263, 0x44312872, 0x00000000}},  //   ffri, _ofri_, taz_,
  { {0x645c0010, 0xb5fb0051, 0x2418007c, 0x00000000}},  //   gfri, neái, зоры_,
  { {0x44312873, 0x200707a0, 0x26c20032, 0x00000000}},  //   raz_, žnik_, biko_,
  { {0x9294008b, 0x66e402a8, 0x645c0209, 0x00000000}},  //   насц, _поја, afri,
  { {0x4431029d, 0x25a22874, 0x00000000, 0x00000000}},  // [7070] paz_, cykl_,   ,
  { {0xb21b0030, 0x00000000, 0x00000000, 0x00000000}},  //   _knæk,   ,   ,
  { {0xb5fb0051, 0x7d1b0943, 0x657d00f6, 0x00000000}},  //   deái, _stus, lvsh,
  { {0x3ea62875, 0x7ae20943, 0x201801e5, 0x00000000}},  //   gkot_, _nkot, _efri_,
  { {0xcbfe0044, 0xf7090082, 0x00000000, 0x00000000}},  //   ুরোধ_, _rầm_,   ,
  { {0x26c212e5, 0x7ae20173, 0xf7090082, 0x00000000}},  //   ziko_, _akot, _sầm_,
  { {0xfc300025, 0x61e601a2, 0x2fc500f8, 0x00000000}},  //   احه_, _zykl, _älg_,
  { {0x6e3b04eb, 0x00000000, 0x00000000, 0x00000000}},  //   _udub,   ,   ,
  { {0x645c0016, 0x6e24027b, 0x3ebf2876, 0x00000000}},  //   yfri, ñibe, _imut_,
  { {0xb4bc03d7, 0xb5fb002a, 0x7ae20740, 0x00000000}},  //   _आगे_, ceái, _ekot,
  { {0x26c221d4, 0x6d4b006a, 0xf7090011, 0x00000000}},  //   tiko_, luga, _tầm_,
  { {0x7e6b0022, 0x3ebf0066, 0x291f00b0, 0x00000000}},  //   negp, _jmut_, ppua_,
  { {0x26c2022b, 0x7afb03b6, 0x6d59002b, 0x00000000}},  //   riko_, mmut, ntwa,
  { {0x26c2022b, 0x7ae90e69, 0xa5bb0d95, 0x00000000}},  //   siko_, llet, mból,
  { {0x6d4b2877, 0x290f000c, 0x7ae921ca, 0x00000000}},  //   huga, _huga_, olet,
  { {0x645c0030, 0x29072878, 0x7ae9165e, 0x00000000}},  //   sfri, _hina_, nlet,
  { {0x290f0149, 0x290706d0, 0xd24f026c, 0x00000000}},  // [7080] _juga_, _kina_, شنل_,
  { {0x2907000b, 0x25fe02fb, 0x290f002d, 0x00000000}},  //   _jina_, रेणी_, _muga_,
  { {0x290707dc, 0x212b0016, 0xe29a01ee, 0x00000000}},  //   _mina_, _ewch_, _дан_,
  { {0x29071992, 0x6d4b0020, 0xdcfb016c, 0x00000000}},  //   _lina_, fuga, _druč,
  { {0xb5fb0051, 0x6d4b04be, 0x3ea60778, 0x00000000}},  //   teái, guga, rkot_,
  { {0x29072879, 0x7ae9088a, 0x00000000, 0x00000000}},  //   _nina_, elet,   ,
  { {0x7ae9001a, 0xb5fb002a, 0x3ead0065, 0x00000000}},  //   flet, reái, _flet_,
  { {0x2907094d, 0xb5fb002a, 0x7ae900f4, 0x00000000}},  //   _aina_, seái, glet,
  { {0x286a01f9, 0x81e00055, 0xb5fb0051, 0x00000000}},  //   орно_, ধের_, peái,
  { {0x2907020c, 0x290f016e, 0x7ae9065d, 0x00000000}},  //   _cina_, _duga_, alet,
  { {0x29070073, 0x291d010f, 0xa7fc014a, 0x00000000}},  //   _dina_, _etwa_, ldız,
  { {0x2907287a, 0x00000000, 0x00000000, 0x00000000}},  //   _eina_,   ,   ,
  { {0x29070039, 0xe4e701fb, 0x290f1e8f, 0x00000000}},  //   _fina_, дівн, _guga_,
  { {0x67d401be, 0x7ae00010, 0xe3b3009e, 0x00000000}},  //   _полу, lomt, نرز_,
  { {0x7d080aa4, 0x6d4b0dab, 0x386c005b, 0x00000000}},  //   _mids, zuga, medr_,
  { {0x29071085, 0x7d0800b9, 0xf1a702ea, 0x00000000}},  //   _zina_, _lids, мрзн,
  { {0x6448287b, 0x50f501e0, 0x6d4b1052, 0x00000000}},  // [7090] ódic, езат, xuga,
  { {0x3ead0030, 0x6d4b0061, 0x3ebf0190, 0x00000000}},  //   _slet_, vuga, _smut_,
  { {0x7ae90016, 0x3ead0190, 0x00000000, 0x00000000}},  //   ylet, _plet_,   ,
  { {0x6d59002b, 0x752d144d, 0x6d4b0169, 0x00000000}},  //   ttwa, _kwaz, tuga,
  { {0x212b018e, 0x7ae9014a, 0x7d0800eb, 0x00000000}},  //   _uwch_, vlet, _bids,
  { {0x6d591515, 0x6d4b002d, 0xdce9037e, 0x00000000}},  //   rtwa, ruga, _pređ,
  { {0x629d008d, 0x7ae91553, 0x6d4b006a, 0x00000000}},  //   _koso, tlet, suga,
  { {0x29070073, 0x79820038, 0xdce90521, 0x00000000}},  //   _sina_, _brow, _vređ,
  { {0x2bdf02fb, 0x629d0010, 0x2907148e, 0x00000000}},  //   _पुरा, _moso, _pina_,
  { {0x7ae90056, 0x660d01a3, 0x629d0036, 0x00000000}},  //   slet, _agak, _loso,
  { {0xdce90091, 0xf0920104, 0x2907287c, 0x00000000}},  //   _uređ, אני_, _vina_,
  { {0x629d287d, 0x79820675, 0x67210091, 0x00000000}},  //   _noso, _frow, rplj,
  { {0xd756026c, 0x798200ab, 0x27e70ca4, 0x00000000}},  //   ولیت_, _grow, _wynn_,
  { {0x6f090089, 0x6aa9068f, 0xb4ca0061, 0x00000000}},  //   _liec, lkef, लचे_,
  { {0x7c3e02d5, 0x629d287e, 0x394d00ab, 0x00000000}},  //   ópri, _boso, lues_,
  { {0x6f090620, 0xe297012b, 0x629d0035, 0x00000000}},  //   _niec, нас_, _coso,
  { {0x2167019d, 0x394d287f, 0x09e10044, 0x00000000}},  // [70a0] нити_, nues_, মেরা,
  { {0x9c7c01ca, 0x68e10016, 0x23db013d, 0x00000000}},  //   _akčn, nold, _मुकद,
  { {0x545700b6, 0x752d01aa, 0x6aa9043e, 0x00000000}},  //   _אביב_, _zwaz, kkef,
  { {0x68e102cc, 0x7d080018, 0x629d018e, 0x00000000}},  //   hold, _sids, _goso,
  { {0x6f091ff6, 0x394d0023, 0x7d080022, 0x00000000}},  //   _diec, jues_, _pids,
  { {0x653b0049, 0x394d2880, 0x68e12881, 0x00000000}},  //   לענד, dues_, jold,
  { {0x6f09000d, 0x7d080030, 0x629d1fb8, 0x00000000}},  //   _fiec, _vids, _yoso,
  { {0x79820046, 0x6ee3006c, 0xafe32882, 0x00000000}},  //   _prow, sõbr, _сосл,
  { {0x68e1018e, 0xf99200b8, 0x7d08080a, 0x00000000}},  //   fold, ابع_, _tids,
  { {0x68e10047, 0x2d84008e, 0x6ef10190, 0x00000000}},  //   gold, _irme_, nåbn,
  { {0x752d01d6, 0x09e10044, 0x7ae000e7, 0x00000000}},  //   _swaz, মেলা, pomt,
  { {0x79820016, 0x752d01aa, 0x29110051, 0x00000000}},  //   _trow, _pwaz, únaí_,
  { {0x68e10030, 0x629d00f8, 0x1874007e, 0x00000000}},  //   bold, _roso, _агля,
  { {0x629d023a, 0x752d01aa, 0x68e10026, 0x00000000}},  //   _soso, _vwaz, cold,
  { {0x629d0059, 0x60c5010e, 0xe28700e2, 0x00000000}},  //   _poso, vihm, нѓан,
  { {0x752d01aa, 0x2d840197, 0x660d0045, 0x00000000}},  //   _twaz, _orme_, _ugak,
  { {0x629d0211, 0x752d0e74, 0x673a0abc, 0x00000000}},  // [70b0] _voso, _uwaz, lstj,
  { {0x6f090046, 0x629d01c3, 0x00000000, 0x00000000}},  //   _siec, _woso,   ,
  { {0x2d840007, 0x6f09230d, 0xdfd10025, 0x00000000}},  //   _arme_, _piec, جيا_,
  { {0x6ee70025, 0x52a70025, 0x94000061, 0x00000000}},  //   رسال, _أصدق, ोखरच_,
  { {0x6f092883, 0x2a6d006c, 0x394d0023, 0x00000000}},  //   _viec, veeb_, xues_,
  { {0x6f090046, 0xe104007e, 0x394d00f4, 0x00000000}},  //   _wiec, _бясп, vues_,
  { {0x4433008e, 0x68e100b5, 0xdea10014, 0x00000000}},  //   _mex_, vold, _پیشی,
  { {0x4433002b, 0x394d0065, 0x68e100bb, 0x00000000}},  //   _lex_, tues_, wold,
  { {0x6aa9009f, 0xe9d90152, 0xe8f9007c, 0x00000000}},  //   rkef, ьки_, мли_,
  { {0x7e7b001f, 0x394d2884, 0x6c740070, 0x00000000}},  //   _haup, rues_, _مطمئ,
  { {0x7e7b0836, 0x394d2885, 0x68e1002d, 0x00000000}},  //   _kaup, sues_, rold,
  { {0x68e10129, 0x44332886, 0x7cf60035, 0x00000000}},  //   sold, _aex_, râre,
  { {0x394d053e, 0x7e7b0390, 0x68e12887, 0x00000000}},  //   ques_, _maup, pold,
  { {0x7e7b006c, 0x443300f6, 0x98a2003b, 0x00000000}},  //   _laup, _cex_, _више,
  { {0x44330035, 0x6ef80224, 0xa50702b8, 0x00000000}},  //   _dex_, líbe, тера_,
  { {0xc24302a8, 0x1b130055, 0x7e7b0058, 0x00000000}},  //   инск, _সবাই_, _naup,
  { {0x25fe0061, 0x26d9004a, 0x00000000, 0x00000000}},  // [70c0] रेशी_, éroe_,   ,
  { {0xf5370049, 0x44330068, 0x00000000, 0x00000000}},  //   _שניי_, _gex_,   ,
  { {0x63a70046, 0xe0d501fb, 0x7e7b01a2, 0x00000000}},  //   cyjn, ують, _baup,
  { {0x44381355, 0xb21b1f7d, 0x7e7b004a, 0x00000000}},  //   lar_, _snæv, _caup,
  { {0xdce00089, 0x7e7b009d, 0xbea301fc, 0x00000000}},  //   _apmā, _daup, јачк,
  { {0x55bb009b, 0x442a0068, 0x13c60044, 0x00000000}},  //   ומנו, nbb_, _শুয়,
  { {0x6d5b00ab, 0xf70a0011, 0x44382888, 0x00000000}},  //   _equa, _hầu_, iar_,
  { {0x44382889, 0x3a740256, 0xbea3004d, 0x00000000}},  //   har_, улир, _каск,
  { {0x44380a42, 0xbea30893, 0xdc5402fd, 0x00000000}},  //   kar_, _татк, _مراک,
  { {0x44380127, 0x7e7b0059, 0xf70a0011, 0x00000000}},  //   jar_, _zaup, _mầu_,
  { {0xd7f70454, 0xf70a0011, 0x69d90066, 0x00000000}},  //   кую_, _lầu_, _exwe,
  { {0x44330472, 0x7c3802d5, 0x673a009f, 0x00000000}},  //   _sex_, lavr, rstj,
  { {0x443820e9, 0x673a009f, 0x44330253, 0x00000000}},  //   far_, sstj, _pex_,
  { {0x44380359, 0x7d1d0129, 0x25ad002b, 0x00000000}},  //   gar_, _ésse, ġel_,
  { {0x25ad018b, 0xd6db00ed, 0x443300d9, 0x00000000}},  //   šel_, _оти_, _vex_,
  { {0xf70a0011, 0x63a70036, 0xd8380466, 0x00000000}},  //   _bầu_, ryjn, lač_,
  { {0xf70a001d, 0x44330039, 0x63a70036, 0x00000000}},  // [70d0] _cầu_, _tex_, syjn,
  { {0x2edb02f4, 0xf70a001d, 0xdce9016c, 0x00000000}},  //   यक्त, _dầu_, _iseć,
  { {0xf41200b6, 0x7e7b0f91, 0x2007021e, 0x00000000}},  //   _לפי_, _paup, äni_,
  { {0x4ea70265, 0xa2950451, 0xd838040d, 0x00000000}},  //   ърза, _самі, hač_,
  { {0x7ced004a, 0x7e7b288a, 0x00000000, 0x00000000}},  //   lúri, _vaup,   ,
  { {0xd838016e, 0x64550232, 0x387c0288, 0x00000000}},  //   jač_, ngzi, _navr_,
  { {0x7e7b0d90, 0x7ced00f6, 0xd838047c, 0x00000000}},  //   _taup, núri, dač_,
  { {0xdce9021d, 0xead10044, 0x00000000, 0x00000000}},  //   _oseć, াত্ম,   ,
  { {0x4438288b, 0x1017013d, 0x7c38012d, 0x00000000}},  //   yar_, _तलाश_, bavr,
  { {0x44380ca7, 0x6ef80211, 0xd8380c0a, 0x00000000}},  //   xar_, ríbe, gač_,
  { {0x6ef8049a, 0xa6ca03dc, 0x38a900c4, 0x00000000}},  //   síbe, елна_, _júri_,
  { {0x4438033b, 0xaca30011, 0xba390049, 0x00000000}},  //   war_, _ruộn, _װײַט,
  { {0x44380f68, 0xd94500c0, 0xe8ee007e, 0x00000000}},  //   tar_, _сели, _гл_,
  { {0x628f0198, 0x4438288c, 0x2a7f288d, 0x00000000}},  //   _anco, uar_, ldub_,
  { {0x395f05a0, 0x6d4b010f, 0xf70a0011, 0x00000000}},  //   ltus_, hrga, _sầu_,
  { {0x44380149, 0x670c0754, 0x2a7f006c, 0x00000000}},  //   sar_, _सूचक_, ndub_,
  { {0x4438288e, 0x395f0394, 0x8186007e, 0x00000000}},  // [70e0] par_, ntus_, ыгаж,
  { {0x628f288f, 0x395f00b0, 0x44382890, 0x00000000}},  //   _enco, itus_, qar_,
  { {0x44442891, 0x03a6025f, 0x395f006c, 0x00000000}},  //   _id_, _сино, htus_,
  { {0xd8380209, 0x395f0d90, 0xf70a0082, 0x00000000}},  //   zač_, ktus_, _tầu_,
  { {0xdca6003b, 0x44441d2a, 0x7c380066, 0x00000000}},  //   лади, _kd_, tavr,
  { {0x4444033b, 0xfce30088, 0x2731050f, 0x00000000}},  //   _jd_, бочо, kšn_,
  { {0xd838040d, 0x2a7d0016, 0xe0d700ed, 0x00000000}},  //   vač_, _bawb_, _свр_,
  { {0x7644000b, 0xdee600a8, 0x7c38016e, 0x00000000}},  //   _ndiy, _соби, savr,
  { {0x44440119, 0xd83804c8, 0x5eca0044, 0x00000000}},  //   _od_, tač_, িকদে,
  { {0x2ee606b2, 0x444400ab, 0x2bdf007d, 0x00000000}},  //   loof_, _nd_, _पुका,
  { {0x2a660017, 0x75242892, 0xd838016e, 0x00000000}},  //   _бълг, _atiz, rač_,
  { {0x44440198, 0x6f02008e, 0xd83801ed, 0x00000000}},  //   _ad_, nmoc, sač_,
  { {0x444400f4, 0x64550009, 0x00000000, 0x00000000}},  //   _bd_, tgzi,   ,
  { {0x44442893, 0x6aa2049b, 0x7644011f, 0x00000000}},  //   _cd_, _hoof, _ediy,
  { {0x4444001c, 0xb865007a, 0x3267105c, 0x00000000}},  //   _dd_, _خانو, лтав,
  { {0x44440198, 0xb6c9026c, 0x6e24004a, 0x00000000}},  //   _ed_, _جاتے_, ñibl,
  { {0x26cb0a15, 0x44440b40, 0x6f02016c, 0x00000000}},  // [70f0] mico_, _fd_, dmoc,
  { {0x26cb0198, 0x44440011, 0x7ced0129, 0x00000000}},  //   lico_, _gd_, púri,
  { {0x644500e7, 0x3f872894, 0x6d4000f8, 0x00000000}},  //   _idhi, ínu_, _avma,
  { {0x26cb0c2e, 0x290e000c, 0x395f0006, 0x00000000}},  //   nico_, _lifa_, ytus_,
  { {0x4444005b, 0x00000000, 0x00000000, 0x00000000}},  //   _yd_,   ,   ,
  { {0x44440211, 0x2a7d21b3, 0x212904cb, 0x00000000}},  //   _xd_, _sawb_, mpah_,
  { {0xeb99004c, 0x2a7d018e, 0x4421012d, 0x00000000}},  //   тий_, _pawb_, _mfh_,
  { {0xf53f0073, 0x26cb0059, 0x395f006c, 0x00000000}},  //   kså_, jico_, ttus_,
  { {0x26cb0851, 0x81e70055, 0x395f0275, 0x00000000}},  //   dico_, যের_, utus_,
  { {0x395f0a0e, 0x229c13c7, 0xe7650088, 0x00000000}},  //   rtus_, _díky_, авоп,
  { {0x395f0515, 0x26cb2895, 0x444405ac, 0x00000000}},  //   stus_, fico_, _rd_,
  { {0x4444023a, 0x26cb2896, 0x6445107e, 0x00000000}},  //   _sd_, gico_, _adhi,
  { {0x290e17ab, 0x6ef806c2, 0xe9a82638, 0x00000000}},  //   _fifa_, níba, _مدون_,
  { {0x7ae40059, 0x6aa200ea, 0x394d0065, 0x00000000}},  //   čite, _zoof, mres_,
  { {0x44442770, 0x394d023a, 0x26cb00ca, 0x00000000}},  //   _vd_, lres_, bico_,
  { {0xb226012b, 0x394d0181, 0x64450022, 0x00000000}},  //   рмал, ores_, _edhi,
  { {0x44442897, 0x394d027b, 0x78a30292, 0x00000000}},  // [7100] _td_, nres_, _konv,
  { {0x394d028c, 0x44440018, 0x3d0f013d, 0x00000000}},  //   ires_, _ud_, ादों_,
  { {0xee3a2898, 0x394d010f, 0x6fd5007e, 0x00000000}},  //   вне_, hres_, біцц,
  { {0x33db00b3, 0x394d0036, 0xeda6007c, 0x00000000}},  //   _יחיד, kres_, ишло,
  { {0x6aa20436, 0x2ee60436, 0x394d0190, 0x00000000}},  //   _roof, roof_, jres_,
  { {0x394d0376, 0x78a30b3d, 0x1d19008b, 0x00000000}},  //   dres_, _nonv, уюць_,
  { {0x394d0211, 0x9f5c021e, 0x00000000, 0x00000000}},  //   eres_, ävä_,   ,
  { {0x26cb0219, 0x394d2899, 0x996602be, 0x00000000}},  //   xico_, fres_, атол,
  { {0x394d0056, 0x26cb01d9, 0x9997005e, 0x00000000}},  //   gres_, vico_, икът_,
  { {0x78a30b25, 0x61eb01a2, 0x3ce700fa, 0x00000000}},  //   _conv, ügli, conv_,
  { {0x26cb0cdf, 0x3ea402ae, 0x78a30007, 0x00000000}},  //   tico_, _komt_, _donv,
  { {0x394d00f6, 0xf53f05b7, 0xbad5008b, 0x00000000}},  //   bres_, tså_, _лічы,
  { {0x26cb0198, 0x394d04bd, 0x78a30173, 0x00000000}},  //   rico_, cres_, _fonv,
  { {0x26cb0691, 0x14cb01ab, 0x00000000, 0x00000000}},  //   sico_, тыми_,   ,
  { {0x26cb02d5, 0xdce901d5, 0x68e800bb, 0x00000000}},  //   pico_, _speċ, modd,
  { {0x68e81506, 0x3f8d012d, 0x00000000, 0x00000000}},  //   lodd, _čeu_,   ,
  { {0x26c90119, 0x518700ed, 0x6fd9006e, 0x00000000}},  // [7110] _imao_, јуба, _मशहू,
  { {0x92d70055, 0x68e80016, 0x64450020, 0x00000000}},  //   িতে_, nodd, _udhi,
  { {0x61ef01aa, 0x00000000, 0x00000000, 0x00000000}},  //   _wycl,   ,   ,
  { {0x22950647, 0x394d0190, 0x68e80016, 0x00000000}},  //   _الحس, yres_, hodd,
  { {0x3cfe012d, 0x3ea401f3, 0x2481012d, 0x00000000}},  //   _bhtv_, _domt_, _kahm_,
  { {0x394d028c, 0x6ef8289a, 0xb4db0129, 0x00000000}},  //   vres_, ríba, cràt,
  { {0x7ced0051, 0x3f8a0521, 0x3f85009d, 0x00000000}},  //   dúrt, _grbu_, _élu_,
  { {0x394d289b, 0x99840006, 0x78a301d6, 0x00000000}},  //   tres_, jamų_, _sonv,
  { {0x394d289c, 0xdc080089, 0x78a300ca, 0x00000000}},  //   ures_, tēģi, _ponv,
  { {0x394d04bd, 0xdcf905d4, 0x2481010f, 0x00000000}},  //   rres_, _صفات_, _nahm_,
  { {0xb69b289d, 0xd70a007c, 0x00000000, 0x00000000}},  //   rmân, лное_,   ,
  { {0x394d289e, 0x2ca50b65, 0x69cb0061, 0x00000000}},  //   pres_, _hold_, _तेथी,
  { {0x81ac0055, 0x2ca508e0, 0x7ae9289f, 0x00000000}},  //   _কেন_, _kold_, moet,
  { {0x78ba07eb, 0x7ae90d49, 0x92d70044, 0x00000000}},  //   chtv, loet, িতো_,
  { {0x2ca524db, 0x00000000, 0x00000000, 0x00000000}},  //   _mold_,   ,   ,
  { {0x7ae9002d, 0xdb120010, 0x5724009e, 0x00000000}},  //   noet, ógép, _بروق,
  { {0x870600a1, 0x290500d9, 0x10160b6c, 0x00000000}},  // [7120] _پڑھے_, omla_, مباد,
  { {0x2ca50058, 0x7ae90288, 0x3ae10142, 0x00000000}},  //   _nold_, hoet, rópy_,
  { {0x443a0173, 0x7ae9002d, 0xd5e900a6, 0x00000000}},  //   _iep_, koet, _معین_,
  { {0x443a014a, 0x80b40061, 0x271700e5, 0x00000000}},  //   _hep_, _इतके, _căni_,
  { {0x2ca528a0, 0x443a01aa, 0x7ae928a1, 0x00000000}},  //   _bold_, _kep_, doet,
  { {0x443a28a2, 0x628413ee, 0x2ca500ab, 0x00000000}},  //   _jep_, ldio, _cold_,
  { {0x3ea41ab8, 0x7ae928a3, 0x798b00d9, 0x00000000}},  //   _tomt_, foet, _argw,
  { {0x62840c79, 0xd00f0025, 0x443a0059, 0x00000000}},  //   ndio, _ألف_, _lep_,
  { {0xe29b0049, 0x9c5a00a2, 0x2ca50133, 0x00000000}},  //   רשפר, _مجاز_, _fold_,
  { {0xad1b009b, 0xb17b0049, 0xa17b0049, 0x00000000}},  //   _עובר, נטיר, נטיט,
  { {0x68e8018e, 0x7ae90032, 0x15e1013d, 0x00000000}},  //   rodd, boet, _गुजर_,
  { {0xfaa30057, 0x6e22023a, 0x443a0ec1, 0x00000000}},  //   _нахо, ncob, _aep_,
  { {0x62840bc4, 0x6d42049a, 0x7c3a0093, 0x00000000}},  //   ddio, nsoa, _ketr,
  { {0x443a28a4, 0xdcfb0166, 0x7c3a183b, 0x00000000}},  //   _cep_, _vruć, _jetr,
  { {0x8726004b, 0x443a0011, 0x57260070, 0x00000000}},  //   _اعتم, _dep_, _ارتق,
  { {0x7c3a0325, 0x443a0288, 0xbb3b0049, 0x00000000}},  //   _letr, _eep_, טעלי,
  { {0xa1590451, 0xe3b000a1, 0x443a000a, 0x00000000}},  // [7130] разу_, ورہ_, _fep_,
  { {0x7c3a0c6e, 0x7ae9002d, 0x6284006c, 0x00000000}},  //   _netr, zoet, adio,
  { {0x83670025, 0xe29f01e5, 0x00000000, 0x00000000}},  //   _ادخل, _siðu_,   ,
  { {0x2ca500ab, 0x2bc301f5, 0xa159007e, 0x00000000}},  //   _sold_, _वेगा, _каму_,
  { {0xee380099, 0x5d67005e, 0xdca5013b, 0x00000000}},  //   сні_, стез, жали,
  { {0x61fd198c, 0x69c0016c, 0x443a02d4, 0x00000000}},  //   _izsl, dzme, _xep_,
  { {0x7ae9006c, 0x2ca50030, 0x01db0044, 0x00000000}},  //   toet, _vold_, _দরিদ,
  { {0xa925013b, 0x2ca50190, 0x6e220026, 0x00000000}},  //   одил, _wold_, ccob,
  { {0x7ae9002d, 0x2ca500ab, 0x7c3a0830, 0x00000000}},  //   roet, _told_, _fetr,
  { {0x7c3a1955, 0x7ae40119, 0x6abb0022, 0x00000000}},  //   _getr, čita, shuf,
  { {0x443a011f, 0xe739012b, 0x7ae90376, 0x00000000}},  //   _rep_, јем_, poet,
  { {0x7d1b21d7, 0x2d8d0173, 0xc878014a, 0x00000000}},  //   _kuus, _kree_, doğu_,
  { {0x443a0263, 0x6e3b28a5, 0xaca30011, 0x00000000}},  //   _pep_, _meub, _huốn,
  { {0x7d1b01c2, 0x69dc014a, 0x7d0601aa, 0x00000000}},  //   _muus, ğret, _èkst,
  { {0x25fe013d, 0xdce00006, 0xd2aa003b, 0x00000000}},  //   रेजी_, _esmė, акве_,
  { {0x443a0145, 0x6e3b0e42, 0x628426a7, 0x00000000}},  //   _wep_, _neub, udio,
  { {0x7d1b0007, 0x7d0100f8, 0xaca30082, 0x00000000}},  // [7140] _nuus, _ohls, _luốn,
  { {0x628401d6, 0x00000000, 0x00000000, 0x00000000}},  //   sdio,   ,   ,
  { {0x7c3a032c, 0x2d8d0207, 0xf42a00b0, 0x00000000}},  //   _retr, _aree_, _elää_,
  { {0x6ef800f6, 0x2d8d0253, 0x6d420032, 0x00000000}},  //   ríbo, _bree_, tsoa,
  { {0x7c3a0c12, 0x2d8d0211, 0x6e22023a, 0x00000000}},  //   _petr, _cree_, rcob,
  { {0x645c049b, 0x9b260057, 0x6d4228a6, 0x00000000}},  //   ngri, офил, rsoa,
  { {0x6d4202d5, 0x201811cc, 0xaca30082, 0x00000000}},  //   ssoa, _igri_, _cuốn,
  { {0x2d8d0866, 0xf413009b, 0x224001a3, 0x00000000}},  //   _free_, ופו_, naik_,
  { {0x69c00107, 0x7cff0007, 0x7d1b0bca, 0x00000000}},  //   uzme, wêre, _guus,
  { {0x6f1c0874, 0x22400640, 0x00000000, 0x00000000}},  //   _kurc, haik_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1c0211, 0xa96a01e0, 0x7d1b00e7, 0x00000000}},  //   _murc, _вида_, _yuus,
  { {0x291f28a7, 0x256428a8, 0x672d01ed, 0x00000000}},  //   cqua_, göl_, _čaje,
  { {0x645c0390, 0x38bb01c3, 0x00000000, 0x00000000}},  //   ggri, _pêre_,   ,
  { {0x938819ec, 0xaca3001d, 0x02a70f62, 0x00000000}},  //   оста_, _xuốn, орам,
  { {0x201828a9, 0x3f87000c, 0x7e6000ca, 0x00000000}},  //   _agri_, ænum_, _ncmp,
  { {0xa2c1006e, 0x00000000, 0x00000000, 0x00000000}},  // [7150] रोग्,   ,   ,
  { {0x6f1c014a, 0xddc9001a, 0x7d1b28aa, 0x00000000}},  //   _burc, _aceş, _ruus,
  { {0x2fc7001d, 0x6f1c0035, 0x7d1b01c2, 0x00000000}},  //   àng_, _curc, _suus,
  { {0x6f1c001f, 0xef18008b, 0x2d8d0173, 0x00000000}},  //   _durc, імі_, _pree_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1c28ab, 0x66d600ca, 0xc05801ff, 0x00000000}},  //   _furc, mške, _міс_,
  { {0x7ae40059, 0x394600fa, 0x394428ac, 0x00000000}},  //   čitn, _avos_, esms_,
  { {0x2d8d112b, 0x09cc0044, 0x63a80190, 0x00000000}},  //   _tree_, _লড়া, ødni,
  { {0x291f0003, 0x6f1c012d, 0x3a3f0093, 0x00000000}},  //   uqua_, _zurc, raup_,
  { {0x3946012d, 0x645c0203, 0x22400232, 0x00000000}},  //   _dvos_, xgri, zaik_,
  { {0xc5e9019b, 0xf771035b, 0x6d59011c, 0x00000000}},  //   _עד_, راد_, luwa,
  { {0x1959008b, 0xda7800a5, 0xe1ff00d4, 0x00000000}},  //   _гады_, _мяч_, _ozó_,
  { {0x6d5928ad, 0xeab00426, 0x645c28ae, 0x00000000}},  //   nuwa, _جعل_, tgri,
  { {0xa50a026b, 0x2eb80061, 0x256428af, 0x00000000}},  //   сега_, _आत्त, röl_,
  { {0x291d28b0, 0x645c0210, 0xe29a012b, 0x00000000}},  //   _huwa_, rgri, бав_,
  { {0x291d0be3, 0xa2cc001c, 0xdbd70b3e, 0x00000000}},  //   _kuwa_, _सगळ्, määr,
  { {0x6f1c06d2, 0x20180093, 0xa5bb0325, 0x00000000}},  // [7160] _surc, _pgri_, ncól,
  { {0xe45a008b, 0x6f1c00ab, 0x6d5928b1, 0x00000000}},  //   _ужо_, _purc, duwa,
  { {0x2721000c, 0xaca30082, 0x212b04d2, 0x00000000}},  //   _jón_, _luồn, _etch_,
  { {0x272128b2, 0x127a0025, 0x3a240026, 0x00000000}},  //   _món_, _احدث_, xcmp_,
  { {0x6d590058, 0x27210048, 0x62860288, 0x00000000}},  //   guwa, _lón_, _iako,
  { {0x6f1c0089, 0x628628b3, 0xdbd705e0, 0x00000000}},  //   _turc, _hako, käär,
  { {0x628601d9, 0x27210011, 0xe4570097, 0x00000000}},  //   _kako, _nón_, ליסט_,
  { {0x62860667, 0x3afa0065, 0x5fdb009b, 0x00000000}},  //   _jako, rëpo_, _החלק,
  { {0x6286000b, 0xaca30011, 0xdee30088, 0x00000000}},  //   _mako, _cuồn, _чоти,
  { {0x628628b4, 0x27211894, 0xfca9284e, 0x00000000}},  //   _lako, _bón_, _والو_,
  { {0xf093009b, 0x00000000, 0x00000000, 0x00000000}},  //   גנת_,   ,   ,
  { {0x62860209, 0x45d50264, 0xa9a600ed, 0x00000000}},  //   _nako, домс, _ниед,
  { {0xf1bf008e, 0x765d00d9, 0x8bee0044, 0x00000000}},  //   _afán_, rgsy, টেশন_,
  { {0x27210051, 0x00000000, 0x00000000, 0x00000000}},  //   _fón_,   ,   ,
  { {0x628628b5, 0xe1ff0344, 0xb4bd013d, 0x00000000}},  //   _bako, _szó_, _आती_,
  { {0x6d590697, 0xdddb12db, 0xcfc40044, 0x00000000}},  //   yuwa, _lauš, ্থান,
  { {0xa3cd006e, 0x6286071e, 0x62d40014, 0x00000000}},  // [7170] _शेर_, _dako, رآفر,
  { {0x55bc009b, 0x752d28b6, 0xdddb01ed, 0x00000000}},  //   _למחו, _itaz, _nauš,
  { {0x5f7928b7, 0x00000000, 0x00000000, 0x00000000}},  //   تماس_,   ,   ,
  { {0x7c2800b5, 0x6d5928b8, 0x6286002d, 0x00000000}},  //   _afdr, tuwa, _gako,
  { {0xdddb129d, 0x7e7900d9, 0x00000000, 0x00000000}},  //   _bauš, rewp,   ,
  { {0x62860305, 0xeb9901e0, 0x752d0020, 0x00000000}},  //   _zako, жик_, _mtaz,
  { {0x62860cd1, 0x6d5928b9, 0xdca228ba, 0x00000000}},  //   _yako, suwa, тащи,
  { {0xdbd701c2, 0x764d0020, 0xfbd0006d, 0x00000000}},  //   väär, _nday, دته_,
  { {0x272104bd, 0xcda90025, 0x752d0009, 0x00000000}},  //   _són_, _بهذه_, _ntaz,
  { {0xd90f026c, 0x764d014a, 0x57490437, 0x00000000}},  //   ھیں_, _aday, озом_,
  { {0x752d002d, 0x66e6013b, 0x9cea00a1, 0x00000000}},  //   _ataz, дона, _بولے_,
  { {0x291d011c, 0x6441000c, 0xaca30082, 0x00000000}},  //   _tuwa_, ðlin, _tuồn,
  { {0x628601ca, 0xe8ee0f93, 0x2b400091, 0x00000000}},  //   _rako, _ал_, ćice_,
  { {0xe73901e0, 0x6286182b, 0x917a0082, 0x00000000}},  //   _дек_, _sako, _lập_,
  { {0x628600b0, 0x752d0263, 0x31690032, 0x00000000}},  //   _pako, _etaz, etaz_,
  { {0xe29700ed, 0xdb240010, 0x6e2d008e, 0x00000000}},  //   мас_, éséh, ñabl,
  { {0x3f83006c, 0x3f910279, 0x61431deb, 0x00000000}},  // [7180] _asju_, _arzu_, кета,
  { {0x62860020, 0x6e291c88, 0x92ce0044, 0x00000000}},  //   _wako, _afeb, শকে_,
  { {0x7306025f, 0x6d49001a, 0x1eca00ed, 0x00000000}},  //   _опоз, _avea, олжи_,
  { {0x917a0082, 0x00000000, 0x00000000, 0x00000000}},  //   _cập_,   ,   ,
  { {0xdce20142, 0x249a0022, 0xdddb0471, 0x00000000}},  //   stoč, _knpm_, _pauš,
  { {0x3e4e0011, 0x160300e8, 0x00000000, 0x00000000}},  //   ột_, रेटर_,   ,
  { {0xeb9700ec, 0x6aab0190, 0x00000000, 0x00000000}},  //   диј_, _bogf,   ,
  { {0x3e86010a, 0xc4bb0164, 0x00000000, 0x00000000}},  //   _būtų_, _उत्ख,   ,
  { {0x6aab018e, 0xbc66012b, 0xb5fb00d6, 0x00000000}},  //   _dogf, _овак, nfát,
  { {0xd90d06c6, 0x47340764, 0xb4e80164, 0x00000000}},  //   مین_, ннос, यको_,
  { {0x20570049, 0x9057009b, 0xf98f0014, 0x00000000}},  //   וייל_, וסיף_, هبی_,
  { {0x5694004c, 0x3ea60093, 0x6ef800c4, 0x00000000}},  //   вают, njot_, fíbi,
  { {0x2d840224, 0x6ef80051, 0x00000000, 0x00000000}},  //   _jsme_, ríbh,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x36d502a8, 0x2cac018e, 0x7ae201ee, 0x00000000}},  //   _покр, _modd_, _kjot,
  { {0x764d13cd, 0x260c0061, 0x26c21ff5, 0x00000000}},  //   _uday, ठेही_, chko_,
  { {0x752d0047, 0xf70a0011, 0x00000000, 0x00000000}},  // [7190] _utaz, _nầy_,   ,
  { {0x316928bb, 0x4427014a, 0x7ae221fc, 0x00000000}},  //   rtaz_, _ün_, _ljot,
  { {0xdfd101b7, 0x3169002d, 0x6d4900d8, 0x00000000}},  //   ديا_, staz_, _svea,
  { {0x867c0049, 0xf70a0082, 0x00000000, 0x00000000}},  //   ַרוו, _bầy_,   ,
  { {0x2cac005b, 0xf70a0082, 0x41e70088, 0x00000000}},  //   _bodd_, _cầy_, _ціна,
  { {0xf70a0082, 0x00000000, 0x00000000, 0x00000000}},  //   _dầy_,   ,   ,
  { {0x2cac0ca4, 0x2d84007f, 0x917a0082, 0x00000000}},  //   _dodd_, _esme_, _tập_,
  { {0xff07007e, 0xc9a917a4, 0x6e94080c, 0x00000000}},  //   _цягн, звие_, _иису,
  { {0x2cac0016, 0xe9d902d3, 0xf70a0082, 0x00000000}},  //   _fodd_, яки_, _gầy_,
  { {0xa3c102fb, 0xa3e00164, 0x48cd0044, 0x00000000}},  //   ्छा_, _दखल_, রক্র,
  { {0x26c20d0a, 0x66d628bc, 0x00000000, 0x00000000}},  //   thko_, eška,   ,
  { {0xb4e80204, 0xddc0000a, 0x0bb60049, 0x00000000}},  //   यक्_, _bemň, _אלעם_,
  { {0x3ead0100, 0x249a0093, 0xef190066, 0x00000000}},  //   _moet_, _pnpm_, _miż_,
  { {0x7afb006c, 0x26c21264, 0xef190066, 0x00000000}},  //   llut, shko_, _liż_,
  { {0xd5b8001e, 0xe29a28bd, 0xa856009b, 0x00000000}},  //   ņā_, пав_, _טיסה_,
  { {0xef190046, 0x05660088, 0x7afb21b8, 0x00000000}},  //   _niż_, _звин, nlut,
  { {0x20560216, 0x4106004d, 0x3afa0049, 0x00000000}},  // [71a0] етер, езав, פּלע,
  { {0x7afb009f, 0x5f7600a1, 0x660401c3, 0x00000000}},  //   hlut, ٹائر, _izik,
  { {0x4438005b, 0x3ead28be, 0x7afb0066, 0x00000000}},  //   mbr_, _boet_, klut,
  { {0x9f580065, 0x764628bf, 0x3ead00f6, 0x00000000}},  //   _hyrë_, naky, _coet_,
  { {0x3ead02ae, 0x26c000e7, 0xef1901f3, 0x00000000}},  //   _doet_, _mlio_, _diż_,
  { {0x224201d5, 0x66040020, 0x443816b1, 0x00000000}},  //   _hekk_, _mzik, nbr_,
  { {0x26c00207, 0x7afb000c, 0x3dc60048, 0x00000000}},  //   _olio_, flut, szow_,
  { {0x22420f68, 0x7afb011c, 0x2907002b, 0x00000000}},  //   _jekk_, glut, _ahna_,
  { {0x63b50046, 0x66040045, 0x2cac0133, 0x00000000}},  //   zyzn, _nzik, _todd_,
  { {0x2918072d, 0x26c01b50, 0x7e6200d9, 0x00000000}},  //   öra_, _alio_, lgop,
  { {0x6441000c, 0x7e620d16, 0x442a0045, 0x00000000}},  //   ðlim, ogop, dcb_,
  { {0x7d1a17ce, 0x7e6204be, 0x26c000f4, 0x00000000}},  //   _hits, ngop, _clio_,
  { {0x7d1a006c, 0x8e2005b8, 0x2b4c00d9, 0x00000000}},  //   _kits, вiк_, _hvdc_,
  { {0x26c00197, 0x7d1a00c4, 0x66040036, 0x00000000}},  //   _elio_, _jits, _dzik,
  { {0xf76f007a, 0x2242000c, 0x764600e0, 0x00000000}},  //   _هاي_, _bekk_, baky,
  { {0x7d1a006c, 0x44380009, 0x26c00026, 0x00000000}},  //   _lits, abr_, _glio_,
  { {0x645a0489, 0x443800f6, 0x3ead00d9, 0x00000000}},  // [71b0] ótic, bbr_, _roet_,
  { {0x9028008b, 0x3ebf01bf, 0x7d1a0058, 0x00000000}},  //   ецца_, _slut_, _nits,
  { {0x3ead28c0, 0x64470089, 0xef19002b, 0x00000000}},  //   _poet_, maji, _piż_,
  { {0x2242000c, 0x644716a6, 0x7e6200ea, 0x00000000}},  //   _gekk_, laji, ggop,
  { {0x629d060c, 0x3ead00c7, 0x09b50044, 0x00000000}},  //   _inso, _voet_, _জেনা,
  { {0xd045005f, 0x644712bd, 0x628d0026, 0x00000000}},  //   yihə, naji, ldao,
  { {0x7d1a01c3, 0x3ead0168, 0x00000000, 0x00000000}},  //   _dits, _toet_,   ,
  { {0x7afb003c, 0x628d00e7, 0x1dd2007d, 0x00000000}},  //   ulut, ndao, _देवत,
  { {0x64470089, 0x2b400091, 0x2d58007c, 0x00000000}},  //   kaji, ćica_, _пить_,
  { {0x7afb0239, 0x8c3c0279, 0x6d4b141a, 0x00000000}},  //   slut, _boğu, msga,
  { {0x81d70055, 0x6f1b0020, 0x7afb2034, 0x00000000}},  //   িথি_, _kiuc, plut,
  { {0x8c3c01f6, 0x6d5900c1, 0x60c500e0, 0x00000000}},  //   _doğu, orwa, hhhm,
  { {0x6d4b032e, 0x41d0013d, 0x95990cb7, 0x00000000}},  //   nsga, _सेंस, нтру_,
  { {0x764628c1, 0x64470089, 0x629d010f, 0x00000000}},  //   saky, gaji, _anso,
  { {0x04430057, 0x64a30072, 0x00000000, 0x00000000}},  //   ресн, шара,   ,
  { {0x3afa0065, 0x26c00020, 0xd5b2004b, 0x00000000}},  //   tëpi_, _ulio_, _نفع_,
  { {0x644701a3, 0x69c900bb, 0x395f11e5, 0x00000000}},  // [71c0] baji, nzee, nuus_,
  { {0x81ac0055, 0x672310ed, 0x64470ade, 0x00000000}},  //   _কেউ_, _kunj, caji,
  { {0x4444002a, 0x7d1a000c, 0x752400b5, 0x00000000}},  //   _ie_, _rits, _huiz,
  { {0x44440038, 0x6f090038, 0x67230091, 0x00000000}},  //   _he_, _chec, _munj,
  { {0x4444033b, 0x7d1a0ac2, 0x752400c4, 0x00000000}},  //   _ke_, _pits, _juiz,
  { {0x444401cd, 0x8cf3007e, 0x69c90089, 0x00000000}},  //   _je_, азіц, dzee,
  { {0x4444048a, 0x7d1a0056, 0x75240181, 0x00000000}},  //   _me_, _vits, _luiz,
  { {0x44440068, 0x7d1a1f98, 0x644701c5, 0x00000000}},  //   _le_, _wits, zaji,
  { {0xf2d3019b, 0x44442280, 0x66d62198, 0x00000000}},  //   יעה_, _oe_, eško,
  { {0x7d1a049b, 0xed57005e, 0xe1ff00f6, 0x00000000}},  //   _uits, _шоу_, _ocón_,
  { {0x644701c5, 0x67230e0d, 0x6aa9004a, 0x00000000}},  //   vaji, _cunj, bjef,
  { {0x44441d21, 0x6723037e, 0x644707de, 0x00000000}},  //   _ae_, _dunj, waji,
  { {0x44440a8a, 0x644701d5, 0x67230022, 0x00000000}},  //   _be_, taji, _eunj,
  { {0x444428c2, 0xa4e4007e, 0x752400b5, 0x00000000}},  //   _ce_, аўск, _duiz,
  { {0x64470e8b, 0x6723022e, 0xa3cd0164, 0x00000000}},  //   raji, _gunj, _शेख_,
  { {0x4444061f, 0x64470557, 0xf2c40451, 0x00000000}},  //   _ee_, saji, асун,
  { {0x444428c3, 0x26d90211, 0x291c00b0, 0x00000000}},  // [71d0] _fe_, miso_, _kiva_,
  { {0x44440073, 0x26d90052, 0x656f0146, 0x00000000}},  //   _ge_, liso_, mtch,
  { {0xa5c7000c, 0x15f400a6, 0x6f1b0026, 0x00000000}},  //   _fróð, _مسیح, _piuc,
  { {0xf773007b, 0x6d4b00eb, 0xa5c7000c, 0x00000000}},  //   יקע_, tsga, _gróð,
  { {0x444428c4, 0x224907a5, 0x656f1339, 0x00000000}},  //   _ye_, maak_, ntch,
  { {0x444400ad, 0x6d4b032e, 0x395f00b0, 0x00000000}},  //   _xe_, rsga, vuus_,
  { {0x6f0919ff, 0x644508b5, 0x44210173, 0x00000000}},  //   _thec, _mehi, _mgh_,
  { {0x6445022b, 0xc207013d, 0x6d4b032e, 0x00000000}},  //   _lehi, _शराब_, psga,
  { {0x987e006b, 0x26d90197, 0x6abb0ef8, 0x00000000}},  //   _açıq_, diso_, rkuf,
  { {0x61fd0428, 0xe0df01aa, 0x67230091, 0x00000000}},  //   _mysl, _dwòg_, _punj,
  { {0x4444045e, 0x395f021e, 0x291c0142, 0x00000000}},  //   _re_, suus_, _diva_,
  { {0xcfc50055, 0x672300e7, 0xb5fb167d, 0x00000000}},  //   _এখান, _vunj, rgán,
  { {0x44441305, 0x644528c5, 0x75240211, 0x00000000}},  //   _pe_, _behi, _quiz,
  { {0x4444048a, 0x6723003f, 0x44210606, 0x00000000}},  //   _qe_, _tunj, _cgh_,
  { {0x444428c6, 0xb5fb0047, 0x394d23fc, 0x00000000}},  //   _ve_, lgál, lses_,
  { {0x44440f44, 0x26d928c7, 0x394d1a86, 0x00000000}},  //   _we_, ciso_, oses_,
  { {0x394d032c, 0x6445002b, 0x442128c8, 0x00000000}},  // [71e0] nses_, _fehi, _fgh_,
  { {0x64450756, 0x444423b4, 0x7e690211, 0x00000000}},  //   _gehi, _ue_, _acep,
  { {0x37d50044, 0x2249063f, 0x00000000, 0x00000000}},  //   _সুতর, baak_,   ,
  { {0x7126026c, 0x6445014a, 0x00000000, 0x00000000}},  //   _مرسل, _zehi,   ,
  { {0x31600240, 0x463b0049, 0x394d1beb, 0x00000000}},  //   quiz_, גענע, jses_,
  { {0x0b8a0d73, 0x00000000, 0x00000000, 0x00000000}},  //   есии_,   ,   ,
  { {0x394d00d4, 0x291c28c9, 0xd0070088, 0x00000000}},  //   eses_, _riva_, _бере_,
  { {0xd12f026c, 0x291c00ca, 0x8c3c005d, 0x00000000}},  //   _ذمہ_, _siva_, _coğr,
  { {0x8c3c047f, 0x26d90207, 0x291c05d2, 0x00000000}},  //   _doğr, viso_, _piva_,
  { {0x224928ca, 0x00000000, 0x00000000, 0x00000000}},  //   zaak_,   ,   ,
  { {0x291c0ffb, 0x2902001e, 0x6445011c, 0x00000000}},  //   _viva_, ēka_, _rehi,
  { {0x64450149, 0x2f970049, 0x44210860, 0x00000000}},  //   _sehi, אכטן_, _sgh_,
  { {0x25bf0010, 0x442110e0, 0x26d90052, 0x00000000}},  //   ául_, _pgh_, riso_,
  { {0x224901d6, 0x00000000, 0x00000000, 0x00000000}},  //   waak_,   ,   ,
  { {0xd6d10188, 0x779200d3, 0x644512a0, 0x00000000}},  //   _وقت_, _ایجا, _vehi,
  { {0xa6ab0188, 0x66c628cb, 0x1dc40164, 0x00000000}},  //   _سابق_, _póke, वनात,
  { {0x224924eb, 0xa1580264, 0x60f9007c, 0x00000000}},  // [71f0] raak_, лату_, вная_,
  { {0x61fd0161, 0x00000000, 0x00000000, 0x00000000}},  //   _vysl,   ,   ,
  { {0x8007007c, 0x672d0471, 0x00000000, 0x00000000}},  //   учае, _čajk,   ,
  { {0x66f7006e, 0x67050164, 0xd13000a1, 0x00000000}},  //   ीतिक_, रतिक_, تمے_,
  { {0xa2ba0164, 0x628f0420, 0x6da50a27, 0x00000000}},  //   _एकत्, _iaco, рила,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x628f02c1, 0xeab10025, 0x00000000, 0x00000000}},  //   _kaco, قعة_,   ,
  { {0x394d006c, 0x628f25d4, 0xc33400a0, 0x00000000}},  //   tses_, _jaco, זוק_,
  { {0x628f0a47, 0x394d00f4, 0x08c5134b, 0x00000000}},  //   _maco, uses_, ибин,
  { {0x394d03db, 0x3f980016, 0x7c9701fa, 0x00000000}},  //   rses_, _yrru_, _حشرا,
  { {0x394d030a, 0xeaae00a1, 0x00000000, 0x00000000}},  //   sses_, سٹی_,   ,
  { {0x89d601ef, 0xe1ff004a, 0xd4910082, 0x00000000}},  //   اویر_, _oyó_, ồn_,
  { {0xcb1200b6, 0xf50600da, 0xd94502dc, 0x00000000}},  //   _ולא_, измо, _тели,
  { {0xb4c20061, 0x00000000, 0x00000000, 0x00000000}},  //   ्फे_,   ,   ,
  { {0x98f40b6c, 0x934600e2, 0x00000000, 0x00000000}},  //   _اثنا, рнбе,   ,
  { {0xd1320025, 0x628f00c4, 0x00000000, 0x00000000}},  //   قمر_, _caco,   ,
  { {0x225d0036, 0x41270745, 0x6906000c, 0x00000000}},  // [7200] ówka_, иото_, iðen,
  { {0xe3ba0099, 0xbebd0006, 0x628f0045, 0x00000000}},  //   _або_, _liūd, _eaco,
  { {0x628f0207, 0x7e260174, 0xb4c2013d, 0x00000000}},  //   _faco, адеж, ंसी_,
  { {0x539b009b, 0x27760049, 0x628f0082, 0x00000000}},  //   _סיכו, יגען_, _gaco,
  { {0x628428cc, 0xc878014a, 0xdd920439, 0x00000000}},  //   meio, liğe_, توش_,
  { {0x61430467, 0x00000000, 0x00000000, 0x00000000}},  //   _фера,   ,   ,
  { {0x69dd0027, 0x628f28cd, 0xa5bb28ce, 0x00000000}},  //   úsen, _yaco, ncór,
  { {0x628f004a, 0x628400fa, 0x8f37009b, 0x00000000}},  //   _xaco, neio, _כאלו_,
  { {0x8d2a0088, 0x394201aa, 0x63bc18f7, 0x00000000}},  //   _розв_, èks_, hyrn,
  { {0x6f020207, 0x20070036, 0x8c660167, 0x00000000}},  //   lloc, żnie_, _خطرن,
  { {0x627e0036, 0x00000000, 0x00000000, 0x00000000}},  //   _złoż,   ,   ,
  { {0x7bdb009b, 0x98ab0089, 0xfaa301ee, 0x00000000}},  //   _בקבו, īcā_, _махо,
  { {0x993406b4, 0x628f0bdb, 0xe8940228, 0x00000000}},  //   _افتت, _raco, _галь,
  { {0x628f0181, 0x76560022, 0x6f0200cf, 0x00000000}},  //   _saco, _edyy, hloc,
  { {0x628f0181, 0xd9e80044, 0x6aa228cf, 0x00000000}},  //   _paco, _পরিম, _knof,
  { {0x6f02001a, 0x798b0016, 0x6284005b, 0x00000000}},  //   jloc, _ysgw, geio,
  { {0x518728d0, 0x20050087, 0x7b15012d, 0x00000000}},  // [7210] шува, _šli_, _tšuv,
  { {0x92d70055, 0xd9e80044, 0xa7fc014a, 0x00000000}},  //   াকে_, _পরাম, ygıl,
  { {0x33950025, 0x628f05f0, 0x6f0201a2, 0x00000000}},  //   _الجز, _taco, floc,
  { {0x539a00a0, 0x628400fa, 0x00000000, 0x00000000}},  //   _עירו, ceio,   ,
  { {0x127a0049, 0x6b9a01a2, 0x00000000, 0x00000000}},  //   _גארע, _artg,   ,
  { {0x8c420174, 0x44310232, 0x6aa20e66, 0x00000000}},  //   пеше, ncz_, _anof,
  { {0xde67005e, 0x627e00b4, 0x00000000, 0x00000000}},  //   _възп, _włoż,   ,
  { {0x6f02059a, 0x3a98007c, 0xa7fc014a, 0x00000000}},  //   cloc, атью_, rgıl,
  { {0x7e7b0145, 0x44330026, 0x7b23016c, 0x00000000}},  //   _ibup, _ofx_, _ađut,
  { {0x2d8d0026, 0x00000000, 0x00000000, 0x00000000}},  //   _isee_,   ,   ,
  { {0x2cf50061, 0x66d6012d, 0x7ae4012d, 0x00000000}},  //   ेतील_, lški, čitr,
  { {0x5b1528d1, 0x66c6000c, 0x66e628d2, 0x00000000}},  //   _умет, _bóka, сома,
  { {0x59c40025, 0x66080036, 0xe9d303e6, 0x00000000}},  //   _ويمك, ędko, _بغض_,
  { {0x66d60006, 0x443300d2, 0x3a3f0022, 0x00000000}},  //   iški, _cfx_, lbup_,
  { {0x78a30c31, 0x7e7b00ca, 0xdce20166, 0x00000000}},  //   _innv, _obup, stoć,
  { {0x26150204, 0x44310036, 0xc878014a, 0x00000000}},  //   नेही_, acz_, riğe_,
  { {0x95560318, 0x463b0049, 0x2d8d00e0, 0x00000000}},  // [7220] _اخبا, _געפע, _nsee_,
  { {0x44330061, 0xb466012b, 0xb4db0129, 0x00000000}},  //   _gfx_, _укол, ssàr,
  { {0x644e000c, 0xee3a017a, 0x6f0205af, 0x00000000}},  //   mabi, гне_, tloc,
  { {0x644e011f, 0x61e907ac, 0xf41300b6, 0x00000000}},  //   labi, _žele, _מפת_,
  { {0x1dd2013d, 0x22400461, 0x00000000, 0x00000000}},  //   _देखत, mbik_,   ,
  { {0x644e0284, 0x6f02219a, 0x8fa60256, 0x00000000}},  //   nabi, sloc, _лаге,
  { {0x6f0200f8, 0x09b50044, 0xdb090161, 0x00000000}},  //   ploc, _জেলা, žnýc,
  { {0x644e0b25, 0xeb97003b, 0x00000000, 0x00000000}},  //   habi, сић_,   ,
  { {0x644e28d3, 0xd91a005e, 0x984a005e, 0x00000000}},  //   kabi, льо_, ляна_,
  { {0xd90d0167, 0xe78600ed, 0xab2a0451, 0x00000000}},  //   نین_, бумо, _божа_,
  { {0x644e117a, 0xda7a005e, 0x00000000, 0x00000000}},  //   dabi, _бял_,   ,
  { {0xb5fb0051, 0x6aa20133, 0x00000000, 0x00000000}},  //   lgái, _unof,   ,
  { {0x644e060c, 0xb5fb0048, 0x00000000, 0x00000000}},  //   fabi, ogái,   ,
  { {0xb5fb1a1c, 0x3160004a, 0x00000000, 0x00000000}},  //   ngái, driz_,   ,
  { {0xf8db009b, 0x241907d0, 0x00000000, 0x00000000}},  //   _תחומ, ровы_,   ,
  { {0x386e009d, 0x7b1501ed, 0x00000000, 0x00000000}},  //   _hcfr_, _ušut,   ,
  { {0x644e28d4, 0xcfd60044, 0xe0d90088, 0x00000000}},  // [7230] babi, _তুলন, адач_,
  { {0x644e04b4, 0x660d002d, 0x764f0036, 0x00000000}},  //   cabi, _izak, lacy,
  { {0x22400010, 0x7bde004a, 0xdea10014, 0x00000000}},  //   bbik_, úpul, ویسی,
  { {0x395f0006, 0x3160006b, 0xd7fb0049, 0x00000000}},  //   yrus_, briz_, נהאל,
  { {0x31600197, 0x9cf50088, 0x7b15016c, 0x00000000}},  //   criz_, озді, _ošur,
  { {0x66d60006, 0x224b0f10, 0x9401006b, 0x00000000}},  //   rški, _heck_, _sahə_,
  { {0x764f0036, 0x3ec40010, 0x5b32009e, 0x00000000}},  //   kacy, ártó_, وٹور,
  { {0x644e0a3b, 0xb5fb0051, 0xdcfb0089, 0x00000000}},  //   zabi, agái, _kruī,
  { {0x644e011f, 0x395f1228, 0x224b01d6, 0x00000000}},  //   yabi, urus_, _meck_,
  { {0x212b0038, 0xf77105d4, 0x395f010e, 0x00000000}},  //   _much_, واج_, rrus_,
  { {0x16aa044b, 0x644e0eb5, 0x660d0600, 0x00000000}},  //   авни_, vabi, _azak,
  { {0x224b00ab, 0x09e80044, 0x644e28d5, 0x00000000}},  //   _neck_, _পররা, wabi,
  { {0x644e049a, 0xa50a01e0, 0x26c200b0, 0x00000000}},  //   tabi, иема_, rkko_,
  { {0x7afb089e, 0x7ae90056, 0x65660058, 0x00000000}},  //   lout, lnet, rukh,
  { {0x212b08ba, 0x36e90752, 0xa5bb0285, 0x00000000}},  //   _auch_, _گروپ_, scóp,
  { {0x7ae9021e, 0x31600489, 0x212b010f, 0x00000000}},  //   nnet, triz_, _buch_,
  { {0x644e014a, 0x7ae90ac2, 0x29050052, 0x00000000}},  // [7240] pabi, inet, olla_,
  { {0x3160022b, 0x7ae907e4, 0x7afb098a, 0x00000000}},  //   rriz_, hnet, hout,
  { {0x2905021e, 0x212b001f, 0x7ae9016e, 0x00000000}},  //   illa_, _euch_, knet,
  { {0xe29a0121, 0x31601338, 0x7afb00f4, 0x00000000}},  //   _там_, priz_, jout,
  { {0x7ae90142, 0x7afb009d, 0x0caa0088, 0x00000000}},  //   dnet, dout, итки_,
  { {0xd0e80123, 0x764f0036, 0x7ae9002d, 0x00000000}},  //   _اکرم_, zacy, enet,
  { {0xf76700a2, 0x7afb00bb, 0xb5fb0051, 0x00000000}},  //   _تا_, fout, rgái,
  { {0x29050108, 0x7afb1339, 0x62960173, 0x00000000}},  //   ella_, gout, ndyo,
  { {0x764f00b5, 0x68fa28d6, 0x660428d7, 0x00000000}},  //   vacy, totd, _nyik,
  { {0x1d0a005e, 0xb17b0049, 0x764f0036, 0x00000000}},  //   _тези_, סטיר, wacy,
  { {0x660d0047, 0xa09b0049, 0x7ae9013e, 0x00000000}},  //   _szak, בייט, bnet,
  { {0x99e80055, 0x290500b0, 0xd6db0594, 0x00000000}},  //   _পরীক, alla_, рто_,
  { {0x764f0036, 0x672404be, 0xe9cf0014, 0x00000000}},  //   racy, _diij, _لغو_,
  { {0xd5b8008b, 0x7ae00e06, 0x212b179f, 0x00000000}},  //   іся_, limt, _ruch_,
  { {0x57f302a8, 0x212b0038, 0x4394013b, 0x00000000}},  //   _општ, _such_, марс,
  { {0x25a60059, 0xb88200b9, 0x660d0032, 0x00000000}},  //   _šole_, řídi, _tzak,
  { {0x69c028d8, 0x660d014a, 0xd52d0082, 0x00000000}},  // [7250] nyme, _uzak, _dựn,
  { {0xcf9b045e, 0x7ae900b9, 0x7afb28d9, 0x00000000}},  //   ије_, znet, zout,
  { {0x752d0023, 0x224b08ea, 0x7afb0339, 0x00000000}},  //   _huaz, _teck_, yout,
  { {0xc7b30104, 0x79820036, 0x23fa009b, 0x00000000}},  //   ובע_, _opow, _להתא,
  { {0xa3df001c, 0x29050332, 0x7ae908e0, 0x00000000}},  //   _देत_, ylla_, vnet,
  { {0x91ba009b, 0x69c005aa, 0xd7ca01f5, 0x00000000}},  //   _המשי, dyme, ानाच,
  { {0x447c007b, 0x7afb00b0, 0x7ae90253, 0x00000000}},  //   ינגע, tout, tnet,
  { {0xfbd0007a, 0x7ae028da, 0x3f830087, 0x00000000}},  //   خته_, gimt, _ipju_,
  { {0x7afb00f4, 0x29050129, 0x69c01e3d, 0x00000000}},  //   rout, tlla_, gyme,
  { {0x88c9012b, 0x7afb11a2, 0x7ae90059, 0x00000000}},  //   слов_, sout, snet,
  { {0xb8e302fb, 0x07a50451, 0x7ae911b9, 0x00000000}},  //   _एक_, чанн, pnet,
  { {0x6a940088, 0xa5c201e5, 0x00000000, 0x00000000}},  //   _оріє, _þókn,   ,
  { {0x6b500051, 0x80bc0061, 0x00000000, 0x00000000}},  //   _tógá, _शकले,   ,
  { {0x2a6d010e, 0x31690d17, 0x00000000, 0x00000000}},  //   lgeb_, duaz_,   ,
  { {0x68e128db, 0x7cf60035, 0x03a3007c, 0x00000000}},  //   mild, târz, ниро,
  { {0x6e29023a, 0xc3230098, 0x2a6d006c, 0x00000000}},  //   _ngeb, емск, ngeb_,
  { {0x752d28dc, 0xdb0a0010, 0x00000000, 0x00000000}},  // [7260] _guaz, ínés,   ,
  { {0x68e128dd, 0xb4661001, 0x41032798, 0x00000000}},  //   nild, _экол, езув,
  { {0x752d28de, 0x69c00133, 0x00000000, 0x00000000}},  //   _zuaz, zyme,   ,
  { {0x68e10270, 0x2d9f00f6, 0x25a000ca, 0x00000000}},  //   hild, _brue_, _kril_,
  { {0x68e1049d, 0x1d0a0893, 0x4c940a1e, 0x00000000}},  //   kild, беди_, дилс,
  { {0x2d9f0146, 0x6e290190, 0x00000000, 0x00000000}},  //   _drue_, _egeb,   ,
  { {0x6fb60151, 0x79820036, 0x7ae00065, 0x00000000}},  //   _عمرا, _spow, timt,
  { {0x78b80197, 0x66c6000c, 0x2d9f068f, 0x00000000}},  //   _sovv, _bókm, _frue_,
  { {0x7ae028df, 0x68e128e0, 0x3914007c, 0x00000000}},  //   rimt, fild, ммир,
  { {0x7ae00065, 0x48aa0175, 0x02c90164, 0x00000000}},  //   simt, стим_, _रत्न,
  { {0xdc3b00a0, 0x752d24e2, 0x69c01e11, 0x00000000}},  //   _העבר, _suaz, syme,
  { {0x25a00112, 0xe0df000a, 0x69c0004a, 0x00000000}},  //   _bril_, _awòl_, pyme,
  { {0x68e1001e, 0x18a600ed, 0x2b400166, 0x00000000}},  //   bild, _надм, ćicu_,
  { {0xf53f044f, 0x65600592, 0x00000000, 0x00000000}},  //   rpå_, ámha,   ,
  { {0x187b009b, 0xa87b009b, 0xe0df01aa, 0x00000000}},  //   _הטוב, _האור, _dwòl_,
  { {0x316928e1, 0x00000000, 0x00000000, 0x00000000}},  //   tuaz_,   ,   ,
  { {0x44f501be, 0xc2c40025, 0x25a00062, 0x00000000}},  // [7270] _опис, ريكي, _gril_,
  { {0x31690032, 0x66f20089, 0x00000000, 0x00000000}},  //   ruaz_, māka,   ,
  { {0x2fc700ad, 0x201e0df8, 0x66f20089, 0x00000000}},  //   áng_, _útil_, lāka,
  { {0xd092005f, 0x2d9f00f6, 0x00000000, 0x00000000}},  //   _müəs, _prue_,   ,
  { {0x3d09001c, 0x66f2001e, 0xfe700151, 0x00000000}},  //   ितले_, nāka, ادم_,
  { {0x2fc700ad, 0x2bde0061, 0x4e180014, 0x00000000}},  //   ơng_, _केहू_, ستند_,
  { {0x68e128e2, 0xfc4600b9, 0x00000000, 0x00000000}},  //   vild, _říci_,   ,
  { {0x6d490606, 0x2d9f0866, 0x68e1107c, 0x00000000}},  //   _twea, _true_, wild,
  { {0xac27081c, 0x68e1014a, 0x2f18007c, 0x00000000}},  //   _ефек, tild, _хоть_,
  { {0x57e9007c, 0x00000000, 0x00000000, 0x00000000}},  //   ждом_,   ,   ,
  { {0x68e101f6, 0xc052009b, 0x00000000, 0x00000000}},  //   rild, כזי_,   ,
  { {0x25a000ca, 0xddc90066, 0x00000000, 0x00000000}},  //   _pril_, _obeż,   ,
  { {0x68e10ebc, 0x7bc30161, 0x66f20089, 0x00000000}},  //   pild, lynu, gāka,
  { {0xa3df0309, 0x00000000, 0x00000000, 0x00000000}},  //   _देह_,   ,   ,
  { {0x46f61281, 0x00000000, 0x00000000, 0x00000000}},  //   _очит,   ,   ,
  { {0x66f20089, 0x25760030, 0x00000000, 0x00000000}},  //   bāka, pæl_,   ,
  { {0xf1de013d, 0x66f20089, 0x91e300e2, 0x00000000}},  // [7280] _नेशन, cāka, воте,
  { {0xdcfb0091, 0xa3df0309, 0x25bf01a2, 0x00000000}},  //   _osuđ, _देव_, äule_,
  { {0x443a28e3, 0x00000000, 0x00000000, 0x00000000}},  //   _ifp_,   ,   ,
  { {0x27330011, 0x6e2d0059, 0x6700007d, 0x00000000}},  //   _mãn_, žabn, ैतिक_,
  { {0xb5fb28e4, 0x2056004d, 0xdc39014a, 0x00000000}},  //   lgár, _отвр, _açıd,
  { {0x23650c0a, 0x40950098, 0x4438005b, 0x00000000}},  //   šlje_, _прст, ncr_,
  { {0x6023008b, 0x9f88000c, 0xaaa90164, 0x00000000}},  //   _адра, _góða_, कांक,
  { {0x443800e7, 0x260f0061, 0x443a0068, 0x00000000}},  //   hcr_, _ठरली_, _lfp_,
  { {0x645e28e5, 0xadba0025, 0x225d0036, 0x00000000}},  //   _odpi, _بهذا_, ówki_,
  { {0x6d420035, 0xb5fb0010, 0x66f20089, 0x00000000}},  //   mpoa, zgás, vāka,
  { {0x1bf20164, 0xda6f05bb, 0x00000000, 0x00000000}},  //   _अखिल_, _ия_,   ,
  { {0x443a00f4, 0x25a60059, 0x66f20089, 0x00000000}},  //   _afp_, _šola_, tāka,
  { {0x443a00d9, 0x6d42002d, 0xceb300b3, 0x00000000}},  //   _bfp_, npoa, דיר_,
  { {0x66f20089, 0xf4840072, 0x61e91a7d, 0x00000000}},  //   rāka, кусн, _želo,
  { {0xa3df0164, 0x25ad0035, 0x00000000, 0x00000000}},  //   _देश_, ţel_,   ,
  { {0x443a0026, 0x2bb6013d, 0x32640cbc, 0x00000000}},  //   _efp_, _अपना, ктув,
  { {0xa3df00e8, 0xb5fb0010, 0x443a0052, 0x00000000}},  // [7290] _देर_, rgás, _ffp_,
  { {0x4395025f, 0x443a0133, 0x2fcb0025, 0x00000000}},  //   _заос, _gfp_, يباً_,
  { {0x645506f9, 0x66c6000c, 0x00000000, 0x00000000}},  //   mazi, _bókh,   ,
  { {0x7c3a01b5, 0xa25b009d, 0x3ea90032, 0x00000000}},  //   _aftr, _clôt, ñat_,
  { {0xdd94007e, 0x00000000, 0x00000000, 0x00000000}},  //   кацы,   ,   ,
  { {0x645528e6, 0xeb9903f3, 0x8b95003b, 0x00000000}},  //   nazi, зик_, ерич,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfcd900a1, 0xa3c2013d, 0x78aa000a, 0x00000000}},  //   _کارڈ_, ्नत_, _anfv,
  { {0x6455022b, 0x7bce010f, 0x68ef008e, 0x00000000}},  //   kazi, _übun, écdo,
  { {0x6d590009, 0xb88101ca, 0xb4be0204, 0x00000000}},  //   mswa, _číse, _आवे_,
  { {0x645528e7, 0x6d5928e8, 0xdcfb04eb, 0x00000000}},  //   dazi, lswa, _usuđ,
  { {0xeaae007e, 0x7ac400a8, 0x443a1ad1, 0x00000000}},  //   _ёй_, _исче, _sfp_,
  { {0x6d5901b5, 0x64550197, 0x6aab0026, 0x00000000}},  //   nswa, fazi, _ingf,
  { {0xbebd010a, 0x6d590022, 0x2bb6007d, 0x00000000}},  //   _siūl, iswa, _अपमा,
  { {0x638300ed, 0x443a0026, 0x777a0009, 0x00000000}},  //   лгра, _vfp_, cttx,
  { {0x44380061, 0x6d590c23, 0x3d16013d, 0x00000000}},  //   scr_, kswa, _पीने_,
  { {0x6455002d, 0xe1ff0051, 0x443a0203, 0x00000000}},  // [72a0] bazi, _scór_, _tfp_,
  { {0x64550198, 0xc05901fb, 0x6d590168, 0x00000000}},  //   cazi, дії_, dswa,
  { {0x9e660d5e, 0xb4cc0309, 0x6d5900d9, 0x00000000}},  //   евед, लसी_, eswa,
  { {0x4816007b, 0x66c6000c, 0xddc000b9, 0x00000000}},  //   ײַבן_, _bóki, _zemř,
  { {0x6da3017a, 0x1d0a0918, 0xfce601bd, 0x00000000}},  //   лица, педи_, нодо,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ac6007c, 0x6d420288, 0x9b260d51, 0x00000000}},  //   еспе, spoa, нфил,
  { {0x6455022b, 0x3192000a, 0x00000000, 0x00000000}},  //   zazi, _kņz_,   ,
  { {0x4c860175, 0x6455013f, 0x6d5900e7, 0x00000000}},  //   _плав, yazi, cswa,
  { {0xeb9a01f9, 0xa3c2006e, 0xd7fa003b, 0x00000000}},  //   _низ_, ्ना_, зум_,
  { {0x6455086f, 0xa3df013d, 0x2cac1d08, 0x00000000}},  //   vazi, _दें_, _indd_,
  { {0x6455000b, 0x569402d3, 0x212a0048, 0x00000000}},  //   wazi, гают, _libh_,
  { {0x645528e9, 0x7ae2016e, 0xc6090044, 0x00000000}},  //   tazi, _imot, রেনা_,
  { {0xab64010f, 0xdce20161, 0x7ae20161, 0x00000000}},  //   _grüß, kroč, _hmot,
  { {0x645528ea, 0xa7370025, 0x291e000c, 0x00000000}},  //   razi, _كثير_, mmta_,
  { {0xdce201d9, 0x6455117a, 0x290c0039, 0x00000000}},  //   droč, sazi, llda_,
  { {0x645528dc, 0x69d6014a, 0x00000000, 0x00000000}},  // [72b0] pazi, _üyed,   ,
  { {0xdce9002b, 0x656f00b4, 0x00000000, 0x00000000}},  //   _iseħ, much,   ,
  { {0x656f28eb, 0x61ea006b, 0x6d440035, 0x00000000}},  //   luch, _əllə, ţial,
  { {0x6d590007, 0xf412009b, 0x8f34007e, 0x00000000}},  //   tswa, _כפי_, уецц,
  { {0x657d01e5, 0x224904cb, 0x656f1238, 0x00000000}},  //   ntsh, mbak_, nuch,
  { {0x6d591915, 0x22490bca, 0x290c012d, 0x00000000}},  //   rswa, lbak_, jlda_,
  { {0x6d59002b, 0x09c9001c, 0x643c0049, 0x00000000}},  //   sswa, िन्य, לעגנ,
  { {0x656f1af8, 0xeab10025, 0x2249162d, 0x00000000}},  //   kuch, شعب_, nbak_,
  { {0x61e910f7, 0x656f28ec, 0x3ead0142, 0x00000000}},  //   _želj, juch, _inet_,
  { {0x656f0428, 0xa3d1007d, 0x4d98007e, 0x00000000}},  //   duch, वना_, _якую_,
  { {0x3ebf1993, 0x3a75005e, 0x366a0088, 0x00000000}},  //   _kout_, _алер, мано_,
  { {0xdb01009d, 0x656f2839, 0x7ae20087, 0x00000000}},  //   _orlé, fuch, _gmot,
  { {0x3ead01d6, 0x3ebf28ed, 0x63a50146, 0x00000000}},  //   _mnet_, _mout_, _arhn,
  { {0x7d0328ee, 0x7ae20059, 0x00000000, 0x00000000}},  //   nons, _zmot,   ,
  { {0xe7b2007a, 0x3ead0036, 0x31690032, 0x00000000}},  //   _نمود, _onet_, eraz_,
  { {0x656f0b77, 0x212a131d, 0x7d030883, 0x00000000}},  //   buch, _sibh_, hons,
  { {0x656f0211, 0x657d0541, 0x00000000, 0x00000000}},  // [72c0] cuch, ctsh,   ,
  { {0x3ebf00f4, 0x7d030056, 0xe0431fd9, 0x00000000}},  //   _aout_, jons, инуи,
  { {0x7d0311b7, 0x3ebf023f, 0xa3df0204, 0x00000000}},  //   dons, _bout_, _देऊ_,
  { {0xcfa90054, 0x3ebf009d, 0x3ead00ab, 0x00000000}},  //   عالم_, _cout_, _cnet_,
  { {0x7d0328ef, 0x290701ca, 0x3ebf01aa, 0x00000000}},  //   fons, _okna_, _dout_,
  { {0x7d030039, 0x50430072, 0xdce2007f, 0x00000000}},  //   gons, _верб, proč,
  { {0x3ebf0168, 0x656f0036, 0xc0e3030d, 0x00000000}},  //   _fout_, zuch, _торк,
  { {0x3ebf0e6d, 0x497400ed, 0xb9980793, 0x00000000}},  //   _gout_, глис, евих_,
  { {0x0d77007a, 0xeef5008b, 0xc878014a, 0x00000000}},  //   _لینک_, _сярэ, liği_,
  { {0x52bf02d2, 0x1be303d7, 0x656f012d, 0x00000000}},  //   _एक्स, _केवल_, vuch,
  { {0x656f010f, 0xc878014a, 0xdb1800b0, 0x00000000}},  //   wuch, niği_, tyvä,
  { {0x7ae20107, 0x656f008e, 0x7c270010, 0x00000000}},  //   _umot, tuch, _újra,
  { {0xb8960025, 0x656f004a, 0xd90f009e, 0x00000000}},  //   _للشع, uuch, _ڈیٹ_,
  { {0x657d0c53, 0x656f0046, 0xdb1800b0, 0x00000000}},  //   rtsh, ruch, syvä,
  { {0x656f001f, 0x68e802ae, 0x657d281b, 0x00000000}},  //   such, midd, stsh,
  { {0x63a50627, 0xc878011f, 0x656f008e, 0x00000000}},  //   _vrhn, diği_, puch,
  { {0x3ebf01aa, 0x7d030b5a, 0x22490032, 0x00000000}},  // [72d0] _rout_, yons, rbak_,
  { {0x316928f0, 0x3ebf0007, 0x660d0058, 0x00000000}},  //   rraz_, _sout_, _iyak,
  { {0x3ebf0173, 0x7d03016e, 0x672d00e7, 0x00000000}},  //   _pout_, vons, _kiaj,
  { {0x660d0022, 0x68e80b1e, 0x672d0066, 0x00000000}},  //   _kyak, hidd, _jiaj,
  { {0x68e801f3, 0xadbc0088, 0x629d1762, 0x00000000}},  //   kidd, мацi, _iaso,
  { {0x3ebf0263, 0x629d0047, 0x660d0117, 0x00000000}},  //   _wout_, _haso, _myak,
  { {0x3ebf11aa, 0x629d1de7, 0x7d0328f1, 0x00000000}},  //   _tout_, _kaso, rons,
  { {0x629d022b, 0x7d03010f, 0x1a650014, 0x00000000}},  //   _jaso, sons, ایشی_,
  { {0x7d03028c, 0x660d28f2, 0x629d000b, 0x00000000}},  //   pons, _nyak, _maso,
  { {0x629d0225, 0x26d90023, 0xe8f6007c, 0x00000000}},  //   _laso, ëron_, ллы_,
  { {0x660d014a, 0x28d9006e, 0xab940088, 0x00000000}},  //   _ayak, योगि, _вихі,
  { {0x660d0009, 0x9666007e, 0x00000000, 0x00000000}},  //   _byak, ыкме,   ,
  { {0x7ae90142, 0x68e8071b, 0xa9790049, 0x00000000}},  //   miet, bidd, _נאַכ,
  { {0x7ae90ebc, 0x6abb0e0d, 0x660d0c2d, 0x00000000}},  //   liet, ljuf, _dyak,
  { {0x629d002d, 0x999d0066, 0x660d0045, 0x00000000}},  //   _baso, _lewż_, _eyak,
  { {0x629d0325, 0xe2970269, 0x7ae91903, 0x00000000}},  //   _caso, лас_, niet,
  { {0x660d0047, 0x21670407, 0x98a70107, 0x00000000}},  // [72e0] _gyak, лити_, _linč_,
  { {0x7ae9184e, 0x2905002d, 0xc878014a, 0x00000000}},  //   hiet, nola_, tiği_,
  { {0x7ae91669, 0x629d0263, 0x2be30061, 0x00000000}},  //   kiet, _faso, _केलं_,
  { {0x629d0263, 0x2905066e, 0xc878014a, 0x00000000}},  //   _gaso, hola_, riği_,
  { {0x2905022b, 0x7ae9117a, 0x00000000, 0x00000000}},  //   kola_, diet,   ,
  { {0x628428f3, 0x629d0036, 0x2f1500f8, 0x00000000}},  //   lfio, _zaso, råga_,
  { {0x290528f4, 0x629d0dfc, 0x7ae900b5, 0x00000000}},  //   dola_, _yaso, fiet,
  { {0x61e902aa, 0xa3bc0061, 0x5a340893, 0x00000000}},  //   _želi, _आपन_, шнит,
  { {0x62840016, 0x2bb60164, 0x6da302ea, 0x00000000}},  //   ifio, _अपवा, _лита,
  { {0x660d0009, 0x00000000, 0x00000000, 0x00000000}},  //   _ryak,   ,   ,
  { {0x7ae928f5, 0xbec2008d, 0x68e80479, 0x00000000}},  //   biet, _çësh, ridd,
  { {0x68e823fb, 0x69c901d6, 0x00000000, 0x00000000}},  //   sidd, byee,   ,
  { {0x672d201f, 0x29050142, 0x00000000, 0x00000000}},  //   _viaj, bola_,   ,
  { {0x290506c0, 0x660d0020, 0x629d002d, 0x00000000}},  //   cola_, _vyak, _saso,
  { {0x629d28f6, 0xa3df02d2, 0xb2ab0364, 0x00000000}},  //   _paso, _देख_, нтаж_,
  { {0x660d00e0, 0x00000000, 0x00000000, 0x00000000}},  //   _tyak,   ,   ,
  { {0x629d01ee, 0xdcfb0091, 0xf1bf0082, 0x00000000}},  // [72f0] _vaso, _upuć, _ngát_,
  { {0x629d0020, 0x7ae9002d, 0x25a90058, 0x00000000}},  //   _waso, ziet, _iral_,
  { {0x629d00b0, 0x8e55007e, 0x7a2b01df, 0x00000000}},  //   _taso, атлі, _kötü,
  { {0x29050032, 0xa2830014, 0x25a9005a, 0x00000000}},  //   zola_, _دیرو, _kral_,
  { {0x7ae9001e, 0xe80b013d, 0x4e7803d6, 0x00000000}},  //   viet, _सुना_, احمد_,
  { {0x7ae90036, 0xdca500ed, 0x98a70d0a, 0x00000000}},  //   wiet, раки, _pinč_,
  { {0x7ae9021e, 0x273a008d, 0x29050207, 0x00000000}},  //   tiet, _nën_, vola_,
  { {0x6457049a, 0x69db022b, 0x2bb6006e, 0x00000000}},  //   _lexi, tzue, _अपरा,
  { {0x7ae9022b, 0xe8f9003b, 0xc8b50783, 0x00000000}},  //   riet, кли_, асны,
  { {0x273a0065, 0x69db00dd, 0x64570387, 0x00000000}},  //   _bën_, rzue, _nexi,
  { {0x290504f4, 0x7ae9082f, 0x25a9011c, 0x00000000}},  //   rola_, piet, _aral_,
  { {0x290528dc, 0x0656007e, 0x3f810016, 0x00000000}},  //   sola_, штоў, ithu_,
  { {0x29051144, 0x66f20089, 0x25a90026, 0x00000000}},  //   pola_, nāki, _cral_,
  { {0xccf2007b, 0x20f4007d, 0x395f28f7, 0x00000000}},  //   ַכן_, _आदेश_, msus_,
  { {0x4256007c, 0x395f04fe, 0xe29f000c, 0x00000000}},  //   итат, lsus_, _bað_,
  { {0x7a2b038c, 0xd7fa009b, 0xddd90173, 0x00000000}},  //   _götü, _בהצל, pawň,
  { {0xe2970174, 0x00e61deb, 0x62840016, 0x00000000}},  // [7300] шат_, ажан, rfio,
  { {0xe0d7012b, 0xe3e700a1, 0x66c6000c, 0x00000000}},  //   аву_, اکین_, _tóks,
  { {0x6e4600a2, 0x00000000, 0x00000000, 0x00000000}},  //   لنام,   ,   ,
  { {0x645c28f8, 0x395f23fc, 0xe0df000a, 0x00000000}},  //   lari, ksus_, _bwòs_,
  { {0x81e40055, 0xe29709b2, 0x3a3f0082, 0x00000000}},  //   _পুর_, _тая_, dcup_,
  { {0x645c1902, 0x395f0515, 0x7b6619d4, 0x00000000}},  //   nari, dsus_, атие,
  { {0x3160019a, 0x645c24ba, 0x7e7b00d9, 0x00000000}},  //   lsiz_, iari, _fcup,
  { {0x645c28f9, 0x09e70055, 0x8f9b00a3, 0x00000000}},  //   hari, _পড়া, _בילי,
  { {0x645c022b, 0xee0a00ed, 0x3160005a, 0x00000000}},  //   kari, _реал_, nsiz_,
  { {0x645c000b, 0x28a602d2, 0x97a600a5, 0x00000000}},  //   jari, _कोशि, армл,
  { {0x6457049a, 0x1037009b, 0xb03701ce, 0x00000000}},  //   _rexi, יטים_, יניג_,
  { {0x25a90263, 0x645728fa, 0x28a6006e, 0x00000000}},  //   _pral_, _sexi, _कोरि,
  { {0x645c1742, 0xe5c4004d, 0x00000000, 0x00000000}},  //   fari, осро,   ,
  { {0x645c28fb, 0x316028fc, 0x00000000, 0x00000000}},  //   gari, dsiz_,   ,
  { {0xa3bc001c, 0x64570068, 0xd6db10d6, 0x00000000}},  //   _आपण_, _vexi, _атп_,
  { {0x66e400ed, 0x39460036, 0x25a9012d, 0x00000000}},  //   _моја, _ktos_, _tral_,
  { {0x645c28fd, 0x765d1dbf, 0x645728fe, 0x00000000}},  // [7310] bari, masy, _texi,
  { {0x645c0412, 0x765d28ff, 0x449907ca, 0x00000000}},  //   cari, lasy, _свою_,
  { {0x2fc70c51, 0x2d8d0270, 0x92950839, 0x00000000}},  //   âng_, _spee_, _ланц,
  { {0x765d2900, 0x3f81018e, 0x39462901, 0x00000000}},  //   nasy, rthu_, _otos_,
  { {0x8c450113, 0x6da501fb, 0x395f006b, 0x00000000}},  //   беле, сила, xsus_,
  { {0x66f20089, 0x395f006c, 0x765d0d25, 0x00000000}},  //   rāki, vsus_, hasy,
  { {0x765d0d5f, 0x39460181, 0x225921af, 0x00000000}},  //   kasy, _atos_, _kesk_,
  { {0x2139008d, 0x645c04f4, 0x395f0004, 0x00000000}},  //   _kush_, zari, tsus_,
  { {0x645c006a, 0xf9910054, 0x765d0f99, 0x00000000}},  //   yari, سبة_, dasy,
  { {0x395f0127, 0x71d800b6, 0x645c0ddd, 0x00000000}},  //   rsus_, יוחד_, xari,
  { {0x395f00f4, 0x39461ad9, 0x69d6014a, 0x00000000}},  //   ssus_, _etos_, _üyen,
  { {0x765d28ff, 0x2b810024, 0x6d4b0b38, 0x00000000}},  //   gasy, móc_, opga,
  { {0xa96900e3, 0x21390035, 0x00000000, 0x00000000}},  //   _сила_, _nush_,   ,
  { {0x2ed40164, 0xdb082902, 0x984b01ab, 0x00000000}},  //   _दत्त, _ardè, _ряда_,
  { {0x656f2903, 0x4adb0061, 0x00000000, 0x00000000}},  //   arch, _बताव,   ,
  { {0x645c0682, 0x31602904, 0x3d09001c, 0x00000000}},  //   sari, tsiz_, ाकडे_,
  { {0x645c114e, 0x806601e1, 0x22590133, 0x00000000}},  // [7320] pari, йваж, _desk_,
  { {0x31600279, 0x21390023, 0x00000000, 0x00000000}},  //   rsiz_, _dush_,   ,
  { {0x44440038, 0xbbb60164, 0x3160005d, 0x00000000}},  //   _if_, _अपेक, ssiz_,
  { {0x4444000c, 0xe8e0001d, 0xa77a0049, 0x00000000}},  //   _hf_, _thủy_, טרעפ,
  { {0x2cea0057, 0x62962905, 0x63f70bb6, 0x00000000}},  //   лько_, meyo, _نفیس_,
  { {0x44441a20, 0x3ea00224, 0x765d0d5b, 0x00000000}},  //   _jf_, žit_, zasy,
  { {0x444405d2, 0x765d0263, 0x00000000, 0x00000000}},  //   _mf_, yasy,   ,
  { {0x656f018e, 0x3946004a, 0xcff70097, 0x00000000}},  //   yrch, _ptos_, _הצלה_,
  { {0x44442735, 0x765d04cd, 0x66f2001e, 0x00000000}},  //   _of_, vasy, nāku,
  { {0xdd8f007a, 0xf1b3009b, 0x656f0161, 0x00000000}},  //   _سوم_, פסת_, vrch,
  { {0x765d2081, 0xa3e802f4, 0x48a70147, 0x00000000}},  //   tasy, _मेल_, стым_,
  { {0x44442906, 0x7d0a2907, 0x4b370104, 0x00000000}},  //   _af_, lofs, _הראל_,
  { {0x765d0263, 0x44442908, 0x62960173, 0x00000000}},  //   rasy, _bf_, deyo,
  { {0x98a30057, 0x44442909, 0x765d290a, 0x00000000}},  //   _ниче, _cf_, sasy,
  { {0x44440810, 0x765d130b, 0xdceb0035, 0x00000000}},  //   _df_, pasy, lugă,
  { {0x4444009f, 0x213900ab, 0x7d0a01a2, 0x00000000}},  //   _ef_, _push_, hofs,
  { {0x4444001c, 0x6aa20020, 0x00000000, 0x00000000}},  // [7330] _ff_, _maof,   ,
  { {0x92e90044, 0x88bc013e, 0x00000000, 0x00000000}},  //   মকে_, změn,   ,
  { {0x623500ed, 0x6296042a, 0xdb080010, 0x00000000}},  //   _мену, beyo, _erdé,
  { {0x4444001a, 0xe0df01aa, 0x6aa20051, 0x00000000}},  //   _zf_, _ewòp_, _naof,
  { {0xa69c0049, 0x00000000, 0x00000000, 0x00000000}},  //   טשאפ,   ,   ,
  { {0x1b490f6f, 0x4f5b0380, 0x00000000, 0x00000000}},  //   азки_, _مجرد_,   ,
  { {0xfd100076, 0xdb090161, 0x00000000, 0x00000000}},  //   رجه_, žníc,   ,
  { {0xcf9200b3, 0x6d4b0056, 0x66f20089, 0x00000000}},  //   _קטן_, ppga, nākt,
  { {0x69d6011f, 0x7e6900e0, 0x60c7016c, 0x00000000}},  //   _üyel, _idep, _kojm,
  { {0x186901fc, 0x6f0b0d4d, 0xe6c50091, 0x00000000}},  //   јани_, logc, _češć,
  { {0xa3e803d7, 0xb8d1007d, 0x6d44001a, 0x00000000}},  //   _में_, _ऑफ_, ţiat,
  { {0x44441dd4, 0x60c71338, 0xd62a0175, 0x00000000}},  //   _sf_, _lojm, ионе_,
  { {0x4444285a, 0x7aeb0009, 0xdd0e005d, 0x00000000}},  //   _pf_, _imgt, nışl,
  { {0x4444290b, 0x394d1923, 0xf7710014, 0x00000000}},  //   _qf_, mpes_, _قاب_,
  { {0x394d008e, 0x6296290c, 0xd3720379, 0x00000000}},  //   lpes_, teyo, ظهر_,
  { {0x8c3c005a, 0x25b50211, 0x7d0a0ecc, 0x00000000}},  //   _mağa, ñaló_, zofs,
  { {0x64a6008b, 0x444400f4, 0xe0df01aa, 0x00000000}},  // [7340] _дапа, _tf_, _pwòp_,
  { {0x78a3290d, 0x44440181, 0x0ef4013d, 0x00000000}},  //   _janv, _uf_, ेक्स_,
  { {0xee3a0017, 0x66f2001e, 0x60c7040d, 0x00000000}},  //   ане_, sāku, _dojm,
  { {0x78a30173, 0x2fc70039, 0x2498000a, 0x00000000}},  //   _lanv, änga_, lerm_,
  { {0xe0df01aa, 0x226500b9, 0x26d90065, 0x00000000}},  //   _twòp_, řský_, ëroi_,
  { {0x6d49002a, 0xdb6a10a9, 0xafe60088, 0x00000000}},  //   _dtea, арил_, _догл,
  { {0xdfd20379, 0x66f20089, 0x3f671867, 0x00000000}},  //   _غير_, nāks, _миро_,
  { {0x78a3049b, 0x249800b5, 0x7d0a0521, 0x00000000}},  //   _aanv, herm_, sofs,
  { {0xdb2400a1, 0xfe4500a1, 0x78a3074d, 0x00000000}},  //   _ہوئی, _رکنی, _banv,
  { {0x236501d9, 0x320f0010, 0x3982000c, 0x00000000}},  //   šlji_, ügyi_, rðs_,
  { {0x2a66005e, 0x24980253, 0xc7b00025, 0x00000000}},  //   _дълг, derm_, رّح_,
  { {0x3ea61892, 0xd6d90036, 0x3ea400ea, 0x00000000}},  //   ndot_, ół_, _jamt_,
  { {0x2d860007, 0xdb010051, 0x26070088, 0x00000000}},  //   ntoe_, _urlá, ючог,
  { {0x3ea600b0, 0x98a70035, 0x8c3c0276, 0x00000000}},  //   hdot_, _vină_, _yağa,
  { {0xd25b0216, 0x92c704f1, 0xf2c701ee, 0x00000000}},  //   ица_, ощад, осан,
  { {0x290c22ec, 0xdd0e0279, 0x236d290e, 0x00000000}},  //   loda_, yışl, čej_,
  { {0x78a3005f, 0xdd0e006b, 0x39490023, 0x00000000}},  // [7350] _yanv, xışl, _çast_,
  { {0xd25000a1, 0x66f20089, 0x3ea6290f, 0x00000000}},  //   ٹنے_, sākt, edot_,
  { {0x3ea40061, 0x6d490e5f, 0xa6c8025a, 0x00000000}},  //   _bamt_, _stea, _طویل_,
  { {0x394d020f, 0x539a0104, 0x290c0161, 0x00000000}},  //   ypes_, _פירו, hoda_,
  { {0x290c2910, 0xdd9b0088, 0x867c009b, 0x00000000}},  //   koda_, рше_, שרדו,
  { {0xdd0e02b9, 0xece80088, 0x33290387, 0x00000000}},  //   rışl, оділ_, lmax_,
  { {0x78a31129, 0x600800a5, 0x33290146, 0x00000000}},  //   _ranv, _днём_, omax_,
  { {0x78a30173, 0x93fc009b, 0x332902d4, 0x00000000}},  //   _sanv, ילוי, nmax_,
  { {0x394d00f4, 0x7c870679, 0x9915007e, 0x00000000}},  //   upes_, _муже, зьні,
  { {0x290c1091, 0xdea300a1, 0xedb403ab, 0x00000000}},  //   goda_, _ریڈی, _تحفظ,
  { {0x78a30190, 0x394d2911, 0x9f4500b0, 0x00000000}},  //   _vanv, spes_, _älä_,
  { {0x394d006c, 0x2ca500ea, 0x78a301c3, 0x00000000}},  //   ppes_, _hald_, _wanv,
  { {0x78a3013e, 0x2ca5068f, 0xe0df0173, 0x00000000}},  //   _tanv, _kald_, _atòm_,
  { {0x290c00d4, 0x628f1dff, 0x26c2012d, 0x00000000}},  //   coda_, _abco, sjko_,
  { {0x628f0059, 0xe8d60097, 0x2ca52912, 0x00000000}},  //   _bbco, _מוסר_, _mald_,
  { {0xb1460407, 0x7afb0836, 0x33290146, 0x00000000}},  //   знал, nnut, gmax_,
  { {0x3ea40030, 0x867b009b, 0x24980023, 0x00000000}},  // [7360] _ramt_, _הרפו, perm_,
  { {0x3ea42161, 0x7afb0027, 0x628f0009, 0x00000000}},  //   _samt_, hnut, _ebco,
  { {0x7afb2913, 0x645e001e, 0x443a0acd, 0x00000000}},  //   knut, _iepi, _igp_,
  { {0x645e014a, 0x290c016e, 0x628f0146, 0x00000000}},  //   _hepi, zoda_, _gbco,
  { {0x7afb0428, 0x3ea60089, 0x1ea90379, 0x00000000}},  //   dnut, rdot_, تالي_,
  { {0xeaf6007d, 0x645e1c70, 0x2d8601b5, 0x00000000}},  //   ुक्त_, _jepi, rtoe_,
  { {0x290c00ee, 0x443a2914, 0x2d8601d6, 0x00000000}},  //   voda_, _mgp_, stoe_,
  { {0x645e2915, 0x7afb0091, 0x2d8602c2, 0x00000000}},  //   _lepi, gnut, ptoe_,
  { {0x2ca50030, 0x3cec0082, 0x00000000, 0x00000000}},  //   _fald_, _tmdv_,   ,
  { {0x81ae08b7, 0x645e001e, 0x6fb3026c, 0x00000000}},  //   _কথা_, _nepi, _تمہا,
  { {0x290c016c, 0x7afb0802, 0xd7f7007c, 0x00000000}},  //   roda_, bnut, зуя_,
  { {0xd6db0517, 0x290c0b2e, 0x6724016c, 0x00000000}},  //   сто_, soda_, _chij,
  { {0x290c00ea, 0x443a016b, 0x645e1555, 0x00000000}},  //   poda_, _bgp_, _bepi,
  { {0x2937007b, 0x645e097c, 0x61e40871, 0x00000000}},  //   _זאגן_, _cepi, dzil,
  { {0x645e2916, 0x026b007e, 0x7e622917, 0x00000000}},  //   _depi, йшай_, kaop,
  { {0x3817019b, 0x443a260d, 0xba3d00b9, 0x00000000}},  //   _מקום_, _egp_, jdůl,
  { {0x33290846, 0x3ced013d, 0xf1940194, 0x00000000}},  // [7370] rmax_, _अगले_, нить,
  { {0x645e00bb, 0x7afb0253, 0x7c3a00e0, 0x00000000}},  //   _gepi, znut, _ngtr,
  { {0x7afb164f, 0xdb08004a, 0x00000000, 0x00000000}},  //   ynut, _ardí,   ,
  { {0xf4030044, 0x645e2918, 0xadf502ea, 0x00000000}},  //   _এরপর_, _zepi, мпеш,
  { {0x64d1001c, 0xdca52488, 0x69c600b0, 0x00000000}},  //   _सकाळ, дали, äkel,
  { {0x777a0032, 0x00000000, 0x00000000, 0x00000000}},  //   kutx,   ,   ,
  { {0x7afb0142, 0x2ca50cfd, 0x78690010, 0x00000000}},  //   tnut, _vald_, _jövő,
  { {0xe9d90d99, 0x612200f4, 0x2ca5010f, 0x00000000}},  //   жки_, rôle, _wald_,
  { {0x7afb0091, 0x2d58007c, 0x672400d9, 0x00000000}},  //   rnut, _нить_, _rhij,
  { {0x6f19018e, 0x67240065, 0x7afb016e, 0x00000000}},  //   llwc, _shij, snut,
  { {0x645e01aa, 0x61e40066, 0x7afb0161, 0x00000000}},  //   _repi, zzil, pnut,
  { {0x645e04cb, 0x443a00bb, 0x6ab4007e, 0x00000000}},  //   _sepi, _sgp_, _псіх,
  { {0x18690113, 0x443a0107, 0x6aa900fa, 0x00000000}},  //   _дали_, _pgp_, mdef,
  { {0x6aa90056, 0x6d5b015e, 0x2a7f2919, 0x00000000}},  //   ldef, _mwua, lgub_,
  { {0xdc450006, 0x672400bb, 0x443a02d4, 0x00000000}},  //   jūči, _thij, _vgp_,
  { {0x6604291a, 0x2bb60061, 0x6aa90056, 0x00000000}},  //   _txik, _अपघा, ndef,
  { {0x8c3c038c, 0x443a0061, 0x798900bb, 0x00000000}},  // [7380] _bağl, _tgp_, ntew,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8c3c0279, 0x130a0783, 0x6d5b0022, 0x00000000}},  //   _dağl, _мной_, _awua,
  { {0x61e4291b, 0xf42a021e, 0xd8380087, 0x00000000}},  //   pzil, _enää_, meče_,
  { {0x6aa910a5, 0xdd9004e8, 0x7e6208da, 0x00000000}},  //   ddef, اوت_, raop,
  { {0x6e3b0032, 0x25ff0204, 0x00000000, 0x00000000}},  //   _egub, रपती_,   ,
  { {0xf7670123, 0xbb470379, 0x8f750088, 0x00000000}},  //   _جا_, ولون_, _путі,
  { {0xf96a007c, 0x6aa900ea, 0xff2401b2, 0x00000000}},  //   орой_, gdef, _سبزی,
  { {0x79890007, 0x8c3c005a, 0x20180065, 0x00000000}},  //   gtew, _yağl, _hyri_,
  { {0x6e3b291c, 0x7e600145, 0x41bb0049, 0x00000000}},  //   _zgub, _hemp, קציע,
  { {0x7e6001a3, 0xd838085c, 0x2b4c0022, 0x00000000}},  //   _kemp, ječe_, _utdc_,
  { {0x6d4000e0, 0x6aa900d4, 0xd8380e0d, 0x00000000}},  //   _kuma, cdef, deče_,
  { {0x7e60020c, 0x6d40000b, 0x9419006b, 0x00000000}},  //   _memp, _juma, əyən_,
  { {0x7e60042c, 0x6d400009, 0x777a05aa, 0x00000000}},  //   _lemp, _muma, putx,
  { {0x6d40006a, 0xa295008b, 0x3d1603d7, 0x00000000}},  //   _luma, наві, _पीछे_,
  { {0x8c3c0676, 0x9294007e, 0x6d400007, 0x00000000}},  //   _sağl, касц, _ouma,
  { {0x6d40291d, 0x26d9010a, 0x628d0016, 0x00000000}},  // [7390] _numa, ūros_, rfao,
  { {0x21380173, 0x6e3b005b, 0x00000000, 0x00000000}},  //   _cirh_, _sgub,   ,
  { {0x657d0065, 0x7e600022, 0x6d400fd1, 0x00000000}},  //   lush, _bemp, _auma,
  { {0x6d40006a, 0x7e6004cb, 0x00000000, 0x00000000}},  //   _buma, _cemp,   ,
  { {0x6d40291e, 0x506701c0, 0xbdf80076, 0x00000000}},  //   _cuma, _отва, ورها_,
  { {0x6d40006a, 0x00000000, 0x00000000, 0x00000000}},  //   _duma,   ,   ,
  { {0xeb910167, 0xd6e00036, 0x6d40000a, 0x00000000}},  //   اظت_, ółki_, _euma,
  { {0x7e600169, 0x2249291f, 0x657d1b1c, 0x00000000}},  //   _gemp, ncak_, kush,
  { {0x6d40006a, 0x6aa90002, 0xee84007e, 0x00000000}},  //   _guma, rdef, _шыро,
  { {0x47c5007c, 0x6aa900ea, 0x8c3c005a, 0x00000000}},  //   ебов, sdef, _yağm,
  { {0x79890007, 0x6d402920, 0x2a7f0022, 0x00000000}},  //   stew, _zuma, pgub_,
  { {0x657d0526, 0x6d402921, 0x7e600082, 0x00000000}},  //   fush, _yuma, _xemp,
  { {0xd838003b, 0x58d5007c, 0x15ba007e, 0x00000000}},  //   veče_, _подт, чыны_,
  { {0x09f6009b, 0x26d90023, 0x00000000, 0x00000000}},  //   _אמנם_, ëror_,   ,
  { {0xd83800ca, 0x141a0025, 0x232a02dc, 0x00000000}},  //   teče_, سيرة_, зови_,
  { {0x657d0065, 0x8c3c014a, 0x97d80025, 0x00000000}},  //   bush, _rağm, _تظهر_,
  { {0x7e601815, 0xd335008b, 0xd8380a0f, 0x00000000}},  // [73a0] _remp, тэры, reče_,
  { {0x6d40020c, 0xd83812ac, 0x53a600c0, 0x00000000}},  //   _ruma, seče_, _заоб,
  { {0x6d402922, 0x7e600169, 0x00000000, 0x00000000}},  //   _suma, _pemp,   ,
  { {0x040b001d, 0x6d40006a, 0x8c150044, 0x00000000}},  //   _lượn, _puma, াধান_,
  { {0x13d50044, 0x00000000, 0x00000000, 0x00000000}},  //   _হইয়,   ,   ,
  { {0x5ba60088, 0x66df0065, 0xf1bf0082, 0x00000000}},  //   ериз, _mëka, _ngáy_,
  { {0x91030867, 0xdb080051, 0x6adb013d, 0x00000000}},  //   _спре, _ardá, बसूर,
  { {0x6d40006a, 0xa3c10204, 0x657d21a4, 0x00000000}},  //   _tuma, ंमत_, yush,
  { {0x2a642923, 0xb9970783, 0xd91a007e, 0x00000000}},  //   ramb_, евых_, зьн_,
  { {0x60ce0240, 0x497307d0, 0x657d010e, 0x00000000}},  //   _jobm, ыльс, vush,
  { {0x273a0006, 0x5cf50088, 0x040b0082, 0x00000000}},  //   _būna_, _ряту, _dượn,
  { {0x09e600ec, 0x00000000, 0x00000000, 0x00000000}},  //   _поен,   ,   ,
  { {0xe9730558, 0x1af7007b, 0x99d300f9, 0x00000000}},  //   _مهند, _אמאל_, _متوا,
  { {0x657d0020, 0x321923d9, 0x040b0082, 0x00000000}},  //   rush, _rysy_, _gượn,
  { {0x25bf001a, 0x657d0023, 0xad1b009b, 0x00000000}},  //   ţul_, sush, פולר,
  { {0x41e70099, 0x657d2924, 0x78aa00f8, 0x00000000}},  //   ніза, push, _hafv,
  { {0x22490563, 0x60ce0544, 0x00000000, 0x00000000}},  // [73b0] rcak_, _bobm,   ,
  { {0xd564005e, 0x1007080c, 0x00000000, 0x00000000}},  //   _стъп, няем,   ,
  { {0xc1040025, 0x00000000, 0x00000000, 0x00000000}},  //   دولي,   ,   ,
  { {0xd356009b, 0x51870404, 0x6122009d, 0x00000000}},  //   _שירי_, _пуга, rôla,
  { {0x6da50175, 0xada50a78, 0x60ce0087, 0x00000000}},  //   тила, талл, _fobm,
  { {0xd3780091, 0xeb99013b, 0x3ea90e3d, 0x00000000}},  //   šće_, дик_, žat_,
  { {0xe810013d, 0x00000000, 0x00000000, 0x00000000}},  //   _ठुला_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xceb201f8, 0xf400001a, 0x2f1500f8, 0x00000000}},  //   _דין_, ăţii_, sågs_,
  { {0xa3c30164, 0xadf42925, 0x2903010e, 0x00000000}},  //   ्हा_, _спуш, õja_,
  { {0x040b0082, 0x395d0009, 0x66e601a4, 0x00000000}},  //   _vượn, _wwws_, вона,
  { {0x6134006b, 0x00000000, 0x00000000, 0x00000000}},  //   rülə,   ,   ,
  { {0x040b001d, 0x00000000, 0x00000000, 0x00000000}},  //   _tượn,   ,   ,
  { {0xe9d80099, 0x6aab0538, 0x64a6003b, 0x00000000}},  //   _які_, _hagf, њава,
  { {0x398b0637, 0x6386005e, 0x07a502dc, 0x00000000}},  //   løs_, ъгва, _райн,
  { {0x06f6007a, 0x00000000, 0x00000000, 0x00000000}},  //   _جستج,   ,   ,
  { {0xa5260a85, 0xd132009e, 0x00000000, 0x00000000}},  // [73c0] _имид, لمر_,   ,
  { {0x9ffa03ab, 0x6aab1fbc, 0x00000000, 0x00000000}},  //   وراء_, _lagf,   ,
  { {0xb4790049, 0x9e660131, 0xdd1c0142, 0x00000000}},  //   _אָרי, введ, _nášh,
  { {0xde76009e, 0x00000000, 0x00000000, 0x00000000}},  //   ئداع,   ,   ,
  { {0xdcfb0066, 0x5de602dc, 0xcd2a03ec, 0x00000000}},  //   _ssuġ, ъжда, وستن_,
  { {0x62840026, 0x2b5e0145, 0x00000000, 0x00000000}},  //   lgio, _pwtc_,   ,
  { {0x6aab0190, 0x8bc3005e, 0x00000000, 0x00000000}},  //   _bagf, исъд,   ,
  { {0x62840207, 0x2b550014, 0xbdc600a1, 0x00000000}},  //   ngio, ایند_, _لگتے_,
  { {0xbd8a007a, 0x6da30069, 0xd8380e0d, 0x00000000}},  //   _زنان_, _кита, deča_,
  { {0xd7fa00ed, 0x6f0207e4, 0x2ee61955, 0x00000000}},  //   дум_, lnoc, lhof_,
  { {0x473501e0, 0x88bc00b9, 0x6aab2926, 0x00000000}},  //   лнос, dmět, _fagf,
  { {0x6f02010f, 0x2cac12d3, 0x2ee6059b, 0x00000000}},  //   nnoc, _hadd_, nhof_,
  { {0xd90e026c, 0xe8940230, 0x6f02004a, 0x00000000}},  //   _ویب_, _баль, inoc,
  { {0x6f0200e5, 0x7ae201e5, 0x00000000, 0x00000000}},  //   hnoc, _hlot,   ,
  { {0x7ae200f8, 0x629f006b, 0x24180a78, 0x00000000}},  //   _klot, teqo, воры_,
  { {0x62840198, 0xf837009b, 0x291e2927, 0x00000000}},  //   ggio, _בנות_, llta_,
  { {0x6f020224, 0xc1050025, 0x291e1610, 0x00000000}},  // [73d0] dnoc, هوري, olta_,
  { {0x7ae22928, 0x273b0006, 0x6b9a0009, 0x00000000}},  //   _llot, _kūno_, _optg,
  { {0xa3d500ed, 0x291e00b0, 0xdce2016c, 0x00000000}},  //   _сонч, ilta_, jrođ,
  { {0x8f140245, 0x612b006c, 0x6f020638, 0x00000000}},  //   афіч, külg, gnoc,
  { {0x6aab2929, 0x00000000, 0x00000000, 0x00000000}},  //   _ragf,   ,   ,
  { {0x6aab292a, 0x7ae20052, 0x5f4500a1, 0x00000000}},  //   _sagf, _alot, _منسل,
  { {0x7ae20039, 0x7c840a27, 0xeb990131, 0x00000000}},  //   _blot, руче, хий_,
  { {0x7ae200ab, 0x6f020197, 0x798000e7, 0x00000000}},  //   _clot, cnoc, fumw,
  { {0xa91d00b9, 0x7c940014, 0x3f8100e7, 0x00000000}},  //   huže, _چشما, luhu_,
  { {0x7ae2077b, 0x2cac0203, 0x88bc013e, 0x00000000}},  //   _elot, _gadd_, dměs,
  { {0x7ae203b4, 0x25a90149, 0x3ebf0056, 0x00000000}},  //   _flot, _asal_, _knut_,
  { {0x291e292b, 0xa6830242, 0x7ae201e5, 0x00000000}},  //   alta_, блюд, _glot,
  { {0x3f8101a3, 0x55f60a7c, 0x00000000, 0x00000000}},  //   huhu_, учну,   ,
  { {0x7ae20036, 0x3b1f006b, 0xd83800ca, 0x00000000}},  //   _zlot, lluq_, seča_,
  { {0xe29a00ed, 0x7d03292c, 0x78a1292d, 0x00000000}},  //   нав_, inns, melv,
  { {0x42550088, 0x3b1f006b, 0xe355007e, 0x00000000}},  //   итут, nluq_, ртрэ,
  { {0x612b0010, 0x62841944, 0x42261606, 0x00000000}},  // [73e0] küld, rgio, удав,
  { {0x78a100ea, 0xa91d0059, 0x26d2008e, 0x00000000}},  //   nelv, lužb, _hoyo_,
  { {0x645c292e, 0x6f0201ee, 0x26d2292f, 0x00000000}},  //   mbri, tnoc, _koyo_,
  { {0x645c2930, 0x79800009, 0x2cac0026, 0x00000000}},  //   lbri, yumw, _sadd_,
  { {0x26d20020, 0x80c40164, 0x6f020f73, 0x00000000}},  //   _moyo_, रादे, rnoc,
  { {0x2ee6021f, 0x33200066, 0x7bd80006, 0x00000000}},  //   shof_, llix_, tyvu,
  { {0x645c0051, 0xafe60423, 0x2d8f0129, 0x00000000}},  //   ibri, _совл, atge_,
  { {0x4974005c, 0x79800cd1, 0x5fbb009b, 0x00000000}},  //   алис, tumw, _אצלנ,
  { {0xdce90059, 0xa91d0521, 0x7ae22931, 0x00000000}},  //   _zveč, dužb, _vlot,
  { {0x78a10479, 0x645c0190, 0x25a90022, 0x00000000}},  //   gelv, jbri, _rsal_,
  { {0x645c0030, 0x26d2000a, 0x06ae0044, 0x00000000}},  //   dbri, _boyo_, গানি,
  { {0x7c282932, 0x7c25010f, 0x7ae20639, 0x00000000}},  //   _izdr, ühre, _ulot,
  { {0x78a101d6, 0x612b18cf, 0xab630036, 0x00000000}},  //   belv, lüle, ążen,
  { {0x645c01d6, 0xa91d0091, 0x26c021b8, 0x00000000}},  //   gbri, tuže, _enio_,
  { {0x24190783, 0x612b014a, 0x69c600ea, 0x00000000}},  //   товы_, nüle, åkef,
  { {0xddc00224, 0x45d5034b, 0x26d2004a, 0x00000000}},  //   _nemů, _воис, _goyo_,
  { {0xdce9010a, 0x645c1a64, 0x50f50e09, 0x00000000}},  // [73f0] _sveč, bbri, азат,
  { {0x656f059b, 0xd3780166, 0x7c28016e, 0x00000000}},  //   msch, šća_, _ozdr,
  { {0x9295008b, 0x656f059b, 0x3ead006c, 0x00000000}},  //   _канц, lsch, _paet_,
  { {0x7d1a006c, 0xde95012b, 0x628a0010, 0x00000000}},  //   _akts, радњ, őfor,
  { {0x656f001f, 0x9e640088, 0x78a10010, 0x00000000}},  //   nsch, свід, yelv,
  { {0x656f010f, 0x88bc00b9, 0x61ed2174, 0x00000000}},  //   isch, změr, mzal,
  { {0xdce905fa, 0x656f010f, 0xa2dc013d, 0x00000000}},  //   _uveč, hsch, _नवम्,
  { {0x656f054e, 0x645c04eb, 0x657d012d, 0x00000000}},  //   ksch, zbri, krsh,
  { {0x9c87006d, 0x61ed2352, 0x26d21fb8, 0x00000000}},  //   _مشاه, nzal, _royo_,
  { {0x656f07eb, 0xf7710025, 0x7e6b0058, 0x00000000}},  //   dsch, ياج_, lagp,
  { {0x672d0e9e, 0x656f0253, 0x78a12933, 0x00000000}},  //   _bhaj, esch, relv,
  { {0x6b830169, 0x672d01aa, 0x656f059b, 0x00000000}},  //   mung, _chaj, fsch,
  { {0x6b83146c, 0x7ae901c9, 0x9583007c, 0x00000000}},  //   lung, mhet, оляе,
  { {0x7ae90047, 0x7afb0006, 0x88bc013e, 0x00000000}},  //   lhet, liut, směr,
  { {0x660d0a5d, 0x26d20487, 0x645c0da6, 0x00000000}},  //   _exak, _toyo_, rbri,
  { {0x645c049b, 0x656f010f, 0x7ae901c9, 0x00000000}},  //   sbri, bsch, nhet,

  { {0x6b832934, 0x656f0173, 0x612b0148, 0x00000000}},  // [7400] hung, csch, züle,
  { {0x6b830390, 0x7f470065, 0x6f1b012d, 0x00000000}},  //   kung, _bujq, _akuc,
  { {0x6b83010a, 0x44440010, 0x6f090283, 0x00000000}},  //   jung, _ig_, _bjec,
  { {0x6b83010f, 0x65640009, 0x249a00f6, 0x00000000}},  //   dung, _kwih, _hbpm_,
  { {0x6f090182, 0x6d4b001c, 0x7ae92935, 0x00000000}},  //   _djec, gqga, dhet,
  { {0x6b83000b, 0x6f090211, 0x44440169, 0x00000000}},  //   fung, _ejec, _jg_,
  { {0x444402d5, 0x6b832936, 0x2fc70002, 0x00000000}},  //   _mg_, gung, ängt_,
  { {0x7ae9143e, 0x612b2937, 0x76440922, 0x00000000}},  //   ghet, rüle, _ngiy,
  { {0x44442938, 0xe1ff0211, 0x612b2939, 0x00000000}},  //   _og_, _león_, süle,
  { {0x4444084e, 0x6b83020c, 0x612b014a, 0x00000000}},  //   _ng_, bung, püle,
  { {0x61ed02cf, 0x6b83293a, 0x7d180161, 0x00000000}},  //   zzal, cung, movs,
  { {0x44440195, 0x656f001f, 0x7ae90a86, 0x00000000}},  //   _ag_, tsch, chet,
  { {0xd9541847, 0x44440127, 0xca9700b3, 0x00000000}},  //   _انتخ, _bg_, _כדאי_,
  { {0x656f04e5, 0x4444003b, 0xa4e4008b, 0x00000000}},  //   rsch, _cg_, оўск,
  { {0x44440129, 0x656f04e5, 0x326701c0, 0x00000000}},  //   _dg_, ssch, итав,
  { {0xd258102a, 0x44440292, 0x083b00b6, 0x00000000}},  //   ицу_, _eg_, _בעול,
  { {0x6b83000b, 0x444408ed, 0x6e2000b9, 0x00000000}},  // [7410] zung, _fg_, _nymb,
  { {0x44441dd3, 0x6b830061, 0x7ae90047, 0x00000000}},  //   _gg_, yung, zhet,
  { {0x7e6b006a, 0x7ae90039, 0x61ed108d, 0x00000000}},  //   tagp, yhet, szal,
  { {0x7ae90065, 0x4444016e, 0x00000000, 0x00000000}},  //   xhet, _zg_,   ,
  { {0x4444027e, 0x6f09293b, 0x6b83293c, 0x00000000}},  //   _yg_, _vjec, wung,
  { {0x6b83293d, 0x4444020b, 0x7d180059, 0x00000000}},  //   tung, _xg_, govs,
  { {0x7ae90047, 0x7e6b011c, 0xeeab007c, 0x00000000}},  //   thet, pagp, _итак_,
  { {0x6b83001f, 0x6f1b0107, 0xa91d0107, 0x00000000}},  //   rung, _ukuc, duža,
  { {0x60d50027, 0x6b83293e, 0x7ae901e2, 0x00000000}},  //   _kozm, sung, rhet,
  { {0x644500ad, 0x6b83094d, 0x65640045, 0x00000000}},  //   _nghi, pung, _rwih,
  { {0x444400c4, 0x7e6900ab, 0x69c609f0, 0x00000000}},  //   _rg_, _keep, äker,
  { {0x6d411b5c, 0xe5a6005e, 0x64450035, 0x00000000}},  //   _hila, бими, _aghi,
  { {0x6d4117ca, 0x4444293f, 0x39900129, 0x00000000}},  //   _kila, _pg_, càs_,
  { {0xdff903d7, 0x6d41002b, 0x3a36009b, 0x00000000}},  //   ्पाद_, _jila, _פרסם_,
  { {0x6d4104b8, 0x4444000c, 0xd3b50057, 0x00000000}},  //   _mila, _vg_, ость,
  { {0x4444114b, 0x6b9c23cb, 0x76440009, 0x00000000}},  //   _wg_, _ärge, _ugiy,
  { {0x4444002a, 0xf1aa007a, 0x6d410032, 0x00000000}},  // [7420] _tg_, دازه_, _oila,
  { {0x4444006a, 0x6d412940, 0x60d50035, 0x00000000}},  //   _ug_, _nila, _cozm,
  { {0x823602fd, 0x0019007e, 0x7d1801ed, 0x00000000}},  //   _گردا, аўцы_, vovs,
  { {0x6d410016, 0xddc00035, 0x7e690146, 0x00000000}},  //   _aila, _nemţ, _ceep,
  { {0x6d412941, 0x7ce6000c, 0x7e6900ab, 0x00000000}},  //   _bila, _aðra, _deep,
  { {0x6d41008d, 0xdcb10082, 0x5c97007e, 0x00000000}},  //   _cila, _cả_, йкія_,
  { {0x6d41020c, 0x7d180161, 0xcec300b9, 0x00000000}},  //   _dila, rovs, áří_,
  { {0xa3b90316, 0x7d18145e, 0x6d4100c7, 0x00000000}},  //   चित_, sovs, _eila,
  { {0x6d410da4, 0x7c96004c, 0x7d0d0051, 0x00000000}},  //   _fila, _грец, éasc,
  { {0x6d4103b0, 0x39900129, 0xd8f80088, 0x00000000}},  //   _gila, ràs_, рної_,
  { {0xf98f089d, 0x61300210, 0x25a00156, 0x00000000}},  //   وبی_, mäld, _apil_,
  { {0xa25b0181, 0x6d411eca, 0xf1bf0010, 0x00000000}},  //   _anôn, _zila, _szám_,
  { {0x2fc70011, 0x6f0306c0, 0xf65f01e5, 0x00000000}},  //   ̣ng_, énci, rbæ_,
  { {0x4427001d, 0x38c802fd, 0x6448016e, 0x00000000}},  //   _ơn_, _خاصی_, ždin,
  { {0x60d51c10, 0x36d5003b, 0x56950d99, 0x00000000}},  //   _rozm, _мокр, _дайт,
  { {0x925901f9, 0x00000000, 0x00000000, 0x00000000}},  //   раат_,   ,   ,
  { {0x60f9008b, 0x3ea600b0, 0x60d5163d, 0x00000000}},  // [7430] аная_, deot_, _pozm,
  { {0x7e69095a, 0x3f93002b, 0x00000000, 0x00000000}},  //   _seep, ttxu_,   ,
  { {0x44272942, 0x6d4101bc, 0x2fc70011, 0x00000000}},  //   _án_, _rila, ãng_,
  { {0x3ea6048d, 0x52a70025, 0x00000000, 0x00000000}},  //   geot_, _اصدق,   ,
  { {0x6f190036, 0x80b80044, 0x7e69010e, 0x00000000}},  //   rowc, _আকর্, _veep,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d4104bd, 0x7e690ac2, 0x09d60044, 0x00000000}},  //   _vila, _teep, _তেলা,
  { {0x6d412943, 0x78830010, 0x93fc01ce, 0x00000000}},  //   _wila, kívü, טלוי,
  { {0x6d41021e, 0xed590091, 0x6c75003b, 0x00000000}},  //   _tila, _brže_, _млађ,
  { {0xb902007e, 0x00000000, 0x00000000, 0x00000000}},  //   дзьк,   ,   ,
  { {0xeaae026c, 0xa6ca09ae, 0x25a00018, 0x00000000}},  //   رٹی_, ална_, _spil_,
  { {0x2ca700b5, 0xa91d1556, 0x61302944, 0x00000000}},  //   lend_, drže, mäle,
  { {0x9404005f, 0x00000000, 0x00000000, 0x00000000}},  //   əmə_,   ,   ,
  { {0x2ca7147c, 0xdb1a0a39, 0x00000000, 0x00000000}},  //   nend_, _artè,   ,
  { {0x7d040051, 0x2ca72945, 0x443e00b0, 0x00000000}},  //   éisi, iend_, ät_,
  { {0x2ca70e4d, 0x032601ff, 0x00000000, 0x00000000}},  //   hend_, ідан,   ,
  { {0x2ca70f12, 0xdb010210, 0xa56600a1, 0x00000000}},  // [7440] kend_, _islä, _بدعن,
  { {0x505a008b, 0x6ab6013d, 0x628f0207, 0x00000000}},  //   ршая_, _अफ्र, _ecco,
  { {0x2ca700c7, 0x232a01fb, 0xe29a0517, 0x00000000}},  //   dend_, _вони_, _кан_,
  { {0x6da6003b, 0x00000000, 0x00000000, 0x00000000}},  //   жида,   ,   ,
  { {0xc27b00b3, 0x2ca701ac, 0x00000000, 0x00000000}},  //   _דרכי, fend_,   ,
  { {0x2ca71a7f, 0xcf5a007c, 0x6ca3005e, 0x00000000}},  //   gend_, _врач_, дръж,
  { {0x61300073, 0x7d0d0051, 0x823602fd, 0x00000000}},  //   räld, éasa, _درگا,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc333019b, 0x2ca72946, 0x0c7a1739, 0x00000000}},  //   ווה_, bend_, _نصاب_,
  { {0x2ca72947, 0xd83800ca, 0x20070036, 0x00000000}},  //   cend_, leči_, źnie_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa91d1282, 0x274401aa, 0xdb1a2948, 0x00000000}},  //   vrže, vènè_, _orté,
  { {0xd6270025, 0x6a9b009b, 0x6744009e, 0x00000000}},  //   تعدي, _כשאנ, _کرتے,
  { {0xe3b30084, 0x395900c4, 0xa91d2949, 0x00000000}},  //   ورز_, ísse_, trže,
  { {0x926b00ed, 0x628f004a, 0x78a806d4, 0x00000000}},  //   ираа_, _pcco, medv,
  { {0xd8380243, 0x25b0021e, 0x2ca7054e, 0x00000000}},  //   ječi_, ällä_, zend_,
  { {0xf19401ab, 0x628f0f02, 0x00000000, 0x00000000}},  // [7450] мить, _vcco,   ,
  { {0xc79500a1, 0x78a804e7, 0x3f81013e, 0x00000000}},  //   _بھیا_, nedv, trhu_,
  { {0x2ca723c8, 0xb4e7013d, 0xddc00087, 0x00000000}},  //   vend_, पसी_, _remš,
  { {0x2ca700c7, 0x628f0009, 0x00000000, 0x00000000}},  //   wend_, _ucco,   ,
  { {0x7cef0637, 0x2ca725f7, 0xd256009b, 0x00000000}},  //   _jørg, tend_, _משרה_,
  { {0xf1bf00f7, 0x7d760025, 0x23b80123, 0x00000000}},  //   _irá_, أمور_, _ادیب_,
  { {0x2ca7294a, 0x81ad0055, 0x8c4200ed, 0x00000000}},  //   rend_, _কপি_, неше,
  { {0x2ca7063c, 0xdd95007e, 0x628d25e1, 0x00000000}},  //   send_, _набы, ngao,
  { {0xceb2061e, 0xdd580230, 0xe8f906c4, 0x00000000}},  //   _אין_, _матч_, йли_,
  { {0xb4ea0061, 0x6d5b00fa, 0x7cef00ea, 0x00000000}},  //   _मते_, _itua, _sørf,
  { {0x779000a1, 0x66df0065, 0x6f0b0082, 0x00000000}},  //   نیوا, _lëku, ongc,
  { {0x6602000c, 0x7cef0190, 0x68ea046a, 0x00000000}},  //   _þokk, _børg, _elfd,
  { {0x63be091d, 0x7aeb0089, 0x69dd010e, 0x00000000}},  //   _srpn, _ilgt, äsed,
  { {0xa8790049, 0x395f294b, 0x6aa900c1, 0x00000000}},  //   _האַר, mpus_, leef,
  { {0xe73a044b, 0x7e7b04eb, 0x66e600e2, 0x00000000}},  //   _лек_, _odup, _нока,
  { {0xdb0101a2, 0xa2cc0061, 0xf1bf01e5, 0x00000000}},  //   _erlö, हाध्, _brá_,
  { {0x612b0010, 0xa5f7003b, 0x395f0288, 0x00000000}},  // [7460] rüln, _нећу_, npus_,
  { {0xf617009b, 0x7e7b01c3, 0x6aa900d9, 0x00000000}},  //   _מחפש_, _adup, heef,
  { {0x6d5b02d5, 0xc2c60054, 0x7c25010f, 0x00000000}},  //   _atua, _فيدي, ührl,
  { {0x6146012b, 0xf1bf0359, 0x7cef0030, 0x00000000}},  //   _нема, _frá_, _lørd,
  { {0x63bc001c, 0xf1bf0051, 0xd8381f6c, 0x00000000}},  //   lvrn, _grá_, reči_,
  { {0x64431195, 0x31601ef5, 0x6d5b0051, 0x00000000}},  //   _únic, mpiz_, _dtua,
  { {0xab381fea, 0x8fa3007c, 0xb60600d0, 0x00000000}},  //   опку_, _паре, lošč,
  { {0x6d5b0065, 0x2aaa1fe6, 0x6aa90328, 0x00000000}},  //   _ftua, стко_, geef,
  { {0xf65f08c8, 0x78a80146, 0x612b294c, 0x00000000}},  //   kjær_, tedv, küll,
  { {0x6f022924, 0x7aeb0006, 0x47780088, 0x00000000}},  //   lioc, _elgt, обою_,
  { {0x3f780089, 0x25b21d30, 0x7cef01e3, 0x00000000}},  //   nču_, _asyl_, _sørg,
  { {0x6f020107, 0x00000000, 0x00000000, 0x00000000}},  //   nioc,   ,   ,
  { {0x612b010f, 0x7cef0374, 0x255800b9, 0x00000000}},  //   füll, _førd, vělý_,
  { {0x2ed9007d, 0x6f020026, 0xb60600ca, 0x00000000}},  //   _भक्त, hioc, došč,
  { {0x291e1958, 0x290c00d8, 0x3cfe0087, 0x00000000}},  //   mota_, mnda_, _mmtv_,
  { {0x291e002d, 0xf1bf00c4, 0x237f040d, 0x00000000}},  //   lota_, _prá_, čuj_,
  { {0x7cef068f, 0x867c009b, 0x30a7007c, 0x00000000}},  // [7470] _høre, _הרחו, зрев,
  { {0x291e1a99, 0x3cf803d7, 0x7cef0018, 0x00000000}},  //   nota_, ्चों_, _køre,
  { {0x8144025a, 0x6f020026, 0x6d5b0d29, 0x00000000}},  //   رنمن, fioc, _stua,
  { {0x6f020207, 0xf1bf27ec, 0x291e0142, 0x00000000}},  //   gioc, _trá_, hota_,
  { {0x291e1c13, 0xd838012d, 0x26c900e7, 0x00000000}},  //   kota_, meču_, _mnao_,
  { {0x3329294d, 0x69d6014a, 0xdb08294e, 0x00000000}},  //   llax_, _üyey, _ordó,
  { {0xeb99007c, 0x291e0ba5, 0xed590087, 0x00000000}},  //   ций_, dota_, _drža_,
  { {0xa91d04a9, 0x290c0198, 0x6f0203d1, 0x00000000}},  //   drža, enda_, cioc,
  { {0x6aa900bb, 0x386e1f75, 0x290c000c, 0x00000000}},  //   reef, _befr_, fnda_,
  { {0x291e008e, 0x612b294f, 0xd3780166, 0x00000000}},  //   gota_, külm, šći_,
  { {0x7d030039, 0x16aa0726, 0x395f001a, 0x00000000}},  //   mins, овни_, spus_,
  { {0x7d030142, 0x98a2001e, 0x7cef0637, 0x00000000}},  //   lins, ēkā_, _døre,
  { {0xb8e30055, 0xdce905fa, 0xba7401fa, 0x00000000}},  //   _এক_, _cveć, _سانت,
  { {0x58d401be, 0x7cef05ba, 0x6f022950, 0x00000000}},  //   _почт, _føre, zioc,
  { {0x7cef0030, 0x1543030d, 0x38650e69, 0x00000000}},  //   _gøre, терм, mblr_,
  { {0x3947009f, 0x7d032673, 0x99e30161, 0x00000000}},  //   _hins_, hins, žňuj,
  { {0x4536007c, 0xb1461c7b, 0x394700f6, 0x00000000}},  // [7480] _охот, днал, _kins_,
  { {0x26c90091, 0xb6060059, 0x39472951, 0x00000000}},  //   _znao_, rošč, _jins_,
  { {0x6f02037e, 0x7d030213, 0x4f7a007c, 0x00000000}},  //   tioc, dins, ющая_,
  { {0x6b98001c, 0x4ea3025f, 0x394700c4, 0x00000000}},  //   vtvg, врша, _lins_,
  { {0x291e01cf, 0x6f0221e7, 0x7d0300ea, 0x00000000}},  //   yota_, rioc, fins,
  { {0x7d030007, 0x6f020107, 0xdb0a0737, 0x00000000}},  //   gins, sioc, lvfø,
  { {0x291e0027, 0x612b006c, 0xe2080036, 0x00000000}},  //   vota_, külj, _wróć_,
  { {0x291e2952, 0x7cef08c8, 0x394706d2, 0x00000000}},  //   wota_, _røre, _ains_,
  { {0x60dc2953, 0x7d032954, 0x7cef0737, 0x00000000}},  //   _korm, bins, _søre,
  { {0x7d0307f9, 0xfbc6022a, 0x67240020, 0x00000000}},  //   cins, _обзо, _akij,
  { {0x60dc2955, 0x394704bd, 0xdce90166, 0x00000000}},  //   _morm, _dins_, _sveć,
  { {0x3947009f, 0x6d480169, 0xfbd3009b, 0x00000000}},  //   _eins_, _hida, _שתף_,
  { {0x394704bd, 0x291e0627, 0x6d480020, 0x00000000}},  //   _fins_, pota_, _kida,
  { {0x60dc049a, 0x6d480173, 0x22590009, 0x00000000}},  //   _norm, _jida, _sfsk_,
  { {0x6d480004, 0xdceb01d5, 0x98a3003b, 0x00000000}},  //   _mida, stgħ, _рије,
  { {0x69c20168, 0x612b2956, 0x6d482957, 0x00000000}},  //   _kroe, rülm, _lida,
  { {0x60dc0066, 0xde8f0011, 0x3329002d, 0x00000000}},  // [7490] _borm, hịch_, rlax_,
  { {0x60dc220d, 0x6d482958, 0x27320051, 0x00000000}},  //   _corm, _nida, mána_,
  { {0xdb1a15ab, 0x656d0022, 0x00000000, 0x00000000}},  //   _artí, _hwah,   ,
  { {0x80cd0061, 0x6d48006c, 0x7d030376, 0x00000000}},  //   साहे, _aida, wins,
  { {0x6d482959, 0x7d030091, 0x2d860093, 0x00000000}},  //   _bida, tins, groe_,
  { {0x6d481160, 0x60dc0016, 0x7c280343, 0x00000000}},  //   _cida, _gorm, _bydr,
  { {0x6d48033b, 0x75cb001c, 0x7c280016, 0x00000000}},  //   _dida, ामुळ, _cydr,
  { {0x764d006a, 0x7d030056, 0x69c2295a, 0x00000000}},  //   _ngay, sins, _broe,
  { {0x7d03023a, 0x69c2018e, 0x6d4828dc, 0x00000000}},  //   pins, _croe, _fida,
  { {0xe8f60604, 0x6d48295b, 0xf1b20097, 0x00000000}},  //   ель_, _gida, נסי_,
  { {0x78b80207, 0x3947295c, 0xd70600e2, 0x00000000}},  //   _davv, _vins_, езни,
  { {0x6d48002d, 0x656d011c, 0x39470aba, 0x00000000}},  //   _zida, _bwah, _wins_,
  { {0x69c2295d, 0x33200068, 0x7c28007f, 0x00000000}},  //   _groe, voix_, _zydr,
  { {0x7ae9250f, 0x6e290061, 0x399910cf, 0x00000000}},  //   lket, _myeb, mès_,
  { {0x3999295e, 0x29050091, 0x03a3007c, 0x00000000}},  //   lès_, mila_, лиро,
  { {0x7ae9002d, 0x29050091, 0x60dc1198, 0x00000000}},  //   nket, lila_, _sorm,
  { {0x656d018e, 0x3999295f, 0x60dc011c, 0x00000000}},  // [74a0] _gwah, nès_, _porm,
  { {0x2905006a, 0x4223072b, 0xb22300d7, 0x00000000}},  //   nila_, удув, умул,
  { {0x60dc224a, 0x7ae9002b, 0xd00f0025, 0x00000000}},  //   _vorm, kket, ملك_,
  { {0x6d48067e, 0x29050013, 0x6d5d002b, 0x00000000}},  //   _sida, hila_, _ħsar,
  { {0x6d482960, 0x2905015e, 0x60dc0c1b, 0x00000000}},  //   _pida, kila_, _torm,
  { {0xd3780091, 0x39991d81, 0xa91d2961, 0x00000000}},  //   šću_, dès_, buži,
  { {0x6d4801e2, 0x29050340, 0x3dd80055, 0x00000000}},  //   _vida, dila_, _দেখল,
  { {0x8f9b0452, 0x69c22962, 0xd00f00f9, 0x00000000}},  //   _מילי, _proe, _الف_,
  { {0x6d48020c, 0x2905238c, 0x6e930025, 0x00000000}},  //   _tida, fila_, _حلقا,
  { {0x69c20100, 0x2732093f, 0x7ae90032, 0x00000000}},  //   _vroe, vána_, aket,
  { {0x28d2013d, 0x656d03ef, 0xad1b01ce, 0x00000000}},  //   ताबि, _swah, _צובר,
  { {0x69c200b7, 0x7ae900ab, 0x399925bf, 0x00000000}},  //   _troe, cket, bès_,
  { {0x29050127, 0x3999028c, 0x48e6007c, 0x00000000}},  //   bila_, cès_, _подв,
  { {0x29050091, 0x7d010019, 0x00000000, 0x00000000}},  //   cila_, _xmls,   ,
  { {0xd7ef045e, 0xe3b0026c, 0x9f470161, 0x00000000}},  //   _су_, یرہ_, šné_,
  { {0x656d21a4, 0x212100e0, 0x00000000, 0x00000000}},  //   _twah, wohh_,   ,
  { {0x02e10316, 0x7f490afb, 0x656d21a4, 0x00000000}},  // [74b0] _नवीन, _rieq, _uwah,
  { {0x7ae9022b, 0x2d80002b, 0x25a90022, 0x00000000}},  //   zket, ġiel_, _ipal_,
  { {0x5f952963, 0x613000b0, 0x2d800027, 0x00000000}},  //   тиет, mäll, šiel_,
  { {0x290500ee, 0x6e2901aa, 0x399901aa, 0x00000000}},  //   zila_, _pyeb, yès_,
  { {0xb2760049, 0x6ab90146, 0xa3b901f5, 0x00000000}},  //   _בערג_, _rawf, चिक_,
  { {0x39992964, 0x25a900d4, 0x29050288, 0x00000000}},  //   vès_, _mpal_, xila_,
  { {0x290500ee, 0x7ae900b0, 0x6114005e, 0x00000000}},  //   vila_, tket, _сдру,
  { {0x63ba1e14, 0x39992965, 0x29052966, 0x00000000}},  //   ætni, tès_, wila_,
  { {0x29050119, 0x7ae90238, 0x6abb0146, 0x00000000}},  //   tila_, rket, rduf,
  { {0x3eaf2967, 0x39992968, 0x7ae90238, 0x00000000}},  //   legt_, rès_, sket,
  { {0x290500ee, 0x2d8f037e, 0x8ae70088, 0x00000000}},  //   rila_, luge_, _підл,
  { {0x29050091, 0xb8e8006e, 0x39992964, 0x00000000}},  //   sila_, _लो_, pès_,
  { {0xd7f8000d, 0x613003a9, 0x29050733, 0x00000000}},  //   ază_, fäll, pila_,
  { {0x7c240c4f, 0x00000000, 0x00000000, 0x00000000}},  //   şire,   ,   ,
  { {0x232a0072, 0xb4b203d7, 0xe29a2969, 0x00000000}},  //   дови_, _ऐसी_, мав_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d8f0521, 0xdddb001a, 0x9c7c0059, 0x00000000}},  // [74c0] juge_, _reuş, _hoče,
  { {0x9c7c296a, 0xf0630e82, 0xd059007e, 0x00000000}},  //   _koče, икуп, ерці_,
  { {0x2732013e, 0x9c7c00ca, 0x00000000, 0x00000000}},  //   náno_, _joče,   ,
  { {0x2d80001e, 0x2d8f062a, 0x69c40006, 0x00000000}},  //   šiem_, fuge_, _šiem,
  { {0x2d960072, 0x9c7c0059, 0x2cbc008e, 0x00000000}},  //   трес, _loče, tdvd_,
  { {0x79890ace, 0x645c005b, 0xed57003b, 0x00000000}},  //   drew, ncri, њој_,
  { {0x69dd010f, 0x6b9a0009, 0x09df0044, 0x00000000}},  //   äsen, _qqtg, _বেলা,
  { {0x273200b9, 0x64df013d, 0x501b009b, 0x00000000}},  //   dáno_, _नक्श, _חולו,
  { {0xbda50318, 0xc866030d, 0x00000000, 0x00000000}},  //   _محلو, ктни,   ,
  { {0x9c7c296b, 0x777a00ea, 0xd00f009e, 0x00000000}},  //   _boče, tstx, _الہ_,
  { {0x61300c4d, 0x00000000, 0x00000000, 0x00000000}},  //   väll,   ,   ,
  { {0x9c7c0091, 0x4bfb00b3, 0xcf93009b, 0x00000000}},  //   _doče, _קלאס, סטר_,
  { {0x61300073, 0xceb300a0, 0x5963005e, 0x00000000}},  //   täll, ביר_, _къща,
  { {0x89d70439, 0x27160089, 0x00000000, 0x00000000}},  //   _جوهر_, rāna_,   ,
  { {0x2458007e, 0x613020d6, 0x00000000, 0x00000000}},  //   тась_, räll,   ,
  { {0x32640d68, 0x6130021e, 0x3f5701d5, 0x00000000}},  //   итув, säll, _dħul_,
  { {0x645c0022, 0x00000000, 0x00000000, 0x00000000}},  // [74d0] bcri,   ,   ,
  { {0x2d8f0009, 0x3eaf01a2, 0x645e0026, 0x00000000}},  //   vuge_, wegt_, _gfpi,
  { {0x7cef0018, 0x00000000, 0x00000000, 0x00000000}},  //   _børn,   ,   ,
  { {0x97570104, 0x00000000, 0x00000000, 0x00000000}},  //   דיאו_,   ,   ,
  { {0x273200b9, 0x3eaf01a2, 0x2bc501f5, 0x00000000}},  //   záno_, regt_, विभा,
  { {0x2d8f016e, 0x3e710082, 0x00000000, 0x00000000}},  //   ruge_, ạt_,   ,
  { {0xeab10054, 0xc878005a, 0x7cf400d4, 0x00000000}},  //   معة_, dağ_, _bàrb,
  { {0x27320224, 0x798901d6, 0x00000000, 0x00000000}},  //   váno_, trew,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9c7c296c, 0xb4b203d7, 0x79890116, 0x00000000}},  //   _poče, _ऐसे_, rrew,
  { {0xd70a07d0, 0x81d90055, 0xc5e900a0, 0x00000000}},  //   енне_, ়নি_, _צד_,
  { {0x7c25010f, 0x7cf40129, 0x00000000, 0x00000000}},  //   ühru, _vàre,   ,
  { {0xc878005f, 0x98a50256, 0x645c1768, 0x00000000}},  //   bağ_, _биле, tcri,
  { {0x81d90044, 0xdc4300b9, 0x97c50188, 0x00000000}},  //   ়না_, _léči, _مقتو,
  { {0x833a17a4, 0x04570025, 0x29360049, 0x00000000}},  //   ечат_, الفة_, _גאסן_,
  { {0x645c032c, 0xa91d016e, 0x00000000, 0x00000000}},  //   scri, ružu,   ,
  { {0xf8b70061, 0x00000000, 0x00000000, 0x00000000}},  // [74e0] _असाय,   ,   ,
  { {0x45fb009b, 0x00000000, 0x00000000, 0x00000000}},  //   _נהיג,   ,   ,
  { {0x749b00b3, 0x90360245, 0x205502ea, 0x00000000}},  //   _אייפ, ухач, ртур,
  { {0x249a0085, 0x00000000, 0x00000000, 0x00000000}},  //   _hcpm_,   ,   ,
  { {0xf767009c, 0xc27b01f8, 0xfce6041f, 0x00000000}},  //   _گا_, _ארכי, лодо,
  { {0x65640020, 0x412a0088, 0x7cef00ea, 0x00000000}},  //   _mtih, _чого_, _døro,
  { {0xf76701f7, 0x249a0022, 0x00000000, 0x00000000}},  //   _دا_, _mcpm_,   ,
  { {0x62960232, 0x6466006b, 0x3af1296d, 0x00000000}},  //   ngyo, əriş, _pápa_,
  { {0x6130006c, 0x6564296e, 0x99830025, 0x00000000}},  //   välj, _ntih, مليو,
  { {0xdd8f004b, 0xc19b009b, 0x00000000, 0x00000000}},  //   _روم_, עשיי,   ,
  { {0x98c30a78, 0x656400e0, 0xd6d50783, 0x00000000}},  //   ссыл, _atih, ажны,
  { {0x7bc8296f, 0x00000000, 0x00000000, 0x00000000}},  //   _irdu,   ,   ,
  { {0x15a8005e, 0x7a7b01ce, 0x58d408fc, 0x00000000}},  //   лъри_, _טראס, _волт,
  { {0x61300039, 0x7d0a002b, 0x249a0026, 0x00000000}},  //   sälj, nifs, _ccpm_,
  { {0x7ae200b0, 0x15d800a1, 0x00000000, 0x00000000}},  //   _koot, نگیں_,   ,
  { {0x81ae0044, 0xc7ad00a1, 0x20070036, 0x00000000}},  //   কিন_, _کڑی_, źnik_,
  { {0x9f470224, 0x7ae20368, 0x612b2970, 0x00000000}},  // [74f0] ání_, _moot, kült,
  { {0x7bc8022b, 0x7ae2006c, 0x7cef00ea, 0x00000000}},  //   _ordu, _loot, _røro,
  { {0x9f470802, 0x53350069, 0x7cef0374, 0x00000000}},  //   šní_, _вент, _søro,
  { {0x7ae2015b, 0x00000000, 0x00000000, 0x00000000}},  //   _noot,   ,   ,
  { {0x7bc8022b, 0x127a0049, 0x427a0104, 0x00000000}},  //   _ardu, _בארע, _בארג,
  { {0x81bc0044, 0x394e002b, 0x2cbe00f6, 0x00000000}},  //   _অথচ_, _nifs_, _catd_,
  { {0x2bc502d2, 0x4c92003b, 0x00000000, 0x00000000}},  //   विधा, цијс,   ,
  { {0x80c90204, 0x00000000, 0x00000000, 0x00000000}},  //   _होते,   ,   ,
  { {0x88d5008b, 0x7ae20288, 0x00000000, 0x00000000}},  //   аўні, _doot,   ,
  { {0x3ebf2971, 0xa85500ec, 0xfd130688, 0x00000000}},  //   _haut_, штиј, _اجر_,
  { {0x3ebf001e, 0x7ae215a4, 0x65640466, 0x00000000}},  //   _kaut_, _foot, _stih,
  { {0x7ae2044e, 0xdb0100d4, 0x00000000, 0x00000000}},  //   _goot, _eslò,   ,
  { {0x99670920, 0x3ebf01a3, 0xdce20161, 0x00000000}},  //   _стел, _maut_, zpoč,
  { {0x3ebf2972, 0xdb010048, 0x81ae0044, 0x00000000}},  //   _laut_, _tsló, কিম_,
  { {0xed590c1e, 0x0446007c, 0x68e32973, 0x00000000}},  //   _drži_, ревн, _iond,
  { {0x160103d7, 0xe355008b, 0xa91d055a, 0x00000000}},  //   _लेकर_, стрэ, drži,
  { {0x68e32974, 0x8be90055, 0x26d2006a, 0x00000000}},  // [7500] _kond, _কেমন_, _inyo_,
  { {0x68e30052, 0x26c00085, 0x7cef0146, 0x00000000}},  //   _jond, _haio_, _børm,
  { {0x68e32975, 0x2d9f19bf, 0x3ebf2976, 0x00000000}},  //   _mond, _aque_, _baut_,
  { {0xbea607d0, 0x26c0002d, 0x3ebf001a, 0x00000000}},  //   радк, _jaio_, _caut_,
  { {0x26c01160, 0x8236007a, 0x7ae20114, 0x00000000}},  //   _maio_, _خردا, _root,
  { {0x68e3002d, 0x6b810253, 0x7ae20114, 0x00000000}},  //   _nond, _bvlg, _soot,
  { {0x3ebf028c, 0x7d0a000c, 0x26d20020, 0x00000000}},  //   _faut_, rifs, _onyo_,
  { {0xbab8007c, 0x9c7c2977, 0x68e32978, 0x00000000}},  //   угих_, _doča, _aond,
  { {0x68e30607, 0xdcfb0091, 0xbb470025, 0x00000000}},  //   _bond, _zvuč, جلين_,
  { {0x26d2011c, 0x7ae20908, 0x7d0d0048, 0x00000000}},  //   _anyo_, _woot, éast,
  { {0x68e30219, 0x7ae20004, 0x26c0049a, 0x00000000}},  //   _dond, _toot, _baio_,
  { {0x6d4f00f4, 0x26c02979, 0x7c3a0b2e, 0x00000000}},  //   _écar, _caio_, _iztr,
  { {0x6f0304bd, 0x443a0032, 0x26c5013e, 0x00000000}},  //   ènci, _azp_, ělo_,
  { {0x68e30047, 0x2bbd02f4, 0xd9431376, 0x00000000}},  //   _gond, ्मचा, _дечи,
  { {0x290c0489, 0x38cb0123, 0x00000000, 0x00000000}},  //   mida_, _جانی_,   ,
  { {0x68e302ae, 0x290c20c1, 0x8c1b00b3, 0x00000000}},  //   _zond, lida_, דולי,
  { {0x6d43297a, 0xdddb0091, 0xdcfb016c, 0x00000000}},  // [7510] ymna, _oduš, _svuč,
  { {0x26c0002d, 0x3ebf009d, 0xdb1800f8, 0x00000000}},  //   _zaio_, _saut_, lvvä,
  { {0x9028008b, 0x8319221c, 0xf7730049, 0x00000000}},  //   ацца_, _مقدر_, ַקס_,
  { {0x290c297b, 0x8f6a00a1, 0x9c7c00ca, 0x00000000}},  //   hida_, النے_, _roča,
  { {0x3ebf00f4, 0xa28200a1, 0x9c7c089f, 0x00000000}},  //   _vaut_, _ریلو, _soča,
  { {0x9c7c0027, 0x00000000, 0x00000000, 0x00000000}},  //   _poča,   ,   ,
  { {0x68e30168, 0x3b090902, 0x290c0325, 0x00000000}},  //   _rond, леко_, dida_,
  { {0x68e307f8, 0xfbd000b8, 0x61300b3e, 0x00000000}},  //   _sond, بته_, väli,
  { {0x68e30161, 0x290c01eb, 0x26c000c4, 0x00000000}},  //   _pond, fida_, _raio_,
  { {0x290c0919, 0xe8f61001, 0x672d0020, 0x00000000}},  //   gida_, йлы_, _akaj,
  { {0xfbd00054, 0x68e30056, 0x26c00207, 0x00000000}},  //   _يتم_, _vond, _paio_,
  { {0x81ae0055, 0x68e30b8d, 0x61ed297c, 0x00000000}},  //   কিত_, _wond, kyal,
  { {0x9c7c0059, 0x26c00011, 0x00000000, 0x00000000}},  //   _močn, _vaio_,   ,
  { {0x290c029d, 0x69cb001f, 0x68fa07eb, 0x00000000}},  //   cida_, _irge, chtd,
  { {0xf7461123, 0x26c0297d, 0xa8a400e2, 0x00000000}},  //   _леко, _taio_, _фрчк,
  { {0x9c7c1e34, 0x61e20cba, 0x7cef0190, 0x00000000}},  //   _nočn, äolo, _børk,
  { {0x61ed0010, 0xd5b10082, 0x00000000, 0x00000000}},  // [7520] gyal, ắc_,   ,
  { {0x205608fd, 0xdb1a0129, 0x6f090020, 0x00000000}},  //   стар, _estè, _amec,
  { {0x9c7c0161, 0x287a0049, 0xa3ba0879, 0x00000000}},  //   _bočn, רנעמ, _صادر_,
  { {0x290c297e, 0x6e930025, 0x69cb0c7a, 0x00000000}},  //   zida_, كلما, _orge,
  { {0x7d1a0009, 0x7c3a0010, 0x00000000, 0x00000000}},  //   _pjts, _sztr,   ,
  { {0x290c049a, 0xa3cc006e, 0x2ee401c3, 0x00000000}},  //   xida_, लिप_, _womf_,
  { {0x69cb1ff4, 0x290c0181, 0xef1a00d7, 0x00000000}},  //   _arge, vida_, _бмв_,
  { {0xbf1601d8, 0x7c3a0059, 0x7d0d0048, 0x00000000}},  //   _اورب, _vztr, éasr,
  { {0x290c2888, 0x00000000, 0x00000000, 0x00000000}},  //   tida_,   ,   ,
  { {0x672d0023, 0x41bb0049, 0x3ce500f8, 0x00000000}},  //   _skaj, נציע, _golv_,
  { {0xda6f008b, 0x69cb001f, 0x290c0114, 0x00000000}},  //   _ня_, _erge, rida_,
  { {0x290c0bf3, 0x7afb001f, 0xdc3b007b, 0x00000000}},  //   sida_, chut, _געבר,
  { {0xeb14013d, 0xfa360151, 0x69cb016c, 0x00000000}},  //   तचीत_, _اراد, _grge,
  { {0xa99b009b, 0x81de0044, 0x00000000, 0x00000000}},  //   _עבור, তনা_,   ,
  { {0xdb1a009d, 0x387e0026, 0x7cef0374, 0x00000000}},  //   _asté, matr_, _sørk,
  { {0x61ed01aa, 0x672d00e7, 0xc9090044, 0x00000000}},  //   tyal, _ukaj, রকৃত_,
  { {0x9c7c297f, 0x7cef043e, 0x00000000, 0x00000000}},  // [7530] _ročn, _førh,   ,
  { {0x61ed2980, 0x6f091140, 0x46a5007d, 0x00000000}},  //   ryal, _smec, ग्रह,
  { {0x9c7c0209, 0xdb1a0325, 0x61ed09e5, 0x00000000}},  //   _počn, _esté, syal,
  { {0x7cef05b7, 0x61ed014a, 0x3e7d0006, 0x00000000}},  //   _tørk, pyal, kštų_,
  { {0x7cef0030, 0x2cac167b, 0x44210082, 0x00000000}},  //   _høri, _bbdd_, _hxh_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x09d1001c, 0x9c7c02db, 0x7afb2981, 0x00000000}},  //   तम्य, _točn, thut,
  { {0x7e620026, 0x6f092982, 0x69db0032, 0x00000000}},  //   ccop, _umec, txue,
  { {0xe8f9013b, 0x3ce52983, 0x443300f8, 0x00000000}},  //   или_, _tolv_, _lyx_,
  { {0x7afb0020, 0x77850467, 0xa3cc007d, 0x00000000}},  //   shut, олоз, लिम_,
  { {0xf092019b, 0x60c50051, 0xf7460088, 0x00000000}},  //   וני_, idhm, жено,
  { {0x6d5b2984, 0x3dcd22df, 0x6f190016, 0x00000000}},  //   _kuua, _krew_, nnwc,
  { {0x69cb1954, 0x7c2d005a, 0x3ead0023, 0x00000000}},  //   _urge, şard, _mbet_,
  { {0x2a7f010f, 0x1869041f, 0x6d5b2985, 0x00000000}},  //   laub_, _таки_, _muua,
  { {0x69c91263, 0x09df0044, 0x6d411c91, 0x00000000}},  //   lvee, _বেচা, _mhla,
  { {0xf26a0242, 0x6130010f, 0xb5fb2986, 0x00000000}},  //   риал_, hält, rbár,
  { {0x69c900bb, 0xb5fb16b8, 0xc05a19d4, 0x00000000}},  // [7540] nvee, lcán, арец_,
  { {0xe0d701fb, 0x61300c4d, 0x3ead0058, 0x00000000}},  //   ову_, jält, _abet_,
  { {0x14d7007b, 0x09b60309, 0x00000000, 0x00000000}},  //   _וויל_, _अन्य,   ,
  { {0x3dcd0719, 0x6d41014a, 0x2d8400f6, 0x00000000}},  //   _brew_, _ahla, _pvme_,
  { {0x6d26007e, 0x6d410051, 0x613003a9, 0x00000000}},  //   оддз, _bhla, fält,
  { {0x6d410428, 0x7e620585, 0xc5f3009b, 0x00000000}},  //   _chla, scop, ודד_,
  { {0x69c90277, 0x00000000, 0x00000000, 0x00000000}},  //   evee,   ,   ,
  { {0x7e7b095d, 0x00000000, 0x00000000, 0x00000000}},  //   _geup,   ,   ,
  { {0xaaa60309, 0x3dcd0133, 0xf1bf0010, 0x00000000}},  //   क्षक, _grew_, _száz_,
  { {0x6d41002a, 0x97a6004c, 0x2d800e3f, 0x00000000}},  //   _ghla, ормл, šies_,
  { {0xfaa600e2, 0x7cfd00f6, 0xe0b7009b, 0x00000000}},  //   _мажо, _sèrg, חליט_,
  { {0xb5e60044, 0x7cfd00f6, 0xf76f0014, 0x00000000}},  //   _পেইচ, _pèrg, کای_,
  { {0xe3b80279, 0x6b550006, 0x7cef00ea, 0x00000000}},  //   çın_, _išga, _søri,
  { {0x4aa602fb, 0x7c2d2987, 0x00000000, 0x00000000}},  //   क्रव, şare,   ,
  { {0xd7e601ff, 0x613003a2, 0x69dd01b1, 0x00000000}},  //   _філо, häls, äsev,
  { {0xd055013f, 0x9c7c00ca, 0x00000000, 0x00000000}},  //   əbəl, _sočl,   ,
  { {0x67ff0010, 0x7e7b0471, 0x60f90641, 0x00000000}},  // [7550] _tájé, _reup, бная_,
  { {0xd1310445, 0x7f5c0957, 0x306b0143, 0x00000000}},  //   رما_, _burq, рјан_,
  { {0x7415004b, 0x7e7b00f4, 0x44270011, 0x00000000}},  //   _روحا, _peup, _ân_,
  { {0xf8b7013d, 0x7cfd009d, 0x6130010f, 0x00000000}},  //   _अस्प, _mère, wält,
  { {0x3ead1ac6, 0xbdf80025, 0x6d410fb8, 0x00000000}},  //   _vbet_, يرها_, _phla,
  { {0x3ac70082, 0x27160089, 0x7cf400d4, 0x00000000}},  //   _ốp_, rāni_, _fàrm,
  { {0x415400ed, 0x22590085, 0x3dcd0066, 0x00000000}},  //   _цврс, _kgsk_, _wrew_,
  { {0x6130021e, 0xa3cc006e, 0x81ae0044, 0x00000000}},  //   sält, लित_, কির_,
  { {0xf9910025, 0xdd9103ab, 0xc334009b, 0x00000000}},  //   ربة_, _سوا_, ווק_,
  { {0xe8f90242, 0x3d940069, 0x48050088, 0x00000000}},  //   сло_, _цифр, зпов,
  { {0xf092007b, 0xccf200b6, 0x69c92988, 0x00000000}},  //   ענט_, _רכב_, svee,
  { {0xa25b009d, 0xd5b10082, 0x9c7c0087, 0x00000000}},  //   _saôn, ắn_, _nočj,
  { {0xcb1200b6, 0xb5fb10c9, 0x00000000, 0x00000000}},  //   _אלא_, scán,   ,
  { {0x26c4220f, 0x00000000, 0x00000000, 0x00000000}},  //   žmo_,   ,   ,
  { {0xfdb80309, 0xa50701ab, 0x395d005b, 0x00000000}},  //   _इन्फ, чера_, _huws_,
  { {0x877a0049, 0x00000000, 0x00000000, 0x00000000}},  //   _פאפי,   ,   ,
  { {0xe717009b, 0xc6930049, 0xa7fc026d, 0x00000000}},  // [7560] _מחקר_, _נאז_, ncın,
  { {0x7bc104eb, 0x00000000, 0x00000000, 0x00000000}},  //   _oslu,   ,   ,
  { {0x4abd0201, 0xaabd0201, 0x5477009b, 0x00000000}},  //   ्याव, ्याक, _מגיע_,
  { {0x794d0036, 0x81bb0044, 0x00000000, 0x00000000}},  //   _dźwi, _অপর_,   ,
  { {0x237f0091, 0x46dd0061, 0x200701e5, 0x00000000}},  //   ćuje_, यातह, únir_,
  { {0x7f5c0065, 0xd1320025, 0xd7db0061, 0x00000000}},  //   _turq, _أمس_, यमाच,
  { {0x60230265, 0x00000000, 0x00000000, 0x00000000}},  //   _здра,   ,   ,
  { {0xada601e0, 0x37d10044, 0x9c7c0802, 0x00000000}},  //   _набл, াহার, _kočk,
  { {0x7cef068f, 0xd7f80035, 0x3f9a0471, 0x00000000}},  //   _rørv, rcăm_, lupu_,
  { {0x7cfd009d, 0xfcaa0014, 0x7cef2989, 0x00000000}},  //   _père, _دارو_, _sørv,
  { {0x5695007e, 0x00000000, 0x00000000, 0x00000000}},  //   мант,   ,   ,
  { {0x2732049a, 0x7bdb009b, 0x00000000, 0x00000000}},  //   dáns_, _לקבו,   ,
  { {0x6d4a00d4, 0x9c7c0087, 0x00000000, 0x00000000}},  //   omfa, _nočk,   ,
  { {0x48e309de, 0x7cef0146, 0x00000000, 0x00000000}},  //   _почв, _føru,   ,
  { {0x7cfd00f6, 0xf3f30025, 0x00000000, 0x00000000}},  //   _hèrc, رأس_,   ,
  { {0x78ba0047, 0xf4080025, 0x7cef08c8, 0x00000000}},  //   letv, سيقى_, _hørt,
  { {0x442d0046, 0x672f0036, 0x7cef0030, 0x00000000}},  // [7570] łe_, mocj, _kørt,
  { {0x51f80147, 0x78ba0190, 0x656d00e7, 0x00000000}},  //   чную_, netv, _itah,
  { {0x8fb90025, 0x656d01f3, 0xdb0304bb, 0x00000000}},  //   تهاء_, _htah, stné,
  { {0x644300d4, 0x8db5007e, 0xff040088, 0x00000000}},  //   _úniq, дскі, нячн,
  { {0xddab0517, 0x00000000, 0x00000000, 0x00000000}},  //   стел_,   ,   ,
  { {0x98a50089, 0x7cfd00d4, 0x11da00b3, 0x00000000}},  //   kolā_, _sèrb, _וחשב,
  { {0xdb1a1343, 0x00000000, 0x00000000, 0x00000000}},  //   _estí,   ,   ,
  { {0x6b88004a, 0x2b5e004a, 0x7bc100ea, 0x00000000}},  //   _dvdg, _dutc_, _vslu,
  { {0xceb20452, 0x656d298a, 0x7cfd00f6, 0x00000000}},  //   _בין_, _ntah, _cèrc,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bc10213, 0xdb010030, 0xb5fb0051, 0x00000000}},  //   _uslu, _oplø, scál,
  { {0xa3cc0164, 0x60c7008d, 0x672f0770, 0x00000000}},  //   लिस_, _lajm, gocj,
  { {0x2bc501f5, 0x443c0006, 0x7cef043e, 0x00000000}},  //   विका, _šv_, _ført,
  { {0x60c70027, 0x7aeb098e, 0x613000f8, 0x00000000}},  //   _najm, _hogt, jälp,
  { {0xa7fc014a, 0x7cef0030, 0x656d0022, 0x00000000}},  //   ncıl, _hørs, _etah,
  { {0x7cef0030, 0x656d01f3, 0x7cf400f6, 0x00000000}},  //   _kørs, _ftah, _pàrk,
  { {0x045a0025, 0xdb1a005b, 0x00000000, 0x00000000}},  // [7580] _وجدت_, _ystâ,   ,
  { {0x3f9a298b, 0x61eb00f8, 0x27160089, 0x00000000}},  //   tupu_, ägla, rānu_,
  { {0x60c70253, 0xd12f0025, 0xdee600e2, 0x00000000}},  //   _dajm, جمل_, можи,
  { {0x9c7c2794, 0xee3a02b8, 0x7aeb01d6, 0x00000000}},  //   _točk, оне_, _nogt,
  { {0x62840032, 0x00000000, 0x00000000, 0x00000000}},  //   maio,   ,   ,
  { {0x9c7c040d, 0x6d4a007f, 0x3f9a01a3, 0x00000000}},  //   _koči, umfa, pupu_,
  { {0x7aeb0a9d, 0x9c7c012d, 0x78ba298c, 0x00000000}},  //   _bogt, _joči, vetv,
  { {0x60c70036, 0x7cef05b7, 0x9c7c03c9, 0x00000000}},  //   _zajm, _børs, _moči,
  { {0x7aeb0007, 0x9c7c0059, 0x7c2d019a, 0x00000000}},  //   _dogt, _loči, ğara,
  { {0x2004006b, 0x7c2d005a, 0x9404006b, 0x00000000}},  //   _əmin_, şara, şmə_,
  { {0x656d059c, 0x78ba0091, 0x78a30009, 0x00000000}},  //   _stah, retv, _dcnv,
  { {0x7cef02cc, 0x3cfe0048, 0x69c201d6, 0x00000000}},  //   _førs, _hltv_, _tsoe,
  { {0xdb1a02d5, 0x77920063, 0x628428dc, 0x00000000}},  //   _estã, ریکا, daio,
  { {0x9f470051, 0x9c7c01ed, 0x2ee606ec, 0x00000000}},  //   ánú_, _boči, hjof_,
  { {0x7cf400d4, 0x291e00e0, 0x2b460082, 0x00000000}},  //   _càri, mnta_, _khoc_,
  { {0x60c70091, 0x628400fa, 0x00000000, 0x00000000}},  //   _sajm, gaio,   ,
  { {0x291e0048, 0x656d298d, 0x00000000, 0x00000000}},  // [7590] onta_, _utah,   ,
  { {0x2724005d, 0x291e22ce, 0xa3cc006e, 0x00000000}},  //   mına_, nnta_, लिश_,
  { {0x291e298e, 0x6f020051, 0x27240279, 0x00000000}},  //   inta_, fhoc, lına_,
  { {0x7cef0030, 0x2b460082, 0x48150049, 0x00000000}},  //   _nørr, _nhoc_, ײַען_,
  { {0x2724005d, 0x2cae0009, 0x6b450325, 0x00000000}},  //   nına_, fffd_, nóge,
  { {0x908700a1, 0x7cef1565, 0xde4600a1, 0x00000000}},  //   _زمرے_, _rørs, ریلو_,
  { {0xeb99004c, 0x7cef00ea, 0xa1580c27, 0x00000000}},  //   чий_, _sørs, _цару_,
  { {0x291e0036, 0x6f020258, 0x2b4611b1, 0x00000000}},  //   enta_, choc, _choc_,
  { {0x628f0009, 0x7aeb0be1, 0x2724014a, 0x00000000}},  //   _mdco, _vogt, jına_,
  { {0x2eed00c7, 0xdb1a0129, 0x78a9003b, 0x00000000}},  //   _hoef_, _està, чког_,
  { {0xe73a00e3, 0x2d9d00bb, 0x2eed16c5, 0x00000000}},  //   зен_, luwe_, _koef_,
  { {0x291e002a, 0x27240180, 0x3af80010, 0x00000000}},  //   anta_, fına_, _lépj_,
  { {0xe3b100a1, 0xdb0301dc, 0x2d9d298f, 0x00000000}},  //   یرِ_, ntní, nuwe_,
  { {0x9c7c0340, 0xb0ce03d7, 0x628f0253, 0x00000000}},  //   _poči, _होंग, _adco,
  { {0xb6020224, 0x62840032, 0x79890168, 0x00000000}},  //   _žádn, taio, lsew,
  { {0x27240180, 0x35a60216, 0x27f80637, 0x00000000}},  //   bına_, _заиг, ørne_,
  { {0x409601e0, 0x79892990, 0x62840032, 0x00000000}},  // [75a0] ерет, nsew, raio,
  { {0x9c7c05d2, 0x628400c4, 0x7cf400f6, 0x00000000}},  //   _toči, saio, _tàri,
  { {0x6f020678, 0x62840197, 0x9c7c0166, 0x00000000}},  //   thoc, paio, _uoči,
  { {0x44440213, 0xeda60b81, 0xa856009b, 0x00000000}},  //   _iz_, ешко, גיעה_,
  { {0x4444014a, 0x2d9d0009, 0x64410089, 0x00000000}},  //   _hz_, guwe_, ļlie,
  { {0x444400ca, 0x6f020e93, 0x6441002b, 0x00000000}},  //   _kz_, shoc, żlie,
  { {0x44440087, 0x504304cf, 0x2724005d, 0x00000000}},  //   _jz_, _берб, zına_,
  { {0x44440142, 0x6e961095, 0xe6ca013d, 0x00000000}},  //   _mz_, _سلطا, ियोज,
  { {0x25660016, 0x443a2595, 0x00000000, 0x00000000}},  //   _nôl_, _lyp_,   ,
  { {0xf2df00ad, 0x444401d9, 0x291e0197, 0x00000000}},  //   _nhân_, _oz_, unta_,
  { {0xdb1a2991, 0x80ca0044, 0x76442992, 0x00000000}},  //   _está, রাপ্, _aziy,
  { {0x2724038c, 0x6d5a04cb, 0xdbc7006c, 0x00000000}},  //   tına_, _hita, _pöör,
  { {0x44441bc0, 0x7c3a0016, 0x443a2993, 0x00000000}},  //   _az_, _hytr, _ayp_,
  { {0x2724038c, 0xf2df001d, 0x4444013f, 0x00000000}},  //   rına_, _chân_, _bz_,
  { {0x6d5a097e, 0x4444101c, 0x2724038c, 0x00000000}},  //   _mita, _cz_, sına_,
  { {0x6d5a0020, 0x083b00b6, 0x44440036, 0x00000000}},  //   _lita, _מעול, _dz_,
  { {0x44442994, 0x325502a8, 0x80ca0055, 0x00000000}},  // [75b0] _ez_, твар, রান্,
  { {0x6d5a000b, 0x44442995, 0x673d074d, 0x00000000}},  //   _nita, _fz_, llsj,
  { {0x44440c8a, 0x628f0991, 0x8af7006b, 0x00000000}},  //   _gz_, _tdco, _şəmk,
  { {0x6d5a24c3, 0x3ee4005e, 0x2d9d00d9, 0x00000000}},  //   _aita, лючв, tuwe_,
  { {0x6d5a022b, 0x444401c5, 0xa2a603d7, 0x00000000}},  //   _bita, _zz_, _छात्,
  { {0x2d9d0020, 0xdb03013e, 0x2eed01c3, 0x00000000}},  //   ruwe_, rtní, _woef_,
  { {0x6d5a0149, 0xdb03004f, 0xed0500a1, 0x00000000}},  //   _dita, stní, _یورپ,
  { {0xe9d90735, 0x8e840025, 0x6d5a006c, 0x00000000}},  //   дки_, _ملفه, _eita,
  { {0x6d5a2996, 0x2b4d2997, 0x79890009, 0x00000000}},  //   _fita, rmec_, usew,
  { {0x25660016, 0xd945003b, 0x67360085, 0x00000000}},  //   _rôl_, ђени, _skyj,
  { {0x79892998, 0x7cf400f6, 0x7d0101e5, 0x00000000}},  //   ssew, _pàrv, _ills,
  { {0x6d5a2999, 0x444400b4, 0x443a299a, 0x00000000}},  //   _zita, _rz_, _ryp_,
  { {0x44440010, 0xf2df001d, 0x7ae9299b, 0x00000000}},  //   _sz_, _phân_, mjet,
  { {0x7ae9045e, 0x81e70055, 0x44440142, 0x00000000}},  //   ljet, বনা_, _pz_,
  { {0x28a6024c, 0x29050033, 0x3f870035, 0x00000000}},  //   _खाति, mhla_, ânul_,
  { {0x44440dc6, 0x61e40ec8, 0x7ae90091, 0x00000000}},  //   _vz_, txil, njet,
  { {0xf2df001d, 0x4444013e, 0x7d010051, 0x00000000}},  // [75c0] _thân_, _wz_, _olls,
  { {0x443a0410, 0x4444000b, 0x42550679, 0x00000000}},  //   _typ_, _tz_, утст,
  { {0x44440580, 0x6d5a299c, 0xb0d703d7, 0x00000000}},  //   _uz_, _rita, ठाजग,
  { {0x6d5a006b, 0x7d01299d, 0x7f490285, 0x00000000}},  //   _sita, _alls, _cheq,
  { {0x6d5a01cd, 0x7ae9299e, 0x6e3b0009, 0x00000000}},  //   _pita, djet, _cyub,
  { {0xb5fb0010, 0x656400b0, 0x1d330245, 0x00000000}},  //   tbáz, _muih, анія,
  { {0x6d5a1844, 0x9fc70081, 0xb5fb0051, 0x00000000}},  //   _vita, _игра_, rcái,
  { {0x6d5a0046, 0xab2701f9, 0xb5fb002a, 0x00000000}},  //   _wita, која_, scái,
  { {0x7c3a0036, 0x973d016c, 0x9c7c00ca, 0x00000000}},  //   _wytr, nuće, _soču,
  { {0x6d5a000d, 0x7afb0b1b, 0x9c7c0465, 0x00000000}},  //   _uita, akut, _poču,
  { {0xa09b007b, 0x2739299f, 0x7ae90b33, 0x00000000}},  //   וייט, ként_, bjet,
  { {0x7ae90066, 0x7d1800f8, 0x00000000, 0x00000000}},  //   cjet, livs,   ,
  { {0x973d0091, 0xceb30049, 0x29050048, 0x00000000}},  //   juće, סיש_, bhla_,
  { {0x29050142, 0x973d04eb, 0x00000000, 0x00000000}},  //   chla_, duće,   ,
  { {0xd7ef012b, 0x9388017f, 0xb607000c, 0x00000000}},  //   _ту_, кста_, _bráð,
  { {0x7d18021c, 0x00000000, 0x00000000, 0x00000000}},  //   hivs,   ,   ,
  { {0x45d501f9, 0xdb1a0039, 0x973d0091, 0x00000000}},  // [75d0] _сопс, _istä, guće,
  { {0xc7ad026c, 0x7f490065, 0x27390062, 0x00000000}},  //   _بڑی_, _sheq, rénu_,
  { {0x7535002b, 0x64450521, 0x6e3b008a, 0x00000000}},  //   mozz, _uzhi, _syub,
  { {0x753503f1, 0x395c032e, 0xf2df0082, 0x00000000}},  //   lozz, _livs_, _khâm_,
  { {0x3da70265, 0x41e4008b, 0x7ae90209, 0x00000000}},  //   треб, _кіра, vjet,
  { {0x4035034b, 0x6b550006, 0x7ae929a0, 0x00000000}},  //   _бегс, _išgi, wjet,
  { {0x7ae90d00, 0xa3cc03d7, 0x4fc4007c, 0x00000000}},  //   tjet, लिए_, _кста,
  { {0x49c929a1, 0x00000000, 0x00000000, 0x00000000}},  //   елин_,   ,   ,
  { {0x7ae91cec, 0x9c7c0161, 0x7cf400f6, 0x00000000}},  //   rjet, _počt, _càrs,
  { {0x7afb010a, 0x7ae90209, 0x776300d4, 0x00000000}},  //   skut, sjet, _punx,
  { {0x395c0c3f, 0x7ae929a2, 0x656400b0, 0x00000000}},  //   _divs_, pjet, _suih,
  { {0x29050107, 0x6f190016, 0x7aa40088, 0x00000000}},  //   shla_, niwc, _виїз,
  { {0xf2df0011, 0x80ca0044, 0x7cf400f6, 0x00000000}},  //   _châm_, রাত্, _tàrt,
  { {0x950600a1, 0xc9920025, 0x75350197, 0x00000000}},  //   اہدے_, _الوظ, gozz,
  { {0x65640022, 0xf2df005b, 0x00000000, 0x00000000}},  //   _wuih, _thâl_,   ,
  { {0x3169006b, 0xdd8500a1, 0x395c01c5, 0x00000000}},  //   fqaz_, _وڈ_, _zivs_,
  { {0x91e30113, 0x6f190016, 0x98ac0089, 0x00000000}},  // [75e0] боте, diwc, lodā_,
  { {0x26c2119a, 0x27390181, 0x5156041f, 0x00000000}},  //   leko_, béns_, утбу,
  { {0xdb1a021e, 0x6f190016, 0x7648006b, 0x00000000}},  //   _ystä, fiwc, ədya,
  { {0x26c2022b, 0x6e460014, 0x973d04eb, 0x00000000}},  //   neko_, هنام, puće,
  { {0xa3cc02d2, 0x7d1804d3, 0x628601c5, 0x00000000}},  //   लिक_, tivs, _ieko,
  { {0x26c2002d, 0x6b81005b, 0x00000000, 0x00000000}},  //   heko_, _bwlg,   ,
  { {0x26c2002d, 0x628601a3, 0x7d1800f8, 0x00000000}},  //   keko_, _keko, rivs,
  { {0x7cf404bd, 0x6f190696, 0x62860173, 0x00000000}},  //   _càrr, ciwc, _jeko,
  { {0x26c2022b, 0xbef700b6, 0xd90d00a1, 0x00000000}},  //   deko_, _עצמו_, ڈین_,
  { {0x57b40d03, 0x62861397, 0xd90d00a6, 0x00000000}},  //   абот, _leko, وین_,
  { {0xeb971376, 0x3942001e, 0xdb030161, 0x00000000}},  //   _бих_, ēks_, stná,
  { {0x62860119, 0x26c21786, 0x3ea60b5a, 0x00000000}},  //   _neko, geko_, ngot_,
  { {0xf2df0011, 0x00000000, 0x00000000, 0x00000000}},  //   _giây_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x62861359, 0x753529a3, 0x26c2002d, 0x00000000}},  //   _beko, rozz, beko_,
  { {0x41e70245, 0xf2df0011, 0x80a7006e, 0x00000000}},  //   ліза, _thâm_, _चाहे,
  { {0x628629a4, 0x161c007d, 0x925900ed, 0x00000000}},  // [75f0] _deko, _पेपर_, таат_,
  { {0x1007007c, 0x7cfd000a, 0x00000000, 0x00000000}},  //   ляем, _pèrm,   ,
  { {0x155a009b, 0x997600b4, 0x00000000, 0x00000000}},  //   _שכתב, nęły_,   ,
  { {0x62862295, 0xa26402dc, 0xa77b01ce, 0x00000000}},  //   _geko, _гърл, גראפ,
  { {0x6f190016, 0x80d00061, 0x00000000, 0x00000000}},  //   riwc, _डोके,   ,
  { {0x26c2022b, 0xeb9900ed, 0xe3b00167, 0x00000000}},  //   zeko_, вик_, _بری_,
  { {0x1d06005e, 0x62860045, 0x26c200e7, 0x00000000}},  //   рещи_, _yeko, yeko_,
  { {0xdab9007e, 0x26c2002d, 0x2418009b, 0x00000000}},  //   тыкі_, xeko_, טחון_,
  { {0x6ca706b4, 0x31af01df, 0x09050088, 0x00000000}},  //   _مصال, nüz_, ипин,
  { {0xbc680054, 0x29030047, 0x6b451261, 0x00000000}},  //   _ممكن_, ója_, cógn,
  { {0x26c20756, 0x7b17001a, 0x7cf40129, 0x00000000}},  //   teko_, lţum, _tàrr,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd8f5007a, 0x26c2022b, 0x38ca0014, 0x00000000}},  //   _پزشک, reko_, رایی_,
  { {0x6286020c, 0x26c2002d, 0x64a601fc, 0x00000000}},  //   _seko, seko_, јава,
  { {0x07a501e0, 0x26c2002d, 0x62861d9c, 0x00000000}},  //   _тайн, peko_, _peko,
  { {0x0566034b, 0x69d90d13, 0x973d012d, 0x00000000}},  //   _квин, _krwe, rućc,
  { {0x62860255, 0x00000000, 0x00000000, 0x00000000}},  // [7600] _veko,   ,   ,
  { {0xe04601fc, 0xb05a0025, 0xdb03006c, 0x00000000}},  //   анзи, نشاط_, ltnä,
  { {0x62862001, 0xc05901fb, 0x9e66132e, 0x00000000}},  //   _teko, гії_, авед,
  { {0xf9870558, 0x69d9005b, 0x88bc00b9, 0x00000000}},  //   _وب_, _orwe, jněn,
  { {0x3ea600ab, 0x88bc00b9, 0x7b170035, 0x00000000}},  //   rgot_, dněn, rţul,
  { {0x80ca0055, 0x7cf400d4, 0x3ea6011c, 0x00000000}},  //   রাহ্, _pàrq, sgot_,
  { {0x69d9018e, 0xb5fb0181, 0x69cb1506, 0x00000000}},  //   _arwe, ncár, _asge,
  { {0xbea3008b, 0x539b0104, 0x00000000, 0x00000000}},  //   _маск, דיקו,   ,
  { {0x6c96067a, 0x5ca600e2, 0x38c80014, 0x00000000}},  //   _نشاط, _визб, هادی_,
  { {0x7f421003, 0xd90e0167, 0x2732139d, 0x00000000}},  //   lloq, بیت_, mány_,
  { {0x69d9001f, 0x473529a5, 0x60d90049, 0x00000000}},  //   _erwe, йнос, אַרג,
  { {0x88bc00b9, 0x2bd30061, 0x7bda01f3, 0x00000000}},  //   cněn, थिरा, _irtu,
  { {0xceb300b6, 0x63be0061, 0x7ae20035, 0x00000000}},  //   חיר_, _appn, _inot,
  { {0xd90e0014, 0xb0d501f5, 0x63be0022, 0x00000000}},  //   _آید_, _डोंग, _bppn,
  { {0xd7fa098c, 0x27320047, 0xd79401b7, 0x00000000}},  //   _јул_, hány_, _البخ,
  { {0xe7050167, 0xdb1a1374, 0x00000000, 0x00000000}},  //   _دستی, _astú,   ,
  { {0x2067003b, 0x00000000, 0x00000000, 0x00000000}},  // [7610] ађев,   ,   ,
  { {0x7bda1293, 0x88bc00b9, 0x27321416, 0x00000000}},  //   _ortu, zněn, dány_,
  { {0xa267005e, 0x31af019a, 0x83f916e8, 0x00000000}},  //   _въгл, süz_, _сенс_,
  { {0xa857009b, 0xdb1a29a6, 0x80ca0044, 0x00000000}},  //   ביבה_, _estú, রাষ্,
  { {0xd087007c, 0x88bc00b9, 0x6b6a0036, 0x00000000}},  //   _выби, vněn, _węgl,
  { {0x7ae20038, 0xfbd10025, 0x6448002b, 0x00000000}},  //   _anot, كتب_, żdie,
  { {0x7f42009d, 0x88bc00b9, 0x4ea700ed, 0x00000000}},  //   bloq, tněn, _врза,
  { {0xcac90057, 0xdb030065, 0x7cfd00d4, 0x00000000}},  //   угие_, munë, _mèri,
  { {0x88bc00b9, 0x80ca0044, 0x7bda29a7, 0x00000000}},  //   rněn, রার্, _ertu,
  { {0x60c5010f, 0x7ae20059, 0x09050088, 0x00000000}},  //   nehm, _enot, спон,
  { {0xdab9008b, 0x88bc00b9, 0xd90d0014, 0x00000000}},  //   _былі_, mněl, ویچ_,
  { {0x6d430039, 0x0a18007a, 0x7ae229a8, 0x00000000}},  //   llna, افیک_, _gnot,
  { {0xe8ee01c0, 0x69d90009, 0x7cfd00d4, 0x00000000}},  //   _ел_, _urwe, _aèri,
  { {0x07f906dd, 0x69c929a9, 0x7ae20059, 0x00000000}},  //   _مربع_, mwee, _znot,
  { {0x68fc06d3, 0xe29a019d, 0x6d4329aa, 0x00000000}},  //   örde, лав_, ilna,
  { {0x6aa9010f, 0x7cfd00f6, 0xfdf90061, 0x00000000}},  //   ngef, _dèri, ्नास_,
  { {0x9c82010a, 0x69c90116, 0xb5fb008e, 0x00000000}},  // [7620] ščia, nwee, scár,
  { {0x26d2000b, 0x343a0188, 0x27320f49, 0x00000000}},  //   _hayo_, _مسجد_, vány_,
  { {0x26d2006a, 0x63be092e, 0x4aa7006e, 0x00000000}},  //   _kayo_, _uppn, _गांव,
  { {0x69c90328, 0xbea60259, 0x273229ab, 0x00000000}},  //   kwee, садк, tány_,
  { {0x26d20219, 0xdd8f0d3a, 0x6da329ac, 0x00000000}},  //   _mayo_, فون_, зича,
  { {0xd132023c, 0x69c929ad, 0x7ae201d6, 0x00000000}},  //   _رمز_, dwee, _snot,
  { {0x8fa30072, 0xb60601d9, 0x973d0091, 0x00000000}},  //   _наре, lišč, dućn,
  { {0x68e301aa, 0x26d20020, 0x49740256, 0x00000000}},  //   _annd, _nayo_, олис,
  { {0x69c901d6, 0xdce20091, 0x3eb3006b, 0x00000000}},  //   gwee, spođ, əxt_,
  { {0xa2da02d2, 0x973d0119, 0xdd8f0054, 0x00000000}},  //   _पोस्, gućn, _أول_,
  { {0x290702a9, 0x26d210d2, 0x06e4006e, 0x00000000}},  //   _dlna_, _bayo_, गांव_,
  { {0x26d2008e, 0x290724cf, 0x6f020253, 0x00000000}},  //   _cayo_, _elna_, nkoc,
  { {0xe8940194, 0x7afd29ae, 0x7cfd0129, 0x00000000}},  //   _даль, öste, _sèri,
  { {0xb60601d9, 0xf76f007a, 0x7cfd00f6, 0x00000000}},  //   dišč, بای_, _pèri,
  { {0x291e001a, 0x249f005a, 0xf1bf0c38, 0x00000000}},  //   mita_, ğum_, _spá_,
  { {0x291e29af, 0x26d20058, 0x249f019a, 0x00000000}},  //   lita_, _gayo_, şum_,
  { {0x7d080056, 0x291e00b0, 0x50f50d73, 0x00000000}},  // [7630] _olds, oita_, озат,
  { {0x291e0149, 0x764d0173, 0x83190014, 0x00000000}},  //   nita_, _izay, _چقدر_,
  { {0x26d20009, 0x6f0201a2, 0x291e00e7, 0x00000000}},  //   _yayo_, fkoc, iita_,
  { {0x291e001a, 0x141a009b, 0x7d1a29b0, 0x00000000}},  //   hita_, _כותב, _amts,
  { {0x291e006a, 0xdd9b0184, 0x7cfd000a, 0x00000000}},  //   kita_, уше_, _mèrv,
  { {0x21ba0049, 0xdb03040a, 0x672d01ee, 0x00000000}},  //   _דזשא, muné, _ljaj,
  { {0x81bb0055, 0xdd9100a1, 0xf53f05fe, 0x00000000}},  //   _আছি_, سوں_, mråd_,
  { {0x69c90038, 0x7d0829b1, 0x29070082, 0x00000000}},  //   twee, _elds, _slna_,
  { {0x6aa900db, 0xae160061, 0x26d2008e, 0x00000000}},  //   rgef, _देऊन_, _rayo_,
  { {0x291e236a, 0x26d229b2, 0x69c900c7, 0x00000000}},  //   gita_, _sayo_, rwee,
  { {0xb17b0073, 0x69c90007, 0x6f09013e, 0x00000000}},  //   _fråg, swee, _klec,
  { {0xe73a00ed, 0xf2df0011, 0x7cfd00f6, 0x00000000}},  //   рем_, _khâu_, _cèrv,
  { {0x291e001a, 0x672d1c70, 0x6f0900b4, 0x00000000}},  //   bita_, _djaj, _mlec,
  { {0x291e0207, 0x26d20009, 0x6f090016, 0x00000000}},  //   cita_, _wayo_, _llec,
  { {0x26d2006a, 0xc746023c, 0x764d01aa, 0x00000000}},  //   _tayo_, _وضعي, _ezay,
  { {0xa22a00e3, 0xb6060059, 0x98ac0a52, 0x00000000}},  //   ажба_, tišč, rodą_,
  { {0x256f005d, 0x88bc00b9, 0xdce0001a, 0x00000000}},  // [7640] _gül_, dněj, _jumă,
  { {0x33290061, 0x6f090adb, 0xf53f044f, 0x00000000}},  //   anax_, _alec, står_,
  { {0x753c29b3, 0x6f0929b4, 0xdfd20025, 0x00000000}},  //   morz, _blec, بيض_,
  { {0x291e29b5, 0x444424a8, 0x290c29b6, 0x00000000}},  //   zita_, _iy_, zhda_,
  { {0x44441273, 0xf2df001d, 0x6f0200b5, 0x00000000}},  //   _hy_, _châu_, rkoc,
  { {0x4444008d, 0x291e022b, 0x6f020036, 0x00000000}},  //   _ky_, xita_, skoc,
  { {0x44441273, 0x6f0929b7, 0x88bc00b9, 0x00000000}},  //   _jy_, _flec, bněj,
  { {0x44440b8d, 0xaec304ef, 0x39450129, 0x00000000}},  //   _my_, _обсл, ells_,
  { {0x291e1825, 0x44440011, 0x753c0046, 0x00000000}},  //   tita_, _ly_, korz,
  { {0x44441be4, 0xeb9a0265, 0x672d0091, 0x00000000}},  //   _oy_, _виж_, _sjaj,
  { {0x444404d7, 0x291e020c, 0xe1ff0011, 0x00000000}},  //   _ny_, rita_, _ngón_,
  { {0x3869014a, 0x76440045, 0xdce000e5, 0x00000000}},  //   _şart_, _byiy, _fumă,
  { {0x44440811, 0x291e000b, 0x753c2777, 0x00000000}},  //   _ay_, pita_, forz,
  { {0x44440a8a, 0x657d0023, 0xe4e403e8, 0x00000000}},  //   _by_, rpsh, місн,
  { {0x444429b8, 0x987b00a3, 0x00000000, 0x00000000}},  //   _cy_, _דרוק,   ,
  { {0x444429b9, 0xf2df0082, 0x68f80ccc, 0x00000000}},  //   _dy_, _nhât_, _hovd,
  { {0x44440890, 0x88bc00b9, 0x33290066, 0x00000000}},  // [7650] _ey_, vněj, rnax_,
  { {0xd49b0081, 0x4444018e, 0x6f0902ae, 0x00000000}},  //   _три_, _fy_, _slec,
  { {0x6f09000d, 0x44440010, 0x656d29ba, 0x00000000}},  //   _plec, _gy_, _huah,
  { {0x656d0020, 0xf53f29bb, 0x68f800ea, 0x00000000}},  //   _kuah, sråd_, _lovd,
  { {0x7bc1184b, 0x237f0091, 0x39450203, 0x00000000}},  //   _splu, ćuju_, ylls_,
  { {0x44440095, 0x656d0145, 0x88bc00b9, 0x00000000}},  //   _yy_, _muah, sněj,
  { {0x6b4529bc, 0x4bd9008b, 0xcfb4005e, 0x00000000}},  //   lógi, сьля_, _обръ,
  { {0xb17b0c73, 0x6f1b0061, 0xf2df0082, 0x00000000}},  //   _tråd, _umuc, _thâu_,
  { {0x3b0d0023, 0x443300e5, 0x60d50095, 0x00000000}},  //   rheq_, _lxx_, _kazm,
  { {0x2fc30009, 0x23cb0164, 0x60d5113f, 0x00000000}},  //   _kpjg_, ाबाद, _jazm,
  { {0x6d41020c, 0x753c29bd, 0x68f8016c, 0x00000000}},  //   _ikla, vorz, _dovd,
  { {0x444429be, 0x753c0046, 0x656d01a3, 0x00000000}},  //   _ry_, worz, _buah,
  { {0x444429bf, 0x753c0036, 0x7cfd00f6, 0x00000000}},  //   _sy_, torz, _fèrt,
  { {0x44440541, 0xb97a034e, 0x60d529c0, 0x00000000}},  //   _py_, _הנסי, _nazm,
  { {0x638602d9, 0x987a0049, 0x44330009, 0x00000000}},  //   ягва, _פאקט, _cxx_,
  { {0x444429c1, 0xe363003b, 0xfe6500a1, 0x00000000}},  //   _vy_, екси, _لگ_,
  { {0x753c0a19, 0x6b4500fd, 0x4444275d, 0x00000000}},  // [7660] porz, gógi, _wy_,
  { {0x4444001d, 0x3ebf00e0, 0xd24f0025, 0x00000000}},  //   _ty_, _abut_, انك_,
  { {0x44440011, 0x09b70044, 0x0019007e, 0x00000000}},  //   _uy_, জিটা, оўцы_,
  { {0x6d41011c, 0xb17b0190, 0xfbc30044, 0x00000000}},  //   _akla, _dråb, ্মাত,
  { {0x62840845, 0x26c00020, 0x443300f6, 0x00000000}},  //   mbio, _mbio_, _zxx_,
  { {0x60d500af, 0x29052270, 0x26c000d9, 0x00000000}},  //   _gazm, jkla_, _lbio_,
  { {0x44330027, 0x69c200c7, 0x68f80c73, 0x00000000}},  //   _xxx_, _spoe, _rovd,
  { {0x6d410173, 0x79a610f3, 0x62840032, 0x00000000}},  //   _ekla, прое, nbio,
  { {0x6da30bbd, 0x60d501f6, 0x7afd29c2, 0x00000000}},  //   _пита, _yazm, östa,
  { {0x290a0c59, 0x26c028dc, 0x80ca0044, 0x00000000}},  //   óba_, _abio_, রাক্,
  { {0x656d00f6, 0x673d29c3, 0x6c4a0025, 0x00000000}},  //   _suah, tosj, _الاف_,
  { {0x6d41013e, 0xb34700fa, 0x00000000, 0x00000000}},  //   _zkla, _maçô,   ,
  { {0xb0ac001c, 0x673d0292, 0xcb1300b3, 0x00000000}},  //   _चांग, rosj, _אלף_,
  { {0x2ec90183, 0x38c8026c, 0x29050039, 0x00000000}},  //   _रस्त, _ذاتی_, ckla_,
  { {0x60d5092f, 0x58bb00b6, 0x88bb009b, 0x00000000}},  //   _razm, _המוצ, _המוז,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd234005e, 0x26cb0082, 0x60f9007e, 0x00000000}},  // [7670] ентъ, meco_, оная_,
  { {0x26cb0c8f, 0x60d5013f, 0x00000000, 0x00000000}},  //   leco_, _qazm,   ,
  { {0x62840197, 0x20071db2, 0x7bdc0010, 0x00000000}},  //   bbio, áni_, _áruh,
  { {0x6d410410, 0x200701d5, 0x26cb12dd, 0x00000000}},  //   _skla, ġni_, neco_,
  { {0x200701ae, 0x9f5c0f49, 0xa1590140, 0x00000000}},  //   šni_, ává_, _маму_,
  { {0xee38111f, 0x26cb00fa, 0x628f005b, 0x00000000}},  //   чні_, heco_, _heco,
  { {0x7af90036, 0x628f003f, 0x6d4104bb, 0x00000000}},  //   _powt, _keco, _vkla,
  { {0x64410046, 0x7cfd1b43, 0x26cb29c4, 0x00000000}},  //   żliw, _pèrs, jeco_,
  { {0xc27c009b, 0x00000000, 0x00000000, 0x00000000}},  //   זרחי,   ,   ,
  { {0x480501fb, 0x27390a50, 0x6d4109fc, 0x00000000}},  //   дпов, mény_, _ukla,
  { {0x629d018b, 0xa6ca00e3, 0x26cb004a, 0x00000000}},  //   _odso, олна_, feco_,
  { {0x628f001a, 0xeab00025, 0x3eaf0026, 0x00000000}},  //   _neco, _معه_, nggt_,
  { {0xdb1a0253, 0xe8f50025, 0xe6170088, 0x00000000}},  //   _estó, _يستخ, ддя_,
  { {0xd82501fc, 0x628f00f6, 0x629d0133, 0x00000000}},  //   _одли, _aeco, _adso,
  { {0x04430057, 0x628f0038, 0x62840066, 0x00000000}},  //   верн, _beco, tbio,
  { {0x26c00091, 0x26cb064e, 0x00000000, 0x00000000}},  //   _ubio_, ceco_,   ,
  { {0x628f0335, 0xa09a0025, 0x629d012d, 0x00000000}},  // [7680] _deco, قضاء_, _ddso,
  { {0x629d0181, 0x8cbf013d, 0x628400f8, 0x00000000}},  //   _edso, ल्मो, sbio,
  { {0x628f0197, 0x6b450010, 0x00000000, 0x00000000}},  //   _feco, lógu,   ,
  { {0x628f00b5, 0x61e9040d, 0x00000000, 0x00000000}},  //   _geco, _šele,   ,
  { {0x27390344, 0x00000000, 0x00000000, 0x00000000}},  //   gény_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69dd05df, 0x00000000, 0x00000000, 0x00000000}},  //   æsen,   ,   ,
  { {0x26cb02d0, 0x00000000, 0x00000000, 0x00000000}},  //   xeco_,   ,   ,
  { {0x26cb0035, 0xbebd0006, 0x00000000, 0x00000000}},  //   veco_, _smūg,   ,
  { {0xcce6067a, 0x973d016c, 0xc7ba01ab, 0x00000000}},  //   _تسري, mući, оём_,
  { {0x7c650054, 0x26cb00c4, 0xdb0a0039, 0x00000000}},  //   _كامل, teco_, ttfä,
  { {0x6d4a0090, 0xdb1a1c88, 0x00000000, 0x00000000}},  //   llfa, _estò,   ,
  { {0x276802fd, 0xb5fb004a, 0x6b450010, 0x00000000}},  //   _کشتی_, lcáz, gógu,
  { {0x628f06da, 0xdb0a09b0, 0x629d0087, 0x00000000}},  //   _seco, stfä, _sdso,
  { {0x628f0197, 0x3eaf092e, 0x273901ca, 0x00000000}},  //   _peco, yggt_, zény_,
  { {0xe667025f, 0x35b52547, 0x973d0243, 0x00000000}},  //   _отпо, _збир, kući,
  { {0x443f0036, 0x973d0091, 0x00000000, 0x00000000}},  // [7690] łu_, jući,   ,
  { {0x7b17001a, 0xc5f2009b, 0x27390010, 0x00000000}},  //   nţur, _עדי_, vény_,
  { {0x44270073, 0xb4cb0061, 0x35f80167, 0x00000000}},  //   _än_, ळजी_, _فرید_,
  { {0x629d0030, 0xe0cf0044, 0x8db50088, 0x00000000}},  //   _udso, রাইভ, ескі,
  { {0x973d0091, 0x31790049, 0x427a0097, 0x00000000}},  //   gući, _מאָד, _מארג,
  { {0xabd500ec, 0x78710010, 0x00000000, 0x00000000}},  //   ециј, _művé,   ,
  { {0xac0902be, 0x00000000, 0x00000000, 0x00000000}},  //   янка_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x1d35005e, 0x00000000, 0x00000000, 0x00000000}},  //   _зная,   ,   ,
  { {0x3f68005d, 0x00000000, 0x00000000, 0x00000000}},  //   _uğur_,   ,   ,
  { {0x80ca0044, 0x00000000, 0x00000000, 0x00000000}},  //   রাচ্,   ,   ,
  { {0x290e0edb, 0x2d8d0022, 0x6448010e, 0x00000000}},  //   _elfa_, _kwee_, üdim,
  { {0x7e7b0020, 0xaa07023c, 0x7aeb0145, 0x00000000}},  //   _mfup, _تظاه, _ingt,
  { {0x25740073, 0xa0000044, 0x00000000, 0x00000000}},  //   _väl_, _এইসব_,   ,
  { {0xa3e7007e, 0xd3720076, 0xdddb0c6e, 0x00000000}},  //   ндра_, اهر_, _neuž,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xcb12007b, 0x05770025, 0x00000000, 0x00000000}},  // [76a0] אלן_, _كمية_,   ,
  { {0x6606068f, 0x00000000, 0x00000000, 0x00000000}},  //   mykk,   ,   ,
  { {0x66060030, 0x24b70049, 0xa4b7009b, 0x00000000}},  //   lykk, _אהין_, _אליה_,
  { {0x216a004c, 0x6710007d, 0x00000000, 0x00000000}},  //   _ними_, ासिक_,   ,
  { {0x6296020e, 0x6e9303ec, 0xfd79009e, 0x00000000}},  //   mayo, الها, وشوں_,
  { {0x6296011c, 0x3d1900a1, 0x7aeb00e0, 0x00000000}},  //   layo, وٹنگ_, _angt,
  { {0x1fb503f3, 0xdb03120f, 0x00000000, 0x00000000}},  //   _истр, stný,   ,
  { {0xa06717be, 0x6e930054, 0x6296000b, 0x00000000}},  //   _часа_, _ملفا, nayo,
  { {0x88bc00b9, 0x95ef013d, 0x80d30044, 0x00000000}},  //   knět, _चपेट_, সার্,
  { {0x629600e0, 0x7b150325, 0x00000000, 0x00000000}},  //   hayo, _náuf,   ,
  { {0xf53f0039, 0x62960020, 0x60c1014a, 0x00000000}},  //   från_, kayo, _ölme,
  { {0xca76007e, 0x00000000, 0x00000000, 0x00000000}},  //   _чужы,   ,   ,
  { {0x6296011c, 0x00000000, 0x00000000, 0x00000000}},  //   dayo,   ,   ,
  { {0x290e0022, 0x63a129c5, 0x00000000, 0x00000000}},  //   _ulfa_, álno,   ,
  { {0xa295008b, 0x00000000, 0x00000000, 0x00000000}},  //   каві,   ,   ,
  { {0x6296011c, 0xdb180142, 0xdce101c5, 0x00000000}},  //   gayo, ftvé, _milā,
  { {0x4ac2007d, 0x00000000, 0x00000000, 0x00000000}},  // [76b0] व्यव,   ,   ,
  { {0x3375007c, 0xb17b0039, 0x6b4500d6, 0x00000000}},  //   _игор, _från, nógr,
  { {0x62960b9a, 0x2d8d0145, 0x394c06ed, 0x00000000}},  //   bayo, _swee_, ilds_,
  { {0xfe700076, 0x539a00a0, 0x6296004a, 0x00000000}},  //   مده_, _קירו, cayo,
  { {0xa69c0049, 0x00000000, 0x00000000, 0x00000000}},  //   לשאפ,   ,   ,
  { {0x313501ee, 0xe1ff0082, 0x00000000, 0x00000000}},  //   _регр, _ngói_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d8d0100, 0x2bc2001c, 0x7e7b00e7, 0x00000000}},  //   _twee_, _शहरा, _ufup,
  { {0x0edd013d, 0x6b450048, 0x7e6411af, 0x00000000}},  //   _नोएड, fógr, žipr,
  { {0x6296000a, 0xb0c7007e, 0x00000000, 0x00000000}},  //   zayo, дпiс,   ,
  { {0xe73a0113, 0xab8415c4, 0x3cfa0049, 0x00000000}},  //   ден_, _бучк, _קלענ,
  { {0x6d430006, 0xfbd200b3, 0x6606004e, 0x00000000}},  //   lona, _כתב_, tykk,
  { {0xaa880025, 0x62960095, 0x00000000, 0x00000000}},  //   _أنهم_, vayo,   ,
  { {0x290b001e, 0x2b4d29c6, 0x2b400247, 0x00000000}},  //   īcas_, llec_, čice_,
  { {0x62960058, 0x6d4300e5, 0xa8480025, 0x00000000}},  //   tayo, iona, _كلهم_,
  { {0x2d80000d, 0x6d43027e, 0xf772009b, 0x00000000}},  //   ţiei_, hona, _דקה_,
  { {0x6d4329c7, 0x973d0166, 0x629629c8, 0x00000000}},  // [76c0] kona, guću, rayo,
  { {0x6d4301d5, 0x62960ee4, 0xb17b00f8, 0x00000000}},  //   jona, sayo, _trån,
  { {0xf9f90055, 0x3f9c00f4, 0x629609d7, 0x00000000}},  //   েছিল_, évu_, payo,
  { {0xbe660379, 0xa856009b, 0x8fa3007e, 0x00000000}},  //   نهاي, דיעה_, раце,
  { {0x6d431b78, 0x9db700b8, 0xdb03005b, 0x00000000}},  //   fona, ندوز_, ernï,
  { {0x80c102d2, 0x6b550006, 0x30760098, 0x00000000}},  //   र्दे, _išgy, _шумс,
  { {0x60dc29c9, 0x5edd0061, 0x00000000, 0x00000000}},  //   _iarm, _नोकऱ,   ,
  { {0x60dc0010, 0x443a0026, 0x24980d78, 0x00000000}},  //   _harm, _mxp_, harm_,
  { {0x6d430207, 0x6b45029d, 0x6f000051, 0x00000000}},  //   bona, tógr, _iomc,
  { {0x6d430129, 0x998d0036, 0x00000000, 0x00000000}},  //   cona, dzeń_,   ,
  { {0x60dc014a, 0x645a000c, 0x394c0133, 0x00000000}},  //   _marm, ýtil, rlds_,
  { {0x60dc21ba, 0x752700b5, 0x7c3a002b, 0x00000000}},  //   _larm, wijz, _ixtr,
  { {0x6f0302d5, 0x249801c5, 0xcb6700ed, 0x00000000}},  //   ênci, farm_, _раце_,
  { {0x06240ae0, 0x00000000, 0x00000000, 0x00000000}},  //   рфюм,   ,   ,
  { {0x61e60006, 0x752700bb, 0x18a300ec, 0x00000000}},  //   _arkl, rijz, _тајм,
  { {0x6d4302d5, 0x6f0001ee, 0x237e0010, 0x00000000}},  //   zona, _nomc, ítja_,
  { {0x443a0011, 0x998d0036, 0x6d4329ca, 0x00000000}},  // [76d0] _exp_, czeń_, yona,
  { {0x2eff01aa, 0x67240091, 0x6d430288, 0x00000000}},  //   _souf_, _zmij, xona,
  { {0x60dc0046, 0x6d430010, 0x61e629cb, 0x00000000}},  //   _darm, vona, _erkl,
  { {0x6d48066b, 0x6d5a2032, 0x224b0039, 0x00000000}},  //   _akda, _ahta, _tyck_,
  { {0x6d430429, 0x60dc1d7a, 0xddc5007c, 0x00000000}},  //   tona, _farm, убли,
  { {0x3f47006c, 0x621a0104, 0x00000000, 0x00000000}},  //   tõus_, _טורק,   ,
  { {0x5f94029b, 0x8b94008b, 0x6f000145, 0x00000000}},  //   _вист, арыч, _fomc,
  { {0xe9d906c4, 0x6d430238, 0x2ca90477, 0x00000000}},  //   еки_, sona, şad_,
  { {0x6d4329cc, 0x60dc006b, 0x764d00e7, 0x00000000}},  //   pona, _yarm, _nyay,
  { {0x67240243, 0x7c3a0066, 0x60dc0032, 0x00000000}},  //   _smij, _fxtr, _xarm,
  { {0xd825007c, 0x00000000, 0x00000000, 0x00000000}},  //   удни,   ,   ,
  { {0x249829cd, 0x764d0009, 0x6813006b, 0x00000000}},  //   warm_, _byay, nədə,
  { {0x6440006b, 0x7d0105ad, 0x764d0009, 0x00000000}},  //   əmiy, _kols, _cyay,
  { {0x7afb20b9, 0x69d9002b, 0x998d0036, 0x00000000}},  //   ljut, _iswe, rzeń_,
  { {0xa6c90044, 0x998d0036, 0x6813006b, 0x00000000}},  //   ষয়ট, szeń_, kədə,
  { {0x7afb0149, 0x672410ec, 0x61e60087, 0x00000000}},  //   njut, _umij, _prkl,
  { {0x60dc11a1, 0xdb0a29ce, 0x00000000, 0x00000000}},  // [76e0] _parm, énés,   ,
  { {0x69d9000a, 0x7afb010e, 0x6f0000e5, 0x00000000}},  //   _mswe, hjut, _somc,
  { {0x60dc021e, 0xdee60069, 0x94bb009b, 0x00000000}},  //   _varm, ложи, _אמית,
  { {0xee3a008b, 0x69cb049b, 0x6d5a008d, 0x00000000}},  //   нне_, _opge, _shta,
  { {0x7d010489, 0x7afb05fa, 0x60dc006c, 0x00000000}},  //   _bols, djut, _tarm,
  { {0x7d01001c, 0x394502d0, 0xfbd20025, 0x00000000}},  //   _cols, jols_, متع_,
  { {0x61e40ff8, 0x6f000142, 0x79820036, 0x00000000}},  //   lvil, _tomc, _stow,
  { {0x61e4010e, 0x290300f8, 0x25a0000a, 0x00000000}},  //   ovil, öjan_, _ovil_,
  { {0xe7e30044, 0x391402b8, 0xee37005e, 0x00000000}},  //   মহোয, имир, _бнт_,
  { {0x41bb007b, 0xd90e0752, 0x7d010066, 0x00000000}},  //   עציע, ثیت_, _gols,
  { {0x61e400b0, 0xac970025, 0x3b862194, 0x00000000}},  //   hvil, _إنما_, _слег,
  { {0x7bda0ac2, 0xd6db0245, 0x61e4000c, 0x00000000}},  //   _istu, хто_, kvil,
  { {0x776d027b, 0x394529cf, 0xdce819ca, 0x00000000}},  //   _viax, bols_, _lidč,
  { {0x61e40006, 0x69c00006, 0xdb1a00c4, 0x00000000}},  //   dvil, mtme, _estô,
  { {0xa87b009b, 0x6813006b, 0x25a000ab, 0x00000000}},  //   _ארוח, yədə, _evil_,
  { {0x2bac0316, 0x2d840107, 0x69c00007, 0x00000000}},  //   _घटना, _otme_, otme,
  { {0x69c00129, 0xdb0300c4, 0x764d00e0, 0x00000000}},  // [76f0] ntme, sunç, _uyay,
  { {0x69c01d9e, 0x926800c0, 0x7bda006c, 0x00000000}},  //   itme, урса_, _ostu,
  { {0x7d010112, 0x69c0006c, 0xff0702be, 0x00000000}},  //   _rols, htme, лядн,
  { {0x2d9d0061, 0x00000000, 0x00000000, 0x00000000}},  //   tswe_,   ,   ,
  { {0x7d010667, 0x7bda03a4, 0x628d015e, 0x00000000}},  //   _pols, _astu, mbao,
  { {0xfce5004c, 0x69c00302, 0x628d0032, 0x00000000}},  //   роко, dtme, lbao,
  { {0x7d0100c7, 0x6114003b, 0x20c4007e, 0x00000000}},  //   _vols, _удру, _усяг,
  { {0x69c029d0, 0x7d0100b4, 0x7bda0085, 0x00000000}},  //   ftme, _wols, _dstu,
  { {0x7bda0325, 0x7afb0004, 0x7d01016c, 0x00000000}},  //   _estu, rjut, _tols,
  { {0x2b400247, 0x7afb01c2, 0x61e90066, 0x00000000}},  //   čica_, sjut, _ġell,
  { {0x69c000ab, 0x394512a0, 0xb17b0039, 0x00000000}},  //   atme, rols_, _bråk,
  { {0x394500d4, 0xf74601fb, 0x9666003b, 0x00000000}},  //   sols_, ремо, икне,
  { {0xe7370764, 0x69d921a4, 0x394525e9, 0x00000000}},  //   рея_, _uswe, pols_,
  { {0x2ed2013d, 0x7c3829d1, 0x00000000, 0x00000000}},  //   _सस्त, _çarç,   ,
  { {0xe29a012b, 0x232a0143, 0xdb03010e, 0x00000000}},  //   кав_, вови_, punä,
  { {0x61e40232, 0x25a000ea, 0x628d0058, 0x00000000}},  //   tvil, _tvil_, gbao,
  { {0x64a6026b, 0x61e4009d, 0xc693009b, 0x00000000}},  // [7700] _капа, uvil, _ואח_,
  { {0x61e4225c, 0x0ce00044, 0xa0a607e1, 0x00000000}},  //   rvil, _বক্ত, ражд,
  { {0x98be0089, 0x00000000, 0x00000000, 0x00000000}},  //   notā_,   ,   ,
  { {0x539b00b6, 0x9c7c0340, 0x00000000, 0x00000000}},  //   _ביטו, _mače,   ,
  { {0xd8380059, 0x69c0211e, 0x1ea90379, 0x00000000}},  //   mače_, xtme, طاني_,
  { {0xd838016e, 0x5ba6030d, 0x00000000, 0x00000000}},  //   lače_, ариз,   ,
  { {0xed57012b, 0x9c7c0340, 0x00000000, 0x00000000}},  //   јој_, _nače,   ,
  { {0x7bda004f, 0xa3e7006e, 0x2ba7013d, 0x00000000}},  //   _vstu, पित_, _गिरा,
  { {0xb997216a, 0x69c022b1, 0x3f68005d, 0x00000000}},  //   авых_, utme, _oğuz_,
  { {0x69c00038, 0xdde9007a, 0x57b4007c, 0x00000000}},  //   rtme, _حرفه_, ббот,
  { {0x69c024e3, 0x7bda0209, 0xb17b00ea, 0x00000000}},  //   stme, _ustu, _pråk,
  { {0xd838016c, 0x69c001a2, 0xf53f0479, 0x00000000}},  //   jače_, ptme, pråk_,
  { {0xd83806fc, 0xef110049, 0x661d00b9, 0x00000000}},  //   dače_, פּט_, uzsk,
  { {0xf8060088, 0x00000000, 0x00000000, 0x00000000}},  //   _вчин,   ,   ,
  { {0x68fc006c, 0xb17b0039, 0xe4e4007e, 0x00000000}},  //   ördu, _tråk, ціян,
  { {0xd8380059, 0x7cfd000a, 0x26c900e7, 0x00000000}},  //   gače_, _dèry, _ubao_,
  { {0x9c7c01d9, 0xcad7009b, 0x94ab00e2, 0x00000000}},  // [7710] _zače, סומת_, _итна_,
  { {0x2ba7006e, 0xe4a7017f, 0x00000000, 0x00000000}},  //   _गिला, _трио,   ,
  { {0xd498008b, 0x2007001a, 0x7cfd0173, 0x00000000}},  //   _тры_, âni_, _gèry,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8b9500aa, 0x00000000, 0x00000000, 0x00000000}},  //   брич,   ,   ,
  { {0xab290900, 0x680a013f, 0x00000000, 0x00000000}},  //   лока_, nədd,   ,
  { {0xd438009b, 0x2bb8013d, 0x00000000, 0x00000000}},  //   יטוי_, _इमरा,   ,
  { {0xceb201f8, 0x9c7c037e, 0xd5ed0011, 0x00000000}},  //   _מין_, _sače, _ngà,
  { {0xd8380209, 0x2903009f, 0xe8f9013b, 0x00000000}},  //   zače_, ðja_, уло_,
  { {0x31710190, 0x80e10044, 0x00000000, 0x00000000}},  //   _mizz_, নাপ্,   ,
  { {0x27320059, 0x63b50107, 0x3171071b, 0x00000000}},  //   kšne_, duzn, _lizz_,
  { {0x99850025, 0xd83801ca, 0xda780265, 0x00000000}},  //   _التو, vače_, _тях_,
  { {0x63ae0087, 0x9c7c0087, 0x63a80062, 0x00000000}},  //   trbn, _tače, ádno,
  { {0xd8380428, 0x7bc30376, 0xa507073b, 0x00000000}},  //   tače_, ntnu, щера_,
  { {0xf74309f1, 0x00000000, 0x00000000, 0x00000000}},  //   _нещо,   ,   ,
  { {0xd8380059, 0x171b009b, 0x7bc3006c, 0x00000000}},  // [7720] rače_, _תופע, htnu,
  { {0x6448006c, 0xb5fb00a0, 0x7bc306d3, 0x00000000}},  //   üdis, _עליכ, ktnu,
  { {0xee86007e, 0x4477009b, 0xd838016e, 0x00000000}},  //   было, _לעיל_, pače_,
  { {0xdfcf0025, 0xf4870014, 0xbda60025, 0x00000000}},  //   عين_, _پایی, محتو,
  { {0x1d0a00e3, 0x317104a5, 0x00000000, 0x00000000}},  //   леди_, _fizz_,   ,
  { {0x25a20009, 0x00000000, 0x00000000, 0x00000000}},  //   iskl_,   ,   ,
  { {0xdee6007c, 0xeb4a02dc, 0x00000000, 0x00000000}},  //   _лови, лчик_,   ,
  { {0xa037009b, 0xef910014, 0x2b400059, 0x00000000}},  //   _האלה_, _آیند, čico_,
  { {0xee3a0175, 0x00000000, 0x00000000, 0x00000000}},  //   _сна_,   ,   ,
  { {0xdce901d5, 0x050a0044, 0x00000000, 0x00000000}},  //   _tweġ, রফুর_,   ,
  { {0xd6d51001, 0x6d4a00c4, 0x7bc30d4d, 0x00000000}},  //   ожны, mofa, ctnu,
  { {0xab6629d2, 0x6d4a0020, 0x3057009b, 0x00000000}},  //   _увел, lofa, משיך_,
  { {0xceb3009b, 0x00000000, 0x00000000, 0x00000000}},  //   היר_,   ,   ,
  { {0x63b5016c, 0x7ae20c97, 0x00000000, 0x00000000}},  //   tuzn, _haot,   ,
  { {0x7ae20004, 0x93880057, 0x24180783, 0x00000000}},  //   _kaot, йста_, боры_,
  { {0xadfa0204, 0x7ae20934, 0xddc90036, 0x00000000}},  //   ्हान_, _jaot, _cześ,
  { {0x9099005e, 0x6d4a1a91, 0x00000000, 0x00000000}},  // [7730] иват_, kofa,   ,
  { {0x672f0036, 0x29c2000c, 0x7ae2010e, 0x00000000}},  //   licj, iða_, _laot,
  { {0x660f0039, 0x6d4a0022, 0x680a006b, 0x00000000}},  //   lyck, dofa, qədd,
  { {0x31710035, 0x672f0036, 0x3f870089, 0x00000000}},  //   _wizz_, nicj, īnu_,
  { {0xa6e30044, 0x00000000, 0x00000000, 0x00000000}},  //   যাপট,   ,   ,
  { {0x212a001f, 0x9ce700a1, 0x6d4a29d3, 0x00000000}},  //   _gmbh_, صوبے_, gofa,
  { {0xff53039d, 0x7ae21304, 0x00000000, 0x00000000}},  //   _فخر_, _baot,   ,
  { {0xc9a90265, 0x7bc30056, 0x3eb9068f, 0x00000000}},  //   авие_, rtnu, _øst_,
  { {0x88d5008b, 0x29c2000c, 0x7ae229d4, 0x00000000}},  //   оўні, gða_, _daot,
  { {0x660f00b9, 0xb17b00ea, 0x77c9005c, 0x00000000}},  //   dyck, _fråv, алог_,
  { {0x672f29d5, 0x06e30044, 0xe8f601e1, 0x00000000}},  //   ficj, যানি, ілю_,
  { {0x7ae20051, 0xfbd0035b, 0x9c7c012d, 0x00000000}},  //   _gaot, _ستم_, _tačc,
  { {0x18a5003b, 0x629f006b, 0x00000000, 0x00000000}},  //   _далм, daqo,   ,
  { {0xdd7a0049, 0x98a50089, 0xddc90036, 0x00000000}},  //   יטשל, bilā_, _sześ,
  { {0x2907093e, 0x629f0023, 0x9c7c04eb, 0x00000000}},  //   _iona_, faqo, _jača,
  { {0x2907002d, 0x6abb29d6, 0x6d4a0020, 0x00000000}},  //   _hona_, nguf, zofa,
  { {0x2907000c, 0x6d4a0020, 0xd83802db, 0x00000000}},  // [7740] _kona_, yofa, mača_,
  { {0x68e301aa, 0xd8380627, 0x290707af, 0x00000000}},  //   _jand, lača_, _jona_,
  { {0x68e3134e, 0x290700f8, 0x60c301aa, 0x00000000}},  //   _mand, _mona_, ònma,
  { {0xa3c9001c, 0x645e29d7, 0x29071612, 0x00000000}},  //   ोबर_, _izpi, _lona_,
  { {0x6d4a0020, 0x68e329d8, 0x00000000, 0x00000000}},  //   tofa, _oand,   ,
  { {0x68e3011c, 0x7ae20051, 0x62840207, 0x00000000}},  //   _nand, _saot, lcio,
  { {0x26c00211, 0x332b0009, 0xd83810f7, 0x00000000}},  //   _ocio_, _ymcx_, kača_,
  { {0x62840219, 0x68e30100, 0xd83810ec, 0x00000000}},  //   ncio, _aand, jača_,
  { {0x290704bd, 0x80ca001c, 0x6284008e, 0x00000000}},  //   _bona_, स्थे, icio,
  { {0x29c2009f, 0x291829d9, 0x290729da, 0x00000000}},  //   rða_, óra_, _cona_,
  { {0x29070129, 0x68e300d6, 0x62840dc6, 0x00000000}},  //   _dona_, _dand, kcio,
  { {0x660f29db, 0x6f02012d, 0x68e300d9, 0x00000000}},  //   tyck, njoc, _eand,
  { {0x68e30030, 0xfa360167, 0x9c7c0428, 0x00000000}},  //   _fand, _براد, _zača,
  { {0x32d5001d, 0x628600d9, 0x660f0039, 0x00000000}},  //   _ấy_, _afko, ryck,
  { {0x7d080030, 0x394c004a, 0x9c830062, 0x00000000}},  //   _mods, mods_, _účes,
  { {0x68e329dc, 0x6aa000e7, 0x7d080190, 0x00000000}},  //   _zand, namf, _lods,
  { {0x672d0213, 0x68e3005d, 0x290700e7, 0x00000000}},  // [7750] _imaj, _yand, _yona_,
  { {0x68e3002b, 0x62840919, 0x98ac0006, 0x00000000}},  //   _xand, acio, rodė_,
  { {0x3cfe006e, 0x6aa01725, 0x974311af, 0x00000000}},  //   लाने_, kamf, šćuj,
  { {0x6284095e, 0x7d1a0378, 0x26d90e20, 0x00000000}},  //   ccio, _alts, neso_,
  { {0xfe700a90, 0x7d0803b1, 0x291e01a3, 0x00000000}},  //   نده_, _bods, khta_,
  { {0x8b95003b, 0xd83804eb, 0x9c7c12db, 0x00000000}},  //   прич, zača_, _pača,
  { {0xeb9905c7, 0x7ed701d8, 0x629d04be, 0x00000000}},  //   щий_, _وزرا, _keso,
  { {0x2907014a, 0x27320059, 0x398001aa, 0x00000000}},  //   _sona_, kšna_, _bòs_,
  { {0x68e32824, 0x629d1dad, 0xd8380466, 0x00000000}},  //   _pand, _meso, vača_,
  { {0x7d080007, 0x2ba5001e, 0x672d05bd, 0x00000000}},  //   _gods, pēc_, _amaj,
  { {0x6f1b0036, 0x2907000c, 0xd8380626, 0x00000000}},  //   _kluc, _vona_, tača_,
  { {0x68e329dd, 0x39800263, 0x3ce51861, 0x00000000}},  //   _wand, _fòs_, _halv_,
  { {0xe9ce0822, 0x68e3248b, 0x29070065, 0x00000000}},  //   _як_, _tand, _tona_,
  { {0x291e29de, 0x81c10055, 0x6f1b00d4, 0x00000000}},  //   chta_, ংবা_, _lluc,
  { {0x61ef29df, 0x78a100ea, 0x61200010, 0x00000000}},  //   _arcl, malv, _hölg,
  { {0x26d90819, 0x98a5001a, 0x26c00107, 0x00000000}},  //   ceso_, bilă_, _ucio_,
  { {0x28c203d7, 0x62840211, 0x98a50035, 0x00000000}},  // [7760] _शामि, rcio, cilă_,
  { {0x62840e68, 0x20b9007e, 0x6f1b0325, 0x00000000}},  //   scio, жыць_, _aluc,
  { {0x62840779, 0x6f0900d9, 0x629d00d4, 0x00000000}},  //   pcio, _boec, _feso,
  { {0x444401d5, 0x629d0343, 0x78a100b5, 0x00000000}},  //   _ix_, _geso, halv,
  { {0x5ea30084, 0x78a100b0, 0x00000000, 0x00000000}},  //   رمول, kalv,   ,
  { {0x44440f02, 0x60220010, 0xac970025, 0x00000000}},  //   _kx_, _címé, كنها_,
  { {0xe7b60055, 0x79990319, 0x7d0802db, 0x00000000}},  //   _জন্য, _awww, _vods,
  { {0x612001f6, 0x44440211, 0xdee301fb, 0x00000000}},  //   _bölg, _mx_, _поси,
  { {0x44440011, 0x291e0023, 0xdb0a0a2f, 0x00000000}},  //   _lx_, thta_, ktfö,
  { {0x9c7c1b4e, 0x78a1008f, 0x44440082, 0x00000000}},  //   _začn, galv, _ox_,
  { {0x26d91425, 0xdc75008b, 0x44441fce, 0x00000000}},  //   teso_, _жыць, _nx_,
  { {0x291e008d, 0x6d58092e, 0x5694004c, 0x00000000}},  //   shta_, llva, нают,
  { {0x4444002b, 0x26d908d3, 0x78a11f7a, 0x00000000}},  //   _ax_, reso_, balv,
  { {0x26d9011c, 0x44440082, 0x9c7c1a47, 0x00000000}},  //   seso_, _bx_, _mačo,
  { {0x629d29e0, 0xccf800b9, 0x26d929e1, 0x00000000}},  //   _peso, _mně_, peso_,
  { {0x4444049a, 0x083b00b3, 0xd7bb009b, 0x00000000}},  //   _dx_, _לעול, _הצהר,
  { {0x9f470051, 0x629d0059, 0x6f0900d9, 0x00000000}},  // [7770] íní_, _veso, _roec,
  { {0x44440030, 0x6f1b012b, 0xe3b000a1, 0x00000000}},  //   _fx_, _sluc, ضرہ_,
  { {0x629d0a15, 0x3ddd03b0, 0x25a90190, 0x00000000}},  //   _teso, wwww_, _hval_,
  { {0x63b50c8a, 0x65651346, 0x3ce50066, 0x00000000}},  //   mrzn, _hhhh, _salv_,
  { {0x444401d6, 0x6f1b00b5, 0xfce50088, 0x00000000}},  //   _zx_, _vluc, доло,
  { {0x3ddd0009, 0xd83800ca, 0x44440ac2, 0x00000000}},  //   rwww_, jačo_, _yx_,
  { {0x68e80030, 0x9c7c05fa, 0x78a1006c, 0x00000000}},  //   dddd, _tačn, valv,
  { {0x7b150027, 0x68f80288, 0x61ed29e2, 0x00000000}},  //   _záuj, _anvd, oval,
  { {0xe29f0359, 0x61ed00b0, 0x78a10129, 0x00000000}},  //   _með_, nval, talv,
  { {0xdb030051, 0x68f800d9, 0x61200010, 0x00000000}},  //   isné, _cnvd, _völg,
  { {0x61ed01cd, 0x79990146, 0x78a101a2, 0x00000000}},  //   hval, _wwww, ralv,
  { {0x21210760, 0x6565011c, 0x321209d7, 0x00000000}},  //   hhhh_, _ahhh, yyyy_,
  { {0x78a1021e, 0x7ae90173, 0xdb0a1fbc, 0x00000000}},  //   palv, mdet, ttfö,
  { {0x44440365, 0x61ed0030, 0x7ae9002d, 0x00000000}},  //   _px_, dval, ldet,
  { {0x2722001d, 0x25a90061, 0x69c9003c, 0x00000000}},  //   _nóng_, _eval_, ltee,
  { {0x7ae929e3, 0x680a006b, 0x65650058, 0x00000000}},  //   ndet, qəda, _ehhh,
  { {0x69c908b2, 0x26d20061, 0xb80500a1, 0x00000000}},  // [7780] ntee, _ibyo_, _رکھے_,
  { {0x2722001d, 0x3ead014a, 0xc05a0595, 0x00000000}},  //   _bóng_, _adet_, орец_,
  { {0x69c9021e, 0x28cf0164, 0x3366003b, 0x00000000}},  //   htee, त्यि, _овог,
  { {0x7ae929e4, 0xa25b00f4, 0x69c9095c, 0x00000000}},  //   jdet, _icôn, ktee,
  { {0x7ae9153a, 0x8d6a00ec, 0x63bc29e5, 0x00000000}},  //   ddet, ојка_, lurn,
  { {0x09bc0055, 0x27320059, 0x7ae9185d, 0x00000000}},  //   _অনলা, kšno_, edet,
  { {0x6120000c, 0x69c900b0, 0x63bc000c, 0x00000000}},  //   _völd, etee, nurn,
  { {0xf8ce001d, 0x7ae929e6, 0x69c90133, 0x00000000}},  //   _cứng_, gdet, ftee,
  { {0x63bc0e2f, 0x612001e5, 0x00000000, 0x00000000}},  //   hurn, _töld,   ,
  { {0x63bc2878, 0x00000000, 0x00000000, 0x00000000}},  //   kurn,   ,   ,
  { {0x9c8301ca, 0x8c3c011f, 0x61ed0091, 0x00000000}},  //   _účas, _beğe, zval,
  { {0x63bc000c, 0x872b007e, 0x00000000, 0x00000000}},  //   durn, іўна_,   ,
  { {0x8c3c011f, 0x69c902ae, 0x6a160647, 0x00000000}},  //   _değe, ctee, _تبار,
  { {0x61ed001c, 0x63bc01e5, 0x26d20009, 0x00000000}},  //   vval, furn, _ebyo_,
  { {0xc6070055, 0x63bc0119, 0x7bca05d5, 0x00000000}},  //   _লেখা_, gurn, ntfu,
  { {0xf8ce0011, 0x14e10061, 0x2d5b00fa, 0x00000000}},  //   _xứng_, _फसवण, vêem_,
  { {0x80c80055, 0x2722001d, 0xd567078d, 0x00000000}},  // [7790] রজন্, _sóng_, _отоп,
  { {0x65651a7e, 0x7ae90010, 0x3f8716b5, 0x00000000}},  //   _uhhh, zdet, ínuo_,
  { {0x61ed010a, 0xf650026c, 0x753501bc, 0x00000000}},  //   sval, _مئی_, mizz,
  { {0x75350409, 0xd250026c, 0x26dc0049, 0x00000000}},  //   lizz, انے_, ַקומ,
  { {0x69c90133, 0xb17b0146, 0x00000000, 0x00000000}},  //   xtee, _gråp,   ,
  { {0x753513f0, 0x7bca0239, 0x7ae90009, 0x00000000}},  //   nizz, ftfu, wdet,
  { {0x4fc40eaf, 0x7bca0190, 0x9c7c0087, 0x00000000}},  //   _иста, gtfu, _kačj,
  { {0x69c9021e, 0x7ae916df, 0x75350197, 0x00000000}},  //   ttee, udet, hizz,
  { {0x7ae90047, 0x63bc0107, 0x25ad0618, 0x00000000}},  //   rdet, zurn, šelj_,
  { {0x7ae90173, 0x6c6a00a1, 0x69c929e7, 0x00000000}},  //   sdet, _کلمہ_, rtee,
  { {0x753501d5, 0x69c929e8, 0x7bca0133, 0x00000000}},  //   dizz, stee, ctfu,
  { {0x69c90f0c, 0x61200010, 0x501a009b, 0x00000000}},  //   ptee, _kölc, פורו,
  { {0x4a9a007b, 0x6b81006c, 0xe61704dd, 0x00000000}},  //   _זינג, _hulg, едя_,
  { {0x63bc0e40, 0x6b81006c, 0x80cf0044, 0x00000000}},  //   turn, _kulg, _হোস্,
  { {0x6b8122c5, 0x680a006b, 0xf8b200b3, 0x00000000}},  //   _julg, nədl, _עשה_,
  { {0xf7d6009b, 0x6b81006c, 0x00000000, 0x00000000}},  //   _נופש_, _mulg,   ,
  { {0x753529e9, 0x2aba014a, 0x63bc01e5, 0x00000000}},  // [77a0] bizz, lübü_, surn,
  { {0x63bc000c, 0x75350207, 0x22590036, 0x00000000}},  //   purn, cizz, _dysk_,
  { {0x06e30044, 0x1ae60044, 0x6b8100d9, 0x00000000}},  //   যারি, কাতে_, _nulg,
  { {0x73e3004c, 0x26c229ea, 0x06b20044, 0x00000000}},  //   _союз, ngko_, ট্রি,
  { {0xed5a003b, 0x127b0049, 0xf2d30049, 0x00000000}},  //   под_, _מאכע, _גער_,
  { {0x61e60091, 0x09d80044, 0x7bca04ce, 0x00000000}},  //   _iskl, তিমা, ttfu,
  { {0x99bc0055, 0x7bca0061, 0x6143007e, 0x00000000}},  //   _অনেক, utfu, _сера,
  { {0x200d0279, 0x75350066, 0x6b810035, 0x00000000}},  //   çmiş_, zizz, _dulg,
  { {0xf98f0167, 0xa3e7013d, 0x7bca0133, 0x00000000}},  //   یبی_, _मैन_, stfu,
  { {0x9c7c1144, 0xf1b30104, 0x6b810374, 0x00000000}},  //   _mačk, נסת_, _fulg,
  { {0x7535002b, 0x3137009b, 0x00000000, 0x00000000}},  //   vizz, תנים_,   ,
  { {0x09d80044, 0x8c1b009b, 0x29030039, 0x00000000}},  //   তিবা, _מובי, öjar_,
  { {0x75350a19, 0xd6e30044, 0x9c7c00d0, 0x00000000}},  //   tizz, যালয, _račj,
  { {0xd90e00a1, 0x2b402588, 0xe4e40088, 0x00000000}},  //   _چیک_, čicu_, лісн,
  { {0x753513f0, 0xf367005e, 0xd90e0167, 0x00000000}},  //   rizz, етан, _نیک_,
  { {0x9c7c016c, 0x7535002b, 0x68ea01e5, 0x00000000}},  //   _bačk, sizz, _hafd,
  { {0x680a006b, 0x7535054f, 0x64430e54, 0x00000000}},  // [77b0] zədl, pizz, _žnid,
  { {0x98be00b9, 0x68ea0066, 0x6aa2031c, 0x00000000}},  //   votě_, _jafd, _leof,
  { {0x439500ed, 0x61e629eb, 0x7b1c00f4, 0x00000000}},  //   _шанс, _eskl, _réun,
  { {0xdb010161, 0x2259080a, 0x290e29ec, 0x00000000}},  //   _ovlá, _tysk_, _lofa_,
  { {0x6b81006c, 0x64630091, 0x00000000, 0x00000000}},  //   _sulg, štić,   ,
  { {0x271e02d2, 0x6b810211, 0x7c87007c, 0x00000000}},  //   _पत्र_, _pulg, худе,
  { {0xfaf10025, 0xbebd08ad, 0x5e950025, 0x00000000}},  //   لثة_, _plūd, _للأط,
  { {0x6b81033f, 0xe29f000c, 0xb4cd006e, 0x00000000}},  //   _vulg, _boði_, रभु_,
  { {0x290e1617, 0x00000000, 0x00000000, 0x00000000}},  //   _bofa_,   ,   ,
  { {0x3f83006c, 0x6b81010e, 0x00000000, 0x00000000}},  //   _kuju_, _tulg,   ,
  { {0x9783007a, 0x2ca71936, 0x00000000, 0x00000000}},  //   دیبه, mand_,   ,
  { {0x5a3501ab, 0x00000000, 0x00000000, 0x00000000}},  //   _инет,   ,   ,
  { {0x290e00c4, 0x7aeb0190, 0xb4cd0316, 0x00000000}},  //   _fofa_, _iagt, रभू_,
  { {0x2ca70f04, 0x01b90044, 0x69d900fa, 0x00000000}},  //   nand_, ুবাদ, _ipwe,
  { {0xdb0101ca, 0x64a3007e, 0x3f830022, 0x00000000}},  //   _zvlá, раса, _nuju_,
  { {0x78a305b7, 0x2ca7029c, 0x7aeb0286, 0x00000000}},  //   _henv, hand_, _jagt,
  { {0x7aeb29ed, 0x98a50036, 0x2ca71802, 0x00000000}},  // [77c0] _magt, wilę_, kand_,
  { {0x3f83096f, 0x2ca70a2e, 0x4f9600ed, 0x00000000}},  //   _buju_, jand_, врду,
  { {0x3f830107, 0x2ca702a6, 0x00000000, 0x00000000}},  //   _cuju_, dand_,   ,
  { {0xee3a1b2d, 0x9c7c1dbe, 0x7aeb29ee, 0x00000000}},  //   мне_, _tačk, _nagt,
  { {0x543606c6, 0x61e602db, 0x2ca701a2, 0x00000000}},  //   _سرگر, _uskl, fand_,
  { {0x9c7c0006, 0x61e40020, 0x614629ef, 0x00000000}},  //   _kači, mwil, _рега,
  { {0x25a001aa, 0x61e429f0, 0x7aeb0190, 0x00000000}},  //   _lwil_, lwil, _bagt,
  { {0xdd9206dd, 0x290e000c, 0x9c7c29f1, 0x00000000}},  //   _نور_, _sofa_, _mači,
  { {0x78a329f2, 0xd8380627, 0x7aeb0190, 0x00000000}},  //   _benv, mači_, _dagt,
  { {0x2ca7001a, 0x61e4010f, 0x69cb0009, 0x00000000}},  //   cand_, iwil, _dqge,
  { {0x2d8400d4, 0xdd31006b, 0x61e41e28, 0x00000000}},  //   _hume_, ləşm, hwil,
  { {0x9c7c0bf8, 0xb8f902f4, 0x78a301b5, 0x00000000}},  //   _nači, _डॉ_, _eenv,
  { {0x61e400b5, 0xfb1b009b, 0x7ae000e7, 0x00000000}},  //   jwil, _קודמ, memt,
  { {0x61e40ace, 0x2d840020, 0x78a31f9d, 0x00000000}},  //   dwil, _mume_, _genv,
  { {0x2d84000d, 0x61e40c3f, 0x24580194, 0x00000000}},  //   _lume_, ewil, варь_,
  { {0x3ea40030, 0xd8380295, 0x2ca729f3, 0x00000000}},  //   _nemt_, jači_, zand_,
  { {0x60f90a78, 0x2d84000d, 0x9c7c29f4, 0x00000000}},  // [77d0] нная_, _nume_, _dači,
  { {0x31c400e1, 0xdce800b9, 0x7bda0091, 0x00000000}},  //   јств, _vidě, _optu,
  { {0x2ca729f5, 0x69c00b83, 0x00000000, 0x00000000}},  //   vand_, hume,   ,
  { {0x69c00292, 0x2ca7010f, 0x3cfe0022, 0x00000000}},  //   kume, wand_, _antv_,
  { {0x7bda0089, 0x69c001c5, 0xd7c40061, 0x00000000}},  //   _aptu, jume, लंडच,
  { {0x9c7c0027, 0x7aeb0125, 0x3f830513, 0x00000000}},  //   _zači, _sagt, _tuju_,
  { {0x7aeb006a, 0x3134007c, 0x78a300f4, 0x00000000}},  //   _pagt, _терр, _renv,
  { {0x7b150285, 0x69c00197, 0x2d84009d, 0x00000000}},  //   _náut, fume, _fume_,
  { {0x2ca70899, 0x2d840627, 0x7aeb0030, 0x00000000}},  //   pand_, _gume_, _vagt,
  { {0x80e10044, 0x7aeb01d6, 0xfd100025, 0x00000000}},  //   নাক্, _wagt, _وجل_,
  { {0xd05c005f, 0xec15023c, 0x628f0016, 0x00000000}},  //   _barə, _حواد, _ofco,
  { {0x69c004d3, 0x2ca5124c, 0x61e40007, 0x00000000}},  //   bume, _held_, ywil,
  { {0x69c003db, 0x6d43028c, 0x78a301c3, 0x00000000}},  //   cume, onna, _tenv,
  { {0x5e560049, 0x27220129, 0x6d431643, 0x00000000}},  //   רישע_, _dóna_, nnna,
  { {0x68e104fb, 0x2ca500b5, 0x9c7c010a, 0x00000000}},  //   meld, _meld_, _pači,
  { {0x28cf02f4, 0x27320059, 0x25a0002b, 0x00000000}},  //   त्रि, kšni_, _twil_,
  { {0x626601f9, 0xfdbe0044, 0xd8380091, 0x00000000}},  // [77e0] уваа, _ইন্ড, vači_,
  { {0x61e401c3, 0x80a601fa, 0x68e1014a, 0x00000000}},  //   rwil, امان, neld,
  { {0x672401d5, 0x69c00925, 0x9c7c010a, 0x00000000}},  //   _klij, zume, _tači,
  { {0x68e1006c, 0x6d430197, 0x91860070, 0x00000000}},  //   held, enna, _مجسم,
  { {0xdd8f0054, 0x6724016e, 0xd8380166, 0x00000000}},  //   كون_, _mlij, rači_,
  { {0x9c7c0521, 0x69c028b3, 0xdb18000c, 0x00000000}},  //   _mačv, vume, ruví,
  { {0xa06701f9, 0x7ae000ca, 0x6724015b, 0x00000000}},  //   _бара_, temt, _olij,
  { {0x6d4306fb, 0x69c00006, 0x2d840020, 0x00000000}},  //   anna, tume, _tume_,
  { {0x68e1010f, 0x2ca5010f, 0x7ae029f6, 0x00000000}},  //   feld, _feld_, remt,
  { {0x69c00624, 0x2ca50b72, 0x680a005f, 0x00000000}},  //   rume, _geld_, lədi,
  { {0x672402ae, 0x6ac60123, 0x6d5a29f7, 0x00000000}},  //   _blij, _مقام, _ikta,
  { {0x680a006b, 0x78a80f12, 0x9c7c0fcd, 0x00000000}},  //   nədi, sadv, _bačv,
  { {0x68e1000c, 0x60c50009, 0x00000000, 0x00000000}},  //   beld, yghm,   ,
  { {0x67241407, 0x7e7d0027, 0xd94329f8, 0x00000000}},  //   _elij, _úspe, _лечи,
  { {0x67240023, 0x657e0133, 0x645e0a55, 0x00000000}},  //   _flij, _diph, _cypi,
  { {0x290c01cd, 0x57fb009b, 0x322b01e1, 0x00000000}},  //   ljda_, _טלוו, нізм_,
  { {0x6d5a04e7, 0x6d430016, 0x680a006b, 0x00000000}},  // [77f0] _okta, ynna, dədi,
  { {0xb274013b, 0x672400d0, 0x628d0048, 0x00000000}},  //   слуш, _zlij, scao,
  { {0x72d50264, 0xa2d0007d, 0x2ca501c3, 0x00000000}},  //   _конф, _डॉक्, _reld_,
  { {0x6d5a0f68, 0x539a00b6, 0x2ca50635, 0x00000000}},  //   _akta, _שירו, _seld_,
  { {0xdbde009f, 0x6120000c, 0x00000000, 0x00000000}},  //   _síða, _köll,   ,
  { {0x68e10009, 0x5bb507e1, 0x8b050036, 0x00000000}},  //   xeld, асиф, _mięś,
  { {0x68e11bbb, 0x2ca501b5, 0x612029f9, 0x00000000}},  //   veld, _veld_, _möll,
  { {0xe9d90256, 0x09d5008b, 0x2ca5018e, 0x00000000}},  //   вки_, ацоў, _weld_,
  { {0x13de0055, 0xaa45007c, 0x291a0066, 0x00000000}},  //   ডিয়, репл, _ċpar_,
  { {0xe8f6132a, 0x672429fa, 0x7d790167, 0x00000000}},  //   аль_, _slij, _شمار_,
  { {0x6c840054, 0xd706017f, 0x68e10635, 0x00000000}},  //   _المم, азни, reld,
  { {0x3989002a, 0x7bc308a7, 0xe73a007c, 0x00000000}},  //   _tús_, munu, тем_,
  { {0x7b7402fd, 0x7bc3014a, 0x68e105cf, 0x00000000}},  //   _اطلا, lunu, peld,
  { {0x4a440099, 0xdb0a01a2, 0x291e29fb, 0x00000000}},  //   _унів, zufü, ckta_,
  { {0x7bc30890, 0xa956034e, 0x00000000, 0x00000000}},  //   nunu, _דיסק_,   ,
  { {0xf772026c, 0x958609de, 0xc32300e1, 0x00000000}},  //   _بات_, _клие, омск,

  { {0x09b50049, 0x645e0036, 0x7bc31256, 0x00000000}},  // [7800] יפּט_, _wypi, hunu,
  { {0x201a0065, 0x9c7c0340, 0x41032798, 0x00000000}},  //   typi_, _začu, озув,
  { {0x7bc3000c, 0x680a006b, 0xd838129d, 0x00000000}},  //   junu, tədi, baču_,
  { {0x7bc3006c, 0xe806007d, 0xa6e2000c, 0x00000000}},  //   dunu, षमता_, áðhe,
  { {0xcd0610d8, 0x680a006b, 0x4c94138c, 0x00000000}},  //   ички, rədi, билс,
  { {0x21a30595, 0x7e690107, 0x7bc329fc, 0x00000000}},  //   _фирм, _dzep, funu,
  { {0x7bc3000c, 0x5043017a, 0xdee6003b, 0x00000000}},  //   gunu, _дерб, _кови,
  { {0x3f9a00b0, 0x00000000, 0x00000000, 0x00000000}},  //   mppu_,   ,   ,
  { {0x9c7c01ae, 0xacea00ed, 0x00000000, 0x00000000}},  //   _raču, _имаа_,   ,
  { {0x9c7c0091, 0xb4e50061, 0x00000000, 0x00000000}},  //   _saču, _नसे_,   ,
  { {0x4c36007e, 0x291e141a, 0xe8380088, 0x00000000}},  //   _тэат, rkta_, упні_,
  { {0xdc3b009b, 0x7e6000b0, 0x00000000, 0x00000000}},  //   _בעבר, _kymp,   ,
  { {0xb9940025, 0x9f650010, 0x8ccd0061, 0x00000000}},  //   _التب, ítés_, _सामो,
  { {0x612002b9, 0x80c20183, 0x7c2b0279, 0x00000000}},  //   _bölm, _लागे, _ömrü,
  { {0x9388012b, 0x92a700e1, 0x80aa006e, 0x00000000}},  //   иста_, ијал, टरने,
  { {0x6d580428, 0x987b0097, 0xa87b0104, 0x00000000}},  //   hova, _ברוק, _באור,
  { {0x6d580062, 0x673d2915, 0x7bc3019a, 0x00000000}},  // [7810] kova, misj, zunu,
  { {0x6d5801ca, 0x673d00bf, 0x7bc3005d, 0x00000000}},  //   jova, lisj, yunu,
  { {0x6d580027, 0x7e690010, 0x7bc3006b, 0x00000000}},  //   dova, _szep, xunu,
  { {0x673d0056, 0xef19002b, 0xb17b198e, 0x00000000}},  //   nisj, _biża_, _spåd,
  { {0x7f490023, 0x6d580142, 0x00000000, 0x00000000}},  //   _vjeq, fova,   ,
  { {0x7bc30004, 0xeb1f0164, 0x06e30044, 0x00000000}},  //   tunu, बस्त_, যাটি,
  { {0x2005012d, 0x00000000, 0x00000000, 0x00000000}},  //   _šlif_,   ,   ,
  { {0x7bc3038c, 0x673d0065, 0xcda90431, 0x00000000}},  //   runu, jisj, _مهره_,
  { {0x7bc329fd, 0x3d94025f, 0x6d580387, 0x00000000}},  //   sunu, _митр, bova,
  { {0x6d580428, 0x7bc3006b, 0x661d29fe, 0x00000000}},  //   cova, punu, dysk,
  { {0xbb850054, 0x753c0089, 0xe1ff0010, 0x00000000}},  //   _الصي, virz, _szól_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xcb12019b, 0xe73707d0, 0x98780089, 0x00000000}},  //   _מלא_, сея_, kšķi_,
  { {0xf992009b, 0xa5c7000c, 0x00000000, 0x00000000}},  //   _צרו_, _stóð,   ,
  { {0x61200073, 0x232a092b, 0xc79503ec, 0x00000000}},  //   _följ, гови_, _اشتب,
  { {0x6d58061b, 0xe7ec02fb, 0x6d5d000c, 0x00000000}},  //   zova, _जनता_, _ísaf,
  { {0x95c900ed, 0xe0da0ab6, 0x00000000, 0x00000000}},  // [7820] _куќа_, лва_,   ,
  { {0xd00a026b, 0x7e6001d6, 0xa0a6073b, 0x00000000}},  //   лезе_, _rymp, сажд,
  { {0x6d580428, 0xa2e6026b, 0x63a9016c, 0x00000000}},  //   vova, _лонд, ćenc,
  { {0x3f9a0f80, 0x6b8800fa, 0x7e600544, 0x00000000}},  //   rppu_, _rudg, _pymp,
  { {0x9c7c01d9, 0x60d70045, 0x00000000, 0x00000000}},  //   _načr, bfxm,   ,
  { {0x40ab00a2, 0xef19002b, 0x00000000, 0x00000000}},  //   _مخفی_, _viża_,   ,
  { {0x6d580027, 0x661d0036, 0x988800a1, 0x00000000}},  //   rova, zysk, یحدہ_,
  { {0x6d580027, 0x7e600052, 0x79e6009e, 0x00000000}},  //   sova, _tymp, موعہ_,
  { {0x6d580387, 0x5e4a0888, 0x673d29ff, 0x00000000}},  //   pova, _спам_, visj,
  { {0x3f8a008a, 0x00000000, 0x00000000, 0x00000000}},  //   _kubu_,   ,   ,
  { {0xa3e703d7, 0x415b0049, 0x673d1256, 0x00000000}},  //   _मैं_, רדיג, tisj,
  { {0x95cb0726, 0x661d00b0, 0x62860058, 0x00000000}},  //   луга_, tysk, _ngko,
  { {0x673d2a00, 0x2bc60061, 0x00000000, 0x00000000}},  //   risj, रंवा,   ,
  { {0x92c50055, 0x3f980089, 0x673d0056, 0x00000000}},  //   _এসে_, _otru_, sisj,
  { {0x9c7c050f, 0x3f8a0045, 0x00000000, 0x00000000}},  //   _začr, _nubu_,   ,
  { {0x69c00197, 0x1fce0044, 0x6b8200e7, 0x00000000}},  //   orme, রবাস, _jiog,
  { {0x60870025, 0xb1150072, 0xd7f80035, 0x00000000}},  // [7830] مشاك, омаш, lvă_,
  { {0x69c00051, 0x3f8a00e7, 0xdb182a01, 0x00000000}},  //   irme, _bubu_, luvä,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x01c9026c, 0x26cb016b, 0x3f8a10d4, 0x00000000}},  //   _پوسٹ_, ngco_, _dubu_,
  { {0xa227023c, 0xf1ab0025, 0x3f98037a, 0x00000000}},  //   _طرحه, _حاجه_, _etru_,
  { {0xa1941602, 0x61ef00f6, 0xe3b000a6, 0x00000000}},  //   _харч, _iscl, _تری_,
  { {0x251c007b, 0xeb99041f, 0x4431012d, 0x00000000}},  //   רווא, ший_, nzz_,
  { {0x443100fa, 0x61fb0066, 0x00000000, 0x00000000}},  //   izz_, _ġulj,   ,
  { {0x6b822a02, 0x69c0012d, 0x00000000, 0x00000000}},  //   _diog, grme,   ,
  { {0x3eaf01e3, 0x92c50044, 0x78a9003b, 0x00000000}},  //   lagt_, _এসো_, шког_,
  { {0x186905a5, 0xd70a008b, 0x574a0437, 0x00000000}},  //   рани_, анне_, изом_,
  { {0x81e00044, 0x6b822a03, 0x61ef07da, 0x00000000}},  //   থিত_, _giog, _oscl,
  { {0x3cfe0061, 0x6a670688, 0x00000000, 0x00000000}},  //   लाचे_, _اطال,   ,
  { {0xfbdd0164, 0x612001a2, 0x6b820026, 0x00000000}},  //   _महाम, _völk, _ziog,
  { {0x48ee001c, 0xa879007b, 0x61ef1560, 0x00000000}},  //   _असतो_, _דאַר, _ascl,
  { {0x7983010f, 0xe29a00ed, 0x3eaf0296, 0x00000000}},  //   _hinw, раа_, jagt_,
  { {0x6aab0047, 0x61ef0009, 0x798300e0, 0x00000000}},  // [7840] _megf, _cscl, _kinw,
  { {0x6aab0047, 0x798b0045, 0x00000000, 0x00000000}},  //   _legf, _mugw,   ,
  { {0x61ef0207, 0x79832a04, 0x4fea02dc, 0x00000000}},  //   _escl, _minw, рмен_,
  { {0x9e6601fb, 0x57cc0049, 0x00000000, 0x00000000}},  //   овед, רמאַ,   ,
  { {0x2ee60133, 0x00000000, 0x00000000, 0x00000000}},  //   reof_,   ,   ,
  { {0x412a07ca, 0x3f8a0066, 0xd65700b3, 0x00000000}},  //   _того_, _tubu_, חינת_,
  { {0xdcfa001e, 0x2ee6158d, 0x6b820207, 0x00000000}},  //   _citā, peof_, _piog,
  { {0x798b0009, 0x81bd0044, 0x00000000, 0x00000000}},  //   _bugw, _আহত_,   ,
  { {0x4431016e, 0x6b820146, 0x69c000d9, 0x00000000}},  //   zzz_, _viog, urme,
  { {0xdce80089, 0xdddb04eb, 0x00000000, 0x00000000}},  //   _vidē, _uguš,   ,
  { {0xf093034e, 0xab2a01e0, 0x3f842170, 0x00000000}},  //   ונת_, _кожа_, _kimu_,
  { {0x7983010f, 0x5694004c, 0xc878014a, 0x00000000}},  //   _einw, мают, neği_,
  { {0xceb3034e, 0x6d4a0197, 0x2cac0010, 0x00000000}},  //   ויר_, onfa, _kedd_,
  { {0x6d4a2a05, 0x79830058, 0x2cac0066, 0x00000000}},  //   nnfa, _ginw, _jedd_,
  { {0x68e80193, 0x442501ca, 0x6d4a01c5, 0x00000000}},  //   medd, ál_, infa,
  { {0x68e81c95, 0x80d801f5, 0x2cac01e2, 0x00000000}},  //   ledd, न्से, _ledd_,
  { {0x8c3c1355, 0x2cac018e, 0x00000000, 0x00000000}},  // [7850] _deği, _oedd_,   ,
  { {0x68e80016, 0x2cac0016, 0x61fd012d, 0x00000000}},  //   nedd, _nedd_, _vrsl,
  { {0x3eaf010f, 0x00000000, 0x00000000, 0x00000000}},  //   tagt_,   ,   ,
  { {0x68e80016, 0x6d4a00d9, 0x25a900d9, 0x00000000}},  //   hedd, enfa, _kwal_,
  { {0x7de70054, 0xc332007b, 0x3eaf0302, 0x00000000}},  //   تسام, _טוט_, ragt_,
  { {0x3eaf010f, 0x78a10009, 0x61ed2839, 0x00000000}},  //   sagt_, xblv, mwal,
  { {0x61ed2a06, 0x68e8005b, 0x00000000, 0x00000000}},  //   lwal, dedd,   ,
  { {0xc878014a, 0x7e7d0161, 0x3ce700c4, 0x00000000}},  //   ceği_, _úspo, senv_,
  { {0x61ed1796, 0x79830435, 0x7b1c009d, 0x00000000}},  //   nwal, _pinw, _réut,
  { {0x3ead0250, 0x3f84049c, 0x81e50044, 0x00000000}},  //   _heet_, _zimu_, পটপ_,
  { {0x25a9020c, 0x09e10044, 0x3f85009d, 0x00000000}},  //   _awal_, বিধা, _élus_,
  { {0x61ed0168, 0xd5b80089, 0xf7720464, 0x00000000}},  //   kwal, ņām_, عاد_,
  { {0x2d850020, 0x7ae9006c, 0x3ead00ab, 0x00000000}},  //   _kile_, meet, _meet_,
  { {0x61ed002b, 0x7ae9002d, 0x25a9002b, 0x00000000}},  //   dwal, leet, _dwal_,
  { {0x69c900b0, 0x29070036, 0x2d850490, 0x00000000}},  //   luee, _inna_, _mile_,
  { {0x7ae92032, 0x2d850020, 0x2b910011, 0x00000000}},  //   neet, _lile_, _mác_,
  { {0x26d20061, 0x61ed0058, 0x7bc301ca, 0x00000000}},  // [7860] _icyo_, gwal, hrnu,
  { {0x3f84000b, 0x7ae90d6f, 0x2d8503ef, 0x00000000}},  //   _simu_, heet, _nile_,
  { {0x3ead0116, 0x2cac00ea, 0x7ae92a07, 0x00000000}},  //   _beet_, _redd_, keet,
  { {0x2d85014a, 0x2cac0909, 0x3ead004a, 0x00000000}},  //   _aile_, _sedd_, _ceet_,
  { {0x2d85011f, 0x7ae9002d, 0x5dda026b, 0x00000000}},  //   _bile_, deet, сфер_,
  { {0x2b91001d, 0x6d4a008e, 0x5ba600ed, 0x00000000}},  //   _bác_, unfa, приз,
  { {0x2b9100ad, 0x3f84000b, 0x6d4a0210, 0x00000000}},  //   _các_, _timu_, rnfa,
  { {0x2d852a08, 0x29070292, 0xb9980088, 0x00000000}},  //   _eile_, _anna_, ових_,
  { {0x2d8513ec, 0xdcfa00e5, 0x2cac0232, 0x00000000}},  //   _file_, _cită, _tedd_,
  { {0xfe4500a6, 0x2918000c, 0x2d850145, 0x00000000}},  //   _تکمی, ðra_, _gile_,
  { {0x7d080018, 0x61ed0036, 0xbc6a0151, 0x00000000}},  //   _inds, zwal, _امان_,
  { {0x2d852a09, 0x68e80016, 0x25a901aa, 0x00000000}},  //   _zile_, sedd, _pwal_,
  { {0x7d1a006a, 0x58d400ed, 0x69c900d9, 0x00000000}},  //   _kots, _жолт, cuee,
  { {0x58d301f9, 0x61ed01aa, 0x2d8500d4, 0x00000000}},  //   _зошт, vwal, _xile_,
  { {0x2b91001d, 0x7d1a093b, 0x61ed01f3, 0x00000000}},  //   _xác_, _mots, wwal,
  { {0x61ed002b, 0xe3b006b4, 0x7d1a002d, 0x00000000}},  //   twal, طرف_, _lots,
  { {0x8ccd013d, 0x3ead2988, 0x7d0802e7, 0x00000000}},  // [7870] _सालो, _reet_, _onds,
  { {0x61ed010f, 0x395e0089, 0x7bca06a4, 0x00000000}},  //   rwal, nots_, kufu,
  { {0x61ed000b, 0x3ead0168, 0x672d0089, 0x00000000}},  //   swal, _peet_, _klaj,
  { {0x7d080fc7, 0x2b910011, 0x2d850091, 0x00000000}},  //   _ands, _rác_, _sile_,
  { {0x6e220047, 0x672d2a0a, 0x7d1a0dcc, 0x00000000}},  //   gyob, _mlaj, _bots,
  { {0x3ead0100, 0x7bca0020, 0x7ae900d9, 0x00000000}},  //   _weet_, fufu, weet,
  { {0xdd91026c, 0x2d85000b, 0x7ae92a0b, 0x00000000}},  //   روں_, _vile_, teet,
  { {0x394c0038, 0x69c90cf0, 0x2d852a0c, 0x00000000}},  //   ends_, tuee, _wile_,
  { {0x1dd102f4, 0xedd50137, 0x7ae90114, 0x00000000}},  //   _समित, _زياد, reet,
  { {0x2b91001d, 0x2d850051, 0x395e08f7, 0x00000000}},  //   _tác_, _uile_, gots_,
  { {0x6120009f, 0x6f1b01aa, 0x672d01a3, 0x00000000}},  //   _tölv, _kouc, _blaj,
  { {0x6d431de7, 0x98ad038c, 0x394c0068, 0x00000000}},  //   lina, ının_, ands_,
  { {0x395e0056, 0x6f1b2a0d, 0x61200047, 0x00000000}},  //   bots_, _mouc, _költ,
  { {0x684501be, 0x6f1b0181, 0x6d432a0e, 0x00000000}},  //   _онла, _louc, nina,
  { {0x3cf003d7, 0x672d0107, 0x00000000, 0x00000000}},  //   _इससे_, _flaj,   ,
  { {0x6d43006a, 0x6f1b1a40, 0x2b4d009d, 0x00000000}},  //   hina, _nouc, nnec_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [7880]   ,   ,   ,
  { {0x6d4308a9, 0x69c60059, 0x6f09009d, 0x00000000}},  //   jina, škeg, _anec,
  { {0x6f1b11aa, 0x7d1a1aef, 0xdb0a0065, 0x00000000}},  //   _bouc, _rots, ënës,
  { {0xf41301f8, 0x7d1a0004, 0x3f9c0089, 0x00000000}},  //   _ספר_, _sots, īvu_,
  { {0x7d1a0129, 0xdd8f0379, 0x9f650010, 0x00000000}},  //   _pots, لون_, ítás_,
  { {0x7bca2839, 0x6f0900d9, 0xb0dd006e, 0x00000000}},  //   tufu, _enec, न्दग,
  { {0xfbcf057d, 0x6f1b02b6, 0x395e01c5, 0x00000000}},  //   لتي_, _fouc, vots_,
  { {0x7bca2a0f, 0x1b770025, 0x776401f3, 0x00000000}},  //   rufu, وصية_, _nkix,
  { {0x6d430263, 0x7bd8003b, 0x3ea603b0, 0x00000000}},  //   bina, stvu, mbot_,
  { {0x6d430325, 0x6120009f, 0x3ea60016, 0x00000000}},  //   cina, _tölu, lbot_,
  { {0xcb6a0680, 0x672d0a29, 0x395e0089, 0x00000000}},  //   _даже_, _plaj, rots_,
  { {0x61e60fdf, 0x613218f9, 0x3a26004d, 0x00000000}},  //   _opkl, _fælg, _омег,
  { {0x672d01ca, 0x7ae22a10, 0x3dc60009, 0x00000000}},  //   _vlaj, _ibot, nrow_,
  { {0xb3470181, 0xe4e40088, 0x249a0146, 0x00000000}},  //   _opçõ, кісн, _cfpm_,
  { {0x61e6010a, 0x672d1bf3, 0x3ea60058, 0x00000000}},  //   _apkl, _tlaj, kbot_,
  { {0x68f80018, 0x6d430006, 0x672d00e7, 0x00000000}},  //   _havd, zina, _ulaj,
  { {0x291c0ef7, 0x3495007e, 0x25090014, 0x00000000}},  // [7890] _kova_, _папр, _فردی_,
  { {0x6d43049a, 0xeb1b001c, 0x6f1b2a11, 0x00000000}},  //   xina, _फक्त_, _souc,
  { {0xa3d603d7, 0x6f1b02d5, 0x6d430213, 0x00000000}},  //   _समय_, _pouc, vina,
  { {0x291c2a12, 0x6d43023a, 0x68f80065, 0x00000000}},  //   _lova_, wina, _lavd,
  { {0x6d432a13, 0xf48502fd, 0x6f090082, 0x00000000}},  //   tina, _تاکی, _vnec,
  { {0x0d8401fb, 0x68f80059, 0x3ea6011c, 0x00000000}},  //   влін, _navd, abot_,
  { {0x61320018, 0x3ea61233, 0x5ff42a14, 0x00000000}},  //   _sælg, bbot_, _изру,
  { {0x6d432a15, 0x3dc60541, 0x00000000, 0x00000000}},  //   sina, brow_,   ,
  { {0x6d43006a, 0x2734001d, 0x61200047, 0x00000000}},  //   pina, _hãng_, _tölt,
  { {0x61320018, 0x291c06c0, 0x63a90166, 0x00000000}},  //   _vælg, _cova_, ćenj,
  { {0x6d412a16, 0x31580049, 0x7ae20026, 0x00000000}},  //   _imla, ויזן_, _fbot,
  { {0x06b00044, 0xe73201d8, 0xdb0a04ce, 0x00000000}},  //   _কাহি, اصد_, gsfä,
  { {0xa6db009f, 0x27340011, 0x68f80087, 0x00000000}},  //   miðl, _lãng_, _favd,
  { {0x7afb002d, 0x61320190, 0x69db0023, 0x00000000}},  //   ldut, _kæle, mtue,
  { {0x394500f6, 0x18750049, 0x3ea61063, 0x00000000}},  //   mils_, _אײַך_, ybot_,
  { {0x7afb022b, 0x14170025, 0x23b1007d, 0x00000000}},  //   ndut, ريقة_, _जबरद,
  { {0x6d410056, 0x64620046, 0x3ea601aa, 0x00000000}},  // [78a0] _omla, _świę, vbot_,
  { {0x25a001aa, 0x20560072, 0x394500d4, 0x00000000}},  //   _itil_, нтер, nils_,
  { {0x9c7c0165, 0x14d701ce, 0x3ea0008e, 0x00000000}},  //   _obča, _אויל_, ñito_,
  { {0x66040006, 0x3f91022b, 0x69db002d, 0x00000000}},  //   _krik, _duzu_, ktue,
  { {0x0cd404ef, 0x69db0065, 0x3ea60b8a, 0x00000000}},  //   волю, jtue, rbot_,
  { {0x3dc600ab, 0x7ae203c5, 0x00000000, 0x00000000}},  //   rrow_, _sbot,   ,
  { {0x3f910209, 0x26c00e32, 0xd47a0049, 0x00000000}},  //   _guzu_, _odio_, האַל,
  { {0x26c0000b, 0x6d41011f, 0x69db0065, 0x00000000}},  //   _ndio_, _emla, ftue,
  { {0x39452a17, 0x68f80023, 0x25a000f6, 0x00000000}},  //   fils_, _pavd, _ntil_,
  { {0x26c00035, 0x3945088f, 0xadb70025, 0x00000000}},  //   _adio_, gils_, _أهلا_,
  { {0x66042a18, 0x26c0016c, 0x3137009b, 0x00000000}},  //   _arik, _bdio_, גנים_,
  { {0xd6db007c, 0x00000000, 0x00000000, 0x00000000}},  //   что_,   ,   ,
  { {0xa3d3001c, 0x69db2a19, 0x6d41018e, 0x00000000}},  //   हून_, ctue, _ymla,
  { {0x66040637, 0x39452a1a, 0x291c0197, 0x00000000}},  //   _drik, cils_, _uova_,
  { {0x6604021e, 0x06b00044, 0x00000000, 0x00000000}},  //   _erik, _কারি,   ,
  { {0x66040065, 0x2b09013d, 0x07f70025, 0x00000000}},  //   _frik, वाएँ_, _أروع_,
  { {0x60f90783, 0x64590036, 0x66042a1b, 0x00000000}},  // [78b0] мная_, _świd, _grik,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf650026c, 0xf8b300a3, 0x853c009b, 0x00000000}},  //   _نئی_, רשע_, _מגזי,
  { {0x27340082, 0x7c3d006b, 0xdcb10082, 0x00000000}},  //   _vãng_, _əsrd, _sẻ_,
  { {0x7afb002b, 0x69db009d, 0x00000000, 0x00000000}},  //   vdut, xtue,   ,
  { {0xfce501f9, 0x00000000, 0x00000000, 0x00000000}},  //   токо,   ,   ,
  { {0x7afb00e0, 0x00000000, 0x00000000, 0x00000000}},  //   tdut,   ,   ,
  { {0x69db0052, 0x7afb0052, 0x00000000, 0x00000000}},  //   ttue, udut,   ,
  { {0x394500f4, 0x7afb002d, 0xdd950147, 0x00000000}},  //   tils_, rdut, _разы,
  { {0x6d4101a2, 0xfe6e0014, 0x7afb0026, 0x00000000}},  //   _umla, _بگم_, sdut,
  { {0xf092019b, 0x39450129, 0x69db002d, 0x00000000}},  //   יני_, rils_, stue,
  { {0x660411e6, 0x69db0065, 0x628f01c3, 0x00000000}},  //   _prik, ptue, _ngco,
  { {0x39451b5a, 0x69350517, 0xbb3a0049, 0x00000000}},  //   pils_, _инду, _קעני,
  { {0x629d244f, 0x628f0026, 0x6aa92a1c, 0x00000000}},  //   _afso, _agco, lbef,
  { {0x628f0365, 0x6b8b0030, 0x442c0a87, 0x00000000}},  //   _bgco, _kigg, ád_,
  { {0x6b8b002b, 0x69c92a1d, 0x6aa92a1e, 0x00000000}},  //   _jigg, oree, nbef,
  { {0x25a0001a, 0x877b0049, 0x69c900d9, 0x00000000}},  // [78c0] _util_, _קאפי, nree,
  { {0x64590046, 0x45b70049, 0xb5b70097, 0x00000000}},  //   _świe, _שפיל_, _שליח_,
  { {0x69c902ae, 0x628f0045, 0xd2aa01ab, 0x00000000}},  //   hree, _fgco, _окне_,
  { {0x25ad001a, 0x69c9010e, 0x00000000, 0x00000000}},  //   ţele_, kree,   ,
  { {0xf2d300bd, 0xe1ff0036, 0xdce1000a, 0x00000000}},  //   _דער_, _wzór_, _eklč,
  { {0xa0a300ed, 0x69c9001a, 0x00000000, 0x00000000}},  //   _вард, dree,   ,
  { {0x6b8b00ab, 0x656e0048, 0x00000000, 0x00000000}},  //   _bigg, ilbh,   ,
  { {0x7bc5004a, 0x6b8b0203, 0xac25007e, 0x00000000}},  //   áhua, _cigg, ыфік,
  { {0x7de50084, 0x63a90363, 0x6b8b0aa4, 0x00000000}},  //   _مسلم, ćeni, _digg,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c90052, 0x00000000, 0x00000000, 0x00000000}},  //   aree,   ,   ,
  { {0xfaa6012b, 0x69c90007, 0x6b8b0b04, 0x00000000}},  //   _радо, bree, _gigg,
  { {0x2d8c002d, 0x69dc0035, 0x6a160f8b, 0x00000000}},  //   _kide_, ăres, _جبار,
  { {0x2d8c0f65, 0x6b8b00bb, 0x00000000, 0x00000000}},  //   _jide_, _zigg,   ,
  { {0x2d8c1fe7, 0x290e0093, 0x9f5f0023, 0x00000000}},  //   _mide_, _infa_, ërën_,
  { {0x2d8c2a1f, 0x656e0051, 0x81e70044, 0x00000000}},  //   _lide_, albh, ভিস_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [78d0]   ,   ,   ,
  { {0x44f507ca, 0x2d8c0087, 0x00000000, 0x00000000}},  //   _спос, _nide_,   ,
  { {0x628f0197, 0xb4c10309, 0x00000000, 0x00000000}},  //   _tgco, ुली_,   ,
  { {0x2d8c028c, 0x66020b4d, 0x69c9055f, 0x00000000}},  //   _aide_, _šoki, yree,
  { {0x6b8b0186, 0x2d8c0a3f, 0xdcb10082, 0x00000000}},  //   _rigg, _bide_, _hỏi_,
  { {0x6b8b000c, 0x69c901bb, 0xbebd0e3f, 0x00000000}},  //   _sigg, vree, _plūs,
  { {0x6b8b00f8, 0x00000000, 0x00000000, 0x00000000}},  //   _pigg,   ,   ,
  { {0x69c90277, 0x2b9800f4, 0x2d8c0056, 0x00000000}},  //   tree, _déc_, _eide_,
  { {0xc33400b6, 0x6b8b101b, 0x6aa901a2, 0x00000000}},  //   יוק_, _vigg, rbef,
  { {0x2d8c0173, 0x69c9002d, 0x3f8d0011, 0x00000000}},  //   _gide_, rree, _hieu_,
  { {0x6b8b1742, 0x7ad50084, 0x3f8d0082, 0x00000000}},  //   _tigg, _مقاص, _kieu_,
  { {0x69c90181, 0xe5a6003b, 0x28a30061, 0x00000000}},  //   pree, лими, _ख्रि,
  { {0x26de0036, 0x3f8d2a20, 0x4df90049, 0x00000000}},  //   ęto_, _mieu_, עפֿא,
  { {0x3f8d028c, 0x98a2007c, 0x00000000, 0x00000000}},  //   _lieu_, _лише,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3f8d0007, 0xdceb002b, 0x00000000, 0x00000000}},  //   _nieu_, bqgħ,   ,
  { {0x9f5e028c, 0x0206007e, 0x00000000, 0x00000000}},  // [78e0] _été_, ызан,   ,
  { {0x98be001a, 0xd5b80089, 0x7981005b, 0x00000000}},  //   mită_, ņās_, nmlw,
  { {0x25b20016, 0x2d8c0edd, 0x232a2a21, 0x00000000}},  //   _hwyl_, _ride_, _зони_,
  { {0x2d8c25d4, 0x25b201c3, 0x5fc9007d, 0x00000000}},  //   _side_, _kwyl_, ांजल,
  { {0x3f8d1eac, 0x2d8c0211, 0x98be001a, 0x00000000}},  //   _dieu_, _pide_, nită_,
  { {0x61460a94, 0x00000000, 0x00000000, 0x00000000}},  //   _сега,   ,   ,
  { {0x0b8a00a8, 0x7b6600e2, 0xc4d3009b, 0x00000000}},  //   нсии_, лтие, צגה_,
  { {0x3cf003d7, 0x2d8c00ab, 0x705301d8, 0x00000000}},  //   _इसके_, _wide_, _انفا,
  { {0x2d8c004e, 0x5f11001c, 0x094a0751, 0x00000000}},  //   _tide_, णार्_, ечни_,
  { {0xa6db000c, 0x2b9800fa, 0xc237009b, 0x00000000}},  //   miði, _téc_, טרפו_,
  { {0x7c930054, 0xa6db000c, 0x5c56004d, 0x00000000}},  //   _المص, liði, _стаф,
  { {0x6d4a00f0, 0x8c1b0104, 0x9a6a0025, 0x00000000}},  //   lifa, _רואי, _كمال_,
  { {0xdb0a043e, 0x29180274, 0x7c2a0de7, 0x00000000}},  //   dsfø, öras_, lyfr,
  { {0x6d4a01d5, 0xdb011a40, 0xb4c1007d, 0x00000000}},  //   nifa, _atlè, ुले_,
  { {0x78ba01c5, 0xa0240044, 0xd37b0679, 0x00000000}},  //   matv, _যেসব_, еча_,
  { {0x6d4a0020, 0x78ba1b25, 0x98be0035, 0x00000000}},  //   hifa, latv, bită_,
  { {0x6d4a0020, 0x7c2a0016, 0xc2f70044, 0x00000000}},  // [78f0] kifa, hyfr, ঙালি_,
  { {0x6d4a0020, 0xf1c80025, 0x3f8d0082, 0x00000000}},  //   jifa, اولى_, _sieu_,
  { {0x6d4a1b27, 0x20072a22, 0x7a480089, 0x00000000}},  //   difa, íni_, lītī,
  { {0x672f0046, 0x63a50085, 0x7c2a005b, 0x00000000}},  //   nkcj, _ithn, dyfr,
  { {0x386e0016, 0x6d4a0093, 0xdce1002b, 0x00000000}},  //   _lyfr_, fifa, _jilħ,
  { {0xdce101f3, 0x00000000, 0x00000000, 0x00000000}},  //   _milħ,   ,   ,
  { {0x3f8d0082, 0x78ba0082, 0x98be0035, 0x00000000}},  //   _tieu_, datv, zită_,
  { {0x64dc0061, 0x3cfe00e7, 0x21230087, 0x00000000}},  //   _बाभळ, _eatv_, _hojh_,
  { {0x6d4a2a23, 0xdce10066, 0x00000000, 0x00000000}},  //   bifa, _nilħ,   ,
  { {0x3945004c, 0x98be001a, 0xbb4400b0, 0x00000000}},  //   рног, vită_, äärä,
  { {0xe73a0200, 0x2eff010f, 0xb461006b, 0x00000000}},  //   вен_, _kauf_, çülə,
  { {0xc9f5002c, 0xdce101f3, 0x98be0035, 0x00000000}},  //   _نستع, _bilħ, tită_,
  { {0x78ba0030, 0x63a50051, 0x00000000, 0x00000000}},  //   batv, _athn,   ,
  { {0x64590046, 0x6abb010f, 0x98be001a, 0x00000000}},  //   _świa, lauf, rită_,
  { {0xdb010181, 0xf77300a1, 0x8883007a, 0x00000000}},  //   _atlé, _ڈاٹ_, _دیدن,
  { {0x97c4007a, 0x6abb010f, 0x6d4a0020, 0x00000000}},  //   _اتوم, nauf, zifa,
  { {0x63a507be, 0xe0da05a5, 0x4736089d, 0x00000000}},  // [7900] _ethn, ква_, _مرکز,
  { {0x399b02d5, 0x6abb186a, 0xdb0a00ea, 0x00000000}},  //   _mês_, hauf, ssfø,
  { {0x6abb010f, 0x61f60016, 0xd00f0025, 0x00000000}},  //   kauf, swyl, ولك_,
  { {0xdee6012b, 0x7c2e010f, 0x539b0104, 0x00000000}},  //   роди, _übri, _שיכו,
  { {0x6d4a2a24, 0x3ea9004a, 0x4df601ab, 0x00000000}},  //   tifa, ñata_, ряет,
  { {0xa6db01e5, 0x00000000, 0x00000000, 0x00000000}},  //   riði,   ,   ,
  { {0x6d4a0fa2, 0x78ba0be1, 0x80ad0044, 0x00000000}},  //   rifa, vatv, _চাচ্,
  { {0x6d4a01a3, 0x98a50006, 0xd00f0257, 0x00000000}},  //   sifa, filį_, _تلف_,
  { {0x3f98000b, 0x3cfe0022, 0x6da3017a, 0x00000000}},  //   _huru_, _tatv_, _мита,
  { {0x3f98150a, 0x6f002a25, 0x7aa60061, 0x00000000}},  //   _kuru_, _hamc, _ट्रॅ,
  { {0x3f982a26, 0x6d480066, 0x78ba00eb, 0x00000000}},  //   _juru_, _imda, ratv,
  { {0x09e60920, 0x6f020724, 0x98a50006, 0x00000000}},  //   _водн, ndoc, bilį_,
  { {0x09e3007e, 0x29110051, 0x78ba1288, 0x00000000}},  //   _моцн, ánaí_, patv,
  { {0x200a0b94, 0x7a790049, 0x69c003e3, 0x00000000}},  //   _orbi_, _גרױס, msme,
  { {0x69c008d5, 0x397b0049, 0x3f980c04, 0x00000000}},  //   lsme, _שטונ, _nuru_,
  { {0x394c1a86, 0x6f0001ee, 0xdce10066, 0x00000000}},  //   lids_, _namc, _tilħ,
  { {0x69c00065, 0x6d482a27, 0x6f020016, 0x00000000}},  // [7910] nsme, _omda, ddoc,
  { {0x2eff00f4, 0x394c041d, 0x3f982a28, 0x00000000}},  //   _sauf_, nids_, _buru_,
  { {0x3f9800e5, 0x00000000, 0x00000000, 0x00000000}},  //   _curu_,   ,   ,
  { {0x69c0001e, 0x6d48018e, 0x671a013d, 0x00000000}},  //   ksme, _amda, धायक_,
  { {0xdef81036, 0xa3d30316, 0x69c0145e, 0x00000000}},  //   рых_, हूर_, jsme,
  { {0xa3be013d, 0x69c01f8e, 0xee380245, 0x00000000}},  //   ुंच_, dsme, шні_,
  { {0x3f98020c, 0xadc3001d, 0x6f0200bb, 0x00000000}},  //   _guru_, _trắn, bdoc,
  { {0x59c201f5, 0x6d480173, 0x545800b3, 0x00000000}},  //   _शिखर, _emda, יבוב_,
  { {0x6abb010f, 0xdce31332, 0x69c0000c, 0x00000000}},  //   rauf, lonč, gsme,
  { {0x9be701fb, 0x394c01b5, 0x6abb010f, 0x00000000}},  //   _відк, gids_, sauf,
  { {0xc6890104, 0xba4500a1, 0x2911005d, 0x00000000}},  //   _נא_, شنگٹ, ıza_,
  { {0x7d010193, 0xe73a0783, 0x81bd0044, 0x00000000}},  //   _hals, уем_, _ইমন_,
  { {0xa3da001c, 0x7d012a29, 0x2b4d0036, 0x00000000}},  //   डून_, _kals, miec_,
  { {0xdce30387, 0x2b4d2a2a, 0x00000000, 0x00000000}},  //   konč, liec_,   ,
  { {0x7d012a2b, 0x61fd0022, 0x1dd1013d, 0x00000000}},  //   _mals, _assl, _समझत,
  { {0x2b4d05fd, 0xdce3016c, 0x3f982a2c, 0x00000000}},  //   niec_, donč, _ruru_,
  { {0x200a021d, 0x61320030, 0x3f980052, 0x00000000}},  // [7920] _srbi_, _fæll, _suru_,
  { {0x1dd10061, 0xb69b1429, 0x7d010087, 0x00000000}},  //   _समजत, ndân, _nals,
  { {0x61fd01a2, 0x3f98013f, 0x00000000, 0x00000000}},  //   _essl, _quru_,   ,
  { {0xee3a012b, 0x1e8602dc, 0x7d0100bb, 0x00000000}},  //   лне_, блем, _aals,
  { {0x7d010ebc, 0x81e70044, 0x00000000, 0x00000000}},  //   _bals, ভিউ_,   ,
  { {0x3f9601f9, 0x69c000d8, 0x3f98078f, 0x00000000}},  //   _граѓ, vsme, _turu_,
  { {0x7d0105e1, 0x78b80436, 0x394c01c5, 0x00000000}},  //   _dals, _revv, vids_,
  { {0x69c01693, 0x5a341666, 0x61e42a2d, 0x00000000}},  //   tsme, жнит, otil,
  { {0x7d010406, 0x394c0239, 0x69c01081, 0x00000000}},  //   _fals, tids_, usme,
  { {0x69c00089, 0xce3700b3, 0xa3d30164, 0x00000000}},  //   rsme, _האמת_, हूँ_,
  { {0x9c7c086e, 0xab960025, 0x394c02e7, 0x00000000}},  //   _obči, _الصغ, rids_,
  { {0x3f8601aa, 0x61e4006c, 0x394c00f6, 0x00000000}},  //   nmou_, ktil, sids_,
  { {0x8b650054, 0xe6670680, 0xe9180451, 0x00000000}},  //   _بالم, стно, _волі_,
  { {0x61e42a2e, 0x29020089, 0x22400036, 0x00000000}},  //   dtil, ēkas_, dzik_,
  { {0xa3d3013d, 0x6b9a0129, 0x61e42a2f, 0x00000000}},  //   हूं_, _jutg, etil,
  { {0xe6160059, 0xdb0300f8, 0x388e006b, 0x00000000}},  //   žišč, ssnö, mər_,
  { {0x388e0163, 0x61e416ec, 0x61320030, 0x00000000}},  // [7930] lər_, gtil, _tæll,
  { {0x660d022b, 0x25a90232, 0x3d02013d, 0x00000000}},  //   _irak, _ital_, लयों_,
  { {0xd01106b4, 0x7d0105d2, 0x273b0065, 0x00000000}},  //   بلا_, _rals, _tënd_,
  { {0x660d0046, 0x7d010e1d, 0x61e4007f, 0x00000000}},  //   _krak, _sals, btil,
  { {0x388e005f, 0x7d012a30, 0x00000000, 0x00000000}},  //   hər_, _pals,   ,
  { {0xc30108b7, 0x2b4d0036, 0x6d58000c, 0x00000000}},  //   _একটি_, wiec_, gnva,
  { {0x7d010ebc, 0xeab10025, 0xcda90014, 0x00000000}},  //   _vals, وعة_, _چهره_,
  { {0x388e005f, 0x6d580007, 0x3c070082, 0x00000000}},  //   dər_, anva, _vđv_,
  { {0x7d0116ae, 0x7e7b0036, 0x28d4013d, 0x00000000}},  //   _tals, _uzup, _दाखि,
  { {0x388e005f, 0x47c5007c, 0x57e903c0, 0x00000000}},  //   fər_, обов, адом_,
  { {0x388e005f, 0x25a90c54, 0x660d1b01, 0x00000000}},  //   gər_, _atal_, _arak,
  { {0x78a1001c, 0x61e40b22, 0x7c3d006b, 0x00000000}},  //   sclv, ytil, _əsrl,
  { {0xe57a0077, 0xba2b0464, 0x00000000, 0x00000000}},  //   изм_, _حسام_,   ,
  { {0x388e005f, 0x660d0056, 0x7ae908ed, 0x00000000}},  //   bər_, _drak, lfet,
  { {0x660d25d5, 0xe7b50054, 0x7bc30479, 0x00000000}},  //   _erak, _بمعد, nsnu,
  { {0x660d0039, 0xe2970153, 0x7ae91529, 0x00000000}},  //   _frak, жат_, nfet,
  { {0x6b5e0089, 0x91e300e2, 0x00000000, 0x00000000}},  // [7940] nīga, моте,   ,
  { {0x29050039, 0x61e42a31, 0xb17b0039, 0x00000000}},  //   ndla_, rtil, _spår,
  { {0x61e4233f, 0x660d016e, 0x22400010, 0x00000000}},  //   stil, _zrak, szik_,
  { {0x6b9a020f, 0xd47b0104, 0xdce0006b, 0x00000000}},  //   _rutg, _כאיל, _rumı,
  { {0x388e005f, 0x3f86271a, 0x6b9a00f6, 0x00000000}},  //   zər_, rmou_, _sutg,
  { {0x61320030, 0x388e006b, 0xa1160f8b, 0x00000000}},  //   _mælk, yər_, _بوست,
  { {0x7ae90a19, 0x6d58141a, 0x7bc30146, 0x00000000}},  //   ffet, rnva, gsnu,
  { {0xdb010181, 0x388e006b, 0xdddb1e00, 0x00000000}},  //   _atlâ, vər_, _uyuş,
  { {0xb9970783, 0x00000000, 0x00000000, 0x00000000}},  //   овых_,   ,   ,
  { {0x660d0ea9, 0x388e006b, 0x61200052, 0x00000000}},  //   _rrak, tər_, _pöly,
  { {0xeb9a01f9, 0x2005009f, 0x80d00044, 0x00000000}},  //   _тие_, _álit_, স্থ্,
  { {0x388e006b, 0x7bd82a32, 0xa6db01e5, 0x00000000}},  //   rər_, muvu, viðs,
  { {0x95d8007c, 0xa5070077, 0xb604007e, 0x00000000}},  //   одят_, оявл, мярк,
  { {0x80d00044, 0xfa77009b, 0x660d0142, 0x00000000}},  //   স্ত্, _ועדת_, _vrak,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc2990930, 0x26c9016c, 0xd5bb02dc, 0x00000000}},  //   сках_, _udao_, _ксо_,
  { {0xa2dc006e, 0x660d00b0, 0x00000000, 0x00000000}},  // [7950] _फार्, _urak,   ,
  { {0xc1780088, 0x7bd82603, 0x00000000, 0x00000000}},  //   оїх_, kuvu,   ,
  { {0x28dd0316, 0x5f95005e, 0x00000000, 0x00000000}},  //   _मासि, чиет,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdca502e9, 0xe1ff008e, 0x00000000, 0x00000000}},  //   пали, _usó_,   ,
  { {0x6b82076d, 0x61f90180, 0xc10b007e, 0x00000000}},  //   _ahog, ğalı, _тэме_,
  { {0x9c7c0059, 0x7bd82a33, 0x6b820051, 0x00000000}},  //   _obču, guvu, _bhog,
  { {0x28dd0183, 0x6b820051, 0x6b5e0089, 0x00000000}},  //   _माहि, _chog, tīga,
  { {0x7ae901bc, 0x7c380107, 0xdcfa0089, 0x00000000}},  //   rfet, _čarš, _citē,
  { {0x7ae90129, 0xa2cb0309, 0x6b5e0089, 0x00000000}},  //   sfet, तृत्, rīga,
  { {0x3ea01144, 0x6b820051, 0x2c740051, 0x00000000}},  //   žite_, _fhog, rúdú_,
  { {0x290301ae, 0x2576000c, 0x6b820066, 0x00000000}},  //   žja_, mæli_, _ghog,
  { {0x6133014a, 0xdb18000c, 0xa6e3000c, 0x00000000}},  //   _kılı, fsvæ, óðas,
  { {0xb4d601f5, 0xdb180190, 0x00000000, 0x00000000}},  //   हले_, gsvæ,   ,
  { {0xf9900076, 0x29360049, 0x00000000, 0x00000000}},  //   _شبه_, _מאסן_,   ,
  { {0xf1c7013d, 0x00000000, 0x00000000, 0x00000000}},  //   _लिखन,   ,   ,
  { {0xa823026c, 0x26c2002d, 0x00000000, 0x00000000}},  // [7960] _رکھن, mako_,   ,
  { {0x26c22a34, 0x6b8901a2, 0x613201e5, 0x00000000}},  //   lako_, hmeg, _kæli,
  { {0x26c20032, 0x4fea017a, 0x397a0049, 0x00000000}},  //   oako_, смен_, צטענ,
  { {0x26c2022b, 0x6b8900b5, 0xdce300b9, 0x00000000}},  //   nako_, jmeg, plně,
  { {0xddcb011f, 0xdce8002b, 0x26c20032, 0x00000000}},  //   ğişi, _jidħ, iako_,
  { {0x6b822a35, 0xdb0100d4, 0x7bd82a36, 0x00000000}},  //   _shog, _atlà, tuvu,
  { {0x26c20119, 0x06c70055, 0x00000000, 0x00000000}},  //   kako_, ষ্টি,   ,
  { {0xd90d007a, 0xd00f00f3, 0x26c20142, 0x00000000}},  //   یین_, _حلف_, jako_,
  { {0xadc3001d, 0xa3d6013d, 0x26c2002d, 0x00000000}},  //   _trạn, _समझ_, dako_,
  { {0xd7fa00e3, 0x27340082, 0x69cf004a, 0x00000000}},  //   бум_, _hãnh_, ácea,
  { {0x6b82131d, 0x37aa00ed, 0x00000000, 0x00000000}},  //   _thog, љтон_,   ,
  { {0x6c7b007b, 0x26c2002d, 0xdb090439, 0x00000000}},  //   _פראד, gako_, _وزنه_,
  { {0x6133011f, 0x27340082, 0x00000000, 0x00000000}},  //   _yılı, _mãnh_,   ,
  { {0x27340011, 0x8afd00b9, 0xb52400a5, 0x00000000}},  //   _lãnh_, voři, ньск,
  { {0x0fd70055, 0x26c2117b, 0xdb18000c, 0x00000000}},  //   _সন্ধ, bako_, rsvæ,
  { {0x4431001c, 0xb7db00b3, 0x926b00e2, 0x00000000}},  //   ryz_, _הקהי, брза_,
  { {0xd047005f, 0x00000000, 0x00000000, 0x00000000}},  // [7970] əməs,   ,   ,
  { {0x55bc00b3, 0x98be013e, 0x68fa2a37, 0x00000000}},  //   _המזו, vitě_, netd,
  { {0x389b01ce, 0xe3a500a2, 0x6721007d, 0x00000000}},  //   ציאנ, _تشخی, यापक_,
  { {0xdb180039, 0x00000000, 0x00000000, 0x00000000}},  //   nsvä,   ,   ,
  { {0x28dd0309, 0x2fc70011, 0x68fa2a38, 0x00000000}},  //   _मालि, ũng_, ketd,
  { {0x26c2022b, 0x7ae20efe, 0x6133006b, 0x00000000}},  //   zako_, _acot, _qılı,
  { {0xbbe80054, 0xdb01008e, 0xdb1800f8, 0x00000000}},  //   كريم_, _atlá, ksvä,
  { {0xeeb9005e, 0x26c20032, 0xc9a929a1, 0x00000000}},  //   _флаш_, xako_, овие_,
  { {0x6b8913f4, 0x26c22a39, 0xdb1800f8, 0x00000000}},  //   rmeg, vako_, dsvä,
  { {0x9f410051, 0x26c200e7, 0x6132000c, 0x00000000}},  //   ithí_, wako_, _pæli,
  { {0x26c20756, 0xfbd000a2, 0x00000000, 0x00000000}},  //   tako_, _متن_,   ,
  { {0x2011037e, 0x2d9f006c, 0x7ae20048, 0x00000000}},  //   _mrzi_, _kuue_, _gcot,
  { {0x26c20756, 0x7bd20089, 0x7afb2a3a, 0x00000000}},  //   rako_, ījuš, meut,
  { {0x26c21e4a, 0x64a600ed, 0x7afb0da6, 0x00000000}},  //   sako_, ќава, leut,
  { {0x26c22a3b, 0x212a0009, 0x3ea600d9, 0x00000000}},  //   pako_, _robh_, ycot_,
  { {0x2907009f, 0x7afb0090, 0xdce801d5, 0x00000000}},  //   _hana_, neut, _tidħ,
  { {0x2907011c, 0x27340082, 0x69c6008f, 0x00000000}},  // [7980] _kana_, _rãnh_, škev,
  { {0x29072a3c, 0x66040004, 0x7afb021e, 0x00000000}},  //   _jana_, _isik, heut,
  { {0x251b007b, 0x29070127, 0x351b061e, 0x00000000}},  //   _וויא, _mana_, _ווינ,
  { {0x20110107, 0x2907022b, 0x7afb02e1, 0x00000000}},  //   _drzi_, _lana_, jeut,
  { {0x26c002d5, 0x7afb010f, 0x25a000f4, 0x00000000}},  //   _meio_, deut, _juil_,
  { {0x290701a3, 0x7ae20531, 0x66040020, 0x00000000}},  //   _nana_, _scot, _msik,
  { {0x69cf0802, 0x68fa00ca, 0x25a00173, 0x00000000}},  //   ácen, vetd, _luil_,
  { {0x2ba70082, 0x3ebf01c3, 0xdb1802e1, 0x00000000}},  //   _sđcc_, _geut_, ksvå,
  { {0x2907011f, 0x7c3d006b, 0x69cf0b18, 0x00000000}},  //   _bana_, _əsri, šcen,
  { {0x290700c4, 0x81b30044, 0x00000000, 0x00000000}},  //   _cana_, _টিম_,   ,
  { {0x29070149, 0x7d1a2a3d, 0xdb0a0039, 0x00000000}},  //   _dana_, _ints, dsfö,
  { {0x81c40055, 0xf093009b, 0x274b0088, 0x00000000}},  //   _এমন_, כנת_, ічно_,
  { {0xceb3009b, 0x290708f8, 0xdb180039, 0x00000000}},  //   כיר_, _fana_, rsvä,
  { {0x2907183d, 0xdb0a00f8, 0xf10d006e, 0x00000000}},  //   _gana_, gsfö, _सफेद_,
  { {0x7d080030, 0x6604003c, 0x26c02a3e, 0x00000000}},  //   _mads, _esik, _feio_,
  { {0x29070020, 0xe3b00b6c, 0x25a00048, 0x00000000}},  //   _zana_, شرف_, _fuil_,
  { {0x7d1a049b, 0x2907014a, 0x2011016c, 0x00000000}},  // [7990] _onts, _yana_, _srzi_,
  { {0x7d080b41, 0xda080011, 0x645a0325, 0x00000000}},  //   _nads, _mỏ_, útic,
  { {0x3ebf028c, 0x7afb02d4, 0x00000000, 0x00000000}},  //   _peut_, yeut,   ,
  { {0xf1a702d2, 0x69cf0164, 0x7d1a0f0d, 0x00000000}},  //   _कंपन, _दिली, _ants,
  { {0x3ebf00f4, 0x31a4005d, 0x7d0800f8, 0x00000000}},  //   _veut_, _göz_, _bads,
  { {0xdd9100a1, 0x91ba0104, 0xa2160049, 0x00000000}},  //   ھوں_, _ממשי, _אַלס_,
  { {0x7afb021e, 0xfaa509f1, 0x60c5033b, 0x00000000}},  //   teut, найо, mahm,
  { {0x29071bc5, 0x7d1a001f, 0x395e0bdb, 0x00000000}},  //   _sana_, _ents, ents_,
  { {0x2907000d, 0xda080011, 0x7afb0056, 0x00000000}},  //   _pana_, _cỏ_, reut,
  { {0x60c517d1, 0x7d080089, 0x25a00116, 0x00000000}},  //   nahm, _gads, _ruil_,
  { {0x7afb00b0, 0x2907006c, 0x6d430051, 0x00000000}},  //   peut, _vana_, mhna,
  { {0x395e0fdb, 0x2907000b, 0x672d0035, 0x00000000}},  //   ants_, _wana_, _coaj,
  { {0xf6520b6c, 0x29070093, 0x26c00181, 0x00000000}},  //   ائج_, _tana_, _veio_,
  { {0x25a000c7, 0x60c505cd, 0xdb1800f8, 0x00000000}},  //   _vuil_, jahm, rsvå,
  { {0x31a4005d, 0xe73a003b, 0x69c90f81, 0x00000000}},  //   _söz_, _нек_, lsee,
  { {0x2327025f, 0x660414f7, 0x41aa0140, 0x00000000}},  //   носи_, _tsik, зван_,
  { {0x66042a3f, 0x69c901b6, 0xe3630920, 0x00000000}},  // [79a0] _usik, nsee, укти,
  { {0x7cf301df, 0x69c900b0, 0xddcb014a, 0x00000000}},  //   nırı, isee, _şişm,
  { {0x7d082a40, 0x6d430048, 0x6f09005b, 0x00000000}},  //   _rads, dhna, _baec,
  { {0x69c9021e, 0x81cf0044, 0x888c0049, 0x00000000}},  //   ksee, _শহর_, קראַ,
  { {0x7cf3014a, 0x7f420023, 0x23600036, 0x00000000}},  //   kırı, rhoq, mnij_,
  { {0xafe6012b, 0xdd8f0318, 0x6d43002a, 0x00000000}},  //   _погл, مون_, ghna,
  { {0x69c900b0, 0x7ac6030d, 0x7cf3019a, 0x00000000}},  //   esee, нспе, dırı,
  { {0xff26005e, 0x9f4a0c4d, 0x00000000, 0x00000000}},  //   _ямбо, ömän_,   ,
  { {0x69c901c3, 0xbc6a01b2, 0x00000000, 0x00000000}},  //   gsee, _کمان_,   ,
  { {0x6d431274, 0xda080011, 0x395e00ab, 0x00000000}},  //   chna, _vỏ_, unts_,
  { {0xdd8f0879, 0x6bd60070, 0x23600036, 0x00000000}},  //   _اول_, _ستار, knij_,
  { {0xda080011, 0x69c90009, 0x7bca0479, 0x00000000}},  //   _tỏ_, bsee, msfu,
  { {0x672d0107, 0x7bca0146, 0x56940131, 0x00000000}},  //   _voaj, lsfu, лают,
  { {0x68462a41, 0x69c6007f, 0x00000000, 0x00000000}},  //   _cédé, škes,   ,
  { {0x9982010a, 0x99830025, 0x5ed00061, 0x00000000}},  //   škų_, _حلوو, हणाऱ,
  { {0x7c25010f, 0xa87b0104, 0xd378007c, 0x00000000}},  //   ähri, _מאור, ечу_,
  { {0x684600f4, 0x6f090022, 0x291c0173, 0x00000000}},  // [79b0] _fédé, _raec, _knva_,
  { {0x290c2a42, 0x69d80316, 0x00000000, 0x00000000}},  //   ndda_, _मिनी,   ,
  { {0xb4dd0164, 0x60c5033b, 0x290c0bdc, 0x00000000}},  //   डली_, rahm, idda_,
  { {0x7bca0748, 0x7cf30276, 0x00000000, 0x00000000}},  //   dsfu, zırı,   ,
  { {0xdd9b0057, 0x22840265, 0x6d430051, 0x00000000}},  //   чше_, _бург, thna,
  { {0x5ff510d8, 0x0638007b, 0x61ed030e, 0x00000000}},  //   _изгу, ענגט_, mtal,
  { {0x61ed0010, 0xdfd80265, 0x61320030, 0x00000000}},  //   ltal, _път_, _vælt,
  { {0x5f94012b, 0x69c9006c, 0x6f1b0107, 0x00000000}},  //   _бист, tsee, _unuc,
  { {0x7cf301f6, 0x22492a43, 0x6aa90133, 0x00000000}},  //   tırı, nzak_, rcef,
  { {0x69c90128, 0x61ed1d1d, 0x22490032, 0x00000000}},  //   rsee, ital, izak_,
  { {0x69c900b5, 0x61ed00b0, 0xf746044b, 0x00000000}},  //   ssee, htal, вено,
  { {0x61ed2a44, 0x00000000, 0x00000000, 0x00000000}},  //   ktal,   ,   ,
  { {0xcb3600b6, 0x61ed0d22, 0x69c600b9, 0x00000000}},  //   _שאני_, jtal, šker,
  { {0x61ed0190, 0xa3bf013d, 0x98a2004c, 0x00000000}},  //   dtal, ुओं_, _кише,
  { {0x61ed01d6, 0x33d50c50, 0x00000000, 0x00000000}},  //   etal, літт,   ,
  { {0x61ed1ead, 0xdb010039, 0x00000000, 0x00000000}},  //   ftal, _utlä,   ,
  { {0x6d412a45, 0x61ed04e7, 0x9586026b, 0x00000000}},  // [79c0] _olla, gtal, _илие,
  { {0xe0d70e82, 0x6d4100f6, 0xb1430b7a, 0x00000000}},  //   кву_, _nlla, анул,
  { {0x4096004c, 0x838a01fb, 0x04460131, 0x00000000}},  //   трат, _обов_, _ренн,
  { {0xc29400a6, 0x443802e1, 0x66162a46, 0x00000000}},  //   _میزب, myr_, _kryk,
  { {0xdee3003b, 0x3ea00e83, 0x44380b69, 0x00000000}},  //   рочи, žito_, lyr_,
  { {0x62860059, 0x28dd0204, 0x0086041f, 0x00000000}},  //   _izko, _मागि, _алго,
  { {0xd47a0049, 0x6d410022, 0x7e6906d2, 0x00000000}},  //   ואַל, _dlla, _exep,
  { {0x6d410211, 0xceea007e, 0x7bca00f8, 0x00000000}},  //   _ella, _ідзе_, rsfu,
  { {0x44380016, 0x7bca00ab, 0xa25b00fa, 0x00000000}},  //   hyr_, ssfu, _leôn,
  { {0xd91701ab, 0x6d410023, 0x44382a47, 0x00000000}},  //   вью_, _glla, kyr_,
  { {0x61ed0010, 0x6d5800b0, 0x313700b3, 0x00000000}},  //   ztal, miva, דריך_,
  { {0x6d582a48, 0x290a0cce, 0x443821d8, 0x00000000}},  //   liva, žba_, dyr_,
  { {0x61ed006b, 0x9f47009d, 0x26d20045, 0x00000000}},  //   xtal, îné_, _ddyo_,
  { {0xb4dd0204, 0x6d580091, 0x6616000c, 0x00000000}},  //   डले_, niva, _dryk,
  { {0x6286002d, 0x00000000, 0x00000000, 0x00000000}},  //   _azko,   ,   ,
  { {0x61ed01d5, 0x2249022b, 0x6d58048f, 0x00000000}},  //   ttal, tzak_, hiva,
  { {0x6d580119, 0x5215007e, 0x20c7007c, 0x00000000}},  // [79d0] kiva, ыдат, всег,
  { {0x61ed121b, 0x6d580091, 0x44382a49, 0x00000000}},  //   rtal, jiva, byr_,
  { {0x6674007a, 0x6286002d, 0xa28300a1, 0x00000000}},  //   _مدیر, _ezko, _چیزو,
  { {0x61ed01e5, 0x6d410065, 0x673d0292, 0x00000000}},  //   ptal, _slla, nksj,
  { {0x926b01f9, 0x22da00b3, 0x6d410023, 0x00000000}},  //   _црна_, _אחרא, _plla,
  { {0x6d5803af, 0x63a5007f, 0x00000000, 0x00000000}},  //   giva, _kuhn,   ,
  { {0x764b0010, 0x6d412a4a, 0xbbf50025, 0x00000000}},  //   _ügyf, _vlla, استث,
  { {0x7e690032, 0x00000000, 0x00000000, 0x00000000}},  //   _txep,   ,   ,
  { {0x6d582a4b, 0x2bae0036, 0x00000000, 0x00000000}},  //   biva, _ręce_,   ,
  { {0x9f5801aa, 0x6d580091, 0xd90f0014, 0x00000000}},  //   _aprè_, civa, زیع_,
  { {0x25b20578, 0x213111cb, 0x00000000, 0x00000000}},  //   _styl_, _mozh_,   ,
  { {0x6d460006, 0xe7e4006e, 0x7c2501a2, 0x00000000}},  //   _įkai, _कमरा_, ähru,
  { {0xcb1200b6, 0x4438018e, 0x7f3a0049, 0x00000000}},  //   _ללא_, wyr_, גערו,
  { {0x3944008b, 0x44382a4c, 0x18690216, 0x00000000}},  //   _кніг, tyr_, _пали_,
  { {0x62860046, 0x443e2a4d, 0x0443005c, 0x00000000}},  //   _szko, át_, берн,
  { {0x6d580119, 0x661605ba, 0x6abb0146, 0x00000000}},  //   ziva, _tryk, nbuf,
  { {0x44380203, 0xd7df0061, 0xdb1808c8, 0x00000000}},  // [79e0] syr_, पूरच, rsvø,
  { {0x6d580129, 0x11d70025, 0x88d50044, 0x00000000}},  //   xiva, اولة_, ত্রক,
  { {0x6d58010a, 0xdfcf0025, 0x00000000, 0x00000000}},  //   viva, كيل_,   ,
  { {0x69db2a4e, 0x00000000, 0x00000000, 0x00000000}},  //   krue,   ,   ,
  { {0x6d580b25, 0xd83801aa, 0xed5a0545, 0x00000000}},  //   tiva, zyč_, нод_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d58021e, 0x69db0026, 0x20180032, 0x00000000}},  //   siva, frue, _irri_,
  { {0x6d5800b0, 0x9e6600a8, 0x0d860264, 0x00000000}},  //   piva, _свад, _блан,
  { {0x4dfb0049, 0x090624ab, 0x00000000, 0x00000000}},  //   _אפמא, учим,   ,
  { {0x3ea9167a, 0x645a0253, 0x00000000, 0x00000000}},  //   žate_, útil,   ,
  { {0x69db00ea, 0x6f02086f, 0x63a52a4f, 0x00000000}},  //   brue, neoc, _ruhn,
  { {0x69db062a, 0x2d9e2a50, 0x63a50fdf, 0x00000000}},  //   crue, _kite_, _suhn,
  { {0x20182a51, 0xe8940b21, 0x6f020048, 0x00000000}},  //   _orri_, _каль, heoc,
  { {0x7a48001e, 0x2d9e1617, 0x65751539, 0x00000000}},  //   sūtī, _mite_, rozh,
  { {0x2d9e0073, 0x290e0359, 0x236d0059, 0x00000000}},  //   _lite_, _hafa_, čejo_,
  { {0x6f02106f, 0x4155007e, 0x26cb0197, 0x00000000}},  // [79f0] deoc, авас, maco_,
  { {0x2d9e04d2, 0x26cb008e, 0x00000000, 0x00000000}},  //   _nite_, laco_,   ,
  { {0x6b5e0089, 0x290e00d2, 0x6aa2005b, 0x00000000}},  //   līgu, _mafa_, _ogof,
  { {0x7ff40054, 0x26cb1003, 0x273b0065, 0x00000000}},  //   إسلا, naco_, _bëni_,
  { {0x398b0637, 0x2d9e032c, 0x20182a52, 0x00000000}},  //   løse_, _bite_, _erri_,
  { {0xabd503f3, 0x2d9e00ab, 0xee38007e, 0x00000000}},  //   ациј, _cite_, ыні_,
  { {0x2d9e008d, 0x00000000, 0x00000000, 0x00000000}},  //   _dite_,   ,   ,
  { {0xb33b011f, 0x2d9e1760, 0x60c72a53, 0x00000000}},  //   _hiçb, _eite_, _hejm,
  { {0x26cb0035, 0x2d9e2264, 0x290e0068, 0x00000000}},  //   daco_, _fite_, _bafa_,
  { {0x69db0252, 0x290e12f0, 0x2d9e117e, 0x00000000}},  //   rrue, _cafa_, _gite_,
  { {0x1869017f, 0xe7660242, 0x3ad50014, 0x00000000}},  //   тани_, ивоп, _نياز,
  { {0x7d03009f, 0x61fd2a54, 0xaa5600a6, 0x00000000}},  //   lens, _opsl, الیا_,
  { {0x80d00044, 0x7d0300c7, 0xe5a60745, 0x00000000}},  //   স্ট্, oens, риги,
  { {0x7d03069a, 0x60c700b9, 0x290e0048, 0x00000000}},  //   nens, _nejm, _gafa_,
  { {0xa8790049, 0x98790049, 0x26cb0325, 0x00000000}},  //   _באַר, _באַט, baco_,
  { {0x7d03010f, 0x200a0093, 0xa3d7013d, 0x00000000}},  //   hens, _rsbi_, _सिर_,
  { {0xdcfa0224, 0x60c70065, 0xb77b009b, 0x00000000}},  // [7a00] _chtě, _bejm, _שאפש,
  { {0x7d030161, 0xa63b009b, 0x20180022, 0x00000000}},  //   jens, _סגיר, _prri_,
  { {0x7d0302a9, 0x6f0200d4, 0x98a7001a, 0x00000000}},  //   dens, teoc, _zonă_,
  { {0x91e600d7, 0xee3a025f, 0x00000000, 0x00000000}},  //   _коме, кне_,   ,
  { {0x6f022582, 0x2d9e16d0, 0xcbb20044, 0x00000000}},  //   reoc, _pite_, _ঘটেছ,
  { {0x7d03001f, 0x764b0010, 0x463b0049, 0x00000000}},  //   gens, _ügye, כענע,
  { {0x2d9e1689, 0xcc240044, 0x61e42a55, 0x00000000}},  //   _vite_, বন্ধ_, luil,
  { {0xcfb700b6, 0x60c700b9, 0x8fa300ed, 0x00000000}},  //   _כללי_, _zejm, _фате,
  { {0x7d03001f, 0xfce62257, 0xcb67003b, 0x00000000}},  //   bens, _возо, јање_,
  { {0x2d9e001a, 0xa954007e, 0x00000000, 0x00000000}},  //   _uite_, ёкні,   ,
  { {0xb8ce03d7, 0x61e41902, 0xe7870959, 0x00000000}},  //   _कल_, huil, иумо,
  { {0x644e1671, 0x290e00e7, 0x61e4010c, 0x00000000}},  //   dzbi, _wafa_, kuil,
  { {0x3ea40436, 0x26cb00c4, 0x0a1600a6, 0x00000000}},  //   _mgmt_, raco_, _خوشح,
  { {0x97a6003b, 0x26cb00c4, 0x6b5e0089, 0x00000000}},  //   _крил, saco_, rīgu,
  { {0xf2c70001, 0x93970025, 0x09290025, 0x00000000}},  //   исан, لجرا, _حسني_,
  { {0x442d0119, 0x7d030059, 0x61e40051, 0x00000000}},  //   će_, zens, fuil,
  { {0x443f001e, 0x61e4009d, 0x7d032a56, 0x00000000}},  // [7a10] ņu_, guil, yens,
  { {0x2b4604bd, 0x867c009b, 0x7d030210, 0x00000000}},  //   _lloc_, _ברחו, xens,
  { {0x7d0313a1, 0xc67800d3, 0x764b0010, 0x00000000}},  //   vens, _محیط_, _ügyb,
  { {0x7d032a57, 0x61e400ab, 0xdb010056, 0x00000000}},  //   wens, buil, _utlø,
  { {0x25a90149, 0x61e400e5, 0x60c70023, 0x00000000}},  //   _jual_, cuil, _tejm,
  { {0x3209009d, 0x25a904be, 0x660d2a58, 0x00000000}},  //   mway_, _mual_, _msak,
  { {0x7d03049a, 0x2b4604bd, 0x32090133, 0x00000000}},  //   rens, _bloc_, lway_,
  { {0x660d044e, 0x99840006, 0x3869012d, 0x00000000}},  //   _osak, kymų_, _ćar_,
  { {0x32090784, 0x7d030549, 0x660d00e0, 0x00000000}},  //   nway_, pens, _nsak,
  { {0x5d850054, 0x39450c89, 0x6d4a2a59, 0x00000000}},  //   _الطل, сног, chfa,
  { {0x2b462a5a, 0xe73a02be, 0x61e42a5b, 0x00000000}},  //   _floc_, ген_, zuil,
  { {0x2bf600b3, 0xc79800a1, 0x2b460544, 0x00000000}},  //   _למען_, جھتا_, _gloc_,
  { {0x25a90219, 0x9b740054, 0x3a29005f, 0x00000000}},  //   _cual_, _بالص, _çap_,
  { {0x61e400b0, 0x9f580197, 0x98a50401, 0x00000000}},  //   vuil, _aprì_, _уике,
  { {0x04430888, 0x39420089, 0x98b80036, 0x00000000}},  //   перн, īkst_, órą_,
  { {0x7ae9020c, 0x2905003b, 0x3ea010f7, 0x00000000}},  //   nget, lela_, žiti_,
  { {0x32090ba7, 0x25a92a5c, 0x67240085, 0x00000000}},  // [7a20] gway_, _gual_, _inij,
  { {0x442a0009, 0x4096007c, 0x61e400bb, 0x00000000}},  //   pxb_, брет, ruil,
  { {0x672400bb, 0x32090058, 0x00000000, 0x00000000}},  //   _knij, away_,   ,
  { {0x2905005b, 0x487a0049, 0x8bff0044, 0x00000000}},  //   hela_, אטעס, ্মান_,
  { {0x61e40219, 0x29050f45, 0x6d4a0de7, 0x00000000}},  //   quil, kela_, thfa,
  { {0x29050209, 0x8bc610e2, 0x00000000, 0x00000000}},  //   jela_, бсид,   ,
  { {0x7ae9010f, 0x3ea90087, 0x00000000, 0x00000000}},  //   fget, žata_,   ,
  { {0x7ae92a5d, 0x6d4a2a5e, 0x00000000, 0x00000000}},  //   gget, shfa,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x67240065, 0xc9260044, 0x7ae92a5f, 0x00000000}},  //   _anij, যস্ত_, aget,
  { {0x6c860025, 0x25a9006b, 0x6d5a006b, 0x00000000}},  //   _الام, _sual_, _imta,
  { {0x09e6142f, 0x99840006, 0xa09b0049, 0x00000000}},  //   _годн, tymų_, טייט,
  { {0x25a92a60, 0xa3cb006e, 0x25a12a61, 0x00000000}},  //   _qual_, रीन_, _pihl_,
  { {0x80de0055, 0x29050161, 0x660d01d9, 0x00000000}},  //   ন্ত্, cela_, _vsak,
  { {0x395e12a0, 0x1829025a, 0x00000000, 0x00000000}},  //   mits_, _نقوی_,   ,
  { {0x660d011c, 0x67242a62, 0x322b013a, 0x00000000}},  //   _tsak, _gnij, лізм_,
  { {0x6d480047, 0x6d5a080a, 0x657e0022, 0x00000000}},  // [7a30] _olda, _omta, _fkph,
  { {0x395e1a86, 0x32092a63, 0xf2df0016, 0x00000000}},  //   nits_, rway_, _glân_,
  { {0x3f1501e0, 0xe4ee00e8, 0x320901a3, 0x00000000}},  //   ждес, _जाति_, sway_,
  { {0x6d48022b, 0x2905002d, 0xc7b3007b, 0x00000000}},  //   _alda, zela_, לבע_,
  { {0xd01000a1, 0x395e0b1a, 0x00000000, 0x00000000}},  //   ولے_, kits_,   ,
  { {0xfe7003ec, 0x527a009b, 0x29052a64, 0x00000000}},  //   ردن_, _כנרא, xela_,
  { {0x395e0169, 0x7ae90125, 0x00000000, 0x00000000}},  //   dits_, tget,   ,
  { {0xa3cb02fb, 0xe9d9012b, 0x80de0055, 0x00000000}},  //   रीय_, аки_, ন্দ্,
  { {0x2905022b, 0xc9a6007c, 0x7ae90f12, 0x00000000}},  //   tela_, овые_, rget,
  { {0x395e1cde, 0xe8f60b21, 0x672429fa, 0x00000000}},  //   gits_, оль_, _snij,
  { {0x2905022b, 0x1cb80355, 0xa3cb006e, 0x00000000}},  //   rela_, _طالب_, रीम_,
  { {0xbf870011, 0x236902aa, 0x6d4301e5, 0x00000000}},  //   _điền_, jnaj_, lkna,
  { {0x395e12a0, 0xb4d50061, 0x00000000, 0x00000000}},  //   bits_, हणू_,   ,
  { {0x395e0bdb, 0x6d4318ee, 0x03a601fc, 0x00000000}},  //   cits_, nkna, живо,
  { {0x64a3007e, 0x00000000, 0x00000000, 0x00000000}},  //   дара,   ,   ,
  { {0x67240059, 0x96ba01f9, 0xb33b00fa, 0x00000000}},  //   _unij, _туку_, _piça,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [7a40]   ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x657c00ea, 0x9eaa00e2, 0x00000000, 0x00000000}},  //   morh, авеа_,   ,
  { {0x1e8601f9, 0x4eba0044, 0x63b301ca, 0x00000000}},  //   олем, ুল্ল, žené,
  { {0xdd8f0014, 0x00000000, 0x00000000, 0x00000000}},  //   چون_,   ,   ,
  { {0xdd8f06b4, 0x00000000, 0x00000000, 0x00000000}},  //   نون_,   ,   ,
  { {0x22400010, 0x395e225c, 0xfbcf0380, 0x00000000}},  //   lyik_, vits_, نتي_,
  { {0x3ce0011f, 0x5a34026b, 0x98a5007f, 0x00000000}},  //   şiv_, знит, oklė_,
  { {0x395e1923, 0xa92a007e, 0x6f1d2a65, 0x00000000}},  //   tits_, аіне_, _ósca,
  { {0x6d430039, 0x23690036, 0x6d5a2967, 0x00000000}},  //   ckna, znaj_, _umta,
  { {0x395e2a66, 0x00000000, 0x00000000, 0x00000000}},  //   rits_,   ,   ,
  { {0x395e12a0, 0x2b5f0035, 0x00000000, 0x00000000}},  //   sits_, ciuc_,   ,
  { {0x657c05b7, 0x395e00f8, 0x8f9b0097, 0x00000000}},  //   forh, pits_, ייטי,
  { {0x23690036, 0xb4d50061, 0x3f860062, 0x00000000}},  //   wnaj_, हणे_, hlou_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bdb00a0, 0x00000000, 0x00000000, 0x00000000}},  //   יקלו,   ,   ,
  { {0x657c00ab, 0x22400010, 0x00000000, 0x00000000}},  // [7a50] borh, gyik_,   ,
  { {0xdb08004a, 0x00000000, 0x00000000, 0x00000000}},  //   _dudé,   ,   ,
  { {0x7f490065, 0x6d4300ea, 0x98b800b4, 0x00000000}},  //   _pleq, vkna, órę_,
  { {0xa3cb0061, 0xbf580088, 0x00000000, 0x00000000}},  //   रीण_, орії_,   ,
  { {0x7bc8018e, 0x22520036, 0xdd140142, 0x00000000}},  //   _awdu, czyk_, _dĺžk,
  { {0xddc2013e, 0xfe700025, 0x00000000, 0x00000000}},  //   nzoř, خدم_,   ,
  { {0x6d43143e, 0x26c20036, 0x3f862a67, 0x00000000}},  //   rkna, ybko_, blou_,
  { {0x3f860129, 0x6d4302e1, 0x20030022, 0x00000000}},  //   clou_, skna, _ipji_,
  { {0xa3cb024c, 0x5d55022a, 0x20030022, 0x00000000}},  //   रीत_, _екат, _hpji_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26c20032, 0x657c0342, 0xb33b0068, 0x00000000}},  //   tbko_, vorh, _niço,
  { {0xabfa009b, 0xc6150044, 0x00000000, 0x00000000}},  //   _להער, ামনা_,   ,
  { {0x657c03c2, 0xf5b60088, 0x7afb1be0, 0x00000000}},  //   torh, ясню, mfut,
  { {0xe9b800a1, 0x5d790049, 0x00000000, 0x00000000}},  //   _بنوں_, מאָק,   ,
  { {0xf746151c, 0x18660534, 0xdb0200f6, 0x00000000}},  //   _неко, _наши_, _bioè,
  { {0xd2aa008b, 0x21f4006c, 0x52aa005e, 0x00000000}},  //   скае_, täh_, свам_,
  { {0xe297026b, 0x6fce0061, 0xe0da0256, 0x00000000}},  // [7a60] зат_, हीनं, йва_,
  { {0x40960679, 0x66040058, 0xacfd007e, 0x00000000}},  //   прет, _ipik, _авiя,
  { {0x22520036, 0xb53b009b, 0xdb0a0056, 0x00000000}},  //   szyk_, _הגיש, ppfø,
  { {0x3f860e6d, 0x2d8705e1, 0x00000000, 0x00000000}},  //   ulou_, elne_,   ,
  { {0x539b00a3, 0xbb4400b0, 0x00000000, 0x00000000}},  //   _ליטו, äämä,   ,
  { {0xf987026c, 0x261d0061, 0x00000000, 0x00000000}},  //   _سب_, मिती_,   ,
  { {0x69dd0027, 0x7afb2a68, 0x00000000, 0x00000000}},  //   ásen, ffut,   ,
  { {0x2d8704d0, 0x2a6904eb, 0x00000000, 0x00000000}},  //   alne_, _žaba_,   ,
  { {0x6443011f, 0xdcf80b4a, 0x60dc0085, 0x00000000}},  //   _üniv, lovč, _kdrm,
  { {0x63a6067e, 0x62860dc6, 0x753a010f, 0x00000000}},  //   _likn, _myko, ötzl,
  { {0x66041e3a, 0x00000000, 0x00000000, 0x00000000}},  //   _apik,   ,   ,
  { {0x63a606ed, 0x61e4073a, 0xa5f9007c, 0x00000000}},  //   _nikn, kril, оему_,
  { {0x62860479, 0x00000000, 0x00000000, 0x00000000}},  //   _nyko,   ,   ,
  { {0x61e4002d, 0x25a5000c, 0x69c02a69, 0x00000000}},  //   dril, öll_, mpme,
  { {0x6604011c, 0xd4040827, 0x61e41254, 0x00000000}},  //   _epik, няти, eril,
  { {0x5334007c, 0x62860007, 0x7d0a01d6, 0x00000000}},  //   нест, _byko, hefs,
  { {0x63a6023a, 0xd7f8001a, 0xddcb0861, 0x00000000}},  // [7a70] _dikn, ltă_, _žižk,
  { {0x69c000ab, 0x69c401d5, 0x00000000, 0x00000000}},  //   ipme, _ħiel,   ,
  { {0xd7f8000d, 0x61e405e0, 0x661d24fd, 0x00000000}},  //   ntă_, aril, lvsk,
  { {0xd7f80035, 0x2bb501c5, 0x00000000, 0x00000000}},  //   ită_, _nāca_,   ,
  { {0x61e42582, 0x00000000, 0x00000000, 0x00000000}},  //   cril,   ,   ,
  { {0xc21200b6, 0x61e20059, 0xf1b200b3, 0x00000000}},  //   _שהם_, šolc, _בסך_,
  { {0x3b9500ed, 0x00000000, 0x00000000, 0x00000000}},  //   мјит,   ,   ,
  { {0x44210145, 0x00000000, 0x00000000, 0x00000000}},  //   _mrh_,   ,   ,
  { {0x6609014a, 0x00000000, 0x00000000, 0x00000000}},  //   çekl,   ,   ,
  { {0x7afb0325, 0x00000000, 0x00000000, 0x00000000}},  //   sfut,   ,   ,
  { {0x661d0065, 0x66042a6a, 0x00000000, 0x00000000}},  //   evsk, _spik,   ,
  { {0xd90f026c, 0x501a009b, 0xa5b2013d, 0x00000000}},  //   ئیں_, קורו, _इंदौ,
  { {0x6b890635, 0xa3cb0164, 0xe8ee003b, 0x00000000}},  //   mleg, रीस_, _ил_,
  { {0x6b892a6b, 0x61e40180, 0x6b9b0032, 0x00000000}},  //   lleg, vril, lmug,
  { {0x63a62a6c, 0xe5a300e3, 0x44212a6d, 0x00000000}},  //   _pikn, тири, _crh_,
  { {0x6b892a6e, 0x37870265, 0x61e40142, 0x00000000}},  //   nleg, _общо_, tril,
  { {0x63a62a6f, 0x6f19018e, 0x61e410fb, 0x00000000}},  // [7a80] _vikn, ddwc, uril,
  { {0x62862a70, 0x92ce0044, 0x61e40238, 0x00000000}},  //   _vyko, রলে_, rril,
  { {0x62860046, 0xa00a0d3a, 0x6b89009f, 0x00000000}},  //   _wyko, تقال_, kleg,
  { {0x60ce02c1, 0x61e40091, 0xc4fa00a1, 0x00000000}},  //   _webm, pril, _اٹھا_,
  { {0x6b890292, 0xf2d30049, 0xdcfa002b, 0x00000000}},  //   dleg, _בער_, _jitħ,
  { {0x6b8201c9, 0x6b8900ea, 0x4c94007c, 0x00000000}},  //   _skog, eleg, нилс,
  { {0x6b8900db, 0x656e0048, 0x6443014a, 0x00000000}},  //   fleg, inbh, _ünit,
  { {0x6b892a6e, 0x7d0a00f8, 0xda14003b, 0x00000000}},  //   gleg, sefs, едињ,
  { {0x3cfb0164, 0xf1bf0048, 0xe9b700a1, 0x00000000}},  //   ल्हे_, _grád_, وچوں_,
  { {0xd8f801fb, 0x6b892a71, 0x0d4a0439, 0x00000000}},  //   чної_, aleg, _بشري_,
  { {0x798800ab, 0x93c50082, 0x00000000, 0x00000000}},  //   rldw, _chắ,   ,
  { {0xb7d8026c, 0xd7f8001a, 0x6b890036, 0x00000000}},  //   _ہوتا_, rtă_, cleg,
  { {0xd7f8000d, 0x3cfb0204, 0xdb08073f, 0x00000000}},  //   stă_, ल्वे_, _judí,
  { {0xd7f8001a, 0x661d0190, 0x6b800fcf, 0x00000000}},  //   ptă_, rvsk, lomg,
  { {0xe7e50754, 0xdb1a009d, 0x00000000, 0x00000000}},  //   _किया_, _atté,   ,
  { {0x442101d9, 0x6b802a72, 0x7bd801d6, 0x00000000}},  //   _vrh_, nomg, isvu,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [7a90]   ,   ,   ,
  { {0x290c006c, 0xddc20036, 0xc0ab00a1, 0x00000000}},  //   neda_, szoś, زائل_,
  { {0xd371023c, 0xdb082a73, 0x00000000, 0x00000000}},  //   _مهد_, _audí,   ,
  { {0x290c0207, 0xc49a00b3, 0x6b890190, 0x00000000}},  //   heda_, _משתת, xleg,
  { {0x290c0066, 0x7bda0022, 0x6b890056, 0x00000000}},  //   keda_, _avtu, vleg,
  { {0x290c0209, 0x61ed01a3, 0x00000000, 0x00000000}},  //   jeda_, mual,   ,
  { {0x6b8903c2, 0x290c010a, 0x61ed00b0, 0x00000000}},  //   tleg, deda_, lual,
  { {0x394e0066, 0xe0d000a1, 0x709400e2, 0x00000000}},  //   _alfs_, _مزہ_, _расф,
  { {0x6b8905ed, 0x61ed2a74, 0x00000000, 0x00000000}},  //   rleg, nual,   ,
  { {0x6b89009f, 0x290c006c, 0xd102006e, 0x00000000}},  //   sleg, geda_, र्पण_,
  { {0x6b891646, 0xef1901d5, 0x61ed0145, 0x00000000}},  //   pleg, _każ_, hual,
  { {0x44260027, 0xb33b0065, 0x61ed002d, 0x00000000}},  //   _čo_, _diçk, kual,
  { {0x290c003b, 0x61ed0022, 0xef190066, 0x00000000}},  //   beda_, jual, _maż_,
  { {0x93c50082, 0x00000000, 0x00000000, 0x00000000}},  //   _thắ,   ,   ,
  { {0xf1bf0195, 0xa3cb001c, 0x232a092b, 0x00000000}},  //   _atá_, रील_, пови_,
  { {0xdcfa002b, 0x00000000, 0x00000000, 0x00000000}},  //   _titħ,   ,   ,
  { {0x61ed00d6, 0x91e32882, 0x00000000, 0x00000000}},  // [7aa0] gual, лоте,   ,
  { {0xdce30006, 0x2d4b0190, 0x96570104, 0x00000000}},  //   monė, _søen_, _נשיא_,
  { {0xdd990173, 0x505a01ab, 0xdce3007f, 0x00000000}},  //   _epňk_, чшая_, lonė,
  { {0x60c3005d, 0x79810016, 0x2d852a75, 0x00000000}},  //   ınma, holw, _akle_,
  { {0x79810036, 0x61ed04cb, 0xef190066, 0x00000000}},  //   kolw, cual, _daż_,
  { {0x3ead27a1, 0x3cfb0164, 0x7bd800ea, 0x00000000}},  //   _eget_, ल्ले_, tsvu,
  { {0xdee60594, 0x290c0b9f, 0xd007122e, 0x00000000}},  //   _пови, veda_, _пере_,
  { {0x2d85011f, 0x26d20b3d, 0x8fa30364, 0x00000000}},  //   _ekle_, _neyo_, _басе,
  { {0x49740072, 0x290c01ed, 0xdce3007f, 0x00000000}},  //   клис, teda_, jonė,
  { {0xccf800b9, 0x9e63003b, 0x79812a76, 0x00000000}},  //   _změn_, _свуд, golw,
  { {0x61ed000d, 0x290c0142, 0x31570049, 0x00000000}},  //   zual, reda_, גיין_,
  { {0x290c0059, 0x7d1a0968, 0x00000000, 0x00000000}},  //   seda_, _hats,   ,
  { {0x7d1a0b3e, 0x61ed1632, 0x290c0093, 0x00000000}},  //   _kats, xual, peda_,
  { {0xd90e007a, 0x6d4a0145, 0xa3b50316, 0x00000000}},  //   _اید_, nkfa, _छंद_,
  { {0x7d1a06a1, 0xc885010f, 0x23e4007e, 0x00000000}},  //   _mats, ößte_, літв,
  { {0xb33b006b, 0x3ea910f7, 0xe3b001af, 0x00000000}},  //   _kiçi, žati_, صرف_,
  { {0xb5a72329, 0x672d0020, 0x00000000, 0x00000000}},  // [7ab0] _прой, _inaj,   ,
  { {0x7d1a2a77, 0x35f80025, 0x61ed2a78, 0x00000000}},  //   _nats, _أريد_, rual,
  { {0x61ed051b, 0xdcb10082, 0x7f190088, 0x00000000}},  //   sual, _bản_, ділу_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x5f740355, 0x7d1a0ace, 0x672d00e7, 0x00000000}},  //   دالر, _bats, _mnaj,
  { {0x7d1a059a, 0xdb0800f6, 0x00000000, 0x00000000}},  //   _cats, _audà,   ,
  { {0x2ef502a8, 0x1af50044, 0xef19002b, 0x00000000}},  //   _извр, _আসবে_, _taż_,
  { {0xb33b01df, 0x3eb9005a, 0x6d4a085d, 0x00000000}},  //   _biçi, _üst_, akfa,
  { {0xfe73025a, 0x7d1a00bb, 0xfe4302fd, 0x00000000}},  //   _صدر_, _fats, _حکای,
  { {0x39452a79, 0x7cd900e9, 0x98a50c96, 0x00000000}},  //   тног, _آواز_, кипе,
  { {0x7981005b, 0x1ae30044, 0x00000000, 0x00000000}},  //   rolw, ক্ষে_,   ,
  { {0x66160193, 0x6f1b0006, 0x7981047a, 0x00000000}},  //   _psyk, _jauc, solw,
  { {0xd045006b, 0x6f1b06ed, 0xdb2600a1, 0x00000000}},  //   rahə, _mauc, _جونی,
  { {0x7dd80051, 0x6f1b01c5, 0x672d2a7a, 0x00000000}},  //   _húsá, _lauc, _enaj,
  { {0xccf200a0, 0x94790269, 0x00000000, 0x00000000}},  //   יכם_, есту_,   ,
  { {0x6f1b0821, 0x00000000, 0x00000000, 0x00000000}},  //   _nauc,   ,   ,
  { {0x03a30cb7, 0x69db00f4, 0xe1fa041f, 0x00000000}},  // [7ac0] рито, nsue, ьга_,
  { {0x672d2a7b, 0x25d7007b, 0xf2130055, 0x00000000}},  //   _znaj, _שוין_, সমূহ_,
  { {0x7d1a044e, 0x6f1b2a7c, 0xc0590088, 0x00000000}},  //   _rats, _bauc, нії_,
  { {0xdee601fb, 0x7d1a0039, 0x6f1b1632, 0x00000000}},  //   тоди, _sats, _cauc,
  { {0x7d1a0f81, 0x7bc10bd3, 0x00000000, 0x00000000}},  //   _pats, _atlu,   ,
  { {0xde93003b, 0xdb0800f6, 0x00000000, 0x00000000}},  //   јашњ, _sudà,   ,
  { {0x3f6a00d7, 0x6d4a01e5, 0x7d1a00b0, 0x00000000}},  //   _живо_, rkfa, _vats,
  { {0x7d1a2a7d, 0x6f1b00f4, 0x5b1400ed, 0x00000000}},  //   _wats, _gauc, умит,
  { {0x7d1a010f, 0x6f02013e, 0x00000000, 0x00000000}},  //   _tats, mfoc,   ,
  { {0x672d2480, 0x35dc013d, 0x7764004a, 0x00000000}},  //   _snaj, _बिज़, _amix,
  { {0x6f1b004a, 0x00000000, 0x00000000, 0x00000000}},  //   _yauc,   ,   ,
  { {0x69db004a, 0x00000000, 0x00000000, 0x00000000}},  //   bsue,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x1af50044, 0x44250051, 0x8937009b, 0x00000000}},  //   _আসতে_, íl_, _ברגע_,
  { {0x291c005d, 0x672d2a7e, 0x3a260030, 0x00000000}},  //   _hava_, _unaj, _krop_,
  { {0x291c1609, 0x6f1b010f, 0x2018008a, 0x00000000}},  // [7ad0] _kava_, _rauc, _asri_,
  { {0x6f1b08f7, 0xe3b000a1, 0x291e0010, 0x00000000}},  //   _sauc, صرہ_, ndta_,
  { {0x7ae2021e, 0x6f020197, 0x6b5e0089, 0x00000000}},  //   _odot, ffoc, lūgu,
  { {0x291c059e, 0x7ae21b1c, 0x26d90026, 0x00000000}},  //   _lava_, _ndot, naso_,
  { {0xdef804af, 0xfce5041f, 0x6f1b009d, 0x00000000}},  //   тых_, голо, _vauc,
  { {0x7ae20047, 0x291c058b, 0x0d840245, 0x00000000}},  //   _adot, _nava_, алін,
  { {0xdb080211, 0x26d90058, 0x6f1b010f, 0x00000000}},  //   _sudá, kaso_, _tauc,
  { {0xe4e3006e, 0x69db002d, 0xd24e00a1, 0x00000000}},  //   कृति_, tsue, _بچہ_,
  { {0x22490149, 0xdea100a1, 0xdce30d0a, 0x00000000}},  //   nyak_, _ایشی, linč,
  { {0x291c059a, 0x7ae2002d, 0x6ce4007e, 0x00000000}},  //   _cava_, _edot, _віце,
  { {0x69db2a7f, 0x291c014a, 0x3a2600b5, 0x00000000}},  //   ssue, _dava_, _erop_,
  { {0xf092009b, 0xdb080010, 0x26d908d3, 0x00000000}},  //   מני_, _tudá, gaso_,
  { {0x6d41011f, 0x09e5007c, 0x291c0026, 0x00000000}},  //   _kola, _солн, _fava_,
  { {0x6d41002d, 0x22492a80, 0x60d5297f, 0x00000000}},  //   _jola, dyak_, _nezm,
  { {0x8cca0061, 0x32190300, 0x5faf0309, 0x00000000}},  //   _स्फो, _assy_, _जंगल,
  { {0x26d9008e, 0x6d412378, 0x7c2e11c3, 0x00000000}},  //   caso_, _lola, _ábre,
  { {0x60d50089, 0xb226008b, 0x2018006b, 0x00000000}},  // [7ae0] _bezm, ымал, _ssri_,
  { {0x6d412a81, 0x20560545, 0x00000000, 0x00000000}},  //   _nola, лтер,   ,
  { {0x6f0208d9, 0xdb0b00c4, 0x60d50035, 0x00000000}},  //   tfoc, _vigê, _dezm,
  { {0xf1bf2a82, 0x6d410288, 0x201800d9, 0x00000000}},  //   _irán_, _aola, _vsri_,
  { {0x6d410039, 0xdee300e3, 0x00000000, 0x00000000}},  //   _bola, сочи,   ,
  { {0x6d410325, 0x3f8f006c, 0xa3cb0309, 0x00000000}},  //   _cola, algu_, रीक_,
  { {0x6d41069b, 0x69c200c7, 0xab5c0089, 0x00000000}},  //   _dola, _stoe, _atļa,
  { {0x6d41002a, 0x3a260129, 0x291c0089, 0x00000000}},  //   _eola, _prop_, _sava_,
  { {0x6d410051, 0x26d90197, 0x32000173, 0x00000000}},  //   _fola, vaso_, ntiy_,
  { {0x6d410016, 0xa96700ed, 0xdb0b00d4, 0x00000000}},  //   _gola, лиња_, _ligè,
  { {0x313700b6, 0x291c2a83, 0xb8dc006e, 0x00000000}},  //   אריך_, _vava_, _अल_,
  { {0x3a26028c, 0x6d412a84, 0x399901aa, 0x00000000}},  //   _trop_, _zola, vèse_,
  { {0x291c0089, 0x6d41006b, 0x33200066, 0x00000000}},  //   _tava_, _yola, ddix_,
  { {0x040e0055, 0x6d582a85, 0xf65f0030, 0x00000000}},  //   হিনী_, nhva, lbæk_,
  { {0x88bb0049, 0x26d90dfb, 0x60d52a86, 0x00000000}},  //   _אזוי, paso_, _rezm,
  { {0xe315003b, 0xdce3007f, 0x98bc000a, 0x00000000}},  //   јмањ, vinč, _movč_,
  { {0x23692a87, 0x00000000, 0x00000000, 0x00000000}},  // [7af0] riaj_,   ,   ,
  { {0x7c281923, 0x23690036, 0x660d011c, 0x00000000}},  //   _ordr, siaj_, _ipak,
  { {0xd011036d, 0xa3cb007d, 0x60d50161, 0x00000000}},  //   تلا_, रीख_, _vezm,
  { {0x6d410127, 0xdce30006, 0x398b0030, 0x00000000}},  //   _sola, rinč, løst_,
  { {0x7c281ca9, 0x8e8500ed, 0x32190022, 0x00000000}},  //   _ardr, јгле, _ussy_,
  { {0x660d000b, 0x6da517da, 0x644804ec, 0x00000000}},  //   _mpak, шила, ädig,
  { {0x6d410142, 0xeab10054, 0x8cc1006e, 0x00000000}},  //   _vola, يعة_, रुषो,
  { {0x660d0209, 0xd5b50204, 0x7e7b0032, 0x00000000}},  //   _opak, ंदाज, _txup,
  { {0x5f4404e8, 0x6d412098, 0x61ed0276, 0x00000000}},  //   _انقل, _tola, nral,
  { {0x63af01a8, 0xd90f00a1, 0x6d580161, 0x00000000}},  //   _licn, سیع_, chva,
  { {0x2d870710, 0x628f0061, 0x660d2a88, 0x00000000}},  //   mone_, _lyco, _apak,
  { {0x61ed014a, 0x6e29010f, 0x70b20164, 0x00000000}},  //   kral, _kreb, _जल्ल,
  { {0x7f3a007b, 0x0ab40070, 0xbb840025, 0x00000000}},  //   דערו, _احمد, _الني,
  { {0x2d870207, 0x69c90112, 0x3dd70044, 0x00000000}},  //   none_, mpee, _সমাল,
  { {0x64a6008b, 0x6f092a89, 0xdb0b0051, 0x00000000}},  //   рава, _obec, _aigé,
  { {0x2d870a60, 0x58940025, 0x00000000, 0x00000000}},  //   hone_, _اجهز,   ,
  { {0x52aa2a8a, 0x2d871747, 0x33200096, 0x00000000}},  // [7b00] твам_, kone_, rdix_,
  { {0x6f090161, 0x2d870006, 0xe3ba007c, 0x00000000}},  //   _abec, jone_, _ибо_,
  { {0x2d8701aa, 0x6e292a8b, 0x46ba013d, 0x00000000}},  //   done_, _areb, _इलाह,
  { {0x61ed2a8c, 0x6e290855, 0xf1bf0062, 0x00000000}},  //   bral, _breb, _král_,
  { {0x2d8702d5, 0x6d582698, 0x6e2903c5, 0x00000000}},  //   fone_, thva, _creb,
  { {0xb5fb0047, 0x7c280126, 0xcbe6026b, 0x00000000}},  //   szág, _prdr, ации,
  { {0x6e2901d6, 0x6ca3005e, 0x317b0049, 0x00000000}},  //   _ereb, оръж, _סאלד,
  { {0x63a400b5, 0x6d5804eb, 0xa3cb007d, 0x00000000}},  //   nmin, shva, रीट_,
  { {0x63a40fc9, 0x6e292645, 0x99820224, 0x00000000}},  //   imin, _greb, íků_,
  { {0x2d870e68, 0x63a4085e, 0x00000000, 0x00000000}},  //   cone_, hmin,   ,
  { {0x660d0107, 0x63a40006, 0x00000000, 0x00000000}},  //   _spak, kmin,   ,
  { {0xdce3001e, 0x7bca010f, 0x63a414a8, 0x00000000}},  //   minā, mpfu, jmin,
  { {0xdce3001e, 0x7bca00ab, 0x63a42a8d, 0x00000000}},  //   linā, lpfu, dmin,
  { {0x61ed006b, 0xb8660014, 0x229c007f, 0x00000000}},  //   vral, _پاتو, iškį_,
  { {0xf367003b, 0x6b5512c5, 0x63a4000a, 0x00000000}},  //   атан, _hága, fmin,
  { {0xe738012b, 0x2d870874, 0x63b70039, 0x00000000}},  //   _већ_, zone_, _vuxn,
  { {0x2d872a8e, 0xa3cb007d, 0xdcef00b9, 0x00000000}},  // [7b10] yone_, रीज_, _řeče,
  { {0x61ed24c3, 0x63a40ac0, 0xdb0b00d6, 0x00000000}},  //   rral, amin, _vigé,
  { {0x63a40129, 0x2d870197, 0x2b810036, 0x00000000}},  //   bmin, vone_, rócz_,
  { {0x6e290c06, 0xdce3001e, 0x2d8700c7, 0x00000000}},  //   _preb, dinā, wone_,
  { {0x2d870912, 0xfe7000b8, 0x1af50055, 0x00000000}},  //   tone_, وده_, _আসলে_,
  { {0x6e2904eb, 0x00000000, 0x00000000, 0x00000000}},  //   _vreb,   ,   ,
  { {0x2d87051b, 0xa3cb0204, 0xeb020316, 0x00000000}},  //   rone_, रीच_, लभूत_,
  { {0x2d872a8f, 0x2b150088, 0x9f052a90, 0x00000000}},  //   sone_, ськр, _دورو,
  { {0x2d871ad2, 0xaa490057, 0x6e290009, 0x00000000}},  //   pone_, уппа_, _ureb,
  { {0x69c900b0, 0x63a4005d, 0xdce30089, 0x00000000}},  //   rpee, zmin, binā,
  { {0x1b1f0055, 0x69c900c7, 0xdce3001e, 0x00000000}},  //   ভাবে_, spee, cinā,
  { {0x63a4006b, 0x69c90e67, 0x6b551a13, 0x00000000}},  //   xmin, ppee, _fága,
  { {0x4e790049, 0xb5c7009e, 0x00000000, 0x00000000}},  //   ראָצ, یڈیم_,   ,
  { {0x044600ed, 0x63a4005b, 0x1de00061, 0x00000000}},  //   бегн, wmin, _निघत,
  { {0x63a40004, 0x8579005e, 0x00000000, 0x00000000}},  //   tmin, рсят_,   ,
  { {0x6756007a, 0x6b890116, 0x63a4007f, 0x00000000}},  //   _دختر, noeg, umin,
  { {0xdce3001e, 0x78c60010, 0x6f010010, 0x00000000}},  // [7b20] zinā, _érvé, zábó,
  { {0x63a40004, 0x1aff0044, 0x00000000, 0x00000000}},  //   smin, ্যিই_,   ,
  { {0xd8da0049, 0x4fea02dc, 0xd24f009e, 0x00000000}},  //   רקער, умен_, ونہ_,
  { {0xdce30089, 0x644e0006, 0x656e0058, 0x00000000}},  //   vinā, mybi, libh,
  { {0x644e04dc, 0xa3d4013d, 0x00000000, 0x00000000}},  //   lybi, सीर_,   ,
  { {0xdce30089, 0x8e200088, 0x00000000, 0x00000000}},  //   tinā, кiв_,   ,
  { {0x61f6014a, 0x644e007f, 0x00000000, 0x00000000}},  //   luyl, nybi,   ,
  { {0xf06303c8, 0xdce3001e, 0x6b5500dc, 0x00000000}},  //   _эксп, rinā, _pága,
  { {0xdce3001e, 0xfe430140, 0x61f6014a, 0x00000000}},  //   sinā, _енто, nuyl,
  { {0x26c209aa, 0x644e0006, 0x81ea0044, 0x00000000}},  //   ecko_, kybi, _মহা_,
  { {0x23810006, 0x61f61811, 0x00000000, 0x00000000}},  //   lėje_, huyl,   ,
  { {0x644e0006, 0x290200b9, 0x79880016, 0x00000000}},  //   dybi, řka_, sodw,
  { {0x2381010a, 0x00000000, 0x00000000, 0x00000000}},  //   nėje_,   ,   ,
  { {0x6d5d0006, 0xdce30035, 0x00000000, 0x00000000}},  //   _įsak, mină,   ,
  { {0x60de0022, 0xa3d4007d, 0x00000000, 0x00000000}},  //   dapm, सील_,   ,
  { {0x443f0119, 0xa91c0027, 0x5b7b0049, 0x00000000}},  //   ću_, koľk, ָרמא,
  { {0xdb080027, 0xe820007d, 0x00000000, 0x00000000}},  // [7b30] _budú, यिका_,   ,
  { {0x30a709da, 0xba9b009b, 0x1a9b0049, 0x00000000}},  //   брев, רסמי, רימע,
  { {0x44270047, 0x5fa40061, 0x691e0066, 0x00000000}},  //   _én_, _ओळखल, _għeż,
  { {0xdddb0428, 0xd7fb0049, 0x00000000, 0x00000000}},  //   _využ, רהאל,   ,
  { {0x6b8902ae, 0xf127105c, 0x9f580010, 0x00000000}},  //   voeg, _льво, _apró_,
  { {0x3cfe2a91, 0x629d0089, 0x00000000, 0x00000000}},  //   _cctv_, _izso,   ,
  { {0xa4fc0049, 0x8c42005e, 0xdca20256, 0x00000000}},  //   אלוט, деще, маши,
  { {0x1b490478, 0x39e9003b, 0x23810006, 0x00000000}},  //   рзии_, адио_, bėje_,
  { {0x499000a1, 0xfaf90089, 0x6b8900bb, 0x00000000}},  //   کیور, rgū_, roeg,
  { {0x764f0036, 0x00000000, 0x00000000, 0x00000000}},  //   dycy,   ,   ,
  { {0x07a600c2, 0xe73a00e3, 0x6b89010e, 0x00000000}},  //   жанн, аен_, poeg,
  { {0x16aa09ae, 0xc4c90097, 0x644e2198, 0x00000000}},  //   ивни_, _יג_, vybi,
  { {0x656e06f6, 0x2bb50089, 0x65a001a2, 0x00000000}},  //   tibh, _vācu_, höhe,
  { {0x644e0eda, 0xdcf800b9, 0x7afb0881, 0x00000000}},  //   tybi, dově, lgut,
  { {0xa34a011e, 0x39470133, 0x656e0048, 0x00000000}},  //   азва_, _ions_, ribh,
  { {0x7afb2a92, 0x644e0006, 0x39470145, 0x00000000}},  //   ngut, rybi, _hons_,
  { {0xe0da017f, 0xc878005f, 0xcb120104, 0x00000000}},  // [7b40] ива_, mağa_, ולן_,
  { {0x21a300ed, 0x40960264, 0x67240020, 0x00000000}},  //   диум, орет, _haij,
  { {0x39470142, 0x67240778, 0x64a60783, 0x00000000}},  //   _mons_, _kaij, _фана,
  { {0x25b7007a, 0x3cfe04e9, 0x23810006, 0x00000000}},  //   _دهید_, _sctv_, tėje_,
  { {0x6724001e, 0xeda6003b, 0x2bd70061, 0x00000000}},  //   _maij, ошко, णीसा,
  { {0x61e4005d, 0x23810006, 0x2b460082, 0x00000000}},  //   msil, rėje_, _sooc_,
  { {0x6b5c00f4, 0x61e41ad7, 0x3cfe0011, 0x00000000}},  //   _lége, lsil, _vctv_,
  { {0x60dc0219, 0x8cca007d, 0x67240258, 0x00000000}},  //   _herm, _स्रो, _naij,
  { {0x39472a93, 0x60dc0dde, 0x6458002b, 0x00000000}},  //   _bons_, _kerm, _żvil,
  { {0x60dc0022, 0x61e400b0, 0x67360010, 0x00000000}},  //   _jerm, isil, _anyj,
  { {0x61e40477, 0x6d5a00b0, 0x672401f3, 0x00000000}},  //   hsil, _ilta, _baij,
  { {0xd6db03f3, 0x61e400b0, 0x6d48016e, 0x00000000}},  //   што_, ksil, _hoda,
  { {0x6d482a94, 0x39470129, 0x7e6201f3, 0x00000000}},  //   _koda, _fons_, nzop,
  { {0xd5b8008b, 0x60dc01ee, 0x7ae00232, 0x00000000}},  //   ўся_, _nerm, lamt,
  { {0x6d48033b, 0x29c0001d, 0x61e602e1, 0x00000000}},  //   _moda, _hòa_, _avkl,
  { {0x53340517, 0x6d480026, 0x7ae02a95, 0x00000000}},  //   мест, _loda, namt,
  { {0x6d5a1755, 0x60dc2a96, 0x776d049a, 0x00000000}},  // [7b50] _olta, _berm, _imax,
  { {0x6d48001e, 0x7d1806ac, 0x60dc04cb, 0x00000000}},  //   _noda, jevs, _cerm,
  { {0x60dc01e3, 0x7ae0107e, 0xd7f8001a, 0x00000000}},  //   _derm, kamt, nuă_,
  { {0x441a019b, 0xdcf80224, 0x4421008d, 0x00000000}},  //   _פורס, pově, _ish_,
  { {0x60dc0e8d, 0x6d480211, 0x433a00b3, 0x00000000}},  //   _ferm, _boda, _הערב,
  { {0x8d650764, 0xabd501fc, 0x3d0001f5, 0x00000000}},  //   явле, пциј, _राणे_,
  { {0x6d482a97, 0x394706ed, 0x00000000, 0x00000000}},  //   _doda, _rons_,   ,
  { {0x442104be, 0xe9d9081e, 0xb5fb0010, 0x00000000}},  //   _msh_, бки_, zzáa,
  { {0x394700d4, 0x44212a98, 0x7afb010e, 0x00000000}},  //   _pons_, _lsh_, rgut,
  { {0x395e0038, 0x7d1801ee, 0x6b5c0010, 0x00000000}},  //   ghts_, cevs, _rége,
  { {0x7d7a0049, 0x442116e7, 0x67240d25, 0x00000000}},  //   _פרעג, _nsh_, _paij,
  { {0x6d4802ae, 0x6f1922b8, 0xed590091, 0x00000000}},  //   _zoda, newc, _duže_,
  { {0xe8ee1662, 0x45d3007e, 0x39470133, 0x00000000}},  //   _пл_, ноўс, _tons_,
  { {0x395e04e5, 0x6b5c0010, 0x88bc00b9, 0x00000000}},  //   chts_, _vége, nděl,
  { {0x68e1006c, 0x67242641, 0x03a60098, 0x00000000}},  //   mald, _taij, зиво,
  { {0x68e11804, 0x44210026, 0x97ae006b, 0x00000000}},  //   lald, _dsh_, üşdü,
  { {0xd29a0088, 0x44210023, 0x6f190016, 0x00000000}},  // [7b60] стві_, _esh_, dewc,
  { {0x68e1022b, 0x64a60072, 0x61e403f2, 0x00000000}},  //   nald, _напа, rsil,
  { {0x6d480181, 0x14d70049, 0x6f000253, 0x00000000}},  //   _roda, _מויל_, _pcmc,
  { {0x6d480343, 0x68e12a99, 0x61e400b0, 0x00000000}},  //   _soda, hald, psil,
  { {0x6d4814d4, 0x68e10e01, 0xf3f10011, 0x00000000}},  //   _poda, kald, ợc_,
  { {0x68e1000c, 0x63be0874, 0x61e20059, 0x00000000}},  //   jald, _kupn, šols,
  { {0x7ae00058, 0x6d5a0802, 0x68e122f6, 0x00000000}},  //   tamt, _vlta, dald,
  { {0x5a34026b, 0xad660014, 0x207b0049, 0x00000000}},  //   днит, _کاره, _האלא,
  { {0x6d482a9a, 0x63be0209, 0x7ae00190, 0x00000000}},  //   _toda, _lupn, ramt,
  { {0x7ae005e9, 0x68e1023e, 0x6d5a2a9b, 0x00000000}},  //   samt, gald, _ulta,
  { {0x7ae0037e, 0x69d901d5, 0xa91c0027, 0x00000000}},  //   pamt, _ewwe, koľv,
  { {0x29c00011, 0x68e1010e, 0x44211c96, 0x00000000}},  //   _tòa_, aald, _rsh_,
  { {0x68e1022b, 0xf1bf001d, 0xe81e01f5, 0x00000000}},  //   bald, _trái_, _बनवा_,
  { {0x5e57007b, 0x68e116ca, 0x18740152, 0x00000000}},  //   ליכע_, cald, _огля,
  { {0x439501fb, 0xdb1a008e, 0xbf1c0061, 0x00000000}},  //   давс, _auté, _नसून_,
  { {0xa87b00b3, 0x187b00a0, 0x88bc00b9, 0x00000000}},  //   _לאור, _לטוב, zděl,
  { {0x248d0046, 0x7afd0129, 0x23810006, 0x00000000}},  // [7b70] łem_, òsti, gėja_,
  { {0x92cd0055, 0x60c52a9c, 0x442100e7, 0x00000000}},  //   রণে_, uchm, _tsh_,
  { {0xb4d902fb, 0x60c52a9d, 0x442122cb, 0x00000000}},  //   ारी_, rchm, _ush_,
  { {0x60c5010f, 0x68e1002d, 0xdb1a009d, 0x00000000}},  //   schm, zald, _futé,
  { {0xe2ab007a, 0x7bda01d5, 0xb5fb0010, 0x00000000}},  //   _دادن_, _awtu, zzán,
  { {0x6280010a, 0x51871123, 0x32090082, 0x00000000}},  //   _žmog, _хума, mtay_,
  { {0xea00001d, 0x68e11b18, 0xbb451c31, 0x00000000}},  //   _đại_, vald, дейк,
  { {0x68e12a9e, 0x00000000, 0x00000000, 0x00000000}},  //   wald,   ,   ,
  { {0x4ea702a8, 0x68e1022b, 0x3209006a, 0x00000000}},  //   _хрва, tald, ntay_,
  { {0x57e91585, 0xdb0b004a, 0x00000000, 0x00000000}},  //   одом_, _digá,   ,
  { {0x68e1002d, 0x8cc809b9, 0x2b5f0082, 0x00000000}},  //   rald, _رونق_, phuc_,
  { {0x68e10004, 0xe73a02e9, 0x63be0087, 0x00000000}},  //   sald, цем_, _rupn,
  { {0x68e12a9f, 0x80e30044, 0xb4d90164, 0x00000000}},  //   pald, _পান্, ारू_,
  { {0x64a6007e, 0x68e1006b, 0x63be1869, 0x00000000}},  //   дага, qald, _pupn,
  { {0x3f8f0004, 0xaad1013d, 0xa50701ab, 0x00000000}},  //   kogu_, _सभाक, ьера_,
  { {0x130a008b, 0xf7720084, 0x03a300ed, 0x00000000}},  //   ўнай_, _جات_, висо,
  { {0xe2970113, 0xb5fb0211, 0x2fcd0091, 0x00000000}},  // [7b80] дат_, nzál, _čega_,
  { {0x6b5c0923, 0x23810006, 0x00000000, 0x00000000}},  //   _méga, rėja_,   ,
  { {0x6b5c028c, 0x7f46007e, 0x40960478, 0x00000000}},  //   _léga, межж, фрат,
  { {0x3f8f01c5, 0x2bc4013d, 0x00000000, 0x00000000}},  //   gogu_, _लंबा,   ,
  { {0x9c7c016c, 0x6b5c00f4, 0xd176007e, 0x00000000}},  //   _meče, _néga, _жывы,
  { {0xdfd20054, 0x9c7c05fa, 0x1ea905f3, 0x00000000}},  //   _ليس_, _leče, ساني_,
  { {0xab9401fb, 0x1d19007e, 0x55770049, 0x00000000}},  //   никі, яюць_, ועסן_,
  { {0x9c7c05c5, 0x2d8e012d, 0xdb020082, 0x00000000}},  //   _neče, sofe_, _khoé,
  { {0x8bb30025, 0x00000000, 0x00000000, 0x00000000}},  //   خصوص,   ,   ,
  { {0x6b5c00f4, 0x4cd80044, 0xdb0b00fa, 0x00000000}},  //   _déga, _ঠাকু, _vigá,
  { {0x9cd7009b, 0xd0f7009b, 0xf1bf093f, 0x00000000}},  //   _חובה_, ומית_, _hrát_,
  { {0x320912b5, 0xf1bf04bb, 0x1ba900a1, 0x00000000}},  //   ytay_, _krát_, _فانٹ_,
  { {0x99660404, 0x09c80044, 0x00000000, 0x00000000}},  //   _откл, _শিকা,   ,
  { {0xb4d902fb, 0xd7fa00ed, 0x88bc00b9, 0x00000000}},  //   ारे_, _дуи_, zděj,
  { {0x62860288, 0x00000000, 0x00000000, 0x00000000}},  //   _axko,   ,   ,
  { {0x799a018e, 0x64430129, 0xe3b300a1, 0x00000000}},  //   lltw, _ànim, ئرس_,
  { {0xf1bf001d, 0x06ad0044, 0x33290066, 0x00000000}},  // [7b90] _quá_, _ক্রি, rdax_,
  { {0x51f80783, 0x1af50044, 0xa30900a1, 0x00000000}},  //   ьную_, _আসছে_, _کردے_,
  { {0x320901a3, 0x6d580030, 0x3f8f007f, 0x00000000}},  //   stay_, dkva, togu_,
  { {0x171c0049, 0x30a4263a, 0x23810006, 0x00000000}},  //   ַווע, трув, mėjo_,
  { {0x63ad2aa0, 0x23810006, 0x3f8f01c5, 0x00000000}},  //   mman, lėjo_, rogu_,
  { {0x63ad0ac2, 0x11da019b, 0xdca50265, 0x00000000}},  //   lman, _מחשב, нали,
  { {0xaf070265, 0x63ad006c, 0x23810006, 0x00000000}},  //   _очак, oman, nėjo_,
  { {0x63ad04cd, 0xe9d90242, 0x73fa0049, 0x00000000}},  //   nman, пки_, פּצו,
  { {0x9c7c1279, 0x8cca006e, 0x443e0082, 0x00000000}},  //   _reče, _स्को, ̣t_,
  { {0x63ad2aa1, 0x9c7c15bc, 0x23810006, 0x00000000}},  //   hman, _seče, kėjo_,
  { {0x06ad0055, 0x9c7c0b4a, 0x66160007, 0x00000000}},  //   _ক্লি, _peče, _spyk,
  { {0x2381010a, 0x63ad0213, 0x00000000, 0x00000000}},  //   dėjo_, jman,   ,
  { {0x63ad0089, 0x9c7c0733, 0x7bc10f7c, 0x00000000}},  //   dman, _veče, _hulu,
  { {0x7bc1044e, 0x6b9b0066, 0x1869005e, 0x00000000}},  //   _kulu, llug, _нали_,
  { {0xa8790049, 0xe9460063, 0x9c7c00ca, 0x00000000}},  //   _מאַר, _سروی, _teče,
  { {0x63ad014a, 0x7bc1003f, 0xc32301fc, 0x00000000}},  //   gman, _mulu, лмск,
  { {0x7bc10fef, 0xe1fa007e, 0x45150044, 0x00000000}},  // [7ba0] _lulu, яга_, ায়ক_,
  { {0x63ad0197, 0x7bc100b0, 0x61f62aa2, 0x00000000}},  //   aman, _oulu, rryl,
  { {0x5ed108b7, 0xdfcf0b59, 0x63ad0190, 0x00000000}},  //   _হয়ে, ميل_, bman,
  { {0xeaa706ea, 0x5de62aa3, 0xed592aa4, 0x00000000}},  //   _مع_, ежда, _ruža_,
  { {0xfe720439, 0x7bc10146, 0x6d5800ea, 0x00000000}},  //   ددا_, _aulu, tkva,
  { {0x7bc1011f, 0xb6060059, 0xac2600e2, 0x00000000}},  //   _bulu, mešč, ефик,
  { {0x6b9b03b4, 0x6d58006c, 0x6aa20010, 0x00000000}},  //   flug, rkva, _szof,
  { {0xa3e202d2, 0x67c80224, 0x6d5819f2, 0x00000000}},  //   नीय_, _něja, skva,
  { {0xc333009b, 0x80e30044, 0x7bc100e5, 0x00000000}},  //   רוח_, _পাত্, _eulu,
  { {0x63ad27dc, 0x65a0010f, 0x20180093, 0x00000000}},  //   zman, wöhn, _kpri_,
  { {0x63ad0036, 0xf7100082, 0x00000000, 0x00000000}},  //   yman, _vầng_,   ,
  { {0xb4d9001c, 0xb5fb0047, 0x63ad0142, 0x00000000}},  //   ार्_, szám, xman,
  { {0xf710001d, 0x7bc10aa8, 0x28d1007d, 0x00000000}},  //   _tầng_, _zulu, _द्वि,
  { {0xb52400a5, 0x63630004, 0xd5b8007c, 0x00000000}},  //   льск, _mõne, есс_,
  { {0x63ad04bd, 0x24e4007e, 0x7f980ddb, 0x00000000}},  //   tman, ыцяг, líqu,
  { {0x6b550977, 0x291e2aa5, 0x23810006, 0x00000000}},  //   _pági, leta_, rėjo_,
  { {0x20180197, 0xb5fb0010, 0x7f98008e, 0x00000000}},  // [7bb0] _apri_, zzáj, níqu,
  { {0x63ad000c, 0x644101b1, 0x00000000, 0x00000000}},  //   sman, älis,   ,
  { {0x6b5c2aa6, 0x63ad1464, 0x26cb0026, 0x00000000}},  //   _négo, pman, occo_,
  { {0x7ff40644, 0x7eb500a1, 0x7ae20471, 0x00000000}},  //   اسلا, نماؤ, _neot,
  { {0x291e022b, 0x7bc101a3, 0x59b2013d, 0x00000000}},  //   keta_, _sulu, ीदार,
  { {0x291e0209, 0x394e01d5, 0x212a0048, 0x00000000}},  //   jeta_, _nofs_, _gabh_,
  { {0x291e2aa7, 0xf1bf26b8, 0x7ae20288, 0x00000000}},  //   deta_, _trás_, _beot,
  { {0x6b5c009d, 0x6e220009, 0x7f98004a, 0x00000000}},  //   _dégo, bwob, fíqu,
  { {0xdcbb0057, 0xd7f80035, 0x7bc10022, 0x00000000}},  //   _еще_, eră_, _wulu,
  { {0x7bc1006a, 0xdb1a00fa, 0x69c20146, 0x00000000}},  //   _tulu, _cutâ, _duoe,
  { {0x6b9b0129, 0xf772031d, 0x8cca006e, 0x00000000}},  //   plug, لاح_, _स्टो,
  { {0x7ae20253, 0x3a260009, 0x321901d6, 0x00000000}},  //   _geot, _fsop_, _opsy_,
  { {0x291e0039, 0xd7f8001a, 0x00000000, 0x00000000}},  //   beta_, ară_,   ,
  { {0x5e56007b, 0x291e0211, 0xb6060059, 0x00000000}},  //   דישע_, ceta_, vešč,
  { {0xf9900355, 0x79a401fc, 0x212a0051, 0x00000000}},  //   _ابن_, _срце, _rabh_,
  { {0x6b5c009d, 0x00000000, 0x00000000, 0x00000000}},  //   _négl,   ,   ,
  { {0x68e30563, 0x98bc00b9, 0x9c7c00d0, 0x00000000}},  // [7bc0] _kend, _nově_, _meča,
  { {0x20560373, 0x68e32aa8, 0x3ebf00d4, 0x00000000}},  //   ктер, _jend, _agut_,
  { {0xd12f01f7, 0xb69b0035, 0x00000000, 0x00000000}},  //   تمل_, ngân,   ,
  { {0x291e07f2, 0x20070129, 0x6363006c, 0x00000000}},  //   zeta_, ània_, _põne,
  { {0x33200129, 0x291e0058, 0x7ae201f3, 0x00000000}},  //   meix_, yeta_, _reot,
  { {0x68e30004, 0x7ae20004, 0x291e2aa9, 0x00000000}},  //   _nend, _seot, xeta_,
  { {0x291e037e, 0x5f060954, 0xad6504b1, 0x00000000}},  //   veta_, _изва, دانه,
  { {0x33200129, 0x68e30020, 0x1ee8025a, 0x00000000}},  //   neix_, _aend, _سوئی_,
  { {0x291e037e, 0x1d2610d8, 0x9c7c05fa, 0x00000000}},  //   teta_, _имам, _deča,
  { {0xdbd90181, 0x68e304cb, 0xd7f8001a, 0x00000000}},  //   _açõe, _cend, tră_,
  { {0x68e322a1, 0x291e0127, 0x3a261071, 0x00000000}},  //   _dend, reta_, _wsop_,
  { {0xf09301f8, 0x68e301bb, 0xa5f9007c, 0x00000000}},  //   ינת_, _eend, нему_,
  { {0x291e011c, 0x33200129, 0xab5c0089, 0x00000000}},  //   peta_, deix_, _guļa,
  { {0x68e3008a, 0xceb300b3, 0xd8760025, 0x00000000}},  //   _gend, ייר_, _لاعب,
  { {0x478b003b, 0x68e80145, 0x2ee401c3, 0x00000000}},  //   _осим_, madd, _oemf_,
  { {0x68e3111a, 0x332004bd, 0x68e8019f, 0x00000000}},  //   _zend, geix_, ladd,
  { {0x6b5c00f4, 0xc7b100a1, 0x68e32aaa, 0x00000000}},  // [7bd0] _régl, _پڑھ_, _yend,
  { {0x44312aab, 0x68e30032, 0x00000000, 0x00000000}},  //   pvz_, _xend,   ,
  { {0xe8d7009b, 0x332b0240, 0x332000d4, 0x00000000}},  //   דובר_, _tacx_, beix_,
  { {0x68e8002b, 0x672d004a, 0x00000000, 0x00000000}},  //   hadd, _jaaj,   ,
  { {0x61ff005f, 0x672d0b37, 0x6b5c0010, 0x00000000}},  //   quql, _maaj, _végl,
  { {0xac09005c, 0x672d021e, 0x68e80022, 0x00000000}},  //   енка_, _laaj, jadd,
  { {0x61ed0302, 0x4c150054, 0x68e30e69, 0x00000000}},  //   lsal, ابتس, _rend,
  { {0x61ed010e, 0xdb1a00f6, 0x20010058, 0x00000000}},  //   osal, _cutà, muhi_,
  { {0x68e30149, 0x61ed00b0, 0x63bd000c, 0x00000000}},  //   _pend, nsal, _misn,
  { {0x68e3008d, 0x6e2901c3, 0x61ed05af, 0x00000000}},  //   _qend, _iseb, isal,
  { {0x68e30c5f, 0x9c7c0627, 0x61ed006b, 0x00000000}},  //   _vend, _teča, hsal,
  { {0x68e3010f, 0x61ed00b0, 0x3ce52aac, 0x00000000}},  //   _wend, ksal, _helv_,
  { {0x68e80a89, 0xfa3402fd, 0x7ae90032, 0x00000000}},  //   badd, _پرند, maet,
  { {0x7ae9018e, 0x68e32aad, 0x68e80197, 0x00000000}},  //   laet, _uend, cadd,
  { {0x63bd04fa, 0x332004bd, 0x49b80380, 0x00000000}},  //   _bisn, teix_, _شاهد_,
  { {0x7ae90bc4, 0x6e2901d9, 0x63bd2aae, 0x00000000}},  //   naet, _oseb, _cisn,
  { {0x332004bd, 0xd3870077, 0x61ed006a, 0x00000000}},  // [7be0] reix_, уйте_, gsal,
  { {0x29c90011, 0x629d0253, 0x7ae90016, 0x00000000}},  //   _múa_, _dyso, haet,
  { {0x5ecd0055, 0x29c90011, 0x63bd0065, 0x00000000}},  //   ারনে, _lúa_, _fisn,
  { {0x2fd702fd, 0x42d501ff, 0x68e80045, 0x00000000}},  //   اوند_, _віру, zadd,
  { {0x7ae90bc4, 0x80e30055, 0x629d0016, 0x00000000}},  //   daet, _পার্, _gyso,
  { {0x20010e1a, 0x6c5400ed, 0x6f090009, 0x00000000}},  //   buhi_, иклу, _ecec,
  { {0x50b5004c, 0xcd2700ed, 0x7ae90016, 0x00000000}},  //   _всту, ужје_, faet,
  { {0x7ae9018e, 0x29c92aaf, 0x3b5400c0, 0x00000000}},  //   gaet, _búa_, ркир,
  { {0xee3a008b, 0x7f75026b, 0x68e801e5, 0x00000000}},  //   _яна_, _турц, tadd,
  { {0xd6e10055, 0x672d01c2, 0x481400e2, 0x00000000}},  //   _ভাইয, _saaj, амос,
  { {0x68e81f5a, 0x77640039, 0xe0fb0049, 0x00000000}},  //   radd, _blix, עלטל,
  { {0x776400f6, 0x61ed0052, 0x80370049, 0x00000000}},  //   _clix, ysal, אנטע_,
  { {0x68e80365, 0x6280010a, 0x9b930025, 0x00000000}},  //   padd, _žmon, _النت,
  { {0x7764027b, 0x672d0020, 0x63bd00fa, 0x00000000}},  //   _elix, _waaj, _sisn,
  { {0x77642ab0, 0x63bd2ab1, 0x80e30044, 0x00000000}},  //   _flix, _pisn, _পাল্,
  { {0x61ed002d, 0x256600f4, 0x870900a1, 0x00000000}},  //   tsal, _rôle_, _شعبہ_,
  { {0x63bd0292, 0x9175007e, 0x61ed01b1, 0x00000000}},  // [7bf0] _visn, агац, usal,
  { {0x61ed01a3, 0x629d0428, 0x63bd2ab2, 0x00000000}},  //   rsal, _vyso, _wisn,
  { {0x61ed2ab3, 0x629d0046, 0x7ae90016, 0x00000000}},  //   ssal, _wyso, yaet,
  { {0x61ed2ab4, 0x200107de, 0x3ce501e3, 0x00000000}},  //   psal, ruhi_, _selv_,
  { {0x1d09003b, 0x2d760036, 0x51870088, 0x00000000}},  //   вели_, ałem_, _бува,
  { {0x29c9049a, 0xee38026c, 0x6e2901d9, 0x00000000}},  //   _rúa_, اقوں_, _vseb,
  { {0x29c9049a, 0x7ae9018e, 0xe0570167, 0x00000000}},  //   _súa_, taet, _حیات_,
  { {0x9c7c0107, 0x7ae90016, 0x236904be, 0x00000000}},  //   _tečn, uaet, nhaj_,
  { {0x69252ab5, 0x7ae90016, 0x6e2900d9, 0x00000000}},  //   ампа, raet, _useb,
  { {0xec6b004d, 0x7ae90032, 0x29050521, 0x00000000}},  //   _прек_, saet, ugla_,
  { {0x778601fc, 0x6d410aa4, 0x98a500e2, 0x00000000}},  //   илоз, _inla, рине,
  { {0x29c9049a, 0x27f81539, 0xc7b9007e, 0x00000000}},  //   _túa_, árna_, лёў_,
  { {0xd945012b, 0x2d760036, 0x00000000, 0x00000000}},  //   _вели, złem_,   ,
  { {0x2d760036, 0x3ea200ea, 0xe3bf0288, 0x00000000}},  //   yłem_, _økte_, _aiñ_,
  { {0x63630004, 0x9c7c07ac, 0xb97a009b, 0x00000000}},  //   _sõna, _nečl, _בנסי,
  { {0xdb02001d, 0x2b4d050f, 0xc3260545, 0x00000000}},  //   _khoá, njec_, јмак,

  { {0x6d41027d, 0x00000000, 0x00000000, 0x00000000}},  // [7c00] _onla,   ,   ,
  { {0xb17b0073, 0xe0d72ab6, 0x6e460014, 0x00000000}},  //   _svår, иву_, ینام,
  { {0xb4fb009b, 0xaec61abd, 0x00000000, 0x00000000}},  //   _בפיי, абел,   ,
  { {0x6d412ab7, 0x23690871, 0xa2d50316, 0x00000000}},  //   _anla, chaj_, युद्,
  { {0x645c1996, 0xdce1014a, 0x02d20061, 0x00000000}},  //   lyri, _aklı, तडीन,
  { {0x443a2ab8, 0x91e301ab, 0xa193007e, 0x00000000}},  //   _krp_, _форе, _маўч,
  { {0x7b660ae0, 0xed57025f, 0x9c7c00d0, 0x00000000}},  //   итие, рој_, _večo,
  { {0x6d410781, 0x443a0253, 0x6b550048, 0x00000000}},  //   _enla, _mrp_, _ságr,
  { {0x3f8601ca, 0xdb020082, 0xdb0b0023, 0x00000000}},  //   mnou_, _choá, _zhgë,
  { {0x3f8601ca, 0x6b5c0010, 0x2918000c, 0x00000000}},  //   lnou_, _mégi, ýra_,
  { {0x0137009b, 0x6b5c2ab9, 0x3f8600c4, 0x00000000}},  //   ברית_, _légi, onou_,
  { {0x3f862aba, 0x23690023, 0xdcf8007f, 0x00000000}},  //   nnou_, xhaj_, tovė,
  { {0x7bc8000b, 0xaac50025, 0x3f8600fa, 0x00000000}},  //   _hudu, _اتمن, inou_,
  { {0x7bc81ff1, 0x645c2abb, 0xdcf80006, 0x00000000}},  //   _kudu, fyri, rovė,
  { {0x7bc82abc, 0xdcfa001e, 0xe516006e, 0x00000000}},  //   _judu, _aktī, द्धि_,
  { {0x3f8601ca, 0x2249002d, 0x443a0145, 0x00000000}},  //   jnou_, txak_, _drp_,
  { {0x3f86004f, 0x657c00e0, 0x7bc82abd, 0x00000000}},  // [7c10] dnou_, birh, _ludu,
  { {0xdb090051, 0x23690023, 0x443a2abe, 0x00000000}},  //   imeá, shaj_, _frp_,
  { {0x2fc7001d, 0x443a2abf, 0x2d760036, 0x00000000}},  //   êng_, _grp_, ałek_,
  { {0x3f8600fa, 0xbfa80478, 0x00000000, 0x00000000}},  //   gnou_, атче_,   ,
  { {0x9294007e, 0x7bc81a3a, 0xd33600a3, 0x00000000}},  //   _маюц, _audu, _פרשה_,
  { {0x7bc80119, 0x645a010f, 0x200e0129, 0x00000000}},  //   _budu, ätig, àfic_,
  { {0xf1b2009b, 0x3f8601ca, 0x00000000, 0x00000000}},  //   _מסך_, bnou_,   ,
  { {0x7bc8003f, 0x88e30044, 0xed590161, 0x00000000}},  //   _dudu, _মাইক, _muži_,
  { {0x5ecd0044, 0x7c3a01a2, 0x00000000, 0x00000000}},  //   ারদে, _ertr,   ,
  { {0x6d41011c, 0x97d90b5f, 0xf1b20049, 0x00000000}},  //   _unla, льму_, ּסט_,
  { {0x3158007b, 0x7bc80aa8, 0x6e3b0161, 0x00000000}},  //   ייזן_, _gudu, _hrub,
  { {0xdb020011, 0x3212021e, 0x2131012d, 0x00000000}},  //   _thoá, ytyy_, _lazh_,
  { {0x443a013e, 0x98a5011f, 0x2d8700f4, 0x00000000}},  //   _srp_, rklı_, onne_,
  { {0xceb200b6, 0x6b5c028c, 0x645c1292, 0x00000000}},  //   פים_, _régi, tyri,
  { {0x6f1b037e, 0x2d87002a, 0x64a6008b, 0x00000000}},  //   _obuc, inne_, сава,
  { {0x321200b0, 0x6e3b2ac0, 0xed5904eb, 0x00000000}},  //   ttyy_, _orub, _duži_,
  { {0x52aa0893, 0xa1c300ed, 0x645c2ac1, 0x00000000}},  // [7c20] увам_, збуд, syri,
  { {0x645c0038, 0x9c7c01a8, 0x6b5c0010, 0x00000000}},  //   pyri, _dečj, _végi,
  { {0x66060343, 0x443a0197, 0x321200b0, 0x00000000}},  //   lukk, _urp_, styy_,
  { {0x2d8700f4, 0x6e3b0022, 0x7bc81284, 0x00000000}},  //   enne_, _brub, _rudu,
  { {0xf2d3007b, 0x63a4198e, 0xb148007a, 0x00000000}},  //   _מער_, mlin, _پیام_,
  { {0xf9870644, 0x63b6000c, 0x3f862ac2, 0x00000000}},  //   _رب_, lmyn, snou_,
  { {0x63a41875, 0x3d09007d, 0x38c80123, 0x00000000}},  //   olin, _सारे_, یادی_,
  { {0x63a4164f, 0x67260065, 0xbf16007a, 0x00000000}},  //   nlin, jekj, _دورب,
  { {0x6e3b011f, 0x26e70044, 0x66060145, 0x00000000}},  //   _grub, _কালো_, jukk,
  { {0xb5fb0047, 0x63a40d9a, 0x7bc80127, 0x00000000}},  //   zzás, hlin, _tudu,
  { {0x63a402d8, 0x319b0049, 0x63b6000c, 0x00000000}},  //   klin, רבינ, kmyn,
  { {0xb7670888, 0x31af014a, 0x32000022, 0x00000000}},  //   стой, müze_, kriy_,
  { {0x7a360b03, 0xb8ce0044, 0x65a001a2, 0x00000000}},  //   _دعائ, _কল_, höhu,
  { {0x63a4046a, 0x9c7c01ee, 0x32000203, 0x00000000}},  //   elin, _rečj, driy_,
  { {0x7bc20087, 0x00000000, 0x00000000, 0x00000000}},  //   _kiou,   ,   ,
  { {0x63a4009f, 0x63b6009f, 0xe3b00647, 0x00000000}},  //   glin, gmyn, فرق_,
  { {0xe800006e, 0x2d8700b4, 0xf1c20089, 0x00000000}},  // [7c30] लंका_, ynne_, košā_,
  { {0x63a4042c, 0x9c7c01d9, 0xf77f2ac3, 0x00000000}},  //   alin, _večj, liç_,
  { {0x63a40292, 0x9c7c0209, 0x6e3b0667, 0x00000000}},  //   blin, _dečk, _srub,
  { {0xceeb0014, 0x2d9e2ac4, 0x2d8c0091, 0x00000000}},  //   اران_, _akte_, _ajde_,
  { {0x44210022, 0x67c800b9, 0xe0e80044, 0x00000000}},  //   _hph_, _ději, _পারভ,
  { {0x3d0e0204, 0xabd501fc, 0x44212ac5, 0x00000000}},  //   _ठाणे_, оциј, _kph_,
  { {0x6b5c1ffa, 0x7afd0325, 0x799a0bde, 0x00000000}},  //   _légu, ósto, dotw,
  { {0x6f1b2ac6, 0x88bc00b9, 0x2d9e0056, 0x00000000}},  //   _ubuc, vděp, _ekte_,
  { {0xc8da001c, 0x6e3b2ac7, 0x291c008e, 0x00000000}},  //   _म्हट, _urub, _bbva_,
  { {0x7d18001c, 0x69db0553, 0x3ead0d61, 0x00000000}},  //   cfvs, rpue, _izet_,
  { {0x69db0219, 0xfd100025, 0x63a40322, 0x00000000}},  //   spue, _سجل_, ylin,
  { {0x66060007, 0x63a400f8, 0xae0d007d, 0x00000000}},  //   tukk, xlin, _समान_,
  { {0x3f9f000b, 0x63a40073, 0xf3f10011, 0x00000000}},  //   _mkuu_, vlin, ận_,
  { {0x6b8903e9, 0x6b5c00f4, 0x7aeb01d6, 0x00000000}},  //   lneg, _dégu, _hegt,
  { {0x44210190, 0x660604cb, 0x63a42ac8, 0x00000000}},  //   _cph_, sukk, tlin,
  { {0x4421004f, 0xf8b200b6, 0x69cb2ac9, 0x00000000}},  //   _dph_, _קשה_, _kuge,
  { {0x7aeb0047, 0x69cb2aca, 0x00da0b6c, 0x00000000}},  // [7c40] _megt, _juge, لبات_,
  { {0x63a40292, 0x7aeb1297, 0x8506007a, 0x00000000}},  //   slin, _legt, _بودن,
  { {0x63a4000d, 0x69c32acb, 0x69cb0004, 0x00000000}},  //   plin, _mine, _luge,
  { {0xee3a012b, 0x80da02f4, 0xe29a1fea, 0x00000000}},  //   ине_, _प्रे, _вам_,
  { {0xf77300a0, 0x6b8905c9, 0x69c3002d, 0x00000000}},  //   וקא_, dneg, _oine,
  { {0xafe6012b, 0x463b0049, 0xc0aa0151, 0x00000000}},  //   _могл, יענע, _نازل_,
  { {0x69cb010f, 0x69d90146, 0x7bc2013f, 0x00000000}},  //   _auge, _atwe, _piou,
  { {0x69cb000d, 0x69c30368, 0x0b8a0098, 0x00000000}},  //   _buge, _aine, јски_,
  { {0x7d0a001c, 0x69c3001a, 0x69cb0035, 0x00000000}},  //   pgfs, _bine, _cuge,
  { {0x6b5c2acc, 0x9c7c01ee, 0x79880908, 0x00000000}},  //   _régu, _leči, undw,
  { {0x69c30779, 0xcb6a00d7, 0x6b892acd, 0x00000000}},  //   _dine, _каже_, bneg,
  { {0x69c308ba, 0x2d9c0091, 0x9c7c0091, 0x00000000}},  //   _eine, love_, _neči,
  { {0x3a3d0016, 0x69cb0145, 0xf77f0189, 0x00000000}},  //   _grwp_, _guge, riç_,
  { {0x69c30949, 0x44210093, 0x80da006e, 0x00000000}},  //   _gine, _pph_, _प्ले,
  { {0xd37b0088, 0x69cb010f, 0x9c7c21e8, 0x00000000}},  //   ача_, _zuge, _beči,
  { {0x56950057, 0x69c3022b, 0x2d9c0213, 0x00000000}},  //   _найт, _zine, hove_,
  { {0x2d9c0209, 0x9c7c003b, 0x60f90147, 0x00000000}},  // [7c50] kove_, _deči, йная_,
  { {0x7bda29e9, 0x290c2ace, 0x69c300d4, 0x00000000}},  //   _ottu, ngda_, _xine,
  { {0x6f0b001c, 0x2d9c04a9, 0x44210022, 0x00000000}},  //   tggc, dove_, _uph_,
  { {0x2fc40009, 0x6b5c0010, 0x6b890009, 0x00000000}},  //   _cimg_, _mégs, xneg,
  { {0x7aeb0343, 0x7bda2acf, 0x6b891d45, 0x00000000}},  //   _regt, _attu, vneg,
  { {0xa3e203d7, 0x69cb152f, 0x6b890036, 0x00000000}},  //   नीक_, _ruge, wneg,
  { {0x6b890aa9, 0x80d60061, 0x69c3008e, 0x00000000}},  //   tneg, मुळे, _rine,
  { {0x69c30563, 0x69cb0fc3, 0x6e2d002b, 0x00000000}},  //   _sine, _puge, ħabb,
  { {0x6b9b0038, 0x6b890aa9, 0x34a80164, 0x00000000}},  //   roug, rneg, _गर्द,
  { {0x6b8905c9, 0x290c00f8, 0x2d9c0253, 0x00000000}},  //   sneg, ggda_, cove_,
  { {0x2fc40061, 0xe73a00e3, 0xc7a601fc, 0x00000000}},  //   _yimg_, бен_, зинк,
  { {0x69cb006c, 0x69c30133, 0xfb380025, 0x00000000}},  //   _tuge, _wine, _وأنت_,
  { {0x69c3000d, 0x9c7c003b, 0x656e0051, 0x00000000}},  //   _tine, _reči, thbh,
  { {0x2eed07a5, 0x9c7c00ca, 0x98ae0173, 0x00000000}},  //   _leef_, _seči, _zafč_,
  { {0x80aa03d7, 0x98a21023, 0x0443004c, 0x00000000}},  //   _करें, _пише, нерн,
  { {0x2d9c037e, 0x2eed0112, 0x57fa009b, 0x00000000}},  //   zove_, _neef_, _הלקו,
  { {0x32090211, 0x020603c8, 0x9c7c01d9, 0x00000000}},  // [7c60] guay_, язан, _veči,
  { {0xe1f70451, 0xdce30006, 0x2fc40045, 0x00000000}},  //   ягу_, minė, _simg_,
  { {0x2d9c057c, 0xdce3010a, 0xb4d801f5, 0x00000000}},  //   vove_, linė, ाडी_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdce3010a, 0x2d9c0091, 0x733b0049, 0x00000000}},  //   ninė, tove_, _העכס,
  { {0x09da0055, 0x2ca50146, 0xd6ae0044, 0x00000000}},  //   _দিলা, _byld_, _গলায,
  { {0xdee6107f, 0xfe6f00a1, 0x80e30044, 0x00000000}},  //   _нови, نگے_, _পাচ্,
  { {0x8fa300e3, 0x2d9c0065, 0x2eed02ae, 0x00000000}},  //   _засе, sove_, _geef_,
  { {0x0e66008b, 0x2d9c0091, 0x00000000, 0x00000000}},  //   _экан, pove_,   ,
  { {0x49732ad0, 0xdce30006, 0x6b80002b, 0x00000000}},  //   ельс, dinė, simg,
  { {0x6d48022b, 0x6b800061, 0x6b5c00f4, 0x00000000}},  //   _inda, pimg, _dégr,
  { {0x2902011f, 0x6d5a0613, 0x61f62ad1, 0x00000000}},  //   şka_, _hota, ksyl,
  { {0x6d5a0897, 0xd05c005f, 0xdce30006, 0x00000000}},  //   _kota, _verə, ginė,
  { {0x6d5a021e, 0xe5c4007c, 0xdb1100f8, 0x00000000}},  //   _jota, ессо, åför,
  { {0x6d5a002d, 0xb33b0095, 0x00000000, 0x00000000}},  //   _mota, _akça,   ,
  { {0x63710073, 0x26c92ad2, 0x6d5a00fa, 0x00000000}},  //   _mång, _ugao_, _lota,
  { {0x6d482ad3, 0x63710073, 0x6d5a0004, 0x00000000}},  // [7c70] _onda, _lång, _oota,
  { {0x6d5a0e34, 0x6363006c, 0x00000000, 0x00000000}},  //   _nota, _mõni,   ,
  { {0x776d062a, 0x7feb04b1, 0x00000000, 0x00000000}},  //   _klax, صراف_,   ,
  { {0x6d481b3e, 0x657e0026, 0x00000000, 0x00000000}},  //   _anda, _zmph,   ,
  { {0x6d5a0c79, 0x320902d4, 0x00000000, 0x00000000}},  //   _bota, quay_,   ,
  { {0x6d5a0181, 0xdca500ed, 0x4d640088, 0x00000000}},  //   _cota, мали, нків,
  { {0x6d5a0224, 0x2eed040f, 0x6b5c01cc, 0x00000000}},  //   _dota, _teef_, _régr,
  { {0x6d4829f9, 0x92c10044, 0x8d7700a2, 0x00000000}},  //   _enda, ুরী_, _کارا,
  { {0x6d5a00f8, 0x7f490133, 0x00000000, 0x00000000}},  //   _fota, _ineq,   ,
  { {0x63712ad4, 0xdce30006, 0xceb200b3, 0x00000000}},  //   _hånd, vinė, _יין_,
  { {0x63710073, 0x6b5c0010, 0x7c670025, 0x00000000}},  //   _gång, _végr, _عائل,
  { {0xdce3010a, 0x61f60016, 0x776d0035, 0x00000000}},  //   tinė, ysyl, _clax,
  { {0x63710039, 0x27e01435, 0x9c7c012d, 0x00000000}},  //   _månd, _čine_, _deču,
  { {0x1869134b, 0xdce3010a, 0x44330026, 0x00000000}},  //   _мали_, rinė, _bsx_,
  { {0x64a32ad5, 0x776d0203, 0xdce30006, 0x00000000}},  //   вара, _flax, sinė,
  { {0x04100044, 0xdce30006, 0x44330a89, 0x00000000}},  //   াবলী_, pinė, _dsx_,
  { {0x3aba0049, 0x256f006c, 0x00000000, 0x00000000}},  // [7c80] ַמענ, _süle_,   ,
  { {0x7e620020, 0x61f60016, 0x37e00044, 0x00000000}},  //   vyop, rsyl, _ভিতর,
  { {0x6d5a2ad6, 0x443c0047, 0x44330253, 0x00000000}},  //   _rota, _év_, _gsx_,
  { {0x6d5a00b0, 0x1e8601ab, 0x00000000, 0x00000000}},  //   _sota, млем,   ,
  { {0xf1af02f4, 0x63a901d5, 0x6d5a2ad7, 0x00000000}},  //   _जीवन, ċent, _pota,
  { {0x9c460088, 0x00000000, 0x00000000, 0x00000000}},  //   дхил,   ,   ,
  { {0xa2d502fb, 0xa2a202d2, 0x7f5b0068, 0x00000000}},  //   युक्, _कुत्, _fouq,
  { {0x5a340517, 0xd00f067a, 0xcf2603d6, 0x00000000}},  //   енит, _خلف_, _ترسي,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d482ad8, 0x588600a5, 0x7c2a0a7c, 0x00000000}},  //   _unda, дыма, _мозг_,
  { {0x9c7c15bc, 0x3cfe00d9, 0x00000000, 0x00000000}},  //   _peču, _idtv_,   ,
  { {0x95cb01f9, 0x09e60088, 0x6363006c, 0x00000000}},  //   жува_, _жодн, _tõni,
  { {0x9f6500f4, 0x644801e2, 0x00000000, 0x00000000}},  //   étés_, ådin,   ,
  { {0x63712ad9, 0xe8942329, 0x00000000, 0x00000000}},  //   _måne, _паль,   ,
  { {0x63711861, 0x776d008e, 0x00000000, 0x00000000}},  //   _låne, _tlax,   ,
  { {0x3a260011, 0x44330203, 0x57fb009b, 0x00000000}},  //   _kpop_, _vsx_, _ולהו,
  { {0xe1f00b6c, 0x7afd2ada, 0x6d0e01f5, 0x00000000}},  // [7c90] لسل_, ósti, _सांग_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd7f8001a, 0x7f5b00c4, 0x92c10044, 0x00000000}},  //   nsă_, _pouq, ুরে_,
  { {0x20df02d2, 0xb0df0309, 0x3cfe00fa, 0x00000000}},  //   _प्रध, _प्रग, _adtv_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xee380822, 0xae110061, 0x3cfe0087, 0x00000000}},  //   ьні_, डंबन_, _cdtv_,
  { {0xdca2003b, 0x7f5b009d, 0x3cfe00e5, 0x00000000}},  //   лаши, _touq, _ddtv_,
  { {0x3cfe01c3, 0x7f490133, 0x9c7c0087, 0x00000000}},  //   _edtv_, _uneq, _rečt,
  { {0x9915007e, 0x3a260082, 0x3f8f00e7, 0x00000000}},  //   ньні, _cpop_, mngu_,
  { {0xa3b603d7, 0x7d79039d, 0x00000000, 0x00000000}},  //   _चीन_, _عمار_,   ,
  { {0xe73a00e3, 0x00000000, 0x00000000, 0x00000000}},  //   пен_,   ,   ,
  { {0xf0920452, 0xe73a0057, 0x00000000, 0x00000000}},  //   רנט_, чем_,   ,
  { {0x15ba007c, 0xd7f8001a, 0x2b14013d, 0x00000000}},  //   зывы_, asă_, _धातु_,
  { {0x6363006c, 0x00000000, 0x00000000, 0x00000000}},  //   _mõnu,   ,   ,
  { {0xa5bb0036, 0x7afd0036, 0x2b5d01f3, 0x00000000}},  //   twór, óstw, _kowc_,
  { {0x02c6073b, 0x00000000, 0x00000000, 0x00000000}},  //   ейбо,   ,   ,
  { {0xe29700ed, 0x67240009, 0x3f8e01e5, 0x00000000}},  // [7ca0] еат_, _ibij, éfum_,
  { {0x764423f6, 0x6b550010, 0x249f0276, 0x00000000}},  //   _iriy, _vágy, şuma_,
  { {0x80a80044, 0x00000000, 0x00000000, 0x00000000}},  //   কেন্,   ,   ,
  { {0x44440a5c, 0x764401aa, 0x00000000, 0x00000000}},  //   _ir_, _kriy,   ,
  { {0x44440209, 0x67240065, 0xb17b05fe, 0x00000000}},  //   _hr_, _mbij, _ståe,
  { {0x44440018, 0x61e40390, 0x256f006c, 0x00000000}},  //   _kr_, mpil, _küla_,
  { {0x61e401c5, 0x44441044, 0xcfaa00a1, 0x00000000}},  //   lpil, _jr_, _فارم_,
  { {0x44442adb, 0x395c2862, 0x61e4010e, 0x00000000}},  //   _mr_, _sovs_, opil,
  { {0x44440995, 0x61e401c5, 0x6d4b0051, 0x00000000}},  //   _lr_, npil, álaí,
  { {0x44440a8a, 0xc27b0097, 0xee37005e, 0x00000000}},  //   _or_, פריי, _яну_,
  { {0xe894008b, 0x76440095, 0x9c7c00ca, 0x00000000}},  //   тань, _ariy, _večs,
  { {0x61e40190, 0xd7f8001a, 0x7644196c, 0x00000000}},  //   kpil, rsă_, _briy,
  { {0x44441218, 0x6b820537, 0x00000000, 0x00000000}},  //   _ar_, _imog,   ,
  { {0x44442adc, 0xd7f80035, 0x224000f8, 0x00000000}},  //   _br_, psă_, dvik_,
  { {0x4444049a, 0x779306c6, 0xd4040aef, 0x00000000}},  //   _cr_, _میدا, ляти,
  { {0x6443064d, 0x53340216, 0xe3b30d3a, 0x00000000}},  //   _ánim, лест, ارس_,
  { {0x444402d8, 0x69ca2add, 0x76442ade, 0x00000000}},  // [7cb0] _er_, _kife, _griy,
  { {0x4444028c, 0x7c282adf, 0x23690059, 0x00000000}},  //   _fr_, _opdr, skaj_,
  { {0x4444009f, 0x6b8200ee, 0x63630004, 0x00000000}},  //   _gr_, _omog, _sõnu,
  { {0x661d2ae0, 0x69ca09dd, 0x61e40089, 0x00000000}},  //   otsk, _life, bpil,
  { {0x444401c5, 0x63ad014a, 0x7c280e3f, 0x00000000}},  //   _zr_, mlan, _apdr,
  { {0x44440bc4, 0x69ca018e, 0x63ad114e, 0x00000000}},  //   _yr_, _nife, llan,
  { {0x32090b3d, 0x98a700b9, 0x63ad0048, 0x00000000}},  //   lray_, _daně_, olan,
  { {0xdb002ae1, 0x753c0107, 0x3f862ae2, 0x00000000}},  //   nomè, zdrz, ciou_,
  { {0x63ad006a, 0xdb1a2ae3, 0x660f0107, 0x00000000}},  //   ilan, _autó, juck,
  { {0x63ad191f, 0x660f041a, 0x6b820026, 0x00000000}},  //   hlan, duck, _emog,
  { {0x2d87061f, 0x66e603e8, 0x63ad15df, 0x00000000}},  //   mine_, кона, klan,
  { {0x63ad0313, 0x7644000a, 0x44440181, 0x00000000}},  //   jlan, _priy, _rr_,
  { {0x44440027, 0x6445253f, 0x2d87002a, 0x00000000}},  //   _sr_, _arhi, oine_,
  { {0x7ae906d3, 0x61e40089, 0x6b8209f4, 0x00000000}},  //   lbet, vpil, _zmog,
  { {0x64a6008b, 0x63ad0090, 0x61fd143e, 0x00000000}},  //   тава, flan, _avsl,
  { {0x672401cd, 0x444400b5, 0x2d872ae4, 0x00000000}},  //   _ubij, _vr_, hine_,
  { {0x7bcb0325, 0x2d87014a, 0x4444023a, 0x00000000}},  // [7cc0] _migu, kine_, _wr_,
  { {0x44442ae5, 0x63ad03b0, 0x61e404cb, 0x00000000}},  //   _tr_, alan, rpil,
  { {0x2d870868, 0x61e42ae6, 0xa2a2007d, 0x00000000}},  //   dine_, spil, _कुर्,
  { {0x63ad001a, 0x7bcb010e, 0x61e42ae7, 0x00000000}},  //   clan, _nigu, ppil,
  { {0x63a416c6, 0x7ae90030, 0x2d87085d, 0x00000000}},  //   moin, dbet, fine_,
  { {0x7bcb2ae8, 0x2d87051b, 0x63a400b0, 0x00000000}},  //   _aigu, gine_, loin,
  { {0x69ca0409, 0xdb0019cd, 0x7bcb0ed6, 0x00000000}},  //   _rife, lomé, _bigu,
  { {0x63a400b0, 0xdb1a0129, 0x7bcb26be, 0x00000000}},  //   noin, _autò, _cigu,
  { {0x2d870059, 0x7bcb020c, 0x69ca00f6, 0x00000000}},  //   bine_, _digu, _pife,
  { {0x637101c9, 0x63a40c7f, 0x7bcb000c, 0x00000000}},  //   _måna, hoin, _eigu,
  { {0x63ad21ec, 0x63a400b0, 0x7ae9014a, 0x00000000}},  //   ylan, koin, bbet,
  { {0x69ca2ae9, 0x63ad006b, 0x661d01c9, 0x00000000}},  //   _wife, xlan, ttsk,
  { {0x673d0693, 0x63a4055a, 0x69ca002b, 0x00000000}},  //   rdsj, doin, _tife,
  { {0x58d301fb, 0x63ad275d, 0xdb000489, 0x00000000}},  //   _кошт, wlan, domé,
  { {0x63ad0047, 0x661d0161, 0x660f0142, 0x00000000}},  //   tlan, stsk, suck,
  { {0x63a422d0, 0x79880c0d, 0x63ad0197, 0x00000000}},  //   goin, lidw, ulan,
  { {0xdb000f57, 0x317100e5, 0xc1b90604, 0x00000000}},  // [7cd0] romè, _plzz_, елах_,
  { {0x63ad0027, 0x2d8700bb, 0xdb0021c3, 0x00000000}},  //   slan, xine_, llmä,
  { {0x31c40057, 0x7ae9014a, 0x63a40c33, 0x00000000}},  //   рств, ybet, boin,
  { {0x63ad006b, 0x62080279, 0xa5bb00c4, 0x00000000}},  //   qlan, ürlü, stód,
  { {0x7bcb0198, 0xfe702aea, 0x128700a6, 0x00000000}},  //   _rigu, يده_, _شمسی_,
  { {0x2cac0bc4, 0x7ae90016, 0x00000000, 0x00000000}},  //   _bydd_, wbet,   ,
  { {0x2d87011f, 0x7ae900b5, 0x7bcb0a62, 0x00000000}},  //   rine_, tbet, _pigu,
  { {0x2d872aeb, 0x2cac018e, 0x00000000, 0x00000000}},  //   sine_, _dydd_,   ,
  { {0x7ae90073, 0x2d8701d9, 0x7bcb0e4b, 0x00000000}},  //   rbet, pine_, _vigu,
  { {0x2cac018e, 0x7ae90030, 0x57e9003b, 0x00000000}},  //   _fydd_, sbet, ндом_,
  { {0x378a026b, 0xfb150076, 0x7bcb20e3, 0x00000000}},  //   ебно_, _مواج, _tigu,
  { {0xab8402dc, 0x7bcb0203, 0x00000000, 0x00000000}},  //   _кучк, _uigu,   ,
  { {0x63a400b0, 0x6b890006, 0x7988011c, 0x00000000}},  //   voin, mieg, bidw,
  { {0x6b89010f, 0x2fcd2aec, 0x39580039, 0x00000000}},  //   lieg, _lieg_, örst_,
  { {0x63a4089e, 0x69c1010f, 0xe1ff00c4, 0x00000000}},  //   toin, mmle, _avó_,
  { {0x69c1011f, 0x6b8909a4, 0x05140044, 0x00000000}},  //   lmle, nieg, াজের_,
  { {0x63a40051, 0x256f0004, 0x63780181, 0x00000000}},  // [7ce0] roin, _küll_, _líng,
  { {0x63a416c6, 0xdb0000f4, 0x6b89002d, 0x00000000}},  //   soin, romé, hieg,
  { {0x6b890046, 0x63a400ab, 0xf3f10011, 0x00000000}},  //   kieg, poin, ật_,
  { {0xdfcf006d, 0x6b89050c, 0x2cac005b, 0x00000000}},  //   سيه_, jieg, _rydd_,
  { {0x2cac0bc4, 0x6b8901d6, 0xef210089, 0x00000000}},  //   _sydd_, dieg, daļā_,
  { {0xa0a61deb, 0x443a008a, 0x6da3003b, 0x00000000}},  //   _багд, _ksp_, бича,
  { {0x443a001c, 0x7988002b, 0x2fcd0026, 0x00000000}},  //   _jsp_, vidw, _fieg_,
  { {0x40930025, 0x443a145e, 0x6b890036, 0x00000000}},  //   _الفر, _msp_, gieg,
  { {0x4974041f, 0x443a007f, 0x298a02ea, 0x00000000}},  //   илис, _lsp_, есно_,
  { {0x443a2aed, 0x2fcd01c3, 0x00000000, 0x00000000}},  //   _osp_, _zieg_,   ,
  { {0xa3c403d7, 0x6b890036, 0x1755073b, 0x00000000}},  //   एगा_, bieg, авня,
  { {0x7c3a2aee, 0xa3d802fb, 0x09e30044, 0x00000000}},  //   _istr, ादन_, _মিরা,
  { {0x443a001c, 0x7afd000c, 0x00000000, 0x00000000}},  //   _asp_, ðste,   ,
  { {0xda7b0104, 0x753e0026, 0x443a01de, 0x00000000}},  //   _אנדר, _capz, _bsp_,
  { {0x443a01c5, 0x68fa2aef, 0x753e0126, 0x00000000}},  //   _csp_, matd, _dapz,
  { {0x443a2af0, 0x1dd4013d, 0x3ea9002b, 0x00000000}},  //   _dsp_, ददात, żati_,
  { {0xa2c0001c, 0x443a09b8, 0x50f500d7, 0x00000000}},  // [7cf0] लेल्, _esp_, изат,
  { {0x7c3a039b, 0x6378027b, 0x6b890089, 0x00000000}},  //   _ostr, _aínd, zieg,
  { {0x443a0035, 0xb03500e2, 0xc03501fc, 0x00000000}},  //   _gsp_, рнеш, рнеј,
  { {0x3ead0065, 0x68fa013f, 0x2fcd01f3, 0x00000000}},  //   _pyet_, hatd, _qieg_,
  { {0x6b890089, 0x68fa10c3, 0x12fa009b, 0x00000000}},  //   vieg, katd, _בהרב,
  { {0x6b892af1, 0x443a0146, 0x2fcd0116, 0x00000000}},  //   wieg, _ysp_, _wieg_,
  { {0x636a009f, 0x6b8907eb, 0x443a00f6, 0x00000000}},  //   _sýni, tieg, _xsp_,
  { {0x290a0010, 0x3d170061, 0x69dd00fa, 0x00000000}},  //   óban_, _नावे_, íseo,
  { {0xc9550147, 0x6b8901a2, 0x3f9c009d, 0x00000000}},  //   атны, rieg, évue_,
  { {0x6e3b0058, 0x6b89010f, 0x636a0142, 0x00000000}},  //   _isub, sieg, _výni,
  { {0x6b8928dc, 0xb8dd007d, 0x7c3a0022, 0x00000000}},  //   pieg, _आर_, _gstr,
  { {0x07a601e1, 0xc7a60088, 0x290b2af2, 0x00000000}},  //   рамн, римк, şca_,
  { {0x443a12dd, 0x7afb00b0, 0x6b5c0010, 0x00000000}},  //   _ssp_, maut, _négy,
  { {0x7afb021e, 0xb17b0039, 0x7c3a005b, 0x00000000}},  //   laut, _stån, _ystr,
  { {0x69db0f07, 0x63780219, 0x673f0065, 0x00000000}},  //   lque, _líne, _faqj,
  { {0x7afb028c, 0x00000000, 0x00000000, 0x00000000}},  //   naut,   ,   ,
  { {0x69db02d0, 0x2b9a0089, 0xd5af00a1, 0x00000000}},  // [7d00] nque, nīca_, سفہ_,
  { {0x6378045b, 0xd5fb0097, 0x69db00d4, 0x00000000}},  //   _sínd, _שפיר, ique,
  { {0x7afb00b0, 0x6e3b0020, 0x443a0181, 0x00000000}},  //   kaut, _asub, _usp_,
  { {0xf8b200b6, 0x7afb2af3, 0x888c0049, 0x00000000}},  //   חשב_, jaut, עראַ,
  { {0xee7a0558, 0x4438018e, 0x9ea70aed, 0x00000000}},  //   خصات_, lwr_, авца_,
  { {0x7afb1c9d, 0x14ba0061, 0x7c3a1c10, 0x00000000}},  //   eaut, _इराण, _pstr,
  { {0x7afb2af4, 0x998d0036, 0x6e3b0197, 0x00000000}},  //   faut, steś_, _esub,
  { {0xe4570049, 0x7afb2af5, 0x637803df, 0x00000000}},  //   שיקט_, gaut, _fíne,
  { {0x3f67025f, 0x44380016, 0x7c3a0036, 0x00000000}},  //   _тито_, hwr_, _wstr,
  { {0xd90e0167, 0xd90d0014, 0x9f5a0026, 0x00000000}},  //   ذیب_, فیه_, cupò_,
  { {0x7c3a0059, 0x7afb2af6, 0x68fa006b, 0x00000000}},  //   _ustr, baut, ratd,
  { {0x69db0c2f, 0x4438018e, 0x776400d4, 0x00000000}},  //   bque, dwr_, _coix,
  { {0xdb000845, 0x69db00f4, 0x6e220056, 0x00000000}},  //   nomí, cque, ntob,
  { {0x61e92af7, 0x44380016, 0x00000000, 0x00000000}},  //   _çeli, fwr_,   ,
  { {0x61e6001e, 0x44380016, 0x776400f6, 0x00000000}},  //   _atkl, gwr_, _foix,
  { {0x8c3c005f, 0x53980088, 0xb4b70061, 0x00000000}},  //   _uyğu, ався_, _जरी_,
  { {0xb7f80044, 0xdb1b01a2, 0x00000000, 0x00000000}},  // [7d10] _অমিত_, hluß,   ,
  { {0x2fd82af8, 0x9f580207, 0x6f1b1cae, 0x00000000}},  //   _burg_, _avrà_, _scuc,
  { {0x69db008e, 0x53350069, 0x75352191, 0x00000000}},  //   zque, _лент, mezz,
  { {0x75352af9, 0x68f82afa, 0x00000000, 0x00000000}},  //   lezz, _levd,   ,
  { {0xfce5005e, 0x7afb0006, 0x69db009d, 0x00000000}},  //   боло, vaut, xque,
  { {0x75350197, 0x290a008e, 0x7afb00d9, 0x00000000}},  //   nezz, óbal_, waut,
  { {0x7afb2afb, 0x65650066, 0x00000000, 0x00000000}},  //   taut, _mohh,   ,
  { {0xd4980104, 0x75350207, 0x6e3b2356, 0x00000000}},  //   יכות_, hezz, _tsub,
  { {0x8e850025, 0x65652afc, 0x75350010, 0x00000000}},  //   _الذه, _oohh, kezz,
  { {0x69db053e, 0x7afb03b6, 0x77642afd, 0x00000000}},  //   rque, saut, _soix,
  { {0x69db0249, 0x20010061, 0x6d4121e6, 0x00000000}},  //   sque, nshi_, _iala,
  { {0x20010020, 0xb17b1a95, 0x6d4301e5, 0x00000000}},  //   ishi_, _stål, ldna,
  { {0x6d4104be, 0x75350766, 0x65650026, 0x00000000}},  //   _kala, fezz, _bohh,
  { {0x6d41020c, 0x20010ea9, 0x6d43000c, 0x00000000}},  //   _jala, kshi_, ndna,
  { {0x6d410504, 0x69d90b28, 0xa3b30061, 0x00000000}},  //   _mala, _huwe, टतं_,
  { {0x69d91bc5, 0x6d41006a, 0x44380016, 0x00000000}},  //   _kuwe, _lala, rwr_,
  { {0x69d90007, 0x75350c0d, 0x7af90066, 0x00000000}},  // [7d20] _juwe, bezz, _mewt,
  { {0x6d412afe, 0x865b00b6, 0x69d911b3, 0x00000000}},  //   _nala, _עדיי, _muwe,
  { {0xa2b4007d, 0x69d90022, 0x2e2001aa, 0x00000000}},  //   _आरक्, _luwe, wòf_,
  { {0x6604000c, 0x6d41011c, 0x6e220197, 0x00000000}},  //   _kvik, _aala, ttob,
  { {0x6d410504, 0x471b007b, 0x69d90007, 0x00000000}},  //   _bala, רונג, _nuwe,
  { {0xdb002aff, 0xd2b7009b, 0x2fd8006c, 0x00000000}},  //   romí, _ללכת_, _turg_,
  { {0x6d411451, 0x6e220059, 0x6fb60076, 0x00000000}},  //   _dala, stob, _همسا,
  { {0x5f960054, 0x6d41002a, 0x68f8047f, 0x00000000}},  //   _الرئ, _eala, _sevd,
  { {0x6d410917, 0x7afd000c, 0x386c0016, 0x00000000}},  //   _fala, ðsta, wydr_,
  { {0xa3d80309, 0xad650025, 0xdb1a00c4, 0x00000000}},  //   ादा_, _واله, _autô,
  { {0x2c0b00a6, 0xd90f00a1, 0x63a9002b, 0x00000000}},  //   _معنی_, ریٹ_, ċenz,
  { {0x6d41002d, 0x2d8e1e55, 0x7ae201ee, 0x00000000}},  //   _zala, life_, _ufot,
  { {0x75352579, 0x6d41005d, 0x7bda1de9, 0x00000000}},  //   tezz, _yala, _hutu,
  { {0x7bda2b00, 0xd943003b, 0x6d412b01, 0x00000000}},  //   _kutu, _нечи, _xala,
  { {0x75352b02, 0x7bda03b6, 0x7aed001a, 0x00000000}},  //   rezz, _jutu, _întâ,
  { {0xa5bb00dc, 0x2001016c, 0x75350026, 0x00000000}},  //   ctón, vshi_, sezz,
  { {0x75352b03, 0x7bda01a3, 0x7d081fbc, 0x00000000}},  // [7d30] pezz, _lutu, _odds,
  { {0x7bda1160, 0x20070825, 0xdb19000a, 0x00000000}},  //   _outu, šnim_, _jiwò,
  { {0x610b001e, 0x93e00061, 0x6d410145, 0x00000000}},  //   vēlē, _खूपच_, _rala,
  { {0x63780489, 0x7d080009, 0x256f006b, 0x00000000}},  //   _vínc, _adds, _sülh_,
  { {0x672d008d, 0x8f34007e, 0x7bda06da, 0x00000000}},  //   _mbaj, яецц, _autu,
  { {0x61ed011c, 0x7bda023a, 0x6d41005f, 0x00000000}},  //   mpal, _butu, _qala,
  { {0x6d410047, 0x6d4301c9, 0x7bda0197, 0x00000000}},  //   _vala, rdna, _cutu,
  { {0x6d4117ca, 0x69d9011c, 0x99e5007c, 0x00000000}},  //   _wala, _puwe, ожид,
  { {0x6d41006a, 0x2ca90036, 0xc3340097, 0x00000000}},  //   _tala, ład_, לוק_,
  { {0xe8f9013b, 0x672d0211, 0x2d8e0181, 0x00000000}},  //   шло_, _abaj, cife_,
  { {0x764d047f, 0x7bda002d, 0x66041fbc, 0x00000000}},  //   _aray, _gutu, _svik,
  { {0x764d006b, 0xa6ca09ae, 0x69d90020, 0x00000000}},  //   _bray, илна_, _tuwe,
  { {0x99d70076, 0x764d009d, 0x7bda0f30, 0x00000000}},  //   _اتصا, _cray, _zutu,
  { {0x764d0058, 0x1a9a0049, 0x224901c3, 0x00000000}},  //   _dray, _דינע, dvak_,
  { {0x6f0901ee, 0x3f8f002d, 0x81d60044, 0x00000000}},  //   _odec, kigu_, _সবই_,
  { {0x3f8f037e, 0x2d8e0e8c, 0x764d009d, 0x00000000}},  //   jigu_, zife_, _fray,
  { {0x764d041d, 0x27e00119, 0x61ed011c, 0x00000000}},  // [7d40] _gray, _čini_, gpal,
  { {0x6f090211, 0xa1c30088, 0x80a80044, 0x00000000}},  //   _adec, дбуд, _কৃষ্,
  { {0x397a0049, 0xcf460641, 0x00000000, 0x00000000}},  //   סטענ, жней,   ,
  { {0x7bda007f, 0xdce1129d, 0x637801e5, 0x00000000}},  //   _rutu, _dolč, _fína,
  { {0x7bda0006, 0x6f09018e, 0xc6280044, 0x00000000}},  //   _sutu, _ddec, মিকা_,
  { {0xdb000047, 0x6f09014a, 0x63b60016, 0x00000000}},  //   domá, _edec, llyn,
  { {0x6023198f, 0xd007007c, 0xdb000129, 0x00000000}},  //   _одра, _мере_, tomà,
  { {0x63b6018e, 0x2d8e000a, 0xdb090048, 0x00000000}},  //   nlyn, sife_, tleá,
  { {0x81dc0044, 0x63b60045, 0x3fc900a1, 0x00000000}},  //   ণীর_, ilyn, _اگلی_,
  { {0x7bda2b04, 0x6f090036, 0x63b622af, 0x00000000}},  //   _tutu, _zdec, hlyn,
  { {0x61ed0266, 0x7bda00b0, 0xdb090048, 0x00000000}},  //   zpal, _uutu, sleá,
  { {0x61ed0061, 0xdbf00044, 0x764d0837, 0x00000000}},  //   ypal, _টিপস_, _pray,
  { {0x61e20051, 0xe738007e, 0x63b60016, 0x00000000}},  //   íoll, цеў_, dlyn,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f47008d, 0xb9c306dd, 0x6378000c, 0x00000000}},  //   ënë_, _تقوي, _sína,
  { {0x764d2b05, 0x2007021c, 0x61ed2b06, 0x00000000}},  //   _tray, šnik_, tpal,
  { {0xc175005e, 0xdce12b07, 0xbb3b0049, 0x00000000}},  // [7d50] плащ, _solč, סעמי,
  { {0x61ed006c, 0x799a05eb, 0x3d04013d, 0x00000000}},  //   rpal, nntw, रणों_,
  { {0x61ed00b0, 0x80070a78, 0xdfa71e8a, 0x00000000}},  //   spal, ючае, ојдо,
  { {0x61ed021e, 0x6458050f, 0xf4120049, 0x00000000}},  //   ppal, _švig, _אפט_,
  { {0x3f8f1f66, 0xfce50069, 0x249f019a, 0x00000000}},  //   rigu_, поло, ğumu_,
  { {0x63ad2b08, 0x00000000, 0x00000000, 0x00000000}},  //   loan,   ,   ,
  { {0x7afd000c, 0x00000000, 0x00000000, 0x00000000}},  //   ðsto,   ,   ,
  { {0xdb000489, 0x7bc2023f, 0x69c801bb, 0x00000000}},  //   tomá, _chou, emde,
  { {0xdb0e0051, 0x3eb9000c, 0x3f8d0087, 0x00000000}},  //   ódál, _ást_, _imeu_,
  { {0x8d770070, 0x63ad0082, 0xdb002b09, 0x00000000}},  //   _بارا, hoan, romá,
  { {0xa3bd03d7, 0x5eb00044, 0xf8ce01f5, 0x00000000}},  //   ेगा_, জেদে, _हृदय,
  { {0x7bc201d6, 0xa5bb1542, 0x91790082, 0x00000000}},  //   _ghou, stól, _lần_,
  { {0x20070f3a, 0x63ad2b0a, 0x7bc92b0b, 0x00000000}},  //   šnih_, doan, mmeu,
  { {0x7bc22b0c, 0x00000000, 0x00000000, 0x00000000}},  //   _zhou,   ,   ,
  { {0x69c30cd2, 0x63ad001a, 0x443300e5, 0x00000000}},  //   _ihne, foan, _cpx_,
  { {0x63ad0bc0, 0x46a601e1, 0x6b9b2b0d, 0x00000000}},  //   goan, _найв, nnug,
  { {0x171b009b, 0x63b62b0e, 0x00000000, 0x00000000}},  // [7d60] _הופע, rlyn,   ,
  { {0x63b6219e, 0x91790082, 0x870600a1, 0x00000000}},  //   slyn, _cần_, _بڑھے_,
  { {0x63ad00ea, 0x44330253, 0xb4d80164, 0x00000000}},  //   boan, _gpx_, िशी_,
  { {0x63ad0375, 0x53a60478, 0xf1bf013e, 0x00000000}},  //   coan, _хамб, _spát_,
  { {0x69c80016, 0x69c301a2, 0x9f030025, 0x00000000}},  //   ymde, _ohne, رووو,
  { {0x7bc20038, 0x25740039, 0xc8ff0044, 0x00000000}},  //   _shou, _sälj_, ্ভুত_,
  { {0x64580325, 0x00000000, 0x00000000, 0x00000000}},  //   _ávid,   ,   ,
  { {0x26c00026, 0x69c317f7, 0x22420145, 0x00000000}},  //   _ozio_, _ahne, _kskk_,
  { {0x62840198, 0xc33300b6, 0x25740039, 0x00000000}},  //   nzio, תוח_, _välj_,
  { {0x628402cf, 0x63ad27ab, 0x6f020048, 0x00000000}},  //   izio, zoan, laoc,
  { {0x7bc20038, 0xac760b03, 0x63ad0020, 0x00000000}},  //   _thou, _عائش, yoan,
  { {0x6284022b, 0xba2a0014, 0xe695007c, 0x00000000}},  //   kzio, _هستم_, димы,
  { {0x63ad2522, 0x00000000, 0x00000000, 0x00000000}},  //   voan,   ,   ,
  { {0x201a01a3, 0xa2cd02f4, 0x6284093c, 0x00000000}},  //   kupi_, _दृष्, dzio,
  { {0x92b90055, 0x63ad0035, 0x62842b0f, 0x00000000}},  //   _চলে_, toan, ezio,
  { {0x636819a2, 0x97a4007e, 0x201a2b10, 0x00000000}},  //   пруг_, _прыл, dupi_,
  { {0x6f020107, 0xa2cd006e, 0x63ad0035, 0x00000000}},  // [7d70] daoc, _दृश्, roan,
  { {0x6458010a, 0x9327007a, 0x291e0006, 0x00000000}},  //   _švie, _کردن, ngta_,
  { {0xf1c80054, 0x6284064c, 0xf1bf0051, 0x00000000}},  //   أولى_, azio, _spás_,
  { {0x27f8015f, 0x6f02016c, 0x00000000, 0x00000000}},  //   árny_, gaoc,   ,
  { {0x3254007e, 0x09140044, 0xa3aa013d, 0x00000000}},  //   _звяр, ত্যু_, खकर_,
  { {0xdd9101af, 0xee3803e8, 0x361c009b, 0x00000000}},  //   ضوع_, яні_, מודד,
  { {0x40340373, 0x201a0026, 0x6b9b2b11, 0x00000000}},  //   _перс, cupi_, tnug,
  { {0x291e0e3f, 0xdce10089, 0x69c30023, 0x00000000}},  //   egta_, _dolā, _shne,
  { {0x7bc90685, 0x2b4608ea, 0x00000000, 0x00000000}},  //   rmeu, _daoc_,   ,
  { {0x98bc0089, 0xfe700426, 0x7bc900d9, 0x00000000}},  //   _savā_, _صدق_, smeu,
  { {0x7d032b12, 0x07a600c2, 0xc7a60088, 0x00000000}},  //   mans, данн, динк,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2eff009d, 0x637800fa, 0x00000000, 0x00000000}},  //   _meuf_, _síno,   ,
  { {0xdd99000a, 0xa3b6007d, 0x00000000, 0x00000000}},  //   _dwňg_, _चीज_,   ,
  { {0x6fad0204, 0x2eff009d, 0x5fd90309, 0x00000000}},  //   टकां, _oeuf_, _बंगल,
  { {0x39472b13, 0x7d032b14, 0x2eff00f4, 0x00000000}},  //   _hans_, hans, _neuf_,
  { {0x394724aa, 0x6f0205fa, 0x26c000e7, 0x00000000}},  // [7d80] _kans_, vaoc, _uzio_,
  { {0x7d0300ee, 0x62840207, 0x201a04be, 0x00000000}},  //   jans, rzio, tupi_,
  { {0x394708d8, 0x7d032b15, 0x6f0205fa, 0x00000000}},  //   _mans_, dans, taoc,
  { {0x213a1a07, 0x20070181, 0x6284002d, 0x00000000}},  //   seph_, ânia_, pzio,
  { {0x7d030016, 0x6f020107, 0x644e068f, 0x00000000}},  //   fans, raoc, lvbi,
  { {0x44440428, 0x753c114b, 0x7d030091, 0x00000000}},  //   _ks_, nerz, gans,
  { {0x4444001c, 0x67240091, 0xac970380, 0x00000000}},  //   _js_, _ocij, ونها_,
  { {0x753c09fa, 0x6d530089, 0x7d0317e3, 0x00000000}},  //   herz, _ādaž, aans,
  { {0x4444001e, 0x7d030056, 0xcb6700ed, 0x00000000}},  //   _ls_, bans, ќање_,
  { {0x44440fb3, 0x7d03016c, 0x79810016, 0x00000000}},  //   _os_, cans, ghlw,
  { {0x39470a8d, 0x444404bd, 0x6d5a12e9, 0x00000000}},  //   _dans_, _ns_, _inta,
  { {0x6d4a0190, 0x6d480127, 0xbc790049, 0x00000000}},  //   ldfa, _hada, _צװײט,
  { {0x6d482b16, 0xa5bb002a, 0x753c010f, 0x00000000}},  //   _kada, ltói, ferz,
  { {0x39470116, 0x6d48286b, 0x442a0009, 0x00000000}},  //   _gans_, _jada, ftb_,
  { {0x44442b17, 0xa5bb002a, 0x6d48066d, 0x00000000}},  //   _cs_, ntói, _mada,
  { {0x444404bd, 0x6d480263, 0x69d81923, 0x00000000}},  //   _ds_, _lada, _hive,
  { {0x444400dd, 0x7d030020, 0x69d80b90, 0x00000000}},  // [7d90] _es_, yans, _kive,
  { {0x444409b8, 0x398001aa, 0xca480011, 0x00000000}},  //   _fs_, _fòse_, _mờ_,
  { {0x44440011, 0x69d82b18, 0x7d032b19, 0x00000000}},  //   _gs_, _mive, vans,
  { {0x6d5a020c, 0x6445008d, 0x7d030036, 0x00000000}},  //   _anta, _ishi, wans,
  { {0x4279007b, 0x7d032722, 0x8db5008b, 0x00000000}},  //   _זאָג, tans, нскі,
  { {0x6d482b1a, 0x44441784, 0x7c2a06d3, 0x00000000}},  //   _cada, _ys_, ftfr,
  { {0xabd5025f, 0xfc31035b, 0x6d4801a3, 0x00000000}},  //   нциј, احت_, _dada,
  { {0x39472b1b, 0x6d5a2957, 0x64450020, 0x00000000}},  //   _sans_, _enta, _mshi,
  { {0x7d032b1c, 0x6d480096, 0xca480011, 0x00000000}},  //   pans, _fada, _cờ_,
  { {0x6d4821a3, 0xf9910025, 0x661d006c, 0x00000000}},  //   _gada, طبخ_, dusk,
  { {0x7b6701be, 0x39470c61, 0x64450e92, 0x00000000}},  //   _отде, _vans_, _nshi,
  { {0x6d480b4a, 0x4444041e, 0x673d00f4, 0x00000000}},  //   _zada, _rs_, gesj,
  { {0x44442b1d, 0x753c1507, 0x39470007, 0x00000000}},  //   _ss_, terz, _tans_,
  { {0x69d82b1e, 0x7d010047, 0x7ae90e32, 0x00000000}},  //   _give, _jels, lcet,
  { {0x44440541, 0x7d01007f, 0x64a3132e, 0x00000000}},  //   _qs_, _mels, гара,
  { {0x4444021e, 0x2905006a, 0x7ae92b1f, 0x00000000}},  //   _vs_, lala_, ncet,
  { {0x4444001c, 0x7f4b001c, 0x6f0000bb, 0x00000000}},  // [7da0] _ws_, ddgq, _remc,
  { {0x290522d5, 0x64450065, 0x7d010e3e, 0x00000000}},  //   nala_, _fshi, _nels,
  { {0x44440038, 0x251b0049, 0x29050035, 0x00000000}},  //   _us_, _צוטא, iala_,
  { {0xdee62b20, 0x6d481cf7, 0x290503b0, 0x00000000}},  //   ходи, _sada, hala_,
  { {0x29051cce, 0x7d010010, 0xa2d603ec, 0x00000000}},  //   kala_, _bels, _سيست,
  { {0x29050868, 0x6d482b21, 0x29fd0027, 0x00000000}},  //   jala_, _qada, dňa_,
  { {0x69d8085d, 0x6d48007f, 0x7d010056, 0x00000000}},  //   _rive, _vada, _dels,
  { {0x5a342b22, 0x69d80d2a, 0x6d482b23, 0x00000000}},  //   внит, _sive, _wada,
  { {0x7d010047, 0xa5bb0051, 0x6d480091, 0x00000000}},  //   _fels, stói, _tada,
  { {0x2905020c, 0x7d01014a, 0xf8ab0011, 0x00000000}},  //   gala_, _gels, ười_,
  { {0x69d8081d, 0x00000000, 0x00000000, 0x00000000}},  //   _vive,   ,   ,
  { {0xca480011, 0xcf930049, 0x7ae90cc8, 0x00000000}},  //   _tờ_, ָטש_, ccet,
  { {0x69d805bc, 0x29050209, 0x95cb0893, 0x00000000}},  //   _tive, bala_, зува_,
  { {0x661d0127, 0xbf0c0061, 0xceb300a3, 0x00000000}},  //   rusk, हणुन_, ריש_,
  { {0xf434007e, 0x661d0653, 0x94a800d7, 0x00000000}},  //   лерэ, susk, етта_,
  { {0x661d01a3, 0x63a90091, 0x58bb009b, 0x00000000}},  //   pusk, čeno, _ממוצ,
  { {0xdb1b0181, 0xdcfa000a, 0x00000000, 0x00000000}},  // [7db0] fluê, _altč,   ,
  { {0x644504be, 0x200700c4, 0x00000000, 0x00000000}},  //   _tshi, ânio_,   ,
  { {0xbf0c001c, 0x6445000b, 0xd01000a1, 0x00000000}},  //   हणून_, _ushi, یلے_,
  { {0x2905022b, 0x7d0101e3, 0x29fd0142, 0x00000000}},  //   zala_, _sels, yňa_,
  { {0x7d01068f, 0x29050145, 0xe8d90082, 0x00000000}},  //   _pels, yala_, _đọ_,
  { {0x7ae90a2e, 0x23690ce4, 0x29fd0027, 0x00000000}},  //   wcet, ljaj_, vňa_,
  { {0x7d0105b7, 0x00000000, 0x00000000, 0x00000000}},  //   _vels,   ,   ,
  { {0x660d01cd, 0x29051bc6, 0x7f4b001c, 0x00000000}},  //   _ovak, wala_, qdgq,
  { {0x7d01000c, 0x7ae9000d, 0x00000000, 0x00000000}},  //   _tels, rcet,   ,
  { {0x7ae90026, 0x7dc40129, 0xc79800a1, 0x00000000}},  //   scet, ròsc, کھتا_,
  { {0x29052b24, 0xd7f8007e, 0x78862b25, 0x00000000}},  //   rala_, нуў_, _révé,
  { {0xc6260055, 0xf4270044, 0x23691ae2, 0x00000000}},  //   যবসা_, মবার_, jjaj_,
  { {0x29050149, 0x236905fa, 0x661a0036, 0x00000000}},  //   pala_, djaj_, ątko,
  { {0x64a6007e, 0x660d1e90, 0x00000000, 0x00000000}},  //   вага, _dvak,   ,
  { {0x232a189f, 0x00000000, 0x00000000, 0x00000000}},  //   мови_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe2972b26, 0x91e3007c, 0xc0e60147, 0x00000000}},  // [7dc0] ват_, иоте, возк,
  { {0xdce81e34, 0x91a70082, 0x00000000, 0x00000000}},  //   _podč, _địa_,   ,
  { {0x63782b27, 0x660d14f8, 0x00000000, 0x00000000}},  //   _líni, _zvak,   ,
  { {0x443a00e7, 0x00000000, 0x00000000, 0x00000000}},  //   _ipp_,   ,   ,
  { {0x443a2b28, 0x25740039, 0x80d30044, 0x00000000}},  //   _hpp_, _fält_, দুল্,
  { {0x1ea90076, 0x443a0bde, 0x61f618fa, 0x00000000}},  //   راني_, _kpp_, mpyl,
  { {0xa2d60201, 0x50c6007d, 0xed570098, 0x00000000}},  //   _मृत्, _वरिष, тој_,
  { {0x443a04e6, 0x00000000, 0x00000000, 0x00000000}},  //   _mpp_,   ,   ,
  { {0x443a2b29, 0x69c7002b, 0x63780919, 0x00000000}},  //   _lpp_, ċjen, _cíni,
  { {0x443a0292, 0x3f862b2a, 0x1e830451, 0x00000000}},  //   _opp_, lhou_, _тлум,
  { {0x660d0119, 0x637800c4, 0xdca32337, 0x00000000}},  //   _svak, _tính, _кафи,
  { {0x3f862b2b, 0x68f5026d, 0xa3e6006e, 0x00000000}},  //   nhou_, ızda, _पढ़_,
  { {0xb5fb0010, 0x443a192b, 0x6b8200e5, 0x00000000}},  //   lyáz, _app_, _ilog,
  { {0xe85406ea, 0xdb11000c, 0x443a0085, 0x00000000}},  //   _منتد, ðgön, _bpp_,
  { {0x443a0145, 0x6b820030, 0xdb1b0129, 0x00000000}},  //   _cpp_, _klog, fluè,
  { {0x443a0093, 0x644300c4, 0x61f601c3, 0x00000000}},  //   _dpp_, _ânim, fpyl,
  { {0x6b820521, 0x443a010e, 0x23690059, 0x00000000}},  // [7dd0] _mlog, _epp_, rjaj_,
  { {0x6b822b2c, 0x7c3a2b2d, 0x3d1c013d, 0x00000000}},  //   _llog, _optr, नलों_,
  { {0x6b820066, 0x443a0690, 0x4395005e, 0x00000000}},  //   _olog, _gpp_, _банс,
  { {0x5ecc0044, 0x547a00a3, 0x00000000, 0x00000000}},  //   িশনে, _נטרו,   ,
  { {0xb2870783, 0x3ea90129, 0x61e20051, 0x00000000}},  //   _рынк, çat_, íolt,
  { {0x3ea901d5, 0x6b820026, 0x00000000, 0x00000000}},  //   ħat_, _alog,   ,
  { {0xe8d9001d, 0x63780051, 0x443a2b2e, 0x00000000}},  //   _đỏ_, _síni, _xpp_,
  { {0x6b8219dd, 0x3f860161, 0x29180c38, 0x00000000}},  //   _clog, chou_, óran_,
  { {0xe9d90264, 0x69ca002a, 0x2b4d2b2f, 0x00000000}},  //   нки_, _bhfe, rdec_,
  { {0x6b820181, 0x2b4d0ab2, 0x3ea00048, 0x00000000}},  //   _elog, sdec_, úite_,
  { {0x63a90295, 0xa3e3007d, 0x6b822b30, 0x00000000}},  //   čenj, _फूल_, _flog,
  { {0x443a0093, 0xeb74007e, 0x6aa4012d, 0x00000000}},  //   _rpp_, _вышэ, _žife,
  { {0x64572b31, 0x7afb020c, 0x443a2425, 0x00000000}},  //   _arxi, mbut, _spp_,
  { {0xceb200b6, 0x1a9a007b, 0x3f86002b, 0x00000000}},  //   צים_, _אינע, zhou_,
  { {0x3ceb013d, 0x23360b86, 0xc7b904eb, 0x00000000}},  //   _चलने_, лхар, suđa_,
  { {0x443a049a, 0x7afb2b32, 0x6e3b0036, 0x00000000}},  //   _vpp_, nbut, _opub,
  { {0xf772025a, 0x443a0145, 0x00000000, 0x00000000}},  // [7de0] _ناک_, _wpp_,   ,
  { {0x201a016c, 0x7afb0009, 0x2d8700ca, 0x00000000}},  //   trpi_, hbut, jhne_,
  { {0xef1a0113, 0x443a05ce, 0x3f860343, 0x00000000}},  //   еме_, _upp_, thou_,
  { {0xa5bb0b33, 0x5f06003b, 0x3f8601dc, 0x00000000}},  //   stót, узда, uhou_,
  { {0x63a42b13, 0x3f860007, 0x7afb2b33, 0x00000000}},  //   mnin, rhou_, dbut,
  { {0x63a40073, 0xa5bb2b34, 0x3f860007, 0x00000000}},  //   lnin, ltór, shou_,
  { {0x63a42b35, 0x6c6600a1, 0x6e3b2b36, 0x00000000}},  //   onin, العہ_, _epub,
  { {0x63a42b37, 0x61e6007f, 0x7afb011c, 0x00000000}},  //   nnin, _kukl, gbut,
  { {0xe8d900ad, 0x63a40038, 0x3f84020c, 0x00000000}},  //   _đề_, inin, _ilmu_,
  { {0xdd8f06f1, 0x63a422ae, 0x2d870471, 0x00000000}},  //   _فوق_, hnin, chne_,
  { {0x63a402e1, 0xa5bb2b38, 0x7afb0146, 0x00000000}},  //   knin, któr, bbut,
  { {0x6b82021d, 0x63a40239, 0x8c1b0104, 0x00000000}},  //   _ulog, jnin, _טובי,
  { {0x63a40239, 0x7ae2002d, 0x6e2204a5, 0x00000000}},  //   dnin, _igot, nuob,
  { {0x7d0a000b, 0x63a4046a, 0x2bc2001c, 0x00000000}},  //   nafs, enin, शतवा,
  { {0x63a4000c, 0x645800dc, 0x61e62b39, 0x00000000}},  //   fnin, _ávil, _aukl,
  { {0x63a40018, 0x981306dd, 0x7d0a2b3a, 0x00000000}},  //   gnin, _ابوا, hafs,
  { {0x31710091, 0x799a00e7, 0x00000000, 0x00000000}},  // [7df0] _pozz_, oitw,   ,
  { {0xa5bb00dc, 0x63a400ab, 0x61150088, 0x00000000}},  //   atór, anin, рджу,
  { {0x31c4007c, 0x63a4279a, 0x6e3b00f6, 0x00000000}},  //   сств, bnin, _spub,
  { {0x7ae204e9, 0xa5bb16b5, 0x63a400ca, 0x00000000}},  //   _ngot, ctór, cnin,
  { {0x11d90054, 0x4431002d, 0xaf0401fb, 0x00000000}},  //   _لوحة_, ltz_, спіл,
  { {0x7ae2008e, 0x44311126, 0x3f840066, 0x00000000}},  //   _agot, otz_, _elmu_,
  { {0x4431022b, 0x7afb2b3b, 0xa5bb000c, 0x00000000}},  //   ntz_, tbut, próf,
  { {0x543c0049, 0x69ca007d, 0x4431002d, 0x00000000}},  //   געהא, _सीबी, itz_,
  { {0x7afb002b, 0x2d870397, 0x628d0026, 0x00000000}},  //   rbut, phne_, nzao,
  { {0x44232b3c, 0x661d221b, 0x7ae2002d, 0x00000000}},  //   kuj_, drsk, _egot,
  { {0x63a4004e, 0x661d0007, 0xfd100025, 0x00000000}},  //   ynin, ersk, _رجل_,
  { {0x6d430207, 0x442318d5, 0x3ebf0058, 0x00000000}},  //   lena, duj_, _kyut_,
  { {0x63a40239, 0xe8ee0364, 0x44310668, 0x00000000}},  //   vnin, _мл_, etz_,
  { {0x6d430091, 0x44311270, 0x63780051, 0x00000000}},  //   nena, ftz_, _línt,
  { {0xa507012b, 0x44230046, 0x04460175, 0x00000000}},  //   реса_, guj_, шевн,
  { {0x6d43002d, 0x6b9b0197, 0x6b8901d6, 0x00000000}},  //   hena, niug, nheg,
  { {0x29070127, 0xa5bb2b3d, 0x2d850039, 0x00000000}},  // [7e00] _kena_, rtór, _olle_,
  { {0x63a4004e, 0xa5bb2b3e, 0x69c12b3f, 0x00000000}},  //   snin, stór, nlle,
  { {0x69c10ad5, 0x6d432283, 0x6378009f, 0x00000000}},  //   ille, dena, _sínu,
  { {0x2907002a, 0x6d43001c, 0x66040cfe, 0x00000000}},  //   _lena_, eena, _kwik,
  { {0x2bdf02d2, 0x7d0a06a4, 0x3a3d0093, 0x00000000}},  //   _पंजा, tafs, _npwp_,
  { {0x6d432b40, 0x29072b41, 0xdd8f006d, 0x00000000}},  //   gena, _nena_, وون_,
  { {0xa067005e, 0x29180051, 0x3f9c009d, 0x00000000}},  //   _кара_, óram_, évus_,
  { {0x2d85028c, 0x6f0b001c, 0x27e0021e, 0x00000000}},  //   _elle_, cagc, _niin_,
  { {0x6d43027e, 0x29070066, 0x44230871, 0x00000000}},  //   bena, _bena_, zuj_,
  { {0x63a91238, 0x6d432b42, 0x661d0190, 0x00000000}},  //   čeni, cena, vrsk,
  { {0xe8d900ad, 0x2907022b, 0x2bdf007d, 0x00000000}},  //   _để_, _dena_, _पंचा,
  { {0x7ae201d9, 0x4423003b, 0x6b9b0207, 0x00000000}},  //   _ugot, vuj_, ciug,
  { {0x661d040f, 0x27e0011c, 0x799a00e7, 0x00000000}},  //   ursk, _diin_, pitw,
  { {0x44230036, 0x443101d6, 0x2d9c0065, 0x00000000}},  //   tuj_, ttz_, nive_,
  { {0x7d082b43, 0x27e71d10, 0x98a50006, 0x00000000}},  //   _meds, _gunn_, delė_,
  { {0x05270055, 0x44231191, 0x6d431983, 0x00000000}},  //   য়ের_, ruj_, zena,
  { {0x6d43000a, 0x442318d5, 0xa7870167, 0x00000000}},  // [7e10] yena, suj_, _مشکو,
  { {0x63781d59, 0x7d0824fd, 0x2907002b, 0x00000000}},  //   _sínt, _neds, _xena_,
  { {0x2d9c19e4, 0x6d43046e, 0x290c00c4, 0x00000000}},  //   dive_, vena, iada_,
  { {0x290c0020, 0x6d43023a, 0x00000000, 0x00000000}},  //   hada_, wena,   ,
  { {0x290c01cd, 0x7d080018, 0x6d43084b, 0x00000000}},  //   kada_, _beds, tena,
  { {0x290c029a, 0x2d9c0030, 0x764d00e0, 0x00000000}},  //   jada_, give_, _msay,
  { {0x290c22c5, 0x672d0107, 0x29070039, 0x00000000}},  //   dada_, _ocaj, _rena_,
  { {0x290701d5, 0xa6db000c, 0x6d430a6b, 0x00000000}},  //   _sena_, veðn, sena,
  { {0x69c104bd, 0x6d43022b, 0x290c00c4, 0x00000000}},  //   tlle, pena, fada_,
  { {0x290c0d42, 0x8d740025, 0x27e00004, 0x00000000}},  //   gada_, _والا, _siin_,
  { {0x69c1018e, 0x6d8a026c, 0x66e6004c, 0x00000000}},  //   rlle, _حملہ_, йона,
  { {0x4cd00055, 0x290715e3, 0x103a0049, 0x00000000}},  //   _স্কু, _wena_, נגרע,
  { {0x2907000b, 0x290c04bd, 0x6fda00b9, 0x00000000}},  //   _tena_, bada_, _důch,
  { {0x290c0df5, 0x225e01ca, 0xdb0900f6, 0x00000000}},  //   cada_, _čtk_, cleò,
  { {0x39450168, 0x443e0129, 0x94790140, 0x00000000}},  //   mels_, ït_, асту_,
  { {0x2d9c0065, 0x08760049, 0x9f9e0023, 0x00000000}},  //   zive_, _לעצט_, rçës_,
  { {0xae1c0309, 0x98a50006, 0x224900e0, 0x00000000}},  // [7e20] _निधन_, telė_, gwak_,
  { {0x3945032c, 0x00000000, 0x00000000, 0x00000000}},  //   nels_,   ,   ,
  { {0x2d9c05f0, 0xa99a0049, 0x7ee60025, 0x00000000}},  //   vive_, נבער, مكان,
  { {0x290c0977, 0x543b007b, 0x39450007, 0x00000000}},  //   zada_, _געטא, hels_,
  { {0x2d9c0038, 0x39450343, 0x290c0180, 0x00000000}},  //   tive_, kels_, yada_,
  { {0xa11601ef, 0x290c2b44, 0x13bd0055, 0x00000000}},  //   _دوست, xada_, _আওয়,
  { {0x30860054, 0x394500ab, 0xd47a0049, 0x00000000}},  //   _الأف, dels_, טאַל,
  { {0x7d0801b5, 0x290c2b45, 0x207b01ce, 0x00000000}},  //   _weds, wada_, _גאלא,
  { {0x290c0004, 0xdb1b2b46, 0x39450129, 0x00000000}},  //   tada_, cluí, fels_,
  { {0xdb0000f7, 0xd90e0123, 0x394505d0, 0x00000000}},  //   tomó, ریب_, gels_,
  { {0x91bb00a3, 0xc1bb0049, 0x315708cd, 0x00000000}},  //   רמיי, רמיש, זיין_,
  { {0x3a2400f8, 0xe61f00c4, 0x00000000, 0x00000000}},  //   pump_, trô_,   ,
  { {0x290c117c, 0x8f9b009b, 0xfa330014, 0x00000000}},  //   pada_, ריכי, _فرود,
  { {0x394501c5, 0x00000000, 0x00000000, 0x00000000}},  //   cels_,   ,   ,
  { {0x499b0452, 0x96f9004d, 0x65942b47, 0x00000000}},  //   _תשוב, _кейт_, чару,
  { {0x07a403f3, 0x26120061, 0x00000000, 0x00000000}},  //   _најн, _तिची_,   ,
  { {0x7dcd1b0f, 0x5215022a, 0x00000000, 0x00000000}},  // [7e30] núsc, юдат,   ,
  { {0x6f0901ee, 0x35f80025, 0x00000000, 0x00000000}},  //   _seec, _اريد_,   ,
  { {0xa5bb0c59, 0x6f092b48, 0x9ee904b1, 0x00000000}},  //   prób, _peec, لفضل_,
  { {0x65770065, 0x394500bb, 0xff0705b8, 0x00000000}},  //   _hoxh, zels_, сяжн,
  { {0x6db50230, 0x61ed006b, 0x7dcd00d4, 0x00000000}},  //   ойду, qqal, júsc,
  { {0xdb02009f, 0xed59004c, 0xb4fb007d, 0x00000000}},  //   _skoð, рок_, ्रिय_,
  { {0xd7c90061, 0x394500ab, 0x00000000, 0x00000000}},  //   रताच, vels_,   ,
  { {0xa2d00204, 0x39450aba, 0xdd99000a, 0x00000000}},  //   _दरम्, wels_, _kwňk_,
  { {0xb4fb0164, 0x6e99007e, 0x00000000, 0x00000000}},  //   ्राय_, _твар_,   ,
  { {0xe8df00ad, 0x3cf1006b, 0x3979007c, 0x00000000}},  //   _giới_, _üzv_, рсию_,
  { {0x394500f4, 0x0cab005e, 0xa3d9007d, 0x00000000}},  //   rels_, _стаи_, ाषा_,
  { {0x39450343, 0x65650082, 0x00000000, 0x00000000}},  //   sels_, _anhh,   ,
  { {0x39451c83, 0x65772b49, 0x70c6007d, 0x00000000}},  //   pels_, _boxh, _वर्ल,
  { {0x9f5a0173, 0xa50704dd, 0x00000000, 0x00000000}},  //   nspò_, жера_,   ,
  { {0xe7320025, 0xa5bb0036, 0xc7b911af, 0x00000000}},  //   _قصة_, wróc, srđa_,
  { {0x776405d2, 0x660216b4, 0x00000000, 0x00000000}},  //   _unix, _çoko,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [7e40]   ,   ,   ,
  { {0x65770023, 0x10a610a9, 0x6616007f, 0x00000000}},  //   _goxh, оизн, _ivyk,
  { {0x661a0036, 0xd6a9025a, 0xf21e013d, 0x00000000}},  //   ątku, _ندیم_, यूज़_,
  { {0xddc90046, 0x7dcd008e, 0x645e0197, 0x00000000}},  //   _treś, yúsc, _irpi,
  { {0x88cf0044, 0xde58007e, 0x5e580088, 0x00000000}},  //   রশিক, салі_, силя_,
  { {0x645e1adc, 0x00000000, 0x00000000, 0x00000000}},  //   _krpi,   ,   ,
  { {0x0b8a0893, 0x00000000, 0x00000000, 0x00000000}},  //   исии_,   ,   ,
  { {0x224201a3, 0x00000000, 0x00000000, 0x00000000}},  //   _kpkk_,   ,   ,
  { {0x9f4d01a2, 0x00000000, 0x00000000, 0x00000000}},  //   _hieß_,   ,   ,
  { {0x7afd006b, 0x290a0a47, 0x6d23003b, 0x00000000}},  //   ısta, úba_, _одуз,
  { {0x6c4a025a, 0x81570049, 0xd7f40930, 0x00000000}},  //   _خلاف_, קסטע_, язны,
  { {0x7dcd0b33, 0x2fc600bb, 0x6e220912, 0x00000000}},  //   púsc, nlog_, orob,
  { {0x8bd70476, 0xdb09010f, 0x6e2200d9, 0x00000000}},  //   _וואו_, ließ, nrob,
  { {0x26c50089, 0x6f022a9c, 0x94ab005e, 0x00000000}},  //   ālo_, hboc, атба_,
  { {0x2fc62b4a, 0x7dcd0051, 0xe8d90011, 0x00000000}},  //   klog_, núsa, _đệ_,
  { {0x27fe0093, 0x2fc60022, 0x00000000, 0x00000000}},  //   mptn_, jlog_,   ,
  { {0x2fc60627, 0xe1f00167, 0x51f80147, 0x00000000}},  // [7e50] dlog_, نسل_, жную_,
  { {0x6e220b41, 0x00000000, 0x00000000, 0x00000000}},  //   drob,   ,   ,
  { {0x6e220089, 0x2fc62b4b, 0xf4850014, 0x00000000}},  //   erob, flog_, _رادی,
  { {0xb4d7001c, 0x63a90428, 0x2fc604eb, 0x00000000}},  //   िधी_, čens, glog_,
  { {0x6e22007f, 0x8d650242, 0x51870216, 0x00000000}},  //   grob, звле, _дува,
  { {0x2fc619d8, 0xf2d200a3, 0xc27a009b, 0x00000000}},  //   alog_, _נעם_, _הרשי,
  { {0x2fc61e7f, 0x1fa7012b, 0x30a4025f, 0x00000000}},  //   blog_, _драг, _жртв,
  { {0x6e2204eb, 0x2fc60740, 0x997c0089, 0x00000000}},  //   brob, clog_, _jāņu_,
  { {0x6e221153, 0x80e00044, 0x6f1b11af, 0x00000000}},  //   crob, _প্প্, _iduc,
  { {0xacf402fd, 0x7dcd0048, 0x00000000, 0x00000000}},  //   _قسمت, búsa,   ,
  { {0x7c590014, 0x00000000, 0x00000000, 0x00000000}},  //   _دلار_,   ,   ,
  { {0xe73a16a9, 0x7b640242, 0xeaae00a1, 0x00000000}},  //   щем_, _отче, ئٹی_,
  { {0x98770059, 0x645e012d, 0x00000000, 0x00000000}},  //   _išče_, _srpi,   ,
  { {0x386a002a, 0x2fc62b4c, 0x00000000, 0x00000000}},  //   óirí_, zlog_,   ,
  { {0x2fc6077d, 0x6f1b11ac, 0x6e220036, 0x00000000}},  //   ylog_, _oduc, zrob,
  { {0x6d86009f, 0x2fc600fa, 0x00000000, 0x00000000}},  //   _aðal, xlog_,   ,
  { {0xe8d9001d, 0x527600e2, 0x00000000, 0x00000000}},  // [7e60] _độ_, чуву,   ,
  { {0x6f1b2b4d, 0x645e09fc, 0x7dc40129, 0x00000000}},  //   _aduc, _trpi, pòsi,
  { {0x757b009b, 0xdefa007c, 0x00000000, 0x00000000}},  //   _הטיפ, был_,   ,
  { {0x91e604ef, 0x6e220181, 0x442a0004, 0x00000000}},  //   _номе, trob, mub_,
  { {0x44442b4e, 0x442a2860, 0x2fc601bb, 0x00000000}},  //   _hp_, lub_, rlog_,
  { {0x444404cb, 0x6e2204f3, 0x763b0049, 0x00000000}},  //   _kp_, rrob, מענג,
  { {0x444428a0, 0x442a005f, 0x4438000d, 0x00000000}},  //   _jp_, nub_, ntr_,
  { {0x6e222b4f, 0x7644000a, 0x7dcd2396, 0x00000000}},  //   prob, _opiy, rúsa,
  { {0x444401d9, 0x442a0016, 0xaa581843, 0x00000000}},  //   _lp_, hub_, ципу_,
  { {0x44442b50, 0x442a2b51, 0x3f8601ca, 0x00000000}},  //   _op_, kub_, lkou_,
  { {0x44440046, 0xdd8f0054, 0x442a2b52, 0x00000000}},  //   _np_, _حول_, jub_,
  { {0x3f862b53, 0x442a006c, 0x00000000, 0x00000000}},  //   nkou_, dub_,   ,
  { {0x44440607, 0xab2701e1, 0xf1be006e, 0x00000000}},  //   _ap_, _хоча_, ्तान,
  { {0x6d5803ed, 0xcaa5006d, 0x6d4a18be, 0x00000000}},  //   ndva, _تصمي, nefa,
  { {0x44440011, 0x69da010f, 0x442a006c, 0x00000000}},  //   _cp_, mmte, gub_,
  { {0x69c80129, 0x9f440065, 0x6d4a00fa, 0x00000000}},  //   llde, _dimë_, hefa,
  { {0x6d4a00f8, 0x717900ed, 0x44380016, 0x00000000}},  // [7e70] kefa, обар_, atr_,
  { {0x44442b54, 0x290e008e, 0x442a006c, 0x00000000}},  //   _fp_, _jefa_, bub_,
  { {0x4444001d, 0x69c80019, 0x6d4a05d5, 0x00000000}},  //   _gp_, ilde, defa,
  { {0x2d8c022b, 0xe0d00025, 0x69da01a2, 0x00000000}},  //   _alde_, ازك_, hmte,
  { {0x0596007a, 0x63ad02e1, 0xddc9001a, 0x00000000}},  //   _رایگ, mnan, _creş,
  { {0x44440061, 0x6d4a010f, 0x7bc22b55, 0x00000000}},  //   _yp_, gefa, _akou,
  { {0xfd100076, 0xbc19007e, 0xe1ff0048, 0x00000000}},  //   اجه_, цілі_, _bróg_,
  { {0x69c800b5, 0x3f8601ca, 0x2d8c014a, 0x00000000}},  //   elde, ckou_, _elde_,
  { {0x63ad010f, 0x6d4a02cc, 0xddc9001a, 0x00000000}},  //   inan, befa, _greş,
  { {0xdb00009f, 0x64450190, 0x442a006b, 0x00000000}},  //   rnmá, _ophi, yub_,
  { {0x8af90265, 0x6d410039, 0x63ad01e2, 0x00000000}},  //   _днес_, _ibla, knan,
  { {0x44440390, 0x69c8022b, 0x63ad00bb, 0x00000000}},  //   _rp_, alde, jnan,
  { {0x444402d5, 0x2bb80025, 0x61ef21f6, 0x00000000}},  //   _sp_, _عامة_, _nucl,
  { {0x7bc9028c, 0x442a006c, 0x290e009f, 0x00000000}},  //   lleu, tub_, _gefa_,
  { {0x290504bd, 0x63ad009f, 0x61fd001e, 0x00000000}},  //   mbla_, fnan, _atsl,
  { {0x442a006b, 0x44440011, 0x645c00b5, 0x00000000}},  //   rub_, _vp_, rvri,
  { {0x4438018e, 0x44440036, 0x442a006c, 0x00000000}},  // [7e80] str_, _wp_, sub_,
  { {0x44442b56, 0x61ef05e6, 0x442a010e, 0x00000000}},  //   _tp_, _ducl, pub_,
  { {0x44440038, 0x3f8d00f4, 0xa6db009f, 0x00000000}},  //   _up_, _bleu_, veði,
  { {0x6d410333, 0xddc9001a, 0x61fd0045, 0x00000000}},  //   _abla, _preş, _ftsl,
  { {0x6d4a006b, 0x63a4003c, 0x7bc90016, 0x00000000}},  //   tefa, miin, dleu,
  { {0xf98702fd, 0x63a425a6, 0x7bc20007, 0x00000000}},  //   _شب_, liin, _skou,
  { {0x7bc90016, 0x6d58101e, 0x6d4a00c4, 0x00000000}},  //   fleu, rdva, refa,
  { {0xaa540e75, 0x63a40052, 0x6d410190, 0x00000000}},  //   евиш, niin, _ebla,
  { {0x6d4a0197, 0xa5bb0010, 0x63a400e0, 0x00000000}},  //   pefa, rtóz, iiin,
  { {0x69c800ab, 0x6d4a0023, 0x98a5007f, 0x00000000}},  //   ulde, qefa, gelį_,
  { {0x69c80073, 0x69da054e, 0x63a400b0, 0x00000000}},  //   rlde, rmte, kiin,
  { {0x29c2000c, 0x63a400e7, 0x7bc90133, 0x00000000}},  //   gðar_, jiin, cleu,
  { {0xa3c90316, 0x29180051, 0x63ad1d15, 0x00000000}},  //   _लीग_, óras_, vnan,
  { {0x63ad0036, 0x7bc00d8f, 0x6d4100d9, 0x00000000}},  //   wnan, lomu, _xbla,
  { {0x63ad011c, 0x63a4001a, 0x08f70318, 0x00000000}},  //   tnan, fiin, _غروب_,
  { {0xb4af0061, 0x63a40058, 0x394c00f8, 0x00000000}},  //   _कशी_, giin, leds_,
  { {0x61e700bb, 0xdce800b9, 0xb60400b9, 0x00000000}},  // [7e90] _pijl, _podě, tvář,
  { {0xef190046, 0x6493010a, 0x660d027f, 0x00000000}},  //   _może_, ežiū, _iwak,
  { {0x31c40057, 0xfe70007a, 0x27e904cb, 0x00000000}},  //   тств, یده_, _kian_,
  { {0x660d000b, 0x394c0190, 0x63a42b57, 0x00000000}},  //   _kwak, heds_, ciin,
  { {0x27e9002a, 0xdb000051, 0x61fd093b, 0x00000000}},  //   _mian_, cimé, _utsl,
  { {0x660d0020, 0xc105067a, 0x6e2b2b58, 0x00000000}},  //   _mwak, _سوري, rugb,
  { {0x55780049, 0x660d047b, 0x2d8701c5, 0x00000000}},  //   ועגן_, _lwak, rkne_,
  { {0x2d872b59, 0xef190036, 0x00000000, 0x00000000}},  //   skne_, _boże_,   ,
  { {0xa5bb029d, 0x7bc92b5a, 0x7bdb00b0, 0x00000000}},  //   tról, rleu, rmuu,
  { {0x6d41037e, 0x2dd4012b, 0x7bc912e3, 0x00000000}},  //   _ubla, _ажур, sleu,
  { {0x7aeb001c, 0xf8b1025a, 0x186900ed, 0x00000000}},  //   _tggt, دکش_, чани_,
  { {0x1cb80188, 0x660d0009, 0x2918000c, 0x00000000}},  //   _غالب_, _bwak, órar_,
  { {0x29c2009f, 0x394c0ace, 0x27e92b5b, 0x00000000}},  //   rðar_, beds_, _dian_,
  { {0x6b8900ea, 0xdb0000f8, 0x00000000, 0x00000000}},  //   lkeg, anmä,   ,
  { {0xf8c60201, 0x69c101ca, 0x63a41c87, 0x00000000}},  //   _रुपय, mole, tiin,
  { {0x27e9001d, 0x6b89068f, 0xdb001059, 0x00000000}},  //   _gian_, nkeg, timé,
  { {0xd24f026c, 0x63a4003c, 0x660d000a, 0x00000000}},  // [7ea0] ینہ_, riin, _gwak,
  { {0x63bb01ae, 0x69c10016, 0x63a403b6, 0x00000000}},  //   čuna, nole, siin,
  { {0x660d00bb, 0x6b892370, 0xb5fb004a, 0x00000000}},  //   _zwak, kkeg, rváe,
  { {0x69c10270, 0xd00f0076, 0x27e921b3, 0x00000000}},  //   hole, صله_, _xian_,
  { {0x69c10046, 0x6493010a, 0x7bc02b5c, 0x00000000}},  //   kole, ržiū, vomu,
  { {0x69c105aa, 0x00000000, 0x00000000, 0x00000000}},  //   jole,   ,   ,
  { {0x7bc00205, 0x69c10213, 0x657e0203, 0x00000000}},  //   tomu, dole, _moph,
  { {0x69c1005b, 0x00000000, 0x00000000, 0x00000000}},  //   eole,   ,   ,
  { {0x7fd7007b, 0x7bc00035, 0x79a60088, 0x00000000}},  //   _טולס_, romu, ерне,
  { {0x7c9600c0, 0x7bc00107, 0x27e9254e, 0x00000000}},  //   _прец, somu, _sian_,
  { {0x394c2b1e, 0x7bc01077, 0x27e900b0, 0x00000000}},  //   reds_, pomu, _pian_,
  { {0x6d5a0622, 0x60da0010, 0x00000000, 0x00000000}},  //   _hata, _útmu,   ,
  { {0x8f9b012f, 0x69c12b5d, 0x27e90052, 0x00000000}},  //   ליטי, bole, _vian_,
  { {0x69c1106f, 0x6d5a0093, 0x26c90020, 0x00000000}},  //   cole, _jata, _vyao_,
  { {0x6d5a1bc6, 0x80a00061, 0xf367005e, 0x00000000}},  //   _mata, _गेले, нтан,
  { {0x6d5a2b5e, 0x660d0600, 0x21f60146, 0x00000000}},  //   _lata, _twak, _bæh_,
  { {0xe1f30318, 0x660d0020, 0x776d0032, 0x00000000}},  // [7eb0] اسر_, _uwak, _inax,
  { {0x6d5a006a, 0x9f580048, 0x00000000, 0x00000000}},  //   _nata, _dtrí_,   ,
  { {0x2bac00b9, 0x00000000, 0x00000000, 0x00000000}},  //   pěch_,   ,   ,
  { {0x6d5a001c, 0x69c100e7, 0x441a0104, 0x00000000}},  //   _aata, zole, _קורס,
  { {0x6d5a1ccc, 0x69c10020, 0xed5900d7, 0x00000000}},  //   _bata, yole, дол_,
  { {0x6d5a01cb, 0xdca502b0, 0x00000000, 0x00000000}},  //   _cata, кали,   ,
  { {0x6d5a2b5f, 0x69c1004f, 0xe73f006c, 0x00000000}},  //   _data, vole, lnõu_,
  { {0x6d5a0048, 0x69d80103, 0x69c100b4, 0x00000000}},  //   _eata, _ahve, wole,
  { {0x69c1000b, 0x6d5a08f8, 0xe9d90264, 0x00000000}},  //   tole, _fata, мки_,
  { {0x6d5a001e, 0x6b890059, 0xd945012b, 0x00000000}},  //   _gata, skeg, њени,
  { {0x69c1294b, 0x2b4d01c5, 0x00000000, 0x00000000}},  //   role, peec_,   ,
  { {0x657e2b60, 0xf0ee013d, 0x69c10114, 0x00000000}},  //   _soph, _जल्द_, sole,
  { {0x6d5a0622, 0x69c100b9, 0x98b1005d, 0x00000000}},  //   _yata, pole, ızı_,
  { {0x9f4a0d62, 0x6d5a004a, 0x684500e2, 0x00000000}},  //   _rubí_, _xata, _анка,
  { {0xf99200b6, 0x9835007e, 0x9f4a004a, 0x00000000}},  //   _דרג_, _рэлі, _subí_,
  { {0x260f0061, 0x69d80065, 0x7afb0145, 0x00000000}},  //   तीही_, _zhve, ncut,
  { {0xcb12007b, 0xf5060265, 0x657e0146, 0x00000000}},  // [7ec0] ילן_, _изпо, _toph,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x34b7009b, 0x637800f6, 0x7f5b004a, 0x00000000}},  //   _יפים_, _nínx, _cauq,
  { {0x6d5a2b61, 0xc33300a0, 0x8e3703ec, 0x00000000}},  //   _pata, _דור_, نسور_,
  { {0x6d5a006b, 0xa2af0061, 0x91030326, 0x00000000}},  //   _qata, ंपर्, _впре,
  { {0x6d5a014a, 0x80e00044, 0xdce10006, 0x00000000}},  //   _vata, _প্র্, _molė,
  { {0x6d5a2379, 0x7c830264, 0x26cc006b, 0x00000000}},  //   _wata, руше, ədov_,
  { {0x6d5a0b9a, 0x4e0b013d, 0x21380145, 0x00000000}},  //   _tata, सीआई_, _kcrh_,
  { {0xce3701f8, 0x49742b62, 0x0e9b009b, 0x00000000}},  //   _באמת_, улос, _חשמל,
  { {0x7e62179a, 0x7afb0133, 0x00000000, 0x00000000}},  //   lvop, bcut,   ,
  { {0x7f422b63, 0x7d1800ca, 0x7afb0943, 0x00000000}},  //   nfoq, lavs, ccut,
  { {0x07a4008b, 0x95cb01f9, 0xdcfa000a, 0x00000000}},  //   раўн, дува_, _lotč,
  { {0x7d180142, 0x00000000, 0x00000000, 0x00000000}},  //   navs,   ,   ,
  { {0x6fc20061, 0x49920014, 0x00000000, 0x00000000}},  //   षकां, _میکر,   ,
  { {0x63bb0746, 0x7d180637, 0x779400a1, 0x00000000}},  //   čuno, havs, _نیپا,
  { {0x25f40061, 0x61d91001, 0x7d1804eb, 0x00000000}},  // [7ed0] ंदणी_, емая_, kavs,
  { {0xa2a7001c, 0x31590d75, 0x395e00eb, 0x00000000}},  //   _घेण्, علاج_, ndts_,
  { {0x7d182b64, 0x661d03b4, 0x213800fa, 0x00000000}},  //   davs, lssk, _dcrh_,
  { {0x4431005d, 0x9f4a00d4, 0x7dcd2b65, 0x00000000}},  //   muz_, _cubà_, músi,
  { {0x661d0239, 0x7afb014a, 0x8fa40014, 0x00000000}},  //   nssk, vcut, جمنه,
  { {0xaac603d7, 0x395c0927, 0xbbcb007d, 0x00000000}},  //   _लड़क, _navs_, ात्क,
  { {0x4431047f, 0x7afb0066, 0x3cfe00fa, 0x00000000}},  //   nuz_, tcut, _dftv_,
  { {0x3869050f, 0x2003012d, 0x00000000, 0x00000000}},  //   _čar_, _itji_,   ,
  { {0x991502f0, 0x7afb01a3, 0xe8d90011, 0x00000000}},  //   льні, rcut, _đố_,
  { {0x7afb000d, 0x661d2229, 0x44311b01, 0x00000000}},  //   scut, dssk, kuz_,
  { {0xe73a0887, 0x5fb703d7, 0x44310066, 0x00000000}},  //   нен_, _अदाल, juz_,
  { {0x44312b66, 0x6f190036, 0x2a6607f0, 0x00000000}},  //   duz_, nawc, _frob_,
  { {0xd945017f, 0x395c035e, 0x2a660091, 0x00000000}},  //   _бели, _favs_, _grob_,
  { {0x442a016c, 0x44312b67, 0x395c0a43, 0x00000000}},  //   trb_, fuz_, _gavs_,
  { {0x4431002d, 0x280200b9, 0x442a0026, 0x00000000}},  //   guz_, ěrné_, urb_,
  { {0xf3e601ff, 0x2b5f2b68, 0x00000000, 0x00000000}},  //   ужбо, nduc_,   ,
  { {0xe2970265, 0x6f190046, 0xb5fb0047, 0x00000000}},  // [7ee0] гат_, dawc, lván,
  { {0x44310e57, 0xdcfa0107, 0x66040020, 0x00000000}},  //   buz_, _potč, _itik,
  { {0x80a6069f, 0x00000000, 0x00000000, 0x00000000}},  //   دمان,   ,   ,
  { {0xdb000048, 0x7c3c006c, 0x3a3f014a, 0x00000000}},  //   timí, _ärri, ktup_,
  { {0xde580245, 0x7d1805d2, 0xdd990173, 0x00000000}},  //   талі_, tavs, _pwňp_,
  { {0x66040020, 0x00000000, 0x00000000, 0x00000000}},  //   _mtik,   ,   ,
  { {0x7d180aaa, 0x4c9404dd, 0x67240166, 0x00000000}},  //   ravs, рийс, _odij,
  { {0xa2db0201, 0xb5fb0010, 0x22400145, 0x00000000}},  //   पेक्, dván, otik_,
  { {0x22400149, 0x61ee04be, 0x66042b69, 0x00000000}},  //   ntik_, _kibl, _ntik,
  { {0x6e930054, 0x2fc62b6a, 0x224025b7, 0x00000000}},  //   _الكا, loog_, itik_,
  { {0xeaaf00a6, 0x660401a3, 0x672411af, 0x00000000}},  //   قعی_, _atik, _bdij,
  { {0x661d02e7, 0x4431005a, 0x61ee2b6b, 0x00000000}},  //   tssk, vuz_, _libl,
  { {0x395c001e, 0xc6a70088, 0x61ee0051, 0x00000000}},  //   _tavs_, урни, _oibl,
  { {0x6b822b6c, 0x2fc602ae, 0x4431022b, 0x00000000}},  //   _hoog, hoog_, tuz_,
  { {0x660415f0, 0xdb0900c4, 0x68fb009b, 0x00000000}},  //   _etik, lneá, _אלוה,
  { {0x44310612, 0x69d80316, 0x6b82006c, 0x00000000}},  //   ruz_, _नीती, _joog,
  { {0x248d001e, 0x6b8200d9, 0x4431005d, 0x00000000}},  // [7ef0] ņem_, _moog, suz_,
  { {0x61ee00f4, 0x6b8201c2, 0x6f190036, 0x00000000}},  //   _cibl, _loog, wawc,
  { {0x61ee04be, 0x22402092, 0x720500a1, 0x00000000}},  //   _dibl, atik_, _چہرہ_,
  { {0x6d481f0f, 0x2837007b, 0x547a0097, 0x00000000}},  //   _abda, רנאך_, _סטרו,
  { {0x6f0b0009, 0x61ee00f6, 0xb5fb0161, 0x00000000}},  //   rbgc, _fibl, zván,
  { {0x3209006a, 0x61ee00ca, 0x6d4301a2, 0x00000000}},  //   mpay_, _gibl, ufna,
  { {0x6c67026c, 0xfaf10025, 0x2fc6040f, 0x00000000}},  //   البہ_, يثة_, boog_,
  { {0x5f94029b, 0x442105fe, 0xba25003b, 0x00000000}},  //   _лист, _mvh_, адик,
  { {0x7f840025, 0x320901aa, 0x49990088, 0x00000000}},  //   _القن, npay_, втня_,
  { {0xb5fb0047, 0x44212b6d, 0x00000000, 0x00000000}},  //   tván, _ovh_,   ,
  { {0x3a3f040d, 0xe8d9001d, 0x2240002d, 0x00000000}},  //   stup_, _đồ_, ztik_,
  { {0x66e600d7, 0x7e69010a, 0xfc3006b4, 0x00000000}},  //   иона, _krep, _رحم_,
  { {0xcaf4026c, 0x6fd8008e, 0x25aa03ec, 0x00000000}},  //   _اسمب, níca, ندسي_,
  { {0xceb2019b, 0x44212b6e, 0x6b8200bb, 0x00000000}},  //   קים_, _bvh_, _zoog,
  { {0x443e00f4, 0x764d2a87, 0x61ee04eb, 0x00000000}},  //   ît_, _epay, _ribl,
  { {0x25aa018e, 0x66042b6f, 0x8c270044, 0x00000000}},  //   sibl_, _ttik, _মহান_,
  { {0x57250025, 0x61ee0263, 0xdb0008aa, 0x00000000}},  // [7f00] _طريق, _pibl, nimá,
  { {0xa06a04b6, 0x2240002d, 0x645a07a8, 0x00000000}},  //   каза_, rtik_, ætis,
  { {0xef1a01f9, 0xc2e70044, 0x798301aa, 0x00000000}},  //   вме_, গুলি_, _monw,
  { {0x7e2a02f0, 0x6fd8008e, 0x9e6608d6, 0x00000000}},  //   віка_, fíca, ивед,
  { {0x5de60001, 0x7e690325, 0x2fc6109a, 0x00000000}},  //   ажда, _crep, roog_,
  { {0x7e69000d, 0xe0da01e0, 0x79830300, 0x00000000}},  //   _drep, _авг_, _nonw,
  { {0x20b90057, 0x7e692b70, 0x2fc6040f, 0x00000000}},  //   _быть_, _erep, poog_,
  { {0x4f9606e3, 0x63b60052, 0x7ac60140, 0x00000000}},  //   _тргу, nnyn, испе,
  { {0xcb6703f3, 0x7e690039, 0xb5fb0010, 0x00000000}},  //   рање_, _grep, gvál,
  { {0x79830016, 0x6b8201c3, 0xd7fa030d, 0x00000000}},  //   _conw, _woog, кум_,
  { {0x3f840b22, 0x798312aa, 0xdddb0089, 0x00000000}},  //   _komu_, _donw, _bruņ,
  { {0x320900e0, 0x00000000, 0x00000000, 0x00000000}},  //   ypay_,   ,   ,
  { {0x3f84016c, 0x79830675, 0x00000000, 0x00000000}},  //   _momu_, _fonw,   ,
  { {0xd5b8007c, 0x68010089, 0x3f840089, 0x00000000}},  //   асс_, _sēde, _lomu_,
  { {0xd5b8005e, 0x6fb80061, 0xa4d505b8, 0x00000000}},  //   рся_, ेकां, сові,
  { {0xe3b300a1, 0xa2f5007e, 0xdce10089, 0x00000000}},  //   زرز_, спач, _solī,
  { {0x764d10ed, 0x67540014, 0xb7dc00b3, 0x00000000}},  // [7f10] _upay, _ذخير, _בקהי,
  { {0x69c80016, 0x69c70e54, 0x7e690065, 0x00000000}},  //   node, čjeg, _rrep,
  { {0xd3710025, 0x3f840020, 0xa1581021, 0x00000000}},  //   _فهد_, _bomu_, раху_,
  { {0x7e690e81, 0xdb0900b5, 0xe4560049, 0x00000000}},  //   _prep, rieë, _פירט_,
  { {0xd37a007b, 0x6db20046, 0x63ad0046, 0x00000000}},  //   _ערשט, kład, mian,
  { {0x63ad2b71, 0xfd47008b, 0xdb090116, 0x00000000}},  //   lian, рэдн, pieë,
  { {0x40950054, 0x7dcd153d, 0xe0e50055, 0x00000000}},  //   _الأر, dúst, _প্রভ,
  { {0x63ad195b, 0x8f34008b, 0xa3d7013d, 0x00000000}},  //   nian, _месц, िति_,
  { {0x69c80faa, 0x2fdf00e0, 0x9df80131, 0x00000000}},  //   fode, _ihug_, _внут_,
  { {0x3897005f, 0x63ad0681, 0x69c80059, 0x00000000}},  //   lərə_, hian, gode,
  { {0xa3d702f4, 0x63ad242a, 0x6ca7012b, 0x00000000}},  //   िता_, kian, _траж,
  { {0x63ad0bbf, 0x2d8500ab, 0x3a2d013e, 0x00000000}},  //   jian, _hole_, prep_,
  { {0x69c800b5, 0x2d852b72, 0x63ad2b73, 0x00000000}},  //   bode, _kole_, dian,
  { {0xb8dd08b7, 0x799a2b74, 0x3897013f, 0x00000000}},  //   _আর_, chtw, hərə_,
  { {0x63ad07cd, 0x232a0a30, 0xdcfa001a, 0x00000000}},  //   fian, лови_, _hotă,
  { {0x96960099, 0x63ad0207, 0x7bc9009d, 0x00000000}},  //   _грош, gian, noeu,
  { {0x63b6007f, 0x3f84190c, 0x00000000, 0x00000000}},  // [7f20] rnyn, _romu_,   ,
  { {0x2d8501ee, 0x42230088, 0xdb1b00c4, 0x00000000}},  //   _nole_, ядув, bouç,
  { {0x3897006b, 0x27e00145, 0x00000000, 0x00000000}},  //   fərə_, _khin_,   ,
  { {0x63ad0181, 0x645e0209, 0x69c80305, 0x00000000}},  //   cian, _ispi, zode,
  { {0x59c7024c, 0x2d851b4c, 0xdfcf0380, 0x00000000}},  //   रकार, _bole_, ريه_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3f84004f, 0x69c801ca, 0x2d851238, 0x00000000}},  //   _tomu_, vode, _dole_,
  { {0x09d00164, 0x6fb601f7, 0x6b9b0058, 0x00000000}},  //   हत्य, _امرا, ghug,
  { {0xb998019d, 0xc333009b, 0x2d850023, 0x00000000}},  //   ивих_, פוז_, _fole_,
  { {0x645e0207, 0x63ad2b75, 0x63bb0bf8, 0x00000000}},  //   _ospi, zian, čuni,
  { {0x69c80142, 0x6fd81b0f, 0x23c801f5, 0x00000000}},  //   rode, níco, लवाद,
  { {0x27e01097, 0x69c82b76, 0x63ad16df, 0x00000000}},  //   _chin_, sode, xian,
  { {0x98b801df, 0x6e2206d3, 0x7d1a05e0, 0x00000000}},  //   ırı_, nsob, _kets,
  { {0x63ad0036, 0xe89418cb, 0x3897006b, 0x00000000}},  //   wian, _маль, zərə_,
  { {0x291e1c0b, 0x63ad002a, 0x7d1a08b2, 0x00000000}},  //   mata_, tian, _mets,
  { {0x52152b77, 0x7d1a0112, 0xdb0900c4, 0x00000000}},  //   ждат, _lets, rneç,
  { {0x6f021238, 0x00000000, 0x00000000, 0x00000000}},  // [7f30] dcoc,   ,   ,
  { {0x7d1a03b4, 0x63ad000b, 0xdb0001b1, 0x00000000}},  //   _nets, sian, limä,
  { {0x63ad0747, 0x66160036, 0x2d8500ab, 0x00000000}},  //   pian, _zwyk, _role_,
  { {0x291e0ab5, 0xdcee00b9, 0x2d85051b, 0x00000000}},  //   hata_, žděn, _sole_,
  { {0xdce80006, 0x2d850114, 0x28cf006e, 0x00000000}},  //   _kodė, _pole_, _सुनि,
  { {0x291e08f0, 0xac09003b, 0x2ea90061, 0x00000000}},  //   jata_, анка_, _कधीत,
  { {0x291e11f2, 0xef190046, 0xeae50055, 0x00000000}},  //   data_, _też_, _নভেম,
  { {0x6f020026, 0x7d1a2a57, 0x00000000, 0x00000000}},  //   ccoc, _eets,   ,
  { {0x291e001a, 0x2d850059, 0x27e0009d, 0x00000000}},  //   fata_, _tole_, _rhin_,
  { {0x291e0207, 0x6b9b000b, 0x7d1a006b, 0x00000000}},  //   gata_, shug, _gets,
  { {0xb90102fb, 0x5f7400a1, 0x9f4b0048, 0x00000000}},  //   _दर_, _ظاہر, _ómós_,
  { {0xe73a0679, 0x7d1a0288, 0x00000000, 0x00000000}},  //   шем_, _zets,   ,
  { {0x291e1c49, 0x06cd0044, 0x6f1b00fa, 0x00000000}},  //   bata_, রেসি, _meuc,
  { {0x291e139c, 0x6f1b010f, 0x2901006c, 0x00000000}},  //   cata_, _leuc, _üha_,
  { {0x6fc90201, 0xe9b800a1, 0xe8d90011, 0x00000000}},  //   िकां, _دنوں_, _đỗ_,
  { {0x130a007e, 0x27e00032, 0x6f02004a, 0x00000000}},  //   рнай_, _uhin_, xcoc,
  { {0x645e0036, 0x4226005e, 0xd5e40082, 0x00000000}},  // [7f40] _wspi, юдав, _trì,
  { {0xb60609f4, 0x776400d4, 0x6fd800dc, 0x00000000}},  //   rašč, _haix, tíco,
  { {0x645e0209, 0x7d1a269f, 0x7764002d, 0x00000000}},  //   _uspi, _rets, _kaix,
  { {0x44382b78, 0x291e1792, 0x444401da, 0x00000000}},  //   mur_, zata_, _iq_,
  { {0x91e600d7, 0x291e005f, 0x443820e9, 0x00000000}},  //   _моме, yata_, lur_,
  { {0x44442b79, 0x44380009, 0x33200129, 0x00000000}},  //   _kq_, our_, laix_,
  { {0x44382b7a, 0x6e220197, 0x6f1b010f, 0x00000000}},  //   nur_, ssob, _feuc,
  { {0x44440207, 0x291e0058, 0x7d1a0112, 0x00000000}},  //   _mq_, wata_, _wets,
  { {0x44380b97, 0x4444002b, 0x7d1a0047, 0x00000000}},  //   hur_, _lq_, _tets,
  { {0x44382b7b, 0x444400c4, 0x2b9108f5, 0x00000000}},  //   kur_, _oq_, _lách_,
  { {0x291e2b7c, 0x77642b7d, 0x6d581701, 0x00000000}},  //   rata_, _baix, meva,
  { {0x77642b7e, 0x291e0390, 0x645c0016, 0x00000000}},  //   _caix, sata_, dwri,
  { {0x291e000b, 0x4444008d, 0x443800f4, 0x00000000}},  //   pata_, _aq_, eur_,
  { {0x44380359, 0x6d580004, 0x95cb0242, 0x00000000}},  //   fur_, neva, рума_,
  { {0x4438009f, 0x77642697, 0x2b910011, 0x00000000}},  //   gur_, _faix, _bách_,
  { {0x442d037b, 0x2b91001d, 0x7764002d, 0x00000000}},  //   če_, _cách_, _gaix,
  { {0xdce8010a, 0x291c0521, 0x4423012d, 0x00000000}},  // [7f50] _todė, _keva_, ssj_,
  { {0x44380169, 0x6d581032, 0x44442b7f, 0x00000000}},  //   bur_, jeva, _fq_,
  { {0x6d58129a, 0x291c04bd, 0x4444013f, 0x00000000}},  //   deva, _meva_, _gq_,
  { {0x291c2b80, 0x9ee90054, 0x65650145, 0x00000000}},  //   _leva_, مفضل_, _hahh,
  { {0x1d09005e, 0x64470007, 0x260f0061, 0x00000000}},  //   бели_, ltji, तीची_,
  { {0xed590081, 0x6d58017d, 0x291c007f, 0x00000000}},  //   сок_, geva, _neva_,
  { {0x64470343, 0x4444008e, 0x6f1b00f6, 0x00000000}},  //   ntji, _xq_, _teuc,
  { {0x2b91001d, 0x64470007, 0x61f52b81, 0x00000000}},  //   _xách_, itji, _hizl,
  { {0x44381113, 0x6d5800eb, 0x291c0026, 0x00000000}},  //   zur_, beva, _beva_,
  { {0x61fd04d4, 0x39450805, 0x291c000d, 0x00000000}},  //   _musl, чног, _ceva_,
  { {0x6d41005f, 0x291c2234, 0x77640181, 0x00000000}},  //   _icla, _deva_, _paix,
  { {0x4438002b, 0xf0920049, 0x6db20036, 0x00000000}},  //   vur_, גנט_, płac,
  { {0xa5bb2b82, 0x77640129, 0x9676007e, 0x00000000}},  //   rsón, _vaix, чыні,
  { {0x44382b83, 0x2b91001d, 0x4444228d, 0x00000000}},  //   tur_, _sách_, _pq_,
  { {0x61fd010f, 0x3e5d01aa, 0x444400df, 0x00000000}},  //   _ausl, _lňt_, _qq_,
  { {0x44382b84, 0x61f5001e, 0x9f460007, 0x00000000}},  //   rur_, _aizl, rmoë_,
  { {0x4438008d, 0x44440263, 0x64470007, 0x00000000}},  // [7f60] sur_, _wq_, atji,
  { {0x44440011, 0x2b4f0009, 0x20180022, 0x00000000}},  //   _tq_, _lbgc_, _pwri_,
  { {0x44380065, 0x6d582b85, 0x2b910011, 0x00000000}},  //   qur_, veva, _tách_,
  { {0x6d410919, 0x212100e0, 0x00000000, 0x00000000}},  //   _acla, aahh_,   ,
  { {0xc33301f8, 0x61fd016c, 0x6d58006c, 0x00000000}},  //   _אור_, _gusl, teva,
  { {0x61f5047f, 0x6da3017f, 0x6d4a00f4, 0x00000000}},  //   _gizl, нича, uffa,
  { {0x6d580059, 0x6d4a26fb, 0xe5370049, 0x00000000}},  //   reva, rffa, לטסט_,
  { {0x291c04bd, 0x6d5803b6, 0x6d4100f4, 0x00000000}},  //   _seva_, seva, _ecla,
  { {0x6d58003b, 0x8d1a007a, 0x291c05fa, 0x00000000}},  //   peva, _هزار_, _peva_,
  { {0xd90d0014, 0xe7d60044, 0x64470007, 0x00000000}},  //   لیه_, _সংগঠ, ytji,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x65650310, 0xd8380b4a, 0x48a70930, 0x00000000}},  //   _sahh, ruč_, ятым_,
  { {0x291c04bd, 0xe1ff0082, 0x00000000, 0x00000000}},  //   _teva_, _trói_,   ,
  { {0x25f4013d, 0x246700b9, 0x00000000, 0x00000000}},  //   ंदगी_, jímá_,   ,
  { {0x58d3012b, 0x64470007, 0x38c80014, 0x00000000}},  //   _пошт, utji, _باشی_,
  { {0xb4bd001c, 0x61fd010a, 0x64470343, 0x00000000}},  //   _अशी_, _pusl, rtji,
  { {0xa5bb004a, 0x656523d6, 0x6fd8013e, 0x00000000}},  // [7f70] lsóm, _tahh, mích,
  { {0x660d000b, 0xd1310025, 0xe7e1006e, 0x00000000}},  //   _itak, ئما_, _गीता_,
  { {0xf993007b, 0xe2f901fb, 0x660d0020, 0x00000000}},  //   ערע_, _мені_, _htak,
  { {0x63bb07a0, 0x29050211, 0x6d410035, 0x00000000}},  //   čuns, zcla_, _scla,
  { {0x8d7401ef, 0xdef8007e, 0x7c280039, 0x00000000}},  //   کانا, чых_, _avdr,
  { {0x660d09c7, 0xddc90036, 0xdce80089, 0x00000000}},  //   _mtak, _speł, _godī,
  { {0x1b210055, 0x22492b86, 0xdd9100a1, 0x00000000}},  //   _যাবে_, ltak_, ٹوں_,
  { {0x2369008d, 0xdfd10054, 0x2b9800f4, 0x00000000}},  //   ndaj_, _شيء_, _déco_,
  { {0x22492b87, 0xd959008b, 0x660d2b88, 0x00000000}},  //   ntak_, ошні_, _ntak,
  { {0x6d4101ee, 0x2fcf2b89, 0x672d0173, 0x00000000}},  //   _ucla, logg_, _adaj,
  { {0x660d000b, 0xa3bf0201, 0xdce100ca, 0x00000000}},  //   _atak, ेवा_, _kalč,
  { {0x29052b8a, 0x2249265f, 0x00000000, 0x00000000}},  //   scla_, ktak_,   ,
  { {0xdce10059, 0xd945012b, 0xf1bf01f5, 0x00000000}},  //   _malč, _жели, ्वान,
  { {0xe1ff0046, 0x2249121b, 0x6b8b00ea, 0x00000000}},  //   _osób_, dtak_, _hogg,
  { {0x660d002d, 0x6b8b01d6, 0x22490032, 0x00000000}},  //   _etak, _kogg, etak_,
  { {0xb4ae001c, 0xd8d60049, 0x660d002b, 0x00000000}},  //   _कधी_, _קוקט_, _ftak,
  { {0x6b8b000c, 0x680800b9, 0x2fcf0fd1, 0x00000000}},  // [7f80] _mogg, _věde, dogg_,
  { {0x6b8b143e, 0x6f090e98, 0x672d0036, 0x00000000}},  //   _logg, _afec, _zdaj,
  { {0x6fd82b8b, 0x757b009b, 0xdce1007f, 0x00000000}},  //   líci, _וטיפ, _balč,
  { {0x6b8b0039, 0x00000000, 0x00000000, 0x00000000}},  //   _nogg,   ,   ,
  { {0x5e5a00a1, 0x6fd82b8c, 0x00000000, 0x00000000}},  //   تجاج_, níci,   ,
  { {0x6f09106f, 0x6db20036, 0x20560ae0, 0x00000000}},  //   _efec, ałan, _отбр,
  { {0x6b8b0030, 0x798a01c3, 0x00000000, 0x00000000}},  //   _bogg, _rofw,   ,
  { {0x798a0093, 0xc0e30641, 0x200500f6, 0x00000000}},  //   _sofw, _роск, _élia_,
  { {0x6b8b0472, 0x00000000, 0x00000000, 0x00000000}},  //   _dogg,   ,   ,
  { {0xc27b00a3, 0xb33b014a, 0x6fd82b8d, 0x00000000}},  //   קריי, _ilçe, díci,
  { {0x3137019b, 0xe8df00ad, 0x660d016e, 0x00000000}},  //   ונים_, _thời_, _stak,
  { {0x6fd8253d, 0x6b8b0007, 0x3f8601aa, 0x00000000}},  //   fíci, _gogg, njou_,
  { {0x4ae202d2, 0x2d8c10f8, 0xd90e025a, 0x00000000}},  //   _परिव, _kode_, _پیج_,
  { {0xa5bb009f, 0x28cf007d, 0x2d8c0007, 0x00000000}},  //   msók, _सुवि, _jode_,
  { {0x2d8c032c, 0x1b210044, 0xa4d40088, 0x00000000}},  //   _mode_, _যাতে_, ворі,
  { {0x69da001f, 0x22490047, 0x672d0021, 0x00000000}},  //   llte, ttak_, _udaj,
  { {0x45d50057, 0x660d2b8e, 0xe8df001d, 0x00000000}},  // [7f90] _поис, _utak, _khởi_,
  { {0x22490119, 0x3ea60089, 0x200700c4, 0x00000000}},  //   rtak_, dzot_, ínio_,
  { {0x2249022b, 0xdce100ca, 0x69da0051, 0x00000000}},  //   stak_, _palč, ilte,
  { {0x2d9e000d, 0x69da010f, 0x22492b8f, 0x00000000}},  //   _alte_, hlte, ptak_,
  { {0x2d8c27dc, 0x6b8b037f, 0x1d091adf, 0x00000000}},  //   _bode_, _rogg, пели_,
  { {0x7bc20c60, 0x6db20046, 0x6b8b0198, 0x00000000}},  //   _ajou, słan, _sogg,
  { {0x6b8b0207, 0x6fd82b90, 0x2d8c0112, 0x00000000}},  //   _pogg, zíci, _dode_,
  { {0x69da01a2, 0x00000000, 0x00000000, 0x00000000}},  //   elte,   ,   ,
  { {0x3e3504e8, 0x7bc22b91, 0x2d8c00c4, 0x00000000}},  //   _سفار, _djou, _fode_,
  { {0x2d8c01e3, 0x7bc20606, 0x00000000, 0x00000000}},  //   _gode_, _ejou,   ,
  { {0x6b8b0857, 0xf746030d, 0x00000000, 0x00000000}},  //   _togg, нено,   ,
  { {0x6fd80ca7, 0x2d870295, 0x69da00ea, 0x00000000}},  //   tíci, ljne_, alte,
  { {0xf6d50088, 0xddc900e5, 0x00000000, 0x00000000}},  //   віря, _greţ,   ,
  { {0x6fd80181, 0xd945017f, 0x00000000, 0x00000000}},  //   ríci, _чеки,   ,
  { {0x64a6008b, 0x680800b9, 0x00000000, 0x00000000}},  //   хава, _vědc,   ,
  { {0xb4e0001c, 0x86460088, 0xdce800b9, 0x00000000}},  //   _तरी_, _зниж, _andě,
  { {0x211a0025, 0xa1360025, 0x5a0c0049, 0x00000000}},  // [7fa0] كتاب_, فراش, ַלאַ,
  { {0xb5fb2b92, 0x00000000, 0x00000000, 0x00000000}},  //   rvát,   ,   ,
  { {0xe8df001d, 0xd00f03ec, 0x98a60521, 0x00000000}},  //   _khối_, ملل_, ćiće_,
  { {0x6db20036, 0x67262b93, 0x2d8c007f, 0x00000000}},  //   ałal, nakj, _sode_,
  { {0x2d8c0907, 0xdb000065, 0xa3bf01f5, 0x00000000}},  //   _pode_, shmë, ेवर_,
  { {0x63a400c4, 0x63b60016, 0x7bc200d9, 0x00000000}},  //   lhin, liyn, _sjou,
  { {0x71d7009b, 0x2d8c0465, 0x44380022, 0x00000000}},  //   _נולד_, _vode_, nrr_,
  { {0x63a40016, 0xddc9001a, 0x2d870023, 0x00000000}},  //   nhin, _preţ, ajne_,
  { {0x8fa3017a, 0x6726008a, 0x2d8c01a2, 0x00000000}},  //   _сате, dakj, _tode_,
  { {0x7a53006d, 0x69c30026, 0xddc90035, 0x00000000}},  //   اضيا, _cjne, _vreţ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3cfe0019, 0xe8df0011, 0x7c2a0635, 0x00000000}},  //   _hgtv_, _chối_, msfr,
  { {0xd6db06c4, 0x63a40020, 0x81d70044, 0x00000000}},  //   ято_, dhin, াগত_,
  { {0x779300a1, 0xa6db000c, 0xddc9016e, 0x00000000}},  //   ئیکا, ggða, _kreš,
  { {0x6fd80219, 0x395e225c, 0xa967025f, 0x00000000}},  //   lícu, mets_, _чија_,
  { {0x395e02d0, 0xa3ab03d7, 0xd8db0104, 0x00000000}},  //   lets_, कों_, _מקור,
  { {0x27e9021e, 0x2d870036, 0x44380051, 0x00000000}},  // [7fb0] _ihan_, yjne_, arr_,
  { {0x395e0089, 0xb6bc009b, 0x442a00fa, 0x00000000}},  //   nets_, _מצחי, bsb_,
  { {0x6fd80211, 0x31c400ed, 0x63a40051, 0x00000000}},  //   hícu, уств, bhin,
  { {0x2a662b94, 0x7c2a0039, 0x395e05ad, 0x00000000}},  //   _osob_, dsfr, hets_,
  { {0x395e05ad, 0x8e080088, 0xf2e40581, 0x00000000}},  //   kets_, енів_, _бюро,
  { {0x395e028c, 0x6fd810af, 0x200e0129, 0x00000000}},  //   jets_, dícu, ífic_,
  { {0x395e00eb, 0x7c2a03b4, 0x27e90058, 0x00000000}},  //   dets_, gsfr, _ohan_,
  { {0x27e90011, 0x69c700ca, 0x201115ed, 0x00000000}},  //   _nhan_, čjem, _itzi_,
  { {0x27200055, 0x395e00f4, 0x8afd00b9, 0x00000000}},  //   _ভালো_, fets_, ndři,
  { {0x6ca7007c, 0x395e0039, 0x63a40065, 0x00000000}},  //   _преж, gets_, zhin,
  { {0x07a60500, 0xe73a00d7, 0xe8df001d, 0x00000000}},  //   ванн, мен_, _phối_,
  { {0x63a40065, 0x21230066, 0x6fd8004a, 0x00000000}},  //   xhin, _lejh_, bícu,
  { {0x395e0030, 0x27e92b95, 0xb8d80061, 0x00000000}},  //   bets_, _dhan_, _घे_,
  { {0x6d43006a, 0xceb20104, 0x6b8911b7, 0x00000000}},  //   ngna, שיך_, ljeg,
  { {0x63a40038, 0x6d432b96, 0xe8df0082, 0x00000000}},  //   thin, igna, _thối_,
  { {0x44382b97, 0x6b890059, 0x27e90066, 0x00000000}},  //   rrr_, njeg, _ghan_,
  { {0x75270087, 0xb5fb0010, 0xb1460478, 0x00000000}},  // [7fc0] bajz, rvár, кнал,
  { {0x4096012b, 0x63a42068, 0xd5af0054, 0x00000000}},  //   крет, shin, _وفي_,
  { {0x69c1000c, 0x657e0051, 0xd59b009b, 0x00000000}},  //   inle, _inph, _חביל,
  { {0x660414d2, 0xd00f0076, 0x7e622b98, 0x00000000}},  //   _kuik, زله_, twop,
  { {0x67241ea7, 0xf77301ce, 0x20110032, 0x00000000}},  //   _meij, יקא_, _etzi_,
  { {0xddc90027, 0xdd8f0b59, 0x6d430039, 0x00000000}},  //   _preš, يون_, ggna,
  { {0x395e0239, 0x644e032e, 0x66040277, 0x00000000}},  //   vets_, ntbi, _luik,
  { {0x6fd80219, 0x6b892b99, 0xfbcf006d, 0x00000000}},  //   tícu, gjeg, يتي_,
  { {0x27e9018e, 0x60270047, 0x395e004e, 0x00000000}},  //   _rhan_, _témá, tets_,
  { {0xddc90afe, 0x27e90023, 0x49730b87, 0x00000000}},  //   _treš, _shan_, альс,
  { {0x7c38001c, 0x67240181, 0x27e9001d, 0x00000000}},  //   qrvr, _beij, _phan_,
  { {0x660400bb, 0x75e0014a, 0x657e0082, 0x00000000}},  //   _buik, sözl, _anph,
  { {0x395e02e1, 0x644e0082, 0x61fc004a, 0x00000000}},  //   pets_, etbi, _oirl,
  { {0x66040250, 0x61fc0093, 0xd83801aa, 0x00000000}},  //   _duik, _nirl, prč_,
  { {0x27e90038, 0xb33b2b9a, 0xd404022a, 0x00000000}},  //   _than_, _alça, ияти,
  { {0x67240fcf, 0x20032b9b, 0x00000000, 0x00000000}},  //   _geij, _ruji_,   ,
  { {0x61fc01f6, 0x68e6005f, 0xe5c7008b, 0x00000000}},  // [7fd0] _birl, əkda, _асно,
  { {0x200304be, 0x61fc00e5, 0x00000000, 0x00000000}},  //   _puji_, _cirl,   ,
  { {0x61fc2b9c, 0x351a009b, 0xd4790049, 0x00000000}},  //   _dirl, _אותנ, _װאָל,
  { {0x5ecc0055, 0x6fd40088, 0xff5301b7, 0x00000000}},  //   ়েছে, аціє, شخص_,
  { {0xdd950147, 0x69c1000c, 0x22840878, 0x00000000}},  //   лады, ynle, _кург,
  { {0xdce8047f, 0x61fc00ab, 0x61140194, 0x00000000}},  //   _aldı, _girl, _вдру,
  { {0x6d43002a, 0x2011022b, 0x6f040059, 0x00000000}},  //   rgna, _utzi_, žica,
  { {0xdfd5007c, 0x69d80cfd, 0x5f94007c, 0x00000000}},  //   _собы, _akve, _кист,
  { {0x672420bd, 0x6b9b2b9d, 0x00000000, 0x00000000}},  //   _reij, rkug,   ,
  { {0x6d43001c, 0x66042b9e, 0x67240052, 0x00000000}},  //   qgna, _ruik, _seij,
  { {0x6b8926a1, 0x69c101e5, 0x66042b9f, 0x00000000}},  //   pjeg, rnle, _suik,
  { {0x66042ba0, 0x290e0085, 0x00000000, 0x00000000}},  //   _puik, _effa_,   ,
  { {0x657e00f6, 0x00000000, 0x00000000, 0x00000000}},  //   _pnph,   ,   ,
  { {0x6603008b, 0x644e2ba1, 0x672400bb, 0x00000000}},  //   спра, ttbi, _weij,
  { {0x64a3243f, 0x657e0082, 0x67240052, 0x00000000}},  //   бара, _vnph, _teij,
  { {0x644e0002, 0x38780030, 0x61fc006b, 0x00000000}},  //   rtbi, ærre_, _sirl,
  { {0x644e01bf, 0x3a2d0169, 0x61fc0197, 0x00000000}},  // [7fe0] stbi, nsep_, _pirl,
  { {0x224000c7, 0xc56600ed, 0xdb0001aa, 0x00000000}},  //   ruik_, _скок, nimò,
  { {0x7e6901aa, 0x61fc0022, 0xd5a4025a, 0x00000000}},  //   _asep, _virl, _ملکی,
  { {0xdd2f00b9, 0x00000000, 0x00000000, 0x00000000}},  //   měři,   ,   ,
  { {0x61fc0016, 0x947600a6, 0x7e690010, 0x00000000}},  //   _tirl, _شدگا, _csep,
  { {0x61fc002a, 0x7d01005b, 0x00000000, 0x00000000}},  //   _uirl, _cgls,   ,
  { {0x7e690173, 0x2d9c018b, 0xa5bb01e5, 0x00000000}},  //   _esep, rkve_, msót,
  { {0x5a340517, 0x69d80142, 0x7c8300c0, 0x00000000}},  //   анит, _skve, суше,
  { {0x6f930025, 0xdee3005e, 0x00000000, 0x00000000}},  //   _القض, _готи,   ,
  { {0x99660175, 0x9f4400f6, 0x9f580095, 0x00000000}},  //   утил, _timó_, _burç_,
  { {0x61d70049, 0x81570049, 0x680800b9, 0x00000000}},  //   רויף_, נסטע_, _vědo,
  { {0xb8ec013d, 0xdb0000c4, 0x00000000, 0x00000000}},  //   _रख_, rimó,   ,
  { {0x12bf0044, 0x00000000, 0x00000000, 0x00000000}},  //   _আর্দ,   ,   ,
  { {0x290e0197, 0x00000000, 0x00000000, 0x00000000}},  //   _uffa_,   ,   ,
  { {0x6fd40061, 0x4d7b0049, 0xd37b01ee, 0x00000000}},  //   धकां, ערלע, нча_,
  { {0x28490049, 0xc2c50025, 0x987b0049, 0x00000000}},  //   _סעפּ, ليزي, _טרוק,
  { {0xd13b003b, 0x00000000, 0x00000000, 0x00000000}},  // [7ff0] ехе_,   ,   ,
  { {0xdb000051, 0xdcfa000a, 0x00000000, 0x00000000}},  //   dhmí, _antč,   ,
  { {0xe1e50061, 0x7e6901f3, 0x00000000, 0x00000000}},  //   _कठीण_, _ssep,   ,
  { {0x0eb900a5, 0xe8d700a0, 0x7f270688, 0x00000000}},  //   кулы_, נואר_, اءال,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xed5901bd, 0xa3bf01f5, 0xdcfa01aa, 0x00000000}},  //   ток_, ेवक_, _entč,
  { {0x96260089, 0x00000000, 0x00000000, 0x00000000}},  //   _ziņā,   ,   ,
  { {0x69c60010, 0x7e69109a, 0x00000000, 0x00000000}},  //   éken, _tsep,   ,
  { {0x3860016c, 0x00000000, 0x00000000, 0x00000000}},  //   _ćira_,   ,   ,
  { {0x49950069, 0xdb2300a1, 0x00000000, 0x00000000}},  //   ршит, جوکی,   ,
  { {0xdd7a007b, 0x00000000, 0x00000000, 0x00000000}},  //   _שטעל,   ,   ,
  { {0xc5e9034e, 0xdd2f00b9, 0x00000000, 0x00000000}},  //   _חד_, věři,   ,
  { {0xf3eb0044, 0x7bc4007f, 0x00000000, 0x00000000}},  //   কদার_, čiut,   ,
  { {0x6907007e, 0xdb020e6d, 0x7ae6014a, 0x00000000}},  //   _сядз, _aloè, ükte,
  { {0x232a0098, 0x07a6008b, 0xe8df0082, 0x00000000}},  //   кови_, _вайн, _phổi_,
  { {0xda080011, 0x00000000, 0x00000000, 0x00000000}},  //   _hỏa_,   ,   ,

  { {0xe29701b3, 0x6db20036, 0x00000000, 0x00000000}},  // [8000] аат_, cław,   ,
  { {0x23bf00b0, 0x00000000, 0x00000000, 0x00000000}},  //   täjä_,   ,   ,
  { {0xe8df0011, 0x80660887, 0x73e61079, 0x00000000}},  //   _thổi_, рвеж, _вонз,
  { {0xdfcf006d, 0x645e0197, 0xf3ff0082, 0x00000000}},  //   ويل_, _ippi, _giã_,
  { {0x3ea00ddf, 0x6f0409fc, 0x00000000, 0x00000000}},  //   áit_, žico,   ,
  { {0xa5bb00c4, 0x00000000, 0x00000000, 0x00000000}},  //   lsór,   ,   ,
  { {0x3ea000b9, 0xdc87005e, 0xbc671f4f, 0x00000000}},  //   šit_, исъл_, لمون_,
  { {0xa5bb0181, 0x201a0052, 0x7c380066, 0x00000000}},  //   nsór, mppi_, _ċarġ,
  { {0x2fc6037e, 0xe8d90011, 0xa9c600ed, 0x00000000}},  //   mnog_, _đỡ_, исок,
  { {0x645e021e, 0x2fc60091, 0xb997007c, 0x00000000}},  //   _oppi, lnog_, ивых_,
  { {0xdb240014, 0x2b98009d, 0x2fc6012d, 0x00000000}},  //   _هوای, _sécu_, onog_,
  { {0x22520a77, 0x2fc60016, 0x2cf40061, 0x00000000}},  //   ktyk_, nnog_, ेखील_,
  { {0x645e0638, 0x6b822ba2, 0x00000000, 0x00000000}},  //   _appi, _inog,   ,
  { {0x2b98009d, 0xd8b700a1, 0x00000000, 0x00000000}},  //   _vécu_, ادیا_,   ,
  { {0xd498007e, 0x8937009b, 0x6db20036, 0x00000000}},  //   арт_, _כרגע_, sław,
  { {0x248d0119, 0xf6990014, 0x291e0006, 0x00000000}},  //   ćem_, _منبع_, lbta_,
  { {0x2fc60119, 0x6b820825, 0x6d5a00ab, 0x00000000}},  // [8010] dnog_, _mnog, _obta,
  { {0xd5b80077, 0x00000000, 0x00000000, 0x00000000}},  //   _всю_,   ,   ,
  { {0x6b820091, 0xa3d5109f, 0x2fc60544, 0x00000000}},  //   _onog, _гонч, fnog_,
  { {0x02d900a2, 0x44312ba3, 0x00000000, 0x00000000}},  //   _موجب_, msz_,   ,
  { {0x44310010, 0x00000000, 0x00000000, 0x00000000}},  //   lsz_,   ,   ,
  { {0x69c60010, 0x6b82005b, 0x947402fd, 0x00000000}},  //   ékel, _anog, _ادیا,
  { {0x4034005e, 0x2fc60166, 0x6d5a000a, 0x00000000}},  //   _мерс, bnog_, _dbta,
  { {0x2fc6037e, 0xc05200a0, 0x69ca016c, 0x00000000}},  //   cnog_, _מזל_, _ajfe,
  { {0xe9d90001, 0x29180279, 0x317101f3, 0x00000000}},  //   лки_, ıran_, _kazz_,
  { {0x6b820197, 0xa969003b, 0xd945003b, 0x00000000}},  //   _enog, ћина_, љени,
  { {0x6616068f, 0x8d7400f3, 0xa3d7007d, 0x00000000}},  //   _styk, _باقا, ाका_,
  { {0x7e7b09fc, 0x44310010, 0x1b210044, 0x00000000}},  //   _krup, dsz_, _যাকে_,
  { {0xeab31edd, 0x44310036, 0xda080011, 0x00000000}},  //   _بعض_, esz_, _tỏa_,
  { {0xb21b0030, 0x4df90049, 0x2fc60091, 0x00000000}},  //   _kræf, רפֿא, znog_,
  { {0x64a3007c, 0x443316d4, 0x681300e5, 0x00000000}},  //   пара, _cvx_, _băde,
  { {0x44330026, 0x68130035, 0x00000000, 0x00000000}},  //   _dvx_, _căde,   ,
  { {0x2fc60119, 0x68130035, 0x00000000, 0x00000000}},  // [8020] vnog_, _dăde,   ,
  { {0xa5bb0181, 0x31710026, 0x00000000, 0x00000000}},  //   ssór, _cazz_,   ,
  { {0x2fc60091, 0xa9ba0049, 0x645e1fbc, 0x00000000}},  //   tnog_, נזער, _uppi,
  { {0x43860054, 0x7f46007e, 0x7e2a01ff, 0x00000000}},  //   _الحق, седж, гіка_,
  { {0xddcb00d0, 0x2fc60091, 0x7e560088, 0x00000000}},  //   _šišk, rnog_, стец,
  { {0x7e7b1cbf, 0x2fc62ba4, 0x3a3f0637, 0x00000000}},  //   _drup, snog_, drup_,
  { {0x409601b7, 0x7c2401ee, 0x2fc60091, 0x00000000}},  //   _الزر, ćiro, pnog_,
  { {0x79831d34, 0x20180026, 0x200a0035, 0x00000000}},  //   _annw, _itri_, _iubi_,
  { {0x224000eb, 0xa92a007e, 0x3a3f00d4, 0x00000000}},  //   nrik_, ліне_, grup_,
  { {0x388e0163, 0x200a016c, 0x44310036, 0x00000000}},  //   ləri_, _kubi_, ysz_,
  { {0x3bd61969, 0x224008a5, 0x00000000, 0x00000000}},  //   _людс, hrik_,   ,
  { {0x65ab2ba5, 0x25ba0093, 0x22402ba6, 0x00000000}},  //   _mühe, _ampl_, krik_,
  { {0x4431122b, 0x65ab006c, 0x200a0036, 0x00000000}},  //   wsz_, _lühe, _lubi_,
  { {0x44310047, 0x22402ba7, 0x6d4a04d3, 0x00000000}},  //   tsz_, drik_, ngfa,
  { {0xe8d9001d, 0x69c82ba8, 0x200a0197, 0x00000000}},  //   _đủ_, mnde, _nubi_,
  { {0x7ae211d1, 0x67d4005e, 0x44310c59, 0x00000000}},  //   _kyot, _нощу, rsz_,
  { {0x44310047, 0x69c800bb, 0xc1b90f62, 0x00000000}},  // [8030] ssz_, onde, алах_,
  { {0x69da00b5, 0x672f0046, 0x64410129, 0x00000000}},  //   note, lacj, àlis,
  { {0x388e006b, 0x69c8010e, 0x200a237d, 0x00000000}},  //   fəri_, inde, _cubi_,
  { {0x69da0161, 0x661d0190, 0x672f0036, 0x00000000}},  //   hote, opsk, nacj,
  { {0x7e7b005f, 0x63ad0051, 0x69da0e33, 0x00000000}},  //   _qrup, mhan, kote,
  { {0x63ad0181, 0x69da0066, 0xd658009b, 0x00000000}},  //   lhan, jote, ציות_,
  { {0x64550756, 0x672f0046, 0x69da00b0, 0x00000000}},  //   ntzi, kacj, dote,
  { {0x69c81d78, 0xeb9909e8, 0x7e7b0710, 0x00000000}},  //   ende, рии_, _trup,
  { {0xbfa8026b, 0x69da006c, 0x7e7b2ba9, 0x00000000}},  //   _утре_, fote, _urup,
  { {0xfeb8025a, 0x49990ae0, 0x3a3f01d6, 0x00000000}},  //   _طاقت_, ртия_, rrup_,
  { {0x63ad011c, 0xa3e9007d, 0x661d0ace, 0x00000000}},  //   khan, यता_, epsk,
  { {0xaa590902, 0x99860046, 0x8b670426, 0x00000000}},  //   _виду_, _ktoś_, _دائم,
  { {0x63ad2baa, 0x69da001f, 0x6db20036, 0x00000000}},  //   dhan, bote, płat,
  { {0x98a50216, 0x7bc90f30, 0x63ad0253, 0x00000000}},  //   _миле, lneu, ehan,
  { {0x63ad01b5, 0x64a61606, 0x661d01d6, 0x00000000}},  //   fhan, цава, apsk,
  { {0x63ad006a, 0x7bc900f4, 0x42260401, 0x00000000}},  //   ghan, nneu, ждав,
  { {0xa3bb02d2, 0x200a1339, 0x25ba0009, 0x00000000}},  // [8040] _अगर_, _subi_, _tmpl_,
  { {0x22401e57, 0xd24f00a1, 0x64470fa4, 0x00000000}},  //   rrik_, ئنل_, buji,
  { {0x63ad2bab, 0x7bc905a6, 0x4f0a05bb, 0x00000000}},  //   bhan, kneu, анен_,
  { {0x68e30635, 0x69da1126, 0x2d850173, 0x00000000}},  //   _mynd, zote, _anle_,
  { {0x68e30436, 0xa3d702d2, 0x69c80190, 0x00000000}},  //   _lynd, ाकर_, ynde,
  { {0x672f0046, 0x200a0cec, 0x69da0032, 0x00000000}},  //   zacj, _tubi_, xote,
  { {0x69da0c6a, 0x8fa6008b, 0x6d4a04f2, 0x00000000}},  //   vote, _даве, rgfa,
  { {0x7bc900f4, 0x69c80016, 0x5b26007e, 0x00000000}},  //   gneu, wnde, цька,
  { {0x69da2001, 0x63a42bac, 0xb21b1f7d, 0x00000000}},  //   tote, ikin, _græd,
  { {0x69c8010f, 0x7ae209c7, 0x672f0036, 0x00000000}},  //   unde, _vyot, wacj,
  { {0x2004005f, 0x69da0ed6, 0x672f0046, 0x00000000}},  //   _kimi_, rote, tacj,
  { {0x29070039, 0x2004013e, 0x69da0059, 0x00000000}},  //   _egna_, _jimi_, sote,
  { {0x2004000b, 0x672f0046, 0x69da2bad, 0x00000000}},  //   _mimi_, racj, pote,
  { {0x7bc0006a, 0x63a411de, 0x27e02bae, 0x00000000}},  //   limu, ekin, _ekin_,
  { {0x63ad002a, 0x63a40107, 0x6575012d, 0x00000000}},  //   than, fkin, rdzh,
  { {0x20040004, 0x6455022b, 0x5215007c, 0x00000000}},  //   _nimi_, rtzi, здат,
  { {0x645500bb, 0x6aa000ea, 0x3e5e0089, 0x00000000}},  // [8050] stzi, nymf, nātā_,
  { {0x63ad000b, 0xddc20046, 0x7bc00058, 0x00000000}},  //   shan, rtoś, himu,
  { {0x63a421b3, 0x7bc00006, 0xddc20036, 0x00000000}},  //   bkin, kimu, stoś,
  { {0x63a40866, 0x7bc00006, 0x86080014, 0x00000000}},  //   ckin, jimu, _دقیق_,
  { {0xa77c0049, 0x7bc00006, 0xab5d0036, 0x00000000}},  //   יראפ, dimu, niże,
  { {0x98a5000d, 0x7bc90016, 0x6aa00016, 0x00000000}},  //   nală_, wneu, dymf,
  { {0x2249022b, 0xdd8e0025, 0x6605006c, 0x00000000}},  //   luak_, اوى_, _mihk,
  { {0x7bc0001a, 0xb21b0030, 0xe1ff0036, 0x00000000}},  //   gimu, _træd, _psów_,
  { {0x7bc902a4, 0x68e6006b, 0x2249002d, 0x00000000}},  //   rneu, əkdi, nuak_,
  { {0x63a4022b, 0x27e000ab, 0xdce3179e, 0x00000000}},  //   zkin, _skin_, lenč,
  { {0x63a4000c, 0xb33b0180, 0x7bc0010e, 0x00000000}},  //   ykin, _elçi, bimu,
  { {0xf7720137, 0x2249002d, 0x6e2909ba, 0x00000000}},  //   راج_, kuak_, _kweb,
  { {0xddc90340, 0x68e32baf, 0x63a41bf5, 0x00000000}},  //   _mrež, _wynd, vkin,
  { {0x68e30030, 0x2249002d, 0xdb000181, 0x00000000}},  //   _tynd, duak_, rimô,
  { {0x63a4011f, 0x69c11eb5, 0x947902be, 0x00000000}},  //   tkin, mile, осту_,
  { {0x69c103fb, 0xdce301d9, 0x130a007e, 0x00000000}},  //   lile, jenč, снай_,
  { {0x63a422c7, 0xc64a0054, 0x69c10051, 0x00000000}},  // [8060] rkin, _اجعل_, oile,
  { {0x63a42bb0, 0x69c1011f, 0x867b00a3, 0x00000000}},  //   skin, nile, _פריו,
  { {0x63a401ee, 0xddc90627, 0x036a005e, 0x00000000}},  //   pkin, _brež, _линк_,
  { {0xb21b0030, 0x69c12bb1, 0x644110c1, 0x00000000}},  //   _dræb, hile, šlic,
  { {0x69c1011f, 0x7bc00006, 0xff030451, 0x00000000}},  //   kile, vimu, няшн,
  { {0x69c1014a, 0x3e5e0089, 0x63ae01c5, 0x00000000}},  //   jile, vātā_, šinē,
  { {0x7bc00cc9, 0x69c103fb, 0x6e2901c3, 0x00000000}},  //   timu, dile, _eweb,
  { {0x65ab005f, 0xdb0000b0, 0x2a6d062a, 0x00000000}},  //   _müha, yhmä, fweb_,
  { {0xadc3001d, 0xe944007a, 0x7bc0143d, 0x00000000}},  //   _quản, وردی, rimu,
  { {0x7bc02bb2, 0x69c11113, 0x00000000, 0x00000000}},  //   simu, gile,   ,
  { {0x7bc02bb3, 0x2249002d, 0x672d2bb4, 0x00000000}},  //   pimu, zuak_, _peaj,
  { {0xeb9707ca, 0x65b000b0, 0x37ab00ed, 0x00000000}},  //   _них_, _lähd, стон_,
  { {0x69c10612, 0xcb070025, 0x98a5001a, 0x00000000}},  //   bile, _عيون_, tală_,
  { {0x69c12bb5, 0xe944007a, 0xf9c401ef, 0x00000000}},  //   cile, _آرشی, _تحصی,
  { {0x98a5001a, 0xe7e801f5, 0x6605003c, 0x00000000}},  //   rală_, _टीका_, _vihk,
  { {0x443f0ade, 0x2249022b, 0x660d0022, 0x00000000}},  //   ču_, tuak_, _tuak,
  { {0x2509025a, 0x98a5001a, 0xc73c009b, 0x00000000}},  // [8070] _وردی_, pală_, _התחת,
  { {0x2249002d, 0x67d20089, 0x00000000, 0x00000000}},  //   ruak_, māja,   ,
  { {0xddc9167a, 0x2249002d, 0xe7cf0044, 0x00000000}},  //   _prež, suak_, রতীয,
  { {0x69c1014a, 0x65770065, 0x22490032, 0x00000000}},  //   zile, _haxh, puak_,
  { {0xee3803e8, 0xdce30387, 0x69c10095, 0x00000000}},  //   зні_, renč, yile,
  { {0xdce31a7d, 0x05010044, 0xfce5005c, 0x00000000}},  //   senč, ্রীর_, моло,
  { {0x69c10211, 0x2a6d01f3, 0x65770023, 0x00000000}},  //   vile, wweb_, _maxh,
  { {0x09b7001c, 0x6e290869, 0x2a6d05d2, 0x00000000}},  //   ेच्य, _tweb, tweb_,
  { {0x69c11147, 0x00000000, 0x00000000, 0x00000000}},  //   tile,   ,   ,
  { {0x2a6d00d4, 0x67d20089, 0x00000000, 0x00000000}},  //   rweb_, dāja,   ,
  { {0x69c1011f, 0xe3c201f6, 0xf74602b8, 0x00000000}},  //   rile, lmış_, мено,
  { {0x69c102d5, 0x08d4007e, 0xfe70009e, 0x00000000}},  //   sile, эцыя, _جدہ_,
  { {0x65b00368, 0xe3c201f6, 0x2a6d0061, 0x00000000}},  //   _lähe, nmış_, qweb_,
  { {0x65ab006c, 0x9c7c00ca, 0x6b840045, 0x00000000}},  //   _püha, _izčr, _òigr,
  { {0x65b023cb, 0xa50702b8, 0x00000000, 0x00000000}},  //   _nähe, дера_,   ,
  { {0xe3c2014a, 0x25b40006, 0x64411748, 0x00000000}},  //   kmış_, _šalį_, ália,
  { {0xd5b201d8, 0xa2060228, 0x00000000, 0x00000000}},  // [8080] _لفظ_, дпад,   ,
  { {0xb1430b7a, 0x65ab01a2, 0xa0a602ea, 0x00000000}},  //   кнул, _hühn, мазд,
  { {0xb21b0030, 0x00000000, 0x00000000, 0x00000000}},  //   _præc,   ,   ,
  { {0x201c0089, 0x443a01d6, 0xdfd20380, 0x00000000}},  //   īvi_, _ivp_, خيص_,
  { {0x65b000b0, 0xfe6f0380, 0x00000000, 0x00000000}},  //   _tähd, لدو_,   ,
  { {0x7e6d00c4, 0x21ef010e, 0x00000000, 0x00000000}},  //   çapa, püha_,   ,
  { {0x9103007c, 0x443800d9, 0x443a01ed, 0x00000000}},  //   _апре, nsr_, _jvp_,
  { {0xda08001d, 0x3a74047d, 0xe8df0082, 0x00000000}},  //   _hỏi_, елир, _chọi_,
  { {0x290a0bf8, 0x443a00d9, 0x2614010e, 0x00000000}},  //   žbam_, _lvp_, _näo_,
  { {0x6e221051, 0x67d20089, 0x4d63005e, 0x00000000}},  //   mpob, vāja, _икув,
  { {0xda080011, 0x65ab010f, 0x317801d6, 0x00000000}},  //   _mỏi_, _bühn, _marz_,
  { {0x67d2001e, 0xda080082, 0x00000000, 0x00000000}},  //   tāja, _lỏi_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x58d4004c, 0xdb0b0f57, 0x443a007f, 0x00000000}},  //   _полт, _algè, _bvp_,
  { {0x443a014a, 0x7c380116, 0x798a000a, 0x00000000}},  //   _cvp_, nsvr, _infw,
  { {0x67d20089, 0x443a0253, 0x00000000, 0x00000000}},  //   pāja, _dvp_,   ,
  { {0x05010055, 0xddc9002b, 0x9f9c000c, 0x00000000}},  // [8090] ্রের_, _preż, víð_,
  { {0xd1310426, 0x51f80147, 0x74f90140, 0x00000000}},  //   اما_, дную_, _непр_,
  { {0x75352bb6, 0x6aca0164, 0x9f9c000c, 0x00000000}},  //   mazz, ापुर, tíð_,
  { {0x75351a64, 0x65b00cfc, 0xa29501ff, 0x00000000}},  //   lazz, _vähe, _замі,
  { {0x59de03d7, 0x9f5800f6, 0x9f9c000c, 0x00000000}},  //   नकार, _auró_, ríð_,
  { {0x65b00004, 0x753501d5, 0xe3c2005d, 0x00000000}},  //   _tähe, nazz, rmış_,
  { {0xe0e4007e, 0xfce200ed, 0x3ea902db, 0x00000000}},  //   _аўто, лошо, šat_,
  { {0x9f58008e, 0xe3c201df, 0xd8380173, 0x00000000}},  //   _duró_, pmış_, ryčl_,
  { {0x753501d5, 0x67f600b9, 0xd8380173, 0x00000000}},  //   kazz, náje, syčl_,
  { {0xf9910054, 0x75350066, 0xf1b20049, 0x00000000}},  //   ابة_, jazz, ָסט_,
  { {0xa3c10201, 0x7535002b, 0x3d940216, 0x00000000}},  //   ्चा_, dazz, _шифр,
  { {0x443a00d2, 0x798a000a, 0x2011164f, 0x00000000}},  //   _rvp_, _enfw, _muzi_,
  { {0xa68309c0, 0x6b8b1535, 0x23ae000c, 0x00000000}},  //   гляд, _ingg, _nýja_,
  { {0xceb2019b, 0x75350409, 0x443a0095, 0x00000000}},  //   נים_, gazz, _pvp_,
  { {0xdb0b00f4, 0x9958013e, 0x00000000, 0x00000000}},  //   _algé, jáři_,   ,
  { {0x44382bb7, 0x67d20089, 0x386700d9, 0x00000000}},  //   rsr_, mājo, _ipnr_,
  { {0xe8df0011, 0x65ab010f, 0x201104f8, 0x00000000}},  // [80a0] _khỏi_, _kühl, _auzi_,
  { {0x75350197, 0x443a00d2, 0xd83801aa, 0x00000000}},  //   cazz, _tvp_, zyčm_,
  { {0x65ab010f, 0x04ca0379, 0x67d20089, 0x00000000}},  //   _mühl, _روحي_, nājo,
  { {0x20110107, 0x645c0146, 0x644e0089, 0x00000000}},  //   _duzi_, mtri, mubi,
  { {0x644e011c, 0xdfcf0025, 0x31780095, 0x00000000}},  //   lubi, حين_, _tarz_,
  { {0x6b8b2bb8, 0xdd900025, 0xda080082, 0x00000000}},  //   _angg, شوب_, _tỏi_,
  { {0x645c049a, 0xa0670121, 0x9f580026, 0x00000000}},  //   ntri, _пара_, _durò_,
  { {0x67d20089, 0x75350066, 0x61fe0146, 0x00000000}},  //   dājo, zazz, lmpl,
  { {0x645c0b96, 0x644e0020, 0xdd8f0123, 0x00000000}},  //   htri, hubi, _گول_,
  { {0x644e022b, 0x6b8b0169, 0x9f5800d4, 0x00000000}},  //   kubi, _engg, _turó_,
  { {0xd8f801fb, 0x7535002b, 0x2d8c2bb9, 0x00000000}},  //   ьної_, vazz, _inde_,
  { {0xe7cf0055, 0x645c0058, 0x2fc60016, 0x00000000}},  //   রত্য, dtri, niog_,
  { {0x2d9e0607, 0xe9a6008b, 0x753501d5, 0x00000000}},  //   _kote_, _падп, tazz,
  { {0xb21b0737, 0x2d9e0065, 0x645c010f, 0x00000000}},  //   _bræn, _jote_, ftri,
  { {0x753501d5, 0xa4d40088, 0xdb090051, 0x00000000}},  //   razz, горі, mheá,
  { {0x2d9e00d6, 0x61fe2bba, 0x75350026, 0x00000000}},  //   _lote_, empl, sazz,
  { {0x2d8c2bbb, 0x75350a19, 0x7179012b, 0x00000000}},  // [80b0] _onde_, pazz, мбар_,
  { {0x2d9e062a, 0xb21b000c, 0x645c06b9, 0x00000000}},  //   _note_, _fræn, btri,
  { {0xb21b0dba, 0x03f900ed, 0x644e008e, 0x00000000}},  //   _græn, _оној_, cubi,
  { {0x2d8c277c, 0x61fe03c5, 0x44210048, 0x00000000}},  //   _ande_, ampl, _ith_,
  { {0x2d9e151e, 0x44210190, 0x290a00ca, 0x00000000}},  //   _bote_, _hth_, žbah_,
  { {0x7bc20c03, 0x2d9e00f4, 0xbea2007e, 0x00000000}},  //   _amou, _cote_, рашк,
  { {0xabd503f3, 0xeb9910e2, 0x2d9e0023, 0x00000000}},  //   кциј, дий_, _dote_,
  { {0x2d8c1c94, 0x77a60b33, 0x442102c1, 0x00000000}},  //   _ende_, _tóxi, _mth_,
  { {0x7e2b0245, 0x98ac0089, 0x644e0dab, 0x00000000}},  //   _хіба_, vadā_, zubi,
  { {0x59821734, 0x44210048, 0x8d740014, 0x00000000}},  //   альб, _oth_, _ماما,
  { {0x645c002b, 0xb6040224, 0x65b0010e, 0x00000000}},  //   xtri, ntář, _näha,
  { {0x2d9e000b, 0x6b8b1535, 0x224911ce, 0x00000000}},  //   _zote_, _ungg, krak_,
  { {0x2d9e000b, 0x4421056f, 0x61fe0203, 0x00000000}},  //   _yote_, _ath_, ympl,
  { {0x645c2bbc, 0x644e0020, 0xdce800b9, 0x00000000}},  //   ttri, tubi, _nadě,
  { {0x2249002d, 0x657c010f, 0x442101a3, 0x00000000}},  //   erak_, rdrh, _cth_,
  { {0x645c010f, 0x2c7c00b9, 0x44210f02, 0x00000000}},  //   rtri, ládá_, _dth_,
  { {0x442100d4, 0x6d410119, 0x644e0020, 0x00000000}},  // [80c0] _eth_, _odla, subi,
  { {0xb21b0018, 0x645c0253, 0x3f8d00d4, 0x00000000}},  //   _træn, ptri, _aneu_,
  { {0x2d9e2bbd, 0x7e6926f1, 0x320a0190, 0x00000000}},  //   _rote_, _apep, _viby_,
  { {0x2d9e0509, 0x6d412bbe, 0xdce80027, 0x00000000}},  //   _sote_, _adla, _podľ,
  { {0x2d9e0263, 0x69c300f8, 0x2fc6005b, 0x00000000}},  //   _pote_, _omne, riog_,
  { {0x2fc6010a, 0x4421023a, 0x7bc201d6, 0x00000000}},  //   siog_, _yth_, _smou,
  { {0x6da300e1, 0x6aca0164, 0x2d9e2bbf, 0x00000000}},  //   рија, ाप्र, _vote_,
  { {0x2d9e000b, 0x65ab0d23, 0x628600b9, 0x00000000}},  //   _wote_, _rühm, _krko,
  { {0xcb67098c, 0x2d9e01a2, 0x00000000, 0x00000000}},  //   тање_, _tote_,   ,
  { {0x2d8c000d, 0x62860107, 0x7aeb0030, 0x00000000}},  //   _unde_, _mrko, _dygt,
  { {0x3137009b, 0x1cba00f3, 0x00000000, 0x00000000}},  //   כנים_, _غائب_,   ,
  { {0x69c302cc, 0x44210093, 0x765d2bc0, 0x00000000}},  //   _emne, _rth_, ttsy,
  { {0xa2c20183, 0xdddb0387, 0x00000000, 0x00000000}},  //   _रेल्, _hruš,   ,
  { {0x765d05d5, 0xdddb05c5, 0xdbd1000c, 0x00000000}},  //   rtsy, _kruš, lýðs,
  { {0xd5b8222e, 0x69c8006c, 0xb4ad006e, 0x00000000}},  //   тся_, mide, कने_,
  { {0x9cd7009b, 0x628604eb, 0x63b6005b, 0x00000000}},  //   דולה_, _brko, ghyn,
  { {0x27e9020c, 0x69c800b0, 0x61f9007e, 0x00000000}},  // [80d0] _ikan_, oide, енаў_,
  { {0x2249022b, 0x69c808a7, 0x645a0129, 0x00000000}},  //   rrak_, nide, àtic,
  { {0x3f8d0161, 0x62860b79, 0x00000000, 0x00000000}},  //   _pneu_, _erko,   ,
  { {0x69c8001a, 0x2249014a, 0x63b62bc1, 0x00000000}},  //   hide, prak_, chyn,
  { {0x69c82bc2, 0x25090167, 0x3f8100b9, 0x00000000}},  //   kide, _ترکی_, ěhu_,
  { {0x7aeb0030, 0x61e7012d, 0xdddb0142, 0x00000000}},  //   _rygt, _ukjl, _bruš,
  { {0x69c8143d, 0x25a100b9, 0x61e50161, 0x00000000}},  //   dide, _mohl_, mohl,
  { {0xdb090181, 0xdddb0f3a, 0xb5fb0181, 0x00000000}},  //   nheç, _druš, ntáb,
  { {0x7e690020, 0x63ad09a3, 0x1a650167, 0x00000000}},  //   _upep, ikan, ایتی_,
  { {0x27e90149, 0x69c80129, 0x6d410030, 0x00000000}},  //   _akan_, gide, _udla,
  { {0xbb550014, 0xcb55002c, 0x07a60500, 0x00000000}},  //   _مناب, _مناظ, ганн,
  { {0x63ad00bb, 0x00000000, 0x00000000, 0x00000000}},  //   jkan,   ,   ,
  { {0x69c8022b, 0x200d0207, 0xdddb01ca, 0x00000000}},  //   bide, _miei_, _zruš,
  { {0x7bc91250, 0x23a7006c, 0x63ad14a6, 0x00000000}},  //   lieu, _mõju_, ekan,
  { {0x7416031d, 0x98ac001a, 0x63b60016, 0x00000000}},  //   اورا, radă_, thyn,
  { {0x7bc902ae, 0xa69602a8, 0x63ad011c, 0x00000000}},  //   nieu, _број, gkan,
  { {0xe1fa012b, 0x6abb010f, 0x63b62325, 0x00000000}},  // [80e0] ега_, nzuf, rhyn,
  { {0x7c3e050f, 0x201c00c4, 0x65b001a2, 0x00000000}},  //   špri, ívio_, _zähn,
  { {0x11d70054, 0x7bc90405, 0x705603d9, 0x00000000}},  //   دولة_, kieu, انصا,
  { {0x63ad0039, 0x69c80baf, 0xee3a00ed, 0x00000000}},  //   ckan, zide, енд_,
  { {0xdddb0d1b, 0x6da6003b, 0x6b9b0026, 0x00000000}},  //   _sruš, лида, djug,
  { {0x1dc40061, 0x657e00e7, 0xdddb0087, 0x00000000}},  //   _वगळत, _japh, _pruš,
  { {0x7bc9009d, 0x00000000, 0x00000000, 0x00000000}},  //   fieu,   ,   ,
  { {0x7bc92bc3, 0x657e060d, 0xafe616c4, 0x00000000}},  //   gieu, _laph, _собл,
  { {0xb5fb2bc4, 0x69c803fc, 0x62840912, 0x00000000}},  //   ntác, tide, nvio,
  { {0x657e031e, 0xb33b00c4, 0x27e92bc5, 0x00000000}},  //   _naph, _moça, _skan_,
  { {0x69c80129, 0x0c2600d7, 0x6b9b002b, 0x00000000}},  //   ride, _смен, bjug,
  { {0x7bc900f4, 0x7a86025a, 0x63ad002d, 0x00000000}},  //   cieu, _مشتم, xkan,
  { {0x69c81fcd, 0xb8eb02f4, 0x199400a5, 0x00000000}},  //   pide, _रे_, _валя,
  { {0x2d9c0065, 0x3eb9014a, 0x00000000, 0x00000000}},  //   njve_, _üste_,   ,
  { {0x63ad0036, 0x29370097, 0xb21b000c, 0x00000000}},  //   tkan, _גאון_, _græj,
  { {0x25a1001f, 0x65ab2bc6, 0x63ad24b0, 0x00000000}},  //   _wohl_, _mühi, ukan,
  { {0x6d5a2bc7, 0x65ab006c, 0x61e507ac, 0x00000000}},  // [80f0] _octa, _lühi, tohl,
  { {0x63ad0235, 0x291e2bc8, 0xb5fb0010, 0x00000000}},  //   skan, ncta_, stáb,
  { {0x63ad0743, 0x3f150e75, 0x62840052, 0x00000000}},  //   pkan, адес, avio,
  { {0x62840061, 0x61fc010f, 0xa857009b, 0x00000000}},  //   bvio, _ehrl, ריאה_,
  { {0xb5fb2bc9, 0x7bc9009d, 0x00000000, 0x00000000}},  //   ctác, vieu,   ,
  { {0xdcfa01f6, 0xdca50242, 0x777f01f3, 0x00000000}},  //   _altı, иали, _laqx,
  { {0x9f6b008b, 0x7bc9009d, 0x00000000, 0x00000000}},  //   _праз_, tieu,   ,
  { {0x0ec00061, 0x747c009b, 0x00000000, 0x00000000}},  //   _शेकड, תנהג,   ,
  { {0x7bc92bca, 0x6280027b, 0x6b9b017b, 0x00000000}},  //   rieu, _ámot, rjug,
  { {0x7bc9028c, 0xa2d80061, 0x89a9051f, 0x00000000}},  //   sieu, _यशस्, тков_,
  { {0xe8f605c7, 0x6abb010f, 0x8afd00b9, 0x00000000}},  //   иль_, szuf, teřs,
  { {0xd7060216, 0xe73a007c, 0x62830089, 0x00000000}},  //   изни, ъем_, ānoj,
  { {0x2bb80054, 0xaf760049, 0x67d20089, 0x00000000}},  //   _حالة_, בערס_, nāji,
  { {0x291e001c, 0xc987003b, 0xb33b00c4, 0x00000000}},  //   ccta_, _људи, _roça,
  { {0x8883026c, 0xab5d01d5, 0xb21b0698, 0x00000000}},  //   _ایجن, viżj, _fræk,
  { {0x0326017a, 0x65b0010f, 0x7e7b050f, 0x00000000}},  //   рдан, _zähl, _osup,
  { {0x3116007e, 0x130a007e, 0xd2a701ab, 0x00000000}},  // [8100] афес, тнай_, акте_,
  { {0x62842bcb, 0xc04603ab, 0x67d20089, 0x00000000}},  //   rvio, لخصو, dāji,
  { {0x7e7b000d, 0xb5fb0142, 0x67f60027, 0x00000000}},  //   _asup, stác, nájo,
  { {0x753c0036, 0x60230088, 0x00000000, 0x00000000}},  //   larz, ідча,   ,
  { {0xfe7202fd, 0xdce10006, 0x7e7b0010, 0x00000000}},  //   تدا_, _kalė, _csup,
  { {0x644e01c3, 0x753c18f8, 0x24780173, 0x00000000}},  //   orbi, narz, _kōm_,
  { {0x10a60088, 0x22400058, 0x4f9617a4, 0x00000000}},  //   _тивн, lsik_, _крау,
  { {0xafe301fb, 0x207b01ce, 0x7e7b0009, 0x00000000}},  //   _досл, _באלא, _fsup,
  { {0x753c0036, 0x2240008a, 0x00000000, 0x00000000}},  //   karz, nsik_,   ,
  { {0x20180ebc, 0x1daa02f4, 0x65ab006c, 0x00000000}},  //   _kuri_, _कवित, _tühi,
  { {0x2018002b, 0x753c0046, 0x7e620052, 0x00000000}},  //   _juri_, darz, ltop,
  { {0x2018001c, 0x65b0010f, 0x2240011c, 0x00000000}},  //   _muri_, _wähl, ksik_,
  { {0x95cb053c, 0x7e6200b0, 0x201800e0, 0x00000000}},  //   вува_, ntop, _luri_,
  { {0x6703001c, 0x6d5806e8, 0x3a260009, 0x00000000}},  //   रेषक_, ngva, _itop_,
  { {0xb21b0030, 0x20182408, 0x44252bcc, 0x00000000}},  //   _træk, _nuri_, ël_,
  { {0x7e621f9d, 0xf77f0181, 0x3e6001aa, 0x00000000}},  //   ktop, moço_, kòt_,
  { {0x20180022, 0x22402bcd, 0x673d2bce, 0x00000000}},  // [8110] _auri_, gsik_, masj,
  { {0x20180061, 0xdce1010a, 0x673d0056, 0x00000000}},  //   _buri_, _galė, lasj,
  { {0x2018266b, 0xd6d90044, 0x7e620943, 0x00000000}},  //   _curi_, _সরিয, etop,
  { {0x9f0506ea, 0x67d2001e, 0x64550020, 0x00000000}},  //   موضو, tāji, muzi,
  { {0x64550198, 0x7e622635, 0x20180032, 0x00000000}},  //   luzi, gtop, _euri_,
  { {0x5187003b, 0x2b460026, 0x201800e5, 0x00000000}},  //   _тума, _adoc_, _furi_,
  { {0x20180ab3, 0x64550197, 0x673d0292, 0x00000000}},  //   _guri_, nuzi, kasj,
  { {0x7e620f5d, 0x3a3f0146, 0xdd3a001a, 0x00000000}},  //   btop, tsup_, păşi,
  { {0x2018002d, 0x673d2bcf, 0xa3af0061, 0x00000000}},  //   _zuri_, dasj, _कवन_,
  { {0x20181544, 0x64551126, 0x00000000, 0x00000000}},  //   _yuri_, kuzi,   ,
  { {0xe73a05b5, 0x3a3f2bd0, 0x4998007e, 0x00000000}},  //   лен_, ssup_, ртыя_,
  { {0x64550a15, 0x753c0036, 0xf3ff0011, 0x00000000}},  //   duzi, warz, _nhã_,
  { {0xa9690113, 0x753c2bd1, 0x31af014a, 0x00000000}},  //   _била_, tarz, _kızı_,
  { {0x64a601ff, 0xf77f00c4, 0x65750010, 0x00000000}},  //   бага, boço_, gezh,
  { {0xa34a005e, 0x6813001a, 0x7e622bd2, 0x00000000}},  //   лзва_, _pădu, ztop,
  { {0x22402bd3, 0x32190837, 0x753c18f8, 0x00000000}},  //   tsik_, _busy_, sarz,
  { {0x175700b6, 0x20180513, 0xe29700ed, 0x00000000}},  // [8120] _הספר_, _suri_, бат_,
  { {0x64550207, 0x20180058, 0x0446004c, 0x00000000}},  //   buzi, _puri_, _леон,
  { {0x7e622bd4, 0x64550207, 0x2240194f, 0x00000000}},  //   wtop, cuzi, ssik_,
  { {0x44440142, 0x7e622a8f, 0xb5fb2bd5, 0x00000000}},  //   _iv_, ttop, ntán,
  { {0x4444006c, 0x0dca00ed, 0x9f5f0082, 0x00000000}},  //   _hv_, луки_, _khuê_,
  { {0x44442bd6, 0x20182bd7, 0x3f801472, 0x00000000}},  //   _kv_, _turi_, žiu_,
  { {0x7e6201d9, 0x3a2600ab, 0xad650014, 0x00000000}},  //   stop, _stop_, تانه,
  { {0x44440030, 0x3e6001aa, 0x1ae10044, 0x00000000}},  //   _mv_, pòt_, খেছে_,
  { {0x44440580, 0x67d2001e, 0xa5bb002a, 0x00000000}},  //   _lv_, nāju, spói,
  { {0x44440142, 0x6d580009, 0x9d43022a, 0x00000000}},  //   _ov_, qgva, _неуд,
  { {0x44440011, 0xd90d0014, 0x673d0292, 0x00000000}},  //   _nv_, نیه_, tasj,
  { {0x20060082, 0x200500f6, 0xf77f00fa, 0x00000000}},  //   nmoi_, _èlit_, roço_,
  { {0x4444067e, 0x673d0292, 0x20060082, 0x00000000}},  //   _av_, rasj, imoi_,
  { {0x444401b5, 0x645528ea, 0xb21b0018, 0x00000000}},  //   _bv_, tuzi, _kræv,
  { {0x63a60039, 0x32190555, 0x7afc006b, 0x00000000}},  //   _bokn, _susy_, ərta,
  { {0x444404bd, 0x64550207, 0xb5fb004a, 0x00000000}},  //   _dv_, ruzi, ctán,
  { {0x4444011f, 0x6d482bd8, 0x67d20089, 0x00000000}},  // [8130] _ev_, _odda, gāju,
  { {0x44440061, 0x6b820048, 0x00000000, 0x00000000}},  //   _fv_, _laog,   ,
  { {0x44440082, 0x63a62bd9, 0x61ee0146, 0x00000000}},  //   _gv_, _fokn, _dkbl,
  { {0x6d48018e, 0x776d01f3, 0x6b821f3f, 0x00000000}},  //   _adda, _jbax, _naog,
  { {0xa77c0049, 0x44440dc1, 0x6da5003b, 0x00000000}},  //   טראפ, _zv_, жила,
  { {0x2bb1006e, 0x98a700b9, 0x31af006b, 0x00000000}},  //   जस्थ, _ceně_, _qızı_,
  { {0x65b0021e, 0x4c92003b, 0x00000000, 0x00000000}},  //   _sähk, дијс,   ,
  { {0x2c610036, 0xaba9005e, 0x6d480145, 0x00000000}},  //   ród_, рвиз_, _edda,
  { {0x60250006, 0xb21b0190, 0x00000000, 0x00000000}},  //   _dėme, _usæd,   ,
  { {0x6e2926e4, 0x65ab01a2, 0x00000000, 0x00000000}},  //   _iteb, _mühs,   ,
  { {0x186900ed, 0xf7720d3a, 0xb21b0146, 0x00000000}},  //   шани_, واح_, _græv,
  { {0x98ac013e, 0x00000000, 0x00000000, 0x00000000}},  //   ladě_,   ,   ,
  { {0xd9450175, 0x63a60066, 0xe9ce2bda, 0x00000000}},  //   _дели, _rokn, _жк_,
  { {0x67d2001e, 0xb5fb1580, 0x63a6121b, 0x00000000}},  //   vāju, stán, _sokn,
  { {0x833a2bdb, 0xa50a0f13, 0x444402d4, 0x00000000}},  //   ичат_, рева_, _qv_,
  { {0x67d2001e, 0x04570025, 0x7983005b, 0x00000000}},  //   tāju, تلفة_, _hanw,
  { {0x9f5f001d, 0x65b00368, 0x79830b9a, 0x00000000}},  // [8140] _thuê_, _lähi, _kanw,
  { {0xb5fb08aa, 0x3ce0014a, 0x7f49169a, 0x00000000}},  //   ntál, şivi_, _adeq,
  { {0xef1a0113, 0x7983006a, 0xdce1001e, 0x00000000}},  //   аме_, _manw, _dalī,
  { {0xf1bf0047, 0xb5fb0051, 0x26c22bdc, 0x00000000}},  //   _után_, htál, ozko_,
  { {0x5de60242, 0x20060023, 0x26c20032, 0x00000000}},  //   ожда, rmoi_, nzko_,
  { {0x7bcb0016, 0x26c2002d, 0xdce10089, 0x00000000}},  //   _amgu, izko_, _galī,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdee602a8, 0x0b8a09ae, 0x79830250, 0x00000000}},  //   _доби, рски_, _aanw,
  { {0xed5a02ea, 0x79832bdd, 0x225200b4, 0x00000000}},  //   _воз_, _banw, nryk_,
  { {0x6d480018, 0x65b0010f, 0x3f840020, 0x00000000}},  //   _udda, _fähi, _hamu_,
  { {0x3f841c52, 0xd7fb17a4, 0xe894007e, 0x00000000}},  //   _kamu_, иум_, чань,
  { {0x3f860181, 0x3f842bde, 0xa7fd0180, 0x00000000}},  //   ndou_, _jamu_, atın,
  { {0x8ad600a1, 0x79830016, 0x3f840466, 0x00000000}},  //   _بتائ, _fanw, _mamu_,
  { {0x69ca2967, 0xd5b8004d, 0x98a50089, 0x00000000}},  //   _umfe, осс_, galē_,
  { {0x26c20032, 0xd83a007e, 0x776d0066, 0x00000000}},  //   azko_, _тэл_, _tbax,
  { {0xdce10089, 0x3f840dec, 0x3f8600b9, 0x00000000}},  //   _salī, _namu_, jdou_,
  { {0xdce1001e, 0x23ae000c, 0x69da044e, 0x00000000}},  // [8150] _palī, _nýju_, onte,
  { {0x64412bdf, 0x69da2be0, 0xd25000a1, 0x00000000}},  //   ális, nnte, کنے_,
  { {0x69da001a, 0x65ab001f, 0x6e290006, 0x00000000}},  //   inte, _führ, _steb,
  { {0xd47a007b, 0xb68800a1, 0xb5fb0010, 0x00000000}},  //   _פארל, _اپیل_, ztál,
  { {0x3f840020, 0xa7fd006b, 0x539a009b, 0x00000000}},  //   _damu_, ytın, _הירו,
  { {0xa7fd006b, 0xa5bb00c4, 0xf2d20049, 0x00000000}},  //   xtın, mpós, _װעל_,
  { {0x21ef010f, 0x9f3503e8, 0x61e21339, 0x00000000}},  //   bühr_, _неві, éole,
  { {0x69da0219, 0x65b00103, 0xeb9909e8, 0x00000000}},  //   ente, _vähi, сии_,
  { {0x79830093, 0x6e2900f8, 0xa7fd0095, 0x00000000}},  //   _panw, _uteb, ttın,
  { {0x65b0006c, 0x7db70025, 0x4999004d, 0x00000000}},  //   _tähi, _بصرا, стия_,
  { {0x7ae20161, 0x79830250, 0xb5fb0f14, 0x00000000}},  //   _exot, _vanw, rtál,
  { {0x69da049a, 0xb5fb2be1, 0x2d85014a, 0x00000000}},  //   ante, stál, _hale_,
  { {0x2d851635, 0x1995005e, 0x79830016, 0x00000000}},  //   _kale_, _надя, _tanw,
  { {0x2d87068f, 0x2d852be2, 0xa7fd01df, 0x00000000}},  //   ndne_, _jale_, ltıl,
  { {0x628f0010, 0x64a60726, 0x2d85085d, 0x00000000}},  //   _arco, чава, _male_,
  { {0x42260256, 0xa7fd047f, 0x22522be3, 0x00000000}},  //   здав, ntıl, tryk_,
  { {0x27e00762, 0xe29700ed, 0xab5d0036, 0x00000000}},  // [8160] _ijin_, пат_, liżs,
  { {0xb4660088, 0x628f0146, 0x225201d6, 0x00000000}},  //   _екол, _drco, rryk_,
  { {0xe1ff02d5, 0x628f0ec0, 0x76460740, 0x00000000}},  //   _após_, _erco, lsky,
  { {0x205509c0, 0xa2a70061, 0x3f840066, 0x00000000}},  //   ьтур, _टॅक्, _qamu_,
  { {0x2d85011c, 0x3f8600c4, 0x69da20d6, 0x00000000}},  //   _bale_, rdou_, ynte,
  { {0x63b6009f, 0xa6db009f, 0x63a40091, 0x00000000}},  //   lkyn, naða, ljin,
  { {0x2d8521ad, 0x3f842be4, 0xc0e3007e, 0x00000000}},  //   _dale_, _tamu_, _зорк,
  { {0x69dd028c, 0xb21b0737, 0x63a40091, 0x00000000}},  //   ésen, _græs, njin,
  { {0x2d8505bc, 0xc986003b, 0x443a004a, 0x00000000}},  //   _fale_, пуни, _lwp_,
  { {0x69da010f, 0x76460030, 0x2d85046e, 0x00000000}},  //   unte, dsky, _gale_,
  { {0x69da010f, 0x764601c3, 0x7d020048, 0x00000000}},  //   rnte, esky, _dírí,
  { {0x3cfb00a3, 0x2d850032, 0x7ae20032, 0x00000000}},  //   _פלאנ, _zale_, _txot,
  { {0x2d850020, 0x2c0b00a1, 0x63a42be5, 0x00000000}},  //   _yale_, _اعلی_, djin,
  { {0xa2a70061, 0x7afd0eaa, 0x00000000, 0x00000000}},  //   _टॅग्, üste,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63a40065, 0x08770049, 0xa295007e, 0x00000000}},  //   gjin, _זעהט_, мабі,
  { {0x628f00f6, 0x00000000, 0x00000000, 0x00000000}},  // [8170] _qrco,   ,   ,
  { {0x940b006b, 0x673f0065, 0x38c2009d, 0x00000000}},  //   _əmək_, _heqj, _géré_,
  { {0xb21b0018, 0x2d8501aa, 0x75350009, 0x00000000}},  //   _præs, _rale_, mbzz,
  { {0x7d1a01d6, 0x00000000, 0x00000000, 0x00000000}},  //   _agts,   ,   ,
  { {0x2d852be6, 0x673f002b, 0x63bd0066, 0x00000000}},  //   _pale_, _meqj, _ilsn,
  { {0x645500bb, 0x00000000, 0x00000000, 0x00000000}},  //   orzi,   ,   ,
  { {0x2d850181, 0xac09008b, 0x2d87006c, 0x00000000}},  //   _vale_, онка_, rdne_,
  { {0x2d85000b, 0x395e0089, 0x79980173, 0x00000000}},  //   _wale_, egts_, _anvw,
  { {0x2d8520f5, 0xfe70007a, 0xa7fd01df, 0x00000000}},  //   _tale_, _مدل_, rtıl,
  { {0x3ce8013d, 0x27f22be7, 0xb5fb0010, 0x00000000}},  //   _चुके_, _skyn_, stáj,
  { {0xdddb0466, 0x3cf004bb, 0x00000000, 0x00000000}},  //   _kruž, čové_,   ,
  { {0x65b00b3e, 0x645511e4, 0x76462be8, 0x00000000}},  //   _läht, drzi, tsky,
  { {0xb8f403d7, 0xa6db000c, 0xdcfa001a, 0x00000000}},  //   _से_, taða, _tată,
  { {0x76462be9, 0x273c001d, 0x65b003b6, 0x00000000}},  //   rsky, ận_, _näht,
  { {0x69c11625, 0xdddb0091, 0x76460203, 0x00000000}},  //   mhle, _oruž, ssky,
  { {0x6d43006a, 0x6b890695, 0x27e00023, 0x00000000}},  //   hana, ndeg, _ujin_,
  { {0xdb0b0845, 0x6d43020c, 0x59e1007d, 0x00000000}},  // [8180] _algú, kana, _पदार,
  { {0x6d43037e, 0x63b607e4, 0x443a2bea, 0x00000000}},  //   jana, skyn, _twp_,
  { {0x6d4301a3, 0x657c127d, 0x7bc70006, 0x00000000}},  //   dana, merh, _įjun,
  { {0x645c0632, 0x657c0007, 0x3fbe0055, 0x00000000}},  //   muri, lerh, েক্ষ,
  { {0xdddb18e1, 0x7988018e, 0x645c001a, 0x00000000}},  //   _druž, yddw, luri,
  { {0x6d4300e0, 0x657c010f, 0x60c900b9, 0x00000000}},  //   gana, nerh, _řeme,
  { {0x645c001a, 0x69c12753, 0x7bc02a1e, 0x00000000}},  //   nuri, dhle, thmu,
  { {0x645c0035, 0x98a5007f, 0x657c2beb, 0x00000000}},  //   iuri, lalė_, herh,
  { {0x645c0209, 0x6d43011c, 0x657c0073, 0x00000000}},  //   huri, bana, kerh,
  { {0x7bc00065, 0x69c10051, 0x657c008e, 0x00000000}},  //   shmu, ghle, jerh,
  { {0x6e20008d, 0x79880016, 0xad650014, 0x00000000}},  //   _humb, rddw, _ساله,
  { {0x645c2005, 0x6e20000b, 0x9b930025, 0x00000000}},  //   duri, _kumb, _للمت,
  { {0xdce8010a, 0x6e200020, 0x6617002d, 0x00000000}},  //   _padė, _jumb, _pixk,
  { {0xceb3052f, 0x645c19bd, 0x6e202bec, 0x00000000}},  //   דיש_, furi, _mumb,
  { {0x67d5102a, 0xb5fb002a, 0xa7fd014a, 0x00000000}},  //   _поку, ntái, ntık,
  { {0x6d4312d9, 0x98be01aa, 0x2b44012d, 0x00000000}},  //   zana, natč_, namc_,
  { {0x6e202bed, 0x6d430390, 0x657c0022, 0x00000000}},  // [8190] _numb, yana, berh,
  { {0x6d430543, 0x645c002b, 0x44312123, 0x00000000}},  //   xana, buri, ppz_,
  { {0x6d430ba5, 0x645c2bee, 0xdddb0091, 0x00000000}},  //   vana, curi, _pruž,
  { {0x6e200089, 0x6d432bef, 0x93c900a1, 0x00000000}},  //   _bumb, wana, _راجہ_,
  { {0x6d4305d7, 0xee380822, 0x44210dbe, 0x00000000}},  //   tana, дні_, _huh_,
  { {0x44212bf0, 0x0d84013a, 0x00000000, 0x00000000}},  //   _kuh_, клін,   ,
  { {0x6d431312, 0x69dd1819, 0x00000000, 0x00000000}},  //   rana, ésem,   ,
  { {0x6d430bc4, 0x65b0010f, 0x442101a3, 0x00000000}},  //   sana, _jähr, _muh_,
  { {0x6d43011c, 0x6e2000d0, 0x6b890207, 0x00000000}},  //   pana, _gumb, rdeg,
  { {0x645c0058, 0x442122d7, 0x6b892bf1, 0x00000000}},  //   yuri, _ouh_, sdeg,
  { {0x657c0343, 0x6d410089, 0x6e200cd3, 0x00000000}},  //   verh, _iela, _zumb,
  { {0x6d4100b5, 0xf0920476, 0x657c0007, 0x00000000}},  //   _hela, אנט_, werh,
  { {0x657c001f, 0x6d41020c, 0xe3c2005a, 0x00000000}},  //   terh, _kela, nlış_,
  { {0x645c0c0e, 0x9aa400b8, 0x6d41020c, 0x00000000}},  //   turi, _جمهو, _jela,
  { {0x6d41020c, 0x660300da, 0x39452bf2, 0x00000000}},  //   _mela, упра, mals_,
  { {0x6d41020c, 0x645c2b67, 0x44210091, 0x00000000}},  //   _lela, ruri, _duh_,
  { {0x2249178f, 0x02062bf3, 0x23600e0d, 0x00000000}},  // [81a0] gsak_, езан, rgij_,
  { {0x6d41010a, 0x645c1c87, 0xe8890011, 0x00000000}},  //   _nela, puri, _kẻ_,
  { {0x6e20020c, 0x65b0010f, 0xdddb0036, 0x00000000}},  //   _sumb, _fähr, _druż,
  { {0xa2cb02d2, 0xfe4602b0, 0x6e201158, 0x00000000}},  //   _सेक्, ендо, _pumb,
  { {0x3945001e, 0xe8890011, 0xc17400a1, 0x00000000}},  //   kals_, _lẻ_, _لگات,
  { {0x6d410390, 0x57ad01f5, 0x6da31023, 0x00000000}},  //   _cela, _चव्ह, лича,
  { {0x6d4101d9, 0x8d1a026c, 0x91e3007c, 0x00000000}},  //   _dela, _ہزار_, _соре,
  { {0x6e2004cb, 0xb5fb0051, 0x6d41006c, 0x00000000}},  //   _tumb, rtái, _eela,
  { {0xb5fb002a, 0x6d410047, 0x6e2000e7, 0x00000000}},  //   stái, _fela, _uumb,
  { {0xbe13031d, 0x7afd2bf4, 0x39450129, 0x00000000}},  //   _موقع, üsta, gals_,
  { {0x8157007b, 0x00000000, 0x00000000, 0x00000000}},  //   עסטע_,   ,   ,
  { {0xfa8800ad, 0x6d41022b, 0xb5fb0181, 0x00000000}},  //   _từ_, _zela, ntáv,
  { {0x394525e9, 0x42db0044, 0x44212bf5, 0x00000000}},  //   bals_, _দর্শ, _suh_,
  { {0x39452bf6, 0x442100b0, 0xc8f4005e, 0x00000000}},  //   cals_, _puh_, _излъ,
  { {0x62862128, 0xd90e00a2, 0x9f5f0048, 0x00000000}},  //   _asko, _دید_, _shuí_,
  { {0x2249002d, 0xdcf80107, 0x765d00e0, 0x00000000}},  //   tsak_, jevč, pusy,
  { {0xd2510688, 0x00000000, 0x00000000, 0x00000000}},  // [81b0] شنا_,   ,   ,
  { {0x65b0010f, 0x442104cb, 0x21f4010f, 0x00000000}},  //   _währ, _tuh_, währ_,
  { {0x6286022b, 0xe8890082, 0xd498007c, 0x00000000}},  //   _esko, _xẻ_, _зря_,
  { {0x6d41020c, 0x798a01aa, 0x3fcf0044, 0x00000000}},  //   _sela, _lafw, িক্ষ,
  { {0x6d41020c, 0xdb0b0065, 0x69dd0010, 0x00000000}},  //   _pela, _vogë, ések,
  { {0xdce8001e, 0x00000000, 0x00000000, 0x00000000}},  //   _gadī,   ,   ,
  { {0x6d41190b, 0x00000000, 0x00000000, 0x00000000}},  //   _vela,   ,   ,
  { {0xe889001d, 0x6d412bf7, 0x62862bf8, 0x00000000}},  //   _rẻ_, _wela, _ysko,
  { {0x3945041d, 0x6d410149, 0xe889001d, 0x00000000}},  //   tals_, _tela, _sẻ_,
  { {0x798a0016, 0x00000000, 0x00000000, 0x00000000}},  //   _cafw,   ,   ,
  { {0x394504bd, 0xb9020088, 0x39580048, 0x00000000}},  //   rals_, изьк, órsa_,
  { {0x39452bf9, 0xe889001d, 0xb90901f5, 0x00000000}},  //   sals_, _vẻ_, _यश_,
  { {0x39452bfa, 0xdb19000a, 0x00000000, 0x00000000}},  //   pals_, _emwò,   ,
  { {0xceb200b6, 0xeab00025, 0x798a0016, 0x00000000}},  //   סים_, _دعم_, _gafw,
  { {0xddc20089, 0xdce80089, 0x63af041a, 0x00000000}},  //   ntoš, _radī, _bocn,
  { {0x0876007b, 0x5eb70044, 0xfe210164, 0x00000000}},  //   _יעצט_, _আইনে, मदास_,
  { {0x6b8b0198, 0x63af016c, 0x61e200f4, 0x00000000}},  // [81c0] _magg, _docn, éolo,
  { {0x6b8b2008, 0x00da0380, 0xb65b00a3, 0x00000000}},  //   _lagg, وبات_, _קדיש,
  { {0xdce8001e, 0xb33b006b, 0x00000000, 0x00000000}},  //   _vadī, _poçt,   ,
  { {0x7053007a, 0x6b8b25e1, 0x2a6d002b, 0x00000000}},  //   شنها, _nagg, kteb_,
  { {0x62862bfb, 0xd33700a0, 0xb5fb0181, 0x00000000}},  //   _usko, _ברכה_, rtáv,
  { {0xb5fb004f, 0x8d63012b, 0xe6260082, 0x00000000}},  //   stáv, авље, _đôla_,
  { {0x6b8b0030, 0xb5fb0224, 0xefb200a6, 0x00000000}},  //   _bagg, ptáv, _پیشگ,
  { {0x6b8b0912, 0x09da0061, 0x61fe09b0, 0x00000000}},  //   _cagg, यच्य, llpl,
  { {0xd00f0054, 0x6b8b16a7, 0x798a01aa, 0x00000000}},  //   _ذلك_, _dagg, _pafw,
  { {0xb5fb0142, 0x00000000, 0x00000000, 0x00000000}},  //   ntát,   ,   ,
  { {0x2d9e0901, 0x6b8b0190, 0x2d8c014a, 0x00000000}},  //   _inte_, _fagg, _iade_,
  { {0x2d8c0073, 0x6b8b0912, 0xe8e00082, 0x00000000}},  //   _hade_, _gagg, _ngụy_,
  { {0xc9aa06e3, 0x2d8c16d0, 0xf77f2bfc, 0x00000000}},  //   _овде_, _kade_, reç_,
  { {0xea7700b6, 0xa4d50088, 0x7bc200b9, 0x00000000}},  //   _סגור_, гогі, _hlou,
  { {0x63af037e, 0x2d8c0038, 0x7bc200b9, 0x00000000}},  //   _pocn, _made_, _klou,
  { {0x2d8c2bfd, 0x61fe2586, 0xd40701ab, 0x00000000}},  //   _lade_, elpl, тяги,
  { {0x63af0107, 0xa344007e, 0x00000000, 0x00000000}},  // [81d0] _vocn, рэсл,   ,
  { {0x2d8c0091, 0x80be0044, 0x7bc200f6, 0x00000000}},  //   _nade_, ্পন্, _llou,
  { {0x44271305, 0xc9530097, 0x69dd0010, 0x00000000}},  //   _în_, שמע_, ései,
  { {0x2d9e0211, 0xb4c103d7, 0x44332bfe, 0x00000000}},  //   _ante_, ्छी_, _itx_,
  { {0x6b8b0207, 0x4ea7005e, 0x443302ee, 0x00000000}},  //   _ragg, ържа, _htx_,
  { {0xf2d200b6, 0x2d8c0375, 0x7bc206f0, 0x00000000}},  //   _פעם_, _cade_, _alou,
  { {0x6b8b0811, 0x2d8c0b5c, 0x7bc219ed, 0x00000000}},  //   _pagg, _dade_, _blou,
  { {0x2d9e0207, 0x44330009, 0x7bc200ab, 0x00000000}},  //   _ente_, _mtx_, _clou,
  { {0xb5fb2bff, 0xee8403c8, 0xddc20089, 0x00000000}},  //   ntás, _выхо, stoš,
  { {0xdcbb0265, 0x2d8c0263, 0x5fb90061, 0x00000000}},  //   _още_, _gade_, _आवडल,
  { {0x6b8b0292, 0x2dd80054, 0xf7460088, 0x00000000}},  //   _tagg, _شبكة_, лено,
  { {0xf7720355, 0x62840696, 0x7bc2032c, 0x00000000}},  //   حاد_, ywio, _glou,
  { {0x63a00129, 0xb5fb0010, 0x2d8c009d, 0x00000000}},  //   _òmni, jtás, _yade_,
  { {0x88c5035b, 0x7bc2037e, 0xd9450545, 0x00000000}},  //   _متعل, _zlou, _секи,
  { {0x4376085f, 0x98790049, 0xa3ea005e, 0x00000000}},  //   луат, _טאַט, едва_,
  { {0xa7662c00, 0x78fa0049, 0xb5fb2c01, 0x00000000}},  //   _скид, _אפצו, tuác,
  { {0x44330843, 0x4ebe0044, 0x00000000, 0x00000000}},  // [81e0] _etx_, _অশ্ল,   ,
  { {0x6d45000c, 0x10a607ab, 0x7981005b, 0x00000000}},  //   ðhal, лизн, nelw,
  { {0x44332a53, 0x7e7b027b, 0xb5fb029d, 0x00000000}},  //   _gtx_, _apup, rtát,
  { {0xb5fb2c02, 0xf1bf2c03, 0x2d8c2c04, 0x00000000}},  //   gráf, _stát_, _sade_,
  { {0xdcf80089, 0x644e00f8, 0x661e0085, 0x00000000}},  //   devā, lsbi, _kipk,
  { {0x7bc200b9, 0x98be001a, 0x2907041a, 0x00000000}},  //   _slou, nată_, _ozna_,
  { {0x6da306e3, 0x644e02e7, 0x7981005b, 0x00000000}},  //   сија, nsbi, delw,
  { {0xb5fb2b8b, 0xba5401fc, 0xaa5429f8, 0x00000000}},  //   ntár, авиј, авиш,
  { {0x7dc6000c, 0x79810678, 0x00000000, 0x00000000}},  //   _aðse, felw,   ,
  { {0x7981018e, 0x98be0035, 0x644e2c05, 0x00000000}},  //   gelw, jată_, ksbi,
  { {0x291803af, 0x98be001a, 0xd917007c, 0x00000000}},  //   ära_, dată_, лью_,
  { {0xa6db000c, 0x81ea0044, 0x44330026, 0x00000000}},  //   laði, মতি_, _rtx_,
  { {0x44332635, 0x645c002d, 0xaa5700a1, 0x00000000}},  //   _stx_, erri, _ملنا_,
  { {0x6d4a00f0, 0xb5fb0181, 0x98be001a, 0x00000000}},  //   nafa, etár, gată_,
  { {0xb4c1013d, 0x644e00f8, 0xd5b80b52, 0x00000000}},  //   ्छे_, gsbi, уся_,
  { {0xa3cf013d, 0x6d4a15df, 0x3cfe0082, 0x00000000}},  //   वों_, hafa, _mytv_,
  { {0x6d4a006b, 0x5b7b0049, 0xf7700439, 0x00000000}},  // [81f0] kafa, ערמא, _راي_,
  { {0x645a0df9, 0x6d4a2c06, 0xb5fb0047, 0x00000000}},  //   átic, jafa, rtás,
  { {0x44382c07, 0xb5fb00dc, 0xdb0906ec, 0x00000000}},  //   cpr_, tráf, skeø,
  { {0x83ab007c, 0xb5fb0f08, 0x645a016e, 0x00000000}},  //   _чтоб_, ctár, štic,
  { {0x69da022b, 0x6d4a0020, 0x63ad199a, 0x00000000}},  //   kite, fafa, mjan,
  { {0x63ad0004, 0x6d4a00d4, 0xa6db01e5, 0x00000000}},  //   ljan, gafa, gaði,
  { {0xa2d901f5, 0x63ad0006, 0xa7fd005a, 0x00000000}},  //   _नेत्, ojan, ntıs,
  { {0x63ad0149, 0x98be001a, 0x79810016, 0x00000000}},  //   njan, zată_, welw,
  { {0x69da00f4, 0x6d4a0c99, 0x798104e4, 0x00000000}},  //   fite, bafa, telw,
  { {0x69da002d, 0x69c8002a, 0x2b46192a, 0x00000000}},  //   gite, ghde, _eeoc_,
  { {0x63ad000c, 0x98be001a, 0x0dc8007c, 0x00000000}},  //   kjan, vată_, _сути_,
  { {0xc60001f5, 0xb5fb2c08, 0xd62a003b, 0x00000000}},  //   ोग्य_, hrád, коме_,
  { {0x63ad012b, 0x69da1cc2, 0x98be001a, 0x00000000}},  //   djan, bite, tată_,
  { {0x69c8010f, 0x7bc900f4, 0x7d1c0051, 0x00000000}},  //   chde, lheu, _úrsc,
  { {0x98be001a, 0x2a79002b, 0x645c2c09, 0x00000000}},  //   rată_, ħsbu_, urri,
  { {0xdb0b253d, 0x7bc900f4, 0x3947103f, 0x00000000}},  //   _logí, nheu, _hens_,
  { {0x644e0210, 0x661e02db, 0x44382c0a, 0x00000000}},  // [8200] ssbi, _tipk, spr_,
  { {0x39470030, 0x644e05fe, 0xb5fb0010, 0x00000000}},  //   _jens_, psbi, stár,
  { {0xa3ea007e, 0x39470aba, 0x0577009b, 0x00000000}},  //   _адна_, _mens_, _דגים_,
  { {0x69da04f4, 0x6d4a0020, 0x76442c0b, 0x00000000}},  //   zite, wafa, _kwiy,
  { {0x44440062, 0xe8e2007d, 0x6d4a0020, 0x00000000}},  //   _hw_, _पश्च, tafa,
  { {0x44440161, 0x394704bd, 0x32432c0c, 0x00000000}},  //   _kw_, _nens_, _ферг,
  { {0x6d4a1aed, 0xa6db000c, 0x7e9600a1, 0x00000000}},  //   rafa, raði, انڈر_,
  { {0x69da2c0d, 0x6d4a0066, 0x44441ff1, 0x00000000}},  //   wite, safa, _mw_,
  { {0x69da2c0e, 0x4444211e, 0x39470181, 0x00000000}},  //   tite, _lw_, _bens_,
  { {0x444402c2, 0x63ad002b, 0x49730259, 0x00000000}},  //   _ow_, zjan, ольс,
  { {0x3b8600ed, 0x3947068f, 0xf77f1052, 0x00000000}},  //   _влег, _dens_, ença_,
  { {0x3947015c, 0x6d48022b, 0x6f000093, 0x00000000}},  //   _eens_, _heda, _kymc,
  { {0x44442211, 0x6d4805cd, 0xd6d80f4e, 0x00000000}},  //   _aw_, _keda, атр_,
  { {0x6d480119, 0x4444000b, 0x3a7b01f8, 0x00000000}},  //   _jeda, _bw_, _סטוד,
  { {0xf77f153d, 0x63ad2bfa, 0x58d30184, 0x00000000}},  //   ança_, tjan, _мошт,
  { {0x4444183c, 0x394c0030, 0x6d480073, 0x00000000}},  //   _dw_, lads_, _leda,
  { {0xcb130049, 0xb5fb00fa, 0x00000000, 0x00000000}},  // [8210] ַלע_, stáq,   ,
  { {0x6f090046, 0x394c00f8, 0x63ad00b4, 0x00000000}},  //   _rzec, nads_, sjan,
  { {0x44440390, 0x63ad002b, 0x2a640045, 0x00000000}},  //   _gw_, pjan, humb_,
  { {0xb21b0190, 0x749a0049, 0x00000000, 0x00000000}},  //   _spæd, _עירפ,   ,
  { {0x6d4802ae, 0x7c280006, 0x8db5008b, 0x00000000}},  //   _beda, _audr, йскі,
  { {0x44440bc4, 0xdef8008b, 0x7c28007f, 0x00000000}},  //   _yw_, шых_, _budr,
  { {0xa6db009f, 0x200d01f3, 0x44441ad1, 0x00000000}},  //   maðu, _thei_, _xw_,
  { {0x394700f4, 0x23691097, 0xa6db000c, 0x00000000}},  //   _sens_, ngaj_, laðu,
  { {0x7bc90112, 0x6f09016c, 0x8f6a00a1, 0x00000000}},  //   rheu, _uzec, _حلقے_,
  { {0x6d481225, 0xa6db000c, 0x76440009, 0x00000000}},  //   _geda, naðu, _rwiy,
  { {0xa3e80201, 0x7c280089, 0x5dfa0049, 0x00000000}},  //   _बदल_, _gudr, _עפענ,
  { {0x44442c0f, 0x394700c7, 0x907a0097, 0x00000000}},  //   _rw_, _wens_, נטרי,
  { {0x39470129, 0x44442c10, 0xa7fd014a, 0x00000000}},  //   _tens_, _sw_, ttır,
  { {0x6e212c11, 0x6e290211, 0x44440036, 0x00000000}},  //   _jilb, _mueb, _pw_,
  { {0xdb0b00c4, 0x6e211796, 0x69c10168, 0x00000000}},  //   _fogã, _milb, mkle,
  { {0xf1bf001d, 0x69c101d6, 0x6e210606, 0x00000000}},  //   _quán_, lkle, _lilb,
  { {0xa7fd014a, 0x6e291521, 0x98be0a62, 0x00000000}},  // [8220] ptır, _nueb, ratą_,
  { {0x69c1011f, 0x01d70054, 0x44440061, 0x00000000}},  //   nkle, موقع_, _tw_,
  { {0x44440662, 0x459b0049, 0x7d0101d6, 0x00000000}},  //   _uw_, _עסטע, _nyls,
  { {0x6d482c12, 0x68fc01a2, 0x6e2122f0, 0x00000000}},  //   _seda, ürdi, _ailb,
  { {0x6e21022b, 0x7c280089, 0x09b90061, 0x00000000}},  //   _bilb, _sudr, ेसाठ,
  { {0x226500b9, 0x44220723, 0x171b0049, 0x00000000}},  //   ňský_, _hik_, אונע,
  { {0x6d48006c, 0x44222c13, 0x394c0089, 0x00000000}},  //   _veda, _kik_, vads_,
  { {0x5a340069, 0x6d482c14, 0x44222c15, 0x00000000}},  //   онит, _weda, _jik_,
  { {0x6d482c16, 0x44221204, 0x394c0af1, 0x00000000}},  //   _teda, _mik_, tads_,
  { {0x2a640c39, 0x69c10c46, 0x6e210335, 0x00000000}},  //   rumb_, gkle, _gilb,
  { {0x394c0d33, 0xf4c30044, 0x7c2800f6, 0x00000000}},  //   rads_, _ঈশ্ব, _uudr,
  { {0x44222c17, 0x69dd00f4, 0x6e21238e, 0x00000000}},  //   _nik_, éser, _zilb,
  { {0x394c0061, 0x95cb15c4, 0x66c808d6, 0x00000000}},  //   pads_, гува_, бург_,
  { {0xf1bf0211, 0x44222c18, 0x69c12c19, 0x00000000}},  //   _cuál_, _aik_, ckle,
  { {0x645a06a6, 0x44220082, 0xdce30089, 0x00000000}},  //   štin, _bik_, venī,
  { {0x44220ada, 0xdc370049, 0x00000000, 0x00000000}},  //   _cik_, מאלט_,   ,
  { {0x442201d5, 0xf8b000a1, 0x7f4906c0, 0x00000000}},  // [8230] _dik_, _رکھ_, _reeq,
  { {0x7c2216cc, 0xe4e70245, 0x44222118, 0x00000000}},  //   _lior, _гімн, _eik_,
  { {0x44220018, 0x6e290668, 0x00000000, 0x00000000}},  //   _fik_, _sueb,   ,
  { {0xdb0b002a, 0x6e290219, 0x44220018, 0x00000000}},  //   _logá, _pueb, _gik_,
  { {0x80da0044, 0x69c10030, 0x7ae416d0, 0x00000000}},  //   _বুদ্, ykle, _žitn,
  { {0x628f0066, 0xb5fb01ca, 0x442220c9, 0x00000000}},  //   _isco, xuál, _zik_,
  { {0x7c220036, 0x6e2101e5, 0xb21b0146, 0x00000000}},  //   _bior, _vilb, _dsæt,
  { {0x7c220fff, 0xa91c0027, 0x23c90309, 0x00000000}},  //   _cior, teľn, रसिद,
  { {0x6e212165, 0x3e72000d, 0xb5fb0d7f, 0x00000000}},  //   _tilb, cât_, tuál,
  { {0x80be0055, 0x8d7702fd, 0xe9d901fc, 0x00000000}},  //   ্পর্, _دارا, рко_,
  { {0x2d872706, 0x7c220207, 0x57ea013b, 0x00000000}},  //   mene_, _fior, идом_,
  { {0x7c220198, 0x2d870292, 0xdd0e0676, 0x00000000}},  //   _gior, lene_, lışm,
  { {0x2d870007, 0xd62a0194, 0xdb0b0010, 0x00000000}},  //   oene_, роге_, _fogá,
  { {0x2d8706ec, 0xdd0e005d, 0x992b007c, 0x00000000}},  //   nene_, nışm, _сюда_,
  { {0x628f0207, 0x44222c1a, 0x26c42c1b, 0x00000000}},  //   _asco, _pik_, šmo_,
  { {0xb5fb0344, 0x2d872c1c, 0x44220023, 0x00000000}},  //   trác, hene_, _qik_,
  { {0x2d872c1d, 0x442205ad, 0xb5fb0027, 0x00000000}},  // [8240] kene_, _vik_, urác,
  { {0x2d87073a, 0xe1660025, 0x93c70082, 0x00000000}},  //   jene_, تدري, _hoặ,
  { {0x44222c1e, 0x2d870292, 0x628f1d70, 0x00000000}},  //   _tik_, dene_, _esco,
  { {0x443a0036, 0xb5fb0161, 0x987a0049, 0x00000000}},  //   _itp_, prác, ירעק,
  { {0x7c221a48, 0x2d87010f, 0xfe6f01fa, 0x00000000}},  //   _rior, fene_, ندو_,
  { {0x443a023a, 0x3e72001a, 0x569b0049, 0x00000000}},  //   _ktp_, rât_, יינצ,
  { {0x7c2219c1, 0x00000000, 0x00000000, 0x00000000}},  //   _pior,   ,   ,
  { {0x443a2c1f, 0xe3bf004a, 0x00000000, 0x00000000}},  //   _mtp_, _tiñe_,   ,
  { {0xf413019b, 0xa91c0027, 0x2d871f88, 0x00000000}},  //   ופה_, teľo, bene_,
  { {0x20060065, 0x443a1db2, 0x00000000, 0x00000000}},  //   lloi_, _otp_,   ,
  { {0x09b70054, 0x645a2c20, 0x28f80245, 0x00000000}},  //   تطيع_, átil, сень_,
  { {0xc6a700e3, 0x7c3a002b, 0x61b701f5, 0x00000000}},  //   орги, _ittr, _आक्ष,
  { {0xf98f0167, 0x645a0091, 0x24810085, 0x00000000}},  //   ربی_, štil, _sphm_,
  { {0x63a604ce, 0x443a2c21, 0x00000000, 0x00000000}},  //   _ankn, _btp_,   ,
  { {0xd4980113, 0x443a0035, 0x66720014, 0x00000000}},  //   орт_, _ctp_, وگیر,
  { {0xd6db005e, 0x443a0095, 0x7988047a, 0x00000000}},  //   _вто_, _dtp_, ledw,
  { {0xa6db000c, 0x6d5a05d2, 0x2d872c22, 0x00000000}},  // [8250] raðs, _odta, yene_,
  { {0x7e622c23, 0xed880006, 0x79880544, 0x00000000}},  //   drop, šųjų_, nedw,
  { {0x2d872c24, 0x443a0784, 0xf8ca013d, 0x00000000}},  //   vene_, _gtp_, ानिय,
  { {0x6d5a2c25, 0xf8b30097, 0x2d872c26, 0x00000000}},  //   _adta, ושע_, wene_,
  { {0x2d870292, 0x7c3a051b, 0x2ba90061, 0x00000000}},  //   tene_, _attr, कासा,
  { {0xb2ba009b, 0xa2ba009b, 0x00000000, 0x00000000}},  //   _המשר, _המשט,   ,
  { {0x2d870209, 0x23bf0316, 0xdd0e005a, 0x00000000}},  //   rene_, _एकाद, rışm,
  { {0x5ba9102a, 0x2d870056, 0x69ca064e, 0x00000000}},  //   ским_, sene_, _alfe,
  { {0xe9d90d99, 0x2d871a3d, 0x7e6200ab, 0x00000000}},  //   йки_, pene_, crop,
  { {0x6ca709ae, 0x5dd503ab, 0x64550010, 0x00000000}},  //   _мреж, _عقائ, kszi,
  { {0x6d4300ab, 0x98a50069, 0x2903000c, 0x00000000}},  //   mbna, чине, æja_,
  { {0x69ca2c27, 0xe29f000c, 0x443a00c4, 0x00000000}},  //   _elfe, _orð_, _rtp_,
  { {0xb90203d7, 0x62980089, 0x443a009d, 0x00000000}},  //   _ने_, āvok, _stp_,
  { {0xceb200b6, 0x7c3a0039, 0x6b8900b5, 0x00000000}},  //   עים_, _yttr, leeg,
  { {0x64552c28, 0x64a3007e, 0xa50a00d7, 0x00000000}},  //   gszi, нара, сева_,
  { {0xe8d6009b, 0x78bc2c29, 0x3cde0061, 0x00000000}},  //   _מוצר_, ärve, _कइसे_,
  { {0x27370011, 0x443a0022, 0x6e3b0045, 0x00000000}},  // [8260] _ủng_, _wtp_, _ntub,
  { {0x7e620059, 0x443a0145, 0x00000000, 0x00000000}},  //   vrop, _ttp_,   ,
  { {0x6e3b011c, 0x55bb009b, 0x7bcb014a, 0x00000000}},  //   _atub, _המיו, _olgu,
  { {0x63a600ab, 0xd7af0061, 0x798800b4, 0x00000000}},  //   _unkn, टायच, zedw,
  { {0xdfcf057d, 0x539b009b, 0x00000000, 0x00000000}},  //   دين_, _היכו,   ,
  { {0x7bcb00d6, 0xb5fb2c2a, 0xf2d30049, 0x00000000}},  //   _algu, hrán, _טער_,
  { {0x2006028c, 0xb5fb009f, 0xa024010f, 0x00000000}},  //   ploi_, krán, größ,
  { {0x79880016, 0x00000000, 0x00000000, 0x00000000}},  //   wedw,   ,   ,
  { {0xdcfa0089, 0x224001aa, 0x800b00a1, 0x00000000}},  //   _patē, npik_, _طرفہ_,
  { {0x6d5a0030, 0xe3bf0288, 0x00000000, 0x00000000}},  //   _udta, _miña_,   ,
  { {0xe3bf027b, 0x7c3a01c9, 0x79880016, 0x00000000}},  //   _liña_, _uttr, redw,
  { {0x61fe01ee, 0x79880173, 0x224000e0, 0x00000000}},  //   hopl, sedw, kpik_,
  { {0x2ba90183, 0xe9a60256, 0xe3bf0211, 0x00000000}},  //   कारा, _надп, _niña_,
  { {0x64550047, 0xb5fb0048, 0x00000000, 0x00000000}},  //   tszi, arán,   ,
  { {0xe97b009b, 0xb5fb01ca, 0x61fe0161, 0x00000000}},  //   _הנוש, brán, dopl,
  { {0xb5fb10fa, 0x64552c2b, 0xd6d10137, 0x00000000}},  //   ntáz, rszi, _لقب_,
  { {0x64550010, 0x61fe006c, 0xc1b902be, 0x00000000}},  // [8270] sszi, fopl, олах_,
  { {0x2902006b, 0x6b890032, 0xe3bf0288, 0x00000000}},  //   əkar_, zeeg, _diña_,
  { {0x6e3b07ea, 0x25d80049, 0x394e0019, 0x00000000}},  //   _stub, _מוזן_, _mefs_,
  { {0xe29f000c, 0x00000000, 0x00000000, 0x00000000}},  //   _eyða_,   ,   ,
  { {0x6ff50046, 0x98be00b9, 0xda0c0061, 0x00000000}},  //   jące, tatě_, हतात_,
  { {0x6b890112, 0xbea2003b, 0xdb07009d, 0x00000000}},  //   weeg, ташк, _éléc,
  { {0x6b89006c, 0x2ba90204, 0x26c20036, 0x00000000}},  //   teeg, काला, zyko_,
  { {0x2fc6037e, 0x5f940256, 0xcbfd0044, 0x00000000}},  //   ckog_, _пист, ুদ্ধ_,
  { {0x60180057, 0x8d870ae0, 0xc334009b, 0x00000000}},  //   _хотя_, _нужд, עוץ_,
  { {0x26c20006, 0x00000000, 0x00000000, 0x00000000}},  //   vyko_,   ,   ,
  { {0x8d7400a6, 0x378a0242, 0x69a10061, 0x00000000}},  //   _سالا, обно_, _कोणी,
  { {0x66e6007e, 0x645a007f, 0x2ba90061, 0x00000000}},  //   дома, štik, काळा,
  { {0xb5fb0211, 0xab0b0014, 0x00000000, 0x00000000}},  //   rrán, _اتاق_,   ,
  { {0xb21b0f4b, 0xe3bf004a, 0x2611006e, 0x00000000}},  //   _spæn, _riña_, _दीदी_,
  { {0x2fcd2c2c, 0x00000000, 0x00000000, 0x00000000}},  //   _oleg_,   ,   ,
  { {0xe3bf008e, 0xf7720025, 0x00000000, 0x00000000}},  //   _piña_, _شاب_,   ,
  { {0x61fe016e, 0x42260364, 0x22590093, 0x00000000}},  // [8280] topl, ддав, _cvsk_,
  { {0xe3bf008e, 0x2fcd0035, 0x3cde0061, 0x00000000}},  //   _viña_, _aleg_, _कइले_,
  { {0x2fc60091, 0xc059007e, 0x2fcd2807, 0x00000000}},  //   tkog_, зіі_, _bleg_,
  { {0xe3bf027b, 0x4f0a05f6, 0x61fe0b38, 0x00000000}},  //   _tiña_, онен_, sopl,
  { {0xa2480014, 0x61fe0253, 0xa91c0142, 0x00000000}},  //   _ریال_, popl, teľk,
  { {0x2fc60091, 0x7d1c000c, 0xddc22c2d, 0x00000000}},  //   skog_, _úrsk, stož,
  { {0x6da306e3, 0xfba90061, 0x394e01cb, 0x00000000}},  //   тија, कांम, _refs_,
  { {0xcfaa01b7, 0xeb97003b, 0x27e00058, 0x00000000}},  //   _باسم_, дић_, _nmin_,
  { {0x298a0088, 0xb5fb004a, 0x2907019a, 0x00000000}},  //   осно_, rtáz, _ayna_,
  { {0x27e0006a, 0x29070007, 0xb5fb13a5, 0x00000000}},  //   _amin_, _byna_, stáz,
  { {0xf1bf0011, 0x00000000, 0x00000000, 0x00000000}},  //   _quái_,   ,   ,
  { {0x628600c7, 0x29070016, 0x5ba50088, 0x00000000}},  //   _opko, _dyna_, _пріз,
  { {0xbc1b0049, 0xa7fd0477, 0xb5fb0327, 0x00000000}},  //   _וואש, brın, brál,
  { {0x27e0005a, 0x34952c2e, 0x20040022, 0x00000000}},  //   _emin_, нагр, _lkmi_,
  { {0xe4e40088, 0x62860089, 0x4ce00044, 0x00000000}},  //   вітн, _apko, _পুতু,
  { {0xddc900b9, 0x6aa20de5, 0x00000000, 0x00000000}},  //   _dveř, _krof,   ,
  { {0x5215017f, 0x6b8202bf, 0xe0d00014, 0x00000000}},  // [8290] едат, _mbog, یزم_,
  { {0x2fcd0007, 0xdddb0091, 0x91e4003b, 0x00000000}},  //   _sleg_, _opuš, вође,
  { {0x3cde001c, 0x35f80025, 0x6b820295, 0x00000000}},  //   _केले_, _تريد_, _obog,
  { {0x764d0ed7, 0x799801aa, 0x2ef500ec, 0x00000000}},  //   _kway, _lavw, нзер,
  { {0x733a0049, 0x433a0104, 0xddc900b9, 0x00000000}},  //   _מערס, _מערב, _zveř,
  { {0x764d0263, 0x6b82083b, 0x72050025, 0x00000000}},  //   _mway, _abog, _أوسم,
  { {0x63bd2c2f, 0x764d01aa, 0x6aa200f6, 0x00000000}},  //   _kosn, _lway, _arof,
  { {0x6aa20016, 0x61e5163b, 0x672d008a, 0x00000000}},  //   _brof, lihl, _ngaj,
  { {0xb5fb0047, 0xba250867, 0x6aa22c30, 0x00000000}},  //   trál, ндик, _crof,
  { {0x63bd0d3e, 0x6e280066, 0x9c870025, 0x00000000}},  //   _losn, _gidb, _يشاه,
  { {0xe3bf0211, 0x764d0058, 0x5eb70044, 0x00000000}},  //   _niño_, _away, _আইটে,
  { {0x63bd04c8, 0x78bc2c31, 0x764d2c32, 0x00000000}},  //   _nosn, ärva, _bway,
  { {0x0aeb007a, 0x6aa2003b, 0xd90f00a1, 0x00000000}},  //   _براي_, _grof, دیں_,
  { {0x69c80039, 0x764d0173, 0x7bc920d9, 0x00000000}},  //   ckde, _dway, lkeu,
  { {0x63bd2c33, 0x69ac0316, 0x00000000, 0x00000000}},  //   _bosn, जारी,   ,
  { {0x63bd0051, 0xdb1901aa, 0x764d0173, 0x00000000}},  //   _cosn, _powè, _fway,
  { {0x7bc900b0, 0x63bd007f, 0x764d1bcb, 0x00000000}},  // [82a0] ikeu, _dosn, _gway,
  { {0x4207003b, 0x6b990544, 0x00000000, 0x00000000}},  //   енуо_, _lawg,   ,
  { {0x7bc900b0, 0x7173067a, 0x940a005c, 0x00000000}},  //   kkeu, اهما, _необ_,
  { {0x9f5f0082, 0x543b0049, 0x6b990066, 0x00000000}},  //   _thuý_, _מעטא, _nawg,
  { {0xdddb091d, 0xbea3008b, 0xfeb70014, 0x00000000}},  //   _spuš, лацк, فاوت_,
  { {0x6aa20023, 0x00000000, 0x00000000, 0x00000000}},  //   _rrof,   ,   ,
  { {0x6f0900d9, 0x00000000, 0x00000000, 0x00000000}},  //   _eyec,   ,   ,
  { {0xe8df0011, 0x6b9b2c34, 0xdb0b00fa, 0x00000000}},  //   _chửi_, gdug, _ingê,
  { {0x6e282c35, 0x60e00006, 0x7d0801c3, 0x00000000}},  //   _tidb, žymė, _wyds,
  { {0x7d080007, 0x764d00de, 0xf77f00fa, 0x00000000}},  //   _tyds, _rway, diça_,
  { {0x764d2c36, 0x69c800d9, 0xe0be0044, 0x00000000}},  //   _sway, rkde, _আধুন,
  { {0x6b820450, 0x2d9c0010, 0x2d8e008e, 0x00000000}},  //   _ubog, ldve_, lefe_,
  { {0xcf93007b, 0x63bd2c37, 0xdb090065, 0x00000000}},  //   נטש_, _rosn, vjeç,
  { {0x764d01aa, 0x63bd0036, 0x5b130088, 0x00000000}},  //   _vway, _sosn, _сміт,
  { {0x63bd0059, 0xc953034e, 0x00000000, 0x00000000}},  //   _posn, _עמק_,   ,
  { {0xe3bf027b, 0x764d0202, 0x00000000, 0x00000000}},  //   _viño_, _tway,   ,
  { {0xe167003b, 0x32010062, 0x8c1b009b, 0x00000000}},  // [82b0] еђен, tohy_, לולי,
  { {0x8cb1013d, 0x00000000, 0x00000000, 0x00000000}},  //   _अपलो,   ,   ,
  { {0xc953007b, 0x61e503fb, 0x63bd0048, 0x00000000}},  //   רמע_, rihl, _tosn,
  { {0x60c500b0, 0x00000000, 0x00000000, 0x00000000}},  //   ryhm,   ,   ,
  { {0xee380106, 0xd35600b3, 0x4433002b, 0x00000000}},  //   ені_, _שישי_, _hux_,
  { {0x442b2c38, 0x1d090216, 0x7bc900b5, 0x00000000}},  //   _hic_, мели_, wkeu,
  { {0xace800a1, 0x645a0c1d, 0x00000000, 0x00000000}},  //   ٹرول_, štiv,   ,
  { {0x44330066, 0xddc20006, 0x442b0093, 0x00000000}},  //   _mux_, ruoš, _jic_,
  { {0x442b094e, 0x44330f04, 0x7bc9178a, 0x00000000}},  //   _mic_, _lux_, rkeu,
  { {0x3f8f000c, 0x442b2c39, 0xddc20006, 0x00000000}},  //   legu_, _lic_, puoš,
  { {0x99910010, 0x442b2c3a, 0xc212009b, 0x00000000}},  //   öző_, _oic_, שהי_,
  { {0x442b2a89, 0xf77201fa, 0x3f8f018e, 0x00000000}},  //   _nic_, جاد_, negu_,
  { {0x4433028c, 0x00000000, 0x00000000, 0x00000000}},  //   _aux_,   ,   ,
  { {0x7d04014a, 0x442b2c3b, 0xdce10279, 0x00000000}},  //   şise, _aic_, _halı,
  { {0xdce1011f, 0x6018008e, 0x3f8f002d, 0x00000000}},  //   _kalı, líme, kegu_,
  { {0x442b19dd, 0x3f8f016e, 0x739900ed, 0x00000000}},  //   _cic_, jegu_, нтус_,
  { {0x442b0919, 0x443300f4, 0xa2060242, 0x00000000}},  // [82c0] _dic_, _eux_, впад,
  { {0xb1430902, 0x06570097, 0x7c2b00d4, 0x00000000}},  //   инул, _שייך_, _ligr,
  { {0xe0d20025, 0x27f702fd, 0xd6a900a6, 0x00000000}},  //   جزء_, _سفید_, _قدیم_,
  { {0x2d8500ab, 0x6e46007e, 0xddce0036, 0x00000000}},  //   _able_, ведз, żdża,
  { {0xc3200044, 0x645c037f, 0x7dd400d4, 0x00000000}},  //   _ফ্রি_, lsri, _làse,
  { {0x44202266, 0x6143008b, 0x442b001a, 0x00000000}},  //   lmi_, _вера, _zic_,
  { {0xdce1047f, 0x7c2b00e0, 0x2d8e0173, 0x00000000}},  //   _balı, _bigr, refe_,
  { {0x44200607, 0xd9ca006e, 0x7c2b00d4, 0x00000000}},  //   nmi_, िस्ट, _cigr,
  { {0xde7700a1, 0x6018008e, 0xdce1005a, 0x00000000}},  //   _لینڈ_, gíme, _dalı,
  { {0x98b800ed, 0x683e0089, 0x7c2b0544, 0x00000000}},  //   елот_, _līde, _eigr,
  { {0x6d581254, 0x4ce00055, 0x44200027, 0x00000000}},  //   mava, _পুরু, kmi_,
  { {0x6d58006c, 0x44202325, 0xbb460741, 0x00000000}},  //   lava, jmi_, _редк,
  { {0x442b00d4, 0xb5fb0047, 0x29020046, 0x00000000}},  //   _ric_, nság, łka_,
  { {0x442b0065, 0x442001c2, 0x7dcf01e3, 0x00000000}},  //   _sic_, emi_, _løsn,
  { {0x442b2c3c, 0x645c0039, 0xdb0b02d0, 0x00000000}},  //   _pic_, gsri, _angè,
  { {0xa77503f3, 0xa3dd03d7, 0x6d58006c, 0x00000000}},  //   _слич, थों_, hava,
  { {0x6d58021e, 0x442b0129, 0xb5fb0051, 0x00000000}},  // [82d0] kava, _vic_, hrái,
  { {0x6d580119, 0x442b0b3d, 0x443300f8, 0x00000000}},  //   java, _wic_, _tux_,
  { {0x442b2ac3, 0x3c380010, 0x3f8f010e, 0x00000000}},  //   _tic_, _név_, tegu_,
  { {0x442b00d4, 0xb5fb0181, 0x44201f86, 0x00000000}},  //   _uic_, cuár, cmi_,
  { {0x645a049c, 0x765d0056, 0x35a8006e, 0x00000000}},  //   štit, nssy, _छोड़,
  { {0x6d58006c, 0x6575002b, 0xa3c30164, 0x00000000}},  //   gava, ngzh, ्सव_,
  { {0xdb0b00f4, 0x7c2b0197, 0x2c0f0061, 0x00000000}},  //   _ingé, _pigr, ातलं_,
  { {0xdce1006b, 0x7c3e0428, 0x00000000, 0x00000000}},  //   _qalı, ípra,   ,
  { {0x6d58016e, 0x7c2b2014, 0xb5fb0048, 0x00000000}},  //   bava, _vigr, arái,
  { {0x6d58016c, 0x4420008d, 0x3c3800f4, 0x00000000}},  //   cava, zmi_, _fév_,
  { {0x44201191, 0xd7af0061, 0xdce1006b, 0x00000000}},  //   ymi_, टांच, _talı,
  { {0x1b050044, 0xbbeb0025, 0x00000000, 0x00000000}},  //   শেষে_, _غرام_,   ,
  { {0xff7a0049, 0xaba80439, 0x645c00e5, 0x00000000}},  //   עטשמ, _جهنم_, wsri,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44202c3d, 0x2a7f006c, 0xb5fb2c3e, 0x00000000}},  //   tmi_, ltub_, tuár,
  { {0x6d581f7f, 0x4420006c, 0x80a70061, 0x00000000}},  //   zava, umi_, घटने,
  { {0xdcfa0089, 0xe8060061, 0x2e3901aa, 0x00000000}},  // [82e0] _patī, रवठा_, _nèf_,
  { {0x644100d6, 0x6d5800fa, 0xddd40027, 0x00000000}},  //   ílic, xava, _ťažk,
  { {0x6d58006c, 0x2a7f006c, 0x8fa6003b, 0x00000000}},  //   vava, htub_, лаже,
  { {0x44440a8a, 0xb4c20316, 0x2a7f2c3f, 0x00000000}},  //   _it_, ्नी_, ktub_,
  { {0x6d580004, 0x44440263, 0xa3c3006e, 0x00000000}},  //   tava, _ht_, ्सर_,
  { {0x444424e7, 0x27030011, 0xb5fb1a43, 0x00000000}},  //   _kt_, ổng_, trái,
  { {0x6d5806a6, 0x44442c40, 0xb5fb0047, 0x00000000}},  //   rava, _jt_, sság,
  { {0x7dc6009f, 0xb5fb0051, 0x7dd400d4, 0x00000000}},  //   _aðst, rrái, _bàsc,
  { {0x44440736, 0x0aea0054, 0x76440009, 0x00000000}},  //   _lt_, عربي_, _ntiy,
  { {0x44440010, 0xf27b0049, 0xc27b01ce, 0x00000000}},  //   _ot_, עריש, עריי,
  { {0x4444143d, 0x26e20044, 0x7d05010f, 0x00000000}},  //   _nt_, _গুলো_, ühst,
  { {0x200607a5, 0x765d0239, 0x2d9e00ab, 0x00000000}},  //   nooi_, tssy, _hate_,
  { {0x44442c41, 0xa91c0027, 0x63af0085, 0x00000000}},  //   _at_, teľs, _rncn,
  { {0x0cb60055, 0xb5fb0428, 0x765d1fbc, 0x00000000}},  //   জনীত, hráv, rssy,
  { {0x94d40088, 0xa4d40088, 0x2d9e2c42, 0x00000000}},  //   борц, борі, _mate_,
  { {0x44442c43, 0x2d9e00ab, 0x00000000, 0x00000000}},  //   _dt_, _late_,   ,
  { {0x44440a8d, 0xe5e502fd, 0xfc3f0161, 0x00000000}},  // [82f0] _et_, _نزدی, _čím_,
  { {0x44440047, 0x2d9e0065, 0x00000000, 0x00000000}},  //   _ft_, _nate_,   ,
  { {0x92b50044, 0xa0a7007c, 0x200601c3, 0x00000000}},  //   জনে_, ышал, fooi_,
  { {0x20060007, 0x66070b18, 0xb4d1006e, 0x00000000}},  //   gooi_, lojk, वनी_,
  { {0x2d9e1f5b, 0x444401a2, 0x00000000, 0x00000000}},  //   _bate_, _zt_,   ,
  { {0xd658012e, 0x22490149, 0x2d9e001a, 0x00000000}},  //   ניות_, mpak_, _cate_,
  { {0xabd500e1, 0xeb9902d3, 0x22490058, 0x00000000}},  //   ициј, вий_, lpak_,
  { {0x3ff9007b, 0xb5fb004a, 0x9e950014, 0x00000000}},  //   _ספּע, nsáb, _پارچ,
  { {0x224901b5, 0x2d9e085d, 0x00000000, 0x00000000}},  //   npak_, _fate_,   ,
  { {0xe8850069, 0x00000000, 0x00000000, 0x00000000}},  //   агоп,   ,   ,
  { {0x7c9501fa, 0x6ce40088, 0x2a7f006c, 0x00000000}},  //   _خلاص, _ліце, stub_,
  { {0x2d210061, 0x2249011c, 0x2d9e0059, 0x00000000}},  //   मधील_, kpak_, _zate_,
  { {0x64450065, 0x2d9e2c44, 0xa3b9013d, 0x00000000}},  //   _athi, _yate_, चान_,
  { {0x4444112d, 0x98a501fc, 0x9fb800b9, 0x00000000}},  //   _pt_, _вике, včí_,
  { {0xb4c202fb, 0x69c3001a, 0x44440082, 0x00000000}},  //   ्ने_, _ione, _qt_,
  { {0x44441287, 0x69c30238, 0xb5fb0285, 0x00000000}},  //   _vt_, _hone, dráu,
  { {0x44440263, 0x6018004f, 0x660700ee, 0x00000000}},  // [8300] _wt_, jíma, bojk,
  { {0x44442c45, 0x69c300ab, 0xbbd2007d, 0x00000000}},  //   _tt_, _jone, _तत्क,
  { {0x4444067e, 0x69c32c46, 0x2d9e1eed, 0x00000000}},  //   _ut_, _mone, _rate_,
  { {0xddc2001e, 0x6d41000d, 0x03a60d68, 0x00000000}},  //   droš, _afla, _тимо,
  { {0x2d9e1089, 0x200601d6, 0x00000000, 0x00000000}},  //   _pate_, rooi_,   ,
  { {0x2b4d001c, 0x69c30339, 0xcf250025, 0x00000000}},  //   ebec_, _none, حرمي,
  { {0x090b0044, 0xb5fb0161, 0x00000000, 0x00000000}},  //   হেতু_, práv,   ,
  { {0x0b8a05a5, 0xbae70044, 0x6d412c47, 0x00000000}},  //   тски_, _পড়ছ, _efla,
  { {0x2a6d0209, 0x6d410016, 0x69c31c13, 0x00000000}},  //   greb_, _ffla, _bone,
  { {0x69c316ca, 0x4e7b00b6, 0x3f860173, 0x00000000}},  //   _cone, _באמצ, lfou_,
  { {0x69c32c48, 0x313701f8, 0x66070119, 0x00000000}},  //   _done, ינים_, vojk,
  { {0x961f0309, 0xe695007c, 0xaa57009e, 0x00000000}},  //   पष्ट_, бимы, _چلنا_,
  { {0x86740088, 0x00000000, 0x00000000, 0x00000000}},  //   оляє,   ,   ,
  { {0x69c3005b, 0x00000000, 0x00000000, 0x00000000}},  //   _gone,   ,   ,
  { {0xe4a40517, 0xb8eb0044, 0xb5fb01e5, 0x00000000}},  //   орто, _রে_, drát,
  { {0x69c32c49, 0x224901d6, 0x8335005e, 0x00000000}},  //   _zone, tpak_, снах,
  { {0x27e901a3, 0x66070740, 0x69c30095, 0x00000000}},  // [8310] _iman_, pojk, _yone,
  { {0x22492c4a, 0xf5950025, 0x683e0089, 0x00000000}},  //   rpak_, _الدج, _zīda,
  { {0xd1380265, 0x22492c4b, 0x43950072, 0x00000000}},  //   рху_, spak_, _ланс,
  { {0x6018000c, 0x27e901f3, 0x2fc400f6, 0x00000000}},  //   tíma, _jman_, _comg_,
  { {0x6d41010f, 0xb5fb2773, 0xbea502dc, 0x00000000}},  //   _pfla, brát, салк,
  { {0x0cb60055, 0x629d002b, 0xb5fb029d, 0x00000000}},  //   জনৈত, _isso, crát,
  { {0x27e900b0, 0x69c30007, 0x3c9300a6, 0x00000000}},  //   _oman_, _rone, تیاز,
  { {0x27e9011c, 0x2a6d2c4c, 0x351c009b, 0x00000000}},  //   _nman_, treb_, כוונ,
  { {0x69c304a9, 0x2b4d2c4d, 0x00000000, 0x00000000}},  //   _pone, rbec_,   ,
  { {0x27e90169, 0x69da00ab, 0xdef80783, 0x00000000}},  //   _aman_, ghte, _тыс_,
  { {0x69c32af8, 0x07a60088, 0xdd150070, 0x00000000}},  //   _vone, банн, _اواخ,
  { {0x629d06c0, 0x69c300b5, 0xc3000044, 0x00000000}},  //   _osso, _wone, ্ধতি_,
  { {0x69c30376, 0x7ccc0089, 0x00000000, 0x00000000}},  //   _tone, _vērš,   ,
  { {0x69da15a6, 0x27e9022b, 0x69c300e7, 0x00000000}},  //   chte, _eman_, _uone,
  { {0x044603f3, 0x25a101c4, 0x628f0026, 0x00000000}},  //   себн, _dahl_, _apco,
  { {0x083a0049, 0x7bdb2c4e, 0x00000000, 0x00000000}},  //   _געקל, nhuu,   ,
  { {0xb5fb13ae, 0x00000000, 0x00000000, 0x00000000}},  // [8320] trát,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x629d00f4, 0x6f1b008e, 0x2fc40022, 0x00000000}},  //   _esso, _azuc, _pomg_,
  { {0x25a10598, 0x201f2c4f, 0x4424135a, 0x00000000}},  //   _zahl_, _chui_, _òm_,
  { {0x63a42c50, 0x248c002b, 0x69da00b0, 0x00000000}},  //   mdin, ħdmu_, yhte,
  { {0x63a42c51, 0x443a0036, 0x62840039, 0x00000000}},  //   ldin, _kup_, mtio,
  { {0x6284021e, 0x443a0c51, 0xf41f00b0, 0x00000000}},  //   ltio, _jup_, _yhä_,
  { {0x443a037e, 0x5bd20061, 0x00f700a0, 0x00000000}},  //   _mup_, तसेव, _המלך_,
  { {0x63a400c7, 0x6284030a, 0x443a1de0, 0x00000000}},  //   idin, ntio, _lup_,
  { {0x984a005e, 0x443a1cf6, 0x27e9023a, 0x00000000}},  //   ляма_, _oup_, _sman_,
  { {0xdb4f005e, 0xb5fb2c52, 0x443a23ed, 0x00000000}},  //   _ню_, krár, _nup_,
  { {0x69da008d, 0x6d5a0039, 0x63a400b5, 0x00000000}},  //   shte, _heta, jdin,
  { {0x63a40472, 0x6d5a020c, 0x689200a1, 0x00000000}},  //   ddin, _keta, _کیجئ,
  { {0xd6d801fb, 0x7c3a0066, 0x62840606, 0x00000000}},  //   стю_, _kutr, dtio,
  { {0xdce8011f, 0x6d5a046e, 0x395e1fcb, 0x00000000}},  //   _kadı, _meta, mats_,
  { {0x6d5a2c53, 0x395e0f4a, 0x7c3a002d, 0x00000000}},  //   _leta, lats_, _mutr,
  { {0xb33b09f7, 0x82f80025, 0x6d5a0460, 0x00000000}},  // [8330] _caça, مركز_, _oeta,
  { {0x7c3a0907, 0x395e04bd, 0x63a40541, 0x00000000}},  //   _outr, nats_, adin,
  { {0xceeb007a, 0x6284028a, 0x93270063, 0x00000000}},  //   گران_, atio, _گردن,
  { {0xb33b2c54, 0x7e620061, 0x395e00f4, 0x00000000}},  //   _faça, fsop, hats_,
  { {0x6284030a, 0x7c3a028c, 0x395e2c55, 0x00000000}},  //   ctio, _autr, kats_,
  { {0x31350c96, 0x6d5a0475, 0xdcf8010a, 0x00000000}},  //   _февр, _ceta, nevė,
  { {0x395e2c56, 0x7c3a001a, 0x201f0011, 0x00000000}},  //   dats_, _cutr, _thui_,
  { {0x69d8009f, 0x7c3a00c4, 0x00000000, 0x00000000}},  //   _alve, _dutr,   ,
  { {0xe9d9005c, 0x6d5a0065, 0x7bdb00b5, 0x00000000}},  //   ики_, _feta, rhuu,
  { {0x395e0129, 0x63a40006, 0x7c3a00b4, 0x00000000}},  //   gats_, zdin, _futr,
  { {0x29c9049a, 0x63a40007, 0x6284002d, 0x00000000}},  //   _súas_, ydin, ztio,
  { {0x69d8121b, 0x6d5a09ac, 0x907a0097, 0x00000000}},  //   _elve, _zeta, סטרי,
  { {0x395e0fdb, 0x443a00f4, 0xab64008b, 0x00000000}},  //   bats_, _sup_, _хвіл,
  { {0x395e2ae8, 0x443a1541, 0xb33b00c4, 0x00000000}},  //   cats_, _pup_, _raça,
  { {0x044304b6, 0xdce80477, 0x63a41569, 0x00000000}},  //   десн, _yadı, tdin,
  { {0x63a40343, 0x29c9049a, 0x7f5b008e, 0x00000000}},  //   udin, _túas_, _neuq,
  { {0x63a4271c, 0x98a5005a, 0x6284009d, 0x00000000}},  // [8340] rdin, malı_, utio,
  { {0x628400ab, 0x443a12da, 0xe69302fd, 0x00000000}},  //   rtio, _tup_, _کلید,
  { {0x6284028a, 0xdbd1014a, 0x3ead000a, 0x00000000}},  //   stio, _güçl, _aret_,
  { {0x6284030a, 0x6d5a0127, 0x98a5005d, 0x00000000}},  //   ptio, _seta, nalı_,
  { {0x6d5a2429, 0x7c3a0213, 0x4e960380, 0x00000000}},  //   _peta, _sutr, تشار,
  { {0x7c3a0169, 0x3ead04bd, 0x2bd20061, 0x00000000}},  //   _putr, _dret_, तस्थ,
  { {0xaff5026c, 0x6d5a003b, 0x395e0129, 0x00000000}},  //   _کہنا_, _veta, vats_,
  { {0xdce8005f, 0x3ead0e6d, 0xaa660264, 0x00000000}},  //   _qadı, _fret_, оток,
  { {0x395e120d, 0x6d5a020c, 0x3ead1014, 0x00000000}},  //   tats_, _teta, _gret_,
  { {0xddc20036, 0x670e013d, 0x442215f8, 0x00000000}},  //   społ, _सड़क_, _lhk_,
  { {0x395e0f4a, 0xeb9a0200, 0x2cac0016, 0x00000000}},  //   rats_, _вие_, _urdd_,
  { {0x395e0f4a, 0x56950184, 0x44222c57, 0x00000000}},  //   sats_, памт, _nhk_,
  { {0x395e0129, 0x37071662, 0x39491f4a, 0x00000000}},  //   pats_, ючов, _şase_,
  { {0x69d8068f, 0x00000000, 0x00000000, 0x00000000}},  //   _ulve,   ,   ,
  { {0xd90f007e, 0x7c2200e7, 0x00000000, 0x00000000}},  //   _ць_, _khor,   ,
  { {0xedb70309, 0x44222c58, 0x98a50477, 0x00000000}},  //   _इच्छ, _chk_, calı_,
  { {0xe1f30464, 0x7c220fcc, 0xa2ad0061, 0x00000000}},  // [8350] وسط_, _mhor, ीमध्,
  { {0x44220004, 0x7c2200f6, 0xdddb016e, 0x00000000}},  //   _ehk_, _lhor, _spuž,
  { {0x7c22002d, 0xb881013e, 0x395c000a, 0x00000000}},  //   _ohor, žíve, _mevs_,
  { {0x3ead2c59, 0xf49400a6, 0x7ddd000a, 0x00000000}},  //   _pret_, _کشید, _mèse,
  { {0x44290073, 0xb3ba00b6, 0xe298007e, 0x00000000}},  //   mma_, _המרכ, _даў_,
  { {0x4429021e, 0x7c220219, 0x270a001d, 0x00000000}},  //   lma_, _ahor, ờng_,
  { {0x44290919, 0x98a50279, 0x506400d7, 0x00000000}},  //   oma_, yalı_, _отта,
  { {0x7c220620, 0x442901f6, 0x3ead0129, 0x00000000}},  //   _chor, nma_, _tret_,
  { {0x6aa4037e, 0x44291263, 0x7c22120e, 0x00000000}},  //   _šifr, ima_, _dhor,
  { {0xe9d900aa, 0x4429056c, 0x9b02008b, 0x00000000}},  //   ско_, hma_, эзыд,
  { {0x7c22002a, 0x442912d9, 0x98a5005a, 0x00000000}},  //   _fhor, kma_, talı_,
  { {0x442906a6, 0x7c222c5a, 0x00000000, 0x00000000}},  //   jma_, _ghor,   ,
  { {0x44290acc, 0x98ab014a, 0xbb3a00b3, 0x00000000}},  //   dma_, ılık_, _העני,
  { {0x7c290c49, 0x442901d5, 0x44220023, 0x00000000}},  //   lmer, ema_, _shk_,
  { {0x98a5047f, 0x7c290207, 0xb5fb00b9, 0x00000000}},  //   palı_, omer, psán,
  { {0x44292c5b, 0x7c2900b5, 0xc2460147, 0x00000000}},  //   gma_, nmer, знак,
  { {0xb77b009b, 0x7c290253, 0x224b0082, 0x00000000}},  // [8360] _האפש, imer, _ctck_,
  { {0x44291395, 0xb33b00f4, 0x7c292c5c, 0x00000000}},  //   ama_, _faço, hmer,
  { {0x7c290056, 0x6557009b, 0x00000000, 0x00000000}},  //   kmer, _מביא_,   ,
  { {0x7c290065, 0x442901ed, 0x00000000, 0x00000000}},  //   jmer, cma_,   ,
  { {0xa3b902f4, 0x7c290142, 0xa7fd014a, 0x00000000}},  //   चार_, dmer, ksın,
  { {0x7c220038, 0x471b0049, 0x63a604be, 0x00000000}},  //   _shor, זונג, _hakn,
  { {0x7c221625, 0x395c0186, 0x61ee002b, 0x00000000}},  //   _phor, _revs_, _imbl,
  { {0x7c2900c7, 0xdcf80089, 0x8fa3007e, 0x00000000}},  //   gmer, levī, _пасе,
  { {0x63a60743, 0x291a00d0, 0x7f44004a, 0x00000000}},  //   _makn, _špa_, ñiqu,
  { {0x44290823, 0x7c220541, 0xdca60bbd, 0x00000000}},  //   zma_, _whor, _нази,
  { {0x4429000c, 0xa31903d7, 0x7c220905, 0x00000000}},  //   yma_, _दर्ज_, _thor,
  { {0x44290a89, 0x63a60091, 0x00000000, 0x00000000}},  //   xma_, _nakn,   ,
  { {0x44291ed5, 0x61ee008e, 0x00000000, 0x00000000}},  //   vma_, _ombl,   ,
  { {0x6aa204d2, 0x1a9b0049, 0x44290af2, 0x00000000}},  //   _isof, _לידע, wma_,
  { {0x442908a1, 0xdcf80089, 0x2578007c, 0x00000000}},  //   tma_, devī, ябрь_,
  { {0x799a0020, 0x7dcf01e3, 0x7dd400f6, 0x00000000}},  //   letw, _høst, _bàsk,
  { {0x69ca0091, 0x6aa20066, 0x6d4800d9, 0x00000000}},  // [8370] _kofe, _jsof, _ofda,
  { {0x799a023a, 0x764d2c5d, 0x7c292c5e, 0x00000000}},  //   netw, _itay, zmer,
  { {0x7c290016, 0x9f4f009d, 0x4429014a, 0x00000000}},  //   ymer, ligé_, pma_,
  { {0xc1040380, 0xa7fd014a, 0x08770049, 0x00000000}},  //   روني, zsın, לעבט_,
  { {0x7c29012d, 0x799a00e7, 0x6da502b8, 0x00000000}},  //   vmer, ketw, дила,
  { {0x6b820211, 0x69ca0016, 0x764d00e7, 0x00000000}},  //   _acog, _nofe, _mtay,
  { {0x63a610ed, 0x7094005e, 0xdca2005e, 0x00000000}},  //   _yakn, _парф, ващи,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69ca00fa, 0x764d0009, 0xcf92009b, 0x00000000}},  //   _bofe, _ntay, _בטן_,
  { {0x7c290047, 0x200f020c, 0x39e901fb, 0x00000000}},  //   smer, logi_, ідно_,
  { {0x6aa22c5f, 0xa7fd005d, 0x7c290056, 0x00000000}},  //   _esof, rsın, pmer,
  { {0x200f005b, 0x7e690006, 0x6b820048, 0x00000000}},  //   nogi_, _kvep, _gcog,
  { {0x7bcb1396, 0x7dcf0146, 0x00000000, 0x00000000}},  //   _iogu, _føst,   ,
  { {0x63a602e1, 0x69ca0678, 0x7bcb008e, 0x00000000}},  //   _sakn, _gofe, _hogu,
  { {0x7bcb0004, 0x660e067f, 0x63a601a3, 0x00000000}},  //   _kogu, robk, _pakn,
  { {0xc3070044, 0x00000000, 0x00000000, 0x00000000}},  //   লেছি_,   ,   ,
  { {0x7bcb0119, 0x63a60301, 0xa3e4013d, 0x00000000}},  // [8380] _mogu, _vakn, भोग_,
  { {0x7bcb008e, 0x6b9b00b5, 0x00da0025, 0x00000000}},  //   _logu, heug, يبات_,
  { {0x63a601a3, 0x00000000, 0x00000000, 0x00000000}},  //   _takn,   ,   ,
  { {0x7bcb1e8f, 0xef1a01fe, 0x200f2c60, 0x00000000}},  //   _nogu, оме_, gogi_,
  { {0xde58007e, 0x601806c0, 0xb33b006b, 0x00000000}},  //   чалі_, ními, _xaçm,
  { {0x6b820197, 0x61ee001a, 0xbc4a022a, 0x00000000}},  //   _scog, _umbl, очие_,
  { {0x69ca00f6, 0x7bcb00b4, 0x6aa22c61, 0x00000000}},  //   _rofe, _bogu, _ssof,
  { {0x69ca2c62, 0x7dcf043e, 0x7bcb00c4, 0x00000000}},  //   _sofe, _søst, _cogu,
  { {0x7bcb002d, 0x5a34005e, 0x1eaa0014, 0x00000000}},  //   _dogu, ннит, _بازي_,
  { {0xdb1b01e5, 0x7dcf0146, 0x00000000, 0x00000000}},  //   rkuð, _døss,   ,
  { {0x2d9c008d, 0x799a0173, 0x764d192b, 0x00000000}},  //   meve_, retw, _stay,
  { {0x2d9c2c63, 0x7bcb0032, 0x00000000, 0x00000000}},  //   leve_, _gogu,   ,
  { {0x6aa2012d, 0x69ca01c3, 0xeafa02fd, 0x00000000}},  //   _usof, _tofe, _برات_,
  { {0x2d9c008d, 0x7dd40129, 0x7bcb0023, 0x00000000}},  //   neve_, _bàsi, _zogu,
  { {0x16340194, 0x200f0022, 0x43950088, 0x00000000}},  //   теря, yogi_, навс,
  { {0x2d9c29e6, 0x6b8000e0, 0x61fe03cd, 0x00000000}},  //   heve_, ngmg, enpl,
  { {0x4e0e03d7, 0x2d9c0065, 0x200f000c, 0x00000000}},  // [8390] ाकाई_, keve_, vogi_,
  { {0x2d9c116b, 0x6b9b001f, 0xdbd60004, 0x00000000}},  //   jeve_, zeug, _hääl,
  { {0x7e692c64, 0xdb0b0039, 0x2d9c0059, 0x00000000}},  //   _svep, _ingå, deve_,
  { {0x4f9400ed, 0x61fe0116, 0xdbd601b1, 0x00000000}},  //   вршу, anpl, _jääl,
  { {0x2d8e0009, 0x7bcb0133, 0x2d9c0023, 0x00000000}},  //   fffe_, _rogu, feve_,
  { {0x44390038, 0x0ea801fb, 0x2d9c0065, 0x00000000}},  //   _his_, ькій_, geve_,
  { {0x44390047, 0x7bcb0129, 0x7ddd00d4, 0x00000000}},  //   _kis_, _pogu, _cèsa,
  { {0x44392c65, 0x00000000, 0x00000000, 0x00000000}},  //   _jis_,   ,   ,
  { {0x4439061f, 0xeab10025, 0x2d9c0023, 0x00000000}},  //   _mis_, اعب_, beve_,
  { {0x44390263, 0x2d9c016c, 0x00000000, 0x00000000}},  //   _lis_, ceve_,   ,
  { {0x443900b0, 0x2fdf0e9f, 0x00000000, 0x00000000}},  //   _ois_, _klug_,   ,
  { {0xf772004b, 0xdb0b05cb, 0xddc200b9, 0x00000000}},  //   داد_, _angå, dpoř,
  { {0x2fcd0007, 0xa3b9007d, 0x80d60061, 0x00000000}},  //   _moeg_, चाई_, _मॅने,
  { {0x4439002a, 0x64a6007e, 0x644800c4, 0x00000000}},  //   _ais_, нага, ídio,
  { {0xb8f40055, 0x4439001f, 0x6018004a, 0x00000000}},  //   _সে_, _bis_, sími,
  { {0x2d9c0065, 0x04570025, 0x44390133, 0x00000000}},  //   zeve_, علقة_, _cis_,
  { {0x44390343, 0xe2970113, 0x27e0005f, 0x00000000}},  // [83a0] _dis_, нат_, _ilin_,
  { {0x4439037f, 0x7981005b, 0x065700a3, 0x00000000}},  //   _eis_, nglw, _רייך_,
  { {0x443901d5, 0x61fe00f8, 0x2d9c0023, 0x00000000}},  //   _fis_, rnpl, veve_,
  { {0x24f5007e, 0x8afd00b9, 0x7c390016, 0x00000000}},  //   _шчыр, zařa, _niwr,
  { {0x2d9c008d, 0x245e00b9, 0x5ed30044, 0x00000000}},  //   teve_, lům_, _দেবে,
  { {0x4439001a, 0x2d8e009d, 0x3d940264, 0x00000000}},  //   _zis_, uffe_, тикр,
  { {0x2d9c008d, 0x27e0003c, 0x2fdf0218, 0x00000000}},  //   reve_, _olin_, _flug_,
  { {0x802602fd, 0x2d9c0065, 0x2242010e, 0x00000000}},  //   _سرزم, seve_, _kukk_,
  { {0x7c39018e, 0x2d9c0065, 0xd007005e, 0x00000000}},  //   _diwr, peve_, _чете_,
  { {0x32030061, 0x27e0148e, 0x2c570036, 0x00000000}},  //   _xjjy_, _alin_, _będę_,
  { {0xdbd6021e, 0x29180fdc, 0x22422c66, 0x00000000}},  //   _pääl, æra_, _lukk_,
  { {0x1ae6005e, 0x245e00b9, 0x27e02c67, 0x00000000}},  //   _поем, dům_, _clin_,
  { {0x6e3a002b, 0x6d4a0051, 0x7bc6010e, 0x00000000}},  //   _kitb, ocfa, ökuu,
  { {0x44392c68, 0x27e00039, 0x6e3a0066, 0x00000000}},  //   _sis_, _elin_, _jitb,
  { {0x44392c69, 0xdbd6021e, 0x6e3a010f, 0x00000000}},  //   _pis_, _tääl, _mitb,
  { {0x6e3a2c6a, 0xa4010044, 0x69da037f, 0x00000000}},  //   _litb, ্ষ্য_, lkte,
  { {0x44390542, 0x1b0e0044, 0x98ac005a, 0x00000000}},  // [83b0] _vis_, াইকে_, madı_,
  { {0x443901d6, 0x2fdf0058, 0x98ac005d, 0x00000000}},  //   _wis_, _slug_, ladı_,
  { {0x2fcd006c, 0x656700ca, 0x00000000, 0x00000000}},  //   _poeg_, majh,   ,
  { {0xddc20c47, 0x98ac019a, 0x443904e7, 0x00000000}},  //   grož, nadı_, _uis_,
  { {0x2fcd00c7, 0x6e3a2c6b, 0x2fdf01bb, 0x00000000}},  //   _voeg_, _bitb, _vlug_,
  { {0x3f9d0093, 0x7c39005b, 0xc69408cd, 0x00000000}},  //   sewu_, _siwr, ראס_,
  { {0x301b0025, 0xdb001f7d, 0x63ad2a36, 0x00000000}},  //   _فترة_, ndmæ, odan,
  { {0x4034007c, 0x69da10ae, 0xeb99007c, 0x00000000}},  //   _бесс, ekte, фии_,
  { {0x63ad10c5, 0x628d0094, 0xb5fb0048, 0x00000000}},  //   idan, ntao, asái,
  { {0x63ad00b0, 0x00000000, 0x00000000, 0x00000000}},  //   hdan,   ,   ,
  { {0x63ad2c6c, 0x27e00942, 0x9b950025, 0x00000000}},  //   kdan, _plin_, _للات,
  { {0x79810016, 0x366a003b, 0x245e013e, 0x00000000}},  //   sglw, мамо_, vům_,
  { {0x63ad2c6d, 0x21e4010f, 0x00000000, 0x00000000}},  //   ddan, _höhe_,   ,
  { {0x7ae90047, 0x69da010f, 0x6fc30061, 0x00000000}},  //   mzet, ckte, ळाडू,
  { {0xa8060265, 0x321304d2, 0x7ae92c6e, 0x00000000}},  //   _изкл, doxy_, lzet,
  { {0x6f160036, 0x245e00b9, 0x63ad0091, 0x00000000}},  //   życi, rům_, gdan,
  { {0x7ae90020, 0xd5b10082, 0xdb0b2c6f, 0x00000000}},  // [83c0] nzet, ốc_, _angú,
  { {0x63ad18d5, 0x867b009b, 0x00000000, 0x00000000}},  //   adan, _קריו,   ,
  { {0xa50a009a, 0x3d16001c, 0x8fa60242, 0x00000000}},  //   _цена_, _पुढे_, каже,
  { {0x44442c70, 0x6e3a01c3, 0x63ad019a, 0x00000000}},  //   _iu_, _sitb, cdan,
  { {0x44442c71, 0x69da01c9, 0x6e940379, 0x00000000}},  //   _hu_, ykte, التا,
  { {0x4444008d, 0x7ae90790, 0x776400fa, 0x00000000}},  //   _ku_, dzet, _leix,
  { {0x44442c72, 0xddc21282, 0x0231009e, 0x00000000}},  //   _ju_, prož, _اہلح,
  { {0x44440119, 0x3d160201, 0xb5fb0051, 0x00000000}},  //   _mu_, _पुणे_, rsái,
  { {0x7ae90c57, 0x249a0093, 0xbea30269, 0x00000000}},  //   gzet, _lppm_, _катк,
  { {0x44440e6d, 0xbda505d4, 0x6e3a01b5, 0x00000000}},  //   _ou_, _محمو, _uitb,
  { {0x44441305, 0x63ad2c73, 0x717b00a3, 0x00000000}},  //   _nu_, ydan, וניס,
  { {0xb5fb0181, 0x00000000, 0x00000000, 0x00000000}},  //   nsáv,   ,   ,
  { {0x44442c74, 0x77642b7d, 0x63ad037e, 0x00000000}},  //   _au_, _deix, vdan,
  { {0x444401f6, 0xceb3009b, 0x7dd400f6, 0x00000000}},  //   _bu_, ביש_, _gàst,
  { {0x44441305, 0x657a0051, 0x499b00a0, 0x00000000}},  //   _cu_, ótha, _חשוב,
  { {0x77641175, 0x00000000, 0x00000000, 0x00000000}},  //   _geix,   ,   ,
  { {0x44441fde, 0x63ad0127, 0xa2c30061, 0x00000000}},  // [83d0] _eu_, rdan, रमध्,
  { {0x4444133c, 0xa29401e1, 0x63ad0bc7, 0x00000000}},  //   _fu_, рафі, sdan,
  { {0x4444002d, 0x7ae9054f, 0x94d52c75, 0x00000000}},  //   _gu_, zzet, _сонц,
  { {0x7ddd0263, 0x65652c76, 0x394e0085, 0x00000000}},  //   _pèso, _hehh, _lffs_,
  { {0x444408ba, 0x442b0240, 0x9ac4002b, 0x00000000}},  //   _zu_, _ihc_, _jiċċ,
  { {0x64451080, 0xee3801fb, 0x4444014a, 0x00000000}},  //   _kuhi, вні_, _yu_,
  { {0x6445006c, 0x44440011, 0x6565006c, 0x00000000}},  //   _juhi, _xu_, _mehh,
  { {0x6445000b, 0x7ae90493, 0xac96006d, 0x00000000}},  //   _muhi, tzet, انيا_,
  { {0xdce303c9, 0x7e600016, 0x776400d4, 0x00000000}},  //   manč, _gwmp, _reix,
  { {0x77641052, 0x7ae92c77, 0x7bdb2c78, 0x00000000}},  //   _seix, rzet, skuu,
  { {0x7ae90047, 0x7764153d, 0x6d412c79, 0x00000000}},  //   szet, _peix, _igla,
  { {0x9ac4002b, 0x2369004a, 0x442b2c7a, 0x00000000}},  //   _biċċ, jaaj_, _nhc_,
  { {0x6445006c, 0xe7372540, 0x7dd400f6, 0x00000000}},  //   _auhi, лею_, _tàst,
  { {0x444400f4, 0x6615002d, 0x644505bd, 0x00000000}},  //   _pu_, gozk, _buhi,
  { {0x44440a8d, 0x776409f7, 0xdce30006, 0x00000000}},  //   _qu_, _teix, kanč,
  { {0x44442c7b, 0xdce3010a, 0x442b0541, 0x00000000}},  //   _vu_, janč, _chc_,
  { {0x6d4101d9, 0x442b00d4, 0xdce30006, 0x00000000}},  // [83e0] _ogla, _dhc_, danč,
  { {0x6d410051, 0x00000000, 0x00000000, 0x00000000}},  //   _ngla,   ,   ,
  { {0x44442c7c, 0x64450ac9, 0x442b00c4, 0x00000000}},  //   _uu_, _guhi, _fhc_,
  { {0x2a6d2c7d, 0xdce3007f, 0x6d412c7e, 0x00000000}},  //   kseb_, ganč, _agla,
  { {0x44200563, 0x643b0049, 0x00000000, 0x00000000}},  //   mli_, _רעכנ,   ,
  { {0x44320ce2, 0xc69300b6, 0x6143007e, 0x00000000}},  //   lmy_, צאו_, _гера,
  { {0x4420018e, 0xa3b90061, 0xdce32091, 0x00000000}},  //   oli_, चाच_, banč,
  { {0x4420047f, 0x3a7408fc, 0x75f4006b, 0x00000000}},  //   nli_, алир, _düzə,
  { {0xaf060780, 0x44201158, 0xe20b0036, 0x00000000}},  //   _спал, ili_, łóż_,
  { {0x2a970054, 0x44202c7f, 0x3f8600c4, 0x00000000}},  //   ائية_, hli_, lgou_,
  { {0x683e0964, 0x021700b3, 0x75f4006b, 0x00000000}},  //   _būda, רחים_, _güzə,
  { {0x3f8601aa, 0x64452c80, 0x443208d2, 0x00000000}},  //   ngou_, _ruhi, jmy_,
  { {0x44200027, 0xeab20151, 0xdb190036, 0x00000000}},  //   dli_, _دعا_, _dowó,
  { {0x44200036, 0xdce30107, 0x44320036, 0x00000000}},  //   eli_, zanč, emy_,
  { {0x44201fe3, 0xe535007c, 0x9ac40066, 0x00000000}},  //   fli_, ревь, _wiċċ,
  { {0x44200198, 0xdb0b000a, 0x44320ad0, 0x00000000}},  //   gli_, _bagè, gmy_,
  { {0x81ae0044, 0x00000000, 0x00000000, 0x00000000}},  // [83f0] কান_,   ,   ,
  { {0x44200198, 0x44322c81, 0x644508b5, 0x00000000}},  //   ali_, amy_, _tuhi,
  { {0x442024bf, 0x4395008b, 0xdce309f4, 0x00000000}},  //   bli_, _канс, tanč,
  { {0xb4c30183, 0x44202c82, 0xd25000a1, 0x00000000}},  //   ्ही_, cli_, تنے_,
  { {0x8d651ac0, 0xea000011, 0xeaa600a1, 0x00000000}},  //   авле, _giầy_, _بٹ_,
  { {0x3f7500ad, 0x7dd40129, 0x127a0049, 0x00000000}},  //   ều_, _bàsq, _באשע,
  { {0x5ed30055, 0x228f2c83, 0x463c00a3, 0x00000000}},  //   _দেশে, lük_, געגע,
  { {0xf0b300a1, 0x2a6d006c, 0x0b45026b, 0x00000000}},  //   _پیچھ, tseb_, шнин,
  { {0x4a4503f3, 0x63af0190, 0x228f24e0, 0x00000000}},  //   јнов, _macn, nük_,
  { {0x4420011f, 0x6d410119, 0x44320721, 0x00000000}},  //   zli_, _ugla, zmy_,
  { {0x44202c84, 0x4806005e, 0xf1b20097, 0x00000000}},  //   yli_, ипов, קסט_,
  { {0x629d0007, 0x5b15005e, 0x442011ca, 0x00000000}},  //   _opso, _кмет, xli_,
  { {0x228f0010, 0x4420014a, 0x25a30190, 0x00000000}},  //   jük_, vli_, fejl_,
  { {0x2d872c85, 0xdb1901aa, 0xeaf809b9, 0x00000000}},  //   ngne_, _fowò, _حرمت_,
  { {0x4420011f, 0x64a6012d, 0x629d0091, 0x00000000}},  //   tli_, шава, _apso,
  { {0x44200207, 0xdb0b00d4, 0x00000000, 0x00000000}},  //   uli_, _pagè,   ,

  { {0x4420049d, 0x44320387, 0xf347031b, 0x00000000}},  // [8400] rli_, rmy_, рпул_,
  { {0xd5a400e9, 0x63af0051, 0x68e400b9, 0x00000000}},  //   _الدی, _eacn, _řidi,
  { {0x4420144d, 0xb5fb0f18, 0x10a61f25, 0x00000000}},  //   pli_, rsát, риен,
  { {0x442011ca, 0x03960d99, 0x2d872c86, 0x00000000}},  //   qli_, _троя, egne_,
  { {0x63a40109, 0x61460256, 0x629d0022, 0x00000000}},  //   mein, _вега, _gpso,
  { {0xdd90031d, 0xde030088, 0x00000000, 0x00000000}},  //   سوب_, опчи,   ,
  { {0xcbe605b5, 0x8fa60140, 0x00000000, 0x00000000}},  //   иции, _каве,   ,
  { {0xdb000047, 0x63a4010f, 0x2d91014a, 0x00000000}},  //   lemé, nein, _özen_,
  { {0x75e20027, 0xee3a0517, 0xdee30931, 0x00000000}},  //   _rôzn, _ана_, _доти,
  { {0x63a4001f, 0x3e32026c, 0xe61f00f4, 0x00000000}},  //   hein, _بہتر, ntôt_,
  { {0x63a40056, 0x228f0148, 0x00000000, 0x00000000}},  //   kein, zük_,   ,
  { {0x228f005d, 0x61d302fb, 0xab830098, 0x00000000}},  //   yük_, _दक्ष, _душк,
  { {0x7bc2009d, 0x41c90204, 0xdb000010, 0x00000000}},  //   _inou, रामस, kemé,
  { {0xaadb0097, 0x00000000, 0x00000000, 0x00000000}},  //   _בחדר,   ,   ,
  { {0xf36701f9, 0xb4c30164, 0x63a40abe, 0x00000000}},  //   итан, ्हे_, fein,
  { {0x63a40010, 0xe3b003ab, 0x228f2c87, 0x00000000}},  //   gein, ورق_, tük_,
  { {0xe6950025, 0x628f0009, 0x2d8c06d2, 0x00000000}},  // [8410] _الخد, _qqco, _ocde_,
  { {0x228f2c88, 0xc05b01e1, 0xf1a702ea, 0x00000000}},  //   rük_, від_, јран,
  { {0xea00001d, 0x63af003b, 0x63a41642, 0x00000000}},  //   _giấy_, _tacn, bein,
  { {0x6457022b, 0x63a400f4, 0x5f740025, 0x00000000}},  //   _itxi, cein, قاهر,
  { {0x2bc50061, 0x82a4007e, 0xf1a702ea, 0x00000000}},  //   वासा, _даўж, _крвн,
  { {0xa1841001, 0x7bc21de2, 0x75eb0279, 0x00000000}},  //   _мысл, _anou, _düzg,
  { {0x2d8700f4, 0xddc9001a, 0xa7fd006b, 0x00000000}},  //   rgne_, _aveţ, nsıs,
  { {0x3ff90049, 0x6e450014, 0x5ff50c27, 0x00000000}},  //   _עפּע, _هنرم, _узбу,
  { {0x75eb2c89, 0x00000000, 0x00000000, 0x00000000}},  //   _küzd,   ,   ,
  { {0x7bc200ab, 0x63a40032, 0x9f440026, 0x00000000}},  //   _enou, zein, _almè_,
  { {0xa889007e, 0x63a42c8a, 0xacb5083e, 0x00000000}},  //   ыйна_, yein, _دماغ,
  { {0xdb000010, 0xa09a0049, 0x00000000, 0x00000000}},  //   zemé, נירט,   ,
  { {0x6457022b, 0xe9ce026b, 0xca480082, 0x00000000}},  //   _atxi, _ек_, _hờn_,
  { {0x63a42c8b, 0x00000000, 0x00000000, 0x00000000}},  //   wein,   ,   ,
  { {0x69c304d3, 0x04b510e1, 0x8afd00b9, 0x00000000}},  //   _inne, остя, daři,
  { {0x6b8907eb, 0x680b0036, 0x62840026, 0x00000000}},  //   ngeg, lędn, tuio,
  { {0x63a426cf, 0xb5fb0181, 0xdb000010, 0x00000000}},  // [8420] rein, rsár, temé,
  { {0x05aa2c8c, 0xb5fb02d5, 0x4586003b, 0x00000000}},  //   _свой_, ssár, _угов,
  { {0x3ead2c8d, 0x63a40ec6, 0x92d80044, 0x00000000}},  //   _aset_, pein, ়ছে_,
  { {0x645c088a, 0x656e0048, 0x6b8900bb, 0x00000000}},  //   mpri, labh, jgeg,
  { {0x6b89001c, 0x69c3021e, 0x2006009d, 0x00000000}},  //   dgeg, _onne, rnoi_,
  { {0x2d91011f, 0x7bc205d2, 0x69d50010, 0x00000000}},  //   _özel_, _snou, özel,
  { {0x3ead03b5, 0x2704013d, 0x6b892c8e, 0x00000000}},  //   _eset_, रपुर_, fgeg,
  { {0x69c31e58, 0x656e0051, 0xba54012b, 0x00000000}},  //   _anne, habh, овиј,
  { {0x6ff50046, 0x75eb011f, 0xdb000030, 0x00000000}},  //   jący, _yüzd, ndmø,
  { {0xd9100123, 0x645c0f86, 0x61fe010e, 0x00000000}},  //   ویش_, kpri, nipl,
  { {0x621b00b6, 0x645c016e, 0xd7c40061, 0x00000000}},  //   רויק, jpri, षांच,
  { {0x69c30ff8, 0xa3cc03d7, 0x61fe014a, 0x00000000}},  //   _enne, लाफ_, hipl,
  { {0x645c0606, 0xa3cc0316, 0x2bc50067, 0x00000000}},  //   epri, लान_, वारा,
  { {0x645c00bb, 0x15eb0088, 0x656e00e0, 0x00000000}},  //   fpri, уємо_, gabh,
  { {0x61fe050e, 0x645c2c8f, 0x0f05013d, 0x00000000}},  //   dipl, gpri, _शख्स_,
  { {0x61fe01c3, 0x98a7007f, 0x00000000, 0x00000000}},  //   eipl, _agnė_,   ,
  { {0x27e92c90, 0x61f9007e, 0x645c00d9, 0x00000000}},  // [8430] _ilan_, анаў_, apri,
  { {0x645c0190, 0xb33b006b, 0x765d0146, 0x00000000}},  //   bpri, _qaçq, mpsy,
  { {0x463c007b, 0x765d08e0, 0x645c1995, 0x00000000}},  //   _געזע, lpsy, cpri,
  { {0x75eb011f, 0xdb090051, 0xd5bf0089, 0x00000000}},  //   _düze, hdeá, žādi_,
  { {0xf41f00b0, 0x00000000, 0x00000000, 0x00000000}},  //   _ikä_,   ,   ,
  { {0x2718001d, 0x321a0011, 0x61fe0232, 0x00000000}},  //   ọng_, copy_, cipl,
  { {0x27e9038c, 0x75eb011f, 0x2bc50164, 0x00000000}},  //   _olan_, _güze, वाला,
  { {0x5f94003b, 0xa3cc0061, 0x8c420242, 0x00000000}},  //   _нист, लाय_, меще,
  { {0x6b8900b5, 0xdd3a000d, 0x224302ae, 0x00000000}},  //   rgeg, tăţi, _kijk_,
  { {0x27e9011f, 0x6b892c91, 0x645c0016, 0x00000000}},  //   _alan_, sgeg, ypri,
  { {0x27e90263, 0x645c107b, 0x224b00ab, 0x00000000}},  //   _blan_, xpri, _luck_,
  { {0xe73a0893, 0x61fe0a69, 0x645c0190, 0x00000000}},  //   иен_, zipl, vpri,
  { {0x645c02c2, 0x27e901ed, 0x00000000, 0x00000000}},  //   wpri, _dlan_,   ,
  { {0xcb3600b6, 0x69c31fd8, 0x27e9006b, 0x00000000}},  //   _ואני_, _unne, _elan_,
  { {0x656e0051, 0x236000b5, 0x27e906d2, 0x00000000}},  //   rabh, tbij_, _flan_,
  { {0x27e91625, 0xa6ca0445, 0x224b0133, 0x00000000}},  //   _glan_, _نوبل_, _buck_,
  { {0xe1fa0551, 0x645c0dc5, 0x236002ae, 0x00000000}},  // [8440] ага_, spri, rbij_,
  { {0xf65300b6, 0xf77f011f, 0x645c00f4, 0x00000000}},  //   _קצת_, rkçe_, ppri,
  { {0x321a1124, 0x661c0450, 0x61fe14ac, 0x00000000}},  //   ropy_, mork, ripl,
  { {0x224b2c92, 0x389a0049, 0x224300d9, 0x00000000}},  //   _fuck_, ייענ, _eijk_,
  { {0xddc92c93, 0xee3a00e3, 0x61fe016c, 0x00000000}},  //   _sveš, анд_, pipl,
  { {0xddc90224, 0x1cba0025, 0x75eb18cf, 0x00000000}},  //   _kteř, لاعب_, _tüze,
  { {0xc0c901f9, 0x3ea9002b, 0x8ed80044, 0x00000000}},  //   _луѓе_, ħata_, _দেশগ,
  { {0xd00a007c, 0x63b60036, 0x2d800035, 0x00000000}},  //   _тебе_, ndyn, şie_,
  { {0x661c00b0, 0x49a600ed, 0x62962c94, 0x00000000}},  //   kork, ојна, ntyo,
  { {0x661c2353, 0x5edc0044, 0xdca602dc, 0x00000000}},  //   jork, _মেথে, _мази,
  { {0x27e9028c, 0xf2df001d, 0x661c00b4, 0x00000000}},  //   _plan_, _ngân_, dork,
  { {0xad1b00a0, 0x00000000, 0x00000000, 0x00000000}},  //   _דובר,   ,   ,
  { {0x63b60016, 0x661c2c95, 0x00000000, 0x00000000}},  //   ddyn, fork,   ,
  { {0xdcfa011f, 0x27e9010f, 0x2d9e016c, 0x00000000}},  //   _hatı, _wlan_, _jbte_,
  { {0xdcfa011f, 0x224300b5, 0x20070010, 0x00000000}},  //   _katı, _rijk_, énik_,
  { {0x69d802cc, 0x27e92c96, 0x7ddd00d4, 0x00000000}},  //   _hove, _ulan_, _hèst,
  { {0x69d800b0, 0x236b012d, 0x672d04eb, 0x00000000}},  // [8450] _kove, _vecj_, _uzaj,
  { {0x69d82c97, 0x68120089, 0x661c05cd, 0x00000000}},  //   _jove, rāde, cork,
  { {0x69d800ab, 0x764d004a, 0x63b60045, 0x00000000}},  //   _move, _huay, bdyn,
  { {0x224b0719, 0x224300b5, 0x2bb6007d, 0x00000000}},  //   _tuck_, _wijk_, _अफगा,
  { {0xed59005e, 0x9e640088, 0xca480082, 0x00000000}},  //   бол_, двід, _bờm_,
  { {0x69d80127, 0xa37b006c, 0x764d014a, 0x00000000}},  //   _nove, _slõh, _muay,
  { {0x459c007b, 0x5ed30055, 0xdcfa005a, 0x00000000}},  //   יסגע, _দেখে, _batı,
  { {0x6e95007c, 0xdc390276, 0x69d80af3, 0x00000000}},  //   _нибу, tçın, _aove,
  { {0x81ae08b7, 0x69d802ae, 0xa3cc0164, 0x00000000}},  //   কার_, _bove, लात_,
  { {0x69d82000, 0x2cbe0066, 0xdce10035, 0x00000000}},  //   _cove, _frtd_, _celă,
  { {0x69d81d3f, 0x661c0142, 0x31bd0044, 0x00000000}},  //   _dove, vork, _আকাশ,
  { {0x201d0036, 0x69ce0a35, 0x661c00ab, 0x00000000}},  //   nowi_, öber, work,
  { {0x661c0387, 0xdce800b9, 0xf71a007e, 0x00000000}},  //   tork, _oddě, сіны_,
  { {0x69d8169a, 0x2ca90036, 0x7e6900e7, 0x00000000}},  //   _gove, ładu_, _mwep,
  { {0xdcfa005a, 0x201d0036, 0x76452c98, 0x00000000}},  //   _yatı, kowi_, _dihy,
  { {0x69d82c99, 0xdcfa006b, 0xddc900b9, 0x00000000}},  //   _zove, _xatı, _vteř,
  { {0x661c0169, 0x764d0211, 0x63b60036, 0x00000000}},  // [8460] pork, _guay, rdyn,
  { {0x69d8027b, 0x422301f9, 0xd9a90061, 0x00000000}},  //   _xove, едув, _कसोट,
  { {0x81ae0055, 0x94760054, 0x62960c2d, 0x00000000}},  //   কাল_, _عددا, styo,
  { {0x3ebf0b50, 0x6d4800f6, 0x8afd013e, 0x00000000}},  //   _brut_, _sgda, nařs,
  { {0x2bbf0061, 0x44220030, 0xdee3003b, 0x00000000}},  //   _शोधा, _ikk_, ноци,
  { {0xdcfa047f, 0x68e1158f, 0x61fc0f3a, 0x00000000}},  //   _satı, kyld, _umrl,
  { {0x69d80638, 0x645800f4, 0x4422006c, 0x00000000}},  //   _rove, _évid, _kkk_,
  { {0x75eb005f, 0xbe0600a1, 0xdcfa006b, 0x00000000}},  //   _müza, _کوئٹ, _qatı,
  { {0x69d801d9, 0x6446009f, 0x5a3409e8, 0x00000000}},  //   _pove, _miki, мнит,
  { {0x64460020, 0x7c66036d, 0x68e10030, 0x00000000}},  //   _liki, _فاصل, fyld,
  { {0x9b46007a, 0x69d82c9a, 0xdb1901a2, 0x00000000}},  //   _فناو, _vove, _anwä,
  { {0x64460020, 0x683f0006, 0x69d824e1, 0x00000000}},  //   _niki, _kūdi, _wove,
  { {0x7c221dc0, 0x9f4d0039, 0x69d81ea7, 0x00000000}},  //   _ikor, _umeå_, _tove,
  { {0x4a7b00a3, 0x644600ea, 0x62842c9b, 0x00000000}},  //   _פרוב, _aiki, drio,
  { {0x64462c9c, 0x2c550089, 0x44220109, 0x00000000}},  //   _biki, _kāda_, _bkk_,
  { {0x683f001e, 0x26c000f7, 0x671e007d, 0x00000000}},  //   _līdz, _frio_, _युवक_,
  { {0x44220018, 0x644604d4, 0xe80203d7, 0x00000000}},  // [8470] _dkk_, _diki, _लगता_,
  { {0x7afd049a, 0x645a0df8, 0x44220145, 0x00000000}},  //   ústi, ític, _ekk_,
  { {0x62840219, 0x64462c9d, 0xdb0b0047, 0x00000000}},  //   ario, _fiki, _magá,
  { {0x3ebf0035, 0x7c220009, 0x683f0964, 0x00000000}},  //   _prut_, _nkor, _būdi,
  { {0x4ea7008b, 0xdfce007a, 0x201d0036, 0x00000000}},  //   яржа, شيو_, rowi_,
  { {0x44292c9e, 0x7c222c9f, 0x64462367, 0x00000000}},  //   lla_, _akor, _ziki,
  { {0x44290198, 0x611400ed, 0x6b9b2ca0, 0x00000000}},  //   ola_, _здру, tfug,
  { {0x44291ed0, 0x69dc0039, 0x68120089, 0x00000000}},  //   nla_, ören, kāda,
  { {0x44291e3a, 0x6b9b02d8, 0x52df0044, 0x00000000}},  //   ila_, rfug, _নেতৃ,
  { {0x44290161, 0xf2df0011, 0x7c2201a3, 0x00000000}},  //   hla_, _ngâm_, _ekor,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xad1a00bd, 0x44291dfb, 0x3f8f020c, 0x00000000}},  //   _ווער, jla_, nggu_,
  { {0x7c29011f, 0x4429004f, 0xa3cc0309, 0x00000000}},  //   mler, dla_, लास_,
  { {0x64a60099, 0x6446288b, 0x44220027, 0x00000000}},  //   мага, _siki, _skk_,
  { {0x442919bd, 0x64460169, 0x69b20061, 0x00000000}},  //   fla_, _piki, _असती,
  { {0x7c29011f, 0x44290213, 0x62842ca1, 0x00000000}},  //   nler, gla_, trio,
  { {0xec09001d, 0xf1c9001c, 0xe297005e, 0x00000000}},  // [8480] yến_, रांन, мат_,
  { {0x4429000d, 0x7c2914c9, 0x6284271c, 0x00000000}},  //   ala_, hler, rrio,
  { {0x44292ca2, 0x7c290483, 0x64462ca3, 0x00000000}},  //   bla_, kler, _tiki,
  { {0x4429001a, 0xe8d60049, 0xd8d60049, 0x00000000}},  //   cla_, ווער_, וועט_,
  { {0x7c2905ba, 0x44200082, 0x7c3b0146, 0x00000000}},  //   dler, moi_, dmur,
  { {0x442010c3, 0xa3cc007d, 0x7bdd010f, 0x00000000}},  //   loi_, लाव_, ösun,
  { {0x7c29014a, 0x212c0051, 0x2ca50087, 0x00000000}},  //   fler, _ádh_, _cpld_,
  { {0x7c2901bf, 0x44201256, 0xdb000129, 0x00000000}},  //   gler, noi_, temà,
  { {0xc986017a, 0x34ab006e, 0x00000000, 0x00000000}},  //   муни, _चन्द,   ,
  { {0x4429011f, 0x7e620a23, 0x7c3b0020, 0x00000000}},  //   zla_, mpop, amur,
  { {0x4429011f, 0x44200efc, 0x7c2901e3, 0x00000000}},  //   yla_, koi_, bler,
  { {0xca48001d, 0x44200065, 0x7c29009d, 0x00000000}},  //   _lời_, joi_, cler,
  { {0x44290039, 0x8c430242, 0x7e620009, 0x00000000}},  //   vla_, _реце, npop,
  { {0x7c200010, 0x44292ca4, 0x7e6200e7, 0x00000000}},  //   lomr, wla_, ipop,
  { {0xa504007e, 0x442029b5, 0x00000000, 0x00000000}},  //   вятл, foi_,   ,
  { {0x44201199, 0x61ee00d9, 0x7c200479, 0x00000000}},  //   goi_, _albl, nomr,
  { {0x7e6211fc, 0x6d5a2161, 0x63ad11ae, 0x00000000}},  // [8490] jpop, _ofta, _činč,
  { {0x7c29011f, 0x7c3b016c, 0x68ed00b9, 0x00000000}},  //   zler, zmur, _řadi,
  { {0x44290a47, 0x7c29014a, 0x442001a3, 0x00000000}},  //   pla_, yler, boi_,
  { {0x6d5a0f4b, 0x44292ca5, 0x44200a16, 0x00000000}},  //   _afta, qla_, coi_,
  { {0x63ad161f, 0xed59005e, 0x7c29014a, 0x00000000}},  //   mean, пол_, vler,
  { {0x63ad002a, 0xed59041f, 0x69dc0039, 0x00000000}},  //   lean, чок_, örel,
  { {0x7c29011f, 0x09b70044, 0x7c3b2b67, 0x00000000}},  //   tler, জামা, tmur,
  { {0x63ad048c, 0x69ca00be, 0x7f85002c, 0x00000000}},  //   nean, _anfe, _سلطن,
  { {0x7c29011f, 0x7c3b023a, 0xdb00029d, 0x00000000}},  //   rler, rmur, temá,
  { {0x7c29011f, 0x63ad002a, 0xe1ff0036, 0x00000000}},  //   sler, hean, _swój_,
  { {0xbc680054, 0x7c29011f, 0x31710766, 0x00000000}},  //   _يمكن_, pler, _mezz_,
  { {0x69ca0211, 0x63ad0035, 0xcc56009b, 0x00000000}},  //   _enfe, jean, _טבעי_,
  { {0x7bcb022b, 0x63ad002a, 0x442000f4, 0x00000000}},  //   _ingu, dean, voi_,
  { {0xba390049, 0x65750065, 0x44201134, 0x00000000}},  //   _צײַט, gazh, woi_,
  { {0x44202ca6, 0xe1ff0036, 0x059402fd, 0x00000000}},  //   toi_, _twój_, _یادگ,
  { {0xca480011, 0x63ad04f0, 0x00000000, 0x00000000}},  //   _rời_, gean,   ,
  { {0x4420008d, 0x6f160036, 0xb5fb0010, 0x00000000}},  // [84a0] roi_, życz, mpán,
  { {0x44200110, 0x171b009b, 0x00000000, 0x00000000}},  //   soi_, _מופע,   ,
  { {0x63ad0051, 0x4420001a, 0xc22200a1, 0x00000000}},  //   bean, poi_, نکڑو,
  { {0x63ad094e, 0xca480011, 0x7e6200d9, 0x00000000}},  //   cean, _vời_, tpop,
  { {0xa2e3005e, 0x3f9a0036, 0x7c2001c4, 0x00000000}},  //   _бояд, ępu_, vomr,
  { {0x7e620dda, 0xa25b0082, 0x00000000, 0x00000000}},  //   rpop, _krôn,   ,
  { {0x3f6a026b, 0x987e00b9, 0x7e6201c5, 0x00000000}},  //   _ниво_, _péče_, spop,
  { {0x22b20173, 0xa2c4006e, 0xc4d30104, 0x00000000}},  //   _kņk_, रिप्, רגה_,
  { {0x7c20004e, 0xa3e8006e, 0x1dc70061, 0x00000000}},  //   romr, _भवन_, लाखत,
  { {0x7bcb1182, 0x7c200239, 0x2006002d, 0x00000000}},  //   _engu, somr, lioi_,
  { {0x2bb8007d, 0xbb4a0439, 0x63ad00e7, 0x00000000}},  //   _आसपा, _فلان_, yean,
  { {0xc02e001d, 0x9cd7009b, 0x7c6505f3, 0x00000000}},  //   _điều_, _רואה_, _شامل,
  { {0x09e60216, 0x63ad001a, 0x95cb00e3, 0x00000000}},  //   _подн, vean, пува_,
  { {0x69ca2ca7, 0xa7fd005d, 0xa2c4013d, 0x00000000}},  //   _unfe, nsız, रिन्,
  { {0x63ad002a, 0xa25b0181, 0xf4841123, 0x00000000}},  //   tean, _crôn, лутн,
  { {0x65750065, 0xdb000190, 0x00000000, 0x00000000}},  //   sazh, remæ,   ,
  { {0x63ad002a, 0x96350517, 0x6249251b, 0x00000000}},  // [84b0] rean, _иниц, _džon,
  { {0x63ad002a, 0x22b2000a, 0x00000000, 0x00000000}},  //   sean, _dņk_,   ,
  { {0x63ad001a, 0xdb000103, 0xddc9014a, 0x00000000}},  //   pean, lemä, _ateş,
  { {0x66070662, 0x200f064e, 0x22b20173, 0x00000000}},  //   lijk, ungi_, _fņk_,
  { {0x44390022, 0x2369001a, 0xdb0000b0, 0x00000000}},  //   _ihs_, mbaj_, nemä,
  { {0x6da5026b, 0xdee2007c, 0xada506b6, 0x00000000}},  //   тика, роши, такл,
  { {0x1fa7008b, 0x44390022, 0xdb00006c, 0x00000000}},  //   _праг, _khs_, hemä,
  { {0xdb0000b0, 0x3035007c, 0x00000000, 0x00000000}},  //   kemä, _ребё,   ,
  { {0x660702ae, 0x44392ca8, 0xef650095, 0x00000000}},  //   kijk, _mhs_, ğıdı_,
  { {0x7d79007a, 0x44390541, 0x3ea20039, 0x00000000}},  //   _آمار_, _lhs_, _äkta_,
  { {0x44390066, 0x9be70088, 0x2fcd01d6, 0x00000000}},  //   _ohs_, _підк, _kneg_,
  { {0x7bcb28c8, 0x6e230272, 0xeab100a1, 0x00000000}},  //   _ungu, lonb, _نعت_,
  { {0x26c400b9, 0x98a20089, 0x9f4f008e, 0x00000000}},  //   ímo_, ākā_, ligó_,
  { {0xa25b2ca9, 0x6e232caa, 0x44390253, 0x00000000}},  //   _prôn, nonb, _ahs_,
  { {0x44390093, 0xdce300b9, 0x2bb8013d, 0x00000000}},  //   _bhs_, vaně, _आसमा,
  { {0x3fbc0044, 0x44390387, 0x6f1e0036, 0x00000000}},  //   _অক্ষ, _chs_, ępcz,
  { {0xe61a00ed, 0x6e232cab, 0x9346025f, 0x00000000}},  // [84c0] _оди_, konb, тнае,
  { {0xf1aa007a, 0xa25b2811, 0x75eb014a, 0x00000000}},  //   باره_, _trôn, _yüzm,
  { {0x27e00f80, 0xdce300b9, 0x638608fc, 0x00000000}},  //   _koin_, raně, _игна,
  { {0x27e00038, 0x3dde01f3, 0xdb00043e, 0x00000000}},  //   _join_, _sotw_, lemå,
  { {0x6e23010f, 0x27e02cac, 0xa7fd005a, 0x00000000}},  //   fonb, _moin_, tsız,
  { {0x27e000f4, 0x27f20016, 0x2fcd0022, 0x00000000}},  //   _loin_, _llyn_, _eneg_,
  { {0x6026007e, 0xa7fd01df, 0xfd7900a1, 0x00000000}},  //   _адва, rsız, رشوں_,
  { {0xeb97012b, 0x27e0021e, 0x6ce30088, 0x00000000}},  //   вић_, _noin_, ріше,
  { {0xea000011, 0x2d9601e0, 0x3dde0b32, 0x00000000}},  //   _nhảy_, _арес, _totw_,
  { {0x09d00044, 0x99d00044, 0xdb0007c4, 0x00000000}},  //   িস্থ, িস্ক, jemå,
  { {0xfbd200a1, 0x6736000a, 0x7afd00c4, 0x00000000}},  //   _پتا_, _azyj, ústr,
  { {0x660700b5, 0x27e02cad, 0x9b0615c4, 0x00000000}},  //   wijk, _coin_, _изед,
  { {0xa3cc02d2, 0xea000011, 0x44392cae, 0x00000000}},  //   लाई_, _chảy_, _rhs_,
  { {0xa25b00f4, 0x4b37009b, 0x27e00051, 0x00000000}},  //   _drôl, _סרגל_, _eoin_,
  { {0x660702ae, 0x48e30098, 0xdb001bf0, 0x00000000}},  //   rijk, _војв, semä,
  { {0xe78701fe, 0xe41401fb, 0x27f20016, 0x00000000}},  //   _руко, адсь, _glyn_,
  { {0x6b820020, 0x98be0477, 0x68e8005b, 0x00000000}},  // [84d0] _mdog, matı_, lydd,
  { {0x35b50a1e, 0x2fcd0229, 0x98be0180, 0x00000000}},  //   _сбор, _sneg_, latı_,
  { {0x21a401fb, 0xc058008b, 0x68e8018e, 0x00000000}},  //   риєм, віч_, nydd,
  { {0x6b820020, 0x98be0279, 0x00000000, 0x00000000}},  //   _ndog, natı_,   ,
  { {0x6e230039, 0x68e80016, 0x3da90404, 0x00000000}},  //   tonb, hydd, екло_,
  { {0x63bd0145, 0x68e80039, 0x20040052, 0x00000000}},  //   _hasn, kydd, _emmi_,
  { {0x63bd0ecc, 0xa0b80679, 0x98be0279, 0x00000000}},  //   _kasn, _игру_, katı_,
  { {0x68e80016, 0x5f451095, 0x2fcd0022, 0x00000000}},  //   dydd, _منزل, _uneg_,
  { {0x63bd2690, 0x6b820016, 0xda650025, 0x00000000}},  //   _masn, _ddog, داعي,
  { {0x27e000f4, 0x68e80016, 0x63bd006c, 0x00000000}},  //   _soin_, fydd, _lasn,
  { {0x7794007a, 0x27e0023a, 0x68e80016, 0x00000000}},  //   لیغا, _poin_, gydd,
  { {0x8cc00164, 0xf64900a3, 0x27ea002b, 0x00000000}},  //   विरो, _זצ_, _ċans_,
  { {0x27e000b0, 0x00000000, 0x00000000, 0x00000000}},  //   _voin_,   ,   ,
  { {0x68e80016, 0x7bdb010e, 0x00000000, 0x00000000}},  //   bydd, ljuu,   ,
  { {0x7ae90010, 0x947901e1, 0xdb002caf, 0x00000000}},  //   lyet, ксту_, remå,
  { {0x63bd0016, 0x6f1b006b, 0x42d601ff, 0x00000000}},  //   _casn, _oxuc, лізу,
  { {0x7ae9023a, 0x070a067a, 0x7afb01a2, 0x00000000}},  // [84e0] nyet, _سيدي_, nzut,
  { {0x3c3a0065, 0x764b009d, 0x63bd0048, 0x00000000}},  //   mëve_, _égyp, _easn,
  { {0x3c3a0065, 0x63bd0016, 0x8136007e, 0x00000000}},  //   lëve_, _fasn, ухац,
  { {0x7ae901aa, 0xe3b2083e, 0xa2c40061, 0x00000000}},  //   kyet, _ارد_, रिद्,
  { {0x7e2a02f0, 0x3c3a0065, 0x63a408f4, 0x00000000}},  //   ніка_, nëve_, mfin,
  { {0x63a4000c, 0xdcba005e, 0x6b820026, 0x00000000}},  //   lfin, ещи_, _sdog,
  { {0xa1160151, 0x98be047f, 0xea000011, 0x00000000}},  //   _صورت, yatı_, _nhạy_,
  { {0x3c3a0065, 0x63a4051b, 0x200401a3, 0x00000000}},  //   këve_, nfin, _ummi_,
  { {0x68e80bc4, 0x3c3a0065, 0x63a4000c, 0x00000000}},  //   wydd, jëve_, ifin,
  { {0x7d1a0009, 0x68e82cb0, 0x3c3a0023, 0x00000000}},  //   _txts, tydd, dëve_,
  { {0xea00001d, 0x481504f1, 0xbc66013b, 0x00000000}},  //   _chạy_, имос, _свек,
  { {0x68e81996, 0x3c0c013e, 0x00000000, 0x00000000}},  //   rydd, těvu_,   ,
  { {0x63bd0107, 0x63a400bb, 0x68e80016, 0x00000000}},  //   _rasn, dfin, sydd,
  { {0x659501f9, 0x63bd0089, 0x63a40133, 0x00000000}},  //   јаву, _sasn, efin,
  { {0x63a40016, 0x63bd0089, 0x81da0044, 0x00000000}},  //   ffin, _pasn, ়সা_,
  { {0x75eb011f, 0x59d20164, 0x7bc0006c, 0x00000000}},  //   _müzi, तावर, ndmu,
  { {0x2ba60183, 0x629d0061, 0x9295022a, 0x00000000}},  // [84f0] क्या, _qqso, разц,
  { {0xddc9251e, 0x395e2cb1, 0x387e0022, 0x00000000}},  //   _svež, ncts_, ostr_,
  { {0x63a40190, 0x7afb0197, 0xfaf90006, 0x00000000}},  //   bfin, zzut, lbūt_,
  { {0xa2950ee0, 0x7ae9006b, 0x63a40094, 0x00000000}},  //   _камі, yyet, cfin,
  { {0x442b0022, 0xa5d8025a, 0x00000000, 0x00000000}},  //   _ikc_, _شبیر_,   ,
  { {0x7bc7001e, 0x644f0211, 0xfce508d6, 0x00000000}},  //   ējum, _hici, иоло,
  { {0xc212009b, 0x3c3a0065, 0x2c550089, 0x00000000}},  //   _והם_, zëve_, _kādi_,
  { {0x7afb09ce, 0x26c90107, 0xddc90521, 0x00000000}},  //   tzut, _orao_, _uvež,
  { {0x644f0375, 0xde590088, 0xa7fd0276, 0x00000000}},  //   _mici, _разі_, rpıl,
  { {0x644f1e3b, 0x7ae92cb2, 0x7bdb006c, 0x00000000}},  //   _lici, ryet, sjuu,
  { {0x7ae92cb3, 0x63a4000c, 0x6fca0061, 0x00000000}},  //   syet, yfin, _सोडू,
  { {0x644f000d, 0x3c3a0065, 0x7ae90f72, 0x00000000}},  //   _nici, tëve_, pyet,
  { {0x6457029d, 0xaa6702b8, 0x65770023, 0x00000000}},  //   _auxi, _стек, _bexh,
  { {0x3c3a008d, 0x644f001e, 0xdce30521, 0x00000000}},  //   rëve_, _aici, lanđ,
  { {0x387e0009, 0x3c3a0023, 0x2a7f01c3, 0x00000000}},  //   cstr_, sëve_, lsub_,
  { {0x3ead0119, 0x69c1000c, 0x442b00d2, 0x00000000}},  //   _opet_, ldle, _ckc_,
  { {0x63a4000c, 0x644f0211, 0x628d0061, 0x00000000}},  // [8500] rfin, _dici, grao,
  { {0x69c1004e, 0xe1f72cb4, 0x667b0049, 0x00000000}},  //   ndle, агу_, _שטיק,
  { {0x03a60242, 0x69c10016, 0x64570065, 0x00000000}},  //   _кино, idle, _guxi,
  { {0x8fa6026b, 0x657c0538, 0xbe8a0e82, 0x00000000}},  //   раде, larh, вске_,
  { {0x68120089, 0x3ead0022, 0x44320133, 0x00000000}},  //   gādi, _cpet_, mly_,
  { {0x44320038, 0x657c000c, 0x644400b0, 0x00000000}},  //   lly_, narh, lmii,
  { {0xeb0e006e, 0x69c100ab, 0xed57003b, 0x00000000}},  //   ाप्त_, ddle, шој_,
  { {0x8aa60099, 0x3178010f, 0x443200ab, 0x00000000}},  //   арод, _herz_, nly_,
  { {0x44320051, 0x1ea90774, 0x7d0f006b, 0x00000000}},  //   ily_, _مالي_, _əksə,
  { {0x44322cb5, 0x2c0b06c6, 0x657c2cb6, 0x00000000}},  //   hly_, _یعنی_, jarh,
  { {0x65770065, 0x44322cb7, 0x395e0606, 0x00000000}},  //   _rexh, kly_, rcts_,
  { {0xcb6a0184, 0x387e01a2, 0x65770f3f, 0x00000000}},  //   _раде_, rstr_, _sexh,
  { {0x44322cb8, 0x644f0197, 0x6701007d, 0x00000000}},  //   dly_, _rici, _लेखक_,
  { {0x644f0207, 0xfaf91104, 0x2b9200a1, 0x00000000}},  //   _sici, rbūt_, _ایکس,
  { {0x44320606, 0x644f001a, 0xe7870072, 0x00000000}},  //   fly_, _pici, _купо,
  { {0x26c9001d, 0x44320de7, 0x645700f8, 0x00000000}},  //   _trao_, gly_, _vuxi,
  { {0xf1d2001c, 0xd251031d, 0x657c02e7, 0x00000000}},  // [8510] सांन, سنا_, barh,
  { {0x644f0016, 0x51f8007e, 0x628d0032, 0x00000000}},  //   _wici, аную_, rrao,
  { {0x44322cb9, 0x644f06f9, 0x3ead01d9, 0x00000000}},  //   bly_, _tici, _spet_,
  { {0x442b00ca, 0x44320133, 0x2a66012d, 0x00000000}},  //   _ukc_, cly_, _otob_,
  { {0x4429002d, 0x683d00f4, 0x7a3d00f4, 0x00000000}},  //   moa_, céde, lète,
  { {0x442921be, 0x2a7f0009, 0x68120089, 0x00000000}},  //   loa_, vsub_, rādi,
  { {0x22592cba, 0xa3cc0061, 0x7a3d0e28, 0x00000000}},  //   _husk_, लाच_, nète,
  { {0x44292cbb, 0x5f940088, 0x2a7f0004, 0x00000000}},  //   noa_, _мист, tsub_,
  { {0x8d8706c6, 0x4e940025, 0x4429002d, 0x00000000}},  //   _نشان, _وشكر, ioa_,
  { {0x44292cbc, 0xe9d9013b, 0x44322cbd, 0x00000000}},  //   hoa_, уко_, zly_,
  { {0x44292cbe, 0x69c12cbf, 0x44320062, 0x00000000}},  //   koa_, rdle, yly_,
  { {0x6249016c, 0x44290315, 0x98160025, 0x00000000}},  //   _džoi, joa_, إبدا,
  { {0xf3ff0055, 0x4429117b, 0x290b0036, 0x00000000}},  //   ্কার_, doa_, ńca_,
  { {0xd99902fd, 0x69dc0039, 0x7c2900c7, 0x00000000}},  //   _صنعت_, öret, loer,
  { {0x657c2cc0, 0x443200ab, 0x44290315, 0x00000000}},  //   rarh, tly_, foa_,
  { {0x44292cc1, 0x7ddd01aa, 0x245c01dc, 0x00000000}},  //   goa_, _vèsy, _vím_,
  { {0x44320038, 0x776401f3, 0x2360050f, 0x00000000}},  // [8520] rly_, _ifix, rcij_,
  { {0x245c2cc2, 0x2ca90036, 0x7ae40045, 0x00000000}},  //   _tím_, łady_, _àite,
  { {0x44320038, 0xef6501f6, 0x4429022b, 0x00000000}},  //   ply_, ğını_, boa_,
  { {0xea00001d, 0xef650279, 0x7c2901d6, 0x00000000}},  //   _thầy_, şını_, joer,
  { {0x31780066, 0x1aec0044, 0x7c290085, 0x00000000}},  //   _terz_, _জেনে_, doer,
  { {0x6296014a, 0x21f60025, 0x75eb006b, 0x00000000}},  //   muyo, _اكسس, _füzu,
  { {0xec09001d, 0x62962cc3, 0x00000000, 0x00000000}},  //   yết_, luyo,   ,
  { {0x7c290066, 0x660e006b, 0x00000000, 0x00000000}},  //   goer, hibk,   ,
  { {0x6296014a, 0xdcf8012d, 0x00000000, 0x00000000}},  //   nuyo, mavč,   ,
  { {0x4429002d, 0xa2bb0049, 0x660e04cb, 0x00000000}},  //   zoa_, נמיט, jibk,
  { {0x7c292cc4, 0x00000000, 0x00000000, 0x00000000}},  //   boer,   ,   ,
  { {0x3137019b, 0x4429002d, 0x2c7500a1, 0x00000000}},  //   מנים_, xoa_, _بیٹھ_,
  { {0x44291b03, 0x63b6006b, 0x858b07d0, 0x00000000}},  //   voa_, deyn, лёва_,
  { {0x225902e7, 0x00000000, 0x00000000, 0x00000000}},  //   _rusk_,   ,   ,
  { {0x44292cc5, 0x2d9e0066, 0x00000000, 0x00000000}},  //   toa_, _mcte_,   ,
  { {0x7a3d009d, 0x00000000, 0x00000000, 0x00000000}},  //   rète,   ,   ,
  { {0x44290234, 0x8af7006b, 0x816b01fc, 0x00000000}},  // [8530] roa_, _çəti, греб_,
  { {0x44292cc6, 0xf77f1323, 0xbb3b0049, 0x00000000}},  //   soa_, laç_, רעמי,
  { {0x9735026c, 0x442921be, 0x53c40204, 0x00000000}},  //   _دکھا, poa_, _लोकश,
  { {0x2d9e2cc7, 0x62960058, 0x753a01a2, 0x00000000}},  //   _acte_, buyo, ütze,
  { {0x539a00b6, 0x7c29017c, 0x201c0181, 0x00000000}},  //   _דירו, voer, évia_,
  { {0xdc3c0089, 0x00000000, 0x00000000, 0x00000000}},  //   kšēj,   ,   ,
  { {0x7c290116, 0x0cd70044, 0xdddb00e5, 0x00000000}},  //   toer, তন্ত, _avuţ,
  { {0x7bc2009d, 0x2d9e0023, 0x61e70087, 0x00000000}},  //   _caou, _ecte_, _hojl,
  { {0x0ae60057, 0x7c2901b5, 0x200f00ca, 0x00000000}},  //   ждый_, roer, migi_,
  { {0x88850326, 0xf8a9004c, 0xc9a6007c, 0x00000000}},  //   олож, авок_, овье_,
  { {0xdb09004a, 0x99580089, 0x00000000, 0x00000000}},  //   rdeñ, kšņi_,   ,
  { {0x4a75007e, 0x69dc0039, 0x200f0f81, 0x00000000}},  //   _дыкт, örer, nigi_,
  { {0xe9d92c8c, 0xddc20089, 0x9f442cc8, 0x00000000}},  //   _вкл_, lpoš, _comè_,
  { {0xdce800b9, 0xf3f10011, 0x6b9b010e, 0x00000000}},  //   _nedě, ện_, lgug,
  { {0x2c550089, 0x7bc2009d, 0xf8a80439, 0x00000000}},  //   _tādu_, _yaou, _هديه_,
  { {0x69c32cc9, 0x6b9b06ad, 0x7e692b51, 0x00000000}},  //   _hane, ngug, _otep,
  { {0xe29a0822, 0x2c55001e, 0x69c3006c, 0x00000000}},  // [8540] раз_, _kāds_, _kane,
  { {0x69c302d5, 0xea00001d, 0x09b70055, 0x00000000}},  //   _jane, _thấy_, জাকা,
  { {0x69c32cca, 0xddc2016c, 0x09ac0044, 0x00000000}},  //   _mane, jpoš, _কোডা,
  { {0x69c3022b, 0xd7dd0061, 0x888a0049, 0x00000000}},  //   _lane, यायच, שרײַ,
  { {0x7bc20bf2, 0xb21b0190, 0x6e2a0bc7, 0x00000000}},  //   _raou, _kvæl, tofb,
  { {0x62860107, 0x7bc2009d, 0xdc8a19d4, 0x00000000}},  //   _ivko, _saou, асил_,
  { {0xb5fb1f1e, 0xf77f014a, 0xd7ca0061, 0x00000000}},  //   mpát, yaç_, ियाच,
  { {0x7a3404bd, 0xdfd20014, 0x62840006, 0x00000000}},  //   màti, _تير_, osio,
  { {0x2ba60201, 0x2fc60b3d, 0x38690087, 0x00000000}},  //   क्षा, mdog_, _čara_,
  { {0x094a0751, 0xc333009b, 0x62840016, 0x00000000}},  //   ични_, ווח_, isio,
  { {0x69c301d9, 0x61e30788, 0x5fcf0061, 0x00000000}},  //   _dane, önli, _सोडल,
  { {0x62840065, 0x2fc6011c, 0x69c30d31, 0x00000000}},  //   ksio, ndog_, _eane,
  { {0x0aba0084, 0x7a2f01e3, 0xf77f014a, 0x00000000}},  //   _خطاب_, tøtt, raç_,
  { {0x69c30ec8, 0xfba60164, 0x3ea60e3f, 0x00000000}},  //   _gane, क्रम, itot_,
  { {0xd37b02e9, 0x09ac0055, 0xf77f0129, 0x00000000}},  //   ича_, _কোথা, paç_,
  { {0x248d01d9, 0x683f001e, 0x6b800020, 0x00000000}},  //   čem_, _lūdz, namg,
  { {0x27e91a5e, 0x69c3004a, 0x2fc6005b, 0x00000000}},  // [8550] _ioan_, _yane, ddog_,
  { {0x69c3049a, 0x27e90011, 0xdb0000c4, 0x00000000}},  //   _xane, _hoan_, lemó,
  { {0x62840052, 0xef6501df, 0x200f0edb, 0x00000000}},  //   asio, şımı_, tigi_,
  { {0x27e92ccb, 0xdb0b1732, 0x00000000, 0x00000000}},  //   _joan_, _magò,   ,
  { {0x200f2579, 0x33da00a0, 0x27e92c57, 0x00000000}},  //   rigi_, _החרד, _moan_,
  { {0xdd910379, 0x8e080088, 0x27e9190f, 0x00000000}},  //   روع_, онів_, _loan_,
  { {0xc18200a1, 0x69c5000c, 0x69c30ad0, 0x00000000}},  //   _سینٹ, _óhei, _rane,
  { {0x251c01ce, 0xcfb4005e, 0x68360802, 0x00000000}},  //   יווא, _обсъ, rádk,
  { {0x69c322a6, 0x200d2ccc, 0xddc20c0a, 0x00000000}},  //   _pane, _imei_, spoš,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c30004, 0xfd560049, 0xd90f00a1, 0x00000000}},  //   _vane, _זשעי_, کیں_,
  { {0x69c3050c, 0x628414f9, 0x3f9d0066, 0x00000000}},  //   _wane, ysio, ngwu_,
  { {0x27e92ccd, 0x00000000, 0x00000000, 0x00000000}},  //   _doan_,   ,   ,
  { {0x2c550089, 0x249801a2, 0x00000000, 0x00000000}},  //   _tāds_, turm_,   ,
  { {0x79811607, 0x6f020197, 0x8cce013d, 0x00000000}},  //   malw, zzoc, थियो,
  { {0x62840004, 0x683d2cce, 0x27e90a49, 0x00000000}},  //   tsio, lédn, _goan_,
  { {0x2bad001c, 0x62840006, 0x9f440285, 0x00000000}},  // [8560] झ्या, usio, _tomé_,
  { {0x200d00c4, 0x2fc60146, 0x5bb80204, 0x00000000}},  //   _amei_, wdog_, _आस्व,
  { {0x62842ccf, 0xfbbd0204, 0xd6250076, 0x00000000}},  //   ssio, ्याम, _تعيي,
  { {0x62840065, 0x61fe0009, 0x79810007, 0x00000000}},  //   psio, shpl, halw,
  { {0x78820047, 0xb5fb0211, 0xed5000a1, 0x00000000}},  //   _kívá, mpár, چھا_,
  { {0x645e2174, 0x6f0200b5, 0x3ea622ec, 0x00000000}},  //   _kupi, rzoc, rtot_,
  { {0x657e2a53, 0x3ea61fbd, 0x32430088, 0x00000000}},  //   _meph, stot_, _черг,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x79810016, 0x8b6600a1, 0x20070023, 0x00000000}},  //   falw, _ہاشم, ënie_,
  { {0xeaaf0380, 0x3dc5018e, 0x39580030, 0x00000000}},  //   اعي_, _galw_, ørs_,
  { {0x645e1b1b, 0xb5fb0010, 0x4993009e, 0x00000000}},  //   _nupi, kpár, ریٹر,
  { {0x1ae600e3, 0x20070068, 0x00000000, 0x00000000}},  //   _ноем, énix_,   ,
  { {0xa3c002d2, 0xe6670242, 0x645e01d6, 0x00000000}},  //   ंजन_, ятно, _aupi,
  { {0x09e301f9, 0x657e014a, 0x645e0190, 0x00000000}},  //   _почн, _ceph, _bupi,
  { {0x657e0093, 0x69c8018e, 0x27e92cd0, 0x00000000}},  //   _deph, mdde, _toan_,
  { {0x03c405f6, 0x69c80016, 0x645e2cd1, 0x00000000}},  //   нсум, ldde, _dupi,
  { {0x69c80016, 0x683d009d, 0x00000000, 0x00000000}},  // [8570] odde, lédo,   ,
  { {0x69c80016, 0x657e00d9, 0xb5fb00fd, 0x00000000}},  //   ndde, _geph, rpás,
  { {0x69c82cd2, 0xdb0b000c, 0x645e1794, 0x00000000}},  //   idde, _lagð, _gupi,
  { {0x657e01d6, 0x68360181, 0x3f15003b, 0x00000000}},  //   _zeph, tádi, мдес,
  { {0x69d800c7, 0x63ad1af8, 0x6249003b, 0x00000000}},  //   _onve, mfan, _džor,
  { {0x63ad0016, 0xfe70023c, 0x68360387, 0x00000000}},  //   lfan, ادن_, rádi,
  { {0x645800f4, 0x63ad0020, 0x79812027, 0x00000000}},  //   _évit, ofan, valw,
  { {0xeb9910f2, 0x69d80018, 0x63ad010f, 0x00000000}},  //   ции_, _anve, nfan,
  { {0x79810058, 0x06e30044, 0x7f580256, 0x00000000}},  //   talw, নৈতি, _хаус_,
  { {0x7d180051, 0x63ad1e28, 0xe2a601e5, 0x00000000}},  //   éasú, hfan, æðin_,
  { {0x39450373, 0xf8af0123, 0x02ba006e, 0x00000000}},  //   ьног, اکت_, _उन्न,
  { {0x6d412cd3, 0xe73a04b6, 0x645e023a, 0x00000000}},  //   _izla, жем_, _rupi,
  { {0x63ad2cd4, 0x7c2d0995, 0x7bd901c3, 0x00000000}},  //   dfan, čard, _inwu,
  { {0x2bbd007d, 0x645e1e47, 0x6aa9012d, 0x00000000}},  //   ्यवा, _pupi, mtef,
  { {0x64a32cd5, 0x6aa9032e, 0x683d009d, 0x00000000}},  //   кара, ltef, cédo,
  { {0x7bc900f4, 0x044301fc, 0x680b0036, 0x00000000}},  //   ndeu, весн, zędz,
  { {0x6aa9002b, 0xc1ea085f, 0x9f4a0276, 0x00000000}},  // [8580] ntef, одаж_, ümün_,
  { {0x26d20061, 0x3f8d00d4, 0x422300e2, 0x00000000}},  //   _iryo_, _adeu_, вдув,
  { {0x764000b9, 0x106a007c, 0xafe60088, 0x00000000}},  //   ůmys, цией_, можл,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c80ee6, 0x7bc92cd6, 0x6d410145, 0x00000000}},  //   ydde, ddeu, _azla,
  { {0xb8060055, 0x44220052, 0x00000000, 0x00000000}},  //   োকিত_, _hjk_,   ,
  { {0xdb0b009f, 0xd83911af, 0x00000000, 0x00000000}},  //   _sagð, luče_,   ,
  { {0xc3fb0049, 0x69c8005b, 0x6143013b, 0x00000000}},  //   ַליש, wdde, _реса,
  { {0x44220022, 0xe7dd0061, 0xd83900ca, 0x00000000}},  //   _mjk_, यासप, nuče_,
  { {0x44220022, 0x69c8005b, 0x00000000, 0x00000000}},  //   _ljk_, udde,   ,
  { {0x69c8068a, 0x44220093, 0x26d20022, 0x00000000}},  //   rdde, _ojk_, _aryo_,
  { {0x7e601659, 0xb8e603d7, 0x628b0010, 0x00000000}},  //   _kump, _उन_, ágok,
  { {0x26d200d9, 0x7e600a6b, 0x7c220009, 0x00000000}},  //   _cryo_, _jump, _ijor,
  { {0x69d82cd7, 0x7e600093, 0x7c220030, 0x00000000}},  //   _unve, _mump, _hjor,
  { {0x395c049a, 0x7e600127, 0x63ad000c, 0x00000000}},  //   _igvs_, _lump, tfan,
  { {0xeac8001d, 0x60c90089, 0x64460066, 0x00000000}},  //   _kỹ_, _ņemo, _chki,
  { {0x4caa0055, 0x63ad000c, 0x7e600093, 0x00000000}},  // [8590] কিটু, rfan, _nump,
  { {0xeac8001d, 0x63ad01e5, 0x9f44004a, 0x00000000}},  //   _mỹ_, sfan, _comí_,
  { {0x2258037f, 0x63ad010f, 0x44220087, 0x00000000}},  //   _dirk_, pfan, _fjk_,
  { {0x66150303, 0x7e600133, 0x62960133, 0x00000000}},  //   lizk, _bump, bryo,
  { {0x7e602cd8, 0x644d16c6, 0x6d410036, 0x00000000}},  //   _cump, mmai, _szla,
  { {0x644d0ac2, 0x0dc8003b, 0xc27a009b, 0x00000000}},  //   lmai, дући_, _מרשי,
  { {0x7c221fbc, 0xdce30089, 0x271b013d, 0x00000000}},  //   _bjor, manī, नपुर_,
  { {0x644d0052, 0x6aa901bf, 0x3869002b, 0x00000000}},  //   nmai, ttef, _ċar_,
  { {0x7bc90007, 0x7c220107, 0x7e600145, 0x00000000}},  //   rdeu, _djor, _gump,
  { {0xdf44008b, 0x89a901e0, 0x644d0051, 0x00000000}},  //   _рэсп, чков_, hmai,
  { {0x07a600c2, 0x6d410089, 0xf1b2007b, 0x00000000}},  //   нанн, _uzla, נסט_,
  { {0x7c220cb2, 0x60da0010, 0x00000000, 0x00000000}},  //   _gjor, _átme,   ,
  { {0x644d007f, 0xdce10006, 0xaffa0049, 0x00000000}},  //   dmai, _pelė, פּטי,
  { {0x7c3b069e, 0x6a1700e9, 0x3ea20039, 0x00000000}},  //   llur, _تبصر, _åkte_,
  { {0x2ba601f5, 0x7c3b0abf, 0x44220145, 0x00000000}},  //   क्का, olur, _pjk_,
  { {0xa7fd006b, 0x62960173, 0x7c3b011c, 0x00000000}},  //   lqın, tryo, nlur,
  { {0x130a008b, 0x7c3b2cd9, 0x66150032, 0x00000000}},  // [85a0] чнай_, ilur, bizk,
  { {0xe7ac007d, 0x7e6004cb, 0x644d21e7, 0x00000000}},  //   ट्रप, _rump, amai,
  { {0x7e60170b, 0x644d2957, 0x22582cda, 0x00000000}},  //   _sump, bmai, _virk_,
  { {0x4ea603e0, 0x644d2cdb, 0x00000000, 0x00000000}},  //   ерка, cmai,   ,
  { {0x4420018e, 0x4432011c, 0x61f30030, 0x00000000}},  //   mni_, moy_, ådlø,
  { {0x44202462, 0x4432006a, 0xf2df0011, 0x00000000}},  //   lni_, loy_, _ngây_,
  { {0x44201eb1, 0xeac80011, 0x6143007e, 0x00000000}},  //   oni_, _sỹ_, _бера,
  { {0x44200359, 0x4432006a, 0x2bba0054, 0x00000000}},  //   nni_, noy_, ساعة_,
  { {0x61ee0292, 0x7017009b, 0x7e600058, 0x00000000}},  //   _kobl, _נחמד_, _uump,
  { {0xfce60407, 0x44200065, 0x4432011c, 0x00000000}},  //   _позо, hni_, hoy_,
  { {0x61ee049a, 0x4432011c, 0x7c3b0b50, 0x00000000}},  //   _mobl, koy_, blur,
  { {0x442000ee, 0x443200ab, 0x27ff000c, 0x00000000}},  //   jni_, joy_, óun_,
  { {0xd6d8085f, 0x4432011c, 0x644d0c4b, 0x00000000}},  //   нтр_, doy_, vmai,
  { {0x44202cdc, 0x63a600ab, 0x6b82011c, 0x00000000}},  //   eni_, _ackn, _heog,
  { {0x4420009f, 0x644d0781, 0x66150032, 0x00000000}},  //   fni_, tmai, rizk,
  { {0x442013f0, 0x443212b5, 0x493b009b, 0x00000000}},  //   gni_, goy_, _מגוו,
  { {0x61ee022c, 0x23690b94, 0x644d2cdd, 0x00000000}},  // [85b0] _bobl, rcaj_, rmai,
  { {0x44201a0c, 0x44f5003b, 0x644d0094, 0x00000000}},  //   ani_, _апос, smai,
  { {0x442001d9, 0x4432011c, 0x61ee0779, 0x00000000}},  //   bni_, boy_, _dobl,
  { {0x4420037e, 0x69ca096e, 0x6b8204eb, 0x00000000}},  //   cni_, _lafe, _neog,
  { {0x539a019b, 0x69a10204, 0x6da50900, 0x00000000}},  //   _קישו, _खाली, вила,
  { {0x44d1010a, 0x61ee0016, 0xdce8001e, 0x00000000}},  //   _ką_, _gobl, _nedē,
  { {0x6b82012b, 0x44d1093c, 0x7c3b001a, 0x00000000}},  //   _beog, _ją_, tlur,
  { {0xa1580822, 0xbbbd0061, 0xdce10035, 0x00000000}},  //   _часу_, ्येक, _află,
  { {0x2fc0006c, 0x9f4400f6, 0x7c3b00f8, 0x00000000}},  //   õige_, _gomà_, rlur,
  { {0x44200047, 0x69ca001a, 0x98b3089f, 0x00000000}},  //   zni_, _cafe, žeči_,
  { {0xd7dd0365, 0x44202cde, 0x7c3b0035, 0x00000000}},  //   यांच, yni_, plur,
  { {0x5b151fa3, 0x2d872cdf, 0x24b90044, 0x00000000}},  //   _имет, lane_, ুমাহ,
  { {0x442001d9, 0x25de0061, 0x2d870035, 0x00000000}},  //   vni_, खाली_, oane_,
  { {0xa7fd005f, 0x7bcb0129, 0x4420010b, 0x00000000}},  //   qqın, _hagu, wni_,
  { {0x44320219, 0x7bcb011c, 0x61ee008e, 0x00000000}},  //   toy_, _kagu, _robl,
  { {0x4420000d, 0x7bcb033b, 0x69ca2047, 0x00000000}},  //   uni_, _jagu, _zafe,
  { {0x44200198, 0x61ee1406, 0x7bcb24c4, 0x00000000}},  // [85c0] rni_, _pobl, _magu,
  { {0x7bcb022b, 0x2d8700ee, 0x4432014a, 0x00000000}},  //   _lagu, jane_, soy_,
  { {0x44200209, 0x2d87092c, 0x44320058, 0x00000000}},  //   pni_, dane_, poy_,
  { {0x7bcb27bc, 0xcbbc0044, 0xef1a007c, 0x00000000}},  //   _nagu, _আচ্ছ, мме_,
  { {0x2d872ce0, 0xa2c1013d, 0xe7aa006e, 0x00000000}},  //   fane_, रौद्, _कानप,
  { {0x2d87092c, 0x63a4000c, 0x998c00b9, 0x00000000}},  //   gane_, lgin, vodů_,
  { {0x6abc02f4, 0x7bcb20be, 0x69ca2ce1, 0x00000000}},  //   ्ट्र, _bagu, _rafe,
  { {0x63a42ce2, 0x69ca00ab, 0x7bcb00b2, 0x00000000}},  //   ngin, _safe, _cagu,
  { {0x5a340797, 0xf413019b, 0x67ff0065, 0x00000000}},  //   лнит, יפה_, _bëjn,
  { {0x2d870036, 0x683d00f4, 0xbd8a0014, 0x00000000}},  //   cane_, médi, _آنان_,
  { {0x7bcb01e5, 0x78aa0009, 0x683d009d, 0x00000000}},  //   _fagu, _qqfv, lédi,
  { {0x3f841a56, 0x63a400bb, 0x7983040f, 0x00000000}},  //   _jemu_, jgin, _eenw,
  { {0x44d10046, 0x69ca0fe2, 0x8a060242, 0x00000000}},  //   _są_, _tafe, _изде,
  { {0x7bc00004, 0x7983158a, 0x63a42ce3, 0x00000000}},  //   lemu, _genw, egin,
  { {0x7bcb1588, 0xa7fd006b, 0x6d5c0027, 0x00000000}},  //   _yagu, lqım, _úrad,
  { {0x7bc00169, 0x63a415c1, 0x79880016, 0x00000000}},  //   nemu, ggin, ladw,
  { {0x36d500a8, 0x2d871fa4, 0x81ac0044, 0x00000000}},  // [85d0] _сопр, yane_, কজন_,
  { {0x44d10bd7, 0x26c90107, 0x7bc0010e, 0x00000000}},  //   _tą_, _isao_, hemu,
  { {0x7bc0021e, 0x21640517, 0xcfb10044, 0x00000000}},  //   kemu, ртуг, _ঘোষন,
  { {0xf8b3007b, 0x2d870046, 0x3f84037e, 0x00000000}},  //   ישע_, wane_, _cemu_,
  { {0x8f34008b, 0x539a00b6, 0x7bcb01bc, 0x00000000}},  //   аецц, _אירו, _ragu,
  { {0x7bcb011c, 0x3dcc018e, 0x645d2ce4, 0x00000000}},  //   _sagu, _cadw_, _hisi,
  { {0x2d8725fb, 0x645d000b, 0x7bcb0065, 0x00000000}},  //   rane_, _kisi, _pagu,
  { {0x2bda0183, 0x7bc0006c, 0x645d20a1, 0x00000000}},  //   भागा, gemu, _jisi,
  { {0x2d870056, 0x79830016, 0x7bcb032c, 0x00000000}},  //   pane_, _penw, _vagu,
  { {0x7bcb1f0f, 0x3dcc0016, 0x44390093, 0x00000000}},  //   _wagu, _gadw_, _lks_,
  { {0x7bcb006a, 0x44391651, 0x63a40036, 0x00000000}},  //   _tagu, _oks_, ygin,
  { {0x2d85068f, 0x645d1111, 0x66e601ee, 0x00000000}},  //   _hele_, _nisi, гома,
  { {0x2d8501d6, 0xa3e7006e, 0xf4090044, 0x00000000}},  //   _kele_, पान_, রচার_,
  { {0x64a60001, 0x645d0da3, 0x9663007c, 0x00000000}},  //   лага, _aisi, скре,
  { {0x69c10483, 0x645d2ce5, 0x5e56007b, 0x00000000}},  //   mele, _bisi, טישע_,
  { {0x69c1011f, 0x2d851848, 0x63a40006, 0x00000000}},  //   lele, _lele_, ugin,
  { {0x645d020c, 0xe29701f9, 0x63a4046e, 0x00000000}},  // [85e0] _disi, лат_, rgin,
  { {0x645d0124, 0x69c1011f, 0x44390374, 0x00000000}},  //   _eisi, nele, _eks_,
  { {0x34aa0d99, 0x5a160049, 0x69c100e7, 0x00000000}},  //   _явно_, נקען_, iele,
  { {0x69c1006c, 0x645d011c, 0xf3f10011, 0x00000000}},  //   hele, _gisi, ệt_,
  { {0x69c102ae, 0x2d852ce6, 0x877b0049, 0x00000000}},  //   kele, _bele_, גאני,
  { {0x69c10047, 0x2d85000d, 0x645d0020, 0x00000000}},  //   jele, _cele_, _zisi,
  { {0x3f8403e9, 0x2d852ce7, 0x7c2d0bf8, 0x00000000}},  //   _temu_, _dele_, čarn,
  { {0x683d2ce8, 0xab5d0036, 0x29180af6, 0x00000000}},  //   pédi, zeże, úram_,
  { {0x69c10047, 0x7bc00fad, 0x2d96013b, 0x00000000}},  //   fele, remu, _брес,
  { {0xdcfa001a, 0x2d8500bb, 0x7bc001a3, 0x00000000}},  //   _cetă, _gele_, semu,
  { {0x7988018e, 0x7bc00093, 0xb21b068f, 0x00000000}},  //   radw, pemu, _kvær,
  { {0x2d85037e, 0x3157012f, 0xa835003b, 0x00000000}},  //   _zele_, טיין_, ремљ,
  { {0x69c121b8, 0xcaf6023c, 0xa7fd006b, 0x00000000}},  //   bele, _حساب, qqım,
  { {0x69c1011f, 0x44390093, 0x645d09f3, 0x00000000}},  //   cele, _sks_, _sisi,
  { {0xe4e40106, 0x44392ce9, 0x645d11f2, 0x00000000}},  //   бітн, _pks_, _pisi,
  { {0x645d0d82, 0xe787003b, 0x7a3d01aa, 0x00000000}},  //   _qisi, _суко, vèti,
  { {0x521501f9, 0xf1e00061, 0x20070065, 0x00000000}},  // [85f0] адат, नांन, ënim_,
  { {0x947500a6, 0x7a3d0129, 0x91e4003b, 0x00000000}},  //   _نگرا, tèti, бође,
  { {0x2d850263, 0x645d09fc, 0x628d00b0, 0x00000000}},  //   _rele_, _tisi, ssao,
  { {0x69c109c8, 0x2d8501aa, 0xd1380140, 0x00000000}},  //   zele, _sele_, уху_,
  { {0x69c1011f, 0x2d850181, 0x66f7007d, 0x00000000}},  //   yele, _pele_, ुनिक_,
  { {0x2bda02d2, 0x2004005f, 0x69c1008e, 0x00000000}},  //   _मोबा, _elmi_, xele,
  { {0x69c10047, 0x2d852cea, 0x06380049, 0x00000000}},  //   vele, _vele_, אנגט_,
  { {0x67ff0065, 0x2d85005b, 0x69c12ceb, 0x00000000}},  //   _bëjm, _wele_, wele,
  { {0x69c10047, 0x8004022a, 0xbda70a4f, 0x00000000}},  //   tele, _учре, _محاو,
  { {0x7c8711a6, 0x2ba7001c, 0x27e001d5, 0x00000000}},  //   _буде, _गावा, _snin_,
  { {0xd9450001, 0x7cdc0035, 0x27e00022, 0x00000000}},  //   рени, _cără, _pnin_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c1000b, 0x09e5007c, 0x6249251b, 0x00000000}},  //   pele, _волн, _džoz,
  { {0x78a10302, 0xcaf400a1, 0x3e6b00ea, 0x00000000}},  //   pulv, _دسمب, _møt_,
  { {0x7afb006b, 0x765e00e7, 0xd9390049, 0x00000000}},  //   lyut, _vipy, _בײַש,
  { {0x3ced03d7, 0x7ae90146, 0x93ca009e, 0x00000000}},  //   _अपने_, oxet, کاڑہ_,
  { {0x43752043, 0x883b009b, 0x826800a1, 0x00000000}},  // [8600] суст, _בתקו, اشرہ_,
  { {0xe1ff2363, 0xb21b02cc, 0x935901e1, 0x00000000}},  //   _stór_, _svær, урсу_,
  { {0x61fe05c6, 0x6f66012b, 0x661c0006, 0x00000000}},  //   rkpl, авез, mirk,
  { {0x7a3d01aa, 0x661c0284, 0x7afb0058, 0x00000000}},  //   pètw, lirk, kyut,
  { {0xdfcf0379, 0x683d00f4, 0x00000000, 0x00000000}},  //   بين_, cédu,   ,
  { {0x661c2cec, 0x27350011, 0xd0b3006b, 0x00000000}},  //   nirk, ụng_, hşət,
  { {0x6da303f3, 0xb21b0030, 0x7f490325, 0x00000000}},  //   ција, _tvær, _ezeq,
  { {0x661c003f, 0x200400e0, 0x00000000, 0x00000000}},  //   hirk, _ulmi_,   ,
  { {0x15f802fb, 0x661c01a3, 0xa3e70164, 0x00000000}},  //   ुसार_, kirk, पात_,
  { {0x7cdc001a, 0x99660545, 0x00000000, 0x00000000}},  //   _pără, штил,   ,
  { {0x661c023a, 0x6d480213, 0xddc90064, 0x00000000}},  //   dirk, _uzda, _uteš,
  { {0xeb970745, 0x00000000, 0x00000000, 0x00000000}},  //   _виц_,   ,   ,
  { {0x661c033b, 0x00000000, 0x00000000, 0x00000000}},  //   firk,   ,   ,
  { {0x1866012b, 0xfa330014, 0x661c2ced, 0x00000000}},  //   _књиг, _ورود, girk,
  { {0xe65401fb, 0xb8940025, 0xedf4006e, 0x00000000}},  //   івсь, _البع, _अवैध_,
  { {0xd37826f0, 0x53980088, 0xab5d0036, 0x00000000}},  //   ичу_, ився_, leża,
  { {0x2458007c, 0xe167003b, 0x9268003b, 0x00000000}},  // [8610] рать_, ађен, арха_,
  { {0x661c2cee, 0x683d009d, 0x00000000, 0x00000000}},  //   cirk, rédu,   ,
  { {0x92e70044, 0x35f80014, 0x8f00007e, 0x00000000}},  //   বনে_, _خريد_, кiя_,
  { {0x4e950025, 0x00000000, 0x00000000, 0x00000000}},  //   مشتر,   ,   ,
  { {0x645a1339, 0x201c0129, 0xc2570014, 0x00000000}},  //   ïtie, èvia_, _نخست,
  { {0xee38111f, 0x72050025, 0x442b0082, 0x00000000}},  //   ані_, _اوسم, _hjc_,
  { {0x93fb0061, 0x00000000, 0x00000000, 0x00000000}},  //   _एकाच_,   ,   ,
  { {0x661c010f, 0x7ae905b3, 0x442b06ed, 0x00000000}},  //   zirk, txet, _jjc_,
  { {0x7d06006b, 0x442b0068, 0x201d00e7, 0x00000000}},  //   _əksi, _mjc_, miwi_,
  { {0x201d09cc, 0x3ebf00e0, 0x656500e0, 0x00000000}},  //   liwi_, _iput_, _nghh,
  { {0x661c0374, 0xe7e40204, 0x61f50036, 0x00000000}},  //   virk, गाला_, _mozl,
  { {0x7e690020, 0x661c010f, 0x7e6100f2, 0x00000000}},  //   _kuep, wirk, _hilp,
  { {0x7e61021e, 0x661c0093, 0x6d4100f8, 0x00000000}},  //   _kilp, tirk, _hyla,
  { {0xbb3a0049, 0x6d412cef, 0x99850025, 0x00000000}},  //   _געני, _kyla, _الثو,
  { {0x7e61004a, 0x442b01c5, 0x201d2cf0, 0x00000000}},  //   _milp, _bjc_, kiwi_,
  { {0x644f0832, 0x6d411db2, 0xe45a2cf1, 0x00000000}},  //   _chci, _myla, ужб_,
  { {0x661c0ebc, 0x63b6018e, 0x38b12cf2, 0x00000000}},  // [8620] pirk, rfyn, lár_,
  { {0xe3b2007a, 0x6d41014a, 0xd5a4025a, 0x00000000}},  //   _کرد_, _oyla, _بلدی,
  { {0x7c2d0059, 0x38b12cf3, 0x04b6005e, 0x00000000}},  //   čarj, nár_, _успя,
  { {0x44d801ca, 0xddc2002b, 0xd12f0439, 0x00000000}},  //   _ič_, spoż, رمن_,
  { {0x248d001e, 0x6d41005d, 0xdfcf0380, 0x00000000}},  //   ņemt_, _ayla, عيه_,
  { {0x44d800b9, 0x64440103, 0x6d4127ef, 0x00000000}},  //   _kč_, llii, _byla,
  { {0x38b12cf4, 0xdd990088, 0x644400b0, 0x00000000}},  //   jár_, рші_, olii,
  { {0x6d41018e, 0x8aa6003b, 0x7bf8017a, 0x00000000}},  //   _dyla, брод, рнир_,
  { {0x44d80263, 0xaf060140, 0x7e690066, 0x00000000}},  //   _lč_, _упал, _guep,
  { {0x98b801f9, 0x2fc60051, 0x3ea62cf5, 0x00000000}},  //   алот_, leog_, muot_,
  { {0x2cbe0093, 0x6444006c, 0x44d82cf6, 0x00000000}},  //   _uptd_, klii, _nč_,
  { {0xfaa6008b, 0x7e612cf7, 0x39420089, 0x00000000}},  //   _гадо, _zilp, āks_,
  { {0xab5d0036, 0xa3e7007d, 0x1994007e, 0x00000000}},  //   leżn, पास_, _даля,
  { {0x8627132a, 0x442b0082, 0x6e240051, 0x00000000}},  //   сьме, _sjc_, éibh,
  { {0x61f5067f, 0x9f440129, 0x6d41016b, 0x00000000}},  //   _rozl, _comú_, _xyla,
  { {0x93f6006b, 0x44d82cf8, 0x61f5019a, 0x00000000}},  //   _şərə, _dč_, _sozl,
  { {0x7a3d0005, 0xe3b00025, 0x5347261d, 0x00000000}},  // [8630] mètr, عرف_, схва,
  { {0x44d80263, 0x32072cf9, 0x656500e0, 0x00000000}},  //   _fč_, óny_, _ughh,
  { {0x201d1c7a, 0xe0e70044, 0x61f500ca, 0x00000000}},  //   tiwi_, পন্ন, _vozl,
  { {0x7e610997, 0x6d410a74, 0x7c2d0f3a, 0x00000000}},  //   _silp, _ryla, čark,
  { {0x8d65109f, 0x38b11db8, 0x7e610093, 0x00000000}},  //   овле, zár_, _pilp,
  { {0x443b2cfa, 0x201d0020, 0xa3e70061, 0x00000000}},  //   loq_, siwi_, पाव_,
  { {0x44290fa4, 0xcc860680, 0xfbda006e, 0x00000000}},  //   ona_, обще_, _मोहम,
  { {0x251c0049, 0x6b84006c, 0x38b110fa, 0x00000000}},  //   טווא, _õigl, vár_,
  { {0x44292cbb, 0xab290113, 0x7e610292, 0x00000000}},  //   ina_, ропа_, _tilp,
  { {0x2d8e09c8, 0x38b12cfb, 0x3ea00051, 0x00000000}},  //   cafe_, tár_, áite_,
  { {0x290303b5, 0x798a0173, 0x644400b0, 0x00000000}},  //   ája_, _defw, ylii,
  { {0x3ea01af1, 0xf0920097, 0x2ca7010f, 0x00000000}},  //   šite_, ונט_, mund_,
  { {0x7c3b0129, 0x2ca701bf, 0x290307a0, 0x00000000}},  //   mour, lund_, šja_,
  { {0x442915f8, 0x44d81ed3, 0x386a0051, 0x00000000}},  //   ena_, _pč_, úirí_,
  { {0x44292cfc, 0x7c290039, 0x3f8f2cfd, 0x00000000}},  //   fna_, oner, kagu_,
  { {0x442912b7, 0x68360027, 0x44d800b9, 0x00000000}},  //   gna_, hádz, _vč_,
  { {0x7c29010f, 0x2ca700eb, 0x6b8b0010, 0x00000000}},  // [8640] iner, hund_, _megg,
  { {0x44291d55, 0x6b8b0383, 0x2bd10061, 0x00000000}},  //   ana_, _legg, _दोघा,
  { {0x4429091e, 0x7c3b01aa, 0x63af021e, 0x00000000}},  //   bna_, kour, ännö,
  { {0x7c3b028c, 0x4429037e, 0xb4c80204, 0x00000000}},  //   jour, cna_, ोटी_,
  { {0x442028d4, 0x7c3b03c7, 0xa3e702d2, 0x00000000}},  //   mii_, dour, पार_,
  { {0x4420000d, 0x7c29006c, 0xa6e3000c, 0x00000000}},  //   lii_, ener, æðis,
  { {0x6b8b004e, 0x2ca7000c, 0x2d8e01a2, 0x00000000}},  //   _begg, gund_, rafe_,
  { {0x4420000d, 0x7c290207, 0x2d8e0284, 0x00000000}},  //   nii_, gner, safe_,
  { {0x442001a3, 0xd24f009e, 0x9c870142, 0x00000000}},  //   iii_, _سچے_, _počú,
  { {0xdb190263, 0x4420001a, 0xd839016c, 0x00000000}},  //   _pawò, hii_, muči_,
  { {0x44292cfe, 0x7c3b00f4, 0x44202cff, 0x00000000}},  //   yna_, bour, kii_,
  { {0x7c3b0549, 0x44292d00, 0x2d8c123c, 0x00000000}},  //   cour, xna_, _hede_,
  { {0x4429057a, 0x77640265, 0x2d8c219e, 0x00000000}},  //   vna_, държ, _kede_,
  { {0x44290046, 0x6b8b02ae, 0x2d8c2d01, 0x00000000}},  //   wna_, _zegg, _jede_,
  { {0x442900ee, 0x69c8145c, 0xa3e702d2, 0x00000000}},  //   tna_, mede, पाल_,
  { {0x69c81e68, 0x44202d02, 0x4429001a, 0x00000000}},  //   lede, gii_, una_,
  { {0x442902e1, 0xd8390bf8, 0x3f8f016c, 0x00000000}},  // [8650] rna_, juči_, vagu_,
  { {0x44290213, 0x69c82d03, 0xdb1100f4, 0x00000000}},  //   sna_, nede, éfér,
  { {0x4420006b, 0x68360027, 0x7c2909a8, 0x00000000}},  //   bii_, vádz, yner,
  { {0x69c821c6, 0x44202d04, 0x44290066, 0x00000000}},  //   hede, cii_, qna_,
  { {0x6b8b042d, 0x69c80148, 0x63ad2d05, 0x00000000}},  //   _regg, kede, mgan,
  { {0x69c80209, 0x63ad0292, 0x2ca7069e, 0x00000000}},  //   jede, lgan, tund_,
  { {0x7c3b00f4, 0x6b8b0207, 0x69c800b5, 0x00000000}},  //   tour, _pegg, dede,
  { {0x2ca72d06, 0x7c290288, 0x00000000, 0x00000000}},  //   rund_, uner,   ,
  { {0x2ca7000c, 0x6b8b021a, 0x2d8c26d8, 0x00000000}},  //   sund_, _vegg, _fede_,
  { {0x6b8b0fe2, 0x7c3b0038, 0x44202d07, 0x00000000}},  //   _wegg, sour, zii_,
  { {0x7c3b009d, 0x9f440173, 0x63ad2d08, 0x00000000}},  //   pour, _anmè_, kgan,
  { {0xdd8f00a1, 0x00000000, 0x00000000, 0x00000000}},  //   _سوچ_,   ,   ,
  { {0x4420001a, 0x63ad05b7, 0x00000000, 0x00000000}},  //   vii_, dgan,   ,
  { {0x69c80198, 0x9c8201d9, 0x2d8c002d, 0x00000000}},  //   cede, ščen, _xede_,
  { {0x4420000d, 0xd942012d, 0x00000000, 0x00000000}},  //   tii_, _пеши,   ,
  { {0x63ad0039, 0x68fc0039, 0x61e70093, 0x00000000}},  //   ggan, ärde, _anjl,
  { {0x44200704, 0xd387058e, 0x06970025, 0x00000000}},  // [8660] rii_, яйте_, _فنية_,
  { {0x44200208, 0x601c006b, 0xd1b300a1, 0x00000000}},  //   sii_, _içmə, ٹیفک,
  { {0x4420000d, 0x2d8c0576, 0x9c7c00ca, 0x00000000}},  //   pii_, _rede_, _krče,
  { {0x2d8c2682, 0x69c80010, 0x00000000, 0x00000000}},  //   _sede_, zede,   ,
  { {0x2d8c2d09, 0xf8a8006e, 0xf41300a0, 0x00000000}},  //   _pede_, _कम्प, _נפש_,
  { {0x2a7f0009, 0x2c710051, 0x69c80bc0, 0x00000000}},  //   dpub_, _bád_, xede,
  { {0x2d8c2d0a, 0x7e7b00b0, 0x00000000, 0x00000000}},  //   _vede_, _etup,   ,
  { {0x69c8011c, 0x8cbd013d, 0x78a800f8, 0x00000000}},  //   wede, _शहरो, vudv,
  { {0x69c82d0b, 0x62962900, 0x8f00007e, 0x00000000}},  //   tede, nsyo, кiх_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63ad00f8, 0xab5d002b, 0x00000000, 0x00000000}},  //   ygan, neżj,   ,
  { {0x62962900, 0x69c8002d, 0x4c160167, 0x00000000}},  //   ksyo, sede, _عباس,
  { {0x78a80030, 0x3e5d0173, 0x200600e0, 0x00000000}},  //   sudv, _sňti_, ikoi_,
  { {0x7afd29f9, 0xa2db013d, 0x00000000, 0x00000000}},  //   äste, निस्,   ,
  { {0x63ad018e, 0x19bb009b, 0x49bb00b3, 0x00000000}},  //   tgan, _המוב, _המוס,
  { {0x63ad0035, 0x9c7c11af, 0x00000000, 0x00000000}},  //   ugan, _grče,   ,
  { {0x979c009b, 0xc619007c, 0x27e90095, 0x00000000}},  // [8670] _השחק, _моих_, _inan_,
  { {0x20c8013d, 0x63ad010f, 0x386e013e, 0x00000000}},  //   रबंध, sgan, _kufr_,
  { {0x7e7c0059, 0x7fd50088, 0x83f90478, 0x00000000}},  //   _črpa, ділі, _денс_,
  { {0x2c710d7f, 0x00000000, 0x00000000, 0x00000000}},  //   _rád_,   ,   ,
  { {0xdcf80089, 0x9ea90088, 0xb2742d0c, 0x00000000}},  //   kavē, івка_, _пляш,
  { {0x6da50175, 0x9f5f00f6, 0x273c0082, 0x00000000}},  //   фика, _lluç_, ửng_,
  { {0xed5601f9, 0x27e92081, 0x55780049, 0x00000000}},  //   мош_, _onan_, לעגן_,
  { {0x1b1e0055, 0x7ae42646, 0xdfd4007c, 0x00000000}},  //   _পড়ে_, _šita, _посы,
  { {0xa7fd006b, 0x7bc9040f, 0x7e7b00e7, 0x00000000}},  //   yqır, reeu, _utup,
  { {0x9c7c1531, 0xf2d40049, 0x7bc900d9, 0x00000000}},  //   _srče, געץ_, seeu,
  { {0x07a60228, 0x200d040f, 0x6aa90026, 0x00000000}},  //   манн, _klei_, suef,
  { {0x6e230203, 0x629600e0, 0x00000000, 0x00000000}},  //   linb, ysyo,   ,
  { {0x6aa9009d, 0x6b65007e, 0xac060088, 0x00000000}},  //   quef, _ўкла, _інша_,
  { {0x200d04bd, 0x6925003b, 0x27e9000a, 0x00000000}},  //   _llei_, _омла, _enan_,
  { {0x9c7c02aa, 0xa6c900a1, 0x966302ea, 0x00000000}},  //   _trče, _ہوٹل_, ткре,
  { {0x9c7c004f, 0xa41c0044, 0x00000000, 0x00000000}},  //   _urče, থক্য_,   ,
  { {0xe1fa08fd, 0x04430264, 0x41b6003b, 0x00000000}},  // [8680] ога_, тетн, дсет,
  { {0x6296011c, 0x7d032d0d, 0x6e2d009d, 0x00000000}},  //   rsyo, kyns, éabl,
  { {0x629617cf, 0x200d0292, 0x04030044, 0x00000000}},  //   ssyo, _blei_, রোধী_,
  { {0x62962900, 0xa2db013d, 0x394701d6, 0x00000000}},  //   psyo, निश्, _myns_,
  { {0x20060065, 0xf1aa0014, 0x200700c4, 0x00000000}},  //   rkoi_, _واسه_, ênia_,
  { {0xa2db0309, 0x6e230405, 0x200d00e5, 0x00000000}},  //   निर्, ginb, _elei_,
  { {0x01630517, 0xd5ed0082, 0x0caa0088, 0x00000000}},  //   _акро, _quả, ітки_,
  { {0x8af800ed, 0x61fc193b, 0x92c20044, 0x00000000}},  //   знис_, _horl, ্মী_,
  { {0x61fc2d0e, 0x6e230b5a, 0x3f86009d, 0x00000000}},  //   _korl, binb, mbou_,
  { {0x4efb009b, 0xc33300b3, 0x3f860861, 0x00000000}},  //   _והמו, כוח_, lbou_,
  { {0x61fc005b, 0x27e9000a, 0x00000000, 0x00000000}},  //   _morl, _pnan_,   ,
  { {0x3f860b5c, 0x00000000, 0x00000000, 0x00000000}},  //   nbou_,   ,   ,
  { {0x61fc06b2, 0xe9da00ed, 0xdb2400b0, 0x00000000}},  //   _oorl, _мкд_, äräy,
  { {0x8a03005e, 0x61fc150c, 0x39470190, 0x00000000}},  //   _изче, _norl, _fyns_,
  { {0x92bb0055, 0x443f0011, 0x00000000, 0x00000000}},  //   _আছে_, _ưu_,   ,
  { {0x69da2d0f, 0x69d801cb, 0x27e90058, 0x00000000}},  //   ldte, _have, _unan_,
  { {0x69d8021e, 0x61fc0039, 0x32550e75, 0x00000000}},  // [8690] _kave, _borl, евар,
  { {0x69da0c53, 0xf3ff0011, 0x69d80023, 0x00000000}},  //   ndte, _giãn_, _jave,
  { {0x69d80030, 0x61fc09ac, 0x6d4808e0, 0x00000000}},  //   _mave, _dorl, _nyda,
  { {0x69d8068f, 0x3f860061, 0x7ae2002d, 0x00000000}},  //   _lave, gbou_, _orot,
  { {0x61fc0378, 0x9f40009f, 0x38b80010, 0x00000000}},  //   _forl, ðið_, hér_,
  { {0x69d8049a, 0x7bc20038, 0x7cd3005f, 0x00000000}},  //   _nave, _abou, _hərə,
  { {0x8c450478, 0x7ae20032, 0x00000000, 0x00000000}},  //   неке, _arot,   ,
  { {0x7ae22d10, 0x69da00bb, 0x61fc005a, 0x00000000}},  //   _brot, edte, _zorl,
  { {0x7ae20197, 0x0e35041f, 0x39470d32, 0x00000000}},  //   _crot, _знаю, _syns_,
  { {0x9c8201ae, 0x7ae206a1, 0xa2a70309, 0x00000000}},  //   ščan, _drot, _चिन्,
  { {0x7ae21d7a, 0x69d8014a, 0x6d481b6c, 0x00000000}},  //   _erot, _dave, _gyda,
  { {0x7ae2002b, 0xb6a600ed, 0x7c2d0f3a, 0x00000000}},  //   _frot, нимл, čars,
  { {0x7ae202ae, 0x69d81994, 0x38690085, 0x00000000}},  //   _grot, _fave, _diar_,
  { {0x69d80030, 0x69da0022, 0x6d4801c3, 0x00000000}},  //   _gave, cdte, _yyda,
  { {0x2ab901aa, 0x7bd90022, 0xddc90c1e, 0x00000000}},  //   lèb_, _kawu, _otež,
  { {0x69d818e1, 0xe73a007c, 0xb60200b9, 0x00000000}},  //   _zave, _ней_, _žádo,
  { {0x7cd3005f, 0x52aa005e, 0x9c7c016c, 0x00000000}},  // [86a0] _dərə, явам_, _mrča,
  { {0x69d805d2, 0x38692d11, 0x7bd90022, 0x00000000}},  //   _xave, _ziar_, _lawu,
  { {0xa3ea0200, 0x61fc010f, 0x4fc6005e, 0x00000000}},  //   _една_, _vorl, есла,
  { {0x61fc2d12, 0xfbae007d, 0x7cd3006b, 0x00000000}},  //   _worl, _टाइम, _gərə,
  { {0x6d480193, 0x69c32d13, 0x64461c9a, 0x00000000}},  //   _syda, _obne, _ikki,
  { {0x7cd3006b, 0x7ae20065, 0x29050f25, 0x00000000}},  //   _zərə, _rrot, kyla_,
  { {0x8fa6008b, 0x7f490061, 0x7bd90009, 0x00000000}},  //   _паве, _eyeq, _bawu,
  { {0x3ea62d14, 0x6d4806b8, 0x69d82c33, 0x00000000}},  //   prot_, _vyda, _save,
  { {0x69d8010a, 0x6d480046, 0x44222d15, 0x00000000}},  //   _pave, _wyda, _mmk_,
  { {0x38691aed, 0x7afd2d16, 0x38b810fa, 0x00000000}},  //   _siar_, ästa, tér_,
  { {0x0b8a0057, 0x290a0010, 0x7ae2112b, 0x00000000}},  //   _если_, ába_, _wrot,
  { {0x7ae2127c, 0x68e3057c, 0x69d800ab, 0x00000000}},  //   _trot, _drnd, _wave,
  { {0x7c221dfb, 0x09d80044, 0x7ae201ed, 0x00000000}},  //   _imor, তাবা, _urot,
  { {0x8cd7007d, 0x7cd3006b, 0x290500b9, 0x00000000}},  //   _मनमो, _sərə, byla_,
  { {0x248d037e, 0xaaa601f5, 0x7bd90045, 0x00000000}},  //   ćemo_, _खिडक, _yawu,
  { {0x7c22002b, 0x60c70093, 0x7cd3013f, 0x00000000}},  //   _jmor, _rpjm, _qərə,
  { {0x7c2221b3, 0x6b840004, 0x2bc20183, 0x00000000}},  // [86b0] _mmor, _õigu, व्या,
  { {0xf3ff00c4, 0x00000000, 0x00000000, 0x00000000}},  //   _tião_,   ,   ,
  { {0x7cd3005f, 0x20070181, 0x7c22001a, 0x00000000}},  //   _tərə, ênio_, _omor,
  { {0xf8b30049, 0x44220288, 0x00000000, 0x00000000}},  //   טשע_, _gmk_,   ,
  { {0x62830119, 0x644d2cdc, 0x7bd90022, 0x00000000}},  //   ćnos, mlai, _rawu,
  { {0x7c220198, 0x623501fb, 0x2ab90263, 0x00000000}},  //   _amor, _регу, vèb_,
  { {0x644d0fdd, 0xdce10036, 0x7bd92d17, 0x00000000}},  //   olai, _oglą, _pawu,
  { {0x644d021e, 0x69c30022, 0x8ca2013d, 0x00000000}},  //   nlai, _sbne, _गिरो,
  { {0x7bdb0116, 0xdea401b2, 0x00000000, 0x00000000}},  //   rduu, _مینی,   ,
  { {0x644d0051, 0x7c22225f, 0x6abb0a7e, 0x00000000}},  //   hlai, _emor, rtuf,
  { {0x644d001e, 0x9c7c2d18, 0x6abb0218, 0x00000000}},  //   klai, _trča, stuf,
  { {0x645a007f, 0x00000000, 0x00000000, 0x00000000}},  //   įtik,   ,   ,
  { {0x9aa401fa, 0x2bda0164, 0xe9ce02e9, 0x00000000}},  //   _ممنو, _मोटा, _кк_,
  { {0x44222d19, 0x7c2200ca, 0x644d007f, 0x00000000}},  //   _smk_, _zmor, elai,
  { {0x442204be, 0x6aa901a2, 0x644d0048, 0x00000000}},  //   _pmk_, lref, flai,
  { {0x644d00f4, 0x69c1000c, 0x6b890f30, 0x00000000}},  //   glai, lfle, nbeg,
  { {0xe29709b2, 0x9196003b, 0x232700e2, 0x00000000}},  // [86c0] кат_, вјеш, воти_,
  { {0x644d230b, 0xd179007e, 0x1757009b, 0x00000000}},  //   alai, есці_, _בספר_,
  { {0x644d10fd, 0x44220f3e, 0x62840048, 0x00000000}},  //   blai, _tmk_, spio,
  { {0x44222d1a, 0x6aa90292, 0x600a007e, 0x00000000}},  //   _umk_, kref, ьнем_,
  { {0x7ed30025, 0x37dc0044, 0x44320941, 0x00000000}},  //   لزوا, ধাপর, mny_,
  { {0xa2a70201, 0x44320a31, 0x7c222d1b, 0x00000000}},  //   _चित्, lny_, _smor,
  { {0x4432137e, 0x61ee0039, 0x69c100d9, 0x00000000}},  //   ony_, _inbl, dfle,
  { {0x4432018e, 0x6b89054e, 0x2cf200e8, 0x00000000}},  //   nny_, gbeg, _अपील_,
  { {0x69c12665, 0x44320ffd, 0x6aa902b6, 0x00000000}},  //   ffle, iny_, gref,
  { {0xd8f80088, 0x44320f6b, 0x2bae0061, 0x00000000}},  //   еної_, hny_, _टाका,
  { {0x38c802fd, 0x644d2d1c, 0x7c220066, 0x00000000}},  //   رادی_, ylai, _tmor,
  { {0x27ed027b, 0x44320a32, 0x27ff009f, 0x00000000}},  //   ñen_, jny_, ðun_,
  { {0x443208e2, 0x61ee298f, 0xcc880014, 0x00000000}},  //   dny_, _onbl, _آنچه_,
  { {0xb88218da, 0x44320253, 0x27ed0010, 0x00000000}},  //   üíst, eny_, űen_,
  { {0x644d0e07, 0xca470014, 0x65942d1d, 0x00000000}},  //   tlai, _جلوه_, расу,
  { {0x44322d1e, 0x2c7800fa, 0x61ee01a2, 0x00000000}},  //   gny_, _méd_, _anbl,
  { {0x644d0051, 0x36050379, 0x7cca006b, 0x00000000}},  // [86d0] rlai, _موظف, _hərd,
  { {0x44320046, 0x644d0943, 0x7cca006b, 0x00000000}},  //   any_, slai, _gərg,
  { {0x260803d7, 0x644d00ab, 0x44320941, 0x00000000}},  //   _सकती_, plai, bny_,
  { {0xa283007a, 0x44322d1f, 0x6aa900ea, 0x00000000}},  //   _نیرو, cny_, yref,
  { {0x4429000b, 0xceeb0167, 0x69c10016, 0x00000000}},  //   mia_, بران_, yfle,
  { {0x44292d20, 0xdce8006b, 0x3eaf1f7d, 0x00000000}},  //   lia_, _addı, rugt_,
  { {0x6b8901a1, 0x7c94007e, 0x44292d21, 0x00000000}},  //   tbeg, арыц, oia_,
  { {0x44291191, 0x6aa915a6, 0x8af7005f, 0x00000000}},  //   nia_, tref, _çəki,
  { {0x985f002b, 0x6b8901a2, 0x00000000, 0x00000000}},  //   _eċċ_, rbeg,   ,
  { {0x4429220a, 0x6aa9027b, 0x443215b1, 0x00000000}},  //   hia_, rref, zny_,
  { {0x4429055e, 0x69c1018e, 0xaad80164, 0x00000000}},  //   kia_, rfle, _बैठक,
  { {0x442904ff, 0x981600b8, 0x7cca006b, 0x00000000}},  //   jia_, ابدا, _sərg,
  { {0x69c1010f, 0x44320161, 0x81ab0044, 0x00000000}},  //   pfle, vny_, ক্য_,
  { {0x3e790263, 0x44320046, 0x98e50025, 0x00000000}},  //   _mèt_, wny_, _مكتو,
  { {0x03a601fb, 0x44320871, 0x3e7901aa, 0x00000000}},  //   ливо, tny_, _lèt_,
  { {0x4429022b, 0x7c290707, 0x443216cc, 0x00000000}},  //   gia_, nier, uny_,
  { {0x44321712, 0x3e790263, 0x7cca006b, 0x00000000}},  // [86e0] rny_, _nèt_, _zərd,
  { {0x7c290207, 0x4429225f, 0x44320871, 0x00000000}},  //   hier, aia_, sny_,
  { {0x4429094f, 0x7c292d22, 0xd00a0401, 0x00000000}},  //   bia_, kier, неже_,
  { {0x3e790263, 0x7c292d23, 0x00000000, 0x00000000}},  //   _bèt_, jier,   ,
  { {0x539b00b6, 0xadf00309, 0x7afd21db, 0x00000000}},  //   _איכו, चालन_, ästl,
  { {0x61460081, 0x3e7901aa, 0x61ee0133, 0x00000000}},  //   _бега, _dèt_, _unbl,
  { {0x7c29275a, 0x00000000, 0x00000000, 0x00000000}},  //   fier,   ,   ,
  { {0x3e790263, 0x7c29010f, 0x09ac0061, 0x00000000}},  //   _fèt_, gier, चल्य,
  { {0xee3a012b, 0xaae60025, 0x7cca006b, 0x00000000}},  //   _зна_, اسبو, _sərd,
  { {0x4429062b, 0x32bb0049, 0x7c290116, 0x00000000}},  //   zia_, עזיד, aier,
  { {0x7c292d24, 0x44292d25, 0x9c7c0142, 0x00000000}},  //   bier, yia_, _krčm,
  { {0x7c290f6a, 0xaae61f4f, 0x386d00f8, 0x00000000}},  //   cier, _مستو, öer_,
  { {0x95cb15c4, 0x7d0a01d6, 0x66c800e2, 0x00000000}},  //   нува_, lyfs, лург_,
  { {0x44290046, 0x998c0006, 0x00000000, 0x00000000}},  //   wia_, rodų_,   ,
  { {0x44291d22, 0x7cca005f, 0x799a0020, 0x00000000}},  //   tia_, _hərb, matw,
  { {0xb4c50061, 0x00000000, 0x00000000, 0x00000000}},  //   _एही_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [86f0]   ,   ,   ,
  { {0x44292d26, 0x7c2928f5, 0x799a01aa, 0x00000000}},  //   sia_, zier, natw,
  { {0x3e7901aa, 0x6013005d, 0x74160123, 0x00000000}},  //   _sèt_, _açma, _چوپا,
  { {0xb4fa01f8, 0x7c292d27, 0x44290065, 0x00000000}},  //   _ספרי, xier, qia_,
  { {0x7c292d28, 0x799a036b, 0x539a00b3, 0x00000000}},  //   vier, katw, _בירו,
  { {0x7c290046, 0x867c007b, 0x9f5f00f4, 0x00000000}},  //   wier, ערוו, _joué_,
  { {0x7c29001f, 0x88c700b9, 0x00000000, 0x00000000}},  //   tier, _kněž,   ,
  { {0x3e790263, 0x9f5f009d, 0x00000000, 0x00000000}},  //   _tèt_, _loué_,   ,
  { {0x7c290109, 0x799a2d29, 0x00000000, 0x00000000}},  //   rier, fatw,   ,
  { {0x7c290474, 0x799a01aa, 0x2fdf0cfd, 0x00000000}},  //   sier, gatw, _haug_,
  { {0x2bc20061, 0x63b60006, 0xdb09004a, 0x00000000}},  //   व्हा, ygyn, rfeñ,
  { {0xfc67005e, 0x00000000, 0x00000000, 0x00000000}},  //   _съзн,   ,   ,
  { {0x799a1e5d, 0x6b9b0146, 0xf3ff0082, 0x00000000}},  //   batw, maug, _giãi_,
  { {0x81ab0055, 0x6b9b000c, 0x645d0026, 0x00000000}},  //   ক্ত_, laug, _ahsi,
  { {0xe94604e1, 0x443900c4, 0x7cca006b, 0x00000000}},  //   _پروی, _bjs_, _zərb,
  { {0xf814007a, 0x3ea010ec, 0x07a62d2a, 0x00000000}},  //   _دستگ, šiti_, _таин,
  { {0xd46719a2, 0x27e00093, 0x422606b6, 0x00000000}},  // [8700] рите_, _iain_, адав,
  { {0x27e0022b, 0x6b9b00ea, 0x260600c4, 0x00000000}},  //   _hain_, haug, _vôos_,
  { {0x27e004fa, 0x6b9b2d2b, 0x7afd006c, 0x00000000}},  //   _kain_, kaug, ästj,
  { {0xe3b203ec, 0x43750245, 0xc059007e, 0x00000000}},  //   _برد_, _гурт, гіі_,
  { {0x2fdf010a, 0x27e00038, 0x6b9b0006, 0x00000000}},  //   _daug_, _main_, daug,
  { {0x27e0020c, 0x7ae4002a, 0xeca6003b, 0x00000000}},  //   _lain_, _áiti, ајин,
  { {0x7cca006b, 0x6e2a2d2c, 0xadf70a4f, 0x00000000}},  //   _sərb, rifb, شروط_,
  { {0xeca703d7, 0x7d0a0007, 0x27e00f75, 0x00000000}},  //   _गिरफ, ryfs, _nain_,
  { {0x7cca006b, 0x799a2d2d, 0xf1c6007d, 0x00000000}},  //   _qərb, tatw, र्थन,
  { {0xdb09014a, 0x3a270022, 0x00000000, 0x00000000}},  //   zgeç, _cmnp_,   ,
  { {0xa3e602fb, 0x27e02d2e, 0x2004000c, 0x00000000}},  //   पया_, _bain_, _komi_,
  { {0x2d9c036f, 0x27e0005b, 0x6d5a26be, 0x00000000}},  //   lave_, _cain_, _izta,
  { {0x2c0b0123, 0x2004012d, 0x799a00e7, 0x00000000}},  //   _جعلی_, _momi_, patw,
  { {0x2d9c1897, 0x44d80173, 0x443902d4, 0x00000000}},  //   nave_, _bō_, _sjs_,
  { {0x44390bd6, 0x27e02d2f, 0xf5e40088, 0x00000000}},  //   _pjs_, _fain_, ціям,
  { {0x27e0022b, 0x20040207, 0x27f200e0, 0x00000000}},  //   _gain_, _nomi_, _gnyn_,
  { {0x81e00055, 0x2d9c0065, 0xe8b60061, 0x00000000}},  // [8710] থান_, kave_, _अमुच,
  { {0x2d9c00ee, 0xf8da03d7, 0x98da013d, 0x00000000}},  //   jave_, _बनाय, _बनाए,
  { {0x2d9c0065, 0x443919ce, 0x645d0045, 0x00000000}},  //   dave_, _tjs_, _thsi,
  { {0x200400c4, 0xa25b009d, 0x00000000, 0x00000000}},  //   _comi_, _apôt,   ,
  { {0x200401aa, 0x6d5a028d, 0x2d9c0f72, 0x00000000}},  //   _domi_, _azta, fave_,
  { {0x2d9c068f, 0x9c7c0091, 0x6b8200c4, 0x00000000}},  //   gave_, _grčk, _afog,
  { {0x6b9b101a, 0x2004004a, 0x00000000, 0x00000000}},  //   taug, _fomi_,   ,
  { {0x2d820010, 0xf538009b, 0x3c3a0089, 0x00000000}},  //   _őket_, ינוי_, tīva_,
  { {0x6d5a022b, 0x6b9b2d30, 0xa3c902d2, 0x00000000}},  //   _ezta, raug, ल्य_,
  { {0x6b9b010a, 0x27e0044e, 0x75280036, 0x00000000}},  //   saug, _sain_, ździ,
  { {0x799801aa, 0x27e00549, 0xdea300a1, 0x00000000}},  //   _devw, _pain_, _ایڈی,
  { {0xa3c902d2, 0xa3e6013d, 0x26c2145e, 0x00000000}},  //   ल्म_, _यों_, ttko_,
  { {0x27e0021e, 0xdce3047f, 0x7bda00b3, 0x00000000}},  //   _vain_, manı, _תקנו,
  { {0xdce3038c, 0x27e02d31, 0x44d8000a, 0x00000000}},  //   lanı, _wain_, _pō_,
  { {0x26c20046, 0x291e0036, 0x9479122e, 0x00000000}},  //   stko_, czta_, исту_,
  { {0x2d9c01d9, 0xdce3005d, 0x93f6006b, 0x00000000}},  //   zave_, nanı, _şəbə,
  { {0x38a301f6, 0x7cca005f, 0xb344006b, 0x00000000}},  // [8720] lır_, _məra, _keçə,
  { {0x81ab0055, 0x9c820059, 0xdce30180, 0x00000000}},  //   ক্স_, ščin, hanı,
  { {0x999a00bd, 0x38a301f6, 0xdce3038c, 0x00000000}},  //   רבעט, nır_, kanı,
  { {0x2d9c0857, 0x6b990082, 0x68fc00f8, 0x00000000}},  //   wave_, _newg, ärdi,
  { {0x2d9c1e8d, 0x9f49009f, 0x20041259, 0x00000000}},  //   tave_, ðað_, _vomi_,
  { {0x6b820207, 0x38a3014a, 0xe3b200a2, 0x00000000}},  //   _sfog, kır_, _برگ_,
  { {0x2d9c008d, 0x55770049, 0x7cca006b, 0x00000000}},  //   rave_, זעצן_, _bəra,
  { {0x38a301f6, 0x2d9c0065, 0x6d5a01dc, 0x00000000}},  //   dır_, save_, _vzta,
  { {0xda7a007e, 0x2d9c0065, 0xa3bb007d, 0x00000000}},  //   ыяй_, pave_, _घास_,
  { {0x38600129, 0x38a301df, 0x6b9901c3, 0x00000000}},  //   _ahir_, fır_, _eewg,
  { {0x6605042b, 0x2bca01fb, 0x6d5a2d32, 0x00000000}},  //   _rohk, _було_, _uzta,
  { {0x315700a0, 0xdce3019a, 0x7ae42c1b, 0x00000000}},  //   מיין_, canı, _šitu,
  { {0x291e115b, 0x28da0061, 0x00000000, 0x00000000}},  //   szta_, _बनवि,   ,
  { {0xbb3b0049, 0xe84c00b9, 0x09e3007c, 0x00000000}},  //   _געדי, ětší, _ночн,
  { {0xe65401fb, 0x9c7c0107, 0x38600048, 0x00000000}},  //   ївсь, _brči, _fhir_,
  { {0x69c80007, 0x00000000, 0x00000000, 0x00000000}},  //   lfde,   ,   ,
  { {0x2458007c, 0x00000000, 0x00000000, 0x00000000}},  // [8730] сать_,   ,   ,
  { {0xdce30279, 0x7afd05e0, 0xdb1f01cc, 0x00000000}},  //   zanı, ästi, évér,
  { {0xdce3027d, 0xa25b0027, 0x00000000, 0x00000000}},  //   yanı, _spôs,   ,
  { {0x9c7c07a0, 0x9f5502b8, 0x00000000, 0x00000000}},  //   _grči, овеч,   ,
  { {0xdce30180, 0x81ab0044, 0x38a3005d, 0x00000000}},  //   vanı, ক্ষ_, zır_,
  { {0x38a3038c, 0x628d0197, 0x7aed19e2, 0x00000000}},  //   yır_, mpao, _šato,
  { {0xdce30279, 0x38a3006b, 0xed59004c, 0x00000000}},  //   tanı, xır_, шок_,
  { {0x7cca005f, 0xe0d20049, 0x442b0e6d, 0x00000000}},  //   _qəra, _קײן_, _jmc_,
  { {0x442b2d33, 0xdce30279, 0x60c50300, 0x00000000}},  //   _mmc_, ranı, lthm,
  { {0x38a3047f, 0x88c9007c, 0xdce3005d, 0x00000000}},  //   tır_, алов_, sanı,
  { {0x2eed0365, 0xdce30279, 0x999e00b9, 0x00000000}},  //   _href_, panı, nitř_,
  { {0xb90103d7, 0x7e7b2d34, 0x38a30180, 0x00000000}},  //   _नई_, _kuup, rır_,
  { {0xf7720151, 0x7c2b2d35, 0x38a31e00, 0x00000000}},  //   باد_, _imgr, sır_,
  { {0x9c7c00d0, 0x7ae900f8, 0x7bc908ea, 0x00000000}},  //   _srči, mvet, lfeu,
  { {0x7ae9001c, 0x3860005b, 0x00000000, 0x00000000}},  //   lvet, _thir_,   ,
  { {0x69de2d36, 0x442b20ae, 0x00000000, 0x00000000}},  //   _óper, _cmc_,   ,
  { {0xa2060088, 0x442b2d37, 0xfbd20104, 0x00000000}},  // [8740] опад, _dmc_, ותן_,
  { {0xe1f701f9, 0xe2460025, 0x00000000, 0x00000000}},  //   огу_, آخري,   ,
  { {0x442b2d38, 0x60260451, 0x7c2b0056, 0x00000000}},  //   _fmc_, оджа, _omgr,
  { {0x2eed00f4, 0x9c7c0428, 0x2d850035, 0x00000000}},  //   _bref_, _urči, _afle_,
  { {0x6441009d, 0xaad8006e, 0x6589009d, 0x00000000}},  //   élie, _बैंक, _éphé,
  { {0x0caa1736, 0x6ce5006e, 0x7ae90039, 0x00000000}},  //   атии_, किंग_, dvet,
  { {0x90c30175, 0xb7bb0181, 0x7bc9009d, 0x00000000}},  //   _обре, lhãe, ffeu,
  { {0x8aa6005c, 0x2eed0009, 0x984d0036, 0x00000000}},  //   ород, _fref_, _iść_,
  { {0x8af7005f, 0x7ae90010, 0xada615c4, 0x00000000}},  //   _şərh, gvet, _маал,
  { {0x2fcd012d, 0x00000000, 0x00000000, 0x00000000}},  //   _zbeg_,   ,   ,
  { {0x7ae90197, 0xb21b000c, 0x91bb009b, 0x00000000}},  //   avet, _stæk, סמטי,
  { {0x81c20044, 0xd90f00a1, 0x00000000, 0x00000000}},  //   ্যি_, ئیٹ_,   ,
  { {0x69b20061, 0x7ae908de, 0x442b009d, 0x00000000}},  //   _आयपी, cvet, _rmc_,
  { {0x442b00f8, 0x60c505af, 0xdcfa01c5, 0x00000000}},  //   _smc_, ythm, _netī,
  { {0x81c20055, 0x80c9013d, 0x442b0133, 0x00000000}},  //   ্যা_, _रहें, _pmc_,
  { {0xb8670084, 0x00000000, 0x00000000, 0x00000000}},  //   _باتو,   ,   ,
  { {0xd763089d, 0x442b0068, 0xb60702dc, 0x00000000}},  // [8750] _تنظی, _vmc_, _дянк,
  { {0xd2510137, 0x442b00d9, 0x628d0197, 0x00000000}},  //   رنا_, _wmc_, rpao,
  { {0x212700ad, 0x7ae90010, 0x6ad30044, 0x00000000}},  //   ành_, zvet, তিযো,
  { {0x60c50016, 0x442b00d9, 0x2eed281b, 0x00000000}},  //   rthm, _umc_, _pref_,
  { {0xfd4c0011, 0x00000000, 0x00000000, 0x00000000}},  //   _triề,   ,   ,
  { {0xc27a009b, 0x7ae9014a, 0x201d00e7, 0x00000000}},  //   _לרשי, vvet, shwi_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ae90065, 0x2eed1194, 0x81bd0044, 0x00000000}},  //   tvet, _tref_, _আসি_,
  { {0xeab10025, 0x7ae92d39, 0x7bc901a2, 0x00000000}},  //   رعة_, uvet, rfeu,
  { {0x7ae90e2d, 0x644d2d3a, 0xa9250139, 0x00000000}},  //   rvet, hoai, здол,
  { {0x7ae901d9, 0xf1b2007b, 0x81bd0044, 0x00000000}},  //   svet, עסט_, _আসা_,
  { {0xb33b006b, 0x7ae90010, 0x00000000, 0x00000000}},  //   _keçd, pvet,   ,
  { {0x644d002d, 0xa3e6007d, 0x3f8a006b, 0x00000000}},  //   doai, _योग_, _əbu_,
  { {0x3e6001aa, 0xa3c9007d, 0x7afd006c, 0x00000000}},  //   pòte_, ल्स_, ästu,
  { {0x1828007a, 0x29350049, 0x7c3b0009, 0x00000000}},  //   _وقتی_, _מאַן_, onur,
  { {0x7c3b0fc7, 0x00000000, 0x00000000, 0x00000000}},  //   nnur,   ,   ,
  { {0x3cdd03d7, 0xc8650054, 0x93430745, 0x00000000}},  // [8760] _कैसे_, _تطوي, енте,
  { {0x7c3b01a2, 0x00000000, 0x00000000, 0x00000000}},  //   hnur,   ,   ,
  { {0x644100f7, 0x757b009b, 0x645600ab, 0x00000000}},  //   élic, _לטיפ, plyi,
  { {0x62811e90, 0x764e0253, 0x1eaa0380, 0x00000000}},  //   _člov, loby, ماتي_,
  { {0x443209d7, 0x442000fa, 0x00000000, 0x00000000}},  //   miy_, mhi_,   ,
  { {0x44200133, 0x44322d3b, 0x00000000, 0x00000000}},  //   lhi_, liy_,   ,
  { {0x39a6002a, 0xdb002d3c, 0x00000000, 0x00000000}},  //   hísí_, ngmö,   ,
  { {0x4420011c, 0x44320b1f, 0xef8603f6, 0x00000000}},  //   nhi_, niy_, _хлап,
  { {0x44200022, 0xef1a02b8, 0x764e0142, 0x00000000}},  //   ihi_, _ума_, koby,
  { {0x7de50025, 0x644d0e64, 0x39140072, 0x00000000}},  //   _يسلم, zoai, дмор,
  { {0x3ea60089, 0x4432013f, 0x69bd007d, 0x00000000}},  //   lsot_, kiy_, _शारी,
  { {0x44202a4a, 0x2d9e0185, 0x3f8612dd, 0x00000000}},  //   jhi_, _hete_, ncou_,
  { {0x44201ea5, 0x2d9e2d3d, 0x44322d3e, 0x00000000}},  //   dhi_, _kete_, diy_,
  { {0x2d9e2d3f, 0x764e00e0, 0x7ae20133, 0x00000000}},  //   _jete_, goby, _isot,
  { {0x2d9e0607, 0x644d00b0, 0x44321575, 0x00000000}},  //   _mete_, toai, fiy_,
  { {0x69da121b, 0x44200207, 0x2d9e0142, 0x00000000}},  //   lete, ghi_, _lete_,
  { {0x644d0035, 0x78ba0fd1, 0x320a05d2, 0x00000000}},  // [8770] roai, lutv, _boby_,
  { {0x320a013e, 0x44200697, 0x69da0e69, 0x00000000}},  //   _coby_, ahi_, nete,
  { {0x7761005f, 0x320a07f1, 0xf4850167, 0x00000000}},  //   əlxa, _doby_, _تاخی,
  { {0x69da0073, 0x44200198, 0x7ae2002d, 0x00000000}},  //   hete, chi_, _osot,
  { {0xa2a70754, 0x69da022b, 0x2d9e022b, 0x00000000}},  //   _चिट्, kete, _bete_,
  { {0x69da1fe9, 0x41e4007e, 0x2d9e0091, 0x00000000}},  //   jete, _піса, _cete_,
  { {0x69da0938, 0x2d9e012b, 0xd0d40265, 0x00000000}},  //   dete, _dete_, _поръ,
  { {0xdb1b0f57, 0x61e70010, 0xea890478, 0x00000000}},  //   lgué, _hajl, обил_,
  { {0x2d9e001a, 0x81e00044, 0x60c70009, 0x00000000}},  //   _fete_, থার_, _hqjm,
  { {0x69da0010, 0xb33b011f, 0xdb1b25bd, 0x00000000}},  //   gete, _geçe, ngué,
  { {0x186a00ed, 0x61e70127, 0x44201926, 0x00000000}},  //   жани_, _majl, yhi_,
  { {0xf0920049, 0x44200065, 0x5b1501ee, 0x00000000}},  //   כנט_, xhi_, _омет,
  { {0x69da2d40, 0x764e0009, 0xddc10964, 0x00000000}},  //   bete, toby, _milž,
  { {0x61e70620, 0x00000000, 0x00000000, 0x00000000}},  //   _najl,   ,   ,
  { {0x4420000b, 0x44320c2d, 0x320a0197, 0x00000000}},  //   thi_, tiy_, _roby_,
  { {0x68fc05cc, 0xe29a00ed, 0xc95200b3, 0x00000000}},  //   årde, жаа_, _שמה_,
  { {0x44202d41, 0x44320890, 0x00000000, 0x00000000}},  // [8780] rhi_, riy_,   ,
  { {0x44200be3, 0x7cca006b, 0x00000000, 0x00000000}},  //   shi_, _sərm,   ,
  { {0xb4660113, 0x2d9e2d42, 0x25e7006e, 0x00000000}},  //   _окол, _rete_, _छोटी_,
  { {0x69da1038, 0xb33b011f, 0x2d9e0181, 0x00000000}},  //   zete, _seçe, _sete_,
  { {0x2d9e01aa, 0x61e7002b, 0x63a4032c, 0x00000000}},  //   _pete_, _fajl, main,
  { {0x63a42d43, 0xd04c006b, 0x3f9f15ab, 0x00000000}},  //   lain, _əhəm, _eeuu_,
  { {0x69da0010, 0x2d9e008d, 0x7ae20066, 0x00000000}},  //   vete, _vete_, _ssot,
  { {0x63a400b0, 0x2d9e2d44, 0x69da00c7, 0x00000000}},  //   nain, _wete_, wete,
  { {0x2d9e0e6d, 0xe457009b, 0x69c301c3, 0x00000000}},  //   _tete_, ויקט_, _bcne,
  { {0x63a42d45, 0x6ffe0035, 0x7ae200ca, 0x00000000}},  //   hain, _făcâ, _vsot,
  { {0x69da2d46, 0x2918143a, 0x63a40288, 0x00000000}},  //   rete, ára_, kain,
  { {0x63a4044e, 0x69da01a3, 0x78ba2d47, 0x00000000}},  //   jain, sete, rutv,
  { {0x63a421d4, 0x78ba00f8, 0x44c801a2, 0x00000000}},  //   dain, sutv, eß_,
  { {0x69da1972, 0x7afd05fe, 0x7bc00190, 0x00000000}},  //   qete, åste, lgmu,
  { {0x63a40016, 0x81bd0044, 0xdb00008e, 0x00000000}},  //   fain, _আসল_, damé,
  { {0x69ca0201, 0x63a42d48, 0x3ea90ed8, 0x00000000}},  //   त्री, gain, šati_,
  { {0x2bd0001c, 0xeabc0044, 0x53340fd8, 0x00000000}},  // [8790] थ्या, _অনুম, ветт,
  { {0xdb0000f4, 0x27e90112, 0xd25b007e, 0x00000000}},  //   ramè, _haan_, іца_,
  { {0xd1310054, 0x63a40020, 0x31c4005e, 0x00000000}},  //   دما_, bain, ъств,
  { {0xa295008b, 0x27e9006c, 0x63a4032c, 0x00000000}},  //   _памі, _jaan_, cain,
  { {0x61e72d49, 0x0f350123, 0x27e92d4a, 0x00000000}},  //   _tajl, رکرد, _maan_,
  { {0x27e90007, 0x780c0061, 0x00000000, 0x00000000}},  //   _laan_, _हक्क_,   ,
  { {0x25a101a2, 0xf41f00f8, 0x00000000, 0x00000000}},  //   _mehl_, _klä_,   ,
  { {0x7cca005f, 0x3eb20006, 0x2d870051, 0x00000000}},  //   _mərh, šyta_, scne_,
  { {0xef54005e, 0x00000000, 0x00000000, 0x00000000}},  //   _акть,   ,   ,
  { {0x63a419be, 0xf41f00b0, 0x7bdb010e, 0x00000000}},  //   zain, _llä_, seuu,
  { {0x27e90250, 0x200d0007, 0x09e10044, 0x00000000}},  //   _baan_, _koei_, বালা,
  { {0xab5d0036, 0x9f440062, 0x2b401adc, 0x00000000}},  //   zeży, _samé_, _žice_,
  { {0x63a411e8, 0xcc3a007b, 0x27e9006a, 0x00000000}},  //   vain, _צענט, _daan_,
  { {0x63a4011c, 0xd9450893, 0x22840538, 0x00000000}},  //   wain, _пели, _rök_,
  { {0x22840073, 0x63a4046e, 0xa50a005e, 0x00000000}},  //   _sök_, tain, чева_,
  { {0x27e90100, 0x6b890169, 0x3c3a0089, 0x00000000}},  //   _gaan_, nceg, tīvi_,
  { {0x41b60867, 0x6aa906ec, 0x69c10009, 0x00000000}},  // [87a0] есет, nsef, ogle,
  { {0x69c10018, 0x63a42a08, 0x80c90044, 0x00000000}},  //   ngle, sain, রবন্,
  { {0x63a40e46, 0xdb0019cd, 0x659b00a0, 0x00000000}},  //   pain, ramé, _מייק,
  { {0x81c20044, 0xa2b2007d, 0x7dd3006b, 0x00000000}},  //   ্যই_, ेंद्, hısı,
  { {0x7cca006b, 0x6aa90190, 0x200d22e1, 0x00000000}},  //   _tərk, jsef, _doei_,
  { {0x6aa92d4b, 0x00000000, 0x00000000, 0x00000000}},  //   dsef,   ,   ,
  { {0x3243041f, 0x7cca006b, 0x200d00d9, 0x00000000}},  //   _серг, _kəri, _foei_,
  { {0x59c2006e, 0xdee6003b, 0x38850089, 0x00000000}},  //   _शाहर, _поби, _pērn_,
  { {0xdcea0676, 0x27e90058, 0xd00f0025, 0x00000000}},  //   rafı, _raan_, _الق_,
  { {0x69c1000c, 0x27e90d4a, 0xf3ff0011, 0x00000000}},  //   ggle, _saan_, _nhãn_,
  { {0x39580030, 0x27e90022, 0x0dc90025, 0x00000000}},  //   ærs_, _paan_, _تبقى_,
  { {0x7cca006b, 0x7e7a0471, 0x00000000, 0x00000000}},  //   _nəri, _hitp,   ,
  { {0x27e9021e, 0x7cca006b, 0x81ab0044, 0x00000000}},  //   _vaan_, _sərh, ক্ট_,
  { {0xdb020181, 0x49920167, 0x7dd3005a, 0x00000000}},  //   _adoç, _حیدر, cısı,
  { {0x644100f4, 0xe78716e0, 0x27e902d4, 0x00000000}},  //   élio, _пупо, _taan_,
  { {0xb4e10164, 0x6d5a00ea, 0xb6f501fc, 0x00000000}},  //   _धनी_, _myta, _азиј,
  { {0x7cca006b, 0x200d01d6, 0x38690288, 0x00000000}},  // [87b0] _dəri, _roei_, _ihar_,
  { {0xa507008b, 0x38690066, 0x00000000, 0x00000000}},  //   _зямл, _hhar_,   ,
  { {0x7cca013f, 0xb33b0023, 0x248100d9, 0x00000000}},  //   _fəri, _deça, _uuhm_,
  { {0x6e951663, 0x69c10e3b, 0x7dd3005a, 0x00000000}},  //   виду, zgle, zısı,
  { {0xdee50a27, 0x7dd3014a, 0x644800f4, 0x00000000}},  //   толи, yısı, édie,
  { {0xde940025, 0x7cca006b, 0x6d5a00f8, 0x00000000}},  //   اجنب, _zəri, _byta,
  { {0x6d5a0036, 0x3869002d, 0x7e7a0085, 0x00000000}},  //   _cyta, _ohar_, _ditp,
  { {0x2ef500d7, 0x201f001a, 0x7cca006b, 0x00000000}},  //   _избр, _ului_, _xəri,
  { {0x6b890091, 0x93f6013f, 0x69c101a2, 0x00000000}},  //   rceg, _şəkə, tgle,
  { {0x6aa920e9, 0x6b890197, 0x69c12d4c, 0x00000000}},  //   rsef, sceg, ugle,
  { {0x69c1001f, 0xd945003b, 0x6aa90056, 0x00000000}},  //   rgle, тени, ssef,
  { {0xe73a0069, 0x69c112dc, 0xb886000c, 0x00000000}},  //   дем_, sgle, _skíð,
  { {0x7dd3005a, 0x00000000, 0x00000000, 0x00000000}},  //   pısı,   ,   ,
  { {0xdb1b1261, 0x7cca013f, 0x00000000, 0x00000000}},  //   nguí, _səri,   ,
  { {0xf3ff0181, 0x00000000, 0x00000000, 0x00000000}},  //   _chão_,   ,   ,
  { {0x38692d4d, 0x7cca006b, 0xe8d6009b, 0x00000000}},  //   _ghar_, _qəri, _יוצר_,
  { {0xb33b0181, 0x00000000, 0x00000000, 0x00000000}},  // [87c0] _peça,   ,   ,
  { {0xb21b124e, 0x42231b67, 0x6448009d, 0x00000000}},  //   _stær, адув, édib,
  { {0xb33b008d, 0x3ead1fe1, 0xa5b70049, 0x00000000}},  //   _veça, _avet_, _בליק_,
  { {0x6e210ca4, 0x6d5a0006, 0x7e7a01d6, 0x00000000}},  //   _allb, _ryta, _sitp,
  { {0x442201f6, 0xdfcf0b59, 0x3ead08de, 0x00000000}},  //   _ilk_, تين_, _cvet_,
  { {0x93f6005f, 0x6d5a0046, 0x37d60044, 0x00000000}},  //   _şəhə, _pyta, _তোমর,
  { {0x3ead014a, 0x10a30088, 0xa3c9006e, 0x00000000}},  //   _evet_, _висн, ल्क_,
  { {0x6d5a2d4e, 0xdc2a0014, 0x7e7a01c3, 0x00000000}},  //   _vyta, بسته_, _witp,
  { {0x629601aa, 0x7e7a01f3, 0x201c007f, 0x00000000}},  //   npyo, _titp, ūvis_,
  { {0x7e7a01b5, 0x38690b4a, 0x7afd03b1, 0x00000000}},  //   _uitp, _shar_, åsta,
  { {0x23e2013d, 0x91bb009b, 0x386900d2, 0x00000000}},  //   _पसंद, ומיי, _phar_,
  { {0x3c3a0089, 0x28c4007d, 0x92a900b4, 0x00000000}},  //   tīvu_, लंबि, nałó,
  { {0xf848007e, 0x7c222d4f, 0x387b0082, 0x00000000}},  //   тчэй_, _ilor, _viqr_,
  { {0xb8f40054, 0x44220052, 0x7c222d50, 0x00000000}},  //   _مكتب, _alk_, _hlor,
  { {0x03c7008b, 0x3869002a, 0x55580242, 0x00000000}},  //   ксам, _thar_, варя_,
  { {0x44220061, 0x99650088, 0x7c22000a, 0x00000000}},  //   _clk_, _стіл, _jlor,
  { {0x24580057, 0x284a0049, 0x44222d51, 0x00000000}},  // [87d0] тать_, _רעפּ, _dlk_,
  { {0x7c22029a, 0x442201b5, 0x9f440129, 0x00000000}},  //   _llor, _elk_, _camí_,
  { {0x0cbd0055, 0x3ead0cce, 0x7c220efe, 0x00000000}},  //   _আন্ত, _svet_, _olor,
  { {0x765507a3, 0x44220082, 0x00000000, 0x00000000}},  //   lozy, _glk_,   ,
  { {0x3c3a001e, 0x7cca006b, 0x03d60104, 0x00000000}},  //   hīvs_, _məru, _גורם_,
  { {0x7c222d52, 0x5187025f, 0x09bd0044, 0x00000000}},  //   _alor, _шума, _অস্থ,
  { {0x7c220093, 0xdb1b0b32, 0xb4b1013d, 0x00000000}},  //   _blor, rguí, _ऑटो_,
  { {0x30da007b, 0x20f30166, 0x09ab0061, 0x00000000}},  //   _אַמע, _ići_, चण्य,
  { {0x32110826, 0x00000000, 0x00000000, 0x00000000}},  //   _kozy_,   ,   ,
  { {0x7c22002d, 0xb33b00f4, 0x68261ad4, 0x00000000}},  //   _elor, _leço, _móde,
  { {0x07a60152, 0x7cca006b, 0x00000000, 0x00000000}},  //   ланн, _sərv,   ,
  { {0x30da007b, 0xc5e9009b, 0x7cca006b, 0x00000000}},  //   ײַטע, _מד_, _pərv,
  { {0x9f8a006c, 0x6b9b107e, 0x00000000, 0x00000000}},  //   _tööd_, mbug,   ,
  { {0x2aba00b6, 0x7c220059, 0x44220253, 0x00000000}},  //   _נמצא, _zlor, _slk_,
  { {0x44220145, 0x00000000, 0x00000000, 0x00000000}},  //   _plk_,   ,   ,
  { {0x44220026, 0xba3d013e, 0x74160426, 0x00000000}},  //   _qlk_, jrůz, دورا,
  { {0xe1fa02b8, 0xa920006b, 0x6826004a, 0x00000000}},  // [87e0] нга_, _çörə, _códe,
  { {0x55e60c45, 0x26c20f2f, 0x7cca006b, 0x00000000}},  //   _сооб, muko_, _zəru,
  { {0x26c2002d, 0x645f0009, 0x44221669, 0x00000000}},  //   luko_, blqi, _tlk_,
  { {0xe29a01fb, 0x7cca006b, 0x00000000, 0x00000000}},  //   _пам_, _mərt,   ,
  { {0xdd9200a6, 0x26c22d53, 0x78ba012d, 0x00000000}},  //   موش_, nuko_, zrtv,
  { {0xc1e704e1, 0x69d303d7, 0x6abe0044, 0x00000000}},  //   _مکمل_, _बॉली, ্বমো,
  { {0x62862d54, 0x7c220129, 0x26c20020, 0x00000000}},  //   _huko, _plor, huko_,
  { {0x61ee0219, 0x6286000b, 0x26c2002d, 0x00000000}},  //   _habl, _kuko, kuko_,
  { {0x61ee000b, 0x7c220065, 0x81e70044, 0x00000000}},  //   _kabl, _vlor, ভার_,
  { {0x61ee01ca, 0xd8f801fb, 0x26c2002d, 0x00000000}},  //   _jabl, вної_, duko_,
  { {0x5bc6023c, 0x6444021e, 0x3257034e, 0x00000000}},  //   _مقال, knii, רסים_,
  { {0x26c20020, 0x61ee008e, 0x2fc60058, 0x00000000}},  //   fuko_, _labl, ngog_,
  { {0xb33b00f4, 0xcc570097, 0x26c21f6b, 0x00000000}},  //   _reço, _גבאי_, guko_,
  { {0x27ed01d9, 0x9f4400f6, 0xd4e704f1, 0x00000000}},  //   žen_, _mamà_, люби,
  { {0xf99300b6, 0x63a60116, 0x76550095, 0x00000000}},  //   _פרק_, _bekn, rozy,
  { {0x6286011c, 0x26c20058, 0x64442d55, 0x00000000}},  //   _buko, buko_, gnii,
  { {0x925901f9, 0x6b820020, 0x76550036, 0x00000000}},  // [87f0] ваат_, _mgog, pozy,
  { {0xbb3b0049, 0x62862d56, 0x00000000, 0x00000000}},  //   געמי, _duko,   ,
  { {0x61ee2d57, 0x2d8e0009, 0x321101dc, 0x00000000}},  //   _dabl, dcfe_, _vozy_,
  { {0x63a6023d, 0x6b820016, 0x2ef50545, 0x00000000}},  //   _gekn, _ngog, изер,
  { {0x69d8299e, 0x62860061, 0xb33b005f, 0x00000000}},  //   _obve, _guko, _keçm,
  { {0x44292d58, 0xef18008b, 0x443b1638, 0x00000000}},  //   lha_, ымі_, liq_,
  { {0x26c21126, 0x20f30166, 0x628601a2, 0x00000000}},  //   zuko_, _ući_, _zuko,
  { {0x44290fb3, 0x26c2107e, 0x443b0ede, 0x00000000}},  //   nha_, yuko_, niq_,
  { {0x6b9b0190, 0x628000f4, 0xcda90025, 0x00000000}},  //   rbug, _émot, _لهذه_,
  { {0x44292d59, 0x6abb2d5a, 0x6b9b01f3, 0x00000000}},  //   hha_, rruf, sbug,
  { {0x5d84006d, 0x44292b1c, 0x7cca006b, 0x00000000}},  //   _المل, kha_, _dərs,
  { {0x26c2022b, 0x44291087, 0x290b00f5, 0x00000000}},  //   tuko_, jha_, ćca_,
  { {0x4429000b, 0xd90f026c, 0x8c1a00b6, 0x00000000}},  //   dha_, تیں_, _שוני,
  { {0x26c2022b, 0x7c292d5b, 0xc98701f9, 0x00000000}},  //   ruko_, lher, _суди,
  { {0x64a604af, 0x443b005f, 0x61ee0059, 0x00000000}},  //   раба, fiq_, _rabl,
  { {0x44290b0e, 0x61ee00f4, 0x26c20020, 0x00000000}},  //   gha_, _sabl, puko_,

  { {0x61ee0211, 0x81c10044, 0x6444006c, 0x00000000}},  // [8800] _pabl, ্জন_, rnii,
  { {0xb33b011f, 0xc69300b6, 0x62860166, 0x00000000}},  //   _geçm, _ואז_, _vuko,
  { {0x442921b3, 0x55bb00b6, 0x7c2905e5, 0x00000000}},  //   bha_, _במיו, kher,
  { {0x44290195, 0xeaa70025, 0xfa880011, 0x00000000}},  //   cha_, _وع_, _lừa_,
  { {0x61ee0472, 0x7c292d5c, 0x7c3b00e5, 0x00000000}},  //   _tabl, dher, diur,
  { {0x40960331, 0x61ee0061, 0x00000000, 0x00000000}},  //   _врат, _uabl,   ,
  { {0xac260517, 0x442000b4, 0x00000000, 0x00000000}},  //   ифик, oki_,   ,
  { {0x6aa20263, 0x20e80279, 0x7c2904b4, 0x00000000}},  //   _pwof, _işi_, gher,
  { {0x787f0089, 0x5a34005e, 0xfa880082, 0x00000000}},  //   _būvn, йнит, _bừa_,
  { {0x4420006c, 0x442918bc, 0x5cd60088, 0x00000000}},  //   hki_, zha_, _відх,
  { {0x4420021e, 0x443b006b, 0xfa880011, 0x00000000}},  //   kki_, yiq_, _dừa_,
  { {0x7c292d5d, 0x44200036, 0x44290065, 0x00000000}},  //   cher, jki_, xha_,
  { {0x44202d5e, 0x81ac0055, 0x09e10044, 0x00000000}},  //   dki_, _গান_, বাজা,
  { {0x44202d5f, 0x20c9001c, 0x4429002b, 0x00000000}},  //   eki_, ांमध, wha_,
  { {0x442906f7, 0x443b006b, 0x44202d60, 0x00000000}},  //   tha_, tiq_, fki_,
  { {0xe97b00b6, 0x44292d61, 0x44200022, 0x00000000}},  //   _בנוש, uha_, gki_,
  { {0x442900b0, 0xf77300a6, 0x443b0350, 0x00000000}},  // [8810] rha_, _باغ_, riq_,
  { {0x442906fe, 0xc7b1026c, 0x69c801e2, 0x00000000}},  //   sha_, _بڑھ_, ngde,
  { {0x44202910, 0x443b0026, 0x46150123, 0x00000000}},  //   bki_, piq_, _نوکر,
  { {0x44201547, 0xa3ce03d7, 0x1dc90204, 0x00000000}},  //   cki_, _राय_, _राहत,
  { {0x63ad00b0, 0x4439010f, 0x161b0204, 0x00000000}},  //   maan, _ims_, _नकार_,
  { {0x63ad011c, 0x6da201f9, 0x7c2900ab, 0x00000000}},  //   laan, пиша, wher,
  { {0x7c290038, 0xa3ce0309, 0x44391697, 0x00000000}},  //   ther, _राम_, _kms_,
  { {0x1be900da, 0x4439006c, 0x61e52d62, 0x00000000}},  //   удии_, _jms_, lehl,
  { {0x7c29010f, 0x7c3b2d63, 0xdb00000c, 0x00000000}},  //   rher, riur, tamá,
  { {0x7c29000b, 0x44202d64, 0x7a2401aa, 0x00000000}},  //   sher, zki_, _pòta,
  { {0x63ad0343, 0xfa88001d, 0x44200036, 0x00000000}},  //   kaan, _vừa_, yki_,
  { {0x63ad0ac0, 0x44390061, 0x7bd90009, 0x00000000}},  //   jaan, _nms_, _ubwu,
  { {0x44200059, 0xceb20049, 0x7bc900e7, 0x00000000}},  //   vki_, ּיל_, mgeu,
  { {0x44200046, 0x69dd0010, 0x00000000, 0x00000000}},  //   wki_, őseb,   ,
  { {0x442003e9, 0x4439007f, 0x63ad01d6, 0x00000000}},  //   tki_, _bms_, faan,
  { {0x3eb2010a, 0x63ad0007, 0xb386003b, 0x00000000}},  //   šyti_, gaan, слал,
  { {0x44202cfe, 0xd467026b, 0x61e5010f, 0x00000000}},  // [8820] rki_, сите_, fehl,
  { {0x645d1c45, 0x7afd00b0, 0xd5b000a1, 0x00000000}},  //   _eksi, ästy, _زہر_,
  { {0x5a3a0049, 0xf77f0181, 0x44201ddd, 0x00000000}},  //   נגעה, meça_, pki_,
  { {0x7ae9000b, 0x63ad0397, 0xf77f00fa, 0x00000000}},  //   kwet, caan, leça_,
  { {0x92f60088, 0x69c800f8, 0x00000000, 0x00000000}},  //   _учні, ygde,   ,
  { {0xd25200a1, 0x7cca006b, 0x7ae9010e, 0x00000000}},  //   _رنز_, _bərp, dwet,
  { {0x645d021e, 0x443900b0, 0x20e80035, 0x00000000}},  //   _yksi, _yms_, _uşi_,
  { {0x443901f3, 0x2d850995, 0xeb97003b, 0x00000000}},  //   _xms_, _egle_, бић_,
  { {0x09ac0044, 0x9c7c000a, 0x00000000, 0x00000000}},  //   _খাবা, _osčv,   ,
  { {0xb33b02b9, 0x98a7011f, 0x23ad0006, 0x00000000}},  //   _seçk, _aynı_, mųjų_,
  { {0x63ad0760, 0xfca90014, 0x2d9500e2, 0x00000000}},  //   yaan, _نانو_, _фрус,
  { {0xbb860025, 0x7ae900e7, 0x6448009d, 0x00000000}},  //   _الإي, bwet, édil,
  { {0x44391651, 0x63ad0052, 0x645d012d, 0x00000000}},  //   _rms_, vaan, _rksi,
  { {0x7afd0030, 0x63ad0020, 0x9f5f009d, 0x00000000}},  //   æste, waan, éréo_,
  { {0x63ad02ae, 0x443912da, 0x16342751, 0x00000000}},  //   taan, _pms_, черя,
  { {0x25bf22cc, 0x443900f6, 0x5399007c, 0x00000000}},  //   şul_, _qms_, рвая_,
  { {0xb33b005f, 0x63ad011c, 0xf77f0181, 0x00000000}},  // [8830] _keçi, raan, beça_,
  { {0x63ad2d65, 0x44390253, 0x00000000, 0x00000000}},  //   saan, _wms_,   ,
  { {0x443900b0, 0x63ad17ce, 0x68260161, 0x00000000}},  //   _tms_, paan, _módn,
  { {0x44392d66, 0x16070316, 0x00000000, 0x00000000}},  //   _ums_, शावर_,   ,
  { {0xa3ce02d2, 0x287c0049, 0x66170032, 0x00000000}},  //   _रात_, אנאמ, _koxk,
  { {0xae0302fb, 0x2c4c00b9, 0x7c9501fc, 0x00000000}},  //   लाइन_, věda_, ориц,
  { {0x7c84003b, 0x66170288, 0x00000000, 0x00000000}},  //   пуње, _moxk,   ,
  { {0xa4b800b6, 0x7ae90066, 0x291e0006, 0x00000000}},  //   צלחה_, twet, dyta_,
  { {0x7bc900f4, 0xdb0001b1, 0x27f2000a, 0x00000000}},  //   rgeu, jamä, _rayn_,
  { {0x394502d3, 0x7ae90112, 0x89a90081, 0x00000000}},  //   жног, rwet, шков_,
  { {0x7ae90007, 0xa3c90061, 0x00000000, 0x00000000}},  //   swet, ईला_,   ,
  { {0xe8df001d, 0x81c10044, 0x00000000, 0x00000000}},  //   hiệm_, ্জি_,   ,
  { {0x66170270, 0x00000000, 0x00000000, 0x00000000}},  //   _boxk,   ,   ,
  { {0xb33b011f, 0x00000000, 0x00000000, 0x00000000}},  //   _geçi,   ,   ,
  { {0xf77f2d67, 0xa9790049, 0x81c10044, 0x00000000}},  //   reça_, _דאַכ, ্জা_,
  { {0xccf2009b, 0xb4660245, 0xdb00006c, 0x00000000}},  //   וכל_, ікал, bamä,
  { {0x987b0049, 0xe8890082, 0x225a0082, 0x00000000}},  // [8840] _דאקט, _kẻo_, topk_,
  { {0x6826139d, 0xfe6500a2, 0x23ad007f, 0x00000000}},  //   _kódo, _سگ_, vųjų_,
  { {0x765c011c, 0x24820022, 0xbf8a19a2, 0x00000000}},  //   mory, _tikm_, абеж_,
  { {0x81e70055, 0x68260047, 0x30760783, 0x00000000}},  //   ভাগ_, _módo, цузс,
  { {0x0877007b, 0xaedc0c18, 0x437600ed, 0x00000000}},  //   קענט_, ублi, _фунт,
  { {0xdcba0265, 0xa0a602dc, 0xe8890082, 0x00000000}},  //   ащи_, _магд, _nẻo_,
  { {0x25ba0022, 0xcc2a013b, 0x00000000, 0x00000000}},  //   _mdpl_, ицид_,   ,
  { {0x765c19ff, 0x09b40055, 0xb33b01f6, 0x00000000}},  //   hory, জ্ঞা, _seçi,
  { {0x32181516, 0x63b90036, 0x2d9602ea, 0x00000000}},  //   _kory_, ówni, _дрес,
  { {0x291e0006, 0xfce62d68, 0x38600022, 0x00000000}},  //   tyta_, _мозо, _akir_,
  { {0x8e75007e, 0xdb000039, 0xed5a004c, 0x00000000}},  //   _хутч, damå, _тож_,
  { {0x8c140055, 0x291e0006, 0x32180197, 0x00000000}},  //   ়োজন_, ryta_, _lory_,
  { {0x249a0093, 0x765c005b, 0x291e0006, 0x00000000}},  //   _atpm_, fory, syta_,
  { {0x765c1721, 0x09b40044, 0xddda000a, 0x00000000}},  //   gory, জ্জা, _oktō,
  { {0x45d4005e, 0x00000000, 0x00000000, 0x00000000}},  //   ьорс,   ,   ,
  { {0x69da0039, 0x25a60107, 0x3cfe012d, 0x00000000}},  //   lfte, _đole_, _mrtv_,
  { {0xf77f0181, 0x8335005e, 0x00000000, 0x00000000}},  // [8850] meço_, чнах,   ,
  { {0x69da01a2, 0xf1c30082, 0x7ae200e7, 0x00000000}},  //   nfte, _giờ_, _mpot,
  { {0xd25000a1, 0xd258007e, 0x64411f1f, 0x00000000}},  //   ڑنے_, іцу_, élis,
  { {0x155a00b6, 0x2c4501c5, 0x47c20044, 0x00000000}},  //   _לכתב, pēdi_, ষ্ঠী,
  { {0x442b00d4, 0x63a2008e, 0xbea5004d, 0x00000000}},  //   _ilc_, ñone, чалк,
  { {0xee380c50, 0x321800b4, 0x00000000, 0x00000000}},  //   оні_, _gory_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61f50211, 0xc1040379, 0xc3120044, 0x00000000}},  //   _hazl, _توفي, _সেটি_,
  { {0xf77f0181, 0x61f50006, 0x0b450152, 0x00000000}},  //   deço_, _kazl, янин,
  { {0x442b00ab, 0x7a24000a, 0x61f52d69, 0x00000000}},  //   _llc_, _fòtm, _jazl,
  { {0x61f52d6a, 0x442b0051, 0x644f0036, 0x00000000}},  //   _mazl, _olc_, _ojci,
  { {0x7c2d06b8, 0x66e60088, 0x1bd520e6, 0x00000000}},  //   ďars, пома, _ходя,
  { {0x765c2d6b, 0x7c2b0026, 0x249a0145, 0x00000000}},  //   tory, _ilgr, _stpm_,
  { {0xa6e3000c, 0xe8890011, 0xa3ce013d, 0x00000000}},  //   óðar, _hẻm_, _राह_,
  { {0xd4d5007e, 0x442b257a, 0x7afb2d6c, 0x00000000}},  //   мітэ, _blc_, lvut,
  { {0xc483064b, 0xccf20049, 0x442b00ca, 0x00000000}},  //   елск, עכן_, _clc_,
  { {0x32180036, 0x442b0dcb, 0x00000000, 0x00000000}},  // [8860] _pory_, _dlc_,   ,
  { {0x175700b6, 0xa3ce0164, 0x442b06ed, 0x00000000}},  //   _מספר_, _राव_, _elc_,
  { {0x2eff0022, 0x442b1746, 0x00000000, 0x00000000}},  //   _aruf_, _flc_,   ,
  { {0x44240011, 0x442b0145, 0x1fd6013d, 0x00000000}},  //   _ôm_, _glc_, ठभेड,
  { {0x61f5011f, 0xdb0b0065, 0x32180075, 0x00000000}},  //   _fazl, _degë, _tory_,
  { {0x13b10044, 0x00000000, 0x00000000, 0x00000000}},  //   _ছায়,   ,   ,
  { {0x7ae21712, 0xa11600a1, 0xd1b300a1, 0x00000000}},  //   _spot, _عورت, _سینک,
  { {0x63a40f4f, 0xdb0b0023, 0x442b00d2, 0x00000000}},  //   nbin, _gegë, _xlc_,
  { {0x61f5014a, 0x298a0088, 0x63a402d4, 0x00000000}},  //   _yazl, йсно_, ibin,
  { {0x3f800006, 0x831b0049, 0x98b80423, 0x00000000}},  //   žius_, צויז, олот_,
  { {0xdca301fb, 0x69da0e42, 0x3b8602dc, 0x00000000}},  //   _захи, rfte, _елег,
  { {0x63a4021c, 0x00000000, 0x00000000, 0x00000000}},  //   jbin,   ,   ,
  { {0xf77f02d5, 0x7ae20091, 0x63a40091, 0x00000000}},  //   reço_, _upot, dbin,
  { {0x4b7b009b, 0xa7fb004a, 0x00000000, 0x00000000}},  //   _האדו, doñe,   ,
  { {0x61f50e3b, 0x7a2d0211, 0x68260010, 0x00000000}},  //   _razl, _fútb, _módj,
  { {0xd251026c, 0x63a40058, 0x442b0026, 0x00000000}},  //   ھنا_, gbin, _qlc_,
  { {0xd767026c, 0x61f5021c, 0x67bc009b, 0x00000000}},  // [8870] _ڈاکٹ, _pazl, _המחק,
  { {0x26cb008e, 0x63a410bd, 0xdb0b1071, 0x00000000}},  //   muco_, abin, _degè,
  { {0x4fd51a02, 0x2127001d, 0xb33b00f4, 0x00000000}},  //   джет, ánh_, _reçu,
  { {0x2eff0145, 0x00000000, 0x00000000, 0x00000000}},  //   _pruf_,   ,   ,
  { {0xa7fb049a, 0x644d0051, 0x26cb004a, 0x00000000}},  //   coñe, mnai, nuco_,
  { {0x2f23001e, 0x644d0995, 0x63af2d6d, 0x00000000}},  //   _rīgā_, lnai, _hecn,
  { {0x644d0181, 0xcfb502dc, 0xb33b0023, 0x00000000}},  //   onai, _обвъ, _veçu,
  { {0x644d1e5a, 0x13b10055, 0x62870211, 0x00000000}},  //   nnai, _ছাড়, _hijo,
  { {0xb33b014a, 0x644d2d6e, 0x7bdb01d6, 0x00000000}},  //   _geçt, inai, rfuu,
  { {0x628f0951, 0x7afb006c, 0x644d0051, 0x00000000}},  //   _muco, rvut, hnai,
  { {0xdb0b0047, 0xd90f007a, 0x63a40006, 0x00000000}},  //   _megé, ایع_, ybin,
  { {0x2fcf0022, 0x629d0d17, 0x00000000, 0x00000000}},  //   nggg_, _otso,   ,
  { {0x09ac0055, 0xd83901aa, 0xcfb6009b, 0x00000000}},  //   _খারা, nsčy_, ולרי_,
  { {0x6287007f, 0xdb0b00f6, 0x644d007f, 0x00000000}},  //   _nijo, _regè, enai,
  { {0x63a40168, 0x98562d6f, 0x21010166, 0x00000000}},  //   tbin, _отиш, nčić_,
  { {0x628f0035, 0x644d009d, 0x26cb0285, 0x00000000}},  //   _buco, gnai, buco_,
  { {0x4b7a007b, 0x628700f4, 0x43430401, 0x00000000}},  // [8880] ַטעג, _bijo, ветв,
  { {0xb5ca0014, 0x644d0051, 0x6287016c, 0x00000000}},  //   _بودم_, anai, _cijo,
  { {0x628704bd, 0xb33b014a, 0x87050167, 0x00000000}},  //   _dijo, _seçt, _قبیل,
  { {0x28c5006e, 0x644d0051, 0x2fcf0085, 0x00000000}},  //   _विनि, cnai, gggg_,
  { {0x987b0049, 0x6287008e, 0xdd920070, 0x00000000}},  //   קאנט, _fijo, نوش_,
  { {0x6287008e, 0x00000000, 0x00000000, 0x00000000}},  //   _gijo,   ,   ,
  { {0x628f00f6, 0x998c012d, 0x216710d6, 0x00000000}},  //   _zuco, tidž_, _жири_,
  { {0x62870288, 0x00000000, 0x00000000, 0x00000000}},  //   _zijo,   ,   ,
  { {0x98460089, 0x7535016e, 0x6e930025, 0x00000000}},  //   _dēļ_, zzzz, _للقا,
  { {0x4d7609b9, 0x00000000, 0x00000000, 0x00000000}},  //   _قطار,   ,   ,
  { {0xa3c0024c, 0xa3ce0183, 0x2d8c01ee, 0x00000000}},  //   ीला_, रला_, _igde_,
  { {0x26cb0885, 0x00000000, 0x00000000, 0x00000000}},  //   tuco_,   ,   ,
  { {0xa7740069, 0x63af01ee, 0xe6670088, 0x00000000}},  //   ключ, _recn, дтво,
  { {0xb8f40044, 0x26d9002d, 0x68fc0d32, 0x00000000}},  //   _হন_, rtso_, årds,
  { {0x628f2d70, 0xdb0b0010, 0x26cb2d71, 0x00000000}},  //   _suco, _regé, suco_,
  { {0x62872d72, 0x628f0880, 0xdb0b0010, 0x00000000}},  //   _sijo, _puco, _segé,
  { {0xf48402be, 0x644d0181, 0x6595007e, 0x00000000}},  // [8890] турн, rnai, _папу,
  { {0x644d1a0b, 0x416b003b, 0x00000000, 0x00000000}},  //   snai, ојем_,   ,
  { {0x63af2d73, 0x62870065, 0x00000000, 0x00000000}},  //   _tecn, _vijo,   ,
  { {0x44320502, 0x628f1cf6, 0x2d8c1ec5, 0x00000000}},  //   chy_, _tuco, _agde_,
  { {0x44292bc7, 0x28c503d7, 0xceeb0014, 0x00000000}},  //   mka_, _विभि, تران_,
  { {0x787600c4, 0x7a240173, 0x00000000, 0x00000000}},  //   máve, _fòti,   ,
  { {0x78761c8d, 0x2918006c, 0x7a2400d4, 0x00000000}},  //   láve, äral_, _gòti,
  { {0xa3d7007d, 0x21010166, 0x2cac00d9, 0x00000000}},  //   _साफ_, rčić_, _dwdd_,
  { {0x4429000c, 0x78761050, 0x00000000, 0x00000000}},  //   ika_, náve,   ,
  { {0x442908b5, 0xe9d901fc, 0xa2c2007d, 0x00000000}},  //   hka_, чко_, _लिस्,
  { {0x442906d5, 0x186a00e3, 0x68462c8c, 0x00000000}},  //   kka_, зани_, енна,
  { {0x44290119, 0x389700e5, 0xdb3500e2, 0x00000000}},  //   jka_, _căra_, _пеењ,
  { {0x787600c4, 0x7c290232, 0x3ead01aa, 0x00000000}},  //   jáve, mker, _jwet_,
  { {0x44290089, 0x78762d74, 0x7c292d75, 0x00000000}},  //   eka_, dáve, lker,
  { {0x7c291ea7, 0x443200ab, 0xa966005e, 0x00000000}},  //   oker, thy_, _пиша_,
  { {0x7c290d6f, 0x44292d76, 0x1ddf01f5, 0x00000000}},  //   nker, gka_, प्तत,
  { {0x7c29015c, 0x03f20044, 0x787600c4, 0x00000000}},  // [88a0] iker, ঙালী_, gáve,
  { {0xe1f70839, 0x7a242d77, 0x442914a6, 0x00000000}},  //   нгу_, _pòti, aka_,
  { {0x7c2902cc, 0x443200ab, 0x3ead04be, 0x00000000}},  //   kker, phy_, _awet_,
  { {0x4429083f, 0x7c2900b5, 0xbe8a012b, 0x00000000}},  //   cka_, jker, пске_,
  { {0x68260977, 0xc8ec0316, 0x63b62d78, 0x00000000}},  //   _códi, _जन्म_, mayn,
  { {0x7c290328, 0x80db0044, 0x3f8d06c0, 0x00000000}},  //   eker, ণিজ্, _egeu_,
  { {0x3da501fb, 0xa3d701f5, 0x00000000, 0x00000000}},  //   тріб, _साम_,   ,
  { {0x7c292d79, 0x63b61084, 0x3ead000a, 0x00000000}},  //   gker, nayn, _fwet_,
  { {0x59d40316, 0x661e20ad, 0x78520089, 0x00000000}},  //   _दादर, _oopk, tāvn,
  { {0x44292d7a, 0x7c29271c, 0x6da60025, 0x00000000}},  //   zka_, aker, _أمام,
  { {0x44290046, 0x787612dd, 0x22961f7d, 0x00000000}},  //   yka_, záve, _læk_,
  { {0x2fc00051, 0x7c292d7b, 0x44292d7c, 0x00000000}},  //   óigh_, cker, xka_,
  { {0x63b600e0, 0xead42540, 0x00000000, 0x00000000}},  //   dayn, _роль,   ,
  { {0x44290046, 0xe980007e, 0x78762d7d, 0x00000000}},  //   wka_, _калi_, váve,
  { {0x6826000a, 0x00000000, 0x00000000, 0x00000000}},  //   _nódw,   ,   ,
  { {0x78ba040d, 0xd6db1548, 0x44290006, 0x00000000}},  //   mstv, _ето_, uka_,
  { {0x78ba07e4, 0x661e0022, 0x07f80380, 0x00000000}},  // [88b0] lstv, _fopk, _سريع_,
  { {0x44290073, 0x51f80a78, 0x78762d7e, 0x00000000}},  //   ska_, нную_, ráve,
  { {0x7fd50245, 0xd7c50061, 0x68260d7b, 0x00000000}},  //   вілі, _वयाच, _sódi,
  { {0x64482d7f, 0x764701aa, 0x44290065, 0x00000000}},  //   édit, lijy, qka_,
  { {0x141a00a3, 0xdb0b0030, 0x0af20044, 0x00000000}},  //   _חורב, _udgø, জমুল_,
  { {0xf7740476, 0x78ba063f, 0x00000000, 0x00000000}},  //   נקס_, kstv,   ,
  { {0x7c290f5d, 0xf402001a, 0x91650014, 0x00000000}},  //   tker, _faţă_, _شهره,
  { {0x78ba00ee, 0x00000000, 0x00000000, 0x00000000}},  //   dstv,   ,   ,
  { {0x3ed90025, 0xce95007c, 0x00000000, 0x00000000}},  //   _زواج_, _разъ,   ,
  { {0x63b60276, 0x00000000, 0x00000000, 0x00000000}},  //   zayn,   ,   ,
  { {0x07a60b7b, 0x78ba01c5, 0x00000000, 0x00000000}},  //   канн, gstv,   ,
  { {0x7e630f80, 0x201f0e6d, 0x00000000, 0x00000000}},  //   lonp, _joui_,   ,
  { {0xfc4601ca, 0x661e01c5, 0x7cca006b, 0x00000000}},  //   ších_, _popk, _sərx,
  { {0xceb2019b, 0x2c4c00b9, 0x78ba06a6, 0x00000000}},  //   שים_, vědi_, bstv,
  { {0xdb0b0010, 0x6fb30061, 0x63b600e0, 0x00000000}},  //   _megí, ुणां, tayn,
  { {0x2ae5006e, 0xe8d60104, 0x6b9b0521, 0x00000000}},  //   _कहाँ_, _סופר_, ncug,
  { {0xd4670517, 0x63b6005f, 0x7e630c5c, 0x00000000}},  // [88c0] тите_, rayn, konp,
  { {0xa3d703d7, 0x22960030, 0x7d08009d, 0x00000000}},  //   _साथ_, _væk_, _jérô,
  { {0x6448009d, 0x200d0258, 0x00000000, 0x00000000}},  //   édis, _bnei_,   ,
  { {0xd91a0049, 0xc952009b, 0x00000000, 0x00000000}},  //   וועל, סמא_,   ,
  { {0xa3d702fb, 0x78ba04bb, 0x200d00e5, 0x00000000}},  //   _सात_, zstv, _dnei_,
  { {0x200d0305, 0x00000000, 0x00000000, 0x00000000}},  //   _enei_,   ,   ,
  { {0x61460072, 0x61fc1f74, 0x61fe00ea, 0x00000000}},  //   _рева, _iarl, mdpl,
  { {0x78ba01d9, 0x5f060175, 0xdfd20379, 0x00000000}},  //   vstv, _изба, _خير_,
  { {0x25b801e5, 0xdfcf09b9, 0x00000000, 0x00000000}},  //   karl_, _ذيل_,   ,
  { {0x78ba06a2, 0x61fe0bbc, 0x68262bdf, 0x00000000}},  //   tstv, ndpl, _módu,
  { {0x61fc0007, 0x4973004c, 0x3ea62d80, 0x00000000}},  //   _marl, ильс, lpot_,
  { {0x78ba086e, 0xa3ce0309, 0x6d5a008e, 0x00000000}},  //   rstv, _राग_, _ixta,
  { {0x6f021e3b, 0x3ea601aa, 0x682600d6, 0x00000000}},  //   nvoc, npot_, _nódu,
  { {0x78ba05fa, 0xa4d50106, 0x6f020779, 0x00000000}},  //   pstv, логі, ivoc,
  { {0xfa77019b, 0xa3ce0061, 0x00000000, 0x00000000}},  //   _שעות_, रलं_,   ,
  { {0x5454004c, 0x787606b8, 0x3ea60336, 0x00000000}},  //   авст, rávc, kpot_,
  { {0x61fc121b, 0x33750867, 0x2d9e02cc, 0x00000000}},  // [88d0] _barl, угар, _ofte_,
  { {0x35f50113, 0xdb000129, 0x41b50025, 0x00000000}},  //   _спор, lamó, امار,
  { {0x61fc018e, 0xdb0b0219, 0x787629c5, 0x00000000}},  //   _darl, _regí, láva,
  { {0xdb0b0047, 0x61fc00ab, 0x2d9e0023, 0x00000000}},  //   _segí, _earl, _afte_,
  { {0x6d5a005f, 0x61fc02e5, 0x787604bb, 0x00000000}},  //   _axta, _farl, náva,
  { {0x7bc20bf2, 0x61fc230d, 0x00000000, 0x00000000}},  //   _adou, _garl,   ,
  { {0xeb990373, 0x7e631136, 0xddda000a, 0x00000000}},  //   ний_, ronp, _oktņ,
  { {0x200d000d, 0x7e630146, 0x1bb90025, 0x00000000}},  //   _unei_, sonp, رابع_,
  { {0x6d5a0208, 0x28c50164, 0x05d301f5, 0x00000000}},  //   _exta, _विहि, _तांब,
  { {0x787606b8, 0x38692d81, 0x2bd50061, 0x00000000}},  //   dáva, _akar_, _धावा,
  { {0x2ba4006e, 0x6abb01e5, 0x00000000, 0x00000000}},  //   _ग्वा, ssuf,   ,
  { {0x6e210030, 0x2c09013d, 0xe73a0121, 0x00000000}},  //   _holb, वाओं_, еем_,
  { {0x28c50201, 0x09e509ae, 0x6e2100db, 0x00000000}},  //   _विवि, _болн, _kolb,
  { {0xaf760049, 0x38691e3a, 0x7f3a0049, 0x00000000}},  //   טערס_, _ekar_, געשו,
  { {0x69c30802, 0x69d801f5, 0x6e2104eb, 0x00000000}},  //   _idne, _माती, _molb,
  { {0x29070085, 0x00000000, 0x00000000, 0x00000000}},  //   _irna_,   ,   ,
  { {0x24800065, 0xa95200a1, 0x3ea60146, 0x00000000}},  // [88e0] rmim_, _نہیں, xpot_,
  { {0xf1a9007a, 0x29070022, 0xdb0b00f6, 0x00000000}},  //   نامه_, _krna_, _megà,
  { {0x61fc06b5, 0x3ebf000d, 0x61fe032e, 0x00000000}},  //   _varl, _avut_, rdpl,
  { {0x6aad0f68, 0x61fc0253, 0x68fc0737, 0x00000000}},  //   _ħafn, _warl, ærdi,
  { {0xc7d7019b, 0x61fc2d82, 0x78520089, 0x00000000}},  //   רוני_, _tarl, tāvj,
  { {0xccfa012b, 0x44220011, 0x3ea601d6, 0x00000000}},  //   ећи_, _hok_, rpot_,
  { {0x6aa2009f, 0xf8c50201, 0x4422023a, 0x00000000}},  //   _stof, _विषय, _kok_,
  { {0x69c30016, 0x68260010, 0x4422266c, 0x00000000}},  //   _adne, _móds, _jok_,
  { {0x5a3401f9, 0x628e13df, 0x2907002a, 0x00000000}},  //   инит, _kibo, _arna_,
  { {0x2ba402fb, 0xa3e402fb, 0x4422000c, 0x00000000}},  //   _ग्रा, प्त_, _lok_,
  { {0x8d9306ea, 0x4422049b, 0x7d930054, 0x00000000}},  //   _المش, _ook_, _المؤ,
  { {0x628e0a04, 0x442202cc, 0x81570049, 0x00000000}},  //   _libo, _nok_, רסטע_,
  { {0xa3ce02f4, 0x2907000c, 0xdb001801, 0x00000000}},  //   _राज_, _erna_, ramó,
  { {0x7c2201b5, 0x44222764, 0x78760027, 0x00000000}},  //   _hoor, _aok_, ráva,
  { {0x7c222d83, 0x442205ad, 0x787610fa, 0x00000000}},  //   _koor, _bok_, sáva,
  { {0x69c30541, 0x4422014a, 0x26de001a, 0x00000000}},  //   _zdne, _cok_, ător_,
  { {0x44222d84, 0x7c220168, 0x64460146, 0x00000000}},  // [88f0] _dok_, _moor, _dmki,
  { {0x7d0811b8, 0x628e016e, 0x6aa40023, 0x00000000}},  //   _ords, _cibo, _çifu,
  { {0x645a2d85, 0x442201aa, 0xdb0b0010, 0x00000000}},  //   étic, _fok_, _megá,
  { {0x7c22017b, 0x6e21004e, 0xe8d700b3, 0x00000000}},  //   _noor, _solb, רואר_,
  { {0x63ad020c, 0x44c1010a, 0x27e904ea, 0x00000000}},  //   mban, lė_, _mban_,
  { {0x51870545, 0x628e2d86, 0x00000000, 0x00000000}},  //   _буба, _gibo,   ,
  { {0x4422011f, 0x44c1010a, 0x6e2100b9, 0x00000000}},  //   _yok_, nė_, _volb,
  { {0x63ad010f, 0xdd9100a1, 0x3cec0035, 0x00000000}},  //   nban, حوں_, _dpdv_,
  { {0x9ed9008b, 0x6e211818, 0x63ad0058, 0x00000000}},  //   _шмат_, _tolb, iban,
  { {0x4a451662, 0x44c1010a, 0x63ad00ef, 0x00000000}},  //   рнов, kė_, hban,
  { {0x7c2208b2, 0x8e840054, 0x63ad011c, 0x00000000}},  //   _foor, _الله, kban,
  { {0x6f09037e, 0x7bc70006, 0x7c2200d9, 0x00000000}},  //   _krec, ėjus, _goor,
  { {0x44220387, 0x63ad093b, 0xf7720070, 0x00000000}},  //   _rok_, dban, تاد_,
  { {0x44220047, 0xbb3a009b, 0x27e9002d, 0x00000000}},  //   _sok_, _בעני, _eban_,
  { {0x628e012b, 0x89da009b, 0x44c10006, 0x00000000}},  //   _ribo, _יחסי, gė_,
  { {0x63ad011c, 0x628e04be, 0x6f092100, 0x00000000}},  //   gban, _sibo, _orec,
  { {0x9676008b, 0x6aa40189, 0x628e2d87, 0x00000000}},  // [8900] _выні, _çift, _pibo,
  { {0x44220bd6, 0x1546012b, 0x63ad0058, 0x00000000}},  //   _wok_, _веом, aban,
  { {0x628e2d88, 0x63ad2c13, 0xe0da21aa, 0x00000000}},  //   _vibo, bban, тве_,
  { {0x6f090016, 0x35dc0164, 0x628e2d1a, 0x00000000}},  //   _brec, _बाड़, _wibo,
  { {0x6f090b76, 0xe7e80061, 0x2bdc0061, 0x00000000}},  //   _crec, ट्या_, _याबा,
  { {0x7c221787, 0x6f092d89, 0x7d000010, 0x00000000}},  //   _soor, _drec, járá,
  { {0x7c2202c2, 0x2ce80123, 0x787d0010, 0x00000000}},  //   _poor, اظتی_, léve,
  { {0x6f091632, 0x64560047, 0x69d80061, 0x00000000}},  //   _frec, nnyi, _माही,
  { {0x7c22049b, 0x6f090375, 0xadba0025, 0x00000000}},  //   _voor, _grec, _لهذا_,
  { {0x7c220100, 0xbae3008b, 0x5a34017a, 0x00000000}},  //   _woor, іцый, снот,
  { {0xa3d703d7, 0x78760428, 0x4ac201f5, 0x00000000}},  //   _साल_, rávn, _शिकव,
  { {0x44c1010a, 0x3e7b00f4, 0x7a2d1a13, 0x00000000}},  //   vė_, rête_, _lúth,
  { {0x787d0010, 0x00000000, 0x00000000, 0x00000000}},  //   jéve,   ,   ,
  { {0x44c1010a, 0xa3e4007d, 0xdb0b0190, 0x00000000}},  //   tė_, प्स_, _begæ,
  { {0x63ad1766, 0x3a7b0049, 0xd49804dd, 0x00000000}},  //   tban, _שטוד, ирт_,
  { {0xe3b301fa, 0x44c10006, 0x64560010, 0x00000000}},  //   ترس_, rė_, gnyi,
  { {0x44c10006, 0x63ad0971, 0x925900ed, 0x00000000}},  // [8910] sė_, rban, гаат_,
  { {0xe7e80754, 0x44c1010a, 0x63ad2d8a, 0x00000000}},  //   ट्ठा_, pė_, sban,
  { {0x6f0912d6, 0x2614007d, 0x63ad0af1, 0x00000000}},  //   _srec, दारी_, pban,
  { {0xe3b8007c, 0x78520089, 0x7d000010, 0x00000000}},  //   _ключ_, tāvi, zárá,
  { {0x6da5013b, 0x59c60061, 0x644d1703, 0x00000000}},  //   била, लणार, miai,
  { {0x644d1218, 0x14b800e9, 0x6f090142, 0x00000000}},  //   liai, _حدیث_, _vrec,
  { {0x6f090016, 0x30a4025f, 0x628511f0, 0x00000000}},  //   _wrec, _мртв, mmho,
  { {0x6f09000d, 0x644d1b73, 0x26c410fa, 0x00000000}},  //   _trec, niai, ámok_,
  { {0x6f09001a, 0x7a240173, 0x00000000, 0x00000000}},  //   _urec, _pòtp,   ,
  { {0xe8f90726, 0x6ce701fb, 0x644d095f, 0x00000000}},  //   гло_, _віде, hiai,
  { {0xa3d7007d, 0x644d0ecb, 0x999e0006, 0x00000000}},  //   सला_, kiai, entų_,
  { {0x9b950054, 0x6aa90190, 0x00000000, 0x00000000}},  //   _الإت, ppef,   ,
  { {0xbb850054, 0x7c3b2d8b, 0x644d0016, 0x00000000}},  //   _الشي, mhur, diai,
  { {0x7c3b0023, 0x00000000, 0x00000000, 0x00000000}},  //   lhur,   ,   ,
  { {0x2ba600b9, 0xe64306bb, 0x644d0f75, 0x00000000}},  //   síců_, черп, fiai,
  { {0x7c3b179a, 0x644d009d, 0x62851a33, 0x00000000}},  //   nhur, giai, emho,
  { {0xd3b9008b, 0x130a007e, 0x6456121b, 0x00000000}},  // [8920] русі_, ынай_, rnyi,
  { {0x26c20059, 0x787d2d8c, 0xf772009e, 0x00000000}},  //   msko_, réve, _واک_,
  { {0x787d0010, 0xd7be0061, 0x3076142c, 0x00000000}},  //   séve, _्याच, будс,
  { {0x644d1160, 0x26c2012d, 0xdb00000c, 0x00000000}},  //   ciai, osko_, mamö,
  { {0x26c20cce, 0x2f180b21, 0x7c3b1ac5, 0x00000000}},  //   nsko_, роль_, dhur,
  { {0x442001cd, 0x4432004f, 0x5096012b, 0x00000000}},  //   lji_, lky_, _грађ,
  { {0x44200006, 0x44320471, 0x1619013d, 0x00000000}},  //   oji_, oky_, दातर_,
  { {0x44320428, 0x389700e5, 0x00000000, 0x00000000}},  //   nky_, _gări_,   ,
  { {0x26c20059, 0x9b580aed, 0x442000d0, 0x00000000}},  //   jsko_, рипт_, iji_,
  { {0x26c20213, 0x00000000, 0x00000000, 0x00000000}},  //   dsko_,   ,   ,
  { {0x290a0181, 0x764e2d8d, 0x44321db2, 0x00000000}},  //   íba_, diby, kky_,
  { {0x44200066, 0x26c21531, 0xdb0b0039, 0x00000000}},  //   jji_, fsko_, _begä,
  { {0x44202480, 0x4432004f, 0x7c650025, 0x00000000}},  //   dji_, dky_, _بالل,
  { {0x44200006, 0x9aa40014, 0x68fc0030, 0x00000000}},  //   eji_, _همچو, ærds,
  { {0x644d1678, 0x59dd006e, 0x44201b12, 0x00000000}},  //   tiai, _मातर, fji_,
  { {0x44202d8e, 0xb4e903d7, 0x69da01a2, 0x00000000}},  //   gji_, _यही_, lgte,
  { {0xe3bf008e, 0x91b9005e, 0x7e6a01d6, 0x00000000}},  // [8930] _coña_, игат_, kofp,
  { {0x4420000b, 0x69da1e7d, 0x644d0006, 0x00000000}},  //   aji_, ngte, siai,
  { {0xdce800b9, 0x44200066, 0x44320161, 0x00000000}},  //   _vzdě, bji_, bky_,
  { {0x44200df0, 0x44320428, 0x2e2b0190, 0x00000000}},  //   cji_, cky_, _løft_,
  { {0x4439028c, 0x9f050025, 0x09d00044, 0x00000000}},  //   _ils_, توشو, ়্যা,
  { {0x443902c2, 0x81e70044, 0x00000000, 0x00000000}},  //   _hls_, _মোর_,   ,
  { {0xfe700558, 0x7c3b21ae, 0xac390088, 0x00000000}},  //   رده_, thur, ичих_,
  { {0x3cfe2c26, 0x5ac9003b, 0x443926fa, 0x00000000}},  //   _dstv_, алим_, _jls_,
  { {0x44392d8f, 0x7c3b00bb, 0x7c43016c, 0x00000000}},  //   _mls_, rhur, _ćurč,
  { {0x7c3b008d, 0x44202d90, 0x44320d86, 0x00000000}},  //   shur, zji_, zky_,
  { {0x35d303d7, 0x9d550b03, 0x44392d91, 0x00000000}},  //   _ताज़, _بنات, _ols_,
  { {0x186a0920, 0x26c20209, 0x44390c0d, 0x00000000}},  //   рами_, tsko_, _nls_,
  { {0x44320428, 0x28c50309, 0x442006a3, 0x00000000}},  //   vky_, _विकि, vji_,
  { {0x44392d92, 0x80ca0044, 0x442000e7, 0x00000000}},  //   _als_, _রহস্, wji_,
  { {0x443206b8, 0x44200087, 0x764e01aa, 0x00000000}},  //   tky_, tji_, riby,
  { {0x26c2016c, 0x44390035, 0xd5dc013d, 0x00000000}},  //   psko_, _cls_, _बावज,
  { {0x42260265, 0x44202d93, 0x44320428, 0x00000000}},  // [8940] одав, rji_, rky_,
  { {0x4439120d, 0x44320428, 0x6aa4002a, 0x00000000}},  //   _els_, sky_, _éife,
  { {0x10a60797, 0x44200891, 0x443900c4, 0x00000000}},  //   циен, pji_, _fls_,
  { {0x23e10164, 0xa2a2013d, 0x443900c4, 0x00000000}},  //   _फायद, _कंप्, _gls_,
  { {0x69da0030, 0x7e6a2d94, 0xa25b0142, 0x00000000}},  //   ygte, tofp, _kvôl,
  { {0x63a41e8f, 0x00000000, 0x00000000, 0x00000000}},  //   lcin,   ,   ,
  { {0x672f0046, 0x61ee0066, 0xd7db0061, 0x00000000}},  //   zycj, _ibbl, _भालच,
  { {0x63a40127, 0x7a2d2d95, 0x7e6a0009, 0x00000000}},  //   ncin, _mútu, sofp,
  { {0x63a42d96, 0x6a7400f6, 0x00000000, 0x00000000}},  //   icin, làfi,   ,
  { {0x200402c1, 0x20060032, 0x298a02e9, 0x00000000}},  //   _hami_, ldoi_, исно_,
  { {0x200424a9, 0xc27b01ce, 0x63a40ff9, 0x00000000}},  //   _kami_, שריי, kcin,
  { {0x20062d97, 0x8b6a007c, 0x20042d98, 0x00000000}},  //   ndoi_, _киев_, _jami_,
  { {0x61ee0282, 0x7c6506dd, 0x4439013f, 0x00000000}},  //   _obbl, _عامل, _rls_,
  { {0x7bc00504, 0x443900ca, 0x63a40089, 0x00000000}},  //   lamu, _sls_, ecin,
  { {0x6e280190, 0x65942d99, 0x344b2d9a, 0x00000000}},  //   _modb, дару, ачан_,
  { {0x320d01f6, 0x7bc00020, 0x2aa001aa, 0x00000000}},  //   _şey_, namu, _kòb_,
  { {0xa3dc001c, 0x4439000a, 0x2aa00173, 0x00000000}},  // [8950] _ठार_, _vls_, _jòb_,
  { {0x26d90058, 0x63a4185c, 0xdb19000a, 0x00000000}},  //   muso_, acin, _dewè,
  { {0x31c4165b, 0x7bc0036b, 0x26d90207, 0x00000000}},  //   ьств, kamu, luso_,
  { {0x63a40207, 0x7bc0007f, 0xa29501e1, 0x00000000}},  //   ccin, jamu, _намі,
  { {0x81e70055, 0xdefb0057, 0x63bd001e, 0x00000000}},  //   _মোঃ_, рые_, _iesn,
  { {0x9e3401e1, 0x32030022, 0x24890792, 0x00000000}},  //   мечч, _uajy_, lmam_,
  { {0x66052d9b, 0x20040173, 0x629d013e, 0x00000000}},  //   _mahk, _fami_, _huso,
  { {0x660517fd, 0x629d2d9c, 0x69ca0016, 0x00000000}},  //   _lahk, _kuso, _adfe,
  { {0x768b0046, 0x6e280018, 0x3da70401, 0x00000000}},  //   _używ, _fodb, _дреб,
  { {0x63bd01ca, 0x3945004c, 0x2bab006e, 0x00000000}},  //   _lesn, зног, _ट्रा,
  { {0x60c50065, 0x629d2d9d, 0x62950023, 0x00000000}},  //   nshm, _luso, _mizo,
  { {0x26d92d9e, 0x7bc000e7, 0xdb0b0010, 0x00000000}},  //   fuso_, camu, _megú,
  { {0x660504fa, 0x8b9a009b, 0x63a4145e, 0x00000000}},  //   _bahk, _הבנת, vcin,
  { {0x8b050046, 0x60c50065, 0x62952d9f, 0x00000000}},  //   _częś, kshm, _nizo,
  { {0x69c119da, 0x60c50065, 0x63bd23c6, 0x00000000}},  //   male, jshm, _besn,
  { {0x69c12da0, 0x26d90e20, 0x63bd0142, 0x00000000}},  //   lale, buso_, _cesn,
  { {0x63a42da1, 0x62950047, 0xe3630920, 0x00000000}},  // [8960] rcin, _bizo, екти,
  { {0x69c1206d, 0x200407ac, 0x7bc00009, 0x00000000}},  //   nale, _sami_, zamu,
  { {0x200401aa, 0x62952220, 0x659b00a3, 0x00000000}},  //   _pami_, _dizo, _לייק,
  { {0x38a1002a, 0x69c100b5, 0x6e282da2, 0x00000000}},  //   _mór_, hale, _sodb,
  { {0x7bc00004, 0x629d1dc0, 0x6295012d, 0x00000000}},  //   vamu, _guso, _fizo,
  { {0x78a1001c, 0x69c10059, 0x6295022b, 0x00000000}},  //   kqlv, jale, _gizo,
  { {0x69c12da3, 0x2ee60168, 0x6026026b, 0x00000000}},  //   dale, stof_, _едва,
  { {0xf8c50164, 0x62952da4, 0x2c7a0065, 0x00000000}},  //   _विजय, _zizo, rëdo_,
  { {0x69c1004e, 0x7bc004f8, 0x79980009, 0x00000000}},  //   fale, ramu, _pgvw,
  { {0x7f3b009b, 0x7bc0025c, 0xfaef0025, 0x00000000}},  //   _העמו, samu, اثي_,
  { {0x7bc00058, 0xa3dc01f5, 0x38a10048, 0x00000000}},  //   pamu, ठला_, _cór_,
  { {0x7d7b007b, 0x315701ce, 0x66050145, 0x00000000}},  //   _פראג, ליין_, _sahk,
  { {0x69c1002d, 0x63bd01d9, 0x60c50023, 0x00000000}},  //   bale, _resn, zshm,
  { {0x69c11ff4, 0x38a1009f, 0x26d90419, 0x00000000}},  //   cale, _fór_, ruso_,
  { {0x62951c5d, 0x1957007e, 0x26d90058, 0x00000000}},  //   _rizo, _нашы_, suso_,
  { {0x26d92da5, 0x629d2da6, 0xab5d0036, 0x00000000}},  //   puso_, _puso, saże,
  { {0x63bd091e, 0xdb0b0219, 0x24890181, 0x00000000}},  // [8970] _vesn, _segú, rmam_,
  { {0x60c5008d, 0x63bd2da7, 0x175800b3, 0x00000000}},  //   tshm, _wesn, _מסחר_,
  { {0x787d009d, 0x63bd264e, 0x6295007f, 0x00000000}},  //   névo, _tesn, _vizo,
  { {0x69c1022b, 0x60c5008d, 0x629d015e, 0x00000000}},  //   zale, rshm, _tuso,
  { {0x442b00d4, 0x60c50065, 0x62952da8, 0x00000000}},  //   _ioc_, sshm, _tizo,
  { {0x69d8001c, 0x442b0011, 0x78760161, 0x00000000}},  //   _मागी, _hoc_, rávi,
  { {0x69c129f9, 0xc21200b6, 0x60c50023, 0x00000000}},  //   vale, _בהם_, qshm,
  { {0x442b1825, 0x69c12da9, 0x2cac0082, 0x00000000}},  //   _joc_, wale, _dtdd_,
  { {0x442b0826, 0x3e72009d, 0xe821007d, 0x00000000}},  //   _moc_, gâts_, याना_,
  { {0x442b000d, 0x38a1049a, 0x3da70098, 0x00000000}},  //   _loc_, _pór_, _храб,
  { {0x69c10219, 0xa3cd0164, 0xda1f001c, 0x00000000}},  //   rale, रणा_, बाबत_,
  { {0x69c1000c, 0x442b2daa, 0x6d5f006b, 0x00000000}},  //   sale, _noc_, şqas,
  { {0x5747007e, 0x7c2b00f6, 0x01d50044, 0x00000000}},  //   дзям_, _iogr, স্যদ,
  { {0x7ae9016a, 0xf1ba0011, 0x7a3f009d, 0x00000000}},  //   mtet, ươi_, _bête,
  { {0x7ae902bb, 0x6a7d04bd, 0x442b001a, 0x00000000}},  //   ltet, lèfo, _boc_,
  { {0x9983010a, 0x3ead2dab, 0x26c42c3e, 0x00000000}},  //   ųjų_, _otet_, ámos_,
  { {0x7ae90047, 0x7c2b194d, 0xa2d5013d, 0x00000000}},  // [8980] ntet, _mogr, यंग्,
  { {0x7c2b0211, 0x7ae9021e, 0x7a3f00f4, 0x00000000}},  //   _logr, itet, _fête,
  { {0x361b061e, 0x7ae92dac, 0x442b05f7, 0x00000000}},  //   _וויד, htet, _foc_,
  { {0xdfcf0025, 0x7ae92d0f, 0x7c2b0089, 0x00000000}},  //   ليم_, ktet, _nogr,
  { {0x7ae90047, 0xbea301fc, 0xbefa004b, 0x00000000}},  //   jtet, вачк, تراض_,
  { {0x768b0046, 0x0caa0fd8, 0x7ae90010, 0x00000000}},  //   _użyt, отии_, dtet,
  { {0xa3e5062e, 0xe297003b, 0x624b0036, 0x00000000}},  //   _नाम_, _цар_, eżow,
  { {0x09c60061, 0x7ae90efd, 0x442b00d4, 0x00000000}},  //   लण्य, ftet, _xoc_,
  { {0xae1e0164, 0x7c2b014a, 0x7ae90010, 0x00000000}},  //   पादन_, _dogr, gtet,
  { {0x1e8309ae, 0x7c2b012d, 0x00000000, 0x00000000}},  //   _алум, _eogr,   ,
  { {0x7ae9027a, 0x00000000, 0x00000000, 0x00000000}},  //   atet,   ,   ,
  { {0x7c2b059f, 0x00000000, 0x00000000, 0x00000000}},  //   _gogr,   ,   ,
  { {0x5b3601f7, 0x442b2dad, 0x7ae9005b, 0x00000000}},  //   _تعار, _roc_, ctet,
  { {0x442b027b, 0x6b820059, 0x00000000, 0x00000000}},  //   _soc_, _izog,   ,
  { {0x442b04bd, 0xfa9708cd, 0x644f0133, 0x00000000}},  //   _poc_, _קדוש_, _pmci,
  { {0x7a3f00f4, 0xb7e60309, 0x443d0036, 0x00000000}},  //   _vête, _कायम_, ów_,
  { {0x521503e0, 0x7d1c01e5, 0x00000000, 0x00000000}},  // [8990] ндат, _ársf,   ,
  { {0x442b27f1, 0x7a3f009d, 0x51f80641, 0x00000000}},  //   _woc_, _tête, мную_,
  { {0x7ae914a9, 0xb06b02dc, 0xe7e60204, 0x00000000}},  //   ztet, ордж_, _कामा_,
  { {0x7ae92dae, 0x442b2daf, 0x64480129, 0x00000000}},  //   ytet, _uoc_, èdit,
  { {0x26140061, 0x6b820045, 0x22410022, 0x00000000}},  //   दाची_, _nzog, phhk_,
  { {0x7c2b0ddb, 0xa3cd006e, 0x00000000, 0x00000000}},  //   _sogr, रणव_,   ,
  { {0x7c2b0119, 0xdfd5007c, 0xba3d00b9, 0x00000000}},  //   _pogr, _повы, způs,
  { {0x9b05081e, 0x7ae9006c, 0xfd650011, 0x00000000}},  //   езид, ttet, _khuẩ,
  { {0x3ead0026, 0xed580027, 0x7ae900b0, 0x00000000}},  //   _utet_, _veľa_, utet,
  { {0x7ae9008d, 0xe29f000c, 0x6b82016c, 0x00000000}},  //   rtet, _urðu_, _dzog,
  { {0x7ae9021e, 0x61e1009f, 0x7c2b0051, 0x00000000}},  //   stet, _öllu, _togr,
  { {0x39580051, 0x24990059, 0x7ae92db0, 0x00000000}},  //   úrsa_, _nism_, ptet,
  { {0xab5d002b, 0x00000000, 0x00000000, 0x00000000}},  //   baża,   ,   ,
  { {0xceb2019b, 0x24990026, 0x00000000, 0x00000000}},  //   רים_, _aism_,   ,
  { {0xa8060676, 0x00000000, 0x00000000, 0x00000000}},  //   _alış,   ,   ,
  { {0x52aa005e, 0x35dc013d, 0x00000000, 0x00000000}},  //   звам_, _बाक़,   ,
  { {0x969602b8, 0xfd65001d, 0xa69607d8, 0x00000000}},  // [89a0] _прош, _chuẩ, _прој,
  { {0x61460081, 0x00000000, 0x00000000, 0x00000000}},  //   неза,   ,   ,
  { {0x78ab001a, 0x261d006e, 0xc69301ce, 0x00000000}},  //   _învă, मारी_, _גאז_,
  { {0xe29a1026, 0x41e2001c, 0xdfd2007a, 0x00000000}},  //   _нам_, _पावस, ايش_,
  { {0xe29a06e3, 0x11d60088, 0x06650014, 0x00000000}},  //   _хаг_, _півр, _سایپ,
  { {0x64562db1, 0x09d50044, 0x20e00061, 0x00000000}},  //   liyi, ত্তা, खंदळ_,
  { {0x6263003b, 0x00000000, 0x00000000, 0x00000000}},  //   _свра,   ,   ,
  { {0x61fe014a, 0xcd03007c, 0xab5d00b4, 0x00000000}},  //   lepl, учши, waża,
  { {0x81e70055, 0xeaaf0014, 0xda7a007e, 0x00000000}},  //   _মোট_, یعی_, зян_,
  { {0xc33300b6, 0x5a3400e3, 0x61fe2db2, 0x00000000}},  //   טוח_, тнот, nepl,
  { {0x765504cd, 0xab5d0036, 0x6fa40061, 0x00000000}},  //   vizy, raża, _ओलां,
  { {0xfaa60072, 0x9cd701f8, 0x415b0049, 0x00000000}},  //   _задо, _טובה_, לדיג,
  { {0x6456005f, 0xe66700ed, 0x61fe00ea, 0x00000000}},  //   diyi, етво, kepl,
  { {0x320a0007, 0x7b060089, 0x61fe016e, 0x00000000}},  //   _naby_, ērtī, jepl,
  { {0x5fd0001c, 0xe82103d7, 0x61fe001a, 0x00000000}},  //   हणाल, यादा_, depl,
  { {0x765501aa, 0x897b009b, 0x64440035, 0x00000000}},  //   sizy, _מרוצ, ghii,
  { {0xc2990500, 0x3a2e00f6, 0x2fc600e0, 0x00000000}},  // [89b0] дках_, _kofp_, daog_,
  { {0x61fe0030, 0x7a3600f4, 0x64670161, 0x00000000}},  //   gepl, _bâti, _špič,
  { {0x659502a8, 0x7a3600e5, 0x249900d9, 0x00000000}},  //   _јану, _câti, _tism_,
  { {0x644400e5, 0x26cb08d3, 0x00000000, 0x00000000}},  //   chii, osco_,   ,
  { {0x61fe014a, 0x26cb0544, 0x00000000, 0x00000000}},  //   bepl, nsco_,   ,
  { {0xee380099, 0x61fe01ee, 0x20090964, 0x00000000}},  //   нні_, cepl, žai_,
  { {0x44291b1b, 0x25e9007d, 0x78ad2479, 0x00000000}},  //   oja_, _जानी_, _čavo,
  { {0x44290213, 0xeb990e1b, 0x09d90061, 0x00000000}},  //   nja_, мий_, ढल्य,
  { {0xe7db02fb, 0x44290052, 0x00000000, 0x00000000}},  //   _भाजप, ija_,   ,
  { {0x442908c0, 0xc3340104, 0x999e007f, 0x00000000}},  //   hja_, רוץ_, ditų_,
  { {0x4429009f, 0x186a064b, 0x00000000, 0x00000000}},  //   kja_, дани_,   ,
  { {0x442901d5, 0x2d85011f, 0x7bc200d9, 0x00000000}},  //   jja_, _izle_, _geou,
  { {0xf0920476, 0x7c290209, 0x3f9f0020, 0x00000000}},  //   ינט_, mjer, _mguu_,
  { {0x7c2901bf, 0x442909a4, 0x7c3b002d, 0x00000000}},  //   ljer, eja_, lkur,
  { {0x44292db3, 0x61fe0190, 0x26cb0197, 0x00000000}},  //   fja_, vepl, asco_,
  { {0x4429009f, 0x69c32db4, 0x290700f6, 0x00000000}},  //   gja_, _hene, _isna_,
  { {0x69c300b0, 0x61fe0387, 0x64442db5, 0x00000000}},  // [89c0] _kene, tepl, rhii,
  { {0x69c30263, 0x44290110, 0x8c3c006b, 0x00000000}},  //   _jene, aja_, _muğa,
  { {0x69c3020c, 0x7c3b009f, 0x44292db6, 0x00000000}},  //   _mene, kkur, bja_,
  { {0x44290df0, 0x69c300b5, 0x61fe0287, 0x00000000}},  //   cja_, _lene, sepl,
  { {0xab5d0036, 0x7c290496, 0x7bc20173, 0x00000000}},  //   ważn, djer, _reou,
  { {0x60de00f8, 0x7c290190, 0x6f0201a2, 0x00000000}},  //   pupm, ejer, rwoc,
  { {0x7176023c, 0x7c2908e0, 0x7bc2000a, 0x00000000}},  //   _شهرا, fjer, _peou,
  { {0xdb0b02d5, 0x06b80055, 0x629c0020, 0x00000000}},  //   _negó, _জিনি, _hiro,
  { {0x629c022b, 0x3f840107, 0xbea60265, 0x00000000}},  //   _kiro, _uzmu_, _разк,
  { {0x69c3018e, 0x44292db7, 0x6569014a, 0x00000000}},  //   _cene, zja_, şehi,
  { {0x69c32db8, 0x787d00f4, 0x7c290030, 0x00000000}},  //   _dene, lévi, bjer,
  { {0xc17300b6, 0x7c3b2a23, 0x4429002b, 0x00000000}},  //   יחת_, ckur, xja_,
  { {0x69c3011f, 0x442921ce, 0xada2000c, 0x00000000}},  //   _fene, vja_, _þúsu,
  { {0x629c03d2, 0x44290066, 0xcf93009b, 0x00000000}},  //   _niro, wja_, יטר_,
  { {0x69c82db9, 0x7ae00065, 0x64480089, 0x00000000}},  //   made, lumt, īdin,
  { {0x04b8026c, 0x69c314a9, 0x44290964, 0x00000000}},  //   کھیں_, _zene, uja_,
  { {0x629c09e3, 0x69c3014a, 0x615500a1, 0x00000000}},  // [89d0] _biro, _yene, گنائ,
  { {0x69c802e1, 0xa3e5024c, 0x442907f2, 0x00000000}},  //   nade, _नाव_, sja_,
  { {0x44290047, 0xdb0b04bd, 0x645a0129, 0x00000000}},  //   pja_, _segü, ètic,
  { {0x629c001e, 0x4429008d, 0x69c805c6, 0x00000000}},  //   _eiro, qja_, hade,
  { {0x7c290182, 0x63ad2200, 0xeabd0044, 0x00000000}},  //   vjer, mcan, _আম্ম,
  { {0x629c04bd, 0x69c82db9, 0x3ea40d2b, 0x00000000}},  //   _giro, jade, _dumt_,
  { {0x69c8217e, 0x7c29016e, 0x7c3b0052, 0x00000000}},  //   dade, tjer, tkur,
  { {0x63ad020c, 0x69c3068f, 0x629c01ee, 0x00000000}},  //   ncan, _sene, _ziro,
  { {0x69c30149, 0x7c290a5c, 0x69c8074e, 0x00000000}},  //   _pene, rjer, fade,
  { {0x69c82dba, 0x6f090645, 0x7c290056, 0x00000000}},  //   gade, _isec, sjer,
  { {0x69c3225f, 0x2bdc0963, 0x00000000, 0x00000000}},  //   _vene, _याचा,   ,
  { {0xb8cb013d, 0x69c3026e, 0x00000000, 0x00000000}},  //   _कं_, _wene,   ,
  { {0x69c3206d, 0x69c80a53, 0x63ad00f8, 0x00000000}},  //   _tene, bade, dcan,
  { {0x69c8282d, 0x69c300e7, 0x2ca52dbb, 0x00000000}},  //   cade, _uene, _kuld_,
  { {0x1543013b, 0x7a3600e5, 0x00000000, 0x00000000}},  //   берм, _câtu,   ,
  { {0x6f0901a8, 0x629c0091, 0xb97a00a0, 0x00000000}},  //   _osec, _siro, _אנצי,
  { {0x629c0010, 0xe821013d, 0x00000000, 0x00000000}},  // [89e0] _piro, यारा_,   ,
  { {0x09d50044, 0x63ad004a, 0x2ca50068, 0x00000000}},  //   ত্রা, acan, _ould_,
  { {0x25e903d7, 0x629c016e, 0xa4940014, 0x00000000}},  //   _जाती_, _viro, _نیست,
  { {0x63ad0207, 0x69c80059, 0x61e50051, 0x00000000}},  //   ccan, zade, aghl,
  { {0x68e10270, 0x24800058, 0x69c813d6, 0x00000000}},  //   huld, mlim_, yade,
  { {0x2480008d, 0x69c80129, 0xd25200a2, 0x00000000}},  //   llim_, xade, _طنز_,
  { {0x69c80004, 0x6f090207, 0x61460088, 0x00000000}},  //   vade, _esec, _сева,
  { {0x68e1037f, 0x69c80222, 0x504301ab, 0x00000000}},  //   duld, wade, _лесб,
  { {0x69c801b9, 0x38a800f4, 0x4f6600a1, 0x00000000}},  //   tade, _sûr_, _صارف,
  { {0x7ae01422, 0x2ca50030, 0x68e10030, 0x00000000}},  //   rumt, _fuld_, fuld,
  { {0x63ad0163, 0xe821001c, 0x6e930054, 0x00000000}},  //   ycan, याला_, _اللا,
  { {0x69c80142, 0x63ad219f, 0x00000000, 0x00000000}},  //   sade, xcan,   ,
  { {0x63ad057c, 0xd90e007a, 0x00000000, 0x00000000}},  //   vcan, زیک_,   ,
  { {0xdd200224, 0x1994008b, 0x7a360068, 0x00000000}},  //   _může, _каля, _pâtu,
  { {0x68e10181, 0x659500ed, 0x63ad00f8, 0x00000000}},  //   culd, раву, tcan,
  { {0x63ad008e, 0x00000000, 0x00000000, 0x00000000}},  //   ucan,   ,   ,
  { {0x325518bf, 0x28da013d, 0x00000000, 0x00000000}},  // [89f0] авар, _भिडि,   ,
  { {0x63ad0e1d, 0x00000000, 0x00000000, 0x00000000}},  //   scan,   ,   ,
  { {0x63ad00e5, 0xdfd10025, 0x61e51a13, 0x00000000}},  //   pcan, قيا_, rghl,
  { {0x6f0915bc, 0x3f15003b, 0x776d0066, 0x00000000}},  //   _psec, идес, _kxax,
  { {0x260a001c, 0x7e7a01cf, 0xddc50088, 0x00000000}},  //   ायची_, _bktp, абли,
  { {0xed591deb, 0x6a7d01aa, 0xfaff0023, 0x00000000}},  //   кол_, pèfi, çëm_,
  { {0x5184007e, 0xe7e6013d, 0x9d450900, 0x00000000}},  //   _гута, _काला_, рейд,
  { {0x201f000d, 0x3ff90049, 0x68e100b5, 0x00000000}},  //   _unui_, _שפּע, vuld,
  { {0x6f092dbc, 0x7e680009, 0x00000000, 0x00000000}},  //   _usec, _fjdp,   ,
  { {0xf2d40049, 0x3869003f, 0x2480016c, 0x00000000}},  //   זעץ_, _ajar_, zlim_,
  { {0xa9690265, 0xd826189f, 0x8bd5023c, 0x00000000}},  //   тина_, адни, _نقاش,
  { {0xe73a0269, 0x68e12dbd, 0x657e01c3, 0x00000000}},  //   вем_, ruld, _ryph,
  { {0x81dd0044, 0x3869002b, 0x8c3c014a, 0x00000000}},  //   থ্য_, _djar_, _muğl,
  { {0xbb840025, 0xf67600e2, 0xf3ff00fa, 0x00000000}},  //   _الهي, румџ, _bjão_,
  { {0xf48400a6, 0x64480006, 0x00000000, 0x00000000}},  //   ماری, ūdim,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x645a00f4, 0x248000c4, 0xb8650439, 0x00000000}},  // [8a00] étiq, rlim_, _داوو,
  { {0x24800390, 0x98be0036, 0x422301bd, 0x00000000}},  //   slim_, sztą_, одув,
  { {0x4fc6008b, 0x765c0279, 0x248004eb, 0x00000000}},  //   асла, miry, plim_,
  { {0xf99200b3, 0xdfd00439, 0x351b009b, 0x00000000}},  //   קרא_, سيت_, _סוכנ,
  { {0x6446006b, 0x2d8101a2, 0x44220133, 0x00000000}},  //   _ilki, ühen_, _ink_,
  { {0x4422016e, 0x00000000, 0x00000000, 0x00000000}},  //   _hnk_,   ,   ,
  { {0xc117026c, 0xdce10006, 0xdb0b000c, 0x00000000}},  //   _پہنچ_, _mylė, _segð,
  { {0x10a309da, 0x26d200e7, 0x00000000, 0x00000000}},  //   _фитн, _ovyo_,   ,
  { {0xd5c60164, 0x4422016e, 0xab38007c, 0x00000000}},  //   वराज, _mnk_, уппу_,
  { {0x44220006, 0x5cf6007e, 0x00000000, 0x00000000}},  //   _lnk_, _вяду,   ,
  { {0x29182dbe, 0x64460052, 0x44222202, 0x00000000}},  //   íra_, _olki, _onk_,
  { {0xdb19010f, 0xdb0900d4, 0x00000000, 0x00000000}},  //   _bewä, cceï,   ,
  { {0x7c22002d, 0x95cb0893, 0x9a860256, 0x00000000}},  //   _inor, кува_, _кукл,
  { {0x64460093, 0xfd1100a1, 0xdbf80044, 0x00000000}},  //   _alki, _بجے_, _অফিস_,
  { {0x44220022, 0x7c2201a2, 0x00000000, 0x00000000}},  //   _bnk_, _knor,   ,
  { {0x38690169, 0x44220087, 0x71270bb6, 0x00000000}},  //   _ujar_, _cnk_, یرال,
  { {0xf1a7017a, 0xdb19010f, 0x49920cd9, 0x00000000}},  // [8a10] арен, _gewä, _دیگر,
  { {0x7d1a010f, 0x44220022, 0xe4e70088, 0x00000000}},  //   _orts, _enk_, _кімн,
  { {0x80f5007e, 0x00000000, 0x00000000, 0x00000000}},  //   спех,   ,   ,
  { {0x5f9515c4, 0x00000000, 0x00000000, 0x00000000}},  //   биет,   ,   ,
  { {0x7d1a00b5, 0x93fa00b6, 0xa2820014, 0x00000000}},  //   _arts, _גלרי, _کیلو,
  { {0xc332007b, 0x9f560010, 0x3cfe0085, 0x00000000}},  //   _צום_, ágát_, _bptv_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x44220082, 0x44d315c7, 0x765c2dbf, 0x00000000}},  //   _xnk_, ić_, ziry,
  { {0x3cfe00c4, 0x753c0036, 0x00000000, 0x00000000}},  //   _eptv_, zyrz,   ,
  { {0x4a4501fb, 0x79e7026c, 0x3e7b00f4, 0x00000000}},  //   снов, جودہ_, rêts_,
  { {0x4999007c, 0x00000000, 0x00000000, 0x00000000}},  //   ытия_,   ,   ,
  { {0x7c220442, 0x6f1b00b4, 0x321108d0, 0x00000000}},  //   _gnor, _kruc, _lazy_,
  { {0x683f0065, 0x44d30046, 0xac740025, 0x00000000}},  //   _mëdh, eć_, _بالش,
  { {0x7c22226d, 0x00000000, 0x00000000, 0x00000000}},  //   _znor,   ,   ,
  { {0x25e9062e, 0xc8b5007c, 0x44220022, 0x00000000}},  //   _जारी_, _услы, _pnk_,
  { {0x6f1b2dc0, 0x47c608d6, 0x765c18ef, 0x00000000}},  //   _oruc, _убив, siry,
  { {0x23272dc1, 0xe1fa00d7, 0x44d30036, 0x00000000}},  // [8a20] боти_, лга_, ać_,
  { {0x1757009b, 0x00000000, 0x00000000, 0x00000000}},  //   _לספר_,   ,   ,
  { {0x0ce208b7, 0xd179008b, 0xdfda005e, 0x00000000}},  //   _মন্ত, асці_, гъл_,
  { {0xdd2c0006, 0x44221591, 0x4ea602ea, 0x00000000}},  //   _nėšt, _unk_, брка,
  { {0x6f1b1632, 0x21d801ef, 0x261d0061, 0x00000000}},  //   _cruc, _نژاد_, माची_,
  { {0x7c22000c, 0x6f1b001f, 0x7d1a00d9, 0x00000000}},  //   _snor, _druc, _prts,
  { {0xd13205d4, 0xa7fb049a, 0x00000000, 0x00000000}},  //   _عمر_, liñe,   ,
  { {0xf0630594, 0x6f1b2c62, 0xf65f0190, 0x00000000}},  //   _експ, _fruc, lsæt_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd90e01ef, 0xd8f80088, 0x09c80044, 0x00000000}},  //   فیت_, аної_, _শাহা,
  { {0x5d860054, 0x28f80088, 0xe895007e, 0x00000000}},  //   _الال, шень_, жань,
  { {0x7c220035, 0x96eb0c18, 0xc19b0049, 0x00000000}},  //   _unor, льга_, טשיי,
  { {0x21270011, 0x3c38009d, 0x6c7b0049, 0x00000000}},  //   ̣nh_, _févr_, _גראד,
  { {0x27ed002b, 0x00000000, 0x00000000, 0x00000000}},  //   żen_,   ,   ,
  { {0x321116bd, 0x00000000, 0x00000000, 0x00000000}},  //   _razy_,   ,   ,
  { {0x69ca1855, 0x00000000, 0x00000000, 0x00000000}},  //   _hefe,   ,   ,
  { {0xf7f40014, 0x69ca0276, 0x6b820022, 0x00000000}},  // [8a30] _رسيد, _kefe, _jyog,
  { {0x69ca00dc, 0x00000000, 0x00000000, 0x00000000}},  //   _jefe,   ,   ,
  { {0x31c4007e, 0x6f1b012d, 0xa28300a1, 0x00000000}},  //   яств, _sruc, _ہیرو,
  { {0x69ca2dc2, 0x61ee0009, 0x753a010f, 0x00000000}},  //   _lefe, _ecbl, ätze,
  { {0x644d0195, 0x69ca01b5, 0x171c0049, 0x00000000}},  //   mhai, _oefe, ָווע,
  { {0x6f1b2dc3, 0x30a70088, 0x69ca014a, 0x00000000}},  //   _vruc, _грав, _nefe,
  { {0x6b820009, 0xc2120104, 0xd1b800a1, 0x00000000}},  //   _ayog, _קהל_, _چاہا_,
  { {0x628501d5, 0x69d805d0, 0x644d00c4, 0x00000000}},  //   llho, _adve, nhai,
  { {0x69ca138a, 0x6f1b0036, 0x628507a5, 0x00000000}},  //   _befe, _uruc, olho,
  { {0xe8f9012b, 0x69ca00c4, 0x6b820058, 0x00000000}},  //   ало_, _cefe, _dyog,
  { {0x644d011c, 0x24610006, 0x61fa0010, 0x00000000}},  //   khai, nėms_, _ötle,
  { {0xc85a0088, 0x291c10f7, 0x00000000, 0x00000000}},  //   ршої_, _drva_,   ,
  { {0x644d0051, 0x7bcb001e, 0x291c07c2, 0x00000000}},  //   dhai, _iegu, _erva_,
  { {0x69ca05c6, 0xe7e60164, 0xceb20049, 0x00000000}},  //   _gefe, _काका_, ויך_,
  { {0x7bcb003f, 0x63a600e0, 0x644d2dc4, 0x00000000}},  //   _kegu, _pgkn, fhai,
  { {0x644d002a, 0xe3ba026b, 0x62852dc5, 0x00000000}},  //   ghai, рба_, elho,
  { {0x7bcb2050, 0x764b0006, 0x4dca0044, 0x00000000}},  // [8a40] _megu, _įgyv, _রাসূ,
  { {0x7bcb08a4, 0x69c12bbd, 0x6aa3002b, 0x00000000}},  //   _legu, nble, _jinf,
  { {0x644d0195, 0x6aa3002b, 0x69c103cb, 0x00000000}},  //   bhai, _minf, ible,
  { {0x644d2dc6, 0xef1a0072, 0x6aa30555, 0x00000000}},  //   chai, име_, _linf,
  { {0x63b40036, 0xda090309, 0x00000000, 0x00000000}},  //   ągną, _वसंत_,   ,
  { {0x6aa31aaa, 0x78a401c2, 0x217606f3, 0x00000000}},  //   _ninf, _liiv, _дубр,
  { {0x69ca2dc7, 0xe0d7026b, 0x69c10435, 0x00000000}},  //   _refe, _мвр_, dble,
  { {0x6aab0240, 0x644400b0, 0x69ca014a, 0x00000000}},  //   _bugf, nkii, _sefe,
  { {0x7bcb0129, 0x9e66013b, 0x69c10190, 0x00000000}},  //   _degu, _двад, fble,
  { {0x291c1a2d, 0xa954003b, 0x6aa300fa, 0x00000000}},  //   _prva_, звољ, _cinf,
  { {0x644400b0, 0x7bcb000c, 0x644d2dc8, 0x00000000}},  //   kkii, _fegu, yhai,
  { {0x6aa32dc9, 0x69ba02fb, 0xfbd200a1, 0x00000000}},  //   _einf, _श्री, _آتا_,
  { {0x69c10209, 0x6aa300f8, 0x645f0023, 0x00000000}},  //   bble, _finf, viqi,
  { {0x69d80030, 0x79830016, 0x7bcb10d2, 0x00000000}},  //   _udve, _fynw, _zegu,
  { {0x644d002a, 0x2cac27c2, 0x660702a9, 0x00000000}},  //   thai, _judd_, rejk,
  { {0xe019001c, 0x2cac2dca, 0x68e82dcb, 0x00000000}},  //   _नोंद_, _mudd_, mudd,
  { {0x644d00b0, 0x68e801a3, 0x44c80c4f, 0x00000000}},  // [8a50] rhai, ludd, aş_,
  { {0x65950216, 0x644d0020, 0x645f006b, 0x00000000}},  //   _напу, shai, siqi,
  { {0xdb09002a, 0x68e8033b, 0xceb900b9, 0x00000000}},  //   iceá, nudd, _stř_,
  { {0x26c90020, 0x224a0288, 0x00000000, 0x00000000}},  //   _kwao_, _elbk_,   ,
  { {0x7bcb2dcc, 0x2fcf0418, 0x645d2dcd, 0x00000000}},  //   _regu, ragg_, _imsi,
  { {0x7bcb1596, 0x443905fe, 0x2cac018e, 0x00000000}},  //   _segu, _hos_, _budd_,
  { {0x44391bb1, 0x7bcb01a3, 0x6aa30197, 0x00000000}},  //   _kos_, _pegu, _rinf,
  { {0x44392dce, 0xef93026c, 0xdfd10025, 0x00000000}},  //   _jos_, _قیاد, _سيئ_,
  { {0x44392dcf, 0xab651ac0, 0x7bcb1441, 0x00000000}},  //   _mos_, явил, _vegu,
  { {0x44391718, 0x7e55002c, 0x68e804be, 0x00000000}},  //   _los_, _عناص, fudd,
  { {0x7bcb17f6, 0x44390007, 0x69c12dd0, 0x00000000}},  //   _tegu, _oos_, rble,
  { {0x69c1010f, 0x186a041f, 0x00000000, 0x00000000}},  //   sble, сами_,   ,
  { {0x3ea52059, 0x78a4003c, 0x6aa3002b, 0x00000000}},  //   _kilt_, _viiv, _tinf,
  { {0x44391160, 0x2fcd2dd1, 0x68e80ee6, 0x00000000}},  //   _aos_, _leeg_, budd,
  { {0x7ae921be, 0x78a40103, 0x3ea500f8, 0x00000000}},  //   luet, _tiiv, _milt_,
  { {0x44390c1f, 0x44262dd2, 0x00000000, 0x00000000}},  //   _cos_, ño_,   ,
  { {0x44390fb3, 0xdcf40107, 0x7ae90032, 0x00000000}},  // [8a60] _dos_, _đačk, nuet,
  { {0x44390089, 0x7c390ca4, 0x644401b1, 0x00000000}},  //   _eos_, _lowr, skii,
  { {0xe821001c, 0xa7fb049a, 0x44392965, 0x00000000}},  //   याचा_, liña, _fos_,
  { {0x7c39001c, 0x3ea50051, 0x7ae9002d, 0x00000000}},  //   _nowr, _ailt_, kuet,
  { {0x9cf80055, 0xdfcf006d, 0x888d0049, 0x00000000}},  //   _আছেন_, ايه_, בראַ,
  { {0x3ead0007, 0x3ea5014a, 0xb146003b, 0x00000000}},  //   _duet_, _cilt_, _енгл,
  { {0xe7ed001c, 0x44390093, 0x7d780123, 0x00000000}},  //   _झाला_, _yos_, غمبر_,
  { {0xbab8007c, 0xaff600a1, 0x3ead00f6, 0x00000000}},  //   огих_, _رہتا_, _fuet_,
  { {0x7ae90211, 0xdee3003b, 0x09bd0044, 0x00000000}},  //   guet, _поти, _আয়া,
  { {0x68e8101b, 0x3ea503a1, 0xcf250025, 0x00000000}},  //   tudd, _gilt_, _ترفي,
  { {0x6e280018, 0xdb090051, 0x00000000, 0x00000000}},  //   _indb, rceá,   ,
  { {0x6e3a2c38, 0x68e80d8c, 0x7c39000a, 0x00000000}},  //   _hotb, rudd, _gowr,
  { {0xfaf70123, 0x6e3a002b, 0x68e80190, 0x00000000}},  //   _فروغ_, _kotb, sudd,
  { {0xc6a410e2, 0x7689009f, 0xdb9b009b, 0x00000000}},  //   ерси, mþyk, _הסדר,
  { {0x92e90055, 0x443901c3, 0x6fcc001c, 0x00000000}},  //   _মনে_, _pos_, ारां,
  { {0x765e0675, 0x6e3a0173, 0x00000000, 0x00000000}},  //   _empy, _lotb,   ,
  { {0x4439028c, 0xe3b01095, 0x00000000, 0x00000000}},  // [8a70] _vos_, ارف_,   ,
  { {0xe60300b0, 0x443900b4, 0x52d801ab, 0x00000000}},  //   ätää, _wos_, ямую_,
  { {0x44390dec, 0x7ae90032, 0x7d1c000c, 0x00000000}},  //   _tos_, zuet, _ársh,
  { {0xaadd013d, 0x3ea5010e, 0x6e28141a, 0x00000000}},  //   _मिलक, _silt_, _andb,
  { {0x3ea50004, 0x2fc0008e, 0x6e3a1307, 0x00000000}},  //   _pilt_, ñiga_, _botb,
  { {0x2d8501d6, 0x2fcd040f, 0xf7740049, 0x00000000}},  //   _pyle_, _weeg_, עקס_,
  { {0x7c390046, 0xc879005a, 0x3ea5000c, 0x00000000}},  //   _powr, luğu_, _vilt_,
  { {0x3ea502ae, 0x7ae9002d, 0xdb020b33, 0x00000000}},  //   _wilt_, tuet, _egoí,
  { {0x6e3a2dd3, 0x4add001c, 0x2ca60016, 0x00000000}},  //   _fotb, _मिळव, _diod_,
  { {0x39450264, 0x4ad7026c, 0x2d850036, 0x00000000}},  //   дног, _ہاتھ_, _tyle_,
  { {0x248901f6, 0x7e630146, 0x7ae9002d, 0x00000000}},  //   klam_, minp, suet,
  { {0x25c60164, 0x6d430006, 0x7e6300b0, 0x00000000}},  //   वर्ण, myna, linp,
  { {0x6d432dd4, 0xba55005e, 0x00000000, 0x00000000}},  //   lyna, _откъ,   ,
  { {0xc87901f6, 0xa7fb049a, 0xdb21004a, 0x00000000}},  //   duğu_, riña, _ñuño,
  { {0x6d430ff0, 0x00000000, 0x00000000, 0x00000000}},  //   nyna,   ,   ,
  { {0x78b30089, 0x7e631489, 0xd7ff0035, 0x00000000}},  //   ēgvā, hinp, şări_,
  { {0x64bc037e, 0xd5af026c, 0x6d430016, 0x00000000}},  // [8a80] _očig, افہ_, hyna,
  { {0x2489011c, 0x66170288, 0x63b600b4, 0x00000000}},  //   alam_, _gaxk, scyn,
  { {0x7e630943, 0x00000000, 0x00000000, 0x00000000}},  //   dinp,   ,   ,
  { {0x6d430006, 0xb7db0049, 0x24891d21, 0x00000000}},  //   dyna, ַקצי, clam_,
  { {0x6e3a01c3, 0xc879014a, 0x00000000, 0x00000000}},  //   _potb, cuğu_,   ,
  { {0xdcba0ae0, 0x7e63162d, 0x64670036, 0x00000000}},  //   ощи_, ginp, ąpił,
  { {0x0ee0001c, 0x00000000, 0x00000000, 0x00000000}},  //   _निवड,   ,   ,
  { {0x25de0061, 0x5b14026b, 0x32180022, 0x00000000}},  //   कृती_, емит, _hary_,
  { {0xc5e60055, 0x3f670545, 0x2fc6149e, 0x00000000}},  //   খ্যা_, _жито_, mbog_,
  { {0x3860008a, 0x6d4303cd, 0x2fc60058, 0x00000000}},  //   _amir_, byna, lbog_,
  { {0x321800ab, 0xc87f010f, 0x00000000, 0x00000000}},  //   _mary_, toß_,   ,
  { {0x7b66004d, 0x00000000, 0x00000000, 0x00000000}},  //   _отле,   ,   ,
  { {0xd78b0054, 0xdca3007c, 0x24890120, 0x00000000}},  //   تخدم_, _раци, vlam_,
  { {0x3eb90211, 0x38600095, 0x00000000, 0x00000000}},  //   _éste_, _emir_,   ,
  { {0x24890085, 0xb8860861, 0x00000000, 0x00000000}},  //   tlam_, _smíš,   ,
  { {0x24892dd5, 0x321800e5, 0x61fe01c3, 0x00000000}},  //   ulam_, _aary_, efpl,
  { {0x6d430036, 0x24890abb, 0x2fc60637, 0x00000000}},  // [8a90] zyna, rlam_, dbog_,
  { {0x24890020, 0x7a3f009d, 0x32180133, 0x00000000}},  //   slam_, _hêtr, _cary_,
  { {0xe3b0026c, 0x2489011f, 0x32182dd6, 0x00000000}},  //   ارہ_, plam_, _dary_,
  { {0x2fc62dd7, 0x61fe0116, 0x00000000, 0x00000000}},  //   gbog_, afpl,   ,
  { {0xe45600bd, 0xdb02001d, 0x442b0038, 0x00000000}},  //   _נישט_, _ngoà, _inc_,
  { {0x645a0089, 0xee3803e8, 0xef18007e, 0x00000000}},  //   ītie, мні_, ьмі_,
  { {0x442b0093, 0x7e630052, 0x3133009e, 0x00000000}},  //   _knc_, rinp, _جہاز,
  { {0xa1942dd8, 0x442b00d4, 0x6d430036, 0x00000000}},  //   _расч, _jnc_, ryna,
  { {0x442b2dd9, 0x2ef4005e, 0x7d7900a1, 0x00000000}},  //   _mnc_, _изтр, _کمار_,
  { {0x1eea0bb6, 0x00000000, 0x00000000, 0x00000000}},  //   _رومی_,   ,   ,
  { {0xf866003b, 0xa3c1007d, 0x00000000, 0x00000000}},  //   евно, ुरा_,   ,
  { {0x66e6012c, 0xc68900a0, 0x9ac40066, 0x00000000}},  //   нома, _הא_, _boċċ,
  { {0x7c2b0781, 0x00000000, 0x00000000, 0x00000000}},  //   _ingr,   ,   ,
  { {0x442b0007, 0xbb3a019b, 0x644f00c4, 0x00000000}},  //   _anc_, _מעני, _alci,
  { {0x26d90197, 0xf202013d, 0x00000000, 0x00000000}},  //   asso_, र्फ़_,   ,
  { {0x14e10061, 0x00000000, 0x00000000, 0x00000000}},  //   _फिरण,   ,   ,
  { {0x7afb0659, 0x442b0085, 0x4226007e, 0x00000000}},  // [8aa0] ntut, _dnc_, ндав,
  { {0x442b231b, 0x877b00a0, 0xb77b009b, 0x00000000}},  //   _enc_, _מאפי, _מאפש,
  { {0x32180482, 0x26c00243, 0xd76400a6, 0x00000000}},  //   _vary_, _htio_, _سنگی,
  { {0x672407fa, 0xdfcf006d, 0x442b008e, 0x00000000}},  //   _krij, ميم_, _gnc_,
  { {0x32180022, 0x2fc60296, 0x2cbe0022, 0x00000000}},  //   _tary_, rbog_, _sttd_,
  { {0x7c2b2dda, 0x48e002d2, 0x2907021a, 0x00000000}},  //   _angr, _किलो_, _opna_,
  { {0xa3e402d2, 0x27e00240, 0xafe601fc, 0x00000000}},  //   _नया_, _odin_, _повл,
  { {0x09d80061, 0x2ee60026, 0x3d010061, 0x00000000}},  //   ढण्य, prof_, _शहरे_,
  { {0xdb19010f, 0x7afb006a, 0x29070087, 0x00000000}},  //   _gewü, gtut, _apna_,
  { {0x7c2b0181, 0xef17008b, 0x27e0002d, 0x00000000}},  //   _engr, _яму_, _adin_,
  { {0x7afb002d, 0x629e00e5, 0x672404eb, 0x00000000}},  //   atut, impo, _arij,
  { {0x6724016e, 0xa7fb008e, 0xc173009b, 0x00000000}},  //   _brij, riño, טחת_,
  { {0x6724016e, 0x870404dd, 0x3ebf0066, 0x00000000}},  //   _crij, ляре, _xtut_,
  { {0x27e0005d, 0x67242ddb, 0x442b219a, 0x00000000}},  //   _edin_, _drij, _snc_,
  { {0x25a50073, 0x442b0145, 0x26d90a15, 0x00000000}},  //   äll_, _pnc_, ssso_,
  { {0x6d580059, 0x629e1c9a, 0x442b109d, 0x00000000}},  //   izva, empo, _qnc_,
  { {0xc6a70069, 0x67242ddc, 0x88bc00b9, 0x00000000}},  // [8ab0] _прои, _grij, svěd,
  { {0x6aaa01d5, 0x442b0026, 0xf7700014, 0x00000000}},  //   _jiff, _wnc_, _چای_,
  { {0x442b1323, 0x7afb002d, 0xf12400a5, 0x00000000}},  //   _tnc_, ztut, льцо,
  { {0x442b04d2, 0x629e00e0, 0x6aaa2ddd, 0x00000000}},  //   _unc_, ampo, _liff,
  { {0x7ff4006d, 0x798a01d6, 0xdb19000a, 0x00000000}},  //   اسما, _lyfw, _lewò,
  { {0x6aaa0066, 0x00000000, 0x00000000, 0x00000000}},  //   _niff,   ,   ,
  { {0xdd91026c, 0x92a60046, 0x93c6001a, 0x00000000}},  //   گوں_, _dołą, sfăş,
  { {0x7afb0198, 0xcf7b0025, 0x0c2500ed, 0x00000000}},  //   ttut, _فإذا_, тмин,
  { {0xdd91026c, 0x6aaa02e7, 0x32cf0036, 0x00000000}},  //   دوں_, _biff, nży_,
  { {0x7afb022b, 0x200f0004, 0x67240023, 0x00000000}},  //   rtut, legi_, _rrij,
  { {0x7afb08b2, 0x67240209, 0x798a0016, 0x00000000}},  //   stut, _srij, _cyfw,
  { {0x67240759, 0x201d2dde, 0x6aaa009d, 0x00000000}},  //   _prij, ndwi_, _eiff,
  { {0xddd800ca, 0xe737005e, 0x6aaa00f8, 0x00000000}},  //   lovš, вея_, _fiff,
  { {0x67242ddf, 0x6aaa0197, 0x63bd190e, 0x00000000}},  //   _vrij, _giff, _afsn,
  { {0x6b8b0f4b, 0x7ae9043e, 0x32cf0036, 0x00000000}},  //   _hygg, lret, eży_,
  { {0xc95200b6, 0x15ee013d, 0x27e004be, 0x00000000}},  //   _כמו_, _जाकर_, _udin_,
  { {0x64a3008b, 0xfbd2009b, 0x200f000c, 0x00000000}},  // [8ac0] рата, יתן_, degi_,
  { {0x6b8b2de0, 0x64590066, 0x00000000, 0x00000000}},  //   _mygg, _ċwie,   ,
  { {0xd877026c, 0x6493006b, 0x69ce000c, 0x00000000}},  //   _سمیت_, mçin, ðbei,
  { {0x694605fa, 0xddd80142, 0x7a3e00b9, 0x00000000}},  //   _učeš, dovš, _zátě,
  { {0x92a60036, 0x00000000, 0x00000000, 0x00000000}},  //   _połą,   ,   ,
  { {0x7ae90030, 0x68e80016, 0x975b009b, 0x00000000}},  //   dret, yrdd, ודנט,
  { {0x6aaa0190, 0x7ae91a00, 0x200f0bb2, 0x00000000}},  //   _riff, eret, begi_,
  { {0x6b8b0332, 0x6aaa0039, 0x200f0a4b, 0x00000000}},  //   _bygg, _siff, cegi_,
  { {0xa067012b, 0x2d81010f, 0x8fa3007c, 0x00000000}},  //   _рата_, üher_, _вате,
  { {0x5ea60151, 0x3eb90211, 0x81e40044, 0x00000000}},  //   _شمال, _ésta_, ভ্র_,
  { {0x7ae9010e, 0x00000000, 0x00000000, 0x00000000}},  //   aret,   ,   ,
  { {0x4bda00e9, 0x7ae90129, 0x00000000, 0x00000000}},  //   _آباد_, bret,   ,
  { {0x2d8c00b4, 0xf804007e, 0x6aaa086a, 0x00000000}},  //   _hyde_, шчэн, _tiff,
  { {0xceb300a3, 0x7d1c01e5, 0x200f2de1, 0x00000000}},  //   ייש_, _árss, zegi_,
  { {0xc7c702a8, 0x984f0036, 0x3eac05b7, 0x00000000}},  //   _испи, jęć_, _midt_,
  { {0x3eac0018, 0x62870193, 0x3dd80044, 0x00000000}},  //   _lidt_, _skjo, _সাফল,
  { {0xb2750679, 0x2d8c08c8, 0x66720014, 0x00000000}},  // [8ad0] глаш, _lyde_, شگیر,
  { {0x7aef0129, 0xbebd01c5, 0x00000000, 0x00000000}},  //   àcti, _brūn,   ,
  { {0xf1a70069, 0x2d8c0030, 0x78ad0026, 0x00000000}},  //   тран, _nyde_, _kiav,
  { {0x7ae9014a, 0x3eac0087, 0x25ff0309, 0x00000000}},  //   yret, _aidt_, श्री_,
  { {0x200f05cf, 0x3eac2de2, 0x00000000, 0x00000000}},  //   regi_, _bidt_,   ,
  { {0x644d021e, 0x6b8b1afa, 0x7ae90142, 0x00000000}},  //   lkai, _rygg, vret,
  { {0x62852de3, 0xa3c70061, 0x7bc90270, 0x00000000}},  //   moho, _उभा_, tbeu,
  { {0xc17200b6, 0x644d2de4, 0x62850161, 0x00000000}},  //   _החל_, nkai, loho,
  { {0xac960025, 0x6f0918e8, 0x7bc92af8, 0x00000000}},  //   دنيا_, _upec, rbeu,
  { {0x7ae9022b, 0x3f7a007b, 0x7bc9054e, 0x00000000}},  //   rret, _אָבע, sbeu,
  { {0x644d021e, 0x7ae90091, 0x78ad0190, 0x00000000}},  //   kkai, sret, _biav,
  { {0x7ae90292, 0x78ad1733, 0x6b8b101b, 0x00000000}},  //   pret, _ciav, _tygg,
  { {0x78ad237d, 0x3b090d11, 0x7d1c000c, 0x00000000}},  //   _diav, _чело_, _ársr,
  { {0x75d60025, 0x644d0006, 0x00000000, 0x00000000}},  //   طيرا, ekai,   ,
  { {0xdb0b0030, 0x649a00ed, 0x2bda0164, 0x00000000}},  //   _afgø, етар_, _यजमा,
  { {0x7c3b01a3, 0x644d006a, 0x78ad2de5, 0x00000000}},  //   njur, gkai, _giav,
  { {0x8c1d0044, 0x645a00d4, 0x00000000, 0x00000000}},  // [8ae0] থাপন_, ètiq,   ,
  { {0x64560e92, 0x64930180, 0x628502c1, 0x00000000}},  //   shyi, lçil, goho,
  { {0x4fea0081, 0x00e6007c, 0x3eac002b, 0x00000000}},  //   емен_, ужен, _ridt_,
  { {0x2d8c098e, 0x661e10f0, 0x644d007f, 0x00000000}},  //   _ryde_, _hapk, ckai,
  { {0x4420011f, 0xbe8a0e82, 0x62851105, 0x00000000}},  //   mdi_, нске_, boho,
  { {0x661e00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _japk,   ,   ,
  { {0x44202de6, 0x3eac05b7, 0x6d47002b, 0x00000000}},  //   odi_, _vidt_, _żjar,
  { {0x44202de7, 0x3ed604e8, 0x661e0006, 0x00000000}},  //   ndi_, _مقرر, _lapk,
  { {0x44201158, 0x78ad0197, 0x0a6a00aa, 0x00000000}},  //   idi_, _riav, ерни_,
  { {0x644d2de8, 0x4420006b, 0x661e0010, 0x00000000}},  //   zkai, hdi_, _napk,
  { {0x19942de9, 0x78ad0197, 0x4420006b, 0x00000000}},  //   раня, _piav, kdi_,
  { {0x4d7b061e, 0x4420086e, 0x6ac30044, 0x00000000}},  //   _ארבע, jdi_, _শিরো,
  { {0xead403c8, 0x44202383, 0xa2b003d7, 0x00000000}},  //   _толь, ddi_, _अंग्,
  { {0x44200207, 0x661e2dea, 0x00000000, 0x00000000}},  //   edi_, _capk,   ,
  { {0x644d021e, 0xa4d501fb, 0xa9bb009b, 0x00000000}},  //   tkai, робі, _אזור,
  { {0x69da0038, 0x24182deb, 0x645a0d90, 0x00000000}},  //   late, лосы_, ūtin,
  { {0x644d0149, 0x628505bd, 0x629c0051, 0x00000000}},  // [8af0] rkai, toho, _bhro,
  { {0x644d0a5c, 0x4420006c, 0x7d1a0bea, 0x00000000}},  //   skai, adi_, _osts,
  { {0x212700ad, 0xffd5008b, 0x62851238, 0x00000000}},  //   ính_, аўля, roho,
  { {0x69da0036, 0x6285255a, 0xa3d6006e, 0x00000000}},  //   hate, soho, हरण_,
  { {0x69da0d0a, 0x6283016c, 0xd2f600a1, 0x00000000}},  //   kate, čnob, _نکلا_,
  { {0x69da2dec, 0x20d705f3, 0xb6bc0049, 0x00000000}},  //   jate, _مترج, עצוי,
  { {0xa3b9006e, 0x6d4a0852, 0x00000000, 0x00000000}},  //   _चला_, gyfa,   ,
  { {0x6ee700e9, 0x3eb9008e, 0x1c450793, 0x00000000}},  //   _مسئل, _ésto_, рним,
  { {0x7c3b002b, 0x69da0016, 0xbebd0dec, 0x00000000}},  //   rjur, fate, _krūm,
  { {0xf41f0039, 0x7c3b0116, 0xc332009b, 0x00000000}},  //   _skäl_, sjur, קוי_,
  { {0x64930279, 0x44202ded, 0x00000000, 0x00000000}},  //   tçil, ydi_,   ,
  { {0x186a0373, 0x38ca0014, 0xc60e0164, 0x00000000}},  //   тами_, کایی_, ाज्य_,
  { {0x69da0181, 0x442001d5, 0x661e2dee, 0x00000000}},  //   bate, vdi_, _papk,
  { {0x69da0038, 0xfed70055, 0x79e700a1, 0x00000000}},  //   cate, _সমাধ, _صوبہ_,
  { {0x287607d0, 0xd46a00ed, 0x4420006b, 0x00000000}},  //   _выпр, виве_, tdi_,
  { {0x629c2c03, 0x44200442, 0x2b09013d, 0x00000000}},  //   _shro, udi_, _वहाँ_,
  { {0x62661deb, 0x629c2def, 0x661e0c47, 0x00000000}},  // [8b00] аваа, _phro, _tapk,
  { {0x91e60902, 0x44200b1e, 0x09a90044, 0x00000000}},  //   роже, sdi_, _খ্যা,
  { {0xdb19010f, 0x44200058, 0x224300ca, 0x00000000}},  //   _gewö, pdi_, _dojk_,
  { {0x69da002d, 0x00000000, 0x00000000, 0x00000000}},  //   zate,   ,   ,
  { {0x629c0038, 0x60c90059, 0x6d4a0016, 0x00000000}},  //   _thro, _čeme, wyfa,
  { {0x69da00d9, 0xa1160014, 0x7d1a0026, 0x00000000}},  //   xate, _پورت, _psts,
  { {0x69da004f, 0xc0e3004d, 0x3dcf0044, 0x00000000}},  //   vate, _морк, _রাখল,
  { {0x69da1575, 0x6d4a005b, 0x6f1b0045, 0x00000000}},  //   wate, ryfa, _fsuc,
  { {0x69da2df0, 0x6d4a00d9, 0xe45700b3, 0x00000000}},  //   tate, syfa, ייקט_,
  { {0x38ba048a, 0x6f0202c2, 0x2caf00ea, 0x00000000}},  //   _për_, mtoc, _eigd_,
  { {0xa3d60309, 0x2f0001aa, 0x8be80044, 0x00000000}},  //   हरा_, lòg_, ক্ষন_,
  { {0x69da028c, 0x64bc01ee, 0x00000000, 0x00000000}},  //   sate, _pčin,   ,
  { {0x69da0390, 0x6f020142, 0xbbd20061, 0x00000000}},  //   pate, ntoc, सरीक,
  { {0xd687017a, 0xddc30035, 0x386b005b, 0x00000000}},  //   румп, minţ, sicr_,
  { {0x046702be, 0x24920016, 0x69d80089, 0x00000000}},  //   атам, flym_, _ieve,
  { {0x320a01a3, 0x69d80148, 0x54540131, 0x00000000}},  //   _abby_, _heve, овст,
  { {0x64bc0340, 0x69d80010, 0xddc3001a, 0x00000000}},  // [8b10] _učin, _keve, ninţ,
  { {0x35f5013b, 0x6f020927, 0x78b8014a, 0x00000000}},  //   _упор, dtoc, _kuvv,
  { {0xdfd10025, 0x69d80129, 0x66152df1, 0x00000000}},  //   كيا_, _meve, mezk,
  { {0x6615002d, 0x5fe70088, 0x00000000, 0x00000000}},  //   lezk, ріжж,   ,
  { {0x5335007b, 0x4fe801e1, 0xdefb007c, 0x00000000}},  //   _האָב_, рмін_, тые_,
  { {0x9e6401fb, 0x6615022b, 0xddc3001a, 0x00000000}},  //   овід, nezk, dinţ,
  { {0x386901a3, 0x7ae2001e, 0xc212009b, 0x00000000}},  //   _omar_, _avot, _מהם_,
  { {0xeb9910e1, 0x3ce916d0, 0x00000000, 0x00000000}},  //   лий_, čav_,   ,
  { {0x6f1b0035, 0xc5ff0089, 0x290e0045, 0x00000000}},  //   _usuc, ļēji_, _apfa_,
  { {0x38691596, 0x69d80087, 0x7bc20022, 0x00000000}},  //   _amar_, _ceve, _efou,
  { {0x69d80e3e, 0x8d950054, 0x6615022b, 0x00000000}},  //   _deve, _الاش, dezk,
  { {0xa85602a8, 0x3d010046, 0x6e21010f, 0x00000000}},  //   стој, mów_, _halb,
  { {0x6e212df2, 0x8b6801fb, 0x41a70061, 0x00000000}},  //   _kalb, _київ_, केतस,
  { {0x69d8017c, 0x65c305f6, 0x6615002d, 0x00000000}},  //   _geve, збра, gezk,
  { {0x3d010046, 0x24890093, 0xe820013d, 0x00000000}},  //   nów_, foam_, _बसपा_,
  { {0x69d823d1, 0x6f020253, 0xab5d0036, 0x00000000}},  //   _zeve, ytoc, waży,
  { {0x04430216, 0x3aba007b, 0x7bd904cb, 0x00000000}},  // [8b20] четн, ָמענ, _mewu,
  { {0x3d010046, 0x69c100d4, 0xb69b1290, 0x00000000}},  //   ków_, ncle, ltân,
  { {0x3d010036, 0x24891fff, 0x02190088, 0x00000000}},  //   jów_, boam_, шіть_,
  { {0x3d010046, 0x7bd90061, 0x6e210018, 0x00000000}},  //   dów_, _newu, _aalb,
  { {0x6e21027b, 0xd9f90061, 0x8bff0044, 0x00000000}},  //   _balb, ्भात_, ্যান_,
  { {0x44222df3, 0x6e2100d4, 0x6f02001a, 0x00000000}},  //   _hak_, _calb, rtoc,
  { {0x6f02027b, 0x6446010a, 0x7bd9023d, 0x00000000}},  //   stoc, _koki, _bewu,
  { {0x44221f8a, 0x64460f38, 0xf07600a1, 0x00000000}},  //   _jak_, _joki, _اُرد,
  { {0x44222df4, 0x64460006, 0x23602df5, 0x00000000}},  //   _mak_, _moki, nzij_,
  { {0xc33300b6, 0x69d8008d, 0x6e960a4f, 0x00000000}},  //   פות_, _qeve, _الطا,
  { {0x3d010036, 0x69d80056, 0x44220133, 0x00000000}},  //   ców_, _veve, _oak_,
  { {0x644601cf, 0x7ae0001c, 0x4422117c, 0x00000000}},  //   _noki, psmt, _nak_,
  { {0x69d82df6, 0x6615022b, 0x76450161, 0x00000000}},  //   _teve, tezk, _pohy,
  { {0x7aef0211, 0xa3cb0204, 0xa5f9003b, 0x00000000}},  //   ácte, रुन_, јеву_,
  { {0x44222df7, 0x64461dea, 0x7c220058, 0x00000000}},  //   _bak_, _boki, _kaor,
  { {0x4422037e, 0x3d1b01f5, 0x6615002d, 0x00000000}},  //   _cak_, _मनसे_, sezk,
  { {0x644601aa, 0x44221300, 0x7c221c7e, 0x00000000}},  // [8b30] _doki, _dak_, _maor,
  { {0x765c0537, 0xf1a700d7, 0x44220032, 0x00000000}},  //   chry, брен, _eak_,
  { {0xf652009b, 0x672d01ca, 0xbebd0d90, 0x00000000}},  //   _חצי_, _hraj, _trūk,
  { {0x44220149, 0x6e21002d, 0x64bc0166, 0x00000000}},  //   _gak_, _salb, _očij,
  { {0xc1e900a1, 0x3d010036, 0x628e012d, 0x00000000}},  //   _نکال_, wów_, _fkbo,
  { {0x3d010046, 0x44222df8, 0x64460107, 0x00000000}},  //   tów_, _zak_, _zoki,
  { {0xed590057, 0x6e210193, 0x44220093, 0x00000000}},  //   рой_, _valb, _yak_,
  { {0x3d010046, 0x27e9014a, 0x672d012d, 0x00000000}},  //   rów_, _ndan_, _oraj,
  { {0x6e2109e2, 0x3d010046, 0x69c12df9, 0x00000000}},  //   _talb, sów_, tcle,
  { {0xe9d90072, 0xda6501fb, 0x27e901aa, 0x00000000}},  //   шко_, івни, _adan_,
  { {0xd9452dfa, 0x26c90022, 0x00000000, 0x00000000}},  //   цени, _atao_,   ,
  { {0x672d037e, 0x69c10531, 0x27e90288, 0x00000000}},  //   _braj, scle, _cdan_,
  { {0xb69b2dfb, 0x64460006, 0x765c0016, 0x00000000}},  //   rtân, _roki, thry,
  { {0x44222dfc, 0x8aa710d8, 0xe93901ef, 0x00000000}},  //   _sak_, _уред, _نسبت_,
  { {0x4422151b, 0x64460027, 0xa9660aed, 0x00000000}},  //   _pak_, _poki, _миша_,
  { {0x672d016e, 0x229400b0, 0x236000bb, 0x00000000}},  //   _fraj, mäki_, tzij_,
  { {0xc5d90055, 0x6446010a, 0x442200b5, 0x00000000}},  // [8b40] _তারপ, _voki, _vak_,
  { {0x44220145, 0xd1960098, 0x437519a2, 0x00000000}},  //   _wak_, ошењ, чуст,
  { {0x64462bac, 0xa3d5013d, 0x2905008e, 0x00000000}},  //   _toki, _सड़क_, ntla_,
  { {0xd00a003b, 0xdfcf023c, 0x00000000, 0x00000000}},  //   реде_, نيم_,   ,
  { {0x9eaa005c, 0x245c0010, 0x4ea60478, 0x00000000}},  //   авда_, _címe_, орка,
  { {0xe2970783, 0x412a007c, 0x7c220051, 0x00000000}},  //   _мая_, _кого_, _saor,
  { {0x910301be, 0xf98700a2, 0x25d70049, 0x00000000}},  //   _опре, _آب_, קוקן_,
  { {0x2fc400c4, 0xcb0a05b8, 0xa4b7009b, 0x00000000}},  //   _ufmg_, аход_, חלקה_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x764800b0, 0xddc30087, 0xd8f80088, 0x00000000}},  //   ödyl, pinš, бної_,
  { {0xc1bb0049, 0x41bb0049, 0x7c220197, 0x00000000}},  //   ימיש, יציע, _taor,
  { {0x672d2dfd, 0xc8670088, 0x00000000, 0x00000000}},  //   _praj, ітни,   ,
  { {0x6747007e, 0x64bc0e54, 0x672d0066, 0x00000000}},  //   цэнз, _učij, _qraj,
  { {0x672d2dfe, 0x00000000, 0x00000000, 0x00000000}},  //   _vraj,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd6db0057, 0x27e9002d, 0x00000000, 0x00000000}},  //   _кто_, _udan_,   ,
  { {0x2458007c, 0xddcb2dff, 0x00000000, 0x00000000}},  // [8b50] цать_, _čižm,   ,
  { {0xbebd0006, 0x00000000, 0x00000000, 0x00000000}},  //   _krūv,   ,   ,
  { {0xc015007c, 0x7d0d0036, 0x3495003b, 0x00000000}},  //   змещ, łasz, _наор,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xce95005e, 0x80dc0044, 0x00000000, 0x00000000}},  //   падъ, মূল্,   ,
  { {0x82d600b3, 0x51870780, 0x245c013e, 0x00000000}},  //   _מושג_, _дуба, _víme_,
  { {0xdfd503c8, 0x29050886, 0x00000000, 0x00000000}},  //   _новы, xtla_,   ,
  { {0x8027025a, 0xc57c009b, 0x0b45005e, 0x00000000}},  //   _برآم, ירות, знин,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe8f90920, 0xadf40545, 0x290501e5, 0x00000000}},  //   бло_, _опуш, ttla_,
  { {0xdcef0006, 0xbd6b0893, 0x2905004a, 0x00000000}},  //   _įdėt, _трае_, utla_,
  { {0x31560049, 0x3a250022, 0x00000000, 0x00000000}},  //   פירן_, sdlp_,   ,
  { {0xd5b80089, 0x29050471, 0x69cc013d, 0x00000000}},  //   žām_, stla_, _द्वी,
  { {0xfe7900b9, 0x00000000, 0x00000000, 0x00000000}},  //   _svůj_,   ,   ,
  { {0xceb2019b, 0x64a6008b, 0x845a0745, 0x00000000}},  //   תים_, зава, брат_,
  { {0x98a3007c, 0x00000000, 0x00000000, 0x00000000}},  //   _пище,   ,   ,
  { {0x08770049, 0xf8b30104, 0x00000000, 0x00000000}},  // [8b60] _מעקט_, _אשה_,   ,
  { {0x42232e00, 0x00000000, 0x00000000, 0x00000000}},  //   ндув,   ,   ,
  { {0x657a0051, 0xfe7900b9, 0x00000000, 0x00000000}},  //   úthd, _tvůj_,   ,
  { {0xdd1e00b9, 0xa06a003b, 0x27e20022, 0x00000000}},  //   tíže, љада_, nakn_,
  { {0xddcf00b9, 0x6aa80045, 0x00000000, 0x00000000}},  //   _řeše, ymdf,   ,
  { {0x27e20022, 0x00000000, 0x00000000, 0x00000000}},  //   hakn_,   ,   ,
  { {0x6493006b, 0x09da0044, 0x38ba0089, 0x00000000}},  //   rçiv, _দালা, _tīri_,
  { {0x321a0036, 0x9e660167, 0x244e01dc, 0x00000000}},  //   lepy_, _کارن, _týmu_,
  { {0xaae60025, 0x00000000, 0x00000000, 0x00000000}},  //   أسبو,   ,   ,
  { {0x61fe0c53, 0x7aef0211, 0xc986013b, 0x00000000}},  //   ngpl, ácta, зуми,
  { {0xfe4500a6, 0xf4b70044, 0x00000000, 0x00000000}},  //   _تکنی, _জব্ব,   ,
  { {0x78a41965, 0x00000000, 0x00000000, 0x00000000}},  //   _chiv,   ,   ,
  { {0x2bd202fb, 0x81e20044, 0x00000000, 0x00000000}},  //   _ध्या, _ধান_,   ,
  { {0x80d20044, 0x00000000, 0x00000000, 0x00000000}},  //   _হিন্,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x95840036, 0xbebd0d90, 0xe3bf0032, 0x00000000}},  //   _łącz, _krūt, _baña_,
  { {0xa2b501fb, 0xe3bf008e, 0x00000000, 0x00000000}},  // [8b70] дбач, _caña_,   ,
  { {0x78a42e01, 0x645f0065, 0xe3b00025, 0x00000000}},  //   _zhiv, shqi, طرق_,
  { {0x41190439, 0x00000000, 0x00000000, 0x00000000}},  //   تياج_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x442901f6, 0x4439001f, 0x645d002b, 0x00000000}},  //   mda_, _ins_, _ilsi,
  { {0xef1802f0, 0x479c0049, 0x4439016e, 0x00000000}},  //   ямі_, ציגס, _hns_,
  { {0x44290006, 0xc1050380, 0x443904a5, 0x00000000}},  //   oda_, _توزي, _kns_,
  { {0xf53801ce, 0xcac9007c, 0xbd180088, 0x00000000}},  //   לטור_, огие_, яції_,
  { {0x442904bd, 0x99f5007e, 0x64932e02, 0x00000000}},  //   ida_, мяні, lçis,
  { {0x44292e03, 0x2bff0044, 0x1a6500a6, 0x00000000}},  //   hda_, ্যেই_, بیتی_,
  { {0x443906b2, 0x4429011c, 0xd5b80089, 0x00000000}},  //   _ons_, kda_, žāk_,
  { {0x44291864, 0x2fdf0007, 0x44390c6b, 0x00000000}},  //   jda_, _jeug_, _nns_,
  { {0x44292e04, 0xbebd001e, 0x61fe0039, 0x00000000}},  //   dda_, _grūt, ygpl,
  { {0x44392e05, 0x44292e06, 0x3ebf021e, 0x00000000}},  //   _ans_, eda_, _muut_,
  { {0xe969007c, 0x44392e07, 0x7afb03b6, 0x00000000}},  //   _файл_, _bns_, luut,
  { {0x7c290125, 0x4429006a, 0x645d0061, 0x00000000}},  //   nder, gda_, _clsi,
  { {0x7c2904b2, 0x3ebf0007, 0xda0e0011, 0x00000000}},  // [8b80] ider, _nuut_, _mỏng_,
  { {0x442901d1, 0x443904bd, 0x4426024f, 0x00000000}},  //   ada_, _ens_, žo_,
  { {0x442901d5, 0x661c2e08, 0x27e0001f, 0x00000000}},  //   bda_, merk, _kein_,
  { {0x7c291932, 0x7afb021e, 0x44390190, 0x00000000}},  //   jder, kuut, _gns_,
  { {0x7c290030, 0x27e0001f, 0x2fdf01d6, 0x00000000}},  //   dder, _mein_, _deug_,
  { {0x7c290207, 0x27e0018e, 0xa2e300ec, 0x00000000}},  //   eder, _lein_, _јорд,
  { {0xda0e0011, 0x00000000, 0x00000000, 0x00000000}},  //   _bỏng_,   ,   ,
  { {0x27e005e9, 0x6724016e, 0x32c4014a, 0x00000000}},  //   _nein_, _osij, _köy_,
  { {0x1dcf0201, 0x661c0056, 0xafe30581, 0x00000000}},  //   _स्वत, kerk, _шотл,
  { {0x7c292b63, 0xdb220036, 0x27450065, 0x00000000}},  //   ader, _źród, _lënë_,
  { {0x44290279, 0x27e003fa, 0x67242e09, 0x00000000}},  //   yda_, _bein_, _asij,
  { {0x26c00197, 0x7afb01d6, 0x27450065, 0x00000000}},  //   _buio_, buut, _nënë_,
  { {0x27e0010f, 0x44290027, 0x443901e5, 0x00000000}},  //   _dein_, vda_, _rns_,
  { {0x661c0fdf, 0x4429208b, 0x44390142, 0x00000000}},  //   gerk, wda_, _sns_,
  { {0x4429006b, 0x4439023a, 0x27450065, 0x00000000}},  //   tda_, _pns_, _bënë_,
  { {0xd5b8004c, 0x44290995, 0x6e280146, 0x00000000}},  //   ься_, uda_, _ladb,
  { {0x4429049d, 0xa3aa0061, 0x6e3a01b5, 0x00000000}},  // [8b90] rda_, गेल_, _ontb,
  { {0x4429006b, 0x27e0022b, 0x6e28016e, 0x00000000}},  //   sda_, _zein_, _nadb,
  { {0x7c290016, 0x25d6009b, 0x00000000, 0x00000000}},  //   yder, _אותן_,   ,
  { {0x44391fdc, 0x245c009f, 0x44292ca5, 0x00000000}},  //   _uns_, _tíma_, qda_,
  { {0x22940039, 0x7c290023, 0x32c4006b, 0x00000000}},  //   täkt_, vder, _göy_,
  { {0xceb80036, 0x6da50437, 0x603e001a, 0x00000000}},  //   _cię_, нила, _pămâ,
  { {0xdc3a014a, 0xe8200061, 0x61e503e1, 0x00000000}},  //   _açıs, _बसला_, mahl,
  { {0x69ca19eb, 0x61e5005f, 0x7c2906b1, 0x00000000}},  //   _affe, lahl, uder,
  { {0x27e00bea, 0x661c0058, 0x3ed90bb6, 0x00000000}},  //   _rein_, yerk, _رواج_,
  { {0x27e02e0a, 0x39450088, 0xfeb80025, 0x00000000}},  //   _sein_, еног, _قالت_,
  { {0x661c067e, 0x7afb021e, 0x2d800035, 0x00000000}},  //   verk, suut, şier_,
  { {0xed5600bd, 0x661c2e0b, 0x7afb2e0c, 0x00000000}},  //   _אבער_, werk, puut,
  { {0x661c022b, 0x443e001d, 0x3a270263, 0x00000000}},  //   terk, _đt_, _tanp_,
  { {0xe3bf04a8, 0x64bc1032, 0x7ae92e0d, 0x00000000}},  //   _baño_, _očit, mset,
  { {0xa979007b, 0x7ae924c7, 0xf8c6007d, 0x00000000}},  //   _מאַכ, lset, _रूपय,
  { {0x46ea0265, 0x7bc900f4, 0xe3bf0211, 0x00000000}},  //   _един_, nceu, _daño_,
  { {0x661c2e0e, 0x7ae904b2, 0x27450065, 0x00000000}},  // [8ba0] perk, nset, _vënë_,
  { {0x99850010, 0x2cad0560, 0x25e10061, 0x00000000}},  //   lelő_, hmed_, करणी_,
  { {0x6e280270, 0x7ae9169c, 0x2cad006c, 0x00000000}},  //   _radb, hset, kmed_,
  { {0xceb80df0, 0x7ae92e0f, 0xf77f1052, 0x00000000}},  //   _się_, kset, laça_,
  { {0x2cad006c, 0x7ae92e10, 0x24800f3a, 0x00000000}},  //   dmed_, jset, mnim_,
  { {0x7ae92ce0, 0x24800213, 0xf77f00d4, 0x00000000}},  //   dset, lnim_, naça_,
  { {0xf65300a3, 0x6e280059, 0x7ae90026, 0x00000000}},  //   רצו_, _vadb, eset,
  { {0x7ae901e5, 0x00000000, 0x00000000, 0x00000000}},  //   fset,   ,   ,
  { {0x7ae90fc7, 0x3f810180, 0x2ca62e11, 0x00000000}},  //   gset, şhur_, _vhod_,
  { {0xdb230051, 0x4a54030d, 0x24802e12, 0x00000000}},  //   órái, ткос, hnim_,
  { {0x386001c9, 0x88bc00b9, 0x2cad00ab, 0x00000000}},  //   _blir_, jvět, bmed_,
  { {0xa3b10164, 0x61e5010f, 0x81570049, 0x00000000}},  //   टेड_, zahl, גסטע_,
  { {0x24800119, 0x64bc0738, 0x61e52e13, 0x00000000}},  //   dnim_, _očis, yahl,
  { {0x09e30055, 0xbb3b0097, 0xe3bf008e, 0x00000000}},  //   _মাথা, _מעדי, _paño_,
  { {0xceb301ce, 0x659500ed, 0x386000ca, 0x00000000}},  //   טיש_, таву, _flir_,
  { {0xd49802b8, 0x38602e14, 0x61e52e15, 0x00000000}},  //   еру_, _glir_, wahl,
  { {0x61e5127d, 0x57f4007e, 0x09e30044, 0x00000000}},  // [8bb0] tahl, _спыт, _মাতা,
  { {0x7afd0129, 0x24802e16, 0x00000000, 0x00000000}},  //   àsti, anim_,   ,
  { {0xf77300a1, 0xdfd1006d, 0x69c7050f, 0x00000000}},  //   _جاں_, ليا_, žjeg,
  { {0x2480037e, 0x1b170055, 0xf9930049, 0x00000000}},  //   cnim_, তিতে_, ארע_,
  { {0xd9ad03d7, 0x442b0068, 0x4f580088, 0x00000000}},  //   _घण्ट, _iac_, ницю_,
  { {0x7ae92e17, 0x442b0095, 0xbd8900a1, 0x00000000}},  //   vset, _hac_, ونشن_,
  { {0x64bc154d, 0xfc310025, 0x644f05fd, 0x00000000}},  //   _učit, لحة_, _koci,
  { {0x7ae92cdf, 0x644f016c, 0x442b0145, 0x00000000}},  //   tset, _joci, _jac_,
  { {0x442b2e18, 0x644f2e19, 0x7bc9009d, 0x00000000}},  //   _mac_, _moci, rceu,
  { {0x644f00ee, 0x442b0068, 0x24800ecc, 0x00000000}},  //   _loci, _lac_, znim_,
  { {0x442b0129, 0x09e30044, 0x00000000, 0x00000000}},  //   _oac_, _মাদা,   ,
  { {0x442b0016, 0x00000000, 0x00000000, 0x00000000}},  //   _nac_,   ,   ,
  { {0x24800c1e, 0x7c2b0061, 0x290c013f, 0x00000000}},  //   vnim_, _iagr, atda_,
  { {0xf1b1007d, 0x442b0082, 0xa3d40164, 0x00000000}},  //   जधान, _aac_, सुन_,
  { {0x442b00f4, 0x24800091, 0xf77f00c4, 0x00000000}},  //   _bac_, tnim_, raça_,
  { {0x644f0219, 0xc483031b, 0x442b0011, 0x00000000}},  //   _coci, алск, _cac_,
  { {0x7c2b006a, 0x130a008b, 0xa3e302fb, 0x00000000}},  // [8bc0] _magr, ьнай_, _नजर_,
  { {0x7c2b0292, 0x24800213, 0x442b0020, 0x00000000}},  //   _lagr, snim_, _eac_,
  { {0x442b000d, 0x644f0010, 0x248004eb, 0x00000000}},  //   _fac_, _foci, pnim_,
  { {0x7e6109e7, 0xc059007e, 0x644f016c, 0x00000000}},  //   _allp, ніі_, _goci,
  { {0x4420000d, 0xbe8a18b4, 0x1eaa0025, 0x00000000}},  //   mei_, мске_, واتي_,
  { {0x4420000d, 0x442b14f6, 0x765c2e1a, 0x00000000}},  //   lei_, _zac_, nkry,
  { {0x7c2b0107, 0xc0e3007c, 0x290c006b, 0x00000000}},  //   _bagr, _воск, xtda_,
  { {0x4420163a, 0x40950216, 0x64810089, 0x00000000}},  //   nei_, _брут, eķij,
  { {0x442015ed, 0x7c2b005b, 0xaf06013a, 0x00000000}},  //   iei_, _dagr, _шпал,
  { {0x7c2b002a, 0x44200181, 0x00000000, 0x00000000}},  //   _eagr, hei_,   ,
  { {0x44200007, 0x5ec70044, 0xdd1f0027, 0x00000000}},  //   kei_, রীদে, píšt,
  { {0x44200232, 0x6d790049, 0x7d1a0085, 0x00000000}},  //   jei_, _אָנװ, _ipts,
  { {0x442009e3, 0x6d58010a, 0x644f008e, 0x00000000}},  //   dei_, lyva, _roci,
  { {0x7c2b0209, 0x442b00f4, 0x09bc0044, 0x00000000}},  //   _zagr, _sac_, _আজকা,
  { {0x644f0387, 0x24190147, 0x442b2a0e, 0x00000000}},  //   _poci, новы_, _pac_,
  { {0x442019be, 0x00000000, 0x00000000, 0x00000000}},  //   gei_,   ,   ,
  { {0x442b171e, 0x644f17b2, 0x5215005c, 0x00000000}},  // [8bd0] _vac_, _voci, лдат,
  { {0xf77f00c4, 0x442b062a, 0x00000000, 0x00000000}},  //   laço_, _wac_,   ,
  { {0xf7700a90, 0x2127001d, 0x4420001f, 0x00000000}},  //   _های_, ình_, bei_,
  { {0x4420001a, 0xcfde0055, 0x644f0107, 0x00000000}},  //   cei_, _ডাউন, _uoci,
  { {0xdea100a1, 0xdd100062, 0x7c2b04a5, 0x00000000}},  //   میری, výše, _ragr,
  { {0x3b0d00bb, 0x00000000, 0x00000000, 0x00000000}},  //   vteq_,   ,   ,
  { {0x7c2b2e1b, 0x00000000, 0x00000000, 0x00000000}},  //   _pagr,   ,   ,
  { {0x0c25026b, 0xa6d90044, 0x24990145, 0x00000000}},  //   умин, _তিনট, _jksm_,
  { {0x78660211, 0xf77f00c4, 0xfe79013e, 0x00000000}},  //   _jóve, daço_, _dvůr_,
  { {0x44200de1, 0x78660181, 0xd9e30044, 0x00000000}},  //   zei_, _móve, _মাহম,
  { {0x7c2b2c85, 0x44200010, 0x81b50044, 0x00000000}},  //   _tagr, yei_, ছুর_,
  { {0x442003c7, 0xbbeb00a6, 0xe43c00b9, 0x00000000}},  //   xei_, _آرام_, _příč,
  { {0x7866009f, 0x442025e8, 0x81e90055, 0x00000000}},  //   _nóve, vei_, _যান_,
  { {0x38ca0014, 0x00000000, 0x00000000, 0x00000000}},  //   بایی_,   ,   ,
  { {0x44201254, 0x765c2e1c, 0x7cd10089, 0x00000000}},  //   tei_, rkry, _dārg,
  { {0x765c0343, 0x7866004a, 0x7bdb0116, 0x00000000}},  //   skry, _bóve, nbuu,
  { {0xa25b0011, 0x52aa0269, 0x00000000, 0x00000000}},  // [8be0] _vuôn, евам_,   ,
  { {0x44201792, 0x61460081, 0x00000000, 0x00000000}},  //   sei_, леза,   ,
  { {0x4420001a, 0xea76007b, 0x629e0142, 0x00000000}},  //   pei_, נגער_, rlpo,
  { {0xb4fb0097, 0x7afb0036, 0xd46a003b, 0x00000000}},  //   _אפטי, krut, _чиме_,
  { {0xe3b200a6, 0x7e782e1d, 0x7afb00d0, 0x00000000}},  //   _درد_, tivp, jrut,
  { {0xb5e20044, 0x11da0025, 0x6d580006, 0x00000000}},  //   _বাঁচ, _سورة_, tyva,
  { {0x2cc90027, 0x7c200232, 0x016619c9, 0x00000000}},  //   _ľudí_, temr, _скво,
  { {0x7afb002b, 0x00000000, 0x00000000, 0x00000000}},  //   frut,   ,   ,
  { {0x307509bb, 0x68f50161, 0xa067003b, 0x00000000}},  //   _турс, ázdn, _сата_,
  { {0x37e10044, 0x9c7c0173, 0x6d58007f, 0x00000000}},  //   _ভাইর, _avčt, pyva,
  { {0x69da0bdf, 0x00000000, 0x00000000, 0x00000000}},  //   rbte,   ,   ,
  { {0x7afb04d3, 0x3ebe000c, 0x20060023, 0x00000000}},  //   brut, _hitt_, ngoi_,
  { {0x7afb2e1e, 0x7c930025, 0xf77f0181, 0x00000000}},  //   crut, _النص, raço_,
  { {0x6d490036, 0x26e5006e, 0x00000000, 0x00000000}},  //   ślał, _कबीर_,   ,
  { {0x3ebe2e1f, 0xf77f0181, 0x24990022, 0x00000000}},  //   _mitt_, paço_, _pksm_,
  { {0x248d01ae, 0x7ae22e20, 0x3ebe0056, 0x00000000}},  //   čemo_, _kwot, _litt_,
  { {0x81e90044, 0x42751606, 0x94a8003b, 0x00000000}},  // [8bf0] _যাব_, агас, утра_,
  { {0x7aef2e21, 0xe70400a1, 0x5ed30044, 0x00000000}},  //   ácti, _اسٹی, _সিলে,
  { {0xcfd60055, 0xe7960014, 0xf1a7007e, 0x00000000}},  //   _হয়ন, _مایک, уран,
  { {0x6f020197, 0x897b0049, 0xc64b00a1, 0x00000000}},  //   fuoc, עראצ, _آجکل_,
  { {0xb817006e, 0x78bf0065, 0x20090089, 0x00000000}},  //   ध्यम_, _miqv, ļai_,
  { {0x62830428, 0x2d9e0142, 0x7bc20173, 0x00000000}},  //   čnos, _byte_, _agou,
  { {0xd658019b, 0x3ebe067e, 0xcda80025, 0x00000000}},  //   ריות_, _ditt_, هههه_,
  { {0xeb9907ca, 0x7afb0181, 0x3ebe021a, 0x00000000}},  //   кий_, trut, _eitt_,
  { {0x6f1b037e, 0x5064007c, 0x3ebe1591, 0x00000000}},  //   _upuc, _утра, _fitt_,
  { {0x7cd1001e, 0x62852e22, 0x7afb002d, 0x00000000}},  //   _pārd, nnho, rrut,
  { {0x186a0954, 0x61e70039, 0x88860242, 0x00000000}},  //   вани_, _mejl, илож,
  { {0x7cd1001e, 0x78ad0181, 0x61e70030, 0x00000000}},  //   _vārd, _chav, _lejl,
  { {0xe9ce00ed, 0x7d032e23, 0xe73a003b, 0x00000000}},  //   _мк_, luns, њег_,
  { {0x61e70224, 0x6e23010f, 0x00000000, 0x00000000}},  //   _nejl, nenb,   ,
  { {0x7d032e24, 0xc6280044, 0x62971293, 0x00000000}},  //   nuns, মালা_, doxo,
  { {0x6e23084b, 0x26c40d7b, 0xdd0100b9, 0x00000000}},  //   henb, ímos_, _štěs,

  { {0xa3b10164, 0xb89b009b, 0xe29a00ed, 0x00000000}},  // [8c00] टेल_, _בבקש, ваа_,
  { {0x6e2300d9, 0x628506d3, 0x61e70a14, 0x00000000}},  //   jenb, gnho, _cejl,
  { {0x61e70030, 0x6e23010f, 0x3ebe0302, 0x00000000}},  //   _dejl, denb, _ritt_,
  { {0x3ebe01e2, 0x2d9e0006, 0x78ad0023, 0x00000000}},  //   _sitt_, _ryte_, _xhav,
  { {0x61e72e25, 0x6e23010f, 0x2d9e0065, 0x00000000}},  //   _fejl, fenb, _syte_,
  { {0x81b50055, 0x44320062, 0x6e2305c6, 0x00000000}},  //   ছুই_, ldy_, genb,
  { {0xafe6008b, 0xddc80036, 0x721b00b3, 0x00000000}},  //   _вобл, _podł, _שולח,
  { {0x69c31543, 0x7ae20263, 0x00000000, 0x00000000}},  //   _agne, _pwot,   ,
  { {0xd24f00a1, 0x6e23010f, 0x15e6013d, 0x00000000}},  //   _عنہ_, benb, करार_,
  { {0x44322e26, 0x2d96007c, 0xf1aa013d, 0x00000000}},  //   hdy_, _крес, _करान,
  { {0x4432004f, 0x60c000b0, 0x7d03001a, 0x00000000}},  //   kdy_, _kimm, cuns,
  { {0x7ae20173, 0x69c301e3, 0x60c0086a, 0x00000000}},  //   _twot, _egne, _jimm,
  { {0x7ad40879, 0x629c0059, 0x62850016, 0x00000000}},  //   _اقتص, _okro, ynho,
  { {0x44320142, 0x60c000f8, 0x7afd07fd, 0x00000000}},  //   edy_, _limm, áste,
  { {0x58870642, 0xa4d50088, 0x644d0d88, 0x00000000}},  //   _выпа, собі, tjai,
  { {0x61300047, 0x629c2e27, 0x44320036, 0x00000000}},  //   zólá, _akro, gdy_,
  { {0x644d00b0, 0xa3b1013d, 0x61e72e28, 0x00000000}},  // [8c10] rjai, टें_, _pejl,
  { {0xdcee00b9, 0x44320652, 0x628501a2, 0x00000000}},  //   áděn, ady_, unho,
  { {0x62850030, 0x61e70018, 0x611300b9, 0x00000000}},  //   rnho, _vejl, dělá,
  { {0x27e92e29, 0x9ef50025, 0x00000000, 0x00000000}},  //   _jean_, مستش,   ,
  { {0x6e23010f, 0x53340057, 0x27e900ab, 0x00000000}},  //   tenb, _деят, _mean_,
  { {0x27e90051, 0x672d10e5, 0x98a800b9, 0x00000000}},  //   _lean_, _msaj, _brně_,
  { {0x60c0009f, 0x4035005e, 0x245c000c, 0x00000000}},  //   _fimm, _левс, _sími_,
  { {0x213e0051, 0x7cd1001e, 0x6e23010f, 0x00000000}},  //   _átha_, _pārb, senb,
  { {0x6e2322b0, 0x98bf0006, 0x7d030095, 0x00000000}},  //   penb, lytė_, suns,
  { {0x443213a6, 0x60c0010f, 0x26c10009, 0x00000000}},  //   zdy_, _zimm, _niho_,
  { {0x44322e2a, 0x27e90122, 0x69c300ca, 0x00000000}},  //   ydy_, _bean_, _vgne,
  { {0xed35026c, 0x245c000c, 0x00000000, 0x00000000}},  //   _پوچھ, _tími_,   ,
  { {0x8c16006d, 0x27e90133, 0x672d0010, 0x00000000}},  //   _طيور_, _dean_, _csaj,
  { {0xa50a00c0, 0x44320036, 0xa3bd0164, 0x00000000}},  //   лега_, wdy_, ेखन_,
  { {0x33f601e1, 0x672d00d9, 0xba740025, 0x00000000}},  //   йчас, _esaj, _بانت,
  { {0x29051312, 0x629c0091, 0xe8170061, 0x00000000}},  //   mula_, _skro, ध्दा_,
  { {0x44320161, 0xe73a0726, 0x26c10087, 0x00000000}},  // [8c20] rdy_, _сеп_, _fiho_,
  { {0x60c00039, 0x200d0035, 0x4432060a, 0x00000000}},  //   _simm, _acei_, sdy_,
  { {0x29050091, 0xd657009b, 0xb3e70044, 0x00000000}},  //   nula_, _היית_, _ফারজ,
  { {0x3a250007, 0xcf46094b, 0x00000000, 0x00000000}},  //   help_, йней,   ,
  { {0x290512e8, 0x60c000f8, 0xe3bf0288, 0x00000000}},  //   hula_, _vimm, _bañu_,
  { {0x412a01fb, 0x29050503, 0x6146003b, 0x00000000}},  //   _його_, kula_, _лега,
  { {0x60c00073, 0xc27b0049, 0x2905010e, 0x00000000}},  //   _timm, _ערלי, jula_,
  { {0xbf4d00b9, 0xcefd0095, 0x00000000, 0x00000000}},  //   _šířk, üğün_,   ,
  { {0xfbcf0380, 0x7cd10089, 0x6f6601ff, 0x00000000}},  //   رتي_, _pārc, _уваз,
  { {0x27e910c9, 0x7f3b0049, 0x29050258, 0x00000000}},  //   _sean_, _געמו, fula_,
  { {0x29052e2b, 0x6e9301f7, 0x6da606b4, 0x00000000}},  //   gula_, _علما, _امام,
  { {0xc86716c4, 0x6ca60070, 0x486702dc, 0x00000000}},  //   стои, _اصطل, съоб,
  { {0x27e9097a, 0x25a4006b, 0xac970025, 0x00000000}},  //   _vean_, əmli_, _اننا_,
  { {0x2905011c, 0x3cef0061, 0x80d90044, 0x00000000}},  //   bula_, ींचे_, _ডিস্,
  { {0x29050779, 0x27e9006c, 0x280400b9, 0x00000000}},  //   cula_, _tean_, ásné_,
  { {0x81c00044, 0x73d900ed, 0x985d0036, 0x00000000}},  //   ীরা_, рдар_, _błąd_,
  { {0x325500da, 0x672d0020, 0x26c10825, 0x00000000}},  // [8c30] овар, _usaj, _tiho_,
  { {0xf8c90082, 0x98bf0006, 0x6a64000a, 0x00000000}},  //   _mẩn_, tytė_, _mòfo,
  { {0xf8c90082, 0x50b90014, 0x00000000, 0x00000000}},  //   _lẩn_, لگرد_,   ,
  { {0x3e6b0056, 0x00000000, 0x00000000, 0x00000000}},  //   _møte_,   ,   ,
  { {0xddc501fb, 0x2905002d, 0x24890058, 0x00000000}},  //   обли, zula_, mnam_,
  { {0xdce8005d, 0x38690129, 0x787601c5, 0x00000000}},  //   _aydı, _llar_, ršvi,
  { {0xe80a02fb, 0x3869005f, 0xde940025, 0x00000000}},  //   _वाला_, _olar_, أجنب,
  { {0xf8c90011, 0x24891091, 0x5f740123, 0x00000000}},  //   _bẩn_, nnam_, _کافر,
  { {0xf8c90011, 0x29050022, 0x00000000, 0x00000000}},  //   _cẩn_, wula_,   ,
  { {0x3869010e, 0xf8c90082, 0x00000000, 0x00000000}},  //   _alar_, _dẩn_,   ,
  { {0xd82601fb, 0x386900ea, 0x00000000, 0x00000000}},  //   одни, _blar_,   ,
  { {0xe73a2c8c, 0x386905f7, 0x76450016, 0x00000000}},  //   аем_, _clar_, _anhy,
  { {0xda35007e, 0x248902b4, 0x00000000, 0x00000000}},  //   _меды, dnam_,   ,
  { {0x2489008f, 0x00000000, 0x00000000, 0x00000000}},  //   enam_,   ,   ,
  { {0x65c302dc, 0x1a9a0049, 0x00000000, 0x00000000}},  //   дбра, _דיסע,   ,
  { {0x60c90ebc, 0x044322c0, 0x9f4f000c, 0x00000000}},  //   _čemp, месн, yggð_,
  { {0xd4670113, 0x03a3004c, 0xc8890379, 0x00000000}},  // [8c40] ците_, дито, _دخول_,
  { {0xae0e007d, 0x00000000, 0x00000000, 0x00000000}},  //   _साधन_,   ,   ,
  { {0x7cf00051, 0x00000000, 0x00000000, 0x00000000}},  //   _mórá,   ,   ,
  { {0xdfd00426, 0xa06a01fc, 0x1b200044, 0x00000000}},  //   ريت_, јада_, বিতে_,
  { {0x6446005f, 0x81e90055, 0x00000000, 0x00000000}},  //   _inki, _যার_,   ,
  { {0x72c30057, 0xccfa003b, 0x00000000, 0x00000000}},  //   _обяз, аћи_,   ,
  { {0x68ed0036, 0x26120164, 0x00000000, 0x00000000}},  //   _ładn, _तानी_,   ,
  { {0x6ab2001c, 0x00000000, 0x00000000, 0x00000000}},  //   ँग्र,   ,   ,
  { {0x3ce90091, 0x69cf013e, 0x00000000, 0x00000000}},  //   ćava_, ěcen,   ,
  { {0x24890b41, 0x64460061, 0x22582e2c, 0x00000000}},  //   znam_, _lnki, _jork_,
  { {0x644600b0, 0x22580173, 0x765700e5, 0x00000000}},  //   _onki, _mork_, _roxy,
  { {0x0b46046c, 0x6f020035, 0x6a6400f6, 0x00000000}},  //   _мнен, oroc, _tòfo,
  { {0x24890087, 0xf8c90082, 0x00000000, 0x00000000}},  //   vnam_, _uẩn_,   ,
  { {0x2258022b, 0x64460036, 0x95c8005e, 0x00000000}},  //   _nork_, _anki, жута_,
  { {0x24890011, 0xd7fb00ed, 0x6f021e64, 0x00000000}},  //   tnam_, _куп_, hroc,
  { {0xd14b0167, 0x6f020832, 0x3869008a, 0x00000000}},  //   یشان_, kroc, _ular_,
  { {0x24890089, 0x22580146, 0x00000000, 0x00000000}},  // [8c50] rnam_, _bork_,   ,
  { {0x64460173, 0x93880451, 0x2489005b, 0x00000000}},  //   _enki, іста_, snam_,
  { {0x7ea400d4, 0x9c7c000a, 0x00000000, 0x00000000}},  //   còpi, _pwčl,   ,
  { {0xc95301ce, 0xd7af0061, 0x859a009b, 0x00000000}},  //   ומע_, _घराच, _לשתו,
  { {0x44291110, 0x22580784, 0xdf780088, 0x00000000}},  //   mea_, _fork_, обці_,
  { {0x44290459, 0x52242e2d, 0x26dc0049, 0x00000000}},  //   lea_, _офса, סקומ,
  { {0x3085004b, 0x00000000, 0x00000000, 0x00000000}},  //   _فلسف,   ,   ,
  { {0x4429000d, 0x6f02010f, 0x9f4401dc, 0x00000000}},  //   nea_, broc, _zemí_,
  { {0x4ea703f3, 0x225800ab, 0x00000000, 0x00000000}},  //   _држа, _york_,   ,
  { {0x4429006c, 0x28cf006e, 0x00000000, 0x00000000}},  //   hea_, _संदि,   ,
  { {0x44292e2e, 0xd9450069, 0x4ea40098, 0x00000000}},  //   kea_, чени, _црта,
  { {0x44292367, 0x00000000, 0x00000000, 0x00000000}},  //   jea_,   ,   ,
  { {0x4429022b, 0xeb8e01fb, 0x44f7002b, 0x00000000}},  //   dea_, _чи_, eħ_,
  { {0xc4c60054, 0x7c292e2f, 0xbb3a0104, 0x00000000}},  //   كترو, leer, _לעני,
  { {0xceb2012e, 0xc1aa03d7, 0x44292662, 0x00000000}},  //   גים_, _करेग, fea_,
  { {0x7c2908ce, 0x44290e64, 0x6f02048d, 0x00000000}},  //   neer, gea_, yroc,
  { {0x22582e30, 0xe3b100a1, 0x00000000, 0x00000000}},  // [8c60] _pork_, ہرے_,   ,
  { {0x69de0004, 0x7c290250, 0x44290009, 0x00000000}},  //   _õpet, heer, aea_,
  { {0x4429002d, 0x23660091, 0x7c29017d, 0x00000000}},  //   bea_, šoj_, keer,
  { {0x6f02029d, 0x22580038, 0x4429001a, 0x00000000}},  //   troc, _work_, cea_,
  { {0xbea60099, 0x22580066, 0x7c292e31, 0x00000000}},  //   падк, _tork_, deer,
  { {0x6f02059a, 0x00000000, 0x00000000, 0x00000000}},  //   rroc,   ,   ,
  { {0x629e016e, 0x6f0220d6, 0xf8c90082, 0x00000000}},  //   mopo, sroc, _bẩm_,
  { {0x6f0200f4, 0x3f6a0057, 0x7c290b20, 0x00000000}},  //   proc, _либо_, geer,
  { {0x20f800ca, 0x61ee0bce, 0xd00f03d6, 0x00000000}},  //   lči_, _kebl, _حلق_,
  { {0x4429119a, 0x61ee2e32, 0x2a6a0010, 0x00000000}},  //   zea_, _jebl, óbb_,
  { {0x7c2900b5, 0xe895008b, 0x61ee0036, 0x00000000}},  //   beer, дань, _mebl,
  { {0x7c2900b5, 0x4429002d, 0xb69b00c4, 0x00000000}},  //   ceer, xea_, grân,
  { {0xb8d302fb, 0x629e10d9, 0xbb490025, 0x00000000}},  //   _जी_, kopo, _وجهك_,
  { {0xcad700b6, 0x61ee0006, 0x442900e7, 0x00000000}},  //   _צוות_, _nebl, wea_,
  { {0x442922d5, 0x629e0062, 0x746b1320, 0x00000000}},  //   tea_, dopo, брав_,
  { {0x81e90055, 0x3e6b00ea, 0xd5b81c0a, 0x00000000}},  //   _যাই_, _møta_, яся_,
  { {0x44291305, 0xe7e303d7, 0x261a001c, 0x00000000}},  // [8c70] rea_, _क्या_, म्ही_,
  { {0xddc8012d, 0x63a602e7, 0x00000000, 0x00000000}},  //   _amdž, _dykn,   ,
  { {0x442923cc, 0x30150057, 0x61ee016e, 0x00000000}},  //   pea_, ддер, _debl,
  { {0x7c2900bb, 0x5ee10044, 0x00000000, 0x00000000}},  //   xeer, _নিবে,   ,
  { {0x7c29224a, 0x61ee10cf, 0x67f80010, 0x00000000}},  //   veer, _febl, lújí,
  { {0x61ee00c7, 0xc3320452, 0x7c292e33, 0x00000000}},  //   _gebl, _שום_, weer,
  { {0x7c292706, 0xf0aa0026, 0x38880010, 0x00000000}},  //   teer, ààà_, lőre_,
  { {0xccf800b9, 0x0b45026b, 0x69d80190, 0x00000000}},  //   _dvě_, днин, _afve,
  { {0x7c292e34, 0x06e20055, 0xa0c40025, 0x00000000}},  //   reer, _বিভি, _سيكو,
  { {0xe8f90001, 0x7c292706, 0x67240022, 0x00000000}},  //   оло_, seer, _rpij,
  { {0x382a01be, 0x672400b5, 0x7c29006c, 0x00000000}},  //   ожно_, _spij, peer,
  { {0x200f10b6, 0x6d412e35, 0x06e20044, 0x00000000}},  //   nggi_, _irla, _বিবি,
  { {0x28cf006e, 0xb69b00c4, 0x629e1519, 0x00000000}},  //   _संवि, rrân, yopo,
  { {0xa96901c0, 0x753c00b9, 0x9f4f009d, 0x00000000}},  //   _мила_, tvrz, gagé_,
  { {0x64a6008b, 0x845a00ed, 0xe5a3014d, 0x00000000}},  //   дава, орат_, вири,
  { {0x161f006e, 0x20f80087, 0x61ee2e36, 0x00000000}},  //   म्बर_, vči_, _sebl,
  { {0x60ce0498, 0x60dc1332, 0xf1fa03ab, 0x00000000}},  // [8c80] _subm, _strm, قعات_,
  { {0x7cd1001e, 0x452a01e0, 0x60ce00ab, 0x00000000}},  //   _pārl, _джон_, _pubm,
  { {0x629e1750, 0x85bb026c, 0x24f6007e, 0x00000000}},  //   ropo, _واپس_, _ўчор,
  { {0x61ee0c46, 0x629e0010, 0x7bcb0022, 0x00000000}},  //   _webl, sopo, _nggu,
  { {0x629e0059, 0x6d4100f8, 0x06e20044, 0x00000000}},  //   popo, _arla, _বিডি,
  { {0x442200f8, 0x7bcb0197, 0x200f02c9, 0x00000000}},  //   _hbk_, _aggu, aggi_,
  { {0xa06a00e3, 0x998500b9, 0x00000000, 0x00000000}},  //   _дава_, delů_,   ,
  { {0x7d0a010f, 0xe043025f, 0x29050bf8, 0x00000000}},  //   rufs, _инси, drla_,
  { {0x6d410577, 0xc5f40055, 0x29050026, 0x00000000}},  //   _erla, _জানা_, erla_,
  { {0xd90e00a6, 0x78a42e37, 0x5a34005e, 0x00000000}},  //   لیت_, _akiv, хнот,
  { {0x2905012d, 0x00000000, 0x00000000, 0x00000000}},  //   grla_,   ,   ,
  { {0x89d801b2, 0x00000000, 0x00000000, 0x00000000}},  //   _کوثر_,   ,   ,
  { {0x7ae0001c, 0x29050e32, 0x00000000, 0x00000000}},  //   qpmt, arla_,   ,
  { {0x1994008b, 0x78a40173, 0x44222e38, 0x00000000}},  //   _паля, _ekiv, _abk_,
  { {0xda65006d, 0x44220032, 0x200f000c, 0x00000000}},  //   _ثاني, _bbk_, yggi_,
  { {0x290c04cb, 0xf993009b, 0x9f4f009d, 0x00000000}},  //   muda_, _שרק_, sagé_,
  { {0x290c006c, 0x7c222e39, 0xe3b300a1, 0x00000000}},  // [8c90] luda_, _mbor, ئرز_,
  { {0xe3b00025, 0x44220032, 0x6a6400f6, 0x00000000}},  //   شرق_, _ebk_, _bòfi,
  { {0x290c05f9, 0x7c2200b9, 0x69dc000c, 0x00000000}},  //   nuda_, _obor, ðrey,
  { {0x41df02fb, 0x5f9503dc, 0xddd811af, 0x00000000}},  //   _प्रस, ниет, vivš,
  { {0x290c0020, 0x645d0035, 0x443b0249, 0x00000000}},  //   huda_, _iosi, mdq_,
  { {0x44390038, 0x7c221994, 0x290c20b9, 0x00000000}},  //   _has_, _abor, kuda_,
  { {0x44392e3a, 0x645d0235, 0x290c006c, 0x00000000}},  //   _kas_, _kosi, juda_,
  { {0x6285002b, 0x44391cc4, 0x645d0209, 0x00000000}},  //   liho, _jas_, _josi,
  { {0x443900d6, 0x99850224, 0x645d00b4, 0x00000000}},  //   _mas_, telů_, _mosi,
  { {0x44391718, 0xc33201f8, 0x78a401bf, 0x00000000}},  //   _las_, נוי_, _skiv,
  { {0x6d41010f, 0x290c0129, 0x60c92e3b, 0x00000000}},  //   _urla, guda_, _kiem,
  { {0x60c90006, 0x6285044e, 0xac190900, 0x00000000}},  //   _jiem, hiho, _ходу_,
  { {0x60c90219, 0x62851658, 0x38b20010, 0x00000000}},  //   _miem, kiho, gára_,
  { {0x78660219, 0x7c220465, 0x60c9002b, 0x00000000}},  //   _móvi, _zbor, _liem,
  { {0x44392e3c, 0x645d018e, 0x290c0095, 0x00000000}},  //   _bas_, _bosi, cuda_,
  { {0x7c3b2e3d, 0x60c90046, 0x44390bdb, 0x00000000}},  //   ndur, _niem, _cas_,
  { {0x44392e3e, 0x645d0027, 0x7c39018e, 0x00000000}},  // [8ca0] _das_, _dosi, _mawr,
  { {0xa79b01f8, 0x6aa1018e, 0xae0e03d7, 0x00000000}},  //   _משפח, nolf, _साइन_,
  { {0x26d2000b, 0x443901aa, 0x4422023a, 0x00000000}},  //   _huyo_, _fas_, _tbk_,
  { {0x60c909a4, 0x61e30279, 0x645d01a3, 0x00000000}},  //   _ciem, ınla, _gosi,
  { {0x60c90089, 0xe818013d, 0x765e1aa0, 0x00000000}},  //   _diem, _थाना_, _kopy,
  { {0x44201263, 0x44392893, 0x7c2200b9, 0x00000000}},  //   lfi_, _zas_, _sbor,
  { {0x44200026, 0x26d20058, 0x443915df, 0x00000000}},  //   ofi_, _luyo_, _yas_,
  { {0x8fa601fb, 0x4420006b, 0x290c016c, 0x00000000}},  //   _забе, nfi_, vuda_,
  { {0xddcf00b9, 0x7c39002b, 0x4420005b, 0x00000000}},  //   řešn, _dawr, ifi_,
  { {0x60c92e3f, 0x290c006c, 0x7c3b186c, 0x00000000}},  //   _ziem, tuda_, adur,
  { {0x7c220009, 0x7c390016, 0x27f2000a, 0x00000000}},  //   _tbor, _fawr, _beyn_,
  { {0x290c2c40, 0x7c22178c, 0x38b210fa, 0x00000000}},  //   ruda_, _ubor, tára_,
  { {0x44392e40, 0x645d001a, 0x26d20211, 0x00000000}},  //   _ras_, _rosi, _cuyo_,
  { {0x765e0038, 0x44392c1f, 0xb9060044, 0x00000000}},  //   _copy, _sas_, _পি_,
  { {0x44390a8d, 0xe80a001c, 0x44200016, 0x00000000}},  //   _pas_, _वाचा_, ffi_,
  { {0x44390066, 0x68fa2e41, 0x00000000, 0x00000000}},  //   _qas_, mstd,   ,
  { {0x443901d9, 0xe4ed013d, 0x60c91015, 0x00000000}},  // [8cb0] _vas_, _जबकि_, _riem,
  { {0x44390a8a, 0x60c90219, 0x69da001a, 0x00000000}},  //   _was_, _siem, ncte,
  { {0x44392e42, 0x60c92e43, 0x645d021e, 0x00000000}},  //   _tas_, _piem, _tosi,
  { {0x44392a9b, 0x81e90044, 0x628503b6, 0x00000000}},  //   _uas_, _যাও_, siho,
  { {0x6e3a1794, 0x6285050f, 0x60c91747, 0x00000000}},  //   _batb, piho, _viem,
  { {0x6e3a01d6, 0x68fa00ea, 0x60c90036, 0x00000000}},  //   _catb, kstd, _wiem,
  { {0x60c90219, 0x6e3a018e, 0x6aa10026, 0x00000000}},  //   _tiem, _datb, volf,
  { {0xdd8e0054, 0x20d7005a, 0x6aa101d6, 0x00000000}},  //   توى_, _içi_, wolf,
  { {0x7c3b12fc, 0xaed50088, 0x7cd10089, 0x00000000}},  //   rdur, _розш, _māri,
  { {0x39452e44, 0x6a86009d, 0x7c3b194f, 0x00000000}},  //   вног, _réfè, sdur,
  { {0x44202e45, 0x26d22e46, 0x6aa10146, 0x00000000}},  //   yfi_, _suyo_, rolf,
  { {0xcc140431, 0x26d20058, 0x765e0022, 0x00000000}},  //   _مذهب, _puyo_, _sopy,
  { {0x6c7a0049, 0x2cbf010e, 0x00000000, 0x00000000}},  //   _קאנפ, mmud_,   ,
  { {0x2cad0038, 0x7afb2e47, 0x2cbf0695, 0x00000000}},  //   lled_, msut, lmud_,
  { {0x4420002b, 0x7afb074d, 0x00000000, 0x00000000}},  //   tfi_, lsut,   ,
  { {0xb4ac01f5, 0x26d20dfb, 0x64be007d, 0x00000000}},  //   गते_, _tuyo_, ्देश,
  { {0xe3630264, 0x4420009f, 0x7afb1d43, 0x00000000}},  // [8cc0] акти, rfi_, nsut,
  { {0x2cad0224, 0x2cbf200f, 0x09c50044, 0x00000000}},  //   hled_, hmud_, _শ্যা,
  { {0xa3ea041f, 0x6e3a01f3, 0xf48700a1, 0x00000000}},  //   _одна_, _ratb, راہی,
  { {0x7afb0103, 0x2482023a, 0x6e3a00d9, 0x00000000}},  //   ksut, _umkm_, _satb,
  { {0x44fe010a, 0x2cad0016, 0xe3b202fd, 0x00000000}},  //   lį_, dled_, _خرد_,
  { {0x2cad002b, 0x24920832, 0x3860009d, 0x00000000}},  //   eled_, lnym_, _loir_,
  { {0x44fe010a, 0x2cad1ad0, 0x6e3a0328, 0x00000000}},  //   nį_, fled_, _vatb,
  { {0x2cad0f3a, 0x386000f4, 0x24922e48, 0x00000000}},  //   gled_, _noir_, nnym_,
  { {0x1fa70088, 0x38b90010, 0xcc330025, 0x00000000}},  //   _акти_, nére_, شريع,
  { {0x44fe0006, 0xf8ca0082, 0x2ca601d6, 0x00000000}},  //   kį_, _mẩu_, _wkod_,
  { {0xd6e20055, 0x2cad00ab, 0xf8ca0082, 0x00000000}},  //   _বিষয, bled_, _lẩu_,
  { {0x68fa054e, 0xb4ac0061, 0x24920036, 0x00000000}},  //   rstd, गतो_, jnym_,
  { {0xf8bf00f4, 0x7f420f57, 0x24920832, 0x00000000}},  //   rmé_, nvoq, dnym_,
  { {0x7aed0279, 0x7f422e49, 0xb7e3006e, 0x00000000}},  //   _çata, ivoq, _क्रम_,
  { {0x7cd10089, 0x387202e1, 0x758801ab, 0x00000000}},  //   _pāri, _flyr_, вств_,
  { {0x4815017f, 0x3a3c0022, 0x2b4600d2, 0x00000000}},  //   _смис, _havp_, _kroc_,
  { {0xf8ca0082, 0x38b90010, 0x00000000, 0x00000000}},  // [8cd0] _cẩu_, gére_,   ,
  { {0x7afd2e4a, 0x7ae2000b, 0x291e095f, 0x00000000}},  //   ásti, _mtot, otta_,
  { {0xdfd10054, 0x2cad0ca4, 0xc1a400e2, 0x00000000}},  //   ميا_, yled_, ајци,
  { {0x7ae22c38, 0x249214a6, 0x00000000, 0x00000000}},  //   _otot, cnym_,   ,
  { {0x2489007f, 0x9ac4002b, 0x2cad0146, 0x00000000}},  //   miam_, _kaċċ, vled_,
  { {0x24890c6e, 0x6b8d11cb, 0x9ac4002b, 0x00000000}},  //   liam_, _žago, _jaċċ,
  { {0x2cad2179, 0xc21200b6, 0x261b0204, 0x00000000}},  //   tled_, _להם_, _बानी_,
  { {0x39491e90, 0x24890dc6, 0x7afb0ac2, 0x00000000}},  //   _čas_, niam_, tsut,
  { {0x2cad0186, 0x291e0625, 0x7c3101ee, 0x00000000}},  //   rled_, etta_, _čerč,
  { {0x386000f4, 0x7afb2e4b, 0x60d509fc, 0x00000000}},  //   _soir_, rsut, _kuzm,
  { {0x7afb05ad, 0xe73c011f, 0x24890006, 0x00000000}},  //   ssut, _küçü, kiam_,
  { {0x7c84005e, 0x2369014a, 0x66e6007c, 0x00000000}},  //   _куче, kyaj_, лома,
  { {0x3860028c, 0x7e61002d, 0x24892e4c, 0x00000000}},  //   _voir_, _kolp, diam_,
  { {0x644f032c, 0x24920036, 0x44fe0006, 0x00000000}},  //   _anci, wnym_, tį_,
  { {0x24920871, 0x062600a1, 0x24892e4d, 0x00000000}},  //   tnym_, نےکی_, fiam_,
  { {0x38b90047, 0x44fe0006, 0x24890914, 0x00000000}},  //   tére_, rį_, giam_,
  { {0x24920871, 0x44fe0006, 0x9ac40066, 0x00000000}},  // [8ce0] rnym_, sį_, _faċċ,
  { {0xe7470fb3, 0x24920024, 0x44fe0006, 0x00000000}},  //   ções_, snym_, pį_,
  { {0x38b90047, 0x600a2e4e, 0x24892e4f, 0x00000000}},  //   sére_, енем_, biam_,
  { {0x24890e04, 0xd00f0025, 0xf8ca0082, 0x00000000}},  //   ciam_, كلم_, _tẩu_,
  { {0x443201a3, 0x7e611ecd, 0x7cd10089, 0x00000000}},  //   mey_, _bolp, _māru,
  { {0x7e610207, 0x443200ab, 0x291e2e50, 0x00000000}},  //   _colp, ley_, ytta_,
  { {0x7ae2179b, 0x60d5008e, 0xad260151, 0x00000000}},  //   _stot, _guzm, ارتو,
  { {0x2b460bd7, 0x44320038, 0x8c3d0035, 0x00000000}},  //   _proc_, ney_, toşa,
  { {0x2e160070, 0x33200066, 0xeb97003b, 0x00000000}},  //   _مباح, ntix_, лић_,
  { {0xc33300b6, 0x27e000f4, 0x7e610489, 0x00000000}},  //   צות_, _afin_, _golp,
  { {0x44320101, 0xc27b0049, 0x291e00b0, 0x00000000}},  //   key_, גריי, utta_,
  { {0x7cd1001e, 0x291e00b0, 0x2b46009d, 0x00000000}},  //   _pārv, rtta_, _troc_,
  { {0x24890181, 0x44320145, 0x39470007, 0x00000000}},  //   viam_, dey_, _erns_,
  { {0xbb3b007b, 0x24890046, 0x7ead0142, 0x00000000}},  //   _רעגי, wiam_, túpi,
  { {0x443201e5, 0xceb300a3, 0x27e00016, 0x00000000}},  //   fey_, מיש_, _ffin_,
  { {0x443200df, 0x3320002b, 0x00000000, 0x00000000}},  //   gey_, ftix_,   ,
  { {0x24890181, 0xf77302fd, 0xe3b00025, 0x00000000}},  // [8cf0] riam_, _داغ_, كرك_,
  { {0x6d482ad3, 0x7cd1001e, 0x200401f3, 0x00000000}},  //   _orda, _kārt, _admi_,
  { {0x7e610007, 0x6601000c, 0x4fd5007c, 0x00000000}},  //   _rolp, ólku, ажет,
  { {0x644f0197, 0x60c20058, 0x7cd10089, 0x00000000}},  //   _unci, gmom, _mārt,
  { {0x6d48018e, 0x64db001c, 0x61f50180, 0x00000000}},  //   _arda, _मंडळ, _tezl,
  { {0x26dc007b, 0x8d650404, 0x20040173, 0x00000000}},  //   עקומ, ивле, _edmi_,
  { {0xed590057, 0xbdf80076, 0x7e610197, 0x00000000}},  //   той_, ارها_, _volp,
  { {0xf0bb025a, 0x7e6100e0, 0x672d0ed9, 0x00000000}},  //   _سازش_, _wolp, _opaj,
  { {0x6d480569, 0x290c0211, 0x29180009, 0x00000000}},  //   _erda, erda_, àran_,
  { {0x4432005a, 0xa925007e, 0x38960089, 0x00000000}},  //   zey_, адол, tāro_,
  { {0x3ea7002b, 0xf9910054, 0x00000000, 0x00000000}},  //   mont_, تبة_,   ,
  { {0x18a60057, 0x92a60036, 0xf746007c, 0x00000000}},  //   рамм, _załą, аемо,
  { {0x44320007, 0xbca4023c, 0xa3d9007d, 0x00000000}},  //   vey_, _امني, ाशन_,
  { {0x4b7a007b, 0x44320e9e, 0xddc10089, 0x00000000}},  //   _באנו, wey_, _nolū,
  { {0x44320173, 0x33f604b6, 0xc6c3007e, 0x00000000}},  //   tey_, ичас, ійск,
  { {0x33202ab8, 0xfe7900b9, 0xd91a01ce, 0x00000000}},  //   ttix_, _stůl_, _סופל,
  { {0x7ae92e51, 0x3ea701aa, 0x44322bbf, 0x00000000}},  // [8d00] npet, kont_, rey_,
  { {0x14b80061, 0xf2df0011, 0x38b900f4, 0x00000000}},  //   _आठवण, _trân_, méra_,
  { {0x33200066, 0x7f49008e, 0xd10d0061, 0x00000000}},  //   stix_, _areq, ांगण_,
  { {0x03a601fb, 0x04462e52, 0xe61200a2, 0x00000000}},  //   _вимо, _темн, _اشک_,
  { {0x3ea72e53, 0x6d480091, 0x7d010190, 0x00000000}},  //   font_, _srda, _avls,
  { {0x60c200eb, 0x7f490023, 0x00000000, 0x00000000}},  //   smom, _dreq,   ,
  { {0x80c60061, 0x2056007e, 0x00000000, 0x00000000}},  //   िषदे, _ктар,   ,
  { {0xa06700d7, 0x6d48012d, 0x9c7c000a, 0x00000000}},  //   _каса_, _vrda, _etčn,
  { {0x7f49008d, 0xa0670517, 0x3ea7005b, 0x00000000}},  //   _greq, _тата_, bont_,
  { {0x7cd1001e, 0x3ea70035, 0x00000000, 0x00000000}},  //   _pārt, cont_,   ,
  { {0x672d0209, 0xfce30264, 0x6d48002d, 0x00000000}},  //   _spaj, _дохо, _urda,
  { {0x7cd10089, 0x00000000, 0x00000000, 0x00000000}},  //   _vārt,   ,   ,
  { {0x6280010a, 0xb7142e54, 0xab83003b, 0x00000000}},  //   _įmon, одящ, _мушк,
  { {0xb882000c, 0x00000000, 0x00000000, 0x00000000}},  //   _þína,   ,   ,
  { {0x2abb0097, 0xa5f81585, 0x3abb0104, 0x00000000}},  //   _שמוא, ресу_, _שמונ,
  { {0xb867025a, 0x57f5003b, 0x657a0045, 0x00000000}},  //   _خاتو, _упит, ùtha,
  { {0x672d00ca, 0x00000000, 0x00000000, 0x00000000}},  // [8d10] _upaj,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc5f200b6, 0x00000000, 0x00000000, 0x00000000}},  //   _מדי_,   ,   ,
  { {0x75360049, 0x6aa8005b, 0x00000000, 0x00000000}},  //   _פארד_, hodf,   ,
  { {0xc8d0001c, 0x442b00c4, 0x3ea71b8a, 0x00000000}},  //   _संघट, _ibc_, tont_,
  { {0x14b50061, 0x00000000, 0x00000000, 0x00000000}},  //   ंतवण,   ,   ,
  { {0x3ea7028c, 0x5d33026c, 0x1ee700a1, 0x00000000}},  //   ront_, تہائ, _چوری_,
  { {0x7f490617, 0x1ee702fd, 0x00000000, 0x00000000}},  //   _treq, _نوری_,   ,
  { {0x7cd1001e, 0x3ea70010, 0x442b01a3, 0x00000000}},  //   _pārs, pont_, _mbc_,
  { {0xfc3f01c8, 0x7ae90211, 0x7aed006b, 0x00000000}},  //   ží_, rpet, _çatm,
  { {0x7ae90198, 0x186a0920, 0x81a90055, 0x00000000}},  //   spet, гани_, খের_,
  { {0x442b0133, 0x7ae9051b, 0x31560049, 0x00000000}},  //   _nbc_, ppet, צירן_,
  { {0x3b0900d7, 0x00000000, 0x00000000, 0x00000000}},  //   _село_,   ,   ,
  { {0x442b2146, 0x78ad0107, 0x00000000, 0x00000000}},  //   _abc_, _ekav,   ,
  { {0xceb201f8, 0xd9c50044, 0xd5b20426, 0x00000000}},  //   פיל_, _শ্রম, سفر_,
  { {0x442b0011, 0x28d00316, 0x475a005e, 0x00000000}},  //   _cbc_, _सूचि, _броя_,
  { {0x04570025, 0x442b00bb, 0x00000000, 0x00000000}},  // [8d20] حلقة_, _dbc_,   ,
  { {0x442b00fa, 0x6f040027, 0x975b0049, 0x00000000}},  //   _ebc_, šick, _עדיט,
  { {0x442b2bd4, 0x236d002b, 0x64a6007e, 0x00000000}},  //   _fbc_, _żejt_, _гана,
  { {0x7c2b0009, 0x442b0145, 0xd91a0049, 0x00000000}},  //   _nbgr, _gbc_, טועל,
  { {0xb4c4013d, 0x00000000, 0x00000000, 0x00000000}},  //   एगी_,   ,   ,
  { {0xbea30517, 0x7c2b01a2, 0x644401c5, 0x00000000}},  //   пачк, _abgr, ldii,
  { {0x3ebe0082, 0xafe6004d, 0x7c2b0022, 0x00000000}},  //   _vhtt_, _гобл, _bbgr,
  { {0x6444010e, 0x61fe0095, 0x7a210173, 0x00000000}},  //   ndii, lapl, _lňtč,
  { {0x9e6500a1, 0x7cd10089, 0x3e79009d, 0x00000000}},  //   _ڈالن, _pārr, _sète_,
  { {0x9e650025, 0xc33300b6, 0x78ad2e55, 0x00000000}},  //   _والن, לוח_, _skav,
  { {0x6f0200f8, 0x00000000, 0x00000000, 0x00000000}},  //   lsoc,   ,   ,
  { {0xc19b007b, 0x13b00055, 0x2db70049, 0x00000000}},  //   רשטי, চেয়, _פלאן_,
  { {0x61fe01b6, 0x6f0200ea, 0xfaa6007c, 0x00000000}},  //   kapl, nsoc, _ладо,
  { {0x442b00c4, 0xeb070025, 0x00000000, 0x00000000}},  //   _sbc_, _اقوى_,   ,
  { {0xd49b00ed, 0x442b0145, 0xe5c4005e, 0x00000000}},  //   гра_, _pbc_, зсто,
  { {0xb4b3024c, 0x38b900f4, 0x629c0065, 0x00000000}},  //   टते_, méro_, _ajro,
  { {0xf2df0082, 0x00000000, 0x00000000, 0x00000000}},  // [8d30] _trâm_,   ,   ,
  { {0x61fe001c, 0x6f0200f8, 0x51f800a5, 0x00000000}},  //   gapl, dsoc, йную_,
  { {0x5559004d, 0x3e6b00ea, 0x00000000, 0x00000000}},  //   _таня_, _møtt_,   ,
  { {0xdd000224, 0x68e40062, 0x00000000, 0x00000000}},  //   štěn, _čidl,   ,
  { {0xd34100a1, 0x4429005b, 0x6f020606, 0x00000000}},  //   _تہذی, mfa_, gsoc,
  { {0x4429056d, 0x999e0047, 0x2c1b0316, 0x00000000}},  //   lfa_, hető_, _याहू_,
  { {0x44290051, 0x6cc52e56, 0x00000000, 0x00000000}},  //   ofa_, ойка,   ,
  { {0x44290016, 0x26d30181, 0x00000000, 0x00000000}},  //   nfa_, _lixo_,   ,
  { {0x290a0047, 0x442929fc, 0xeb99034b, 0x00000000}},  //   ában_, ifa_, рип_,
  { {0x090501fb, 0x4429005b, 0x00000000, 0x00000000}},  //   опон, hfa_,   ,
  { {0xdd9b041f, 0xa3d90164, 0x38960089, 0x00000000}},  //   _сша_, ाशा_, lāri_,
  { {0xc5e9019b, 0x44290846, 0x26d300d4, 0x00000000}},  //   _יד_, jfa_, _aixo_,
  { {0x7c29000c, 0x4429018e, 0x27ff000c, 0x00000000}},  //   mfer, dfa_, ðuna_,
  { {0x44292e57, 0x2243012d, 0x00000000, 0x00000000}},  //   efa_, _najk_,   ,
  { {0x61fe011f, 0x26d3004a, 0x261b00e8, 0x00000000}},  //   vapl, _dixo_, _बारी_,
  { {0x26d31ce5, 0x7416023c, 0x4429005b, 0x00000000}},  //   _eixo_, تورا, gfa_,
  { {0x61fe0c98, 0x26d30181, 0xc2e90025, 0x00000000}},  // [8d40] tapl, _fixo_, معلم_,
  { {0x44290093, 0x41b62d9a, 0x7ce70095, 0x00000000}},  //   afa_, осет, _kırd,
  { {0x27240b90, 0x61fe0095, 0x7c2900ea, 0x00000000}},  //   lön_, rapl, kfer,
  { {0x5ee10055, 0x7c2900b5, 0x61fe014a, 0x00000000}},  //   _নিজে, jfer, sapl,
  { {0xaf360076, 0xd00f0076, 0x7c29005b, 0x00000000}},  //   ترات, ئله_, dfer,
  { {0x999e0010, 0x6f02074e, 0x7c29010f, 0x00000000}},  //   zető_, rsoc, efer,
  { {0x7c291d23, 0x27240444, 0x7cd10089, 0x00000000}},  //   ffer, hön_, _pārp,
  { {0x61fc0286, 0x60c00058, 0x61e90521, 0x00000000}},  //   _herl, _uhmm, _đeli,
  { {0x272418ee, 0x61fc104b, 0x60dc19ae, 0x00000000}},  //   jön_, _kerl, _hurm,
  { {0x60dc014a, 0x5ee10044, 0x7c290035, 0x00000000}},  //   _kurm, _নিচে, afer,
  { {0x4429011f, 0x60dc109c, 0x00000000, 0x00000000}},  //   yfa_, _jurm,   ,
  { {0xab2a00e3, 0x60dc00ea, 0xd6e20044, 0x00000000}},  //   _вода_, _murm, _বিজয,
  { {0xd90e089d, 0xa09b007b, 0xaa462e58, 0x00000000}},  //   ریک_, שיכט, _медл,
  { {0x61fc00f8, 0xee2e013a, 0x00000000, 0x00000000}},  //   _nerl, енi_,   ,
  { {0x7e681071, 0x4429002b, 0x60dc00b0, 0x00000000}},  //   _modp, tfa_, _nurm,
  { {0xd5b8132a, 0x44290173, 0x61fc0048, 0x00000000}},  //   юся_, ufa_, _aerl,
  { {0x61fc033b, 0x44292e59, 0xb275064b, 0x00000000}},  // [8d50] _berl, rfa_, плаш,
  { {0x4eac0055, 0x4429098d, 0x656e0010, 0x00000000}},  //   গগুল, sfa_, ínhá,
  { {0x44290009, 0x2fd90025, 0x61fc1109, 0x00000000}},  //   pfa_, مواد_, _derl,
  { {0x60dc2e5a, 0x61fc01b5, 0x7e7a2e5b, 0x00000000}},  //   _durm, _eerl, _altp,
  { {0x61fc000c, 0x66c00039, 0x38690146, 0x00000000}},  //   _ferl, söke, _moar_,
  { {0x61fc1257, 0x60dc0253, 0x7aed2e5c, 0x00000000}},  //   _gerl, _furm, _çati,
  { {0xc694007b, 0xf3ff02d5, 0x7c29010f, 0x00000000}},  //   ואס_, _joão_, tfer,
  { {0x61e50016, 0x272400b0, 0x61fc01a2, 0x00000000}},  //   lchl, yön_, _zerl,
  { {0x7c2903d0, 0x61fc038c, 0x5f9401fb, 0x00000000}},  //   rfer, _yerl, _житт,
  { {0x61e50048, 0x7e6801c5, 0x62800006, 0x00000000}},  //   nchl, _godp, _įmok,
  { {0x7c2905e9, 0x61e50678, 0x00000000, 0x00000000}},  //   pfer, ichl,   ,
  { {0x6d41020c, 0x201d01d5, 0x7e6806b8, 0x00000000}},  //   _isla, ngwi_, _zodp,
  { {0xacaa009c, 0x3869000d, 0x31b80164, 0x00000000}},  //   _اپنے_, _doar_, _अर्ध,
  { {0x2cad01bb, 0xbb420849, 0x76450093, 0x00000000}},  //   loed_, _чешк, _cahy,
  { {0x27240ae4, 0xa9790049, 0x00000000, 0x00000000}},  //   sön_, _לאַכ,   ,
  { {0x61fc02e2, 0x2cad0016, 0x07a601e1, 0x00000000}},  //   _serl, noed_, _найн,
  { {0x61fc020c, 0xd467026b, 0x60dc006c, 0x00000000}},  // [8d60] _perl, чите_, _surm,
  { {0x6d410161, 0x2cad0abb, 0x60dc063f, 0x00000000}},  //   _osla, hoed_, _purm,
  { {0x61fc037f, 0xd5b0026c, 0x29050039, 0x00000000}},  //   _verl, _شہر_, nsla_,
  { {0xb4d802f4, 0x6d5c0009, 0x60dc0279, 0x00000000}},  //   ादी_, _àrai, _vurm,
  { {0x7e680387, 0x61fc0149, 0x6d41005d, 0x00000000}},  //   _podp, _terl, _asla,
  { {0x6446005f, 0x60dc0181, 0x29050089, 0x00000000}},  //   _haki, _turm, ksla_,
  { {0xdb070428, 0x628e0412, 0x644601a3, 0x00000000}},  //   _člán, _imbo, _kaki,
  { {0x64462e5d, 0xc19b009b, 0x2cad01b5, 0x00000000}},  //   _jaki, _השלי, goed_,
  { {0x6446066d, 0x6d410b32, 0x386900ea, 0x00000000}},  //   _maki, _esla, _roar_,
  { {0x6446000b, 0x3a0600a1, 0x9d46279d, 0x00000000}},  //   _laki, سکتی_, _незд,
  { {0xef1f01d5, 0x442200f8, 0x29050635, 0x00000000}},  //   ħżen_, _ock_, gsla_,
  { {0x6446006a, 0x3eae01e5, 0x44220ebd, 0x00000000}},  //   _naki, loft_, _nck_,
  { {0x61e52e5e, 0x24800065, 0x628e0039, 0x00000000}},  //   ychl, dhim_, _ombo,
  { {0x4422141b, 0x2c7100b9, 0x64462e5f, 0x00000000}},  //   _ack_, _rádi_, _aaki,
  { {0x6446006a, 0x76470030, 0x6d410026, 0x00000000}},  //   _baki, rdjy, _xsla,
  { {0x628e0489, 0xa8a4008b, 0x76450169, 0x00000000}},  //   _ambo, _прык, _wahy,
  { {0x644615f0, 0x320101dc, 0x27e9005b, 0x00000000}},  // [8d70] _daki, tahy_, _ifan_,
  { {0x8234035b, 0x44221440, 0xdbf2013e, 0x00000000}},  //   فرما, _eck_, dříz,
  { {0x7c222697, 0x44220030, 0x2509007a, 0x00000000}},  //   _ocor, _fck_, _برخی_,
  { {0x61e5001f, 0x628e0576, 0xdfd10b59, 0x00000000}},  //   schl, _embo, نيا_,
  { {0x2cad0116, 0x6d41012d, 0x00000000, 0x00000000}},  //   voed_, _ssla,   ,
  { {0x7c220e98, 0x64462e60, 0xed59072b, 0x00000000}},  //   _acor, _zaki, жок_,
  { {0xdd91026c, 0x644601a3, 0x27e9000c, 0x00000000}},  //   کوں_, _yaki, _ofan_,
  { {0xe81f02fb, 0x98720089, 0x14bf007d, 0x00000000}},  //   _भाषा_, kšā_, ्षिण,
  { {0x200d2e61, 0x1c420783, 0x2cad005b, 0x00000000}},  //   _idei_, тным, roed_,
  { {0xbdf8025a, 0x6f090387, 0x7c2204d2, 0x00000000}},  //   _فرما_, _ivec, _ecor,
  { {0x19c51734, 0xa969005e, 0x3896001e, 0x00000000}},  //   ьбом, цина_, kārt_,
  { {0x162003d7, 0x2905021a, 0x7d1c01e3, 0x00000000}},  //   _बाहर_, rsla_, _årsa,
  { {0xac180077, 0x7c3b00f4, 0x6446069b, 0x00000000}},  //   _хочу_, meur, _raki,
  { {0x6446110b, 0x7c3b00f4, 0x00000000, 0x00000000}},  //   _saki, leur,   ,
  { {0xceb201f8, 0x6446066d, 0x248003e7, 0x00000000}},  //   דים_, _paki, thim_,
  { {0x7c3b00f4, 0x38960089, 0x6f090253, 0x00000000}},  //   neur, tāru_, _ovec,
  { {0x64462e62, 0x2b4d0087, 0x628e003d, 0x00000000}},  // [8d80] _vaki, nvec_, _pmbo,
  { {0x64462e63, 0x2480008d, 0x7c3b03a4, 0x00000000}},  //   _waki, shim_, heur,
  { {0x64460046, 0x7c3b0250, 0x6f09008e, 0x00000000}},  //   _taki, keur, _avec,
  { {0x7c3b009d, 0x44220023, 0xa9270062, 0x00000000}},  //   jeur, _uck_, _zaží,
  { {0x9c7c0182, 0x1eaa0025, 0x6f090521, 0x00000000}},  //   _juče, ياتي_, _cvec,
  { {0x7c2219eb, 0x44202e64, 0x628e2e65, 0x00000000}},  //   _scor, lgi_, _umbo,
  { {0x7c3b1de2, 0x44202e66, 0x38960089, 0x00000000}},  //   feur, ogi_, nārs_,
  { {0x442016c3, 0x7c3b00f4, 0x547b0049, 0x00000000}},  //   ngi_, geur, ַטיו,
  { {0x44202e67, 0xcf4602dc, 0x27e90022, 0x00000000}},  //   igi_, _юнай, _rfan_,
  { {0xf2df0035, 0x00000000, 0x00000000, 0x00000000}},  //   _grâu_,   ,   ,
  { {0x7c3b049b, 0x02170104, 0x1958007e, 0x00000000}},  //   beur, וחים_, чаны_,
  { {0x3eb90089, 0x7c3b009d, 0x00000000, 0x00000000}},  //   _īsti_, ceur,   ,
  { {0x3f862e68, 0xab9a0070, 0x00000000, 0x00000000}},  //   nzou_, _بخار_,   ,
  { {0xf98f089d, 0x64830004, 0xddda0224, 0x00000000}},  //   ابی_, _kõig, _potř,
  { {0x08f70647, 0x7ce7014a, 0x443b0a89, 0x00000000}},  //   _قريب_, _kıra, teq_,
  { {0x442005d3, 0x261b0309, 0x629e0052, 0x00000000}},  //   ggi_, _बाकी_, enpo,
  { {0x439403f3, 0x66c00073, 0x6483006c, 0x00000000}},  // [8d90] ватс, söka, _lõig,
  { {0x629e243c, 0x33290066, 0xa3ce0164, 0x00000000}},  //   gnpo, rtax_, षेध_,
  { {0x332901d5, 0x2eed01d6, 0x7c3b0923, 0x00000000}},  //   stax_, _stef_, yeur,
  { {0x8c3d001a, 0xf8ca0082, 0x629e00e7, 0x00000000}},  //   noşt, _bẩy_, anpo,
  { {0xb4bd03d7, 0x7c3b2e69, 0xa3b6007d, 0x00000000}},  //   ेगी_, veur, _चुप_,
  { {0x171c0049, 0x00000000, 0x00000000, 0x00000000}},  //   קווע,   ,   ,
  { {0x7ce7011f, 0x7c3b032c, 0x7bc20e6d, 0x00000000}},  //   _bıra, teur, _azou,
  { {0x0b4500da, 0x7c94007e, 0x88bd00b9, 0x00000000}},  //   енин, крыц, stěj,
  { {0x6f090521, 0x7c3b00f4, 0xf2df0011, 0x00000000}},  //   _uvec, reur, _trâu_,
  { {0x7c3b110a, 0xdb0e0051, 0xaa4500ed, 0x00000000}},  //   seur, ádál, хеол,
  { {0x64db0061, 0x49990a1e, 0x7c3b009d, 0x00000000}},  //   _मंगळ, ятия_, peur,
  { {0x9c7c00d0, 0x00000000, 0x00000000, 0x00000000}},  //   _puče,   ,   ,
  { {0x4420005d, 0xd5b80089, 0xf8ca0082, 0x00000000}},  //   vgi_, ļām_, _xẩy_,
  { {0x9c7c11af, 0x389601c5, 0x00000000, 0x00000000}},  //   _vuče, tārs_,   ,
  { {0x44202e6a, 0x81e50044, 0x3f861575, 0x00000000}},  //   tgi_, নরা_, zzou_,
  { {0x0443003b, 0x69c30119, 0x44202e6b, 0x00000000}},  //   лесн, _izne, ugi_,
  { {0x44202e6c, 0x22160745, 0xb89b009b, 0x00000000}},  // [8da0] rgi_, ефер, _מבקש,
  { {0x442010fd, 0xc7d7009b, 0x63790088, 0x00000000}},  //   sgi_, _אופי_, єстр_,
  { {0x7cd1001e, 0x66c000b0, 0x44200056, 0x00000000}},  //   _dārz, löko, pgi_,
  { {0x5f06003b, 0xfbc70d0b, 0x44fe00b9, 0x00000000}},  //   езда, _مت_, mů_,
  { {0x08e60055, 0xddc80036, 0x44fe00b9, 0x00000000}},  //   _কিছু_, łoże, lů_,
  { {0x7ce7047f, 0x78a40087, 0xf8ca0082, 0x00000000}},  //   _sıra, _ljiv, _vẩy_,
  { {0x44fe00b9, 0xddc10861, 0xc5f3009b, 0x00000000}},  //   nů_, _polš, נדה_,
  { {0xf8ca0011, 0x26da0247, 0x315700b3, 0x00000000}},  //   _tẩy_, _lipo_, _אילן_,
  { {0x8fa308fc, 0x44fe00b9, 0xddc1012d, 0x00000000}},  //   _бате, hů_, _volš,
  { {0xdee30265, 0xd90e00a6, 0x44fe00b9, 0x00000000}},  //   _софи, میت_, ků_,
  { {0x2d870046, 0x44fe00b9, 0xda210061, 0x00000000}},  //   czne_, jů_, _मारत_,
  { {0x44fe00b9, 0x6fd6005d, 0xc2f60044, 0x00000000}},  //   dů_, _gücü, _চিনি_,
  { {0x987406e7, 0xc6a70c96, 0x00000000, 0x00000000}},  //   уляц, ерви,   ,
  { {0x66c02e6d, 0xba2a28b7, 0x00000000, 0x00000000}},  //   sökn, _رستم_,   ,
  { {0x26da0022, 0x00000000, 0x00000000, 0x00000000}},  //   _dipo_,   ,   ,
  { {0x291e0035, 0xf9690088, 0x00000000, 0x00000000}},  //   muta_, _юрій_,   ,
  { {0x291e0207, 0x4814007c, 0xe3b303e6, 0x00000000}},  // [8db0] luta_, _смыс, ارز_,
  { {0x979c00b6, 0x64830004, 0x7ae200b0, 0x00000000}},  //   _משחק, _sõid, _muot,
  { {0x291e2e6e, 0xf1a70242, 0x7ae2021e, 0x00000000}},  //   nuta_, хран, _luot,
  { {0x26da0020, 0xc0780088, 0xe0d000a1, 0x00000000}},  //   _zipo_, нсії_, مزن_,
  { {0x54540b7b, 0x7ae20006, 0x645d130f, 0x00000000}},  //   _свят, _nuot, _insi,
  { {0x291e0020, 0x644d1395, 0x88bd00b9, 0x00000000}},  //   kuta_, ldai, stěh,
  { {0xd65801f8, 0x291e006c, 0xdea400a1, 0x00000000}},  //   תיות_, juta_, دیلی,
  { {0x644d00f4, 0x291e01bc, 0x4c35007e, 0x00000000}},  //   ndai, duta_, тэкт,
  { {0x7ae2201f, 0x5ba90152, 0x660700ca, 0x00000000}},  //   _cuot, ьким_, kajk,
  { {0x291e000b, 0xc332009b, 0x7ae20006, 0x00000000}},  //   futa_, סוי_, _duot,
  { {0x645d2e6f, 0x291e2e70, 0x60db0020, 0x00000000}},  //   _onsi, guta_, _kium,
  { {0x26da0173, 0x44fe00b9, 0x9b9200a2, 0x00000000}},  //   _sipo_, vů_, الیت,
  { {0x60c91a07, 0x644d0016, 0x26da05dd, 0x00000000}},  //   _mhem, ddai, _pipo_,
  { {0x645d002a, 0x291e2e71, 0x09e21364, 0x00000000}},  //   _ansi, buta_, _кошн,
  { {0xceb2012f, 0x291e001a, 0x69c309fc, 0x00000000}},  //   ייך_, cuta_, _uzne,
  { {0x26da11d1, 0x44fe00b9, 0x9c7c050f, 0x00000000}},  //   _wipo_, rů_, _kuča,
  { {0x44fe00b9, 0x6b8900d9, 0x00000000, 0x00000000}},  // [8dc0] sů_, nzeg,   ,
  { {0x645d2e72, 0x644d0051, 0x6285002b, 0x00000000}},  //   _ensi, adai, ghho,
  { {0x44e70011, 0x68e30181, 0xb60600ca, 0x00000000}},  //   _gõ_, _jund, rušč,
  { {0xc2f60044, 0x60db2e73, 0x644d01da, 0x00000000}},  //   _চিঠি_, _cium, cdai,
  { {0x1616001c, 0x68e32e74, 0x60db04bd, 0x00000000}},  //   _तयार_, _lund, _dium,
  { {0x7ae22e75, 0x291e0ee8, 0x60c9010f, 0x00000000}},  //   _ruot, yuta_, _ehem,
  { {0x60db0207, 0x6026005e, 0x569b0049, 0x00000000}},  //   _fium, _идва, ויסצ,
  { {0x291e1425, 0x9c7c00ca, 0x60c92e76, 0x00000000}},  //   vuta_, _buča, _ghem,
  { {0xeb97012b, 0x68e30d53, 0xcb070025, 0x00000000}},  //   кић_, _aund, نيين_,
  { {0x291e022b, 0x7ae227a3, 0x68e32e77, 0x00000000}},  //   tuta_, _vuot, _bund,
  { {0x2004008d, 0x644d018e, 0x68e3008e, 0x00000000}},  //   _kemi_, ydai, _cund,
  { {0x7ae2021e, 0x2004008d, 0x44e7001d, 0x00000000}},  //   _tuot, _jemi_, _rõ_,
  { {0x6b890046, 0x291e006c, 0x6d5c2e78, 0x00000000}},  //   czeg, suta_, _árab,
  { {0x27e00756, 0xd9540d0b, 0x68e32e79, 0x00000000}},  //   _egin_, _منتخ, _fund,
  { {0x44322e7a, 0x00000000, 0x00000000, 0x00000000}},  //   ffy_,   ,   ,
  { {0x44e7001d, 0xab63002b, 0x20042050, 0x00000000}},  //   _võ_, żżej, _nemi_,
  { {0x644d002a, 0x68e3007f, 0x60c92e7b, 0x00000000}},  // [8dd0] rdai, _zund, _rhem,
  { {0x60c9008d, 0xf8bf0353, 0x6d4801c3, 0x00000000}},  //   _shem, llé_, _osda,
  { {0x60db0197, 0x6b892e7c, 0x6483006c, 0x00000000}},  //   _pium, zzeg, _võib,
  { {0x645d010f, 0x33200129, 0xcfe9023c, 0x00000000}},  //   _unsi, buix_, رفته_,
  { {0x2004033b, 0x60db0020, 0xe8e00011, 0x00000000}},  //   _demi_, _vium, _ướt_,
  { {0x9c7c0091, 0xf8bf05d2, 0x672d0066, 0x00000000}},  //   _ruča, hlé_, _mqaj,
  { {0x60c903a1, 0x66050059, 0x2004108f, 0x00000000}},  //   _them, _mehk, _femi_,
  { {0x68e302cc, 0x660500b9, 0x6b89002d, 0x00000000}},  //   _rund, _lehk, tzeg,
  { {0xf8bf0062, 0x00000000, 0x00000000, 0x00000000}},  //   dlé_,   ,   ,
  { {0x68e320bb, 0x6b890036, 0x20042e7d, 0x00000000}},  //   _pund, rzeg, _zemi_,
  { {0x6b89108d, 0x7ce7014a, 0x20041baf, 0x00000000}},  //   szeg, _kırm, _yemi_,
  { {0x9b450188, 0x68e32370, 0xf8bf009d, 0x00000000}},  //   _منصو, _vund, glé_,
  { {0x68e3010f, 0x9cd600b6, 0xc7960783, 0x00000000}},  //   _wund, _עונה_, урны,
  { {0x68e30004, 0x6d5c0051, 0x2cbf010e, 0x00000000}},  //   _tund, _árac, llud_,
  { {0x68e32062, 0xc2240014, 0xf8bf009d, 0x00000000}},  //   _uund, یکسو, blé_,
  { {0xf8bf009d, 0x9c7c013e, 0x03e20044, 0x00000000}},  //   clé_, _lučn, বর্ণ,
  { {0x7413007a, 0x7ce7014a, 0x200401ed, 0x00000000}},  // [8de0] صولا, _sırl, _remi_,
  { {0xe3b70088, 0x09d70044, 0x38b90010, 0x00000000}},  //   убу_, _দ্যা, sért_,
  { {0x7a7a007b, 0xda7a0049, 0x7f49008e, 0x00000000}},  //   ערעס, ענער, _aseq,
  { {0xdee6012b, 0x50ba0014, 0xc483005c, 0x00000000}},  //   годи, رداد_, _глюк,
  { {0x3ae92e7e, 0x00000000, 0x00000000, 0x00000000}},  //   _núp_,   ,   ,
  { {0x91e3005e, 0x7d1c0cf5, 0x69dc0089, 0x00000000}},  //   _горе, _årsk, žrei,
  { {0x20042e7f, 0x7f490026, 0xf8bf2e80, 0x00000000}},  //   _temi_, _eseq, ylé_,
  { {0x115b0049, 0x3ae90011, 0x5b140745, 0x00000000}},  //   _אדלע, _búp_, амит,
  { {0x543b0049, 0x3ae90011, 0xc61c0044, 0x00000000}},  //   געפא, _cúp_, দ্যা_,
  { {0x386001c3, 0xfce62e81, 0x00000000, 0x00000000}},  //   _anir_, _божо,   ,
  { {0x09d70044, 0x02b70049, 0x8c26023c, 0x00000000}},  //   _দ্বা, רליך_, _مفاه,
  { {0x290c2e82, 0x2cbf0035, 0xf8bf009d, 0x00000000}},  //   rsda_, clud_, ulé_,
  { {0xf8bf00f4, 0x00000000, 0x00000000, 0x00000000}},  //   rlé_,   ,   ,
  { {0x672f0009, 0xe45f0039, 0x3ea00048, 0x00000000}},  //   rtcj, _snö_, éith_,
  { {0x45d500da, 0xf8bf2e83, 0x660501b1, 0x00000000}},  //   ровс, plé_, _vehk,
  { {0x660500b5, 0x77930014, 0x672d0066, 0x00000000}},  //   _wehk, _هیجا, _tqaj,
  { {0x660501c2, 0x00000000, 0x00000000, 0x00000000}},  // [8df0] _tehk,   ,   ,
  { {0xa15901a4, 0xa1ab10f3, 0x00000000, 0x00000000}},  //   казу_, нтез_,   ,
  { {0x9c7c1581, 0x7d1c03b1, 0xf77300a1, 0x00000000}},  //   _ručn, _årsh, _خاں_,
  { {0xb4fa007b, 0x7ce7006b, 0x4035003b, 0x00000000}},  //   _שפרי, _qırm, редс,
  { {0x44390197, 0x442b00e7, 0x24891ae9, 0x00000000}},  //   _ibs_, _icc_, mham_,
  { {0x644f0219, 0x24890181, 0x4439033b, 0x00000000}},  //   _haci, lham_, _hbs_,
  { {0x44392e84, 0x3ae90082, 0x644f266b, 0x00000000}},  //   _kbs_, _súp_, _kaci,
  { {0xaf3406c6, 0x24890181, 0x44392e85, 0x00000000}},  //   _گرفت, nham_, _jbs_,
  { {0x644f0036, 0xfd4c0011, 0x442b2e86, 0x00000000}},  //   _maci, _khiể, _mcc_,
  { {0x644f04bd, 0x7f840025, 0x44390133, 0x00000000}},  //   _laci, _الكن, _lbs_,
  { {0xf86617da, 0x4439003d, 0x442b004a, 0x00000000}},  //   авно, _obs_, _occ_,
  { {0x442b00f8, 0x443925fa, 0x31e60044, 0x00000000}},  //   _ncc_, _nbs_, _পড়াশ,
  { {0x66e60121, 0x9c7c0087, 0x24890133, 0x00000000}},  //   рога, _mučl, dham_,
  { {0x4439010f, 0x442b0011, 0xe9a800a1, 0x00000000}},  //   _abs_, _acc_, ئدین_,
  { {0x44390061, 0x644f0213, 0x442b0145, 0x00000000}},  //   _bbs_, _baci, _bcc_,
  { {0x3d0803d7, 0x386006c2, 0x442b2e87, 0x00000000}},  //   _सबसे_, _unir_, _ccc_,
  { {0x0206012b, 0x644f001a, 0xa206025f, 0x00000000}},  // [8e00] изан, _daci, ипад,
  { {0xe1f70902, 0x442b0207, 0x5eaa0055, 0x00000000}},  //   игу_, _ecc_, _চীনে,
  { {0x600a07ab, 0x3fe62337, 0x00000000, 0x00000000}},  //   внем_, ажев,   ,
  { {0x24890036, 0x92e40044, 0x5f1701f5, 0x00000000}},  //   cham_, _নবী_, _निश्_,
  { {0x24800f9f, 0x00000000, 0x00000000, 0x00000000}},  //   mkim_,   ,   ,
  { {0x644f0871, 0x8c46006b, 0x975700b3, 0x00000000}},  //   _zaci, mişə, יינו_,
  { {0x27f20016, 0x644f2e88, 0x44390093, 0x00000000}},  //   _ofyn_, _yaci, _ybs_,
  { {0x2480007f, 0xc0e3007c, 0x443900d4, 0x00000000}},  //   nkim_, _фотк, _xbs_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc333019b, 0x60c22e89, 0x25ad2e8a, 0x00000000}},  //   קות_, llom, şeli_,
  { {0x2d960147, 0xfc66005e, 0xc27b01ce, 0x00000000}},  //   _трас, _вълн, דריי,
  { {0x5faa0061, 0x60c20dd7, 0xdd7b0049, 0x00000000}},  //   _कशाल, nlom, _שטאל,
  { {0x07a4008b, 0x44390181, 0x2bd20164, 0x00000000}},  //   жаўн, _rbs_, देशा,
  { {0x644f003b, 0x4439014a, 0x6d5a2e8b, 0x00000000}},  //   _saci, _sbs_, _krta,
  { {0x44390606, 0x24190147, 0x24890133, 0x00000000}},  //   _pbs_, ловы_, tham_,
  { {0x6d5a0091, 0x26050061, 0x59f50014, 0x00000000}},  //   _mrta, वरही_, _پکیج_,
  { {0x644f2e8c, 0x24892e8d, 0x22840039, 0x00000000}},  // [8e10] _vaci, rham_, _söka_,
  { {0x6d5a047f, 0x442b0066, 0x24890145, 0x00000000}},  //   _orta, _wcc_, sham_,
  { {0x644f0fb2, 0x442b00c4, 0x24890082, 0x00000000}},  //   _taci, _tcc_, pham_,
  { {0x24802e8e, 0x60c2009d, 0x442b1c7e, 0x00000000}},  //   ckim_, glom, _ucc_,
  { {0xfd4c0011, 0x543a0049, 0xe8e00082, 0x00000000}},  //   _thiể, _גערא, _ngời_,
  { {0x44290004, 0x52850054, 0x7c390016, 0x00000000}},  //   lga_, _السك, _sbwr,
  { {0x44290051, 0x60c20190, 0x6d5a0091, 0x00000000}},  //   oga_, blom, _crta,
  { {0x291e0087, 0x00000000, 0x00000000, 0x00000000}},  //   drta_,   ,   ,
  { {0x291e0211, 0x6d5c0c38, 0x44290a0e, 0x00000000}},  //   erta_, _áran, iga_,
  { {0x8e740025, 0xf2d20049, 0x00000000, 0x00000000}},  //   _والض, ּעט_,   ,
  { {0xd945022a, 0xb4e603d7, 0x24802e8f, 0x00000000}},  //   щени, _पढे_, ykim_,
  { {0x44290450, 0x8c46006b, 0x9c7c0087, 0x00000000}},  //   jga_, yişə, _lučj,
  { {0x6d5a0521, 0x291e0051, 0x442900f8, 0x00000000}},  //   _zrta, arta_, dga_,
  { {0x7bcb0340, 0x4429006c, 0x60c22e90, 0x00000000}},  //   _izgu, ega_, zlom,
  { {0xe8f506f1, 0x24800340, 0xb6060e0d, 0x00000000}},  //   _استخ, tkim_, vršč,
  { {0x44292e91, 0xdb23000c, 0x628700d0, 0x00000000}},  //   gga_, _þróu, _aljo,
  { {0xf8b3012f, 0x24802e92, 0x7afb0032, 0x00000000}},  // [8e20] _משה_, rkim_, nput,
  { {0x44292e93, 0x24800213, 0x7c2901a2, 0x00000000}},  //   aga_, skim_, hger,
  { {0xc693009b, 0x27ed0340, 0x7afb0022, 0x00000000}},  //   _מאז_, žene_, hput,
  { {0x63a90253, 0x7c2900bb, 0x53a60888, 0x00000000}},  //   _žene, jger, _гамб,
  { {0x8c46006b, 0x60c20093, 0x6d5a016c, 0x00000000}},  //   qişə, rlom, _srta,
  { {0x44ee001d, 0xacf802e9, 0x60c200b0, 0x00000000}},  //   _ký_, анку_, slom,
  { {0x7c292e94, 0x629e1fc7, 0x00000000, 0x00000000}},  //   fger, mipo,   ,
  { {0x7c292708, 0x629e000b, 0x22510009, 0x00000000}},  //   gger, lipo, _zazk_,
  { {0x44ee001d, 0xeaf7007a, 0x320a0027, 0x00000000}},  //   _lý_, یریت_, _keby_,
  { {0x3914005e, 0xaa66005c, 0x3377009b, 0x00000000}},  //   омор, стик, צעים_,
  { {0x44ee009f, 0x6d5a022b, 0x44291d0c, 0x00000000}},  //   _ný_, _urta, yga_,
  { {0xc173009b, 0x00000000, 0x00000000, 0x00000000}},  //   לחת_,   ,   ,
  { {0x9c7c050f, 0x629e0176, 0xeb330167, 0x00000000}},  //   _lučk, kipo, _فروخ,
  { {0x291e0059, 0x25580173, 0x8bd700b3, 0x00000000}},  //   prta_, _bčl_, _הודו_,
  { {0x787f0065, 0x7a5301f7, 0x629e0ec2, 0x00000000}},  //   _lëvi, _رضوا, dipo,
  { {0xcd020046, 0x44291a8a, 0x18a403f3, 0x00000000}},  //   mość_, uga_, _најм,
  { {0x44290149, 0x660e027e, 0x2458007c, 0x00000000}},  // [8e30] rga_, babk, щать_,
  { {0x5b7b007b, 0x44290058, 0x9c7c00ca, 0x00000000}},  //   ארמא, sga_, _bučk,
  { {0xcd020046, 0x320a0685, 0x442900ea, 0x00000000}},  //   ność_, _deby_, pga_,
  { {0x33200606, 0xf8c9006e, 0xdbd900c4, 0x00000000}},  //   brix_, रतिय, nção,
  { {0x3f690407, 0x629e010e, 0x320a0022, 0x00000000}},  //   рило_, bipo, _feby_,
  { {0xcd020036, 0xee380088, 0x629e00c4, 0x00000000}},  //   kość_, йні_, cipo,
  { {0x7bc22e95, 0x00000000, 0x00000000, 0x00000000}},  //   _ayou,   ,   ,
  { {0x6aa81016, 0x7c290129, 0x7f5b1396, 0x00000000}},  //   endf, uger, _truq,
  { {0x15fb01f5, 0x200f0217, 0x68ea01a2, 0x00000000}},  //   ्रार_, magi_, _aufd,
  { {0x7afb2e96, 0x7c29010f, 0x78ad01c2, 0x00000000}},  //   rput, sger, _ajav,
  { {0x68460888, 0xddab007c, 0x9f46000c, 0x00000000}},  //   онна, _стал_, lboð_,
  { {0x200f0004, 0x6d410ca4, 0xfd100025, 0x00000000}},  //   nagi_, _ipla, _أجل_,
  { {0x61c60201, 0x3b092e97, 0xc1c60164, 0x00000000}},  //   _वर्ष, _тело_, _वर्ग,
  { {0x200f006a, 0x96ba078e, 0x629e00e5, 0x00000000}},  //   hagi_, руму_, xipo,
  { {0x649a007e, 0xa50a00e3, 0x200f006c, 0x00000000}},  //   атар_, реба_, kagi_,
  { {0x07a60088, 0x7ae32e98, 0x200f1d73, 0x00000000}},  //   _майн, _hint, jagi_,
  { {0x200f0004, 0x629e011c, 0x8c3d005f, 0x00000000}},  // [8e40] dagi_, tipo, mişd,
  { {0x7ae301d5, 0x6d411c72, 0x66c01361, 0x00000000}},  //   _jint, _opla, töku,
  { {0x629e1bbf, 0x4fea005e, 0xb5ca0014, 0x00000000}},  //   ripo, амен_, _خودم_,
  { {0x69c32e99, 0x7ae30281, 0x9c7c0107, 0x00000000}},  //   _myne, _lint, _vučk,
  { {0x6d410006, 0x7ae32e9a, 0x69c3123c, 0x00000000}},  //   _apla, _oint, _lyne,
  { {0x7ae3002d, 0x68e42e9b, 0xddc10059, 0x00000000}},  //   _nint, _liid, _dolž,
  { {0x200f023a, 0x629c0022, 0xa2b9006e, 0x00000000}},  //   bagi_, _imro, ्तर्,
  { {0x68e417f9, 0x7ae3002d, 0x7aeb119d, 0x00000000}},  //   _niid, _aint, _bugt,
  { {0xcd020046, 0x7ae304cb, 0xc4d3009b, 0x00000000}},  //   wość_, _bint, וגה_,
  { {0x7ae30127, 0xd90e06c6, 0x5a3400e3, 0x00000000}},  //   _cint, نیت_, чнот,
  { {0x7ae3000d, 0x69c30016, 0x6483006c, 0x00000000}},  //   _dint, _cyne, _sõim,
  { {0x7ae31359, 0x8c460057, 0x57f40265, 0x00000000}},  //   _eint, _феде, мпют,
  { {0x629c00b5, 0x7ae30197, 0x68e404be, 0x00000000}},  //   _omro, _fint, _diid,
  { {0x64830004, 0x7ae30006, 0x69c31c26, 0x00000000}},  //   _võim, _gint, _fyne,
  { {0xd49b017f, 0x69c30161, 0x29111580, 0x00000000}},  //   ара_, _gyne, ázat_,
  { {0xd7fb0265, 0x7ae3114c, 0x9c7c007f, 0x00000000}},  //   _тук_, _zint, _buči,
  { {0x27e92e9c, 0x533402dc, 0xd251009e, 0x00000000}},  // [8e50] _igan_, метт, ٹنا_,
  { {0x64830004, 0xf2c7007e, 0x9c7c0521, 0x00000000}},  //   _kõik, ісан, _duči,
  { {0x75830167, 0x200f010e, 0x8c3d014a, 0x00000000}},  //   _غیرم, tagi_, lişe,
  { {0x92ab0055, 0xa2cb007d, 0x66c00039, 0x00000000}},  //   খতে_, _तीर्, sökt,
  { {0x6483006c, 0x200f065d, 0x6d412e9d, 0x00000000}},  //   _lõik, ragi_, _spla,
  { {0xfce504b6, 0x200f0fb4, 0x6d4102c0, 0x00000000}},  //   поко, sagi_, _ppla,
  { {0x7ae300b0, 0x8c3d006b, 0x27e90093, 0x00000000}},  //   _rint, yişd, _ogan_,
  { {0x27e90127, 0x69c30036, 0x62850168, 0x00000000}},  //   _ngan_, _ryne, lkho,
  { {0x69c30378, 0xdd91026c, 0x68e401c2, 0x00000000}},  //   _syne, بوں_, _riid,
  { {0x62850232, 0x27e90093, 0xee780025, 0x00000000}},  //   nkho, _agan_, _وصلت_,
  { {0x8c3d006b, 0x527c0049, 0x00000000, 0x00000000}},  //   tişd, ינזא,   ,
  { {0x7aeb2e9e, 0x7cd9007c, 0xdb390014, 0x00000000}},  //   _tugt, _умер_, _هستش_,
  { {0x7ae3002b, 0x69c3018e, 0x7c3b2062, 0x00000000}},  //   _tint, _wyne, mfur,
  { {0x7c3b01e5, 0x9c7c04c8, 0x27e91624, 0x00000000}},  //   lfur, _ruči, _egan_,
  { {0x2ee50061, 0xf48402fd, 0x68e4010e, 0x00000000}},  //   _milf_, واری, _tiid,
  { {0x7c3b2e9f, 0x63a9049c, 0x7ce7014a, 0x00000000}},  //   nfur, _žena, _hırs,
  { {0x46a60140, 0x0326007e, 0x6aa10048, 0x00000000}},  // [8e60] _наив, ядан, oilf,
  { {0x9c7c12d6, 0x7ce7026d, 0x00000000, 0x00000000}},  //   _vuči, _yırt,   ,
  { {0x867b009b, 0x66c00039, 0xf67b009b, 0x00000000}},  //   _הריו, söks, _האימ,
  { {0x6aa1010f, 0xd12f03ec, 0x00000000, 0x00000000}},  //   hilf, طمه_,   ,
  { {0xd00f06f1, 0xdce3007f, 0x2ee5005b, 0x00000000}},  //   اله_, lynė, _bilf_,
  { {0x62850073, 0x216a013b, 0x629c0093, 0x00000000}},  //   ckho, _лиги_, _umro,
  { {0x61430551, 0x7c3b2ea0, 0x6aa101a3, 0x00000000}},  //   _пера, ffur, dilf,
  { {0xd00f0025, 0x00000000, 0x00000000, 0x00000000}},  //   _ملف_,   ,   ,
  { {0x769000b0, 0x78bd2ea1, 0x7ce7014a, 0x00000000}},  //   _käyd, vosv, _sırt,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe8e00011, 0x6f09010f, 0xd05c006b, 0x00000000}},  //   _ngồi_, _zwec, _surə,
  { {0xab2a0783, 0x64830004, 0xd90e0014, 0x00000000}},  //   _года_, _võik, پیک_,
  { {0xac970025, 0x7ce7014a, 0x6383000c, 0x00000000}},  //   _عنها_, _fırs, _mínú,
  { {0x7bdb00a0, 0x00000000, 0x00000000, 0x00000000}},  //   _הקדו,   ,   ,
  { {0x9412006b, 0x7e7a02e1, 0x78bd0010, 0x00000000}},  //   liyə_, _motp, posv,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x38690051, 0x9412006b, 0x00000000, 0x00000000}},  // [8e70] _inar_, niyə_,   ,
  { {0x09e00055, 0x7e7a00ca, 0xf8bf009d, 0x00000000}},  //   _ম্যা, _notp, loé_,
  { {0x628500bb, 0xc5fb007d, 0x00000000, 0x00000000}},  //   rkho, ्रीय_,   ,
  { {0xdbf100b9, 0x00000000, 0x00000000, 0x00000000}},  //   třík,   ,   ,
  { {0x3dc5018e, 0x00000000, 0x00000000, 0x00000000}},  //   _sylw_,   ,   ,
  { {0x6e940457, 0x9412006b, 0x00000000, 0x00000000}},  //   ничу, diyə_,   ,
  { {0x3015025f, 0x38690032, 0xa28200a1, 0x00000000}},  //   _одвр, _onar_, _جیلو,
  { {0xdbf100b9, 0x7e6805af, 0x00000000, 0x00000000}},  //   přík, _endp,   ,
  { {0x7c3b001a, 0x6aa1002b, 0xcd4500a1, 0x00000000}},  //   rfur, tilf, سپکٹ,
  { {0x386904bd, 0x66020521, 0x89a90920, 0x00000000}},  //   _anar_, _đoko, жков_,
  { {0x6fd90061, 0x38690022, 0x7d1c01c4, 0x00000000}},  //   बेरं, _bnar_, _årsp,
  { {0xc689007b, 0xe73a007c, 0x768b014a, 0x00000000}},  //   _דא_, оем_, _rüya,
  { {0x2cad0c78, 0x386900ca, 0xf3ff00fa, 0x00000000}},  //   mned_, _dnar_, _anão_,
  { {0x2cbf010f, 0xcb12009b, 0xdce30006, 0x00000000}},  //   loud_, _ילד_, tynė,
  { {0x66e30057, 0x2cad00ab, 0x00000000, 0x00000000}},  //   тора, oned_,   ,
  { {0x130a007e, 0x2cad00ab, 0x2cbf2ea2, 0x00000000}},  //   жнай_, nned_, noud_,
  { {0x2cad00ab, 0x03a3003b, 0x00000000, 0x00000000}},  // [8e80] ined_, вито,   ,
  { {0x2cbf049b, 0x0219008b, 0x00000000, 0x00000000}},  //   houd_, зіць_,   ,
  { {0x63a9009f, 0x2cbf01d6, 0x00000000, 0x00000000}},  //   _þenn, koud_,   ,
  { {0xd095007e, 0x7df801f5, 0x6d5c296d, 0x00000000}},  //   ншчы, ुर्ग_, _árai,
  { {0x7e7a0119, 0x769000b0, 0x7e68000a, 0x00000000}},  //   _potp, _täyd, _pndp,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x604401aa, 0x00000000, 0x00000000, 0x00000000}},  //   _pčmč,   ,   ,
  { {0x2cad00ab, 0x2258002d, 0x2cbf1818, 0x00000000}},  //   gned_, _hark_, goud_,
  { {0x8c4300ec, 0x20060145, 0x7e7a00f6, 0x00000000}},  //   тење, mboi_, _totp,
  { {0x6f020211, 0xd0130044, 0xed4f00a1, 0x00000000}},  //   mpoc, _হায়_, دھے_,
  { {0x2258038f, 0x291806b8, 0x2cbf01d6, 0x00000000}},  //   _mark_, éra_, boud_,
  { {0x3b860131, 0x6483006c, 0x594200a1, 0x00000000}},  //   _олег, _hõiv, _یکجہ,
  { {0x27ed00b9, 0x00000000, 0x00000000, 0x00000000}},  //   ženo_,   ,   ,
  { {0x3b530088, 0x00000000, 0x00000000, 0x00000000}},  //   _шкір,   ,   ,
  { {0x7aef0027, 0x870900a1, 0x00000000, 0x00000000}},  //   íctv, _کعبہ_,   ,
  { {0x628e177c, 0x00000000, 0x00000000, 0x00000000}},  //   _albo,   ,   ,
  { {0x200600e0, 0x2258071e, 0x00000000, 0x00000000}},  // [8e90] dboi_, _bark_,   ,
  { {0x2cbf01aa, 0x1b000044, 0xdcee013e, 0x00000000}},  //   zoud_, _এটাই_, íděn,
  { {0x225800ab, 0x66150b79, 0x00000000, 0x00000000}},  //   _dark_, mazk,   ,
  { {0x8c3d005f, 0x628e0e69, 0x66152ea3, 0x00000000}},  //   kişa, _elbo, lazk,
  { {0x2258014a, 0x644d01b1, 0x00000000, 0x00000000}},  //   _fark_, meai,   ,
  { {0x8d550920, 0xed590081, 0x2cbf2ea4, 0x00000000}},  //   етич, зок_, woud_,
  { {0x20e8005d, 0x2b460bc0, 0x3f890006, 0x00000000}},  //   _işin_, _apoc_, šau_,
  { {0x44f52ad9, 0x24890d0a, 0x101700a1, 0x00000000}},  //   _må_, nkam_, _زبرد,
  { {0x2cbf01d6, 0x2cad00ab, 0x44f50637, 0x00000000}},  //   roud_, rned_, _lå_,
  { {0x17fa0164, 0x24890022, 0x2a7c00f6, 0x00000000}},  //   ूर्व_, hkam_, _covb_,
  { {0xa96900c0, 0x44f50bda, 0x66150032, 0x00000000}},  //   чина_, _nå_, dazk,
  { {0x6941016c, 0xf1b200a3, 0x00000000, 0x00000000}},  //   jćeš, רסט_,   ,
  { {0xeb8e0ad9, 0x644d0052, 0x00000000, 0x00000000}},  //   _си_, deai,   ,
  { {0x6615022b, 0x2006001a, 0x24890089, 0x00000000}},  //   gazk, zboi_, ekam_,
  { {0xceb2019b, 0x49bb007a, 0x04460216, 0x00000000}},  //   אים_, _باشد_, невн,
  { {0x44f51f82, 0x22580725, 0x644d009d, 0x00000000}},  //   _då_, _sark_, geai,
  { {0x225800ab, 0x00000000, 0x00000000, 0x00000000}},  // [8ea0] _park_,   ,   ,
  { {0x44f51861, 0x201f0d16, 0x20f301ee, 0x00000000}},  //   _få_, _adui_, _ećim_,
  { {0x44f505cb, 0xe5a6003b, 0x225801d6, 0x00000000}},  //   _gå_, _чини, _vark_,
  { {0x248911e4, 0x78a61332, 0x764e0146, 0x00000000}},  //   ckam_, nikv, leby,
  { {0xde580451, 0x2258006c, 0x3cfe2ea5, 0x00000000}},  //   далі_, _tark_, _sttv_,
  { {0x471b0049, 0x44320010, 0x764e0056, 0x00000000}},  //   לונג, lgy_, neby,
  { {0x6483006c, 0x52be006e, 0xd00a04b6, 0x00000000}},  //   _võiv, ्तीस, _неве_,
  { {0x7764049a, 0x44320142, 0x66150032, 0x00000000}},  //   _orix, ngy_, zazk,
  { {0x61f30023, 0x00000000, 0x00000000, 0x00000000}},  //   _çelë,   ,   ,
  { {0x60c20004, 0xd8f80088, 0x39470022, 0x00000000}},  //   loom, мної_, _bpns_,
  { {0x6f1b037e, 0xe895008b, 0x3947023a, 0x00000000}},  //   _zvuc, вань, _cpns_,
  { {0x44f524fd, 0x27ed043e, 0x60c2006c, 0x00000000}},  //   _rå_, øen_, noom,
  { {0x44f50945, 0x6615002d, 0xe7870088, 0x00000000}},  //   _så_, tazk, хуно,
  { {0x44f51aec, 0x36d50f40, 0x60c201c3, 0x00000000}},  //   _på_, тогр, hoom,
  { {0x66150266, 0x04670264, 0xfbb20044, 0x00000000}},  //   razk, нтам, _চরিত,
  { {0x3f860173, 0x3913005e, 0x776422d1, 0x00000000}},  //   kyou_, _смър, _frix,
  { {0xe8070164, 0x925900ed, 0x248910c2, 0x00000000}},  // [8eb0] _व्या_, маат_, rkam_,
  { {0x6d482ea6, 0x66d2000c, 0x7aea002b, 0x00000000}},  //   _opda, lækn, _jift,
  { {0x7aea01d5, 0x26c30006, 0x644d0016, 0x00000000}},  //   _mift, mojo_, peai,
  { {0x251a00b3, 0x26c31f51, 0xc1040439, 0x00000000}},  //   _קורא, lojo_, اوني,
  { {0x6d482ea7, 0x8416009b, 0x673d010e, 0x00000000}},  //   _apda, _בקרב_, ntsj,
  { {0x7aea002b, 0x26c30006, 0xddc8016c, 0x00000000}},  //   _nift, nojo_, _dodž,
  { {0xd658009b, 0x60c20116, 0x5ff5005e, 0x00000000}},  //   גיות_, boom, _азбу,
  { {0x2d510224, 0x764e0036, 0x27ed00ca, 0x00000000}},  //   _vše_, zeby, ženj_,
  { {0x9e15008b, 0x26c30006, 0x00000000, 0x00000000}},  //   _адзі, kojo_,   ,
  { {0x26c30006, 0x39470093, 0x7aea29d1, 0x00000000}},  //   jojo_, _ppns_, _cift,
  { {0xe9d90077, 0x69ca018e, 0x3ea70047, 0x00000000}},  //   ько_, _cyfe, mint_,
  { {0x64830004, 0x3ea70016, 0x98a6004c, 0x00000000}},  //   _mõis, lint_, тиме,
  { {0x2d871228, 0x7aea00ab, 0x768b014a, 0x00000000}},  //   lyne_, _fift, _tüyl,
  { {0x7aea098e, 0x3ea70129, 0x60c21fac, 0x00000000}},  //   _gift, nint_, zoom,
  { {0x69ca0bc4, 0x764e00eb, 0x31610061, 0x00000000}},  //   _gyfe, reby, jvhz_,
  { {0x29051d55, 0x77640007, 0x764e00f8, 0x00000000}},  //   mpla_, _trix, seby,
  { {0x753c0046, 0x443200ab, 0x78a41489, 0x00000000}},  // [8ec0] strz, rgy_, _imiv,
  { {0x64830004, 0x3f8601aa, 0x26c3004a, 0x00000000}},  //   _sõit, vyou_, cojo_,
  { {0x3ea72252, 0xfbc70014, 0x60c20961, 0x00000000}},  //   dint_, _چت_, toom,
  { {0xfbc713d9, 0xddc81332, 0x3f86000a, 0x00000000}},  //   _نت_, _podž, tyou_,
  { {0x60c22ea8, 0x64830004, 0x3ea72ea9, 0x00000000}},  //   room, _võit, fint_,
  { {0xeaa70025, 0x6d4800ea, 0x44220203, 0x00000000}},  //   _ضع_, _ppda, _hdk_,
  { {0x90c6007e, 0x7aea01e5, 0xdfd200a6, 0x00000000}},  //   _абве, _rift, _چيز_,
  { {0xdfd2007a, 0x69ca0016, 0x3ea70048, 0x00000000}},  //   _نيز_, _ryfe, aint_,
  { {0xee3a1ae1, 0x8c3d0279, 0xa03b0049, 0x00000000}},  //   _она_, mişl, _קעמפ,
  { {0x63a919f0, 0x3ea70051, 0x44222e92, 0x00000000}},  //   _ženk, cint_, _ldk_,
  { {0x6d480038, 0x66d2000c, 0x7aea02d8, 0x00000000}},  //   _upda, tækn, _vift,
  { {0x387f0359, 0xa9c301fb, 0x8c3d0279, 0x00000000}},  //   ður_, рськ, nişl,
  { {0x26c3010a, 0x7aea01d5, 0x66d20698, 0x00000000}},  //   tojo_, _tift, rækn,
  { {0x6d5c0a87, 0x78a40026, 0x442202c1, 0x00000000}},  //   _áras, _emiv, _adk_,
  { {0x26c32eaa, 0x673d06d9, 0x44220145, 0x00000000}},  //   rojo_, stsj, _bdk_,
  { {0x332902a9, 0x26c300ca, 0x998e000a, 0x00000000}},  //   trax_, sojo_, _jefō_,
  { {0x44220a9d, 0x00000000, 0x00000000, 0x00000000}},  // [8ed0] _ddk_,   ,   ,
  { {0x44220203, 0x00000000, 0x00000000, 0x00000000}},  //   _edk_,   ,   ,
  { {0x68ed0047, 0x3ea70129, 0x7c220a7e, 0x00000000}},  //   _kiad, vint_, _odor,
  { {0x64830004, 0x66020107, 0x5f9505f6, 0x00000000}},  //   _võis, _đoki, лиет,
  { {0x3ea700d4, 0x645d2eab, 0xfd640082, 0x00000000}},  //   tint_, _iasi, _truớ,
  { {0x645d0beb, 0x7c221729, 0x0ccb02fb, 0x00000000}},  //   _hasi, _ador, ात्म,
  { {0x645d027c, 0x41e401e1, 0x3ea70e69, 0x00000000}},  //   _kasi, _віта, rint_,
  { {0x799a0046, 0x3ea71aed, 0x645d0814, 0x00000000}},  //   dztw, sint_, _jasi,
  { {0x645d0149, 0x2d870007, 0x7c84003b, 0x00000000}},  //   _masi, syne_, рује,
  { {0x7c220032, 0x2d8701d6, 0x44390253, 0x00000000}},  //   _edor, pyne_, _lcs_,
  { {0x645d0145, 0x8c3d011f, 0x60db050c, 0x00000000}},  //   _oasi, lişm, _khum,
  { {0x645d0149, 0xe45f0039, 0x44391aa5, 0x00000000}},  //   _nasi, _skön_, _ncs_,
  { {0x7bcb011f, 0x68ed0169, 0x60db002b, 0x00000000}},  //   _uygu, _diad, _mhum,
  { {0x29050039, 0x645d2eac, 0x6b9b10a2, 0x00000000}},  //   ppla_, _aasi, mzug,
  { {0x44220065, 0x4439016b, 0x98a60035, 0x00000000}},  //   _pdk_, _bcs_, gulă_,
  { {0x64a32ead, 0xa3ea031b, 0x78a402aa, 0x00000000}},  //   баса, едба_, _umiv,
  { {0x6b892eae, 0x6b9b010f, 0x645d007f, 0x00000000}},  // [8ee0] nyeg, nzug, _dasi,
  { {0x44390f1d, 0x68ed0a13, 0x645d00ab, 0x00000000}},  //   _ecs_, _ziad, _easi,
  { {0x645d2974, 0x64a6003b, 0x44220169, 0x00000000}},  //   _fasi, _бана, _tdk_,
  { {0x60db2302, 0x645d0942, 0x44390048, 0x00000000}},  //   _chum, _gasi, _gcs_,
  { {0x8c3d005a, 0x69ca0309, 0x60db2176, 0x00000000}},  //   rişl, _सुनी, _dhum,
  { {0x645d05e1, 0x64b7012d, 0xb5ab00a1, 0x00000000}},  //   _zasi, nćin, _آئیے_,
  { {0x645d0020, 0x765e0020, 0x00000000, 0x00000000}},  //   _yasi, _mapy,   ,
  { {0x27ed0340, 0x63a9016e, 0x765e00e0, 0x00000000}},  //   ženi_, _ženi, _lapy,
  { {0x68ed0027, 0x2aaa003b, 0x79880016, 0x00000000}},  //   _riad, етно_, wydw,
  { {0x7c240089, 0x68ed1b42, 0x00000000, 0x00000000}},  //   _ķiru, _siad,   ,
  { {0x68ed0181, 0xaa6307d0, 0x98b40095, 0x00000000}},  //   _piad, стык, çeği_,
  { {0x6d5a2eaf, 0x2d950121, 0xeb9a05f6, 0x00000000}},  //   _ista, _трус, _пие_,
  { {0x443903e2, 0x2ca60030, 0x68ed0f07, 0x00000000}},  //   _rcs_, _imod_, _viad,
  { {0x68ed0046, 0x645d0f77, 0x765e0203, 0x00000000}},  //   _wiad, _sasi, _capy,
  { {0x645d1750, 0x4439023a, 0x58d50256, 0x00000000}},  //   _pasi, _pcs_, _кокт,
  { {0x24580077, 0x6d5a0518, 0x645d002b, 0x00000000}},  //   лась_, _msta, _qasi,
  { {0x645d0a89, 0x291e1759, 0x44390181, 0x00000000}},  // [8ef0] _vasi, lsta_, _vcs_,
  { {0x60db048a, 0x645d000b, 0x60c9009f, 0x00000000}},  //   _shum, _wasi, _skem,
  { {0x6d5a2eb0, 0x645d04cb, 0x7d0d016c, 0x00000000}},  //   _nsta, _tasi, ćask,
  { {0x291e06d5, 0x765e0036, 0x443900fa, 0x00000000}},  //   ista_, _zapy, _ucs_,
  { {0x8335007b, 0x6d5a1aba, 0x3ea50022, 0x00000000}},  //   _דאָס_, _asta, _pmlt_,
  { {0x291e0ba5, 0x6d5a0009, 0x2ca60016, 0x00000000}},  //   ksta_, _bsta, _amod_,
  { {0x60db0339, 0x6d5a01c3, 0x69ce2ba5, 0x00000000}},  //   _thum, _csta, übel,
  { {0x9f050014, 0x291e0039, 0x4c852eb1, 0x00000000}},  //   _نورو, dsta_, рлив,
  { {0x291e04bd, 0xeb990264, 0x00000000, 0x00000000}},  //   esta_, тип_,   ,
  { {0xea89005e, 0x7aa500e3, 0x39450088, 0x00000000}},  //   тбол_, риоз, аног,
  { {0xd945051f, 0xe807001c, 0x291e2eb2, 0x00000000}},  //   шени, _व्हा_, gsta_,
  { {0x29030089, 0x2ca60d28, 0x00000000, 0x00000000}},  //   īja_, _gmod_,   ,
  { {0xb8fc001c, 0x291e25a8, 0x765e01aa, 0x00000000}},  //   _ती_, asta_, _papy,
  { {0x6d5a2eb3, 0xb87b004a, 0x00000000, 0x00000000}},  //   _ysta, rmía,   ,
  { {0x441600ed, 0xe6170517, 0x6d5a02d4, 0x00000000}},  //   ифат, рдс_, _xsta,
  { {0x7786005e, 0x765e0020, 0x99d4023c, 0x00000000}},  //   _влиз, _wapy, _اتها,
  { {0xd3870d99, 0x765e0006, 0xd6d20025, 0x00000000}},  // [8f00] айте_, _tapy, _وقع_,
  { {0x386000ab, 0x6444001a, 0x769000b0, 0x00000000}},  //   _hair_, sfii, _käym,
  { {0xf67b007b, 0x867b009b, 0x321a00ab, 0x00000000}},  //   _סאטמ, _סרטו, rapy_,
  { {0x504601fb, 0x661c0056, 0x386000c4, 0x00000000}},  //   редб, lark, _jair_,
  { {0xdfcf0426, 0x44fc193c, 0x3860005b, 0x00000000}},  //   ويم_, _hí_, _mair_,
  { {0x661c0127, 0x44fc001d, 0x6d5a0009, 0x00000000}},  //   nark, _kí_, _psta,
  { {0xb87b0224, 0x44fc00b9, 0x66d2000c, 0x00000000}},  //   dmín, _jí_, tækj,
  { {0x44fc2eb4, 0x661c022b, 0x32180690, 0x00000000}},  //   _mí_, hark, _hery_,
  { {0x661c0292, 0x44fc0011, 0x6d5a0036, 0x00000000}},  //   kark, _lí_, _wsta,
  { {0x661c0169, 0x7f3b00b3, 0x66d2000c, 0x00000000}},  //   jark, _בעמו, sækj,
  { {0x44fc2eb5, 0x661c2eb6, 0x291e2077, 0x00000000}},  //   _ní_, dark, usta_,
  { {0x291e0332, 0x661722f8, 0x38602eb7, 0x00000000}},  //   rsta_, _sexk, _cair_,
  { {0x38602eb8, 0x44fc0181, 0xdc9b00a0, 0x00000000}},  //   _dair_, _aí_, _ביאל,
  { {0x44fc2eb9, 0x661c002d, 0x3f420011, 0x00000000}},  //   _bí_, gark, _mưu_,
  { {0x3f42001d, 0x45d500ed, 0x69d80089, 0x00000000}},  //   _lưu_, совс, _uzve,
  { {0xd498132e, 0x316d2eba, 0x38600016, 0x00000000}},  //   ару_, _čez_, _gair_,
  { {0x2458007c, 0x7cf50006, 0x00000000, 0x00000000}},  // [8f10] шать_, _išre,   ,
  { {0x661c0107, 0x38600035, 0x8c3d014a, 0x00000000}},  //   cark, _zair_, tişk,
  { {0xd5b8041f, 0x00000000, 0x00000000, 0x00000000}},  //   _вся_,   ,   ,
  { {0x3f420011, 0x75350026, 0x27ed2ebb, 0x00000000}},  //   _bưu_, muzz, ženu_,
  { {0x753501d5, 0x32180093, 0xb87b0051, 0x00000000}},  //   luzz, _fery_, hmío,
  { {0xee3801fb, 0x76552ebc, 0x32180007, 0x00000000}},  //   ині_, nezy, _gery_,
  { {0x31e50055, 0x01e50055, 0x8c3d005a, 0x00000000}},  //   _প্রশ, _প্রদ, lişi,
  { {0x45b800b6, 0x69ca0164, 0x661c2ebd, 0x00000000}},  //   יפול_, _सुधी, zark,
  { {0x201d033b, 0x661c2ebe, 0x8c3d0276, 0x00000000}},  //   mawi_, yark, nişi,
  { {0x38602ebf, 0x66d20030, 0x201d0020, 0x00000000}},  //   _sair_, rækk, lawi_,
  { {0x661c2e27, 0x386000ab, 0xb87b0161, 0x00000000}},  //   vark, _pair_, rmín,
  { {0x661c2ec0, 0x753501d5, 0x7e6100b0, 0x00000000}},  //   wark, duzz, _halp,
  { {0x2d8a001f, 0x44fc2ec1, 0x661c00b0, 0x00000000}},  //   _über_, _sí_, tark,
  { {0x2cad03a1, 0x201d2ec2, 0x66032ec3, 0x00000000}},  //   lied_, hawi_, зпра,
  { {0x7e6101aa, 0x6d430333, 0x661c0056, 0x00000000}},  //   _malp, ntna, rark,
  { {0x3860002a, 0x661c020c, 0x44fc2ec4, 0x00000000}},  //   _uair_, sark, _ví_,
  { {0xd467046c, 0x661c01a3, 0xb2260425, 0x00000000}},  // [8f20] щите_, park, ймал,
  { {0x44fc1fce, 0x7535002b, 0x6d43007f, 0x00000000}},  //   _tí_, buzz, ktna,
  { {0x75350066, 0x32180038, 0x3f420011, 0x00000000}},  //   cuzz, _very_, _sưu_,
  { {0x26ca0e30, 0x201d0058, 0x7f420026, 0x00000000}},  //   lobo_, gawi_, ttoq,
  { {0x6d430011, 0x543b0049, 0x645601df, 0x00000000}},  //   etna, _געכא, meyi,
  { {0x6d430061, 0x6456005a, 0x7e610555, 0x00000000}},  //   ftna, leyi, _calp,
  { {0x2cad0038, 0x7f4201d5, 0x201d011c, 0x00000000}},  //   fied_, stoq, bawi_,
  { {0x6456014a, 0x24800213, 0x00000000, 0x00000000}},  //   neyi, njim_,   ,
  { {0x6d69001e, 0x81cd0055, 0x9e3a0025, 0x00000000}},  //   _īpaš, শেদ_, _مساء_,
  { {0x7e612ec5, 0x6fb300f9, 0x0e6a0025, 0x00000000}},  //   _galp, _عملا, _حصري_,
  { {0x2cad01b5, 0x67240107, 0x6d4300bb, 0x00000000}},  //   bied_, _avij, ctna,
  { {0x8c3d2ec6, 0x63bb000c, 0x2cad014f, 0x00000000}},  //   yişi, _þung, cied_,
  { {0x67240243, 0x24800107, 0x29070197, 0x00000000}},  //   _cvij, djim_, _etna_,
  { {0x67240182, 0x7535002b, 0x95cb00e3, 0x00000000}},  //   _dvij, tuzz, губа_,
  { {0xceb30097, 0x59cf007d, 0x65940887, 0x00000000}},  //   ליש_, _सुपर, пару,
  { {0x8c3d011f, 0x753501bc, 0x24800023, 0x00000000}},  //   tişi, ruzz, gjim_,
  { {0x26ca008e, 0x6e280caa, 0x32010133, 0x00000000}},  // [8f30] bobo_, _oddb, tchy_,
  { {0x63a901d9, 0x8c3d005a, 0x26ca2ccc, 0x00000000}},  //   _žens, rişi, cobo_,
  { {0x67240209, 0x201d0020, 0x320107fc, 0x00000000}},  //   _zvij, tawi_, rchy_,
  { {0x6e2822dc, 0x78af01ee, 0x4fd5007c, 0x00000000}},  //   _addb, nicv, ожет,
  { {0x643a007b, 0x7ff40025, 0x00000000, 0x00000000}},  //   _דערנ, أسما,   ,
  { {0x3eae01bf, 0x6d430039, 0x171c0049, 0x00000000}},  //   gift_, ttna, נווע,
  { {0x7e612ec7, 0x201d0058, 0xdc990478, 0x00000000}},  //   _valp, pawi_, итиш_,
  { {0x6d43165e, 0x13ad0044, 0xcf2e014a, 0x00000000}},  //   rtna, _কুয়, üğüm_,
  { {0x62872ec8, 0x7e6117c9, 0x2cad02f1, 0x00000000}},  //   _kojo, _talp, ried_,
  { {0xa9252821, 0x4ea701fc, 0x64562ec9, 0x00000000}},  //   одол, _урба, zeyi,
  { {0x67240182, 0x3f8f018e, 0x62870466, 0x00000000}},  //   _svij, lygu_, _mojo,
  { {0x776d20e3, 0x00000000, 0x00000000, 0x00000000}},  //   _brax,   ,   ,
  { {0x776d0197, 0x00000000, 0x00000000, 0x00000000}},  //   _crax,   ,   ,
  { {0xa969026b, 0xd4910082, 0x62870943, 0x00000000}},  //   _вика_, ền_, _nojo,
  { {0x26ca00ca, 0xa2ba0309, 0xd05f006b, 0x00000000}},  //   robo_, ्वस्, şvət,
  { {0x7c3b0127, 0x26ca0093, 0xdbd4004a, 0x00000000}},  //   ngur, sobo_, _zúñi,
  { {0x67240182, 0x52aa0265, 0x62870161, 0x00000000}},  // [8f40] _uvij, авам_, _bojo,
  { {0x62871965, 0x6456005a, 0x248000ee, 0x00000000}},  //   _cojo, seyi, sjim_,
  { {0x62870066, 0xf77201b2, 0x00000000, 0x00000000}},  //   _dojo, _راک_,   ,
  { {0xd46a003b, 0x63bb00d0, 0x00000000, 0x00000000}},  //   _тиме_, _žune,   ,
  { {0x44200b53, 0x7c3b0d0a, 0x3eae01a2, 0x00000000}},  //   mai_, dgur, tift_,
  { {0x6f0904be, 0x62870023, 0x00000000, 0x00000000}},  //   _dtec, _gojo,   ,
  { {0x3eae25d4, 0xbea300ed, 0x68f9006b, 0x00000000}},  //   rift_, ќајк, _əbdü,
  { {0x44202eca, 0xc5f300b3, 0xdbd4000c, 0x00000000}},  //   nai_, ודו_, _búði,
  { {0x1fd10055, 0x46da0061, 0x3fb600a1, 0x00000000}},  //   ়েবস, णताह, _بھاگ_,
  { {0x7c3b0420, 0x20e8014a, 0x13ad0044, 0x00000000}},  //   agur, _eşit_, _কুড়,
  { {0xa3ac0309, 0x3257009b, 0xf1d0013d, 0x00000000}},  //   _केस_, חסים_, _तुमन,
  { {0x44200a5c, 0x776d0f73, 0x48ab013b, 0x00000000}},  //   jai_, _prax, ртом_,
  { {0x44202c3a, 0x7cf50006, 0x6f0900d4, 0x00000000}},  //   dai_, _išra, _xtec,
  { {0x24550011, 0x78af0019, 0x00000000, 0x00000000}},  //   _ấm_, sicv,   ,
  { {0x44202ecb, 0x6287008e, 0x1a9b0049, 0x00000000}},  //   fai_, _rojo, _דיגע,
  { {0x4420020c, 0x7c2000d9, 0x00000000, 0x00000000}},  //   gai_, namr,   ,
  { {0x8c3d2754, 0x62870093, 0x78ad1013, 0x00000000}},  // [8f50] mişt, _pojo, _imav,
  { {0x8c3d1c17, 0x7afd0916, 0x416b003b, 0x00000000}},  //   lişt, ísti, ијем_,
  { {0x4420010a, 0x6f09010f, 0xddc10089, 0x00000000}},  //   bai_, _stec, _valū,
  { {0x44200010, 0x8c3d228e, 0x00000000, 0x00000000}},  //   cai_, nişt,   ,
  { {0xb4d7001c, 0x53440242, 0x3f69003b, 0x00000000}},  //   िती_, _охра, сило_,
  { {0x81cd0055, 0x442b0145, 0x7c3b002b, 0x00000000}},  //   শেষ_, _hdc_, wgur,
  { {0x78ad042b, 0x442b1d57, 0xa2ba007d, 0x00000000}},  //   _omav, _kdc_, ्वर्,
  { {0x7c3b0a0a, 0x442b2296, 0x00000000, 0x00000000}},  //   ugur, _jdc_,   ,
  { {0xbf15031d, 0x7c3b04d4, 0x442b2ecc, 0x00000000}},  //   _رواب, rgur, _mdc_,
  { {0x44200ff0, 0x78ad0a15, 0x00000000, 0x00000000}},  //   zai_, _amav,   ,
  { {0x81cd0055, 0x442001a3, 0x88ca022a, 0x00000000}},  //   শের_, yai_, йлов_,
  { {0xa3ac0061, 0x8c3d2ecd, 0x29e100c4, 0x00000000}},  //   _कइल_, gişt, _açaí_,
  { {0x4420010a, 0xf7720025, 0xd5b70082, 0x00000000}},  //   vai_, راح_, ống_,
  { {0x4420020c, 0x200d006b, 0x00000000, 0x00000000}},  //   wai_, əmiş_,   ,
  { {0x4420010a, 0x0496008b, 0x442b0494, 0x00000000}},  //   tai_, праў, _bdc_,
  { {0x442b0129, 0x2be2006e, 0x8c3d0095, 0x00000000}},  //   _cdc_, _परमा, mişs,
  { {0x44202ece, 0xf1fa2712, 0x883b009b, 0x00000000}},  // [8f60] rai_, معات_, _התפו,
  { {0x4420010a, 0x442b0190, 0x27e01578, 0x00000000}},  //   sai_, _edc_, _izin_,
  { {0x442b0061, 0x68e40127, 0x7c2b00b4, 0x00000000}},  //   _fdc_, _khid, _odgr,
  { {0xe0d228b7, 0x442b1238, 0x00000000, 0x00000000}},  //   رزا_, _gdc_,   ,
  { {0x67260292, 0xef7400a1, 0x68f60095, 0x00000000}},  //   nskj, بخاک, _miyd,
  { {0x42551fa3, 0xbea3003b, 0x63a408ff, 0x00000000}},  //   _отст, начк, mzin,
  { {0x63a400c4, 0x00000000, 0x00000000, 0x00000000}},  //   lzin,   ,   ,
  { {0x63a41325, 0xc5f3009b, 0x00000000, 0x00000000}},  //   ozin, עדה_,   ,
  { {0x8fa3007c, 0xe45701ce, 0x7c2b0009, 0x00000000}},  //   _зате, ליקט_, _ddgr,
  { {0x63a42ecf, 0x8f9b00b3, 0x68e400e7, 0x00000000}},  //   izin, _הימי, _ahid,
  { {0xade8006e, 0x8c3d2ed0, 0x7c200022, 0x00000000}},  //   टेशन_, tişt, pamr,
  { {0x290a001e, 0x68e4008e, 0x63a40032, 0x00000000}},  //   ība_, _chid, kzin,
  { {0x68e4000b, 0x63a400b5, 0x442b009d, 0x00000000}},  //   _dhid, jzin, _rdc_,
  { {0x63a42ed1, 0x7cc1001e, 0xf1be01f5, 0x00000000}},  //   dzin, mēra, ्थान,
  { {0xd49b06b6, 0x27e0022b, 0x661e023a, 0x00000000}},  //   бра_, _ezin_, _depk,
  { {0xe45f009f, 0x68e42ed2, 0xb4d70061, 0x00000000}},  //   _mjög_, _ghid, िते_,
  { {0xa3e7013d, 0x442b0082, 0x63a400bb, 0x00000000}},  // [8f70] यें_, _vdc_, gzin,
  { {0x68e4065e, 0x00000000, 0x00000000, 0x00000000}},  //   _zhid,   ,   ,
  { {0x442b0030, 0x78bd0210, 0x66d2000c, 0x00000000}},  //   _tdc_, onsv, rækt,
  { {0x442b0197, 0x629c0232, 0x78bd00ea, 0x00000000}},  //   _udc_, _elro, nnsv,
  { {0x5f940088, 0x644d0145, 0x00000000, 0x00000000}},  //   ницт, mfai,   ,
  { {0x644d0048, 0x661e00f6, 0x7a290010, 0x00000000}},  //   lfai, _xepk, _kötő,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x644d2ed3, 0xfd5e0011, 0x00000000, 0x00000000}},  //   nfai, _huyề,   ,
  { {0x76900f3c, 0x00000000, 0x00000000, 0x00000000}},  //   _käyt,   ,   ,
  { {0x68e406a4, 0x69c30009, 0x00000000, 0x00000000}},  //   _shid, _pxne,   ,
  { {0x63a40207, 0x6e23000c, 0x661e16d0, 0x00000000}},  //   zzin, manb, _repk,
  { {0x61ec006b, 0x00000000, 0x00000000, 0x00000000}},  //   ünlə,   ,   ,
  { {0x644d002a, 0x00000000, 0x00000000, 0x00000000}},  //   dfai,   ,   ,
  { {0x7690021e, 0xddc30010, 0x7afd1ade, 0x00000000}},  //   _näyt, lenő, ístu,
  { {0xa507017f, 0x644d0f75, 0x67262ed4, 0x00000000}},  //   деса_, ffai, sskj,
  { {0x63a409ce, 0x644d0048, 0x672602e1, 0x00000000}},  //   tzin, gfai, pskj,
  { {0xc61d0055, 0x6e23023a, 0x661e014a, 0x00000000}},  // [8f80] _তারা_, kanb, _tepk,
  { {0xe1f20b6c, 0x4ecf0044, 0x6e232ed5, 0x00000000}},  //   نسا_, িগুল, janb,
  { {0x81d60055, 0x63a40333, 0x2a6701aa, 0x00000000}},  //   াইভ_, szin, _manb_,
  { {0x644d0051, 0x38ab0036, 0x63a401c5, 0x00000000}},  //   cfai, _górę_, pzin,
  { {0x09b10044, 0x201f0022, 0x213a00e7, 0x00000000}},  //   _ঘুমা, _deui_, suph_,
  { {0xc33300a3, 0x765c007f, 0x6e230668, 0x00000000}},  //   _בוש_, nery, ganb,
  { {0x60260098, 0x910300ed, 0x201f0022, 0x00000000}},  //   _одва, _апсе, _feui_,
  { {0x765c0093, 0x91e302dc, 0x00000000, 0x00000000}},  //   hery, _росе,   ,
  { {0x9ce8009c, 0xd00f031d, 0x765c0af1, 0x00000000}},  //   _ہوئے_, _خلق_, kery,
  { {0x765c2ed6, 0x753c1712, 0xee37003b, 0x00000000}},  //   jery, kurz, _ону_,
  { {0x644d1ad0, 0x765c01d6, 0xe8730014, 0x00000000}},  //   yfai, dery, نندگ,
  { {0x6f000020, 0x00000000, 0x00000000, 0x00000000}},  //   _kumc,   ,   ,
  { {0xb905007d, 0x765c2ed7, 0x6d4a0190, 0x00000000}},  //   _बी_, fery, ltfa,
  { {0x59cf0204, 0x765c0af1, 0x00000000, 0x00000000}},  //   _सुवर, gery,   ,
  { {0x7764027b, 0x7e680190, 0x644d2ed8, 0x00000000}},  //   _esix, _madp, tfai,
  { {0x7ce500c4, 0xdef80066, 0x00000000, 0x00000000}},  //   córd, _liċ_,   ,
  { {0x644d1321, 0xf8bf2ed9, 0x69d800b5, 0x00000000}},  // [8f90] rfai, mné_, _hyve,
  { {0x38690100, 0xfd5e001d, 0xf8bf01ca, 0x00000000}},  //   _haar_, _quyề, lné_,
  { {0xf8bf2eda, 0x673d0056, 0x00000000, 0x00000000}},  //   oné_, lusj,   ,
  { {0x3869049b, 0xf8bf0387, 0x9f9c000c, 0x00000000}},  //   _jaar_, nné_, tæða_,
  { {0x3869049b, 0x6e23011f, 0x7690021e, 0x00000000}},  //   _maar_, tanb, _täyt,
  { {0x9e6401e1, 0x9f9c000c, 0x6d4a010f, 0x00000000}},  //   квід, ræða_, ftfa,
  { {0x6e23006b, 0x7e7a00f6, 0xdef8002b, 0x00000000}},  //   ranb, _dntp, _diċ_,
  { {0x38690662, 0x6e232edb, 0xf8bf01ca, 0x00000000}},  //   _naar_, sanb, jné_,
  { {0xf8bf0428, 0xdef8002b, 0x6d4a0146, 0x00000000}},  //   dné_, _fiċ_, atfa,
  { {0x2eca0164, 0x673d2edc, 0xb87b000c, 0x00000000}},  //   ाकृत, dusj, nlíf,
  { {0xe9d9005e, 0x765c0253, 0x186a0216, 0x00000000}},  //   яко_, very, пани_,
  { {0x6e211cb8, 0xf8bf00f4, 0xa2cc0061, 0x00000000}},  //   _helb, gné_, तकऱ्,
  { {0x386906b2, 0x765c006a, 0x6e210b8b, 0x00000000}},  //   _daar_, tery, _kelb,
  { {0x2cbf0004, 0x7d0100ca, 0x753c0036, 0x00000000}},  //   lnud_, _kuls, turz,
  { {0x69d8010a, 0xf8bf06b8, 0xba7400a1, 0x00000000}},  //   _gyve, bné_, _جانت,
  { {0x765c011c, 0xf8bf06b8, 0x2cbf006c, 0x00000000}},  //   sery, cné_, nnud_,
  { {0x765c2081, 0x26d1004a, 0xccf200a0, 0x00000000}},  // [8fa0] pery, bozo_, רכן_,
  { {0x05662edd, 0xb87b06c2, 0xc3090044, 0x00000000}},  //   _звон, glíf, _লিখি_,
  { {0x7d010190, 0x00000000, 0x00000000, 0x00000000}},  //   _nuls,   ,   ,
  { {0x7690021e, 0x38a20027, 0xf53700a0, 0x00000000}},  //   _täys, _fóre_, _אנטי_,
  { {0x2cbf006c, 0x7645018e, 0x442217cf, 0x00000000}},  //   dnud_, _ychy, _iek_,
  { {0x442201d6, 0xf8bf015f, 0x7d012ede, 0x00000000}},  //   _hek_, zné_, _buls,
  { {0xa0a601fb, 0x6e2100f8, 0x442215fb, 0x00000000}},  //   _завд, _delb, _kek_,
  { {0x6d4a0073, 0x442201a3, 0xa3e70204, 0x00000000}},  //   rtfa, _jek_, येक_,
  { {0xf8bf0428, 0x442201a3, 0x10a3137c, 0x00000000}},  //   vné_, _mek_, _ситн,
  { {0xc333019b, 0x6e211d67, 0x628e0646, 0x00000000}},  //   נות_, _gelb, _jobo,
  { {0x3869037f, 0xf8bf0d83, 0x2be20164, 0x00000000}},  //   _paar_, tné_, _परवा,
  { {0xdd8f0014, 0x26f902fb, 0x44220091, 0x00000000}},  //   _دوم_, ंद्र_, _nek_,
  { {0xf8bf004f, 0x38690007, 0x7af8016c, 0x00000000}},  //   rné_, _vaar_, _tivt,
  { {0x38690100, 0x7c220051, 0xf8bf0428, 0x00000000}},  //   _waar_, _heor, sné_,
  { {0x45d50081, 0x44220007, 0xf1d0007d, 0x00000000}},  //   товс, _bek_, _तुलन,
  { {0x442204cb, 0x38690026, 0x7cc800b9, 0x00000000}},  //   _cek_, _uaar_, běre,
  { {0x628e0016, 0x44221ece, 0x2a7c00bb, 0x00000000}},  // [8fb0] _bobo, _dek_, _knvb_,
  { {0x44220004, 0xd0190309, 0x628e001a, 0x00000000}},  //   _eek_, दर्भ_, _cobo,
  { {0x628e0010, 0x44220173, 0xd13b005e, 0x00000000}},  //   _dobo, _fek_, яха_,
  { {0x6e21001f, 0x7cc1001e, 0x44220250, 0x00000000}},  //   _selb, vēro, _gek_,
  { {0x7d01023a, 0x6e210127, 0x248906ed, 0x00000000}},  //   _suls, _pelb, mjam_,
  { {0xed590373, 0x7bd90016, 0x628e0145, 0x00000000}},  //   док_, _rywu, _gobo,
  { {0x2cbf0004, 0x6e210190, 0xa1580454, 0x00000000}},  //   tnud_, _velb, _пару_,
  { {0x6e210116, 0x628e05c9, 0x672d00ee, 0x00000000}},  //   _welb, _zobo, _ovaj,
  { {0x2ef5106d, 0x7c220048, 0x2cbf006c, 0x00000000}},  //   _азар, _deor, rnud_,
  { {0x3da703f3, 0x7d010403, 0xb87b00b9, 0x00000000}},  //   _преб, _tuls, hlíd,
  { {0x98a601bd, 0x89f4008b, 0x672d0052, 0x00000000}},  //   вине, ляюц, _avaj,
  { {0xf3ff0011, 0x61fa2edf, 0x00000000, 0x00000000}},  //   _ngã_, _útle,   ,
  { {0xeb8e1ef9, 0xc6260055, 0x24892ee0, 0x00000000}},  //   _ти_, _বাবা_, djam_,
  { {0x44222559, 0x672d1238, 0x2296000c, 0x00000000}},  //   _sek_, _dvaj, _tæki_,
  { {0xceb2019b, 0x628e049a, 0x4422014a, 0x00000000}},  //   בים_, _robo, _pek_,
  { {0x69ca0061, 0x00000000, 0x00000000, 0x00000000}},  //   _सुटी,   ,   ,
  { {0x2b4d0035, 0xe8d7009b, 0xb87b004a, 0x00000000}},  // [8fc0] ntec_, _בוקר_, rmít,
  { {0x442201d6, 0x27fe013e, 0x236d0066, 0x00000000}},  //   _wek_, ětnu_, _ġejt_,
  { {0x44222ee1, 0xa69b009b, 0x00000000, 0x00000000}},  //   _tek_, _חשיפ,   ,
  { {0x628e0173, 0xa7fb004a, 0xb87b00fa, 0x00000000}},  //   _wobo, señe, clíd,
  { {0x628e0091, 0xdfd20025, 0x00000000, 0x00000000}},  //   _tobo, جيش_,   ,
  { {0x7c22020c, 0x6e940025, 0x5f930184, 0x00000000}},  //   _seor, طلبا, ришт,
  { {0x7c22008e, 0xed57012b, 0x3f80001a, 0x00000000}},  //   _peor, вој_, ţiu_,
  { {0x61e3011f, 0x7ce500c4, 0x6c3400a1, 0x00000000}},  //   ünle, vórc, اہشا,
  { {0x3dd20036, 0x2d8101a2, 0x00000000, 0x00000000}},  //   ływ_, äher_,   ,
  { {0xbbe202fb, 0x60c21a2d, 0x00000000, 0x00000000}},  //   _परीक, lnom,   ,
  { {0x672d0006, 0x5d860257, 0xbc670bb6, 0x00000000}},  //   _svaj, _جلال, رمین_,
  { {0x60c20292, 0x6d5a014a, 0x00000000, 0x00000000}},  //   nnom, _ipta,   ,
  { {0x2b4d00f6, 0x00000000, 0x00000000, 0x00000000}},  //   ctec_,   ,   ,
  { {0x60c21487, 0x7ce52ee2, 0x3f8600fa, 0x00000000}},  //   hnom, móra, ixou_,
  { {0xddda00b9, 0x60c201d6, 0x2489012d, 0x00000000}},  //   _patř, knom, tjam_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x24890059, 0x672d0059, 0xb87b004a, 0x00000000}},  // [8fd0] rjam_, _uvaj, smís,
  { {0x6d5a0030, 0x22470047, 0x66e402ea, 0x00000000}},  //   _opta, ünk_, _коња,
  { {0xddc82ee3, 0xa2ba01f5, 0xc69200b3, 0x00000000}},  //   _andž, ्वज्, _האי_,
  { {0x60c201e8, 0xc9530049, 0x00000000, 0x00000000}},  //   gnom, ימע_,   ,
  { {0x4429212c, 0xc43a00b6, 0x6d5a2ee4, 0x00000000}},  //   maa_, _אתרי, _apta,
  { {0x4429021e, 0xc10505f3, 0x38a22ee5, 0x00000000}},  //   laa_, _موسي, _móra_,
  { {0xb87b0181, 0xf2d200b3, 0x290a0b33, 0x00000000}},  //   ilíb, _העם_, íbal_,
  { {0x4429021e, 0x7ce50051, 0x27ed01dc, 0x00000000}},  //   naa_, fóra, ženy_,
  { {0xddc113c7, 0x7b750076, 0x63bb012d, 0x00000000}},  //   _dalš, اطبا, _žunj,
  { {0x44292349, 0xd90c00a1, 0xc3340104, 0x00000000}},  //   haa_, ڈیو_, בוץ_,
  { {0x4429021e, 0x26c30059, 0xd90c025a, 0x00000000}},  //   kaa_, dnjo_, ویو_,
  { {0x44290943, 0xe73a008b, 0x3da4005c, 0x00000000}},  //   jaa_, нем_, _труб,
  { {0x44290622, 0x7c290190, 0xa3b30316, 0x00000000}},  //   daa_, maer, _झेल_,
  { {0x25ef001c, 0x78a60023, 0x38a22a22, 0x00000000}},  //   _आणखी_, shkv, _dóra_,
  { {0x4429000b, 0xceb200b3, 0x610c0180, 0x00000000}},  //   faa_, זים_, _oğla,
  { {0x4429194a, 0x38a20428, 0x7c291d56, 0x00000000}},  //   gaa_, _fóra_, naer,
  { {0x38a20046, 0x78a4000b, 0x60c20b4a, 0x00000000}},  // [8fe0] _góra_, _iliv, vnom,
  { {0x7c290016, 0x610c005d, 0x4429016e, 0x00000000}},  //   haer, _ağla, aaa_,
  { {0x7c29022b, 0x442901c5, 0xc6930049, 0x00000000}},  //   kaer, baa_, _לאז_,
  { {0x1b190055, 0xd5ad026c, 0x673b0235, 0x00000000}},  //   _দিনে_, _کہہ_, šuje,
  { {0x60c2010f, 0x7c292ee6, 0x78a400e7, 0x00000000}},  //   rnom, daer, _mliv,
  { {0x78a400f6, 0x3fcb0241, 0x00000000, 0x00000000}},  //   _lliv, ردنی_,   ,
  { {0x78a42e72, 0xf9870447, 0xc05a279d, 0x00000000}},  //   _oliv, _اب_, _прац_,
  { {0x7c291a97, 0x26c30e0d, 0x00000000, 0x00000000}},  //   gaer, znjo_,   ,
  { {0x40930a4f, 0x26da0022, 0x00000000, 0x00000000}},  //   _القر, _okpo_,   ,
  { {0x78a40020, 0x44290020, 0x629e01d6, 0x00000000}},  //   _aliv, zaa_, nkpo,
  { {0x78a42ee7, 0x7c290058, 0x2d9801e3, 0x00000000}},  //   _bliv, baer, _ære_,
  { {0x78a401d6, 0xe3bf008e, 0x7cc8013e, 0x00000000}},  //   _cliv, _leña_, běra,
  { {0x4429021e, 0x26c3050f, 0xfcd30014, 0x00000000}},  //   vaa_, tnjo_, _اينج,
  { {0x386d0c76, 0x442900e7, 0x2d980010, 0x00000000}},  //   žer_, waa_, _üres_,
  { {0x4429021e, 0x00000000, 0x00000000, 0x00000000}},  //   taa_,   ,   ,
  { {0x893301d8, 0x6aba0190, 0x6e2a0016, 0x00000000}},  //   _اعوا, litf, hafb,
  { {0x4429021e, 0x26c300ca, 0x68ed01f3, 0x00000000}},  // [8ff0] raa_, pnjo_, _ihad,
  { {0x27e90756, 0x7ce5009f, 0x44290ac0, 0x00000000}},  //   _izan_, jórn, saa_,
  { {0x4429021e, 0x68ed0145, 0x27ec0036, 0x00000000}},  //   paa_, _khad, ędne_,
  { {0x0467005e, 0x6f0d0d7b, 0x00000000, 0x00000000}},  //   _стом, íaco,   ,
  { {0x3f6901ee, 0x68ed035e, 0x68ff006b, 0x00000000}},  //   тило_, _mhad, _miqd,
  { {0x1eea0167, 0xee3602dc, 0x7cc10089, 0x00000000}},  //   نونی_, анш_, pērk,
  { {0x63ad0207, 0x200e000c, 0x7c290032, 0x00000000}},  //   lzan, ækið_, taer,
  { {0x1b190044, 0x68ed1503, 0x27e9026d, 0x00000000}},  //   _দিবে_, _nhad, _ozan_,
  { {0x63ad0be3, 0x7c291d58, 0xbf150137, 0x00000000}},  //   nzan, raer, _ضواب,
  { {0xdfd80265, 0x60c901e3, 0x68ed0020, 0x00000000}},  //   _със_, _hjem, _ahad,
  { {0x09e50264, 0x7e6300b0, 0x7cc800b9, 0x00000000}},  //   ронн, menp, měrn,
  { {0x6d430207, 0x68ed0012, 0x7e630fa8, 0x00000000}},  //   muna, _chad, lenp,
  { {0x6d43011f, 0x78a42ee8, 0x60db00e7, 0x00000000}},  //   luna, _vliv, _mkum,
  { {0x63ad0871, 0x8f9a01ce, 0x7e6317f7, 0x00000000}},  //   dzan, דישי, nenp,
  { {0x68ed0051, 0x60db014a, 0xb8250044, 0x00000000}},  //   _fhad, _okum, _ভারত_,
  { {0x60c90119, 0xa7fb0211, 0x68ed002b, 0x00000000}},  //   _njem, seña, _ghad,

  { {0xd46718ea, 0x6d430504, 0x29000c56, 0x00000000}},  // [9000] шите_, huna, _iiia_,
  { {0x29071a0c, 0x6d432e23, 0xb87b1505, 0x00000000}},  //   _kuna_, kuna, plíc,
  { {0x6d432ee9, 0x26d800c4, 0xa06a2eea, 0x00000000}},  //   juna, moro_, кажа_,
  { {0x3ea505ce, 0x29072de7, 0x26d80617, 0x00000000}},  //   _allt_, _muna_, loro_,
  { {0x2907000d, 0x63ad0036, 0x60c92c63, 0x00000000}},  //   _luna_, czan, _djem,
  { {0x8d7602fd, 0x60c90219, 0x26d80419, 0x00000000}},  //   لاعا, _ejem, noro_,
  { {0x6d43020c, 0x6e2a00bb, 0x7d780014, 0x00000000}},  //   guna, rafb, امبر_,
  { {0x26d801dd, 0x63bb00d0, 0x60c92eeb, 0x00000000}},  //   horo_, _žuni, _gjem,
  { {0x26d80091, 0x7ac619c9, 0x68ed005b, 0x00000000}},  //   koro_, исое, _rhad,
  { {0x29070ac8, 0x781f02fb, 0x68ed00ab, 0x00000000}},  //   _buna_, पर्क_, _shad,
  { {0x6d43003b, 0x63ad0207, 0x29072eec, 0x00000000}},  //   cuna, zzan, _cuna_,
  { {0x29070010, 0x6e2800f8, 0x7ae11f74, 0x00000000}},  //   _duna_, _hedb, allt,
  { {0x61050006, 0x26d808d3, 0xf804007e, 0x00000000}},  //   _vėli, foro_, ючэн,
  { {0x26d82eed, 0x67240022, 0xdb9b009b, 0x00000000}},  //   goro_, _dwij, _בסדר,
  { {0x6e2801bf, 0x2907027e, 0x7d080b3d, 0x00000000}},  //   _medb, _guna_, _juds,
  { {0x1b190055, 0x63ad0129, 0x7cc10089, 0x00000000}},  //   _দিতে_, tzan, tēri,
  { {0x6d432eee, 0x26d80019, 0x78bd01c2, 0x00000000}},  // [9010] zuna, boro_, misv,
  { {0x63ad0036, 0x6d430058, 0x7d0800c7, 0x00000000}},  //   rzan, yuna, _ouds,
  { {0x2f0b0018, 0x63ad0036, 0x67242eef, 0x00000000}},  //   _søg_, szan, _zwij,
  { {0x78bd130e, 0xa49b00f6, 0x6d432da0, 0x00000000}},  //   nisv, _diòc, vuna,
  { {0x95e9026c, 0x7e632ef0, 0x7ae10016, 0x00000000}},  //   _جبکہ_, tenp, yllt,
  { {0x6d43006a, 0x7d0811b8, 0x00000000, 0x00000000}},  //   tuna, _buds,   ,
  { {0x7e632ef1, 0x2ca60193, 0x365c009b, 0x00000000}},  //   renp, _blod_, דכונ,
  { {0x60db0020, 0x3a2701aa, 0x60c90450, 0x00000000}},  //   _ukum, _senp_, _ujem,
  { {0xdd91026c, 0x6d43022b, 0x290712fc, 0x00000000}},  //   توں_, suna, _suna_,
  { {0x29070c33, 0x6d43006a, 0x2900006c, 0x00000000}},  //   _puna_, puna, _siia_,
  { {0xf76900b6, 0x26d80198, 0x382a007c, 0x00000000}},  //   _רק_, voro_, лжно_,
  { {0x78bd01e5, 0x2ca6005b, 0x00000000, 0x00000000}},  //   gisv, _glod_,   ,
  { {0x6f09008e, 0x2900006c, 0x00000000, 0x00000000}},  //   _juec, _viia_,   ,
  { {0xd63a007e, 0x62951ae3, 0x290703ef, 0x00000000}},  //   ыямі_, _nozo, _tuna_,
  { {0x6f0122b7, 0x26d80a64, 0x38a9009d, 0x00000000}},  //   _milc, roro_, _sûre_,
  { {0x26d82ef2, 0x672400b5, 0x394519d6, 0x00000000}},  //   soro_, _twij, muls_,
  { {0x26d80009, 0x6295087a, 0x6f09008e, 0x00000000}},  // [9020] poro_, _bozo, _nuec,
  { {0x62950035, 0xb87b01e5, 0x6f0100fa, 0x00000000}},  //   _cozo, nlín, _nilc,
  { {0x62950161, 0xb87b0048, 0x00000000, 0x00000000}},  //   _dozo, ilín,   ,
  { {0x7ce5008e, 0xef86007e, 0x6f0901a2, 0x00000000}},  //   fórm, йлеп, _buec,
  { {0x4420000b, 0xdee6003b, 0x3ebc05cb, 0x00000000}},  //   mbi_, боди, tivt_,
  { {0x6f092ef3, 0x6295002d, 0x7d080190, 0x00000000}},  //   _duec, _gozo, _puds,
  { {0x2ca6016e, 0x6e2807c4, 0x4420010e, 0x00000000}},  //   _plod_, _vedb, obi_,
  { {0x44202ef4, 0x39450129, 0x5b14007c, 0x00000000}},  //   nbi_, duls_, омит,
  { {0x6e28005a, 0x00000000, 0x00000000, 0x00000000}},  //   _tedb,   ,   ,
  { {0xd91a1fea, 0xc6010044, 0x4420057e, 0x00000000}},  //   льм_, ্রতা_, hbi_,
  { {0x78bd1f47, 0x1958007e, 0x394506ed, 0x00000000}},  //   tisv, шаны_, guls_,
  { {0xab2a00ed, 0x290c006b, 0x44201adc, 0x00000000}},  //   _бода_, rqda_, jbi_,
  { {0x442002aa, 0x274b007c, 0xa7fb04de, 0x00000000}},  //   dbi_, ычно_, reño,
  { {0x442d11b0, 0xa7fb0211, 0x7bdc005d, 0x00000000}},  //   _že_, seño, ğrud,
  { {0x3abb00b6, 0x62950142, 0x67220023, 0x00000000}},  //   _תמונ, _rozo, _çojn,
  { {0x941905a7, 0xd4980816, 0x44200016, 0x00000000}},  //   ржат_, бру_, gbi_,
  { {0x62950395, 0x6115005f, 0xb87b0048, 0x00000000}},  // [9030] _pozo, _işlə, llío,
  { {0x7d02002a, 0xf8bf009d, 0x4420006c, 0x00000000}},  //   _lios, lié_, abi_,
  { {0x6f092a65, 0x44200e69, 0x00000000, 0x00000000}},  //   _suec, bbi_,   ,
  { {0xb87b0048, 0x7d0200b4, 0xf8bf0068, 0x00000000}},  //   ilío, _nios, nié_,
  { {0x629508de, 0x6f010ad0, 0xdea1025a, 0x00000000}},  //   _tozo, _pilc, ویری,
  { {0x88cf0044, 0x442b006b, 0xfd110025, 0x00000000}},  //   রতিক, _hec_, وجب_,
  { {0x6f010089, 0x442b023a, 0x3135012b, 0x00000000}},  //   _vilc, _kec_, _фебр,
  { {0x802700a6, 0x7ce50036, 0x6f0100b4, 0x00000000}},  //   _درآم, mórk, _wilc,
  { {0x7d021d59, 0x442b1994, 0xf8bf00f4, 0x00000000}},  //   _dios, _mec_, dié_,
  { {0x443900ca, 0x442b01c5, 0x44200091, 0x00000000}},  //   _lds_, _lec_, zbi_,
  { {0xf8660088, 0xf8bf00f4, 0xb87b0399, 0x00000000}},  //   овно, fié_, rlín,
  { {0x443917cf, 0xc6890104, 0x442b0020, 0x00000000}},  //   _nds_, _בא_, _nec_,
  { {0x2cad0018, 0x442000ca, 0x7c2b01c5, 0x00000000}},  //   mhed_, vbi_, _iegr,
  { {0x394500d4, 0x44391e55, 0x442b00f8, 0x00000000}},  //   puls_, _ads_, _aec_,
  { {0x660309f1, 0x44390082, 0x645d00ea, 0x00000000}},  //   дпра, _bds_, _bbsi,
  { {0x03260265, 0x2cad0030, 0xf8bf00f4, 0x00000000}},  //   ждан, nhed_, cié_,
  { {0x442013a3, 0x7c2b0010, 0x2bf60049, 0x00000000}},  // [9040] rbi_, _megr, ַמען_,
  { {0x7c2b2ef5, 0x442b0009, 0x644f0197, 0x00000000}},  //   _legr, _eec_, _ecci,
  { {0x442b0009, 0xa3e60067, 0x44392ef6, 0x00000000}},  //   _fec_, _फरक_, _fds_,
  { {0x442b0180, 0xf0ba00a1, 0xddc80165, 0x00000000}},  //   _gec_, جائش_, _nadš,
  { {0xf8b300b6, 0x7d020051, 0xbe8a0cee, 0x00000000}},  //   ושא_, _rios, иске_,
  { {0xbea3012b, 0x442b2ef7, 0x7d020036, 0x00000000}},  //   мачк, _zec_, _sios,
  { {0x7d020036, 0x10a6019d, 0x443910be, 0x00000000}},  //   _pios, _дивн, _yds_,
  { {0x442b00f6, 0x2cad0905, 0x14da0061, 0x00000000}},  //   _xec_, ghed_, ढविण,
  { {0x7cc1001e, 0x7c2b00ab, 0xfbcf00a1, 0x00000000}},  //   vērt, _degr, ہتی_,
  { {0x7d020036, 0xb87b0048, 0x2bb70025, 0x00000000}},  //   _wios, tlío, غاية_,
  { {0x29180065, 0xf8bf00f4, 0x7d0200c4, 0x00000000}},  //   ëra_, tié_, _tios,
  { {0x7c2b275e, 0xb87b002a, 0x2cad0133, 0x00000000}},  //   _gegr, rlío, ched_,
  { {0x442b037e, 0x29180ebc, 0x81d60055, 0x00000000}},  //   _rec_, ūra_, াইট_,
  { {0x44390059, 0xaa580389, 0x6ee400d4, 0x00000000}},  //   _sds_, _طلبا_, fòbi,
  { {0x442b0089, 0x25db006e, 0xf8bf0299, 0x00000000}},  //   _pec_, _खुशी_, pié_,
  { {0x291e0129, 0x00000000, 0x00000000, 0x00000000}},  //   mpta_,   ,   ,
  { {0x442b0142, 0x44391eb6, 0x00000000, 0x00000000}},  // [9050] _vec_, _vds_,   ,
  { {0x44390066, 0x04eb0044, 0x7cd3001a, 0x00000000}},  //   _wds_, কদের_, măre,
  { {0x644f00e7, 0x00000000, 0x00000000, 0x00000000}},  //   _tcci,   ,   ,
  { {0x644f0207, 0x4439008e, 0x26c40142, 0x00000000}},  //   _ucci, _uds_, émov_,
  { {0x8e852ef8, 0x7c2b0335, 0xb4d70164, 0x00000000}},  //   згле, _regr, ाकी_,
  { {0x7c2b0207, 0xa137007a, 0x7ce51665, 0x00000000}},  //   _segr, _ورزش, móri,
  { {0x2cad2ef9, 0x62870a61, 0x7ce50e04, 0x00000000}},  //   thed_, _injo, lóri,
  { {0x644d149a, 0x7cc10089, 0x271800b9, 0x00000000}},  //   ngai, vērs, něný_,
  { {0x2cad0030, 0x5f770014, 0x7c2b00ca, 0x00000000}},  //   rhed_, _بازر, _vegr,
  { {0x2cad0038, 0x7c2b0007, 0x00000000, 0x00000000}},  //   shed_, _wegr,   ,
  { {0xa9692efa, 0x60cb0082, 0x2cad0133, 0x00000000}},  //   щина_, ongm, phed_,
  { {0x2904010e, 0x661500b4, 0x00000000, 0x00000000}},  //   öma_, eczk,   ,
  { {0x291e001a, 0x7ce501e5, 0x00000000, 0x00000000}},  //   apta_, jóri,   ,
  { {0x6d430197, 0x00000000, 0x00000000, 0x00000000}},  //   orna,   ,   ,
  { {0x09e2007e, 0x23620022, 0x00000000, 0x00000000}},  //   _пошн, _spkj_,   ,
  { {0x62870181, 0x24990146, 0x00000000, 0x00000000}},  //   _anjo, _cosm_,   ,
  { {0x7ce51b6d, 0x7cd30035, 0x00000000, 0x00000000}},  // [9060] góri, căre,   ,
  { {0x644d2efb, 0x9696012b, 0x6d43016c, 0x00000000}},  //   agai, _хриш, krna,
  { {0x386001d5, 0xd24f0014, 0x869b0049, 0x00000000}},  //   _kbir_, انم_, _הייז,
  { {0x628700ab, 0x6d432efc, 0x2f100129, 0x00000000}},  //   _enjo, drna, _pàg_,
  { {0x4432006a, 0xecd10044, 0x98bf0035, 0x00000000}},  //   may_, াতাড, lută_,
  { {0x4432066d, 0x7f420efe, 0x33200146, 0x00000000}},  //   lay_, rroq, mpix_,
  { {0x4c9401e0, 0xacf807d0, 0x33200253, 0x00000000}},  //   дийс, онку_, lpix_,
  { {0x4432006a, 0x7f420957, 0x00000000, 0x00000000}},  //   nay_, proq,   ,
  { {0x33200d32, 0x6d430051, 0x60c2086f, 0x00000000}},  //   npix_, arna, miom,
  { {0x44320811, 0x60c20a64, 0x644d2efd, 0x00000000}},  //   hay_, liom, zgai,
  { {0x05db0201, 0x4432110c, 0x28f901fb, 0x00000000}},  //   _मुंब, kay_, жень_,
  { {0x48ab013b, 0x44320cec, 0x60c2007f, 0x00000000}},  //   стом_, jay_, niom,
  { {0x44320038, 0x765c0016, 0x2d6e00b9, 0x00000000}},  //   day_, ffry, _hře_,
  { {0x2be10204, 0x291e02e1, 0x6d4a00e7, 0x00000000}},  //   _पडता, ppta_, oufa,
  { {0x6d4a27a4, 0x44322efe, 0x60c22eff, 0x00000000}},  //   nufa, fay_, kiom,
  { {0x7ce502d5, 0x44322f00, 0xb4d7006e, 0x00000000}},  //   tóri, gay_, ाके_,
  { {0x644d1e4a, 0x28580025, 0x78ad1c49, 0x00000000}},  // [9070] rgai, _رؤية_, _ilav,
  { {0x78ad0428, 0x290e0020, 0x644d002d, 0x00000000}},  //   _hlav, _kufa_, sgai,
  { {0x4432006a, 0x7ce50181, 0x26c30059, 0x00000000}},  //   bay_, sóri, mijo_,
  { {0x26c30059, 0x60c20419, 0xd1380245, 0x00000000}},  //   lijo_, giom, яху_,
  { {0x5ec50044, 0x78ad012d, 0x7eaf0292, 0x00000000}},  //   _লীগে, _mlav, _løpe,
  { {0x78ad029a, 0x26c30059, 0x628701d5, 0x00000000}},  //   _llav, nijo_, _unjo,
  { {0x6d4300f4, 0x78ad0052, 0x60c200fa, 0x00000000}},  //   urna, _olav, biom,
  { {0xdb00009d, 0x26c30087, 0x6d430ede, 0x00000000}},  //   lymè, hijo_, rrna,
  { {0x1ee70167, 0x81df0044, 0x765c0016, 0x00000000}},  //   _فوری_, দেশ_, yfry,
  { {0x443201aa, 0x26c30059, 0x6d4a0026, 0x00000000}},  //   zay_, jijo_, bufa,
  { {0x81df08b7, 0x26c3024f, 0x78ad0d79, 0x00000000}},  //   দের_, dijo_, _blav,
  { {0x78ad2f01, 0xb4d7007d, 0x644a0010, 0x00000000}},  //   _clav, ाको_, őfiz,
  { {0x44320263, 0x610c011f, 0x26c30059, 0x00000000}},  //   vay_, _işle, fijo_,
  { {0x44322f02, 0x60c20036, 0x78ad006c, 0x00000000}},  //   way_, ziom, _elav,
  { {0x4432224b, 0x78ad238d, 0x9985007a, 0x00000000}},  //   tay_, _flav, _آلبو,
  { {0x78ad0295, 0x61fa000c, 0x1ad50044, 0x00000000}},  //   _glav, _útli, _হওয়া,
  { {0xa857012e, 0x44322f03, 0x26c30059, 0x00000000}},  // [9080] _חיפה_, ray_, bijo_,
  { {0x4432006a, 0x26c301d9, 0x33200009, 0x00000000}},  //   say_, cijo_, rpix_,
  { {0x4432224b, 0x60c219db, 0x290e00f6, 0x00000000}},  //   pay_, tiom, _xufa_,
  { {0x3b070c0d, 0x3320021f, 0x4fea0216, 0x00000000}},  //   _linq_, ppix_, омен_,
  { {0x60c206aa, 0x60c301aa, 0x3eac00e0, 0x00000000}},  //   riom, ènma, _pldt_,
  { {0xd25206b4, 0x60c20006, 0x6d58000c, 0x00000000}},  //   _جنس_, siom, ttva,
  { {0x60c20026, 0x2138016c, 0x63a40133, 0x00000000}},  //   piom, _uvrh_, lyin,
  { {0x26c30059, 0x5ba60088, 0x629c08d0, 0x00000000}},  //   zijo_, дроз, _horo,
  { {0x6d5820b9, 0x63a401a3, 0x0a6a0b11, 0x00000000}},  //   stva, nyin, орни_,
  { {0x78ad0119, 0x3b0700f4, 0x68e40518, 0x00000000}},  //   _slav, _cinq_, _akid,
  { {0x6da600b8, 0x78ad0209, 0x629c0020, 0x00000000}},  //   _تمام, _plav, _moro,
  { {0xa9c301fb, 0x629c01a3, 0x68f6160e, 0x00000000}},  //   тськ, _loro, _chyd,
  { {0x26c30059, 0x6f081259, 0x2fc00051, 0x00000000}},  //   tijo_, _kidc, úigh_,
  { {0x629c001a, 0xeb97003b, 0x68e40032, 0x00000000}},  //   _noro, _циљ_, _ekid,
  { {0x26c307a0, 0x2a6c0026, 0x7cd30035, 0x00000000}},  //   rijo_, medb_, lăra,
  { {0x6b8207f9, 0x26c30059, 0x63a400ab, 0x00000000}},  //   _krog, sijo_, fyin,
  { {0x7ce50051, 0x26c308fb, 0x00000000, 0x00000000}},  // [9090] mórt, pijo_,   ,
  { {0x27e9011c, 0xddc3001a, 0x2a6c0026, 0x00000000}},  //   _iyan_, nenţ, nedb_,
  { {0x629c0036, 0x610c005d, 0x00000000, 0x00000000}},  //   _doro, _oğlu,   ,
  { {0x38a208ab, 0x92bf0044, 0x63a42f04, 0x00000000}},  //   _fóru_, ঁকে_, byin,
  { {0x629c2f05, 0x63b60046, 0x6f080009, 0x00000000}},  //   _foro, czyn, _bidc,
  { {0xd35600b6, 0x629c2f06, 0x672d00e7, 0x00000000}},  //   _אישי_, _goro, _mwaj,
  { {0xddc3001a, 0x20120051, 0x6114007e, 0x00000000}},  //   denţ, íniú_, _адсу,
  { {0xf1b2007b, 0x6b820190, 0xeb990797, 0x00000000}},  //   _עסן_, _brog, зии_,
  { {0x68f6018e, 0x27e9011c, 0xa6db000c, 0x00000000}},  //   _rhyd, _nyan_, luðu,
  { {0x6b820046, 0xddc3001a, 0xdd95007e, 0x00000000}},  //   _drog, genţ, _пазы,
  { {0x6b820207, 0x27e9011c, 0xa6db000c, 0x00000000}},  //   _erog, _ayan_, nuðu,
  { {0x6b82002d, 0x2d980129, 0x00000000, 0x00000000}},  //   _frog, _àrea_,   ,
  { {0x1b190055, 0x7ba70025, 0x29090066, 0x00000000}},  //   _দিকে_, _تصام, _diaa_,
  { {0x27e9011c, 0x394c0146, 0x9f560010, 0x00000000}},  //   _dyan_, buds_, égét_,
  { {0x629c0e6d, 0x27e900e0, 0x24f61606, 0x00000000}},  //   _roro, _eyan_, ечар,
  { {0x629c0047, 0x68e42f07, 0x63a400b0, 0x00000000}},  //   _soro, _ukid, tyin,
  { {0xd8d70049, 0x4343022a, 0x7ae10026, 0x00000000}},  // [90a0] _רופט_, летв, oolt,
  { {0x63b60036, 0x996e006b, 0x63a40133, 0x00000000}},  //   rzyn, nəş_, ryin,
  { {0x0657007b, 0x629c0035, 0x63b60036, 0x00000000}},  //   _אייך_, _voro, szyn,
  { {0x7ae1000c, 0xddc3001a, 0x63a40133, 0x00000000}},  //   holt, zenţ, pyin,
  { {0x629c0313, 0x6eed0489, 0x7ae12f08, 0x00000000}},  //   _toro, públ, kolt,
  { {0x7cd3001a, 0x1fdf0044, 0x6b820065, 0x00000000}},  //   văra, _বৃহস, _rrog,
  { {0xddc30035, 0x7ae10516, 0x00000000, 0x00000000}},  //   venţ, dolt,   ,
  { {0x91e300da, 0x60c00058, 0x7ce5000c, 0x00000000}},  //   _сосе, _ummm, dórs,
  { {0xddc3001a, 0x7ac6005e, 0xbbca0061, 0x00000000}},  //   tenţ, есне, ापेक,
  { {0x394c0129, 0x27e90837, 0x00000000, 0x00000000}},  //   tuds_, _ryan_,   ,
  { {0x0c2601e1, 0xddc3001a, 0x02b70049, 0x00000000}},  //   _змен, renţ, גליך_,
  { {0xeb9a026b, 0x013700b6, 0x7cd3001a, 0x00000000}},  //   _ние_, ערכת_, păra,
  { {0xfaa62f09, 0x7ae10daf, 0x00000000, 0x00000000}},  //   _падо, bolt,   ,
  { {0x7ae1108c, 0x38a20051, 0x00000000, 0x00000000}},  //   colt, _sórt_,   ,
  { {0x7ce50181, 0x45d406b6, 0x7e7a0479, 0x00000000}},  //   pórt, горс, _matp,
  { {0x672d2f0a, 0x27e90058, 0x00000000, 0x00000000}},  //   _twaj, _tyan_,   ,
  { {0x3255017f, 0x672d0020, 0xcb130049, 0x00000000}},  // [90b0] квар, _uwaj, ָלע_,
  { {0x64480089, 0x7e7a0091, 0x555200a1, 0x00000000}},  //   _ēdie, _natp, دھیر,
  { {0x35f501ee, 0x00000000, 0x00000000, 0x00000000}},  //   _шпор,   ,   ,
  { {0xc5f201f8, 0x7ae10010, 0x90e7069f, 0x00000000}},  //   _כדי_, zolt, رسان,
  { {0x442906fe, 0x64360049, 0xef180088, 0x00000000}},  //   mba_, _בארא_, емі_,
  { {0x4429010a, 0x7bdc005a, 0x8fa2007c, 0x00000000}},  //   lba_, ğrul, раше,
  { {0x7ae104b9, 0x6917001e, 0x442912dd, 0x00000000}},  //   volt, _aģen, oba_,
  { {0xfebb007a, 0x4c85007c, 0x00000000, 0x00000000}},  //   _کارت_, тлив,   ,
  { {0x4429011c, 0x7ae10232, 0x00000000, 0x00000000}},  //   iba_, tolt,   ,
  { {0x44290066, 0x89a9004d, 0x9f040647, 0x00000000}},  //   hba_, дков_, _موقو,
  { {0x44290010, 0x7ae10010, 0x2d9a00ea, 0x00000000}},  //   kba_, rolt, øpet_,
  { {0x442901d5, 0x7ae10ef1, 0xe73a003b, 0x00000000}},  //   jba_, solt, мем_,
  { {0x7c29033b, 0x44290b41, 0x98bf0aec, 0x00000000}},  //   mber, dba_, nutę_,
  { {0xaa450256, 0x44292f0b, 0xbb4203f3, 0x00000000}},  //   _рекл, eba_, _тешк,
  { {0x65c30c27, 0x87070088, 0x7c290032, 0x00000000}},  //   абра, терв_, ober,
  { {0x7c290218, 0x44292f0c, 0xf74a0379, 0x00000000}},  //   nber, gba_, _قلبي_,
  { {0x130a008b, 0x7c29125c, 0x78bd0023, 0x00000000}},  // [90c0] днай_, iber, ërve,
  { {0x4429001a, 0x7c29014a, 0x96fa0025, 0x00000000}},  //   aba_, hber, _تعبر_,
  { {0x44291864, 0xf8c603d7, 0x644b0b33, 0x00000000}},  //   bba_, _लगाय, ógic,
  { {0x64a6007e, 0x4429033f, 0x7e7a023a, 0x00000000}},  //   _рама, cba_, _satp,
  { {0xdfcf0054, 0x7c290193, 0xddc30059, 0x00000000}},  //   ييم_, dber, venš,
  { {0x3ce60030, 0x7c2901a2, 0xb87b0010, 0x00000000}},  //   _skov_, eber, llít,
  { {0x628e00b5, 0x7d0b007f, 0x127b0049, 0x00000000}},  //   _inbo, _bigs, _קאלע,
  { {0x7c290fcf, 0x29180181, 0x3ced00f6, 0x00000000}},  //   gber, íram_, glev_,
  { {0x7d0b01c3, 0xe29f000c, 0x00000000, 0x00000000}},  //   _digs, _guðs_,   ,
  { {0x44290c76, 0xc33300b6, 0xa021000c, 0x00000000}},  //   zba_, סות_, _þörf,
  { {0x7c290207, 0x44290046, 0x7cd30035, 0x00000000}},  //   bber, yba_, căro,
  { {0xa8a70088, 0x8c43007e, 0x00000000, 0x00000000}},  //   трок, _веце,   ,
  { {0x58d401e0, 0x628e016b, 0x44290161, 0x00000000}},  //   роят, _onbo, vba_,
  { {0x6e380009, 0xddda0006, 0x44290554, 0x00000000}},  //   navb, _natū, wba_,
  { {0x26cd0166, 0x55582f0d, 0x00000000, 0x00000000}},  //   đeo_, каря_,   ,
  { {0x628e09ac, 0x442924f2, 0x00000000, 0x00000000}},  //   _anbo, uba_,   ,
  { {0x44292f0e, 0x93f506b6, 0x6d4a010f, 0x00000000}},  // [90d0] rba_, упац, hrfa,
  { {0xf1a7003b, 0x442918e1, 0x7c2916f8, 0x00000000}},  //   крен, sba_, zber,
  { {0xd011023c, 0x7c29005b, 0x25a50039, 0x00000000}},  //   ملا_, yber, älld_,
  { {0xf1c3010a, 0x628e0032, 0x30a7005e, 0x00000000}},  //   _rašė_, _enbo, ързв,
  { {0x7d0b0030, 0xb4c1006e, 0xb87b2f0f, 0x00000000}},  //   _rigs, ्ची_, llís,
  { {0x7d0b01d6, 0x00000000, 0x00000000, 0x00000000}},  //   _sigs,   ,   ,
  { {0x7d0b0058, 0x3ced2f10, 0xc69400b3, 0x00000000}},  //   _pigs, tlev_, יאס_,
  { {0x7c290e9f, 0xb87b0048, 0x7eb400f6, 0x00000000}},  //   uber, ilís, _ràpe,
  { {0x81e80055, 0x3ced0030, 0x7d0b2f11, 0x00000000}},  //   মেদ_, rlev_, _vigs,
  { {0x7c290474, 0x3ced0190, 0x00000000, 0x00000000}},  //   sber, slev_,   ,
  { {0x7c290109, 0xb87b2f12, 0x7d0b00e0, 0x00000000}},  //   pber, roín, _tigs,
  { {0xc3240044, 0x7d0b00d9, 0x00000000, 0x00000000}},  //   _পিসি_, _uigs,   ,
  { {0x2a7c00f6, 0x4c9a00a3, 0xf7720a4f, 0x00000000}},  //   _favb_, _רבנו, حاج_,
  { {0x1bb80070, 0x998500a1, 0x2cad00ab, 0x00000000}},  //   _جامع_, _ملتو, lked_,
  { {0xd46a00ed, 0x628e00f6, 0x2cad0133, 0x00000000}},  //   ниве_, _rnbo, oked_,
  { {0x2cad13ec, 0x00000000, 0x00000000, 0x00000000}},  //   nked_,   ,   ,
  { {0x2f190263, 0xe61a00ed, 0x577a0025, 0x00000000}},  // [90e0] _nèg_, _пдп_, _أصبح_,
  { {0xa6db000c, 0x68e6013e, 0xb87b1ade, 0x00000000}},  //   yrði, lokd, blís,
  { {0x673b1a2d, 0x672401ed, 0xb87b00fa, 0x00000000}},  //   šujt, _htij, clís,
  { {0x25a52f13, 0x26ca00e0, 0x00000000, 0x00000000}},  //   älle_, libo_,   ,
  { {0xe3b2035b, 0xde58008b, 0xbea60454, 0x00000000}},  //   _طرح_, валі_, ладк,
  { {0xf1240167, 0xdee3041f, 0x2ea600a1, 0x00000000}},  //   _نظری, бочи, دھری_,
  { {0xccf800b9, 0x21750478, 0x00000000, 0x00000000}},  //   _opět_, _кутр,   ,
  { {0x248003d4, 0x26ca2f14, 0x6d4a0796, 0x00000000}},  //   ndim_, hibo_, rrfa,
  { {0x24800051, 0x26ca0e20, 0x61ee0016, 0x00000000}},  //   idim_, kibo_, _hybl,
  { {0xee37007e, 0x5a342f15, 0x9e6502fd, 0x00000000}},  //   _бнф_, шнот, _نامن,
  { {0xd917007c, 0x67241727, 0xddc804eb, 0x00000000}},  //   лья_, _atij, _hadž,
  { {0x2cad0038, 0x61ee0082, 0x37d90044, 0x00000000}},  //   cked_, _mybl, _সরবর,
  { {0x0a940500, 0x24800066, 0xdc3b0049, 0x00000000}},  //   _валю, ddim_, _טעאר,
  { {0x4b7b0049, 0xddc80059, 0x29021c27, 0x00000000}},  //   _נאוו, _madž, amka_,
  { {0x68e600ea, 0x61ee1fbf, 0x00000000, 0x00000000}},  //   bokd, _nybl,   ,
  { {0x38c9026c, 0xb4c103d7, 0x00000000, 0x00000000}},  //   _جاتی_, ्चे_,   ,
  { {0x36d50057, 0x925901f9, 0x38690032, 0x00000000}},  // [90f0] _вопр, каат_, _ibar_,
  { {0xccf80224, 0x26ca0b33, 0x2f1901aa, 0x00000000}},  //   _zpět_, cibo_, _règ_,
  { {0x386901d5, 0xa49b00f6, 0xa4d9007e, 0x00000000}},  //   _kbar_, _biòt, _адну_,
  { {0xddc8016c, 0x3aeb0056, 0x61ee005b, 0x00000000}},  //   _badž, løpt_, _dybl,
  { {0x443b005f, 0x38690023, 0x00000000, 0x00000000}},  //   maq_, _mbar_,   ,
  { {0x443b178e, 0x171c0049, 0xa3d400ed, 0x00000000}},  //   laq_, עווע, _ѓорч,
  { {0x38690022, 0xf2d2009b, 0xd658009b, 0x00000000}},  //   _obar_, _ועם_, איות_,
  { {0x0b45017f, 0x443b006b, 0x00000000, 0x00000000}},  //   анин, naq_,   ,
  { {0x2cad2f16, 0xb87b0048, 0x60cb1de5, 0x00000000}},  //   rked_, roíl, migm,
  { {0x4e781095, 0x2cad0018, 0x60cb190e, 0x00000000}},  //   _محمد_, sked_, ligm,
  { {0x67242962, 0xbd4b0379, 0xe8fa01fc, 0x00000000}},  //   _stij, _سؤال_, кло_,
  { {0xa3b502fb, 0x2541010a, 0x76450093, 0x00000000}},  //   जना_, dėl_, _adhy,
  { {0x26ca149a, 0x443b006b, 0x290201ee, 0x00000000}},  //   tibo_, daq_, rmka_,
  { {0x7c3b001a, 0x49b9006d, 0x2b4d00ca, 0x00000000}},  //   laur, _لابد_, mrec_,
  { {0xceb2019b, 0x26ca2412, 0x443b2f17, 0x00000000}},  //   חים_, ribo_, faq_,
  { {0x26ca1eaf, 0x7c3b0f30, 0x6aa32f18, 0x00000000}},  //   sibo_, naur, _honf,
  { {0x60cb049a, 0x24800bf7, 0x03230242, 0x00000000}},  // [9100] digm, rdim_, ждун,
  { {0x7c3b0020, 0x236000b5, 0x6aa307e0, 0x00000000}},  //   haur, rtij_, _jonf,
  { {0x6aa30197, 0x78a400b0, 0x7c3b011c, 0x00000000}},  //   _monf, _koiv, kaur,
  { {0x443b0163, 0x2480005f, 0xef8600ed, 0x00000000}},  //   caq_, qdim_, илеп,
  { {0x6fd60054, 0x7ccd001e, 0x7c3b0c2f, 0x00000000}},  //   جزائ, _mērķ, daur,
  { {0x442001d9, 0x2b4d037a, 0x6aa32f19, 0x00000000}},  //   lci_, drec_, _nonf,
  { {0x6143007e, 0x00000000, 0x00000000, 0x00000000}},  //   _мера,   ,   ,
  { {0x8fa601e0, 0x78a40181, 0xc0e3007c, 0x00000000}},  //   _кабе, _noiv, _доск,
  { {0x4425005f, 0x3d16013d, 0x6aa300c4, 0x00000000}},  //   _əl_, _पूरे_, _bonf,
  { {0x443b006b, 0x78b60006, 0xfaa60900, 0x00000000}},  //   zaq_, _alyv, ршин,
  { {0x81e80055, 0x44200224, 0x021700b3, 0x00000000}},  //   মের_, kci_, יחים_,
  { {0x44200091, 0x7c3b25e9, 0x00000000, 0x00000000}},  //   jci_, caur,   ,
  { {0x78a400f4, 0x442001ca, 0x7c220066, 0x00000000}},  //   _doiv, dci_, _ifor,
  { {0x44200046, 0x6aa303e2, 0xa6db000c, 0x00000000}},  //   eci_, _gonf, yrðu,
  { {0x78b6068f, 0x443b006b, 0x7ae816ec, 0x00000000}},  //   _flyv, taq_, modt,
  { {0x7c220066, 0x64460009, 0x6eed0051, 0x00000000}},  //   _jfor, _cdki, lúbt,
  { {0x443b2ca5, 0x8afd0224, 0x7cfe0065, 0x00000000}},  // [9110] raq_, stře, përf,
  { {0x7c3b0035, 0x44200142, 0x443b11ca, 0x00000000}},  //   zaur, aci_, saq_,
  { {0x442000b9, 0x60cb11c8, 0x443b013f, 0x00000000}},  //   bci_, tigm, paq_,
  { {0x44200207, 0x7c2200ea, 0x443b0d82, 0x00000000}},  //   cci_, _nfor, qaq_,
  { {0x44390129, 0x60cb0058, 0x6d410243, 0x00000000}},  //   _ies_, rigm, _svla,
  { {0x7c22003b, 0x44390bd3, 0x7cd3001a, 0x00000000}},  //   _afor, _hes_, mări,
  { {0x443903f2, 0x63ad011c, 0x7c3b09fb, 0x00000000}},  //   _kes_, lyan, taur,
  { {0xec790364, 0x25d80104, 0x44390007, 0x00000000}},  //   упи_, יוון_, _jes_,
  { {0x63ad0811, 0x60db0020, 0xdcb10011, 0x00000000}},  //   nyan, _ijum, _của_,
  { {0x4439053e, 0x7c3b065c, 0x2b4d0129, 0x00000000}},  //   _les_, saur, rrec_,
  { {0x7c22018e, 0x44392f1a, 0x78a400f4, 0x00000000}},  //   _ffor, _oes_, _poiv,
  { {0x4439010a, 0x63ad2f1b, 0x7c22057b, 0x00000000}},  //   _nes_, kyan, _gfor,
  { {0x442006a6, 0xef190046, 0x63ad0061, 0x00000000}},  //   vci_, _już_, jyan,
  { {0x63ad011c, 0x44392f1c, 0x6aba010f, 0x00000000}},  //   dyan, _aes_, chtf,
  { {0x3ea504bd, 0x44391818, 0x44200142, 0x00000000}},  //   _molt_, _bes_, tci_,
  { {0x4439028c, 0x25a50039, 0x2d87006c, 0x00000000}},  //   _ces_, älla_, ivne_,
  { {0x44392f1d, 0x4420205b, 0x64a30780, 0x00000000}},  // [9120] _des_, rci_, чата,
  { {0x44202f1e, 0x44390004, 0x2912011c, 0x00000000}},  //   sci_, _ees_, _hiya_,
  { {0xc69300b6, 0x44390129, 0x6a3a0049, 0x00000000}},  //   _זאת_, _fes_, רגעפ,
  { {0x7c390066, 0x92d80055, 0x44390039, 0x00000000}},  //   _newr, াতে_, _ges_,
  { {0xf98700a1, 0x7cd3001a, 0x80ca0044, 0x00000000}},  //   _کب_, cări, িকল্,
  { {0x7c220a19, 0xdee3005e, 0x443900b5, 0x00000000}},  //   _sfor, почи, _zes_,
  { {0x11da0054, 0x44390038, 0x609800a1, 0x00000000}},  //   _صورة_, _yes_, _پچاس_,
  { {0x0cb80055, 0x29120811, 0x60db0065, 0x00000000}},  //   ুক্ত, _niya_, _gjum,
  { {0xdfcf0054, 0x99850006, 0xbb470025, 0x00000000}},  //   _كيف_, kalų_, ملين_,
  { {0x9e66007a, 0x68ed0cb2, 0x29000026, 0x00000000}},  //   _دارن, _skad, _ahia_,
  { {0x63ad2f1f, 0x29120f91, 0x7cd3001a, 0x00000000}},  //   zyan, _biya_, zări,
  { {0x2900001d, 0x7c2205b7, 0x7c390112, 0x00000000}},  //   _chia_, _ufor, _gewr,
  { {0x44392f20, 0x657e181d, 0x7d1a002d, 0x00000000}},  //   _res_, _asph, _huts,
  { {0x4439028c, 0x7d1a0004, 0x99850006, 0x00000000}},  //   _ses_, _kuts, galų_,
  { {0x7cfe0065, 0x2ca6006c, 0xa49b00f6, 0x00000000}},  //   përd, _kood_, _biòp,
  { {0x7cd3001a, 0x63ad2f21, 0x2ca60a2a, 0x00000000}},  //   tări, tyan, _jood_,
  { {0x44390c30, 0x7d1a17f6, 0x7eb400f6, 0x00000000}},  // [9130] _ves_, _luts, _nàpo,
  { {0x63ad134e, 0x2d8c049a, 0x44390007, 0x00000000}},  //   ryan, _orde_, _wes_,
  { {0x44392f22, 0x63ad130b, 0x97d8089d, 0x00000000}},  //   _tes_, syan, _نظیر_,
  { {0x443900f6, 0x2ca60007, 0x4395005e, 0x00000000}},  //   _ues_, _nood_, _дамс,
  { {0x6e3a01ee, 0x2d8c0035, 0x3ea500ca, 0x00000000}},  //   _betb, _arde_, _polt_,
  { {0x7d1a00e0, 0x81e80044, 0x867c0049, 0x00000000}},  //   _buts, মেই_, ָרהו,
  { {0x3ea50047, 0x629518a9, 0x2ca600bb, 0x00000000}},  //   _volt_, _inzo, _bood_,
  { {0x60db2984, 0x60c90020, 0x2d8702aa, 0x00000000}},  //   _ujum, _umem, rvne_,
  { {0x2ca606b2, 0x7d1a002d, 0x2d8c010f, 0x00000000}},  //   _dood_, _euts, _erde_,
  { {0x628501d5, 0x29120811, 0x290000e7, 0x00000000}},  //   ndho, _siya_, _shia_,
  { {0x2ca60038, 0x7d1a010f, 0x6ce70088, 0x00000000}},  //   _food_, _guts, _ліде,
  { {0x2ca60038, 0x3f8d0065, 0x9b950025, 0x00000000}},  //   _good_, _kreu_, _ولات,
  { {0x6130000a, 0x629500d9, 0x00000000, 0x00000000}},  //   _kòlò, _onzo,   ,
  { {0x6b892f23, 0x6f1b004a, 0x62852f24, 0x00000000}},  //   mveg, _muuc, jdho,
  { {0x29120058, 0x99850006, 0x6b89010e, 0x00000000}},  //   _tiya_, ralų_, lveg,
  { {0x6295008e, 0x78bd01a2, 0x842a0152, 0x00000000}},  //   _anzo, chsv, ржав_,
  { {0x6b890207, 0x42ca00ed, 0xd6d20025, 0x00000000}},  // [9140] nveg, аган_, _يقع_,
  { {0x7cd3001a, 0x6d431a3a, 0x33d50088, 0x00000000}},  //   măru, ksna, чіст,
  { {0x64a6012b, 0x69c1010f, 0x2c4c0006, 0x00000000}},  //   _дана, nzle, lėdų_,
  { {0xa06a012b, 0x629500bb, 0x3f8d0129, 0x00000000}},  //   рада_, _enzo, _breu_,
  { {0x3f8d2f25, 0x2ca600b5, 0x7d1a0032, 0x00000000}},  //   _creu_, _rood_, _suts,
  { {0x443200b9, 0xde93012b, 0x765c2280, 0x00000000}},  //   lby_, дашњ, ngry,
  { {0x44320716, 0x6d4305ad, 0x2ca6006c, 0x00000000}},  //   oby_, gsna, _pood_,
  { {0x5c980265, 0xa3ae0309, 0xed4f00a1, 0x00000000}},  //   ския_, _कथा_, کھے_,
  { {0xae7a0057, 0x3f8d2f26, 0x320d006b, 0x00000000}},  //   _всех_, _greu_, _şeyx_,
  { {0x2ca600ab, 0x7d1a019a, 0x6d432f27, 0x00000000}},  //   _wood_, _tuts, bsna,
  { {0x44320036, 0xc957007e, 0x765c1938, 0x00000000}},  //   kby_, оўя_, dgry,
  { {0x6d58006c, 0x44322f28, 0x386000e5, 0x00000000}},  //   muva, jby_, _ccir_,
  { {0x6d58003c, 0x44322f29, 0x6bd60a4f, 0x00000000}},  //   luva, dby_, _بتار,
  { {0x3ce91238, 0x00000000, 0x00000000, 0x00000000}},  //   čave_,   ,   ,
  { {0xa3d0006e, 0x610c014a, 0x628300fa, 0x00000000}},  //   _वेब_, _eşli, ônom,
  { {0x44320007, 0xd498058f, 0x19bb009b, 0x00000000}},  //   gby_, ору_, _כמוב,
  { {0x6d58003c, 0x7cd3001a, 0x00000000, 0x00000000}},  // [9150] huva, căru,   ,
  { {0x6d580b3e, 0x291c021e, 0x6d432077, 0x00000000}},  //   kuva, _kuva_, ysna,
  { {0x44320161, 0x6d58016c, 0x628515ef, 0x00000000}},  //   bby_, juva, rdho,
  { {0x3f8d04bd, 0x26d10020, 0x291c0107, 0x00000000}},  //   _preu_, lizo_, _muva_,
  { {0x291c2f2a, 0x69c10133, 0x9ac401f3, 0x00000000}},  //   _luva_, zzle, _keċċ,
  { {0x6d430168, 0x26d10b33, 0x7d022122, 0x00000000}},  //   tsna, nizo_, _ahos,
  { {0x7d020051, 0x6d581462, 0x6d4316a7, 0x00000000}},  //   _bhos, guva, usna,
  { {0x6d4300b5, 0x3f8d0191, 0x7d0204f0, 0x00000000}},  //   rsna, _treu_, _chos,
  { {0x6d432f2b, 0x38a20046, 0x26d10020, 0x00000000}},  //   ssna, _góry_, kizo_,
  { {0x6b890542, 0x7cd3001a, 0x6d58139b, 0x00000000}},  //   rveg, văru, buva,
  { {0x44321124, 0x291c0107, 0x6b892bf1, 0x00000000}},  //   yby_, _cuva_, sveg,
  { {0x291c01ee, 0x7d021b2a, 0xf1b20049, 0x00000000}},  //   _duva_, _ghos, גסט_,
  { {0x7d092f2c, 0x69c10047, 0x44320161, 0x00000000}},  //   mmes, szle, vby_,
  { {0x7d09011f, 0x44320319, 0x26d10020, 0x00000000}},  //   lmes, wby_, gizo_,
  { {0x2a3a0104, 0x6603005e, 0x44320161, 0x00000000}},  //   _העצמ, епра, tby_,
  { {0x03260057, 0x7d09011f, 0x7d0214d3, 0x00000000}},  //   здан, nmes, _xhos,
  { {0x44322be9, 0x26d10009, 0x421a0025, 0x00000000}},  // [9160] rby_, bizo_, مزاج_,
  { {0xb87b27d5, 0xd6c400a6, 0x7d092f2d, 0x00000000}},  //   gníf, _آمدی, hmes,
  { {0x7d091462, 0x7cfe0023, 0x00000000, 0x00000000}},  //   kmes, hëra,   ,
  { {0xd12f039d, 0x88bd013e, 0x00000000, 0x00000000}},  //   امن_, spěv,   ,
  { {0x7d020016, 0x7d09006c, 0x7cfe0023, 0x00000000}},  //   _rhos, dmes, jëra,
  { {0x6d580a0e, 0x61460088, 0xdfcf006d, 0x00000000}},  //   tuva, _нега, ديه_,
  { {0x7d022f2e, 0x20560887, 0xda780027, 0x00000000}},  //   _phos, _нтар, veď_,
  { {0x6d58002b, 0x7d092f2f, 0xa0670478, 0x00000000}},  //   ruva, gmes, _наса_,
  { {0x291c2f30, 0x6d5817ee, 0x00000000, 0x00000000}},  //   _suva_, suva,   ,
  { {0xc33300b6, 0x7d0200ab, 0x6d5803b6, 0x00000000}},  //   עות_, _whos, puva,
  { {0x7d022f31, 0xf8bf009d, 0x7d0903be, 0x00000000}},  //   _thos, thé_, bmes,
  { {0x38bb0065, 0xf8bf00b9, 0x7d092f32, 0x00000000}},  //   _bëra_, uhé_, cmes,
  { {0x26d1000b, 0x00000000, 0x00000000, 0x00000000}},  //   tizo_,   ,   ,
  { {0xba170054, 0x2eee2f33, 0x291c2f34, 0x00000000}},  //   _فيها_, noff_, _tuva_,
  { {0x9608007e, 0x26d1008e, 0x65940a78, 0x00000000}},  //   зэта_, rizo_, нару,
  { {0x6aaa2f35, 0x26d10020, 0x2eee01a2, 0x00000000}},  //   _hoff, sizo_, hoff_,
  { {0x6aaa00c7, 0xd3710025, 0x2eee062a, 0x00000000}},  // [9170] _koff, ضها_, koff_,
  { {0x6aaa002b, 0x6d480107, 0x672d2564, 0x00000000}},  //   _joff, _ovda, _itaj,
  { {0x6aaa002b, 0x2eee00f8, 0x38bb0023, 0x00000000}},  //   _moff, doff_, _zëra_,
  { {0x92bf0044, 0x98a6001a, 0x7f7501bd, 0x00000000}},  //   ুকে_, mplă_, дукц,
  { {0x2489006a, 0x4e940014, 0x8e8500ec, 0x00000000}},  //   mdam_, کشنر, дгле,
  { {0x248928a9, 0x2eee00c4, 0x6aaa002b, 0x00000000}},  //   ldam_, goff_, _noff,
  { {0x7d0908a7, 0xfce502dc, 0x249900d9, 0x00000000}},  //   tmes, моко, _knsm_,
  { {0x645f0066, 0x248904cb, 0x6d481b02, 0x00000000}},  //   ngqi, ndam_, _dvda,
  { {0x23690209, 0x7d092f36, 0x62870173, 0x00000000}},  //   ntaj_, rmes, _kajo,
  { {0xeab10054, 0x7d092f37, 0x6aaa0549, 0x00000000}},  //   ئعة_, smes, _coff,
  { {0x672d0258, 0x6aaa00d9, 0x1eea00a1, 0x00000000}},  //   _ataj, _doff, _بولی_,
  { {0x8d7400a6, 0x2b520279, 0x62872f0c, 0x00000000}},  //   _ساما, üncü_, _lajo,
  { {0xa49b001d, 0x6aaa0009, 0x00000000, 0x00000000}},  //   _phòn, _foff,   ,
  { {0x628709fc, 0x6aaa0016, 0x394700d9, 0x00000000}},  //   _najo, _goff, _tvns_,
  { {0x672d001a, 0xd575189c, 0x00000000, 0x00000000}},  //   _etaj, нуть,   ,
  { {0x38bb0065, 0x00000000, 0x00000000, 0x00000000}},  //   _tëra_,   ,   ,
  { {0x62871ae2, 0xd5b80089, 0x24860027, 0x00000000}},  // [9180] _bajo, šā_, ľom_,
  { {0x6aaa077e, 0x6287008e, 0x24862f38, 0x00000000}},  //   _xoff, _cajo, žom_,
  { {0x62870023, 0x00000000, 0x00000000, 0x00000000}},  //   _dajo,   ,   ,
  { {0x6aaa0309, 0x2587013e, 0x00000000, 0x00000000}},  //   _चक्र, sílá_,   ,
  { {0xe3b20d3a, 0x2eee04b2, 0xcf7a0076, 0x00000000}},  //   _شرح_, toff_, تصاص_,
  { {0x5f9301fc, 0x6700013d, 0xd1320257, 0x00000000}},  //   тишт, ोगिक_, _لمس_,
  { {0x6aaa0a75, 0x78bd01c5, 0x9987007f, 0x00000000}},  //   _roff, ūrvi, _menų_,
  { {0x6aaa2f39, 0x98bf0089, 0x64440058, 0x00000000}},  //   _soff, kstā_, naii,
  { {0xda7a0401, 0x6aaa00d9, 0x7eb400f6, 0x00000000}},  //   оян_, _poff, _làpi,
  { {0x60c22da4, 0x3ce90091, 0x63ab0030, 0x00000000}},  //   lhom, čava_, øgni,
  { {0x6c83026c, 0x28f90245, 0x3257009b, 0x00000000}},  //   رلیم, зень_, וסים_,
  { {0x23690046, 0x60c2009d, 0x7cfe0065, 0x00000000}},  //   ytaj_, nhom, mëro,
  { {0x6aaa002b, 0x24890e8c, 0x672d01f3, 0x00000000}},  //   _toff, vdam_, _qtaj,
  { {0x6aaa068f, 0xe9cf01b2, 0x00000000, 0x00000000}},  //   _uoff, اغی_,   ,
  { {0x62870ba5, 0x7eb400d4, 0xda5b009b, 0x00000000}},  //   _rajo, _càpi, _וכול,
  { {0xb4e901f5, 0x62870023, 0xb4fb0164, 0x00000000}},  //   मके_, _sajo, ्षेप_,
  { {0x248902ae, 0x672d2f3a, 0x60c20066, 0x00000000}},  // [9190] rdam_, _utaj, dhom,
  { {0x23692f3b, 0x24891848, 0x764700a1, 0x00000000}},  //   rtaj_, sdam_, _زیرِ_,
  { {0x2369008d, 0x62870010, 0x7cfe0023, 0x00000000}},  //   staj_, _vajo, jëro,
  { {0xe3b000a1, 0x60c21ec6, 0x62870b43, 0x00000000}},  //   درہ_, ghom, _wajo,
  { {0x442909fc, 0x442b0145, 0x62872f3c, 0x00000000}},  //   mca_, _ifc_, _tajo,
  { {0x44290059, 0x60c20009, 0x442b0dea, 0x00000000}},  //   lca_, ahom, _hfc_,
  { {0x3f84001e, 0x442900fa, 0x60c200ea, 0x00000000}},  //   _esmu_, oca_, bhom,
  { {0x60c20046, 0x442b02d4, 0x00000000, 0x00000000}},  //   chom, _jfc_,   ,
  { {0x4429001a, 0xfe7500ed, 0x7cfe0065, 0x00000000}},  //   ica_, _плаќ, përn,
  { {0xde97004b, 0x3eac01e3, 0x4429128e, 0x00000000}},  //   _تجرب, _godt_, hca_,
  { {0x644f0036, 0x98bf0006, 0x78ad00c4, 0x00000000}},  //   _odci, nutė_, _boav,
  { {0x44291470, 0x7eb40129, 0x2d852f3d, 0x00000000}},  //   jca_, _ràpi, _isle_,
  { {0x44290027, 0x249e0011, 0xeb9908f3, 0x00000000}},  //   dca_, _đtm_, _хил_,
  { {0x09e52f3e, 0x4429001c, 0x442b0145, 0x00000000}},  //   _полн, eca_, _afc_,
  { {0x442900ca, 0x60c20fcf, 0x99850025, 0x00000000}},  //   fca_, yhom, _ألبو,
  { {0x4429001c, 0x442b01aa, 0x4619007e, 0x00000000}},  //   gca_, _cfc_, ьцяў_,
  { {0x4256005e, 0x442b10f0, 0xa3fe0044, 0x00000000}},  // [91a0] етет, _dfc_, ংখ্য_,
  { {0x44290f04, 0x60c20066, 0xae0f007d, 0x00000000}},  //   aca_, whom, ाधान_,
  { {0x2726001d, 0x60c21e3c, 0x442b1e3c, 0x00000000}},  //   _hôn_, thom, _ffc_,
  { {0x44290198, 0x70f60054, 0xb87b0802, 0x00000000}},  //   cca_, رسائ, mníc,
  { {0xb87b0802, 0x7416025a, 0x00000000, 0x00000000}},  //   lníc, _سوسا,   ,
  { {0x7cfe008d, 0x27262f3f, 0x7c2b2f40, 0x00000000}},  //   tëro, _môn_, _afgr,
  { {0x91e60751, 0x629c0051, 0x27262f41, 0x00000000}},  //   _чове, _inro, _lôn_,
  { {0x7c290129, 0x63a40066, 0xd01200a1, 0x00000000}},  //   gcer, oxin, _ملز_,
  { {0xdcfa001a, 0x63a42f42, 0x27260082, 0x00000000}},  //   _astă, nxin, _nôn_,
  { {0x44290211, 0x7c291278, 0x78ad2f43, 0x00000000}},  //   zca_, acer, _soav,
  { {0x7cfe0065, 0x44292f44, 0xb87b01ca, 0x00000000}},  //   qëro, yca_, jníc,
  { {0xb87b004f, 0x7c290197, 0x6016005d, 0x00000000}},  //   dníc, ccer, _gümü,
  { {0x27260011, 0x6f1a00ab, 0x629c00bb, 0x00000000}},  //   _côn_, _kitc, _onro,
  { {0x44290046, 0x68e4008e, 0x442b0133, 0x00000000}},  //   wca_, _ejid, _sfc_,
  { {0x44290d0a, 0x6d4a00ea, 0x442b14ba, 0x00000000}},  //   tca_, nsfa, _pfc_,
  { {0x442901c5, 0x629c00ea, 0x6d4a0270, 0x00000000}},  //   uca_, _anro, isfa,
  { {0x44292f45, 0x98bf000d, 0x395e00f6, 0x00000000}},  // [91b0] rca_, astă_, luts_,
  { {0xa3d0001c, 0xb87b01ca, 0xa1950147, 0x00000000}},  //   _वेळ_, bníc, казч,
  { {0x395e0129, 0x44290046, 0xa2b2007d, 0x00000000}},  //   nuts_, pca_, _आकर्,
  { {0x6d4a05fe, 0x9f350088, 0x4429006b, 0x00000000}},  //   dsfa, веді, qca_,
  { {0x27260011, 0x6f1a0133, 0x395e0022, 0x00000000}},  //   _xôn_, _bitc, huts_,
  { {0xf77400a0, 0x6f080082, 0x60161a6f, 0x00000000}},  //   רקס_, _chdc, _sümü,
  { {0xada5005e, 0x6d4a00f8, 0x7c2901c5, 0x00000000}},  //   тайл, gsfa, tcer,
  { {0xeb990797, 0x00000000, 0x00000000, 0x00000000}},  //   дии_,   ,   ,
  { {0x26c10181, 0x76470009, 0xa49b00f6, 0x00000000}},  //   _olho_, kajy, _diòx,
  { {0x68f62f46, 0x7c29051b, 0x6d4a0296, 0x00000000}},  //   _skyd, scer, bsfa,
  { {0x395e0129, 0xbbeb00a1, 0x27260016, 0x00000000}},  //   guts_, _کرام_, _sôn_,
  { {0x2d9816ad, 0xb87b004f, 0x26c12f47, 0x00000000}},  //   _área_, vníc, _alho_,
  { {0x63a4002b, 0xfd100a4f, 0xa3d0013d, 0x00000000}},  //   xxin, _اجل_, _वें_,
  { {0x395e2f48, 0xb87b0428, 0x2909002d, 0x00000000}},  //   buts_, tníc, _ehaa_,
  { {0xe64307e1, 0x26c10142, 0x395e21f6, 0x00000000}},  //   респ, _dlho_, cuts_,
  { {0x27260011, 0xb87b01ca, 0x63a423ca, 0x00000000}},  //   _tôn_, rníc, txin,
  { {0x46ea07ca, 0xb87b01ca, 0x935916c1, 0x00000000}},  // [91c0] _один_, sníc, ерху_,
  { {0xb87b0062, 0x6d4a005b, 0x00000000, 0x00000000}},  //   pníc, ysfa,   ,
  { {0x26d80285, 0x67242f49, 0xe45f01a2, 0x00000000}},  //   miro_, _huij, _blöd_,
  { {0x6d58001c, 0x26d80922, 0x6d4a032e, 0x00000000}},  //   vrva, liro_, vsfa,
  { {0x6f1a00ab, 0xc0a90380, 0x2243035f, 0x00000000}},  //   _pitc, عامل_, _fejk_,
  { {0x26d80061, 0x6d4a0210, 0x6d580161, 0x00000000}},  //   niro_, tsfa, trva,
  { {0x7cfe0023, 0x67242f4a, 0x6f1a0082, 0x00000000}},  //   sërm, _luij, _vitc,
  { {0x7cfe0065, 0x76470009, 0x6d4a00f8, 0x00000000}},  //   përm, zajy, rsfa,
  { {0xc4d3009b, 0x6d4a0210, 0x7bc9010f, 0x00000000}},  //   יגה_, ssfa, gzeu,
  { {0xbe8505f3, 0x395e02d0, 0x2480010f, 0x00000000}},  //   _مجمو, tuts_, heim_,
  { {0x26d80c35, 0x02b70049, 0x248016c2, 0x00000000}},  //   diro_, דליך_, keim_,
  { {0x26d82346, 0x395e01c5, 0x61fc0156, 0x00000000}},  //   eiro_, ruts_, _myrl,
  { {0x26d800c4, 0x672400d9, 0x76470943, 0x00000000}},  //   firo_, _cuij, tajy,
  { {0xbc1b00b6, 0x26d80032, 0x672400d9, 0x00000000}},  //   _חודש, giro_, _duij,
  { {0x25b80061, 0xa5f806f3, 0x04672063, 0x00000000}},  //   gyrl_, веру_, ктам,
  { {0x54542e00, 0xba17009b, 0x00000000, 0x00000000}},  //   ивст, _בחוץ_,   ,
  { {0xc29909c0, 0x26d82f4b, 0x38690026, 0x00000000}},  // [91d0] нках_, biro_, _icar_,
  { {0x26d80061, 0x78bd0168, 0xc6f8007c, 0x00000000}},  //   ciro_, lksv, _иных_,
  { {0x7bc900f8, 0x00000000, 0x00000000, 0x00000000}},  //   zzeu,   ,   ,
  { {0x61fc0f4b, 0x78bd0fcf, 0x00000000, 0x00000000}},  //   _dyrl, nksv,   ,
  { {0x78bd2f4c, 0x8afd00b9, 0xb9ff007d, 0x00000000}},  //   iksv, stři, _उर्फ_,
  { {0x623402a8, 0x61fc2f4d, 0x0e640088, 0x00000000}},  //   _веру, _fyrl, икін,
  { {0x518401ee, 0x00000000, 0x00000000, 0x00000000}},  //   _кута,   ,   ,
  { {0x7d760025, 0x764501c3, 0x00000000, 0x00000000}},  //   امير_, _lehy,   ,
  { {0xec7607d0, 0x2b150088, 0x26d800e7, 0x00000000}},  //   упы_, льор, yiro_,
  { {0x7bc9010f, 0x59850d15, 0x672400d9, 0x00000000}},  //   rzeu, глоб, _ruij,
  { {0x26d8007f, 0xdd910084, 0x00000000, 0x00000000}},  //   viro_, _دوا_,   ,
  { {0x26d8005b, 0x00000000, 0x00000000, 0x00000000}},  //   wiro_,   ,   ,
  { {0x1cb80014, 0x7c3b03a1, 0x6724008e, 0x00000000}},  //   _جالب_, mbur, _quij,
  { {0x7c3b022b, 0x00000000, 0x00000000, 0x00000000}},  //   lbur,   ,   ,
  { {0x649a00d7, 0x26d80061, 0x93c800a1, 0x00000000}},  //   нтар_, riro_, ھارہ_,
  { {0x77860265, 0xa7d6031d, 0x7c3b2f4e, 0x00000000}},  //   _близ, _متخص, nbur,
  { {0xe29a01f9, 0x78ad00b9, 0x7c3b2f4f, 0x00000000}},  // [91e0] наа_, žová, ibur,
  { {0x76450116, 0x24802f50, 0x7cfe0023, 0x00000000}},  //   _gehy, seim_, tërk,
  { {0x25a50002, 0x3aba0049, 0x0219007e, 0x00000000}},  //   ällt_, עמענ, віць_,
  { {0x64a6008b, 0x7c3b2f51, 0x70560439, 0x00000000}},  //   _сама, jbur, انشا,
  { {0x7c3b07b8, 0x6d412f52, 0x00000000, 0x00000000}},  //   dbur, _awla,   ,
  { {0x6446055b, 0x7cfe2f53, 0x3ce60030, 0x00000000}},  //   _heki, mëri, _sjov_,
  { {0x44220022, 0x64460095, 0x628e00e0, 0x00000000}},  //   _kgk_, _keki, _iabo,
  { {0x7c3b146c, 0x628e2f54, 0x40950986, 0x00000000}},  //   gbur, _habo, _крут,
  { {0x7cfe0065, 0x28a8013d, 0xe0d501ab, 0x00000000}},  //   nëri, गानि, _тюрь,
  { {0x4974005c, 0x628e0ae3, 0x7c3b0288, 0x00000000}},  //   алос, _jabo, abur,
  { {0x6d41018e, 0x628e22fc, 0xe9f90082, 0x00000000}},  //   _gwla, _mabo, _đả_,
  { {0x6446179b, 0x628e0b25, 0x7cfe0065, 0x00000000}},  //   _neki, _labo, këri,
  { {0x7c22002d, 0x7cfe0065, 0x00000000, 0x00000000}},  //   _igor, jëri,   ,
  { {0x442d0df0, 0x44220145, 0x00000000, 0x00000000}},  //   _że_, _agk_,   ,
  { {0x644602ae, 0x05bb025a, 0x442202d4, 0x00000000}},  //   _beki, ردست_, _bgk_,
  { {0x7c2201f3, 0x64462f55, 0x628e0058, 0x00000000}},  //   _jgor, _ceki, _aabo,
  { {0x628e011c, 0xd25b2f56, 0x7cfe0023, 0x00000000}},  // [91f0] _babo, еце_, gëri,
  { {0x628e0181, 0xf8bf01dc, 0x7c3b0db7, 0x00000000}},  //   _cabo, lké_, zbur,
  { {0xb87b002a, 0x7c3b2f57, 0x7c220213, 0x00000000}},  //   nnío, ybur, _ogor,
  { {0x64460007, 0x7c220016, 0x38bb0065, 0x00000000}},  //   _geki, _ngor, _bëri_,
  { {0x8fa5091b, 0xb87b0051, 0x628e0032, 0x00000000}},  //   рале, hnío, _fabo,
  { {0x7c222f58, 0x628e002d, 0xed590077, 0x00000000}},  //   _agor, _gabo, вок_,
  { {0x56b801ce, 0x00000000, 0x00000000, 0x00000000}},  //   רפון_,   ,   ,
  { {0x628e0119, 0x644600f6, 0xa9270062, 0x00000000}},  //   _zabo, _xeki, _leží,
  { {0x628e18aa, 0x4b25003b, 0x00000000, 0x00000000}},  //   _yabo, јмов,   ,
  { {0x7c3b037f, 0x7c2228f4, 0x2b4d00e5, 0x00000000}},  //   sbur, _egor, rsec_,
  { {0xceb80046, 0x7c3b0007, 0x38bb0065, 0x00000000}},  //   _więc_, pbur, _zëri_,
  { {0x7c220087, 0x00000000, 0x00000000, 0x00000000}},  //   _ggor,   ,   ,
  { {0x6446021e, 0xfaa50451, 0x903a0049, 0x00000000}},  //   _reki, _вало, כערה,
  { {0x64460149, 0x98ab001e, 0x7c220059, 0x00000000}},  //   _seki, ībā_, _zgor,
  { {0xb8cc0055, 0x628e0f5d, 0x44220085, 0x00000000}},  //   _গত_, _rabo, _pgk_,
  { {0xf8bf004f, 0x628e016e, 0x7cfe0065, 0x00000000}},  //   cké_, _sabo, tëri,
  { {0x628e011c, 0xc24600a8, 0x6446014a, 0x00000000}},  // [9200] _pabo, инак, _veki,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x442201a3, 0x7cfe0023, 0x86c60014, 0x00000000}},  //   _tgk_, sëri, _ميکن,
  { {0x7cfe008d, 0x2cad002b, 0x628e0020, 0x00000000}},  //   përi, jjed_, _wabo,
  { {0x7cfe0065, 0xddd800b9, 0xa0670216, 0x00000000}},  //   qëri, devš, рача_,
  { {0xf8bf00b9, 0x7c222f59, 0x00000000, 0x00000000}},  //   zké_, _sgor,   ,
  { {0x91e30131, 0xf65308cd, 0x00000000, 0x00000000}},  //   _доре, קצה_,   ,
  { {0x320a025d, 0x00000000, 0x00000000, 0x00000000}},  //   _izby_,   ,   ,
  { {0xef1a0200, 0x04180055, 0xcb670025, 0x00000000}},  //   _ама_, ধুরী_, لميه_,
  { {0x657e2f5a, 0x63ab04ce, 0x00000000, 0x00000000}},  //   _opph, ägni,   ,
  { {0xd90f00d3, 0x5d860025, 0x00000000, 0x00000000}},  //   ویت_, _خلال,   ,
  { {0x7c220232, 0x00000000, 0x00000000, 0x00000000}},  //   _ugor,   ,   ,
  { {0xdb02001f, 0x69c50004, 0x27ed014a, 0x00000000}},  //   _groß, _ühen, çen_,
  { {0xf8bf004f, 0x4b7b0049, 0x657e0022, 0x00000000}},  //   ské_, _סאוו, _bpph,
  { {0xd5b80517, 0x3a3700a0, 0xb87b0802, 0x00000000}},  //   аст_, _דרום_, lním,
  { {0x2d8c0b3d, 0x32c4006b, 0x09331289, 0x00000000}},  //   _msde_, _röya_, _بروج,
  { {0x5399007c, 0x04f401ff, 0x81b40044, 0x00000000}},  // [9210] ывая_, ізую, _জেল_,
  { {0xd7fc009b, 0x2d870036, 0x395e00bb, 0x00000000}},  //   _בהחל, ywne_, orts_,
  { {0x21270011, 0xdcfa0036, 0x2f09000c, 0x00000000}},  //   ênh_, _wstę, júga_,
  { {0x859a009b, 0xe0d00379, 0x00000000, 0x00000000}},  //   _עשרו, وزن_,   ,
  { {0x644d01c2, 0xa283007a, 0x61ee0009, 0x00000000}},  //   maai, _ویرو, _exbl,
  { {0x644d0007, 0x141a00b3, 0xb87b093f, 0x00000000}},  //   laai, _תושב, dním,
  { {0xd658009b, 0x62852f5b, 0x00000000, 0x00000000}},  //   ביות_, meho,   ,
  { {0x62850740, 0x644d00bb, 0x7cfe0023, 0x00000000}},  //   leho, naai, zërv,
  { {0x1c420147, 0x395e0270, 0x7b06000c, 0x00000000}},  //   чным, erts_, rðun,
  { {0x62850292, 0x2cbf2f5c, 0x2cad0243, 0x00000000}},  //   neho, skud_, sjed_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe73a0081, 0x7c841ab7, 0x3ff90049, 0x00000000}},  //   лем_, _муче, ָפֿע,
  { {0x62850056, 0xeaae022a, 0x8ca4013d, 0x00000000}},  //   keho, _ей_, कारो,
  { {0x6285016e, 0x6b8901a2, 0x00000000, 0x00000000}},  //   jeho, mweg,   ,
  { {0xceb2061e, 0x68e6001c, 0x80b80055, 0x00000000}},  //   ליך_, pnkd, _আগস্,
  { {0x70b6006e, 0x644d0328, 0x6b890036, 0x00000000}},  //   _अकेल, gaai, oweg,
  { {0x78a401aa, 0x6b892f5d, 0xa5071fd9, 0x00000000}},  // [9220] _iniv, nweg, сета_,
  { {0x62850286, 0x78b6008e, 0x644d01c3, 0x00000000}},  //   geho, _hoyv, aaai,
  { {0x78a40239, 0x657e05ce, 0x26da01f3, 0x00000000}},  //   _kniv, _upph, _impo_,
  { {0x764e0473, 0x00000000, 0x00000000, 0x00000000}},  //   laby,   ,   ,
  { {0x44320036, 0xbef50061, 0x5fd20061, 0x00000000}},  //   mcy_, ेतून_, _देखल,
  { {0xdfa50054, 0x764e0016, 0xb87b0802, 0x00000000}},  //   تحمي, naby, vním,
  { {0x171b007b, 0x78a40173, 0x67dc0089, 0x00000000}},  //   נוצע, _oniv, lājī,
  { {0x44320038, 0x6cd4002c, 0xccf90036, 0x00000000}},  //   ncy_, تقبا, goś_,
  { {0x60c2000c, 0x39ae005f, 0xe81a007d, 0x00000000}},  //   mkom, məsi_, नेमा_,
  { {0x78a40181, 0x39ae006b, 0xa954003b, 0x00000000}},  //   _aniv, ləsi_, овољ,
  { {0x69c5006c, 0x60c20089, 0x395e009d, 0x00000000}},  //   _ühel, okom, urts_,
  { {0x60c202ae, 0x23601088, 0x66cb014a, 0x00000000}},  //   nkom, krij_, _müke,
  { {0x02fa013d, 0xb87b01ca, 0x44320036, 0x00000000}},  //   ्ताह_, lník, dcy_,
  { {0x39ae006b, 0x98bf0006, 0x644d2f5e, 0x00000000}},  //   həsi_, putį_, waai,
  { {0x60c201d5, 0x7afa1382, 0xd6d810e1, 0x00000000}},  //   kkom, mott, стя_,
  { {0xf98f0054, 0x60c200b5, 0x7cfe0023, 0x00000000}},  //   _أبو_, jkom, përu,
  { {0x60c20146, 0x62850052, 0x644d00c7, 0x00000000}},  // [9230] dkom, teho, raai,
  { {0x7afa13d7, 0x32550099, 0x60c201d6, 0x00000000}},  //   nott, івер, ekom,
  { {0x39ae006b, 0x6285066d, 0x644d174d, 0x00000000}},  //   fəsi_, reho, paai,
  { {0x7afa0ba4, 0x60c20828, 0x212a0051, 0x00000000}},  //   hott, gkom, _dubh_,
  { {0x7afa00b0, 0x68ed2f5f, 0x6285037a, 0x00000000}},  //   kott, _mjad, peho,
  { {0x24ab0044, 0xad591c21, 0x7afa2f60, 0x00000000}},  //   _ঐতিহ, арих_, jott,
  { {0x7afa2f61, 0x39ae006b, 0x68ed2f62, 0x00000000}},  //   dott, bəsi_, _ojad,
  { {0x2b5f2f63, 0x6b892f64, 0x39ae006b, 0x00000000}},  //   truc_, tweg, cəsi_,
  { {0xb87b00b9, 0x63ad2f65, 0x6b8900bb, 0x00000000}},  //   mníh, nxan, uweg,
  { {0xb87b01ca, 0x63ad00d4, 0x6b892f66, 0x00000000}},  //   lníh, ixan, rweg,
  { {0x6b89010f, 0xfbd9013d, 0x7cfe0023, 0x00000000}},  //   sweg, _बेरम, tërt,
  { {0xb87b013e, 0x7ae800e5, 0x764e0045, 0x00000000}},  //   nníh, andt, waby,
  { {0x7afa0039, 0x69d90061, 0x764e2f67, 0x00000000}},  //   bott, _फेरी, taby,
  { {0x44320046, 0x7afa0207, 0x272f014a, 0x00000000}},  //   wcy_, cott, _dün_,
  { {0x60c908b2, 0x7cfe0065, 0x764e0101, 0x00000000}},  //   _olem, përt, raby,
  { {0x764e0061, 0xa3ea00ed, 0x236000bb, 0x00000000}},  //   saby, адба_, trij_,
  { {0x272f038c, 0x44320036, 0xb87b01ca, 0x00000000}},  // [9240] _gün_, rcy_, dníh,
  { {0x44320036, 0x60db11a8, 0x59de007d, 0x00000000}},  //   scy_, _amum, _फेडर,
  { {0x60c200b5, 0x39ae005f, 0x60c90048, 0x00000000}},  //   tkom, təsi_, _blem,
  { {0x7afa0047, 0xb87b0428, 0x03a600ed, 0x00000000}},  //   zott, vník, _димо,
  { {0x60c202ae, 0x39ae006b, 0x888d0049, 0x00000000}},  //   rkom, rəsi_, טראַ,
  { {0x66cb2f68, 0x39ae006b, 0x61460069, 0x00000000}},  //   _tüke, səsi_, _мега,
  { {0x60c90030, 0x6da3025f, 0x7afa00b0, 0x00000000}},  //   _flem, дија, vott,
  { {0x4127005c, 0x60c92cba, 0xa067026b, 0x00000000}},  //   _фото_, _glem, _маса_,
  { {0x7afa0047, 0x2aaa01fc, 0x8e760783, 0x00000000}},  //   tott, атно_, _мужч,
  { {0x7cfe0065, 0x00000000, 0x00000000, 0x00000000}},  //   tërs,   ,   ,
  { {0x7afa09f0, 0xd8f90088, 0x29000022, 0x00000000}},  //   rott, йної_, _bkia_,
  { {0x7afa0010, 0x2d9e004a, 0xa9c30088, 0x00000000}},  //   sott, _irte_, фськ,
  { {0x7afa0052, 0xdc290025, 0xdb24006c, 0x00000000}},  //   pott, _اسمه_, öpäe,
  { {0x6b820026, 0x7cfe0023, 0xb87b013e, 0x00000000}},  //   _ipog, përs, zníh,
  { {0x344b003b, 0x7bc0007f, 0xc4db003b, 0x00000000}},  //   ичан_, lymu, ађа_,
  { {0x63ad2f69, 0x00000000, 0x00000000, 0x00000000}},  //   txan,   ,   ,
  { {0xb87b00b9, 0x68fd0065, 0x00000000, 0x00000000}},  // [9250] vníh, mosd,   ,
  { {0x60c92f6a, 0x63ad2f6b, 0x2d9e010f, 0x00000000}},  //   _slem, rxan, _orte_,
  { {0x672d0065, 0xb87b00b9, 0x60c90466, 0x00000000}},  //   _huaj, tníh, _plem,
  { {0x397b0049, 0x15fa009b, 0x7bc00006, 0x00000000}},  //   שטאנ, _להתע, kymu,
  { {0x2d9e022b, 0x9028008b, 0xb87b00b9, 0x00000000}},  //   _arte_, іцца_, rníh,
  { {0x672d0065, 0x7bc00006, 0xb87b00b9, 0x00000000}},  //   _muaj, dymu, sníh,
  { {0xf2d2007b, 0x672d0065, 0x2d9e11af, 0x00000000}},  //   _װען_, _luaj, _crte_,
  { {0x60db0169, 0x60c92f6c, 0x2489001a, 0x00000000}},  //   _umum, _ulem, neam_,
  { {0x7cfe0065, 0x200d002d, 0x62950253, 0x00000000}},  //   tërr, _uzei_, _kazo,
  { {0x0b42008b, 0xdd950783, 0x69c5006c, 0x00000000}},  //   эньн, _назы, _ühek,
  { {0x62950036, 0x672d0020, 0xf76900a3, 0x00000000}},  //   _mazo, _auaj, _תק_,
  { {0x62952f6d, 0x68fd004a, 0x00000000, 0x00000000}},  //   _lazo, gosd,   ,
  { {0x2489001a, 0x672d008e, 0x6fbd0316, 0x00000000}},  //   deam_, _cuaj, ्निं,
  { {0x62950738, 0x6b9b0045, 0x672d0023, 0x00000000}},  //   _nazo, mvug, _duaj,
  { {0x64a6132e, 0x00000000, 0x00000000, 0x00000000}},  //   пава,   ,   ,
  { {0x01c30055, 0x6fbd01f5, 0xb87b00b9, 0x00000000}},  //   ্পাদ, ्नां, riíc,
  { {0x62952c1f, 0x672d0b33, 0xe45f0039, 0x00000000}},  // [9260] _bazo, _guaj, _glöm_,
  { {0x6295004a, 0x7ae10052, 0x479b009b, 0x00000000}},  //   _cazo, nilt, _פייס,
  { {0x69c10010, 0xe9f90011, 0x7bc01f00, 0x00000000}},  //   nyle, _đẻ_, zymu,
  { {0x7ae10032, 0x2489001a, 0xb35801b2, 0x00000000}},  //   hilt, ceam_, _ویزا_,
  { {0x7ae101aa, 0x6295003b, 0x4393007e, 0x00000000}},  //   kilt, _fazo, _заўс,
  { {0x62950036, 0x69c104d3, 0x63a9251b, 0x00000000}},  //   _gazo, kyle, _šeng,
  { {0x6b821a99, 0x51550769, 0xb87b013e, 0x00000000}},  //   _spog, _отту, mnív,
  { {0x2124002a, 0x66cb006b, 0x7bc00006, 0x00000000}},  //   _uimh_, _müka, tymu,
  { {0xfc3f0211, 0x66cb006c, 0x00000000, 0x00000000}},  //   ñía_, _lüka,   ,
  { {0x7f3b00b6, 0x672d0065, 0x7ae1049d, 0x00000000}},  //   _לעמו, _ruaj, gilt,
  { {0x2d9e022b, 0x68fd01d6, 0xe29b0049, 0x00000000}},  //   _urte_, tosd, זשיר,
  { {0xab5d0036, 0x05000044, 0x7ae10048, 0x00000000}},  //   wyże, ্দুর_, ailt,
  { {0x7ae1022b, 0x672d0065, 0x68fd2f6e, 0x00000000}},  //   bilt, _quaj, rosd,
  { {0x672d0065, 0x96eb1280, 0x69c1199e, 0x00000000}},  //   _vuaj, сьма_, byle,
  { {0x248913ba, 0x62950213, 0x672501c2, 0x00000000}},  //   team_, _razo, _vihj,
  { {0x672d0065, 0xb9250025, 0x7d0200f6, 0x00000000}},  //   _tuaj, _تفعي, _jkos,
  { {0x629501ee, 0x248900ab, 0x7d022f6f, 0x00000000}},  // [9270] _pazo, ream_, _mkos,
  { {0x97360049, 0x23690023, 0x00000000, 0x00000000}},  //   _קרתא_, ruaj_,   ,
  { {0x7d020010, 0x6295007f, 0x75260032, 0x00000000}},  //   _okos, _vazo, _fikz,
  { {0xc5f200b6, 0x7ae101aa, 0x0467007c, 0x00000000}},  //   _ידי_, zilt, _этом,
  { {0x443900f8, 0x442b00f6, 0x644f0089, 0x00000000}},  //   _ifs_, _igc_, _ieci,
  { {0xc3320049, 0xde050216, 0xc7d8009b, 0x00000000}},  //   _בוך_, мпли, הודי_,
  { {0x644f0149, 0xd164005e, 0x693a0066, 0x00000000}},  //   _keci, _пъти, _jċed,
  { {0x644f1547, 0x442b0022, 0x645a0089, 0x00000000}},  //   _jeci, _jgc_, _ētik,
  { {0xeb99005e, 0x644f001a, 0x442b00f6, 0x00000000}},  //   цип_, _meci, _mgc_,
  { {0x644f0036, 0x4439007f, 0x442b04a5, 0x00000000}},  //   _leci, _lfs_, _lgc_,
  { {0xa88a0c4e, 0x7ae100b0, 0x44390051, 0x00000000}},  //   ойна_, rilt, _ofs_,
  { {0x7ae100b0, 0x66d00052, 0x442b08d0, 0x00000000}},  //   silt, _mäke, _ngc_,
  { {0x66d00039, 0x7d1b010e, 0x7c2b0066, 0x00000000}},  //   _läke, mmus, _iggr,
  { {0x69c11624, 0x7d1b010e, 0x645d2f70, 0x00000000}},  //   pyle, lmus, _adsi,
  { {0xcb1200b6, 0x442b0009, 0x66d000b0, 0x00000000}},  //   _שלו_, _bgc_, _näke,
  { {0xf50a01e1, 0xe8f60025, 0x65610010, 0x00000000}},  //   інал_, _تستخ, álha,
  { {0x44390179, 0x073a0025, 0x442b0146, 0x00000000}},  // [9280] _dfs_, _بسبب_, _dgc_,
  { {0x244c0011, 0x7d09010f, 0x05000044, 0x00000000}},  //   ếm_, hles, ্দের_,
  { {0x2734021e, 0x63a901d5, 0x7d090161, 0x00000000}},  //   _hän_, _ġene, kles,
  { {0x7d090047, 0x44390288, 0x644f2f71, 0x00000000}},  //   jles, _gfs_, _geci,
  { {0x2d85000a, 0x7d1b010e, 0x7d090133, 0x00000000}},  //   _aple_, dmus, dles,
  { {0x7c2b19eb, 0x27340039, 0xbea304b6, 0x00000000}},  //   _aggr, _män_, качк,
  { {0x27340039, 0x7d0901bc, 0x3d0a0061, 0x00000000}},  //   _län_, fles, ातले_,
  { {0x1ee8009c, 0x7d090213, 0x997200b9, 0x00000000}},  //   _کوئی_, gles, těže_,
  { {0x2d8500ea, 0x00000000, 0x00000000, 0x00000000}},  //   _eple_,   ,   ,
  { {0x7d090ede, 0x00000000, 0x00000000, 0x00000000}},  //   ales,   ,   ,
  { {0x7d090056, 0x7d1b00d4, 0x7c390016, 0x00000000}},  //   bles, bmus, _ffwr,
  { {0x7d09002b, 0x7d020aee, 0x6d580c31, 0x00000000}},  //   cles, _ukos, msva,
  { {0xad1b007b, 0x644f0781, 0xb33b0181, 0x00000000}},  //   _וואר, _reci, _orça,
  { {0x644f2f72, 0x443900f8, 0x5bb701e1, 0x00000000}},  //   _seci, _sfs_, _юлія_,
  { {0x6d5804d3, 0xef0e007e, 0x44390085, 0x00000000}},  //   nsva, ымi_, _pfs_,
  { {0x7d00040e, 0xc98301ee, 0x6d5801b1, 0x00000000}},  //   noms, _руши, isva,
  { {0x66d00073, 0xbf0e007d, 0x442b00d9, 0x00000000}},  // [9290] _säke, िताभ_, _vgc_,
  { {0xd25101f7, 0x6716006e, 0x6d580894, 0x00000000}},  //   انا_, _दीपक_, ksva,
  { {0x7d092a44, 0x7d002f73, 0x644f0181, 0x00000000}},  //   yles, koms, _teci,
  { {0x645d0030, 0x90150245, 0x6d58032e, 0x00000000}},  //   _udsi, нфлі, dsva,
  { {0x8e8504f9, 0x6d5a01c9, 0xe8d800a3, 0x00000000}},  //   егле, _avta, וואר_,
  { {0x2d95004c, 0x7a310010, 0x7d092f74, 0x00000000}},  //   ерис, _műté, wles,
  { {0x7d09006c, 0xdce8005d, 0x7d1b006b, 0x00000000}},  //   tles, _ardı, tmus,
  { {0x9f510010, 0xcf7b0025, 0x6aaa0016, 0x00000000}},  //   ából_, _وإذا_, _anff,
  { {0x7d090292, 0x7d1b006c, 0x76550036, 0x00000000}},  //   rles, rmus, kazy,
  { {0x7d1b0c53, 0x39450e09, 0xeab10054, 0x00000000}},  //   smus, нног, اعة_,
  { {0x7d1b06d3, 0x88e6007c, 0x00000000, 0x00000000}},  //   pmus, ежне,   ,
  { {0xe0bd0044, 0x6d430203, 0x1dd80061, 0x00000000}},  //   _আগুন, mpna, _भेटत,
  { {0x6d432118, 0xbbeb023c, 0x00000000, 0x00000000}},  //   lpna, _برام_,   ,
  { {0x27340039, 0x76550036, 0x290b016c, 0x00000000}},  //   _vän_, gazy, alca_,
  { {0x48e6012d, 0x24990035, 0xb87b00f6, 0x00000000}},  //   _покв, _basm_, gnís,
  { {0x05000055, 0x7a310010, 0x27340052, 0x00000000}},  //   ্দ্র_, _fűté, _tän_,
  { {0x3860002a, 0x29020006, 0x00000000, 0x00000000}},  // [92a0] _idir_, moka_,   ,
  { {0x29022f75, 0x68e6006b, 0x6306083e, 0x00000000}},  //   loka_, likd, روال,
  { {0xdcff00b9, 0x7d0000e7, 0x56370049, 0x00000000}},  //   ívěs, yoms, _ראטע_,
  { {0x25a50030, 0x29022f76, 0x2615006e, 0x00000000}},  //   ælle_, noka_, _धरती_,
  { {0x64562f77, 0x70530014, 0x656e011c, 0x00000000}},  //   mayi, انها, lubh,
  { {0x6d580039, 0x6d430009, 0x290214ad, 0x00000000}},  //   tsva, fpna, hoka_,
  { {0x29022f78, 0xe9f90011, 0x7d000213, 0x00000000}},  //   koka_, _đế_, toms,
  { {0x24800f6e, 0x645609e5, 0xdd8e00a1, 0x00000000}},  //   nfim_, nayi, لوڈ_,
  { {0x7d000010, 0x29020a6e, 0x1e8600c0, 0x00000000}},  //   roms, doka_, _плам,
  { {0xdce30089, 0x64560058, 0x7d0002e1, 0x00000000}},  //   runā, hayi, soms,
  { {0xfbcf01ef, 0x290213e1, 0x64560e6a, 0x00000000}},  //   لتی_, foka_, kayi,
  { {0x29022f79, 0x64560022, 0x00000000, 0x00000000}},  //   goka_, jayi,   ,
  { {0x64560f99, 0x8ae60088, 0x3ebe010e, 0x00000000}},  //   dayi, _пікл, _kott_,
  { {0x3860005f, 0x3ebe0b5e, 0x2499016c, 0x00000000}},  //   _edir_, _jott_, _sasm_,
  { {0x3a37007b, 0x29020056, 0x64560173, 0x00000000}},  //   _ארום_, boka_, fayi,
  { {0x3ebe002b, 0x64560a5f, 0xade30061, 0x00000000}},  //   _lott_, gayi, _कइसन_,
  { {0x66cb2f7a, 0xc299085f, 0x78ad0020, 0x00000000}},  // [92b0] _yükl, мках_, _inav,
  { {0x320a00e5, 0x3ebe03c2, 0x00000000, 0x00000000}},  //   _byby_, _nott_,   ,
  { {0x64560111, 0x78ad00ca, 0xa5f9007c, 0x00000000}},  //   bayi, _knav, _цену_,
  { {0x64560095, 0x00000000, 0x00000000, 0x00000000}},  //   cayi,   ,   ,
  { {0x3ebe00f8, 0x78ad00e7, 0x00000000, 0x00000000}},  //   _bott_, _mnav,   ,
  { {0x290210d2, 0xdb0201d6, 0xaca700a1, 0x00000000}},  //   zoka_, _droë, کھئے_,
  { {0x3ebe0207, 0xf08200a1, 0x395c00d9, 0x00000000}},  //   _dott_, _چیمپ, _nvvs_,
  { {0x6b84001a, 0x3eac08e0, 0x3ebe00d9, 0x00000000}},  //   _ţiga, _endt_, _eott_,
  { {0x66d00039, 0x98a8001a, 0x2902007f, 0x00000000}},  //   _läka, _lună_, voka_,
  { {0x3ebe2f7b, 0x78ad2f7c, 0x6d4306a1, 0x00000000}},  //   _gott_, _anav, ppna,
  { {0x2902000b, 0x186a026b, 0x6f0300b4, 0x00000000}},  //   toka_, мани_, monc,
  { {0x48e600e3, 0x6f03008e, 0x2369016e, 0x00000000}},  //   томв, lonc, kraj_,
  { {0x290201d9, 0xda0d0164, 0x5bc401af, 0x00000000}},  //   roka_, _हरकत_, _متوف,
  { {0x6f032f7d, 0x8a050467, 0x7c3b00b5, 0x00000000}},  //   nonc, _изле, lcur,
  { {0x6456011c, 0xa50a00ed, 0x290201e5, 0x00000000}},  //   tayi, дева_, poka_,
  { {0x78ad0190, 0x320a08e2, 0x03f60044, 0x00000000}},  //   _gnav, _ryby_, _আরবী_,
  { {0x645601aa, 0xa507243a, 0x68e40056, 0x00000000}},  // [92c0] rayi, тета_, _imid,
  { {0x645600ea, 0x69c5006c, 0x6f03009d, 0x00000000}},  //   sayi, _ühes, jonc,
  { {0x6456000a, 0x3ebe010e, 0x6d410066, 0x00000000}},  //   payi, _rott_, _ntla,
  { {0x6456006b, 0x3ebe0e5d, 0x4fea007c, 0x00000000}},  //   qayi, _sott_, ммен_,
  { {0x6f0300f4, 0x6d41191c, 0x3ebe141a, 0x00000000}},  //   fonc, _atla, _pott_,
  { {0x1ee60014, 0x6f030145, 0x7c3b00d9, 0x00000000}},  //   ضوعی_, gonc, ecur,
  { {0x180f0183, 0x68e400e5, 0x91e60264, 0x00000000}},  //   _सर्व_, _omid, _рове,
  { {0xc5f3009b, 0xdb98041f, 0x5ba60581, 0x00000000}},  //   ידו_, евич_, вроз,
  { {0xcb6703f3, 0x629c01d5, 0x09ca0204, 0x00000000}},  //   вање_, _karo, ान्य,
  { {0x60c02f7e, 0x629c07e4, 0x705300a1, 0x00000000}},  //   _homm, _jaro, _منہا,
  { {0x60c029f9, 0x629c205b, 0xddc80036, 0x00000000}},  //   _komm, _maro, _wedł,
  { {0xcfa9026c, 0x629c006a, 0xc173009b, 0x00000000}},  //   _تاہم_, _laro, סחר_,
  { {0x48e4007e, 0x60c0066d, 0x98a80035, 0x00000000}},  //   роўв, _momm, _sună_,
  { {0x629c0a0f, 0x60c00030, 0x68e40026, 0x00000000}},  //   _naro, _lomm, _emid,
  { {0xd6d801fb, 0xe5c40888, 0xa4d50088, 0x00000000}},  //   ття_, асто, гові,
  { {0x629c103f, 0x60c01b30, 0x78ad0a13, 0x00000000}},  //   _aaro, _nomm, _unav,
  { {0x629c2f7f, 0x7b320046, 0x63a60bf8, 0x00000000}},  // [92d0] _baro, _dług, _crkn,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c805a6, 0x66cb006c, 0x7c3b0009, 0x00000000}},  //   nyde, _lükk, ycur,
  { {0x60c0028a, 0x26c10ca9, 0x69da0032, 0x00000000}},  //   _comm, _hoho_, izte,
  { {0x6f030211, 0x60c02f80, 0x629c0285, 0x00000000}},  //   tonc, _domm, _faro,
  { {0x629c1729, 0xaf04007e, 0x26c11135, 0x00000000}},  //   _garo, апіл, _joho_,
  { {0x8d54008b, 0xf075026c, 0x7c3b0085, 0x00000000}},  //   атыч, _میاں_, tcur,
  { {0x60c00207, 0xe8140061, 0x6f0304e7, 0x00000000}},  //   _gomm, _ठरला_, sonc,
  { {0x7c3b000d, 0x6f030062, 0x629c013f, 0x00000000}},  //   rcur, ponc, _yaro,
  { {0x7c3b001a, 0x68e42f81, 0x66cb014a, 0x00000000}},  //   scur, _smid, _dükk,
  { {0xaad9013d, 0x6d41093b, 0x59ca0164, 0x00000000}},  //   योगक, _utla, ानगर,
  { {0xf7462f82, 0x63a90066, 0x00000000, 0x00000000}},  //   лемо, _ġenn,   ,
  { {0x6b650099, 0x2d0f001c, 0x7b06000c, 0x00000000}},  //   _скла, ातील_, rður,
  { {0x5a47008b, 0x69c80030, 0xdbd1006c, 0x00000000}},  //   _рэда, byde, _müüm,
  { {0x629c0285, 0x98b90089, 0x7cfe01c3, 0x00000000}},  //   _raro, ūrā_, eëry,
  { {0x68e405b7, 0x629c0010, 0x97c601d8, 0x00000000}},  //   _umid, _saro, _مقبو,
  { {0xdd030006, 0x00000000, 0x00000000, 0x00000000}},  // [92e0] ūrėj,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60c00f69, 0x10a600ed, 0x2caf00f6, 0x00000000}},  //   _pomm, лижн, _ongd_,
  { {0xd12f0076, 0x26c122d1, 0xa09a0025, 0x00000000}},  //   سمه_, _zoho_, عضاء_,
  { {0x69c80036, 0x08770049, 0x69da008e, 0x00000000}},  //   zyde, רענט_, zzte,
  { {0x63a4000c, 0xdd9a003b, 0xf8bf009d, 0x00000000}},  //   mvin, еши_, mmée_,
  { {0x63a400ab, 0xf8bf009d, 0x00000000, 0x00000000}},  //   lvin, lmée_,   ,
  { {0xbd870379, 0x63a4143d, 0x212d01f3, 0x00000000}},  //   انين_, ovin, _gieh_,
  { {0x63a40a16, 0x66d00039, 0x4fa30088, 0x00000000}},  //   nvin, _räkn, _литв,
  { {0x69da001f, 0x69c804d7, 0xe45f021e, 0x00000000}},  //   tzte, tyde, _ylös_,
  { {0x26c10020, 0xd2b7009b, 0x7c8600aa, 0x00000000}},  //   _roho_, אלית_, _буле,
  { {0x69c82f83, 0xa3e50061, 0x8dfb009b, 0x00000000}},  //   ryde, _भइल_, _אהבת,
  { {0x69da0047, 0x81bc0055, 0x63a402ae, 0x00000000}},  //   szte, েছি_, jvin,
  { {0x99d6004b, 0x98bf0006, 0x2d8c0093, 0x00000000}},  //   _متعا, ystė_, _kpde_,
  { {0x58d5007c, 0x69c5010e, 0x63a40f12, 0x00000000}},  //   _войт, _ühep, evin,
  { {0x290f0051, 0x84c400ed, 0xb8670076, 0x00000000}},  //   _óga_, бљуд, _صابو,
  { {0x395e001e, 0x26c10428, 0x63a42f84, 0x00000000}},  // [92f0] lsts_, _toho_, gvin,
  { {0x5215007e, 0x66d000f8, 0x00000000, 0x00000000}},  //   адзт, _jäkl,   ,
  { {0x4615007a, 0x66d00039, 0xb035034b, 0x00000000}},  //   _خودر, _mäkl, анеш,
  { {0x395e01c5, 0x5f750014, 0x00000000, 0x00000000}},  //   ists_, لاتر,   ,
  { {0x644d04be, 0x926b06e3, 0xb4c30316, 0x00000000}},  //   mbai, _прва_, ्सी_,
  { {0x395e001e, 0xddc500ed, 0xa3de0061, 0x00000000}},  //   ksts_, ибли, _थेट_,
  { {0xfc310025, 0xbd450025, 0xc6940104, 0x00000000}},  //   يحة_, جنبي, מאס_,
  { {0xff150055, 0x644d022b, 0x999c0010, 0x00000000}},  //   াদেশ_, nbai, _nevű_,
  { {0x395e04bd, 0x00000000, 0x00000000, 0x00000000}},  //   ests_,   ,   ,
  { {0x752f0046, 0x62850051, 0x89a90256, 0x00000000}},  //   _licz, nfho, вков_,
  { {0x63a9012d, 0x63a40471, 0x00000000, 0x00000000}},  //   _šenl, zvin,   ,
  { {0x63a42f85, 0x752f0036, 0xd82602e9, 0x00000000}},  //   yvin, _nicz, идни,
  { {0x26d80016, 0xdcf40521, 0x395e0133, 0x00000000}},  //   thro_, _šaći, asts_,
  { {0x63a40066, 0x5f360049, 0x00000000, 0x00000000}},  //   vvin, יטשע_,   ,
  { {0x2d53001a, 0x09e200ed, 0x00000000, 0x00000000}},  //   nţe_, _мошн,   ,
  { {0x8a140014, 0x47c60152, 0x628501d6, 0x00000000}},  //   _اظها, _вбив, efho,
  { {0x63a40145, 0x68fd0010, 0x60c90066, 0x00000000}},  // [9300] uvin, érde, _ċemp,
  { {0x55e60c45, 0xf8bf00f4, 0x2366007f, 0x00000000}},  //   _вооб, rmée_, šojo_,
  { {0xddc32f86, 0x00000000, 0x00000000, 0x00000000}},  //   vanş,   ,   ,
  { {0xb358026c, 0x39a5001e, 0x765c13a7, 0x00000000}},  //   _میرا_, _mēs_, lary,
  { {0x98a6026d, 0xd007007e, 0xb1860146, 0x00000000}},  //   nslı_, аеце_, _blåø,
  { {0x765c066b, 0x5d660594, 0xfaf90006, 0x00000000}},  //   nary, атиз, irūs_,
  { {0xdce1014a, 0x69c70030, 0x00000000, 0x00000000}},  //   _aslı, øjel,   ,
  { {0x0ca70057, 0x656e002a, 0xfbe70044, 0x00000000}},  //   атьи_, irbh, _পড়ত,
  { {0x225806b2, 0x765c2f87, 0xafe60ad9, 0x00000000}},  //   _kerk_, kary, _тоал,
  { {0x225801a3, 0x0f7b00a3, 0x644d2efd, 0x00000000}},  //   _jerk_, _באמב, zbai,
  { {0x765c010a, 0x20f80006, 0x00000000, 0x00000000}},  //   dary, nčio_,   ,
  { {0x395e0089, 0x76572f88, 0x1bea0797, 0x00000000}},  //   rsts_, _sexy, _идеи_,
  { {0x98bf0089, 0x765c0016, 0x3949297f, 0x00000000}},  //   lstī_, fary, _čase_,
  { {0x765c0a71, 0x8c1b0104, 0x2b460022, 0x00000000}},  //   gary, _סוגי, _itoc_,
  { {0x7afd00d4, 0x6abc000c, 0x00000000, 0x00000000}},  //   éste, örfu,   ,
  { {0x04c90025, 0x693a01f3, 0xc4d8003b, 0x00000000}},  //   دوري_, _jċem, ађу_,
  { {0xe3b00025, 0x941917a4, 0x284a0049, 0x00000000}},  // [9310] ورك_, ужат_, _געפּ,
  { {0xf1a70920, 0xf69907d8, 0x644d0009, 0x00000000}},  //   ирен, _свој_, sbai,
  { {0x28cc013d, 0x00000000, 0x00000000, 0x00000000}},  //   ासचि,   ,   ,
  { {0x62850051, 0x00000000, 0x00000000, 0x00000000}},  //   sfho,   ,   ,
  { {0x225800d0, 0x4fa5005e, 0xddc100e5, 0x00000000}},  //   _ferk_, силв, _belş,
  { {0xaaa6006e, 0x20180025, 0x273d0082, 0x00000000}},  //   _कोलक, جتمع_, _mìn_,
  { {0x0204007e, 0xad580147, 0x2c130044, 0x00000000}},  //   _дзён, арых_, _হলেই_,
  { {0x85f8009b, 0x22580032, 0xe5f8009b, 0x00000000}},  //   יצוע_, _zerk_, יזור_,
  { {0x6d4a0048, 0x765c0058, 0x861a000a, 0x00000000}},  //   apfa, yary, _rapٍ_,
  { {0x7b320036, 0x9f95006c, 0x00000000, 0x00000000}},  //   _słuc, _müüa_,   ,
  { {0x39e901e0, 0x765c2f89, 0x2a7c00f6, 0x00000000}},  //   удно_, vary, _dcvb_,
  { {0x765c2f8a, 0x6575012d, 0x00000000, 0x00000000}},  //   wary, duzh,   ,
  { {0xfaa5008b, 0x765c163c, 0xdc360049, 0x00000000}},  //   _гало, tary, _האנט_,
  { {0x2cbf2f8b, 0xe73700ed, 0x7d090016, 0x00000000}},  //   ljud_, сер_, loes,
  { {0x765c224b, 0x66d001b1, 0x2aba009b, 0x00000000}},  //   rary, _häkk, _תמצא,
  { {0x765c00d2, 0xd3ba0088, 0x81bd0044, 0x00000000}},  //   sary, лузі_, ইনা_,
  { {0x75240a3e, 0x22580145, 0x273d0082, 0x00000000}},  // [9320] rmiz, _perk_, _gìn_,
  { {0x05080044, 0x7d092f8c, 0x00000000, 0x00000000}},  //   লগের_, hoes,   ,
  { {0x225829b1, 0x98b90006, 0x3ced2f8d, 0x00000000}},  //   _verk_, ūrą_, kiev_,
  { {0x22582f8e, 0x20f8007f, 0x00000000, 0x00000000}},  //   _werk_, rčio_,   ,
  { {0x0eea01fb, 0x787b0049, 0x20f80006, 0x00000000}},  //   льки_, אָוו, sčio_,
  { {0xdb0200c4, 0x11d60783, 0x52751026, 0x00000000}},  //   _proí, _любя, _мусу,
  { {0x64430046, 0x2b462f8f, 0xddc10010, 0x00000000}},  //   śnie, _stoc_, _belő,
  { {0x6d4a01a2, 0xc1f7009b, 0x00000000, 0x00000000}},  //   rpfa, _המלץ_,   ,
  { {0x8c432337, 0x00000000, 0x00000000, 0x00000000}},  //   чење,   ,   ,
  { {0xfbcf0076, 0x63ab1c8c, 0xd90f02fd, 0x00000000}},  //   عتي_, ågni, کیب_,
  { {0x2d9800f4, 0x7d0900c4, 0xddc10010, 0x00000000}},  //   _ère_, boes, _felő,
  { {0x7d0906c2, 0x021700b3, 0x2d9e1238, 0x00000000}},  //   coes, מחים_, _iste_,
  { {0x61e0006b, 0x00000000, 0x00000000, 0x00000000}},  //   _əmla,   ,   ,
  { {0x81de0055, 0xf4000044, 0x2eee0145, 0x00000000}},  //   _তখন_, ্ধার_, niff_,
  { {0x2d9e0224, 0x9f95006c, 0x00000000, 0x00000000}},  //   _jste_, _süüa_,   ,
  { {0x2eee01a2, 0x6575012d, 0x00000000, 0x00000000}},  //   hiff_, ruzh,   ,
  { {0x20f8099d, 0x68ef1ad1, 0x290b150d, 0x00000000}},  // [9330] rčil_, micd, moca_,
  { {0x8c1b019b, 0x290b029d, 0x2d9e0190, 0x00000000}},  //   רומי, loca_, _oste_,
  { {0x399a0ebc, 0xa2bf007d, 0x00000000, 0x00000000}},  //   _jūs_, लॉग्,   ,
  { {0x399a0089, 0x7e680009, 0x30150069, 0x00000000}},  //   _mūs_, _addp, одер,
  { {0x2d9e022b, 0x49180097, 0x6d480089, 0x00000000}},  //   _aste_, זקאל_, _atda,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7d091b3c, 0x290b26e4, 0x31c42f90, 0x00000000}},  //   toes, koca_, _еств,
  { {0x645f005f, 0x3c2f006b, 0x62970e04, 0x00000000}},  //   naqi, _növü_, lexo,
  { {0x2d9e2f91, 0x7d091d58, 0x8c640025, 0x00000000}},  //   _este_, roes, سطين,
  { {0x05ba02f4, 0x399a001e, 0x38692f92, 0x00000000}},  //   _उपलब, _būs_, _adar_,
  { {0xe8fa013b, 0x7d090007, 0xe0d000a1, 0x00000000}},  //   ило_, poes, _غزہ_,
  { {0xa3d9013d, 0x00000000, 0x00000000, 0x00000000}},  //   ़ना_,   ,   ,
  { {0x68fd008e, 0x98160257, 0x00000000, 0x00000000}},  //   érda, تبدا,   ,
  { {0xf3ff00c4, 0x38690145, 0x00000000, 0x00000000}},  //   _adão_, _edar_,   ,
  { {0xceb20452, 0x62970061, 0x845a0265, 0x00000000}},  //   וים_, dexo, ират_,
  { {0x6aa30016, 0x9e3c06b8, 0x290b00c4, 0x00000000}},  //   _hanf, _maďa, coca_,
  { {0xb6a601bd, 0xd3f40245, 0x20f8016c, 0x00000000}},  // [9340] _дипл, нiст, učim_,
  { {0x6aa30032, 0x78a42c4f, 0x00000000, 0x00000000}},  //   _janf, _haiv,   ,
  { {0x6aa3033b, 0x78a400b0, 0xdb0b0065, 0x00000000}},  //   _manf, _kaiv, _argë,
  { {0x6aa301aa, 0x78a62f93, 0x78a4004a, 0x00000000}},  //   _lanf, ndkv, _jaiv,
  { {0xdfd00014, 0x2eee2f94, 0x64430036, 0x00000000}},  //   عيت_, tiff_, śnic,
  { {0x78a42f95, 0x6aa3000a, 0x00000000, 0x00000000}},  //   _laiv, _nanf,   ,
  { {0x20d71355, 0x628e01f3, 0x63a9002b, 0x00000000}},  //   _için_, _ibbo, _ġeni,
  { {0x78a4041a, 0x66cb01f6, 0xdb0b00c4, 0x00000000}},  //   _naiv, _yüks, _urgê,
  { {0xfb86008b, 0x394901d9, 0x00000000, 0x00000000}},  //   цыйн, _časa_,   ,
  { {0xcb1a01f9, 0x6aa30016, 0x00000000, 0x00000000}},  //   јќи_, _canf,   ,
  { {0x09f80054, 0x7afd064d, 0x2d9e022b, 0x00000000}},  //   صفحة_, ésta, _uste_,
  { {0x7aef0211, 0x78a40026, 0xfaf801c5, 0x00000000}},  //   éctr, _caiv, snī_,
  { {0x3f860181, 0x6035006b, 0x68ef006b, 0x00000000}},  //   ntou_, _həmç, ricd,
  { {0xa3ae03d7, 0x387f03b2, 0x6aa30016, 0x00000000}},  //   किन_, żur_, _ganf,
  { {0x290b001a, 0x58d50f93, 0x6297077d, 0x00000000}},  //   poca_, _нокт, vexo,
  { {0x628e01bc, 0x6aa32f96, 0x78a40dc0, 0x00000000}},  //   _abbo, _zanf, _gaiv,
  { {0x645f008d, 0x60c2012d, 0x00000000, 0x00000000}},  // [9350] raqi, djom,   ,
  { {0x238e0089, 0x3f9f0022, 0x00000000, 0x00000000}},  //   dējā_, _rsuu_,   ,
  { {0x78a400e7, 0x00000000, 0x00000000, 0x00000000}},  //   _yaiv,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x645d2f97, 0xa4f90061, 0xcf9b003b, 0x00000000}},  //   _iesi, ्कीच_, рје_,
  { {0x6da52f98, 0x63af1978, 0x8d550920, 0x00000000}},  //   зика, _ircn, птич,
  { {0xb146007a, 0x645d288b, 0x6aa301aa, 0x00000000}},  //   _فیلم_, _kesi, _ranf,
  { {0xdd8e0b59, 0x645d1222, 0x6aa301a2, 0x00000000}},  //   اوي_, _jesi, _sanf,
  { {0x645d2f99, 0x60db00d6, 0x78a40ac2, 0x00000000}},  //   _mesi, _ilum, _raiv,
  { {0x645d000c, 0x68ed0181, 0x44390207, 0x00000000}},  //   _lesi, _amad, _lgs_,
  { {0x4efa0049, 0x60db0193, 0xaf080025, 0x00000000}},  //   _פלעג, _klum, _بقلم_,
  { {0x645d0a76, 0x44390319, 0x3ea503a1, 0x00000000}},  //   _nesi, _ngs_, _halt_,
  { {0x3ea52f9a, 0x78a400b0, 0x6aa30010, 0x00000000}},  //   _kalt_, _vaiv, _tanf,
  { {0x44392008, 0x60db0129, 0x68ed006c, 0x00000000}},  //   _ags_, _llum, _emad,
  { {0x645d1200, 0x60db014a, 0x78a400b0, 0x00000000}},  //   _besi, _olum, _taiv,
  { {0x60c900b5, 0x934600ed, 0x2748001a, 0x00000000}},  //   _noem, знае, _pînă_,
  { {0x645d0038, 0x2d87006c, 0x44390095, 0x00000000}},  // [9360] _desi, htne_, _dgs_,
  { {0x60db04bd, 0x2d870c30, 0x64440087, 0x00000000}},  //   _alum, ktne_, scii,
  { {0x60db119b, 0x60c901d6, 0x68ed0016, 0x00000000}},  //   _blum, _boem, _ymad,
  { {0x645d2f9b, 0x55bb009b, 0x4439059c, 0x00000000}},  //   _gesi, _המטו, _ggs_,
  { {0x60c92f9c, 0x3ea506ed, 0x4463005e, 0x00000000}},  //   _doem, _balt_, _явяв,
  { {0xa3e50204, 0x3f8605d2, 0x2d8710c1, 0x00000000}},  //   _भेट_, rtou_, ftne_,
  { {0x3f862f9d, 0x3ea504bd, 0x60db0181, 0x00000000}},  //   stou_, _dalt_, _flum,
  { {0x2900000b, 0x60db2f9e, 0xd1320025, 0x00000000}},  //   _njia_, _glum, _أمر_,
  { {0x613a00b9, 0x3ea505ed, 0x00000000, 0x00000000}},  //   _důle, _falt_,   ,
  { {0x3ea5068f, 0x68ed0dc5, 0xada604b6, 0x00000000}},  //   _galt_, _smad, _назл,
  { {0x1ea9006d, 0xa7fb004a, 0xdd8f0647, 0x00000000}},  //   _باقي_, daña, _مول_,
  { {0xfce307ca, 0x00000000, 0x00000000, 0x00000000}},  //   _похо,   ,   ,
  { {0x645d114e, 0x44390006, 0xcce50426, 0x00000000}},  //   _resi, _rgs_, _تسلي,
  { {0x645d2f9f, 0xa7fb008e, 0x765e0022, 0x00000000}},  //   _sesi, gaña, _cepy,
  { {0x645d04d4, 0x5678007c, 0x44390082, 0x00000000}},  //   _pesi, ября_, _pgs_,
  { {0x5fbe0183, 0xba1700b3, 0x7afc0059, 0x00000000}},  //   ्हाल, _מחוץ_, črtu,
  { {0xd90f00e9, 0x645d00b0, 0x60c90112, 0x00000000}},  // [9370] _لیگ_, _vesi, _roem,
  { {0x60db0039, 0x2919002b, 0x60c90352, 0x00000000}},  //   _slum, llsa_, _soem,
  { {0x645d27b5, 0x68fd2fa0, 0x60c901cb, 0x00000000}},  //   _tesi, onsd, _poem,
  { {0x68fd03e3, 0x63a9016c, 0x39ac013e, 0x00000000}},  //   nnsd, _šenu, _měs_,
  { {0xbea502dc, 0x2724000c, 0x765e026d, 0x00000000}},  //   далк, bönd_, _yepy,
  { {0x7c390016, 0xa159007e, 0x63ad2fa1, 0x00000000}},  //   _sgwr, _магу_, mvan,
  { {0x63ad121e, 0x3ea523c3, 0xa19400e3, 0x00000000}},  //   lvan, _valt_, _парч,
  { {0x3ea50ace, 0x2d871553, 0x9f5f0010, 0x00000000}},  //   _walt_, rtne_, áról_,
  { {0x63ad00c7, 0x2d8721e1, 0x3ea52fa2, 0x00000000}},  //   nvan, stne_, _talt_,
  { {0x39450057, 0xab5d0036, 0x291200ea, 0x00000000}},  //   мног, wyżs, _skya_,
  { {0x6dd50167, 0x7e630052, 0xf2d20104, 0x00000000}},  //   _تقاض, manp, דעי_,
  { {0x7e632fa3, 0x39400059, 0x63ad03fc, 0x00000000}},  //   lanp, _čist_, kvan,
  { {0x691d00f4, 0x2724010f, 0xe79c014a, 0x00000000}},  //   péen, höne_, _düğü,
  { {0x63ad0030, 0x6b8910ba, 0xdce3012d, 0x00000000}},  //   dvan, mteg, munđ,
  { {0x6b89022b, 0x044601e0, 0x63ad0142, 0x00000000}},  //   lteg, дебн, evan,
  { {0xdb020023, 0x6b890288, 0x7e6325b9, 0x00000000}},  //   _proç, oteg, hanp,
  { {0xfa8e001d, 0xccf2009b, 0xa7fb004a, 0x00000000}},  // [9380] _mừng_, דכן_, paña,
  { {0x6b89002d, 0xfa8e0082, 0x38600a6b, 0x00000000}},  //   iteg, _lừng_, _heir_,
  { {0x63a90059, 0xa87a0049, 0x7e63016e, 0x00000000}},  //   _šent, ַאַר, danp,
  { {0x63ad0173, 0xdb022fa4, 0x657c0052, 0x00000000}},  //   bvan, _troç, murh,
  { {0x6aa8018e, 0x38602fa5, 0x63ad01ee, 0x00000000}},  //   yddf, _meir_, cvan,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc69300b6, 0xfa8e0082, 0x6b89010e, 0x00000000}},  //   דאו_, _bừng_, eteg,
  { {0xdc13005a, 0x6b892fa6, 0x24800023, 0x00000000}},  //   _ağır, fteg, ngim_,
  { {0xfa8e0011, 0x7e632fa7, 0x6b8901d6, 0x00000000}},  //   _dừng_, banp, gteg,
  { {0x7b320036, 0x38600051, 0x00000000, 0x00000000}},  //   _tłum, _aeir_,   ,
  { {0x63ad0466, 0x66d00934, 0xa9c30e85, 0x00000000}},  //   zvan, _läks, всяк,
  { {0xa3de02d2, 0x63ad047f, 0x38600016, 0x00000000}},  //   तना_, yvan, _ceir_,
  { {0x8c4302e9, 0x38600051, 0xd838007e, 0x00000000}},  //   _рече, _deir_, дэр_,
  { {0x63ad2fa8, 0x68fd0026, 0x7c222fa9, 0x00000000}},  //   vvan, snsd, _izor,
  { {0xb8e50055, 0x09070931, 0x79a3007e, 0x00000000}},  //   _এত_, _очим, _арые,
  { {0x63ad049b, 0x38601f1c, 0xadf10061, 0x00000000}},  //   tvan, _geir_, _अइसन_,
  { {0xa7fb008e, 0x44220161, 0x63ad009d, 0x00000000}},  // [9390] maño, _czk_, uvan,
  { {0x05010044, 0x63ad0f12, 0x7d020635, 0x00000000}},  //   ্ষের_, rvan, _ljos,
  { {0x6b89022b, 0x63ad006c, 0x7e6304fd, 0x00000000}},  //   zteg, svan, vanp,
  { {0x63ad00bb, 0xd4790049, 0x00000000, 0x00000000}},  //   pvan, _צאָל,   ,
  { {0x752d0282, 0xfa8e0011, 0x7e630358, 0x00000000}},  //   mmaz, _rừng_, tanp,
  { {0x752d0047, 0xfa8e0082, 0xd3f4007e, 0x00000000}},  //   lmaz, _sừng_, нiцт,
  { {0x7e630052, 0x3d0b0067, 0x7d020a92, 0x00000000}},  //   ranp, ावले_, _bjos,
  { {0x7e630082, 0x4c8509f1, 0x752d019a, 0x00000000}},  //   sanp, хлив, nmaz,
  { {0x38600b51, 0x7e6304d4, 0x6b89002d, 0x00000000}},  //   _reir_, panp, uteg,
  { {0x6b890c46, 0x7c2201ee, 0x386000e0, 0x00000000}},  //   rteg, _dzor, _seir_,
  { {0x6b890004, 0xfa8e001d, 0x7c220288, 0x00000000}},  //   steg, _từng_, _ezor,
  { {0xc68900b6, 0x6d41011c, 0xa7fb008e, 0x00000000}},  //   _לא_, _iula, gaño,
  { {0xbd2c00bd, 0x6d41011c, 0x291e001e, 0x00000000}},  //   _וואָ, _hula, ēta_,
  { {0x6d41006a, 0x7d1b044e, 0x4422012d, 0x00000000}},  //   _kula, llus, _rzk_,
  { {0x6d41110d, 0x5a44007e, 0xb87b0048, 0x00000000}},  //   _jula, _рэча, mhín,
  { {0x6d410149, 0x64a3007e, 0x20f800b9, 0x00000000}},  //   _mula, ласа, nčit_,
  { {0x24070517, 0x0326005e, 0x6d41128e, 0x00000000}},  // [93a0] енти_, едан, _lula,
  { {0xe9ff001d, 0x7d1b010f, 0x6d4101d6, 0x00000000}},  //   _giải_, hlus, _oula,
  { {0x7d1b0004, 0x7f40006b, 0x6d41007f, 0x00000000}},  //   klus, _sumq, _nula,
  { {0x20f8013e, 0x00000000, 0x00000000, 0x00000000}},  //   jčit_,   ,   ,
  { {0x6d410181, 0x7d1b006c, 0x7e612191, 0x00000000}},  //   _aula, dlus, _belp,
  { {0x6d410149, 0x6e94005e, 0xd00f03ec, 0x00000000}},  //   _bula, тику, حله_,
  { {0x40961948, 0x7e610292, 0x7c222faa, 0x00000000}},  //   _прат, _delp, _szor,
  { {0x629e188a, 0xf8bf0010, 0x61e1006c, 0x00000000}},  //   lepo, rmék_, _ülla,
  { {0xa2c402fb, 0xb09b009b, 0x6d410032, 0x00000000}},  //   राप्, _צימר, _eula,
  { {0x6d41000b, 0x629e01d6, 0x7c2211b0, 0x00000000}},  //   _fula, nepo, _vzor,
  { {0x6d41011c, 0x7c220036, 0x5cd60088, 0x00000000}},  //   _gula, _wzor, _підх,
  { {0x6609011f, 0x7d1b0b25, 0x629e010e, 0x00000000}},  //   şekk, clus, hepo,
  { {0x629e00ea, 0x7c220166, 0x6d410fa5, 0x00000000}},  //   kepo, _uzor, _zula,
  { {0x629e016e, 0x66d00039, 0x00000000, 0x00000000}},  //   jepo, _säkr,   ,
  { {0x65940551, 0xa7fb0219, 0xf527017a, 0x00000000}},  //   лару, paño, ефан,
  { {0x57b501e0, 0x6aaa25e3, 0x629e012d, 0x00000000}},  //   _абит, _haff, eepo,
  { {0x752d2fab, 0xd371023c, 0x00000000, 0x00000000}},  // [93b0] rmaz, شها_,   ,
  { {0x6aaa2fac, 0x629e032e, 0x2369012d, 0x00000000}},  //   _jaff, gepo, rsaj_,
  { {0x0736009b, 0x7d1b0016, 0x00000000, 0x00000000}},  //   _שאתם_, ylus,   ,
  { {0x7e610640, 0x6d410035, 0x6aaa009d, 0x00000000}},  //   _selp, _rula, _laff,
  { {0x8fa50088, 0xf77f014a, 0x629e2fad, 0x00000000}},  //   тале, nuç_, bepo,
  { {0x6d41027e, 0x629e2fae, 0xa3ae01f5, 0x00000000}},  //   _pula, cepo, किर_,
  { {0xf2d200bd, 0xdcfa038c, 0x7d1b0004, 0x00000000}},  //   _דעם_, _artı, tlus,
  { {0x7e610c0c, 0x6d412faf, 0xdb0b00c4, 0x00000000}},  //   _welp, _vula, _orgã,
  { {0x7d1b02e5, 0x7e61001e, 0x6d410093, 0x00000000}},  //   rlus, _telp, _wula,
  { {0x6d410b5a, 0x7d1b000c, 0x6aaa1a9a, 0x00000000}},  //   _tula, slus, _caff,
  { {0x7d1b006c, 0x6d410058, 0x00000000, 0x00000000}},  //   plus, _uula,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9cd6009b, 0x6aaa0007, 0xb7c00044, 0x00000000}},  //   _שונה_, _faff, উন্ট,
  { {0x6aaa00b7, 0x2cad0133, 0x00000000, 0x00000000}},  //   _gaff, lded_,   ,
  { {0xe7370081, 0x629e2c1f, 0x2cad0133, 0x00000000}},  //   тер_, vepo, oded_,
  { {0x2cad0038, 0xa3ae006e, 0x6aaa0197, 0x00000000}},  //   nded_, किल_, _zaff,
  { {0x93430081, 0xd70a01f9, 0x629e0c1b, 0x00000000}},  // [93c0] инте, _оние_, tepo,
  { {0xf1fa0a4f, 0xd36f0439, 0x69dc1565, 0x00000000}},  //   وعات_, زهم_, øreg,
  { {0x629e002d, 0x1677009b, 0xd657009b, 0x00000000}},  //   repo, _בגיל_, _שיטת_,
  { {0x2902000c, 0x629e010e, 0x3d0b013d, 0x00000000}},  //   nnka_, sepo, हकों_,
  { {0x2cad2fb0, 0x7762006b, 0xdb0b0129, 0x00000000}},  //   dded_, _çoxd, _orgà,
  { {0xf41300b6, 0xc7d7009b, 0x63a400e7, 0x00000000}},  //   _כפר_, כוני_, mwin,
  { {0x6aaa0207, 0x63a40007, 0xb4db00f6, 0x00000000}},  //   _raff, lwin, _diàf,
  { {0x6aaa2fb1, 0xfd0f0025, 0x3fc600a1, 0x00000000}},  //   _saff, يجي_, _لگتی_,
  { {0x63a400b5, 0x2484000c, 0xfe7201fa, 0x00000000}},  //   nwin, _ömmu_, _ندا_,
  { {0xb87b0051, 0x63ab0030, 0x2cad0133, 0x00000000}},  //   thío, ægni, aded_,
  { {0x63a42936, 0xfbcf0167, 0xc27b00b3, 0x00000000}},  //   hwin, متی_, וריי,
  { {0x63a40007, 0x6aaa010f, 0x81570049, 0x00000000}},  //   kwin, _waff, כסטע_,
  { {0x6aaa0066, 0x64430036, 0xa49b000a, 0x00000000}},  //   _taff, śnik, _djòl,
  { {0x29021d85, 0x63a40aba, 0x00000000, 0x00000000}},  //   anka_, dwin,   ,
  { {0x63a40007, 0x00000000, 0x00000000, 0x00000000}},  //   ewin,   ,   ,
  { {0xba37009b, 0x92af0044, 0x272400f8, 0x00000000}},  //   _בטוח_, _ওকে_, röna_,
  { {0x63a4298f, 0x39490059, 0xe5340131, 0x00000000}},  // [93d0] gwin, _časi_, реть,
  { {0x2473001d, 0x78ad003c, 0x43940b86, 0x00000000}},  //   ệm_, _haav, рафс,
  { {0x75d50025, 0x7afd0181, 0x78ad00b0, 0x00000000}},  //   _إيجا, ésti, _kaav,
  { {0xf2df001a, 0x63a400b5, 0xc0ab00f3, 0x00000000}},  //   _atât_, bwin, بائل_,
  { {0x7f19007e, 0x78ad0934, 0x747a009b, 0x00000000}},  //   ніку_, _maav, _אנרג,
  { {0x753d1a53, 0xdb0b0387, 0x3ebe0011, 0x00000000}},  //   _hisz, _orgá, _cntt_,
  { {0x753d0010, 0xfc3f01ca, 0x29020832, 0x00000000}},  //   _kisz, žím_, ynka_,
  { {0x644d2665, 0x62850066, 0x00000000, 0x00000000}},  //   ncai, lgho,   ,
  { {0x2cad00ab, 0x644f0009, 0x753d0c59, 0x00000000}},  //   rded_, _mfci, _misz,
  { {0x62851e2d, 0xfff60123, 0x753d115b, 0x00000000}},  //   ngho, _حکمت_, _lisz,
  { {0x5dd50b03, 0x63a4114b, 0xa2c40309, 0x00000000}},  //   _حقائ, zwin, रात्,
  { {0x63a401d6, 0xdce70089, 0x753d0036, 0x00000000}},  //   ywin, ēlēj, _nisz,
  { {0x8cc0013d, 0x00000000, 0x00000000, 0x00000000}},  //   वारो,   ,   ,
  { {0xf74302ea, 0x99d5039d, 0x00000000, 0x00000000}},  //   серо, _متبا,   ,
  { {0x63a40009, 0x660602dc, 0x00000000, 0x00000000}},  //   wwin, упва,   ,
  { {0x30ae0044, 0x753d0ef2, 0xd5b70082, 0x00000000}},  //   _কক্স, _cisz, ứng_,
  { {0x753d2fb2, 0x63a400bb, 0x2903013e, 0x00000000}},  // [93e0] _disz, uwin, čkat_,
  { {0x63a40168, 0xa2c401f5, 0x33d50088, 0x00000000}},  //   rwin, राध्, шіст,
  { {0x63a40007, 0x394f001a, 0xccf90036, 0x00000000}},  //   swin, _însă_, kiś_,
  { {0x74550265, 0x600a07d0, 0x63a40009, 0x00000000}},  //   _върх, ннем_, pwin,
  { {0x6aa100eb, 0x3eac0009, 0x41a401f5, 0x00000000}},  //   kelf, _padt_, _गैरस,
  { {0xe1660025, 0x3243005e, 0x71660025, 0x00000000}},  //   _مدري, _герг, _مارك,
  { {0x91e60f40, 0x7d0d0387, 0x6aa105a6, 0x00000000}},  //   _сове, časn, delf,
  { {0x5ba6166c, 0x673e2fb3, 0x798100e7, 0x00000000}},  //   гроз, _lipj, dulw,
  { {0x09dc0061, 0xcb67025f, 0xc006007e, 0x00000000}},  //   मन्य, гање_, _спак,
  { {0x78ad08b2, 0xbda60014, 0x8f9b00a0, 0x00000000}},  //   _saav, _محصو, _אימי,
  { {0x527b007b, 0x78ad003c, 0x765c24fd, 0x00000000}},  //   ענטא, _paav, dbry,
  { {0x27e61f27, 0x8c460954, 0x6d58018d, 0x00000000}},  //   _żona_, _седе, mpva,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f4b00ea, 0x00000000, 0x00000000, 0x00000000}},  //   _åmås_,   ,   ,
  { {0x753d0ef2, 0x644d01d6, 0x7afa2fb4, 0x00000000}},  //   _pisz, tcai, mitt,
  { {0x7afa021e, 0x5455005e, 0x69da007f, 0x00000000}},  //   litt, рват, myte,
  { {0x69da0ec6, 0x753d0047, 0x644d0051, 0x00000000}},  // [93f0] lyte, _visz, rcai,
  { {0x7afa1603, 0x644d0c9a, 0x320b0517, 0x00000000}},  //   nitt, scai, нхен_,
  { {0x753d0047, 0x62850894, 0x69da0010, 0x00000000}},  //   _tisz, rgho, nyte,
  { {0x7afa021e, 0x6aa100b5, 0xf8bf009d, 0x00000000}},  //   hitt, zelf, mmés_,
  { {0x08780049, 0x7afa00b0, 0xddd001ca, 0x00000000}},  //   רעדט_, kitt, _češt,
  { {0x6aa1109d, 0x60c00173, 0xfd99003b, 0x00000000}},  //   xelf, _enmm, втић_,
  { {0x7afa2fb5, 0x6aa10190, 0x00000000, 0x00000000}},  //   ditt, velf,   ,
  { {0x69da1ad1, 0x29090020, 0xeb990bba, 0x00000000}},  //   dyte, _njaa_, вии_,
  { {0xa7fb1ec4, 0x2b460082, 0x7afa2fb6, 0x00000000}},  //   bañi, _cuoc_, fitt,
  { {0x7afa133a, 0x2b460011, 0x290900b0, 0x00000000}},  //   gitt, _duoc_, _ajaa_,
  { {0x8a38007c, 0xdeba0097, 0x98a90066, 0x00000000}},  //   ляют_, _שמעל, _ghaċ_,
  { {0x3c470054, 0x6aa10343, 0xab9501fb, 0x00000000}},  //   _إضاف, self, _виді,
  { {0x39491b4e, 0xf746004c, 0x81bd0044, 0x00000000}},  //   _času_, рего, েনি_,
  { {0x69da00b9, 0xaa880025, 0x7afa2fb7, 0x00000000}},  //   byte, _منهم_, citt,
  { {0x765c0030, 0xeb110061, 0x69da00ab, 0x00000000}},  //   rbry, ठकीत_, cyte,
  { {0x81bd0055, 0x2caf01a2, 0x68e4170e, 0x00000000}},  //   েনা_, _jagd_, _ulid,

  { {0x626600ed, 0x9e3c000a, 0x23480014, 0x00000000}},  // [9400] иваа, _haďt, اسری_,
  { {0x4256005e, 0x39470007, 0x2caf03b1, 0x00000000}},  //   ртат, _kuns_, _lagd_,
  { {0xc69300b6, 0x867b01ce, 0x21a6005e, 0x00000000}},  //   _ואת_, _בריו, рием,
  { {0xe7b3089d, 0x7afa00b5, 0xa2c4007d, 0x00000000}},  //   _امید, zitt, राह्,
  { {0x44242fb8, 0x00000000, 0x00000000, 0x00000000}},  //   _ám_,   ,   ,
  { {0xdd9a0bbd, 0xa2e60057, 0x3940006c, 0x00000000}},  //   вши_, _тогд, _liis_,
  { {0xf8bf00f4, 0x7afa021e, 0xbd67007c, 0x00000000}},  //   llée_, vitt, арые_,
  { {0x7afa0c4c, 0xa2c40061, 0x00000000, 0x00000000}},  //   witt, राव्,   ,
  { {0x7afa2fb9, 0x2b460011, 0x644000c4, 0x00000000}},  //   titt, _quoc_, _úmid,
  { {0x39470719, 0xf2d30049, 0xf2df0011, 0x00000000}},  //   _buns_, ַער_, _luân_,
  { {0x7afa0198, 0x26d300c4, 0x6f18040d, 0x00000000}},  //   ritt, _roxo_, movc,
  { {0x7afa021e, 0x7c830175, 0x6f180255, 0x00000000}},  //   sitt, _душе, lovc,
  { {0xcb540151, 0x6d480058, 0x7afa0056, 0x00000000}},  //   _انتظ, _huda, pitt,
  { {0x6f181238, 0x6d4816c3, 0xd7f81001, 0x00000000}},  //   novc, _kuda, рую_,
  { {0x99840025, 0x69da0065, 0x04670407, 0x00000000}},  //   _العو, qyte, итам,
  { {0x6d482fba, 0x657a0a87, 0xdb0b010f, 0x00000000}},  //   _muda, átha, _ergä,
  { {0x6d48037e, 0x6f180626, 0xc29917c3, 0x00000000}},  // [9410] _luda, kovc, лках_,
  { {0x2919064e, 0xa2c40309, 0xddc3001a, 0x00000000}},  //   losa_, राष्, nanţ,
  { {0x80c30061, 0x6f180471, 0x6d482fbb, 0x00000000}},  //   ळाले, dovc, _nuda,
  { {0x29190091, 0x11280088, 0xf8bf009d, 0x00000000}},  //   nosa_, аючи_, blée_,
  { {0x2d9e2fbc, 0x29190197, 0x7e6800d9, 0x00000000}},  //   _apte_, iosa_, _bedp,
  { {0xef18008b, 0x6d482fbd, 0x6f18092f, 0x00000000}},  //   амі_, _buda, govc,
  { {0x2919000b, 0xa2c40309, 0x00000000, 0x00000000}},  //   kosa_, रार्,   ,
  { {0x6d481a97, 0xf2df001d, 0x386900ab, 0x00000000}},  //   _duda, _xuân_, _near_,
  { {0x39470089, 0x39400030, 0x29190b33, 0x00000000}},  //   _suns_, _riis_, dosa_,
  { {0x39400cfc, 0x7645018e, 0xcac90783, 0x00000000}},  //   _siis_, _nghy, угое_,
  { {0xc7a9012f, 0x291900d4, 0x38691c7f, 0x00000000}},  //   _רב_, fosa_, _bear_,
  { {0xcd9600b6, 0x291900c4, 0x386900fa, 0x00000000}},  //   _לדעת_, gosa_, _cear_,
  { {0xe8f72fbe, 0x3940006c, 0x386900ab, 0x00000000}},  //   сля_, _viis_, _dear_,
  { {0x7c2b0209, 0xdc360049, 0xddc3001a, 0x00000000}},  //   _izgr, _פאסט_, canţ,
  { {0x38690531, 0x7f41002b, 0x39400058, 0x00000000}},  //   _fear_, _milq, _tiis_,
  { {0x39912fbf, 0xf2df001d, 0x2919203d, 0x00000000}},  //   más_, _quân_, cosa_,
  { {0x39910047, 0xa3ab013d, 0xf8bf0068, 0x00000000}},  // [9420] lás_, _कैद_, ulée_,
  { {0x16aa10f2, 0x7f410066, 0x7b1d00d4, 0x00000000}},  //   _свои_, _nilq, cèut,
  { {0x38690038, 0x39910010, 0x7e6808cb, 0x00000000}},  //   _year_, nás_, _redp,
  { {0x6d480051, 0x3d21013d, 0x2d9e004a, 0x00000000}},  //   _ruda, मतों_, _rpte_,
  { {0x6d480149, 0x351b00b6, 0xa4b700a0, 0x00000000}},  //   _suda, _תוכנ, _הלכה_,
  { {0x39910010, 0x6d480145, 0x3ce604bb, 0x00000000}},  //   kás_, _puda, _slov_,
  { {0xfe6f01d8, 0x629c2611, 0x6f180142, 0x00000000}},  //   ردو_, _ibro, rovc,
  { {0x44220343, 0x39910047, 0x3b540081, 0x00000000}},  //   _kyk_, dás_, окир,
  { {0xddc3001a, 0x7524008e, 0x386900ab, 0x00000000}},  //   tanţ, iliz, _rear_,
  { {0x6d482cc9, 0x4974004c, 0x2ca40fdc, 0x00000000}},  //   _tuda, олос, semd_,
  { {0x629c008d, 0x44220343, 0x2919008e, 0x00000000}},  //   _mbro, _lyk_, tosa_,
  { {0x7aef0129, 0x44220022, 0x7afd004a, 0x00000000}},  //   èctr, _oyk_, éstr,
  { {0xb7b90044, 0x6c3600a2, 0x657a2fc0, 0x00000000}},  //   ুন্ট, _افشا, áthn,
  { {0x39910010, 0x386900ab, 0x7b320036, 0x00000000}},  //   bás_, _wear_, _głup,
  { {0x291906c2, 0x7c220082, 0xf3ff00c4, 0x00000000}},  //   posa_, _hyor, _peão_,
  { {0xddc30089, 0x24890089, 0x442201a3, 0x00000000}},  //   nanš, ugam_, _byk_,
  { {0x248901c5, 0x6d420035, 0x284a0049, 0x00000000}},  // [9430] rgam_, _mioa, _דעפּ,
  { {0x752402d5, 0x4422032e, 0xdb090350, 0x00000000}},  //   aliz, _dyk_, rveç,
  { {0x1a9b007b, 0x7524002d, 0x66d0021e, 0x00000000}},  //   ריבע, bliz, _näky,
  { {0x629c0032, 0xddc300ca, 0x442b012d, 0x00000000}},  //   _ebro, janš, _tzc_,
  { {0x39912fc1, 0x7c220056, 0x7f490919, 0x00000000}},  //   zás_, _nyor, _queq,
  { {0xb87b2fc2, 0x8d550069, 0x00000000, 0x00000000}},  //   chív, отич,   ,
  { {0x6d420016, 0xed591001, 0x7c2200e0, 0x00000000}},  //   _bioa, шой_, _ayor,
  { {0x629c0036, 0x7cfe0dec, 0x63bb002b, 0x00000000}},  //   _zbro, tūra, _ġunj,
  { {0x69dc05b7, 0xe0e4007e, 0x4fc70e82, 0x00000000}},  //   øren, _эўро, _усва,
  { {0x39912fc3, 0x7aa500aa, 0x63bd012d, 0x00000000}},  //   tás_, циоз, _mrsn,
  { {0x3ea72fc4, 0xa969012b, 0x75240036, 0x00000000}},  //   ment_, јима_, yliz,
  { {0x2d870198, 0x3ea00166, 0x6d421746, 0x00000000}},  //   mune_, đite_, _gioa,
  { {0x7d1b001c, 0x7c220047, 0x7d24007c, 0x00000000}},  //   mous, _gyor, _эффе,
  { {0x3ea703d5, 0x44220007, 0x39910010, 0x00000000}},  //   nent_, _ryk_, pás_,
  { {0x3ea700f4, 0xba390049, 0x7d090020, 0x00000000}},  //   ient_, _דײַט, ones,
  { {0x7d0902cc, 0xe45a00e3, 0x7d1b1241, 0x00000000}},  //   nnes, ржа_, nous,
  { {0x3ea700b5, 0x75240007, 0x7d0900f2, 0x00000000}},  // [9440] kent_, rliz, ines,
  { {0x3ea72fc5, 0x75240b33, 0x7d1b00ab, 0x00000000}},  //   jent_, sliz, hous,
  { {0x3ea71311, 0x7d090ff3, 0x7d1b2007, 0x00000000}},  //   dent_, knes, kous,
  { {0xa99a007b, 0x44220190, 0x9f96006c, 0x00000000}},  //   יבער, _tyk_, _tüüp_,
  { {0xbba8006e, 0x86e902fd, 0x5e58007c, 0x00000000}},  //   _कनेक, _ضعیف_, биля_,
  { {0x3ea7028c, 0x629c0c76, 0x7d091be3, 0x00000000}},  //   gent_, _ubro, enes,
  { {0xf987035b, 0x2d87023e, 0xe801013d, 0x00000000}},  //   _تب_, gune_, _लेना_,
  { {0x7d090030, 0x00000000, 0x00000000, 0x00000000}},  //   gnes,   ,   ,
  { {0x3ea70006, 0xe7a9013d, 0x81bd0044, 0x00000000}},  //   bent_, _चैंप, েনঃ_,
  { {0x3ea71f59, 0x7d090197, 0x212604be, 0x00000000}},  //   cent_, anes, lloh_,
  { {0x2d870e8d, 0x395807a5, 0x6e930014, 0x00000000}},  //   cune_, ërs_, _آلما,
  { {0xeb9a0256, 0x6d5a0b5e, 0x3ced04c7, 0x00000000}},  //   _вид_, _itta, chev_,
  { {0x7762006b, 0x5ead0044, 0x00000000, 0x00000000}},  //   _çoxl, চারে,   ,
  { {0x3f50001d, 0x613111b6, 0x7d00014a, 0x00000000}},  //   _màu_, måle, lims,
  { {0xd5b805a5, 0xfc3f00b9, 0xee2e0451, 0x00000000}},  //   ост_, žít_, ннi_,
  { {0x3ea7284c, 0x7d000279, 0x63bd0142, 0x00000000}},  //   zent_, nims, _prsn,
  { {0x439401fc, 0x3ea72fc6, 0x2d870032, 0x00000000}},  // [9450] матс, yent_, zune_,
  { {0x7d09001e, 0x6d5a021e, 0x3ea70115, 0x00000000}},  //   znes, _otta, xent_,
  { {0x3ea7032c, 0x7d000416, 0x7d090133, 0x00000000}},  //   vent_, kims, ynes,
  { {0x76550036, 0x2d87010e, 0x3ea7026e, 0x00000000}},  //   lczy, vune_, went_,
  { {0x6d5a1eef, 0x8cce013d, 0x7d0908e0, 0x00000000}},  //   _atta, थानो, vnes,
  { {0x643a007b, 0x2d87017b, 0x63ad0020, 0x00000000}},  //   _לערנ, tune_, mwan,
  { {0x69dc0737, 0xddc10af3, 0x00000000, 0x00000000}},  //   ørel, _belš,   ,
  { {0x3ea7030a, 0x2d87002d, 0x3cc9003b, 0x00000000}},  //   sent_, rune_, слио_,
  { {0xff530426, 0x7d1b0c6a, 0x6d5a129e, 0x00000000}},  //   _آخر_, rous, _etta,
  { {0x2d872dab, 0xdd00001e, 0x63a00073, 0x00000000}},  //   pune_, ētāj, _ämne,
  { {0x63ad0b70, 0x499000a1, 0x7d1b06f0, 0x00000000}},  //   hwan, نیور, pous,
  { {0x63ad107e, 0x7aea2fc7, 0x8c3d014a, 0x00000000}},  //   kwan, _elft, leşm,
  { {0xdb02000c, 0x00000000, 0x00000000, 0x00000000}},  //   _troð,   ,   ,
  { {0x63ad05eb, 0x290b29b5, 0x6d5a00ea, 0x00000000}},  //   dwan, anca_, _ytta,
  { {0x1dbd01f5, 0xd62a08fc, 0x63ad0036, 0x00000000}},  //   ्मित, сове_, ewan,
  { {0xf8bf154b, 0x63ad010f, 0x00000000, 0x00000000}},  //   llén_, fwan,   ,
  { {0x63ad0870, 0x00000000, 0x00000000, 0x00000000}},  // [9460] gwan,   ,   ,
  { {0x78b6011f, 0xb87b0051, 0x00000000, 0x00000000}},  //   _hayv, bhís,   ,
  { {0xb87b008e, 0x00000000, 0x00000000, 0x00000000}},  //   chís,   ,   ,
  { {0x5a0c0049, 0x63ad047b, 0x7d000023, 0x00000000}},  //   סלאַ, bwan, xims,
  { {0x6b890211, 0x9f53008b, 0x26da05ae, 0x00000000}},  //   jueg, евіч, _kopo_,
  { {0x29020058, 0x7cfe0006, 0x26da2fc8, 0x00000000}},  //   hika_, tūro, _jopo_,
  { {0x2902187c, 0x6aa801e3, 0x7d000095, 0x00000000}},  //   kika_, vedf, tims,
  { {0xe05501ef, 0x3f50001d, 0x29020020, 0x00000000}},  //   _قیمت_, _tàu_, jika_,
  { {0x290206fe, 0x3f67005e, 0x7f4a004b, 0x00000000}},  //   dika_, _нито_, _طلاق_,
  { {0x613123a4, 0xdea001b2, 0x26da0145, 0x00000000}},  //   råle, _شیعی, _nopo_,
  { {0x29022fc9, 0x6d5a093b, 0xbc6a007a, 0x00000000}},  //   fika_, _utta, _همان_,
  { {0x63ad0046, 0x76550036, 0x6aa80009, 0x00000000}},  //   ywan, wczy, sedf,
  { {0xb4db0129, 0x26da0022, 0x6123006c, 0x00000000}},  //   _diàl, _bopo_, põlv,
  { {0x26da00c4, 0xa3c2007d, 0x68e600ea, 0x00000000}},  //   _copo_, ्मन_, akkd,
  { {0xcb13007b, 0x26da0198, 0x29020518, 0x00000000}},  //   _אלס_, _dopo_, bika_,
  { {0x63ad1a07, 0xe81e006e, 0xa4d40ee0, 0x00000000}},  //   twan, _युवा_, носі,
  { {0xa87c00b6, 0x316a00bb, 0x68ed0288, 0x00000000}},  // [9470] _האחר, _awbz_, _ilad,
  { {0x6eef0018, 0x63ad1440, 0x26da00e5, 0x00000000}},  //   _købe, rwan, _gopo_,
  { {0x68ed0161, 0x63ad1073, 0x9b17009b, 0x00000000}},  //   _klad, swan, לחמה_,
  { {0xf1c000ad, 0x6eef0637, 0x93c700e5, 0x00000000}},  //   ương_, _møbe, _arăţ,
  { {0x6eef0018, 0x93c700e5, 0x00000000, 0x00000000}},  //   _løbe, _brăţ,   ,
  { {0x68ed1c65, 0xad590cbc, 0x00000000, 0x00000000}},  //   _llad, орих_,   ,
  { {0xfe7003ec, 0xdd9100a1, 0x68ed016c, 0x00000000}},  //   اده_, ڑوں_, _olad,
  { {0x2902184d, 0x6b890032, 0x00000000, 0x00000000}},  //   xika_, tueg,   ,
  { {0x2d8a0030, 0x394e010f, 0x1dbd0309, 0x00000000}},  //   _åben_, _aufs_, ्महत,
  { {0x68ed010e, 0x6b890325, 0xe5780089, 0x00000000}},  //   _alad, rueg, šķi_,
  { {0x290206fe, 0x68ed018d, 0x60db0263, 0x00000000}},  //   tika_, _blad, _koum,
  { {0x68ed1a5e, 0x6f03014a, 0x60db0173, 0x00000000}},  //   _clad, linc, _joum,
  { {0x29021f0f, 0x6b89004a, 0x26da2461, 0x00000000}},  //   rika_, queg, _popo_,
  { {0x29022fca, 0x68ed06c9, 0x6f030808, 0x00000000}},  //   sika_, _elad, ninc,
  { {0xceb2019b, 0x60c90fda, 0x68ed0030, 0x00000000}},  //   כים_, _onem, _flad,
  { {0x60db2fcb, 0xa3ea15c4, 0x00000000, 0x00000000}},  //   _noum, одба_,   ,
  { {0x26da02d5, 0x29120009, 0x6f030095, 0x00000000}},  // [9480] _topo_, _ijya_, kinc,
  { {0x6f0310b1, 0x26da0026, 0x6f0d0048, 0x00000000}},  //   jinc, _uopo_, éacl,
  { {0x2b470181, 0x00000000, 0x00000000, 0x00000000}},  //   _minc_,   ,   ,
  { {0x2b47018e, 0x61e305b7, 0x236000b5, 0x00000000}},  //   _linc_, ønla, ppij_,
  { {0x4f570447, 0x60db0e6d, 0x6f030197, 0x00000000}},  //   وجود_, _doum, finc,
  { {0x93460106, 0x60c90e2d, 0x6f0323a1, 0x00000000}},  //   _інве, _enem, ginc,
  { {0x1ea90054, 0x6da30098, 0x27360030, 0x00000000}},  //   ثاني_, вија, mænd_,
  { {0x629e0061, 0x60db01aa, 0x4095013b, 0x00000000}},  //   lfpo, _goum, _прут,
  { {0x6f0301a3, 0x2aaa0679, 0x00000000, 0x00000000}},  //   binc, отно_,   ,
  { {0x6f032fcc, 0x2b470129, 0xddc6003b, 0x00000000}},  //   cinc, _cinc_, _обзи,
  { {0x68ed0018, 0x6d5e0428, 0xe895007e, 0x00000000}},  //   _plad, ípad, нань,
  { {0x80e00044, 0x63a601bb, 0x6ba700f8, 0x00000000}},  //   পোর্, _opkn, örgå,
  { {0x7d0d0626, 0x59b003d7, 0xc7b8007e, 0x00000000}},  //   čast, _जनवर, мёр_,
  { {0x68ed0016, 0x00000000, 0x00000000, 0x00000000}},  //   _wlad,   ,   ,
  { {0x442d17fd, 0xb6040b52, 0x645a0035, 0x00000000}},  //   _še_, вятк, _ştia,
  { {0x39982ae8, 0x7bc200b9, 0x6f032fcd, 0x00000000}},  //   més_, _krou, zinc,
  { {0xe6670001, 0x39982fce, 0x60db0957, 0x00000000}},  // [9490] _отно, lés_, _roum,
  { {0x35b501f9, 0x60db2fcf, 0x394910ed, 0x00000000}},  //   _збор, _soum, _hias_,
  { {0x6f032fd0, 0x399800f4, 0x60db0bf2, 0x00000000}},  //   vinc, nés_, _poum,
  { {0x30150594, 0x6ab80087, 0x6f032fd1, 0x00000000}},  //   ндер, _lavf, winc,
  { {0x399800f4, 0x3f69003b, 0xdbd603b6, 0x00000000}},  //   hés_, чило_, _jääm,
  { {0x60db0173, 0x39980010, 0x6ab80009, 0x00000000}},  //   _woum, kés_, _navf,
  { {0x6f03038c, 0x7bc22fd2, 0xada50088, 0x00000000}},  //   rinc, _arou, хайл,
  { {0x62340264, 0x6f0329c4, 0x39982fd3, 0x00000000}},  //   _ресу, sinc, dés_,
  { {0xa2c40061, 0x7bc2009d, 0xe0d20049, 0x00000000}},  //   राच्, _crou, _גײן_,
  { {0x3998009d, 0x3949010e, 0xa3c2006e, 0x00000000}},  //   fés_, _aias_, ्मत_,
  { {0x39492fd4, 0x39980353, 0x2b4700d4, 0x00000000}},  //   _bias_, gés_, _vinc_,
  { {0xf8bf0428, 0x394900c4, 0x00000000, 0x00000000}},  //   blém_, _cias_,   ,
  { {0x7bc2030a, 0x39492fd5, 0x2b470129, 0x00000000}},  //   _grou, _dias_, _tinc_,
  { {0xfbd0025a, 0x39981697, 0x2cad1702, 0x00000000}},  //   _ختم_, bés_, leed_,
  { {0x64a6008b, 0x399804bd, 0x18a60425, 0x00000000}},  //   нава, cés_, _займ,
  { {0x69c3002b, 0x2d870051, 0x9abc002b, 0x00000000}},  //   _irne, irne_, roċe,
  { {0xccf20049, 0x81dd0044, 0x78a40009, 0x00000000}},  // [94a0] אכן_, _তেল_, _ibiv,
  { {0x221601fb, 0x2cad11d1, 0x3f862fd6, 0x00000000}},  //   нфер, heed_, vrou_,
  { {0xd01200a1, 0x008600e2, 0x00000000, 0x00000000}},  //   گلش_, елео,   ,
  { {0x7053007a, 0x3f862b2b, 0xa3c2006e, 0x00000000}},  //   هنما, trou_, ्मद_,
  { {0x39980047, 0x2d8726e8, 0x2cad00ab, 0x00000000}},  //   zés_, erne_, deed_,
  { {0x399800f4, 0x7bc40006, 0x3f8600c4, 0x00000000}},  //   yés_, _šiuo, rrou_,
  { {0xf98701b7, 0xc6930049, 0x2cad01a3, 0x00000000}},  //   _حب_, טאג_, feed_,
  { {0x13e40044, 0xc19b00b3, 0x3f860087, 0x00000000}},  //   _নেয়, _משלי, prou_,
  { {0xdccf001d, 0x39492fd7, 0x2d8703c6, 0x00000000}},  //   _tỉnh_, _rias_, arne_,
  { {0x39982fd8, 0x7bc2049b, 0x2d8700b4, 0x00000000}},  //   tés_, _vrou, brne_,
  { {0x0d8601f9, 0x394900eb, 0xdb0b20c4, 0x00000000}},  //   _член, _pias_, _argó,
  { {0x399804bd, 0xa3c20164, 0x3eae0061, 0x00000000}},  //   rés_, ्मा_, left_,
  { {0x39981e39, 0x69c3010f, 0x394900c4, 0x00000000}},  //   sés_, _erne, _vias_,
  { {0x39980047, 0x00000000, 0x00000000, 0x00000000}},  //   pés_,   ,   ,
  { {0x3949008e, 0x2d9c0010, 0x6283008e, 0x00000000}},  //   _tias_, ntve_, ónom,
  { {0x81d60044, 0x612a01e5, 0x3eae2156, 0x00000000}},  //   িনা_, býli, heft_,
  { {0x69c300ca, 0x00000000, 0x00000000, 0x00000000}},  // [94b0] _zrne,   ,   ,
  { {0x78bd00eb, 0x78a40166, 0xd5bb00ed, 0x00000000}},  //   ldsv, _zbiv, _есм_,
  { {0x7d02054f, 0x00000000, 0x00000000, 0x00000000}},  //   _omos,   ,   ,
  { {0x823406ea, 0x78bd0332, 0xd4790049, 0x00000000}},  //   اركا, ndsv, _קאָל,
  { {0xe9ff0011, 0x78bd0116, 0x752d00e7, 0x00000000}},  //   _khải_, idsv, mlaz,
  { {0x7d021ce5, 0x752d054f, 0x00000000, 0x00000000}},  //   _amos, llaz,   ,
  { {0x62342cf1, 0x2cad006c, 0x2d870133, 0x00000000}},  //   _беру, teed_, urne_,
  { {0x6b9b261f, 0x7cf52fd9, 0x06ad0044, 0x00000000}},  //   ttug, _márg, খাটি,
  { {0x2cad2a7d, 0x78af001a, 0x69dc2fda, 0x00000000}},  //   reed_, decv, ären,
  { {0x6b9b02d5, 0x7d020007, 0x2cad010e, 0x00000000}},  //   rtug, _emos, seed_,
  { {0x3f8f006c, 0x2cad0061, 0x6b9b00f8, 0x00000000}},  //   lugu_, peed_, stug,
  { {0x69c300ca, 0xf1b201ce, 0x00000000, 0x00000000}},  //   _vrne, בסט_,   ,
  { {0x442b2fdb, 0x752d01ee, 0x907a00b3, 0x00000000}},  //   _nyc_, dlaz, וטרי,
  { {0x6d4b011c, 0x6f0d0051, 0x6b8905c6, 0x00000000}},  //   _higa, éach, mreg,
  { {0x3f8f001c, 0x6d4b14a5, 0x6b8900b5, 0x00000000}},  //   hugu_, _kiga, lreg,
  { {0x752d00bb, 0x442b0036, 0x7cfe0dec, 0x00000000}},  //   glaz, _byc_, tūri,
  { {0x032601fb, 0x6d4b023a, 0x6b8905c6, 0x00000000}},  // [94c0] вдан, _miga, nreg,
  { {0x6d4b19fa, 0x3f8f1b01, 0x394a0161, 0x00000000}},  //   _liga, dugu_, _časy_,
  { {0xe2970888, 0x752d00bb, 0x63a90089, 0x00000000}},  //   тах_, blaz, _ģene,
  { {0x6b8900b5, 0x21670b11, 0x55770049, 0x00000000}},  //   kreg, тици_, _בעטן_,
  { {0xa85700b6, 0x6023007c, 0x752404a7, 0x00000000}},  //   דינה_, адца, moiz,
  { {0x6b890030, 0x6d4b2fdc, 0x57fb009b, 0x00000000}},  //   dreg, _aiga, ולנו,
  { {0x6d4b2fdd, 0x3eae0376, 0x6b8900bb, 0x00000000}},  //   _biga, reft_, ereg,
  { {0x6d4b18a7, 0x2d8e010f, 0x6b8901a2, 0x00000000}},  //   _ciga, rufe_, freg,
  { {0x6b89009f, 0x6d4b033b, 0x2d9c16d0, 0x00000000}},  //   greg, _diga, stve_,
  { {0x61310073, 0x6d4b0d3e, 0x2ac6003b, 0x00000000}},  //   håll, _eiga, тљив,
  { {0xa2c30183, 0x6d4b00f4, 0x7524002d, 0x00000000}},  //   रयत्, _figa, koiz,
  { {0x6b890129, 0x7cf5008e, 0x765c013e, 0x00000000}},  //   breg, _cárd, ecry,
  { {0xe9ff00ad, 0x6d58001c, 0x0eb60061, 0x00000000}},  //   _phải_, lqva, _आघाड,
  { {0x6d4b0dab, 0x6eef0190, 0x6d400133, 0x00000000}},  //   _ziga, _løbn, lmma,
  { {0x09e302a8, 0x35e40ee0, 0x27ed0340, 0x00000000}},  //   _војн, ацтв, šen_,
  { {0x6d4e009d, 0xc9830140, 0x75240032, 0x00000000}},  //   _ébau, _туши, goiz,
  { {0xe9ff0011, 0x6d4000b0, 0x752d0288, 0x00000000}},  // [94d0] _thải_, imma, rlaz,
  { {0x7cf50047, 0x752d0282, 0x8c3d001a, 0x00000000}},  //   _tárg, slaz, meşt,
  { {0x22470210, 0x2d5800f4, 0x8c3d1c17, 0x00000000}},  //   änk_, _née_, leşt,
  { {0x3f8f022b, 0xf8bf00f4, 0x6b890190, 0x00000000}},  //   tugu_, ndé_, yreg,
  { {0x6d4b01d5, 0x8c3d1f4a, 0x8fa50745, 0x00000000}},  //   _riga, neşt, уале,
  { {0x6d4b2fde, 0x539a00b3, 0x7e780089, 0x00000000}},  //   _siga, _אישו, gavp,
  { {0x6d4b00e7, 0x3f8f010e, 0x69dc2fdf, 0x00000000}},  //   _piga, sugu_, ärel,
  { {0x6b890df9, 0x24990f65, 0x7cfe007f, 0x00000000}},  //   treg, _jcsm_, kūru,
  { {0x6d4b006c, 0x1b49103d, 0x74c50044, 0x00000000}},  //   _viga, нзии_, _একাউ,
  { {0x6b8906c0, 0xe9d9012b, 0x6d4000b0, 0x00000000}},  //   rreg, еко_, amma,
  { {0x6d4b148e, 0x7c2b0036, 0x613800b9, 0x00000000}},  //   _tiga, _wygr, síle,
  { {0x6b891c47, 0x69c11bb7, 0x00000000, 0x00000000}},  //   preg, rvle,   ,
  { {0xae07007d, 0x69c12fe0, 0x00000000, 0x00000000}},  //   _वेतन_, svle,   ,
  { {0x7d0929f1, 0x2cbf006c, 0x7cf500b9, 0x00000000}},  //   lies, ldud_, _dáre,
  { {0xe737005e, 0x752401c5, 0x940e006b, 0x00000000}},  //   уер_, toiz, əfə_,
  { {0x7d0918d5, 0xf99201ce, 0x2cbf006c, 0x00000000}},  //   nies, _הרה_, ndud_,
  { {0x4ab7001c, 0x75242fe1, 0x8c3d001a, 0x00000000}},  // [94e0] _असाव, roiz, ceşt,
  { {0x7bc40006, 0xd36f0025, 0x7d0901a2, 0x00000000}},  //   _šiuk, سهم_, hies,
  { {0xea76007b, 0x869b00a3, 0x7d0927ef, 0x00000000}},  //   רגער_, _אייז, kies,
  { {0x7d09174d, 0x7762006b, 0x00000000, 0x00000000}},  //   jies, _çoxs,   ,
  { {0x7d090007, 0xdee601fb, 0xe61200a6, 0x00000000}},  //   dies, лоди, _خشک_,
  { {0x2d80001e, 0x3f5900f6, 0x7cf50048, 0x00000000}},  //   ņiem_, _dèu_, _nárb,
  { {0x7d092fe2, 0xc69300b3, 0xd1320025, 0x00000000}},  //   fies, צאה_, _همس_,
  { {0x7d091058, 0x6d400333, 0xc5f3009b, 0x00000000}},  //   gies, umma, מדו_,
  { {0x4e960025, 0x7cf50285, 0x6d580197, 0x00000000}},  //   _مشار, _bárb, sqva,
  { {0x8c3d001a, 0xd00f03ec, 0x00000000, 0x00000000}},  //   veşt, _علل_,   ,
  { {0x28f91769, 0x7d092aae, 0x39150726, 0x00000000}},  //   вень_, bies, имор,
  { {0x8c3d001a, 0x2ca60e50, 0x3ebe0056, 0x00000000}},  //   teşt, _ubod_, _hatt_,
  { {0xead41734, 0x3ebe18ee, 0xf8bf0068, 0x00000000}},  //   _воль, _katt_, rdé_,
  { {0x8c3d000d, 0xbb830025, 0x26060061, 0x00000000}},  //   reşt, _الوي, _हेही_,
  { {0x8c3d001a, 0x4a5b00a3, 0x7e5701ce, 0x00000000}},  //   seşt, _אדוו, רסלב_,
  { {0xdb19010f, 0xa99b009b, 0x628a008e, 0x00000000}},  //   _erwä, _נבחר, ófon,
  { {0x63b6005b, 0x657a0048, 0x00000000, 0x00000000}},  // [94f0] gwyn, áthr,   ,
  { {0x290b0213, 0x7d090036, 0x3ebe00d8, 0x00000000}},  //   lica_, zies, _natt_,
  { {0x3860009f, 0xa2c9001c, 0x90552fe3, 0x00000000}},  //   _yfir_, _होण्, авец,
  { {0x7cf52678, 0xb4db00f6, 0x7d092fe4, 0x00000000}},  //   _márc, _ciàt, xies,
  { {0x7d0916a6, 0xdb09000c, 0x248e013e, 0x00000000}},  //   vies, kveð, íjmů_,
  { {0x7d092fe5, 0x290b00b5, 0x74d30061, 0x00000000}},  //   wies, hica_, डावृ,
  { {0x7d092305, 0x290b016e, 0x3ebe0635, 0x00000000}},  //   ties, kica_, _datt_,
  { {0xa2c9001c, 0x290b0091, 0x443900ca, 0x00000000}},  //   _होत्, jica_, _kzs_,
  { {0x7d090007, 0x3ebe01d5, 0x69ce0030, 0x00000000}},  //   ries, _fatt_, åben,
  { {0x7d090007, 0x3ebe0066, 0x6eef0030, 0x00000000}},  //   sies, _gatt_, _købm,
  { {0x290b0198, 0x7d0928a9, 0x186a0467, 0x00000000}},  //   fica_, pies, кани_,
  { {0x61fa0004, 0x443900ca, 0x7cf5013e, 0x00000000}},  //   _ütle, _ozs_, _dárc,
  { {0x443900ca, 0x69dc0030, 0x07a61e8a, 0x00000000}},  //   _nzs_, ører, јагн,
  { {0xe73a00ed, 0x3ebe0066, 0x00000000, 0x00000000}},  //   тег_, _xatt_,   ,
  { {0x7ae3002a, 0x649a008b, 0xd62a2fe6, 0x00000000}},  //   _iont, ктар_, тове_,
  { {0x290b05fa, 0x7ae30f90, 0xb466007c, 0x00000000}},  //   cica_, _hont, ркал,
  { {0xdbd90181, 0x42560174, 0xe29a00ed, 0x00000000}},  // [9500] _açúc, атет, каа_,
  { {0x8ccc03d7, 0x68e408b2, 0x577b0049, 0x00000000}},  //   _दोनो, _hoid, _שטיצ,
  { {0x3ebe00f8, 0x68e4010e, 0x00000000, 0x00000000}},  //   _ratt_, _koid,   ,
  { {0x7ae30488, 0x3ebe01e2, 0x68e400b0, 0x00000000}},  //   _lont, _satt_, _joid,
  { {0x3ebe23d6, 0x443900ca, 0x684a0006, 0x00000000}},  //   _patt_, _gzs_, būdž,
  { {0x290b000d, 0xdfcf0054, 0x7ae3023a, 0x00000000}},  //   zica_, بيه_, _nont,
  { {0x629c06ec, 0x443901c5, 0x00000000, 0x00000000}},  //   _icro, _zzs_,   ,
  { {0x290b049a, 0x7ae3002a, 0x3ea000b9, 0x00000000}},  //   xica_, _aont, řit_,
  { {0x7ae30010, 0x2eb60aef, 0x3ebe0056, 0x00000000}},  //   _bont, _всес, _tatt_,
  { {0x60c2010a, 0x8f9b00b3, 0x3b070026, 0x00000000}},  //   ldom, _בימי, _cmnq_,
  { {0x7ae32578, 0x68f61ffe, 0x3257009b, 0x00000000}},  //   _dont, _blyd, יסים_,
  { {0x60c000c7, 0x68f60ca4, 0x61e30190, 0x00000000}},  //   _jamm, _clyd, ønli,
  { {0x4bd70014, 0x81ac0044, 0x68e400c4, 0x00000000}},  //   _نبود_, কটি_, _doid,
  { {0x60c0006c, 0x7ae3005b, 0xbb4301fc, 0x00000000}},  //   _lamm, _gont, _дечк,
  { {0x5bb6006e, 0x60c22fe7, 0x68f61f9d, 0x00000000}},  //   _अनुव, kdom, _flyd,
  { {0x629c00ab, 0x2fc60091, 0x81ac0044, 0x00000000}},  //   _acro, kvog_, কটা_,
  { {0x5695005e, 0x60c205d5, 0x7cf50010, 0x00000000}},  // [9510] _лапт, ddom, _jára,
  { {0x60c21b5a, 0x68e41f51, 0x6131068f, 0x00000000}},  //   edom, _zoid, måli,
  { {0x651900a6, 0x31580025, 0xb4db0129, 0x00000000}},  //   _مقدس_, لجنة_, _diàr,
  { {0x60c01f95, 0x60c203bd, 0x6b820091, 0x00000000}},  //   _camm, gdom, _ovog,
  { {0x60c002e1, 0xf8bf00f4, 0x7cf506b8, 0x00000000}},  //   _damm, llés_, _nára,
  { {0x69ca00d4, 0xaf040088, 0x60c20036, 0x00000000}},  //   _orfe, опіл, adom,
  { {0x613800b9, 0x60c2009d, 0x645a001a, 0x00000000}},  //   síla, bdom, _ştii,
  { {0xeb9909e8, 0x7ae30023, 0x26c11449, 0x00000000}},  //   гии_, _sont, _laho_,
  { {0x7ae31596, 0x69ca018e, 0x09e40044, 0x00000000}},  //   _pont, _arfe, _ফেলা,
  { {0x26c12048, 0x60c01bac, 0x68f61bbb, 0x00000000}},  //   _naho_, _zamm, _slyd,
  { {0x68e400f4, 0x7ae303f0, 0x60c00943, 0x00000000}},  //   _poid, _vont, _yamm,
  { {0x673e0065, 0x7ae3061d, 0x7cf513f5, 0x00000000}},  //   _shpj, _wont, _fára,
  { {0x68e4021e, 0x6b650088, 0x69ca00c7, 0x00000000}},  //   _void, _укла, _erfe,
  { {0x7afa111d, 0x60c20089, 0xa03a0049, 0x00000000}},  //   chtt, zdom, טערפ,
  { {0x99850b59, 0xf8bf0f2a, 0xb99501b7, 0x00000000}},  //   _البو, glés_, _العب,
  { {0x629c001c, 0xe8f60123, 0xa50701ee, 0x00000000}},  //   _scro, _دستخ, беса_,
  { {0x60c001e3, 0x7cfc0047, 0x63bd0009, 0x00000000}},  // [9520] _ramm, _férf, _cssn,
  { {0x60c027a1, 0x212d0022, 0xf8bf009d, 0x00000000}},  //   _samm, _akeh_, blés_,
  { {0x60c00022, 0x60c20d22, 0xb4db0129, 0x00000000}},  //   _pamm, tdom, _viàr,
  { {0x7bcb00d6, 0x03a601e0, 0x53a60478, 0x00000000}},  //   _orgu, _лимо, _ламб,
  { {0x4424001d, 0x81e60055, 0xbbb60164, 0x00000000}},  //   _âm_, _বেশ_, _अनेक,
  { {0x63a40006, 0x60c205d5, 0x60c00bc7, 0x00000000}},  //   mtin, sdom, _wamm,
  { {0x60c0003c, 0x81e60055, 0xa3c2007d, 0x00000000}},  //   _tamm, _বের_, ्मक_,
  { {0x63a400ab, 0x7cf50010, 0xa11601d8, 0x00000000}},  //   otin, _pára, _اورت,
  { {0xac180888, 0xa2cd0061, 0xda7a02be, 0x00000000}},  //   ропу_, साच्, лян_,
  { {0xf2d30049, 0x7cf50010, 0xdd7300a1, 0x00000000}},  //   ִער_, _vára, _کھوک,
  { {0x63a4003c, 0x7bcb0d3d, 0x68fd0023, 0x00000000}},  //   htin, _ergu, ërdo,
  { {0x63a42fe8, 0x7cfc000c, 0x6b820166, 0x00000000}},  //   ktin, _sérf, _tvog,
  { {0x63a412d8, 0x6d5a1212, 0x26c100fa, 0x00000000}},  //   jtin, _huta, _paho_,
  { {0x6d5a000b, 0x7e7a00f8, 0xf4c50044, 0x00000000}},  //   _kuta, _jetp, _একেব,
  { {0x6d5a12e0, 0x26c309e4, 0x63a40aba, 0x00000000}},  //   _juta, rdjo_, etin,
  { {0x6d5a2953, 0xa4f1014a, 0x7cf50051, 0x00000000}},  //   _muta, _dışı_, _lárn,
  { {0x63a40343, 0x6d5a0cda, 0x69c805b7, 0x00000000}},  // [9530] gtin, _luta, lvde,
  { {0x7e7a0190, 0x6d5a06fa, 0xf8bf01e6, 0x00000000}},  //   _netp, _outa, plés_,
  { {0x7cfc0047, 0x2ee50210, 0x6d5a0006, 0x00000000}},  //   _kérd, _rolf_, _nuta,
  { {0x63a42fe9, 0x999b0049, 0xd0111095, 0x00000000}},  //   btin, רבאט, ولا_,
  { {0x6d5a00f4, 0x63a40549, 0xdbf100b9, 0x00000000}},  //   _auta, ctin, _přív,
  { {0x6d5a2fea, 0x3983011f, 0x9abc002b, 0x00000000}},  //   _buta, yıs_, soċj,
  { {0x78ad0119, 0x7bc7001e, 0x3f760036, 0x00000000}},  //   _obav, ājum, ału_,
  { {0x6d5a0a44, 0xab65004c, 0x55780049, 0x00000000}},  //   _duta, овил, זעהן_,
  { {0xeab902dc, 0x28dd0204, 0x00000000, 0x00000000}},  //   айп_, यानि,   ,
  { {0x7e7a2feb, 0x6d5a0010, 0x78ad2fec, 0x00000000}},  //   _getp, _futa, _abav,
  { {0xd94601be, 0x6d5a1855, 0x63a40032, 0x00000000}},  //   жени, _guta, ztin,
  { {0x63a4009f, 0x7bcb016c, 0x00000000, 0x00000000}},  //   ytin, _trgu,   ,
  { {0xe73a2fed, 0x7cf50047, 0xbbeb05d4, 0x00000000}},  //   ием_, _háro, _حرام_,
  { {0x7cf50010, 0x291900b0, 0x63a401ee, 0x00000000}},  //   _káro, ansa_, vtin,
  { {0x39400a8a, 0x69160059, 0x65c30364, 0x00000000}},  //   _this_, jšeg, мбра,
  { {0x68fd010f, 0x00000000, 0x00000000, 0x00000000}},  //   chsd,   ,   ,
  { {0x63a401e5, 0x130a007e, 0x03a300ed, 0x00000000}},  // [9540] utin, анай_, мито,
  { {0x63a4046e, 0x78ad2fee, 0x16aa09e8, 0x00000000}},  //   rtin, _zbav, _твои_,
  { {0x0219008b, 0x7cf50428, 0x7bcd25ec, 0x00000000}},  //   біць_, _náro, _šaul,
  { {0x63a41bbb, 0x7cfc0010, 0x92da0044, 0x00000000}},  //   ptin, _kére, ়সে_,
  { {0x6d5a010a, 0xae9a0025, 0x316d012d, 0x00000000}},  //   _suta, لضغط_, _čeze_,
  { {0x2480002a, 0x7cfc0010, 0x3ce6006c, 0x00000000}},  //   laim_, _mére, _soov_,
  { {0xccfa003b, 0x7cf50010, 0x3f760036, 0x00000000}},  //   ићи_, _várn, słu_,
  { {0x6d5c0b33, 0x24800048, 0x7e7a0908, 0x00000000}},  //   _éram, naim_, _wetp,
  { {0xd0120188, 0x9abc002b, 0x2fcd0133, 0x00000000}},  //   _غلط_, loċi, _greg_,
  { {0x79a602dc, 0x78ad0197, 0x3f800006, 0x00000000}},  //   орме, _sbav, šius_,
  { {0xed5a008b, 0x7cfc029d, 0xdca600ed, 0x00000000}},  //   _тое_, _aére, _мажи,
  { {0x7cfc2fef, 0x69c800f8, 0x00000000, 0x00000000}},  //   _bére, rvde,   ,
  { {0x7cf501ca, 0x7cfc00c4, 0x24802ff0, 0x00000000}},  //   _záro, _cére, daim_,
  { {0xdcf80006, 0x00000000, 0x00000000, 0x00000000}},  //   tuvė,   ,   ,
  { {0x6d420011, 0xa4d503e8, 0x00000000, 0x00000000}},  //   _khoa, пові,   ,
  { {0x2458041f, 0x7aea0089, 0x78ad2982, 0x00000000}},  //   жать_, žotā, _ubav,
  { {0x7cfc00f4, 0xd25b1efa, 0x2bcd013d, 0x00000000}},  // [9550] _gére, аце_, ़िया,
  { {0x026b007e, 0x00000000, 0x00000000, 0x00000000}},  //   ршай_,   ,   ,
  { {0x116a007a, 0x24800051, 0x51841606, 0x00000000}},  //   مللی_, baim_, дуча,
  { {0x1db40061, 0x2fcd00ea, 0x24800048, 0x00000000}},  //   ंबईत, _preg_, caim_,
  { {0x7c220065, 0x9f350088, 0x00000000, 0x00000000}},  //   _nxor, педі,   ,
  { {0xed59004c, 0x7cf507fd, 0x69160e0d, 0x00000000}},  //   бок_, _páro, pšeg,
  { {0x408700ed, 0xad580a78, 0x63b9005d, 0x00000000}},  //   _муаб, орых_, şanı,
  { {0x7cf50047, 0x2fcd0065, 0x6d420082, 0x00000000}},  //   _váro, _treg_, _choa,
  { {0x2d980039, 0x3ec400b0, 0x7bc9009d, 0x00000000}},  //   _åren_, östä_, uveu,
  { {0x7bc900f4, 0x4fc4008b, 0x7cf50010, 0x00000000}},  //   rveu, _ўста, _táro,
  { {0x99d51019, 0x00000000, 0x00000000, 0x00000000}},  //   ستدا,   ,   ,
  { {0x7cfc004a, 0x6131063b, 0x00000000, 0x00000000}},  //   _pére, måls,   ,
  { {0x6d492ff1, 0x7cf50010, 0x2480010e, 0x00000000}},  //   mmea, _járm, vaim_,
  { {0xb8f302d2, 0x7cf52ff2, 0x6d490c0e, 0x00000000}},  //   _हो_, _márm, lmea,
  { {0x24802f50, 0x00000000, 0x00000000, 0x00000000}},  //   taim_,   ,   ,
  { {0x7d1b2ff3, 0x77860517, 0x6d4904df, 0x00000000}},  //   nnus, _елиз, nmea,
  { {0x24800051, 0x7cfc1261, 0xaad00061, 0x00000000}},  // [9560] raim_, _hérc, _थोडक,
  { {0x6d490051, 0x66270010, 0x248016eb, 0x00000000}},  //   hmea, érké, saim_,
  { {0x672e0146, 0xc2190088, 0x7d1b0190, 0x00000000}},  //   mobj, оєї_, knus,
  { {0x7cfc2ff4, 0x3167027b, 0x7cf50047, 0x00000000}},  //   _mérc, ínza_, _bárm,
  { {0xa49b000a, 0x6d49017b, 0x7cf500fa, 0x00000000}},  //   _blòf, dmea, _cárm,
  { {0x6daa005f, 0x6e9406e3, 0x7d1b006c, 0x00000000}},  //   _fəal, фику, enus,
  { {0x4343081c, 0x1ea90d3a, 0x00000000, 0x00000000}},  //   _черв, تاني_,   ,
  { {0x7cf500dc, 0x7d1b0614, 0xf653009b, 0x00000000}},  //   _fárm, gnus, עצה_,
  { {0x395c0f10, 0xa49b0173, 0x00000000, 0x00000000}},  //   _suvs_, _imòt,   ,
  { {0xfee90025, 0xb4db0011, 0xbea30140, 0x00000000}},  //   _وعلى_, _nhàn, _паук,
  { {0x386d0211, 0x672e0059, 0x6d420011, 0x00000000}},  //   ñero_, dobj, _thoa,
  { {0x7c22002d, 0xddc82ff5, 0x6d4900e5, 0x00000000}},  //   _txor, _kedž, cmea,
  { {0x2c080014, 0x3f8600c4, 0xb9a300a1, 0x00000000}},  //   _بعضی_, nsou_, ومیٹ,
  { {0xddc8010a, 0xb4db001d, 0x3f8600fa, 0x00000000}},  //   _medž, _chàn, isou_,
  { {0xbb2b00a1, 0x00000000, 0x00000000, 0x00000000}},  //   _اتنے_,   ,   ,
  { {0x2eb903d7, 0x645a001a, 0x7aea0190, 0x00000000}},  //   _इस्त, _ştir, _hoft,
  { {0x3f8600b9, 0x69c5000c, 0x98a4012b, 0x00000000}},  // [9570] jsou_, _áher, _чиње,
  { {0xd25b1606, 0xd7fc009b, 0x7bcd0006, 0x00000000}},  //   сца_, _להחל, _šauk,
  { {0xaaae0164, 0xf1c20089, 0x7aea12e9, 0x00000000}},  //   ज्यक, jušā_, _moft,
  { {0x7aea124c, 0x00000000, 0x00000000, 0x00000000}},  //   _loft,   ,   ,
  { {0x3ce00309, 0x00000000, 0x00000000, 0x00000000}},  //   काने_,   ,   ,
  { {0xe8da03d7, 0x2d5100b9, 0x799a0020, 0x00000000}},  //   _बच्च, _všem_, kutw,
  { {0x7bc2000a, 0x6d490c78, 0x6aba06ec, 0x00000000}},  //   _asou, tmea, detf,
  { {0xed560265, 0x613102e1, 0x00000000, 0x00000000}},  //   мощ_, råls,   ,
  { {0x6d490fff, 0x7d1b0ad1, 0xddc8012d, 0x00000000}},  //   rmea, rnus, _gedž,
  { {0xff530025, 0x3869000c, 0x799a0020, 0x00000000}},  //   _أخر_, _afar_, futw,
  { {0x776d05d2, 0x7bc2000a, 0x7aea00f8, 0x00000000}},  //   _atax, _esou, _doft,
  { {0x38690065, 0x7cf50010, 0x7bc20009, 0x00000000}},  //   _cfar_, _márk, _fsou,
  { {0xfaa50175, 0xe9db0014, 0x99d50014, 0x00000000}},  //   _жало, _گذشت_, ستگا,
  { {0xfc300445, 0x00000000, 0x00000000, 0x00000000}},  //   _صحن_,   ,   ,
  { {0x7cfc2ff6, 0x64a62ff7, 0xe73700ed, 0x00000000}},  //   _héra, мава, фер_,
  { {0x69c301d6, 0x6eef0030, 0x672e29f9, 0x00000000}},  //   _isne, _købs, sobj,
  { {0xb4db00ad, 0xb4be03d7, 0xe94700a6, 0x00000000}},  // [9580] _thàn, _इसी_, _تروی,
  { {0x61380ca7, 0x2d8705b7, 0xb0c6007d, 0x00000000}},  //   míli, ksne_, _रोजग,
  { {0x7cf50010, 0x0219007e, 0x6eef0190, 0x00000000}},  //   _várj, піць_, _løbs,
  { {0x7cf500b9, 0x0cd80044, 0x69c32ff8, 0x00000000}},  //   _dárk, _তত্ত, _msne,
  { {0x6ef40129, 0xddd811af, 0x00000000, 0x00000000}},  //   _hàbi, davš,   ,
  { {0x69c3000a, 0xbd6a005e, 0x81b60044, 0x00000000}},  //   _osne, орие_, জিব_,
  { {0xf987026c, 0x3f860181, 0x2cad0133, 0x00000000}},  //   _جب_, ssou_, ffed_,
  { {0x67210746, 0xdb1901a2, 0x40930025, 0x00000000}},  //   člji, _erwü, _للفر,
  { {0x7aea001a, 0x7cfc009d, 0x69c300fa, 0x00000000}},  //   _poft, _céra, _asne,
  { {0x7aea008d, 0x7cfc00f4, 0x00000000, 0x00000000}},  //   _qoft, _déra,   ,
  { {0x6aba0f5d, 0xd9151001, 0x00000000, 0x00000000}},  //   retf, едны,   ,
  { {0x61e30039, 0x7bc2000a, 0x38690023, 0x00000000}},  //   änli, _tsou, _qfar_,
  { {0x628e004f, 0x7cfc0e16, 0x69c32ff9, 0x00000000}},  //   _odbo, _géra, _esne,
  { {0xaff90049, 0x00000000, 0x00000000, 0x00000000}},  //   פּרי,   ,   ,
  { {0xe93b035b, 0x16342e54, 0x5ec80044, 0x00000000}},  //   _وسعت_, веря, লাপে,
  { {0x628e0016, 0x3ea90166, 0x27ee0023, 0x00000000}},  //   _adbo, đati_, ëjnë_,
  { {0x61380181, 0xa87c009b, 0x43740088, 0x00000000}},  // [9590] cíli, _ואחר, вуєт,
  { {0x28dd0061, 0x7cf52717, 0x68ed02d4, 0x00000000}},  //   यावि, _párk, _hoad,
  { {0x68ed002d, 0x2d9c001b, 0x6ef400d4, 0x00000000}},  //   _koad, juve_, _gàbi,
  { {0x78bd0039, 0x2d9c004a, 0x659a0049, 0x00000000}},  //   nesv, duve_, _צירק,
  { {0x68ed2b11, 0x3f89009d, 0x00000000, 0x00000000}},  //   _moad, éau_,   ,
  { {0x68ed0038, 0xed590077, 0x2cad005b, 0x00000000}},  //   _load, пок_, wfed_,
  { {0x62850058, 0x78bd0479, 0x44392ffa, 0x00000000}},  //   maho, kesv, _hys_,
  { {0xd65800b6, 0x62850010, 0x2d8701ee, 0x00000000}},  //   ויות_, laho, rsne_,
  { {0x60db011c, 0x61380181, 0xfbd10d3a, 0x00000000}},  //   _inum, xíli, اتب_,
  { {0x6285006a, 0x7cf52ffb, 0x78a40197, 0x00000000}},  //   naho, _mári, _sciv,
  { {0x68ed12b2, 0x7cf50051, 0xc3320097, 0x00000000}},  //   _boad, _lári, רוי_,
  { {0xb4be03d7, 0x7cfc009f, 0x68ed001a, 0x00000000}},  //   _इसे_, _hérn, _coad,
  { {0xb8e803d7, 0x44392ffc, 0x62851449, 0x00000000}},  //   _उस_, _nys_, kaho,
  { {0x29020065, 0x6d591876, 0x613800c4, 0x00000000}},  //   shka_, _hiwa, ríli,
  { {0x6d59000b, 0x61380181, 0x386b0051, 0x00000000}},  //   _kiwa, síli, éirí_,
  { {0x07a60081, 0x44391b91, 0x6d59003f, 0x00000000}},  //   _заин, _bys_, _jiwa,
  { {0x442602d5, 0x2bd2013d, 0x7cf52ffd, 0x00000000}},  // [95a0] ço_, तिया, _várh,
  { {0x60db2ffe, 0x6d59011c, 0xa857009b, 0x00000000}},  //   _anum, _liwa, _איפה_,
  { {0x5ec80044, 0x290001a3, 0x443900d9, 0x00000000}},  //   লামে, _klia_, _eys_,
  { {0x6d592fff, 0xcfa60478, 0x60c9004a, 0x00000000}},  //   _niwa, ешки, _caem,
  { {0x08770049, 0x628500e0, 0x4439123c, 0x00000000}},  //   גענט_, baho, _gys_,
  { {0x2d9c3000, 0x60db0035, 0x8f750088, 0x00000000}},  //   tuve_, _enum, туці,
  { {0x6da306e3, 0x7ec80089, 0xb87b0f6c, 0x00000000}},  //   гија, _rūpē, rkíz,
  { {0xed57012b, 0x6d590022, 0x2d9c28e2, 0x00000000}},  //   ној_, _ciwa, ruve_,
  { {0x6b89003a, 0x68ed00ab, 0xd11700a3, 0x00000000}},  //   gseg, _road, _נקמה_,
  { {0x29002927, 0xa49b0173, 0x00000000, 0x00000000}},  //   _alia_, _klòc,   ,
  { {0xf8dd024c, 0x1317009b, 0x78bd0f86, 0x00000000}},  //   यालय, תחיל_, tesv,
  { {0x62850880, 0x040b0011, 0x29000d0a, 0x00000000}},  //   zaho, _cưỡn, _clia_,
  { {0x040b001d, 0x7cfc1697, 0x68ed00c4, 0x00000000}},  //   _dưỡn, _héro, _voad,
  { {0x29000b93, 0x7f5a002b, 0x443f002b, 0x00000000}},  //   _elia_, _jitq, _ġu_,
  { {0x44391651, 0x68ed3001, 0x628507e4, 0x00000000}},  //   _sys_, _toad, vaho,
  { {0xf98f1298, 0x98a50089, 0xb0cf01f5, 0x00000000}},  //   _ابو_, ēlē_, _सोंग,
  { {0x545500e3, 0x628500b9, 0x00000000, 0x00000000}},  // [95b0] тват, taho,   ,
  { {0x2d8c3002, 0x7cf502d5, 0x60c9010e, 0x00000000}},  //   _ovde_, _vári, _saem,
  { {0x44390343, 0xa2d00061, 0x3949027e, 0x00000000}},  //   _wys_, _डोळ्, _khas_,
  { {0x44390036, 0x62850253, 0x00000000, 0x00000000}},  //   _tys_, saho,   ,
  { {0x7cfc00f4, 0x6d592943, 0x62850275, 0x00000000}},  //   _aéro, _riwa, paho,
  { {0x63ad015e, 0x6d5900e7, 0x9f40000c, 0x00000000}},  //   mtan, _siwa, áið_,
  { {0xa9280142, 0x69160161, 0x00000000, 0x00000000}},  //   nažé, dšen,   ,
  { {0x92580265, 0x7cfc00f4, 0x6b890d49, 0x00000000}},  //   _част_, _déro, tseg,
  { {0x63ad020c, 0x6d59000b, 0x2d8c014a, 0x00000000}},  //   ntan, _viwa, _evde_,
  { {0x9e07017f, 0x3949011c, 0xa3d2007d, 0x00000000}},  //   _пчел, _ahas_, वित_,
  { {0x6b890207, 0x63ad27d2, 0x6d592b1c, 0x00000000}},  //   sseg, htan, _tiwa,
  { {0x63ad01c9, 0xa3c10164, 0x39490048, 0x00000000}},  //   ktan, ंबा_, _chas_,
  { {0x7cfc0010, 0x7bc70089, 0x00000000, 0x00000000}},  //   _mérl, ājus,   ,
  { {0x63ad0ea4, 0x6ef400f6, 0x7c240006, 0x00000000}},  //   dtan, _fàbu, _žirg,
  { {0x63ad0799, 0x6efd000a, 0x00000000, 0x00000000}},  //   etan, _lèbo,   ,
  { {0x2cbf018e, 0x63ad15df, 0x3949002b, 0x00000000}},  //   neud_, ftan, _ghas_,
  { {0xa3d20201, 0xdcea0107, 0x63ad3003, 0x00000000}},  // [95c0] विध_, žiće, gtan,
  { {0x130306b6, 0xc7d7009b, 0x3cef0045, 0x00000000}},  //   азум, _יופי_, _logv_,
  { {0xa50a1ef9, 0x63ad008a, 0x7cfc0010, 0x00000000}},  //   _жена_, atan, _bérl,
  { {0x6f010009, 0x63ad3004, 0xc4830401, 0x00000000}},  //   _allc, btan, _клюк,
  { {0x10a3081c, 0x7cf50010, 0x7cfc3005, 0x00000000}},  //   ричн, _járu, _séro,
  { {0xdd900426, 0x7cfc15a3, 0x09c80044, 0x00000000}},  //   موت_, _péro, ষমতা,
  { {0xe29701f9, 0x78b60161, 0x7cf501e5, 0x00000000}},  //   _јас_, _obyv, _láru,
  { {0x60970025, 0x7cfc009d, 0x614602ea, 0x00000000}},  //   _لنفس_, _véro, _реба,
  { {0x9eaa01f9, 0xfd0f0cd9, 0xf8bf00f4, 0x00000000}},  //   _оваа_, تجو_, nnée_,
  { {0x38601994, 0x8c43025f, 0x691600b9, 0x00000000}},  //   _agir_, шење, ušen,
  { {0x63ad002d, 0x692404eb, 0x7bcd05a0, 0x00000000}},  //   ztan, rđen, _šaut,
  { {0x63ad10e9, 0xd90f00a6, 0x776400f6, 0x00000000}},  //   ytan, تیب_, _buix,
  { {0x63ad1ad6, 0x6916061b, 0x7d021ac4, 0x00000000}},  //   xtan, pšen, _ilos,
  { {0xd7f817c3, 0x8c43170a, 0x395b0066, 0x00000000}},  //   тую_, _тече, _wiqs_,
  { {0xb9090044, 0x80d80204, 0x3495058c, 0x00000000}},  //   _যত_, _नोभे, лавр,
  { {0x63ad0c71, 0x69240091, 0x25ba0022, 0x00000000}},  //   ttan, nđel, _dppl_,
  { {0x29190181, 0xf8bf00f4, 0x776400d4, 0x00000000}},  // [95d0] misa_, gnée_, _guix,
  { {0x63ad0971, 0x291904cb, 0x6443006b, 0x00000000}},  //   rtan, lisa_, ənil,
  { {0xa834025a, 0x7cf50d7f, 0x7d023006, 0x00000000}},  //   _معیش, _kárt, _olos,
  { {0x63ad01aa, 0x2919000b, 0x7cf50010, 0x00000000}},  //   ptan, nisa_, _járt,
  { {0x7cf526d5, 0x6efd000a, 0x83840930, 0x00000000}},  //   _márt, _fèbl, _высе,
  { {0x2489000b, 0x7d0201aa, 0x29190035, 0x00000000}},  //   laam_, _alos, hisa_,
  { {0x29190263, 0x609b0025, 0x00000000, 0x00000000}},  //   kisa_, _يخرج_,   ,
  { {0x7d020038, 0x24890250, 0xdd110095, 0x00000000}},  //   _clos, naam_, _düşl,
  { {0x7cfc3007, 0x3ea500a1, 0x69dc1565, 0x00000000}},  //   _kérj, _مشاہ, åren,
  { {0x81b60044, 0x7d0204e7, 0x6138000c, 0x00000000}},  //   জির_, _elos, bíls,
  { {0x29190020, 0x7cf53008, 0x2010007f, 0x00000000}},  //   fisa_, _bárt, ėlių_,
  { {0x7cf50051, 0x29190058, 0xc19a0049, 0x00000000}},  //   _cárt, gisa_, עשרי,
  { {0xb4db0009, 0x776400c4, 0x24891487, 0x00000000}},  //   _ghài, _quix, daam_,
  { {0x7d02016c, 0x8c1a00a0, 0x673501d5, 0x00000000}},  //   _zlos, _אוני, gozj,
  { {0x2919000b, 0xd6270aa2, 0x442b006b, 0x00000000}},  //   bisa_, горе_, _axc_,
  { {0x29190181, 0x64990b5f, 0x656500e0, 0x00000000}},  //   cisa_, ктур_, _duhh,
  { {0xe3ba008b, 0x03260816, 0x93aa01f7, 0x00000000}},  // [95e0] эба_, гдан, عارف_,
  { {0xf8bf00f4, 0x03a302ea, 0x442b0146, 0x00000000}},  //   rnée_, сифо, _dxc_,
  { {0x442b033f, 0x6b9b22f0, 0x00000000, 0x00000000}},  //   _exc_, hrug,   ,
  { {0xbfaa0140, 0x104a0077, 0x00000000, 0x00000000}},  //   етке_, няли_,   ,
  { {0x7524050a, 0xb4c0006e, 0xd12f0025, 0x00000000}},  //   mniz, ंजी_, أمن_,
  { {0xa3c10309, 0x51861880, 0x91860151, 0x00000000}},  //   ंबर_, _مشرق, _مجرم,
  { {0x7d023009, 0x6f180087, 0x29190045, 0x00000000}},  //   _plos, rivc, yisa_,
  { {0x7cfc0b76, 0x3fa60137, 0x6b9b300a, 0x00000000}},  //   _térm, _مصطف, frug,
  { {0xd0260147, 0x2aaa025f, 0x60c200e7, 0x00000000}},  //   _смай, нтно_, meom,
  { {0x60c2033f, 0x248900b5, 0x6d4b00fa, 0x00000000}},  //   leom, zaam_, _ehga,
  { {0x69160006, 0x7cf52717, 0x6ef40129, 0x00000000}},  //   pšel, _párt, _fàbr,
  { {0x6b9b0030, 0x7d0200b0, 0xb4db0009, 0x00000000}},  //   brug, _ulos, _thài,
  { {0x29190065, 0x68fd300b, 0x6d400009, 0x00000000}},  //   risa_, rksd, mlma,
  { {0x291923f7, 0x27ff002b, 0xa49b00f6, 0x00000000}},  //   sisa_, ġun_, _clòn,
  { {0x29190091, 0x442b00f8, 0x6d4001c3, 0x00000000}},  //   pisa_, _sxc_, olma,
  { {0x69ca01d5, 0x1b1a0044, 0x7524300c, 0x00000000}},  //   _isfe, _নীচে_, gniz,
  { {0x6d400368, 0xd371023c, 0x60c2010e, 0x00000000}},  // [95f0] ilma, زها_, deom,
  { {0x75240032, 0x2489300d, 0x2d9c016c, 0x00000000}},  //   aniz, saam_, krve_,
  { {0x26c3102c, 0x5215300e, 0xf7700014, 0x00000000}},  //   mejo_, јдет, _وای_,
  { {0x26c30b7f, 0x60c20146, 0xe5c40088, 0x00000000}},  //   lejo_, geom, _усьо,
  { {0xa2d00061, 0xafe501ab, 0x00000000, 0x00000000}},  //   _डोक्, ролл,   ,
  { {0x26c3300f, 0x6d400270, 0x69d801ee, 0x00000000}},  //   nejo_, elma, _orve,
  { {0x6b820173, 0xfce52f15, 0xf4ba01e5, 0x00000000}},  //   _awog, иоко, _þýða_,
  { {0x6b9b085a, 0xdb0000f6, 0x00000000, 0x00000000}},  //   trug, lumè,   ,
  { {0x69d80004, 0x2d9c3010, 0x60c4006c, 0x00000000}},  //   _arve, arve_, õime,
  { {0x6b9b002b, 0x26c301d9, 0xe9d90072, 0x00000000}},  //   rrug, jejo_, вко_,
  { {0x62870219, 0x69d80363, 0x2bb70061, 0x00000000}},  //   _mejo, _crve, _अहवा,
  { {0x62873011, 0x69d80091, 0x7cf50a87, 0x00000000}},  //   _lejo, _drve, _várs,
  { {0x290c010a, 0x69ca00d6, 0x69d800bb, 0x00000000}},  //   ėda_, _esfe, _erve,
  { {0x7cf50047, 0x3ced07a0, 0x05020044, 0x00000000}},  //   _társ, ljev_, _এদের_,
  { {0x2d9805cb, 0x7524022e, 0x2d5100ca, 0x00000000}},  //   _året_, tniz, _ušes_,
  { {0x7d1b0f88, 0x8883005e, 0x3ced0fd0, 0x00000000}},  //   nius, _длъж, njev_,
  { {0x75240314, 0xf7720355, 0x93c800a1, 0x00000000}},  // [9600] rniz, _باب_, دازہ_,
  { {0x7d1b0197, 0x7cf5008e, 0x26c300ca, 0x00000000}},  //   hius, _márq, cejo_,
  { {0x41aa00e3, 0xa2a7006e, 0x60c208ce, 0x00000000}},  //   твен_, _चार्, teom,
  { {0x53a60780, 0x19b60049, 0x00000000, 0x00000000}},  //   _камб, יפער_,   ,
  { {0x7d090065, 0xe3b2031d, 0x7d1b0a62, 0x00000000}},  //   dhes, _برج_, dius,
  { {0x7cfc0010, 0x98ab0036, 0x62870093, 0x00000000}},  //   _térk, mocą_, _gejo,
  { {0xb23a0054, 0x63a40052, 0x7cfc00f4, 0x00000000}},  //   _شكرا_, luin, _héri,
  { {0x6b820263, 0x92a60046, 0x7d1b0207, 0x00000000}},  //   _pwog, _wyłą, gius,
  { {0xa2db0061, 0x6d40000c, 0x7cf512c5, 0x00000000}},  //   नाच्, rlma, _párr,
  { {0x69d80209, 0x7cfc06d2, 0x2d9c2c2d, 0x00000000}},  //   _prve, _méri, prve_,
  { {0xf2d90049, 0x63a40145, 0x6ce6007e, 0x00000000}},  //   אַרל, huin, _віле,
  { {0x63a40315, 0xfca90025, 0x7d1b007f, 0x00000000}},  //   kuin, _ماهو_, cius,
  { {0x8c43098c, 0x3157007b, 0xe667151c, 0x00000000}},  //   _деце, ייטן_, итво,
  { {0x63a400d4, 0x7cfc000c, 0x69d8016c, 0x00000000}},  //   duin, _sérh, _trve,
  { {0x26d10046, 0x628711b1, 0x26c3024f, 0x00000000}},  //   rdzo_, _rejo, rejo_,
  { {0x26c33012, 0x3f8f0016, 0x6287009d, 0x00000000}},  //   sejo_, ysgu_, _sejo,
  { {0x63a4081d, 0x26c3008e, 0x6e2d014a, 0x00000000}},  // [9610] guin, pejo_, ğabi,
  { {0x883c00b6, 0x7cfc00f4, 0x6e2d014a, 0x00000000}},  //   _בתחו, _déri, şabi,
  { {0x75d5023c, 0x2d510087, 0x00000000, 0x00000000}},  //   _ايجا, _ošep_,   ,
  { {0x7cfc0699, 0x63a4003a, 0x00000000, 0x00000000}},  //   _féri, buin,   ,
  { {0x63a4001a, 0x7f190cf2, 0x6287004a, 0x00000000}},  //   cuin, ліку_, _tejo,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7d090065, 0x9294003b, 0x3cff010e, 0x00000000}},  //   thes, _фасц, tkuv_,
  { {0x518402dc, 0x00000000, 0x00000000, 0x00000000}},  //   _фура,   ,   ,
  { {0x3ced01d9, 0x7d1b0036, 0x7d090010, 0x00000000}},  //   rjev_, rius, rhes,
  { {0xfe70002c, 0x7d090065, 0x78ad00f6, 0x00000000}},  //   _قدم_, shes, _acav,
  { {0x7d09014a, 0x63a43013, 0x6efd0173, 0x00000000}},  //   phes, zuin, _nèbi,
  { {0x05090044, 0x00000000, 0x00000000, 0x00000000}},  //   রচুর_,   ,   ,
  { {0xeb99004c, 0xdb0b0030, 0x7bd90045, 0x00000000}},  //   _сил_, _opgø, _urwu,
  { {0xa3c10201, 0xda7b041f, 0x00000000, 0x00000000}},  //   ंबई_, _ряд_,   ,
  { {0x7cfc128c, 0xe8d90011, 0x7ae30292, 0x00000000}},  //   _séri, _giỏ_, _innt,
  { {0x7cfc00f4, 0x63a400b0, 0x6efd00d4, 0x00000000}},  //   _péri, tuin, _dèbi,
  { {0x68e41659, 0x044a003b, 0x00000000, 0x00000000}},  // [9620] _inid, упак_,   ,
  { {0x7cfc028c, 0x63a40051, 0x7c2e010f, 0x00000000}},  //   _véri, ruin, ßbri,
  { {0x28dd01f5, 0x68f6014a, 0x63a40e2d, 0x00000000}},  //   याचि, _koyd, suin,
  { {0x29020052, 0x657c0093, 0x660100ea, 0x00000000}},  //   nkka_, mprh, ølke,
  { {0x63a40df9, 0x290200b0, 0x24800023, 0x00000000}},  //   quin, ikka_, mbim_,
  { {0x4dbe0044, 0x2f0b00ea, 0x5f931e8a, 0x00000000}},  //   ্মসূ, _nøgd_, чишт,
  { {0x7cf5004a, 0x93c30035, 0x2fcd01d6, 0x00000000}},  //   _párp, ţătu, _eseg_,
  { {0xbb7403f3, 0x7ae301c3, 0x644b08e8, 0x00000000}},  //   огиј, _annt, ügig,
  { {0x61fe00ea, 0xc006005c, 0x7d000009, 0x00000000}},  //   lypl, _упак, rkms,
  { {0x78ad0207, 0x68e40095, 0x00000000, 0x00000000}},  //   _scav, _anid,   ,
  { {0xdd920014, 0x81b60044, 0x69cf0036, 0x00000000}},  //   _روش_, জিক_, łcen,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x07a4007e, 0x6134026d, 0x00000000, 0x00000000}},  //   паўн, _gülş,   ,
  { {0x98be0089, 0x7cfc06c2, 0x6b56003b, 0x00000000}},  //   ētā_, _cérv, _утех,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68e43014, 0x61fe00b4, 0x00000000, 0x00000000}},  //   _gnid, dypl,   ,
  { {0x36d5003b, 0x2f0b0056, 0x2bdb0316, 0x00000000}},  // [9630] _допр, _høge_, बिया,
  { {0x2f0b0030, 0x44270082, 0x76ab0517, 0x00000000}},  //   _køge_, ăn_, _стив_,
  { {0x24801c50, 0xdb090051, 0x2bcf007d, 0x00000000}},  //   bbim_, nteá, _तैना,
  { {0xdb09002a, 0x00000000, 0x00000000, 0x00000000}},  //   iteá,   ,   ,
  { {0xcf9b012b, 0xff510123, 0x60c4006c, 0x00000000}},  //   ује_, وخت_, õima,
  { {0x13ba0049, 0xd2f6025a, 0x01c900a1, 0x00000000}},  //   _דזשע, _وکلا_, _پورٹ_,
  { {0xace9005e, 0x2909004a, 0x290200ea, 0x00000000}},  //   имка_, _olaa_, ykka_,
  { {0x8b950088, 0x00000000, 0x00000000, 0x00000000}},  //   ороч,   ,   ,
  { {0xa49b000a, 0x68e4012d, 0x34da0049, 0x00000000}},  //   _alòk, _rnid, בֿיב,
  { {0x68f60180, 0x29093015, 0x691611a5, 0x00000000}},  //   _soyd, _alaa_, nšev,
  { {0x2dfa026c, 0xcebb006b, 0xbe04009e, 0x00000000}},  //   _پبلک_, şəsi_, _ٹونٹ,
  { {0x68f6006b, 0x7cfc3016, 0x00000000, 0x00000000}},  //   _qoyd, _sérv,   ,
  { {0x3c47002c, 0x290200b0, 0x4c2500a1, 0x00000000}},  //   _اضاف, rkka_, _بظاہ,
  { {0x2bcf03d7, 0xead4007c, 0x7ae30056, 0x00000000}},  //   _तैया, _ночь, _unnt,
  { {0x96632efa, 0x9f62006b, 0x24f602ea, 0x00000000}},  //   дкре, şqçi_, очар,
  { {0x68e40977, 0xd46702b8, 0x212d0065, 0x00000000}},  //   _unid, жите_, _njeh_,
  { {0x24800314, 0xd7ef0025, 0xb4db0045, 0x00000000}},  // [9640] rbim_, _لكي_, _phàr,
  { {0x681c001e, 0xe29a01e0, 0x6b4f0030, 0x00000000}},  //   rādī, раж_, bøge,
  { {0x673c002b, 0x7c2d000c, 0xf8bf0010, 0x00000000}},  //   morj, _þarf, knél_,
  { {0xb9ac0049, 0x00000000, 0x00000000, 0x00000000}},  //   רבאָ,   ,   ,
  { {0x7cfc0010, 0xa3ce007d, 0x00000000, 0x00000000}},  //   _mért, _शनि_,   ,
  { {0x7c2421e8, 0xdd9a0072, 0x673c1727, 0x00000000}},  //   _žiro, аши_, norj,
  { {0xa3d2007d, 0x4c94004d, 0x213f0022, 0x00000000}},  //   विक_, пийс, _fkuh_,
  { {0x61e10047, 0x3ea00a29, 0x673c0059, 0x00000000}},  //   _álla, şit_, horj,
  { {0x63b60639, 0xd00700e3, 0x2f0b0030, 0x00000000}},  //   ntyn, _дете_, _søge_,
  { {0x29090020, 0x8af7006b, 0x39400006, 0x00000000}},  //   _slaa_, _şəri, _akis_,
  { {0x673c070c, 0x63b600b0, 0x7cfc1e50, 0x00000000}},  //   dorj, htyn, _séru,
  { {0x26d30030, 0x88b10014, 0x7cfc0068, 0x00000000}},  //   _saxo_, ریخچ, _péru,
  { {0xc86401fb, 0xdb090051, 0xab2a01e0, 0x00000000}},  //   дтри, steá, _кода_,
  { {0x673c02db, 0x00000000, 0x00000000, 0x00000000}},  //   gorj,   ,   ,
  { {0x7cfc1f1e, 0x45d400c0, 0xf8bf2688, 0x00000000}},  //   _fért, морс, lném_,
  { {0x92a90036, 0x6b4f0190, 0x00000000, 0x00000000}},  //   kułó, røge,   ,
  { {0x6b4f0030, 0x673c2460, 0xf8bf2ef5, 0x00000000}},  // [9650] søge, borj, nném_,
  { {0x26c7013e, 0x00000000, 0x00000000, 0x00000000}},  //   _úno_,   ,   ,
  { {0x69160059, 0x69240091, 0xc1b9005e, 0x00000000}},  //   ršev, rđev, слех_,
  { {0x55da0049, 0x657a3017, 0x249900e7, 0x00000000}},  //   _פֿינ, íthe, _udsm_,
  { {0x69de0059, 0x2ee50022, 0xf8bf013e, 0x00000000}},  //   _špel, _pnlf_, jném_,
  { {0x644f0089, 0xf8bf00b9, 0x00000000, 0x00000000}},  //   _izci, dném_,   ,
  { {0xf8bf0010, 0x00000000, 0x00000000, 0x00000000}},  //   tnél_,   ,   ,
  { {0x673c0059, 0x7d760025, 0x691601c5, 0x00000000}},  //   zorj, أمير_, nšet,
  { {0x39520016, 0x764500b0, 0xe0d20049, 0x00000000}},  //   _rhys_, _lyhy, _אײן_,
  { {0x38690149, 0x05cb0061, 0x7cfc0092, 0x00000000}},  //   _agar_, ाबाब, _sért,
  { {0x7bc21339, 0x673c0059, 0x4a4502dc, 0x00000000}},  //   _epou, vorj, янов,
  { {0x2fdf0091, 0x63b600b0, 0x00000000, 0x00000000}},  //   _krug_, ytyn,   ,
  { {0x673c2d93, 0x7cfc3018, 0x7d0b0089, 0x00000000}},  //   torj, _vért, _ilgs,
  { {0x7bda009b, 0xbb780123, 0x2cad006c, 0x00000000}},  //   _לקנו, _بلوچ_, lged_,
  { {0x395201d6, 0x76450016, 0x6ace0044, 0x00000000}},  //   _thys_, _cyhy, ়াশো,
  { {0x63b6021e, 0x2cad00ab, 0x673c3019, 0x00000000}},  //   ttyn, nged_, sorj,
  { {0xf42a0027, 0x644f0036, 0x3dc30044, 0x00000000}},  // [9660] _opäť_, _czci, ্মিল,
  { {0x63b60d96, 0x27e00288, 0x434602dc, 0x00000000}},  //   rtyn, _irin_, чезв,
  { {0x63b6301a, 0x7bdb0052, 0x00000000, 0x00000000}},  //   styn, hvuu,   ,
  { {0x2fdf0018, 0x63b60006, 0xa99a0049, 0x00000000}},  //   _brug_, ptyn, מבער,
  { {0x2cad00ab, 0x61e10010, 0x09a8007d, 0x00000000}},  //   dged_, _álln, _कम्य,
  { {0x69c30250, 0xf67a0049, 0x290b0089, 0x00000000}},  //   _opne, זאַמ, ībai_,
  { {0x7bc200b9, 0x629c301b, 0x63a40a74, 0x00000000}},  //   _spou, _idro, lrin,
  { {0xf8bf1465, 0x628e008a, 0x7af8000a, 0x00000000}},  //   tném_, _hebo, _sovt,
  { {0x7cfc009f, 0x8fa300ed, 0x656600ea, 0x00000000}},  //   _sérs, _пате, _mikh,
  { {0x999800ed, 0x63a400c4, 0x6566301c, 0x00000000}},  //   окот_, irin, _likh,
  { {0x63a406b5, 0x6446009f, 0x27e00032, 0x00000000}},  //   hrin, _lyki, _arin_,
  { {0x63a42a46, 0x628e19cd, 0x27e00b73, 0x00000000}},  //   krin, _lebo, _brin_,
  { {0x629c0871, 0x27e00035, 0x7cfc0325, 0x00000000}},  //   _odro, _crin_, _férr,
  { {0x63a40292, 0x27e00abe, 0x628e1238, 0x00000000}},  //   drin, _drin_, _nebo,
  { {0x27e000b5, 0x3abb009b, 0xf8bf0010, 0x00000000}},  //   _erin_, _המונ, nnék_,
  { {0xca470b59, 0x63a40016, 0x629c018e, 0x00000000}},  //   _عليه_, frin, _adro,
  { {0x63a4010a, 0x27e00190, 0x628e0030, 0x00000000}},  // [9670] grin, _grin_, _bebo,
  { {0x628e0b33, 0x69c30085, 0x2fdf0023, 0x00000000}},  //   _cebo, _ypne, _rrug_,
  { {0x320713a5, 0xd047006b, 0x3f80001a, 0x00000000}},  //   ány_, ələn, ţiul_,
  { {0x63a4301d, 0xf42a0027, 0xdb0000f6, 0x00000000}},  //   brin, _späť_, humà,
  { {0xf8bf009d, 0x63a40133, 0x3fc90014, 0x00000000}},  //   ciée_, crin, تدای_,
  { {0x628e0fe2, 0x2fdf0007, 0x61e10010, 0x00000000}},  //   _gebo, _vrug_, _állo,
  { {0x30a70a1e, 0x60dd004a, 0x00000000, 0x00000000}},  //   _нрав, _ósmo,   ,
  { {0x629c13c2, 0x48e80055, 0x26ca301e, 0x00000000}},  //   _zdro, _পত্র, zebo_,
  { {0x2cad301f, 0x69dc08e0, 0x26d83020, 0x00000000}},  //   rged_, æren, ydro_,
  { {0x7c26000c, 0x1a05005e, 0x6d420032, 0x00000000}},  //   úkra, дпом, _ekoa,
  { {0x98a600e2, 0x25b80026, 0x00000000, 0x00000000}},  //   мине, xtrl_,   ,
  { {0x27e0000d, 0x63a40056, 0xec6e025f, 0x00000000}},  //   _prin_, yrin, _јп_,
  { {0x26ca01d6, 0xcd4200a1, 0x7cfc3021, 0x00000000}},  //   tebo_, _جھوٹ, _térr,
  { {0x6d49002a, 0x656600ea, 0x6d5b3022, 0x00000000}},  //   llea, _sikh, lmua,
  { {0xed16026c, 0xe64300ed, 0x6566129a, 0x00000000}},  //   _رہیں_, верп, _pikh,
  { {0x628e0387, 0x752d0207, 0x27e0022c, 0x00000000}},  //   _sebo, gnaz, _trin_,
  { {0x6d491d53, 0xc953009b, 0x628e00e0, 0x00000000}},  // [9680] ilea, _במה_, _pebo,
  { {0x6d5b0065, 0xf8bf00f4, 0x6d490048, 0x00000000}},  //   hmua, riée_, hlea,
  { {0x63a4127b, 0x65660066, 0xd46a005e, 0x00000000}},  //   srin, _tikh, _мине_,
  { {0x63a41d7a, 0x628e3023, 0xc5f300a0, 0x00000000}},  //   prin, _webo, _סדר_,
  { {0x628e0161, 0x00000000, 0x00000000, 0x00000000}},  //   _tebo,   ,   ,
  { {0xf8bf0010, 0xdee30140, 0x877b0049, 0x00000000}},  //   tnék_, кочи, קאצי,
  { {0x6263017a, 0x00000000, 0x00000000, 0x00000000}},  //   _авра,   ,   ,
  { {0xe8e00082, 0xed57025f, 0x00000000, 0x00000000}},  //   _trội_, мој_,   ,
  { {0xaf2a02dc, 0x00000000, 0x00000000, 0x00000000}},  //   _джаз_,   ,   ,
  { {0xadba0054, 0xe45701ce, 0x6d490032, 0x00000000}},  //   _وهذا_, ויפט_, alea,
  { {0x6d4900f4, 0xf2d300b6, 0x5eeb0061, 0x00000000}},  //   blea, דעת_, चार्_,
  { {0xcb6a026b, 0x6d4900ab, 0xf78700fa, 0x00000000}},  //   _даде_, clea, íços_,
  { {0xac97007a, 0x6d4005dd, 0x78bd01e5, 0x00000000}},  //   _آنها_, moma, rfsv,
  { {0x6d4000b0, 0x2f0b08c8, 0x2bdb0061, 0x00000000}},  //   loma, _løgn_, बिरा,
  { {0xdb00008e, 0x31c80204, 0x00000000, 0x00000000}},  //   cumá, रबोध,   ,
  { {0x6d40021e, 0x66f8014a, 0x657a0010, 0x00000000}},  //   noma, _aşkı, ítha,
  { {0x752d1a64, 0xf66b0025, 0x43940364, 0x00000000}},  // [9690] rnaz, _وحده_, катс,
  { {0x6d401c7e, 0x6d49002d, 0x00000000, 0x00000000}},  //   homa, zlea,   ,
  { {0x6d40021e, 0x7cf500c4, 0x6d493024, 0x00000000}},  //   koma, _várz, ylea,
  { {0x55760049, 0x00000000, 0x00000000, 0x00000000}},  //   _רערן_,   ,   ,
  { {0x6d401cc4, 0x2f0b05b7, 0x25750039, 0x00000000}},  //   doma, _døgn_, _hål_,
  { {0x63ad0149, 0x60cb0109, 0xda0e0061, 0x00000000}},  //   muan, segm, ानात_,
  { {0x6d4001aa, 0x63ad027e, 0x2009008f, 0x00000000}},  //   foma, luan, šai_,
  { {0x6d49027b, 0x2575044f, 0x6d4000c4, 0x00000000}},  //   ulea, _mål_, goma,
  { {0x6d490add, 0x63ad0207, 0x6d5b0065, 0x00000000}},  //   rlea, nuan, rmua,
  { {0x6d49022b, 0xa3e002fb, 0xfaf10025, 0x00000000}},  //   slea, थित_, اثة_,
  { {0x6d490211, 0x63ad0733, 0xf8bf2b60, 0x00000000}},  //   plea, huan, ffé_,
  { {0x6d401800, 0xdb0902d5, 0xe8f70147, 0x00000000}},  //   coma, nteú, елю_,
  { {0x63ad04cb, 0xfaa501e0, 0x7d090093, 0x00000000}},  //   juan, _зало, mkes,
  { {0x63ad0169, 0x7d0905d5, 0x2575032e, 0x00000000}},  //   duan, lkes, _bål_,
  { {0xe7370517, 0x00000000, 0x00000000, 0x00000000}},  //   хер_,   ,   ,
  { {0x69a40061, 0x63ad00e7, 0x7c240e3b, 0x00000000}},  //   _किती, fuan, _žiri,
  { {0x63ad0129, 0xa49b01aa, 0x03a301ab, 0x00000000}},  // [96a0] guan, _alòs, лито,
  { {0x0686008b, 0xdbc6006c, 0x6d400035, 0x00000000}},  //   _ягон, _tööa, zoma,
  { {0x7d0901e3, 0x6d401baa, 0xa49b000a, 0x00000000}},  //   kkes, yoma, _plòt,
  { {0x26da000b, 0x63ad008a, 0x397a0049, 0x00000000}},  //   _hapo_, buan, לטענ,
  { {0xd12f0644, 0x4375003b, 0x63ad004a, 0x00000000}},  //   حمن_, _ауст, cuan,
  { {0x26da1077, 0x31711624, 0x2d8c0058, 0x00000000}},  //   _japo_, _fuzz_, _pwde_,
  { {0x2d9a1580, 0x26da3025, 0x5d6602e9, 0x00000000}},  //   épe_, _mapo_, нтиз,
  { {0xc5f300b6, 0x91bb009b, 0x8d7300a1, 0x00000000}},  //   רדה_, _ממלי, داوا,
  { {0x39420de8, 0x5ce3007c, 0x00000000, 0x00000000}},  //   doks_, ующа,   ,
  { {0x2d6e0224, 0x6d40016a, 0x6b4f0030, 0x00000000}},  //   _před_, soma, søgn,
  { {0x6d400036, 0x2efe0085, 0xddc800b4, 0x00000000}},  //   poma, _iotf_, _wzdł,
  { {0x69b1013d, 0x63ad1ecd, 0x386d068f, 0x00000000}},  //   _अमरी, yuan, øer_,
  { {0xb8d90183, 0xbb2b00a1, 0x26da11fe, 0x00000000}},  //   _चा_, _کتنے_, _bapo_,
  { {0x26da0207, 0xe667005e, 0x00000000, 0x00000000}},  //   _capo_, етбо,   ,
  { {0x95c80216, 0x3942004e, 0x38c900a1, 0x00000000}},  //   нута_, boks_, _ہاکی_,
  { {0x290b0580, 0xa4d40088, 0x799a00b4, 0x00000000}},  //   ības_, лосі, mstw,
  { {0x68ed002b, 0xb4db00f6, 0x317101d6, 0x00000000}},  // [96b0] _inad, _khàz, _suzz_,
  { {0x63ad3026, 0x257500f8, 0x26da00e5, 0x00000000}},  //   ruan, _tål_, _gapo_,
  { {0x799a0c28, 0x692b00b9, 0x41e4007e, 0x00000000}},  //   nstw, před, ліца,
  { {0x63ad0a15, 0x67270009, 0xdb000934, 0x00000000}},  //   puan, lijj, lumä,
  { {0x63ad1729, 0x389c01ce, 0x26da0020, 0x00000000}},  //   quan, ליאנ, _yapo_,
  { {0x6da5026b, 0xf3ff0011, 0xa49b0129, 0x00000000}},  //   вика, _ngãi_, _glòr,
  { {0x53340264, 0x68ed00d4, 0x7d0903b6, 0x00000000}},  //   _серт, _onad, tkes,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa2c1001c, 0xdb00003c, 0x00000000, 0x00000000}},  //   र्थ्, kumä,   ,
  { {0x68ed014a, 0x7d09006c, 0xf8aa0309, 0x00000000}},  //   _anad, skes, कल्प,
  { {0x26da01aa, 0x39420006, 0x60db0085, 0x00000000}},  //   _rapo_, toks_, _kaum,
  { {0xdb2604e1, 0x60db0129, 0x26da3027, 0x00000000}},  //   _یونی, _jaum, _sapo_,
  { {0x26da2564, 0x60db0020, 0x7d0600b0, 0x00000000}},  //   _papo_, _maum, ökse,
  { {0x4ad7009c, 0xfaa501f9, 0x68ed3028, 0x00000000}},  //   _ساتھ_, _рако, _enad,
  { {0xceb2019b, 0x6d590003, 0x6b9b000c, 0x00000000}},  //   יים_, _khwa, lsug,
  { {0x26da0020, 0x443900f6, 0x68ed01a2, 0x00000000}},  //   _wapo_, _bxs_, _gnad,
  { {0x26da0006, 0xe3ba0a78, 0x29120a89, 0x00000000}},  // [96c0] _tapo_, ьба_, _ilya_,
  { {0xdb00006b, 0x68ed11af, 0x2900010e, 0x00000000}},  //   rumç, _znad, _hoia_,
  { {0x60db010f, 0x44390009, 0x68ed005b, 0x00000000}},  //   _baum, _exs_, _ynad,
  { {0xdcfe0089, 0x29003029, 0x6b9b302a, 0x00000000}},  //   īvīb, _joia_, ksug,
  { {0xe0430517, 0x08770049, 0x60db01a2, 0x00000000}},  //   анци, דענט_, _daum,
  { {0xa3c1013d, 0x6d590022, 0xdfcf0025, 0x00000000}},  //   ूबर_, _ahwa, تيه_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d59302b, 0x60db0089, 0x290013ca, 0x00000000}},  //   _chwa, _gaum, _noia_,
  { {0x5ec70044, 0x504610e1, 0x6b9b011c, 0x00000000}},  //   লয়ে, _реаб, gsug,
  { {0x68ed00b9, 0x3f860129, 0x7f43009d, 0x00000000}},  //   _snad, mpou_, conq,
  { {0x7c2d009f, 0x60db0697, 0x29000375, 0x00000000}},  //   _þarn, _yaum, _boia_,
  { {0x0c260057, 0x799a0046, 0xe8e0001d, 0x00000000}},  //   _имен, rstw, _trời_,
  { {0x692b0224, 0x212400e7, 0x29000288, 0x00000000}},  //   třeb, _mmmh_, _doia_,
  { {0xf8bf0211, 0x644b006c, 0x19ba0025, 0x00000000}},  //   cién_, ügim, _قطعة_,
  { {0xf62801fb, 0xdb000039, 0x9f440065, 0x00000000}},  //   віти_, rumä, _armë_,
  { {0x69d8006b, 0x68ed0020, 0x290020c6, 0x00000000}},  //   _isve, _unad, _goia_,
  { {0x545501fb, 0xe8d90011, 0x60db302c, 0x00000000}},  // [96d0] уват, _nhỉ_, _raum,
  { {0x60db2671, 0xe3b00d75, 0x36d501ab, 0x00000000}},  //   _saum, ترف_, _соор,
  { {0x26d1302d, 0x60db011c, 0x7c36000c, 0x00000000}},  //   mezo_, _paum, _þyrf,
  { {0x26d1000b, 0x30150088, 0x629700f6, 0x00000000}},  //   lezo_, лдер, saxo,
  { {0xe8d900ad, 0xd91c007b, 0xf8bf027b, 0x00000000}},  //   _chỉ_, וואל, lnés_,
  { {0x7c2d050f, 0x60db0020, 0x69ca010f, 0x00000000}},  //   _žaro, _waum, _opfe,
  { {0xf8bf00f4, 0x60db18bb, 0x2d94007e, 0x00000000}},  //   nnés_, _taum, арыс,
  { {0x26d1000b, 0x2bb7001c, 0x925801fc, 0x00000000}},  //   hezo_, _आमदा, _раст_,
  { {0x26d1000b, 0x69ca010f, 0x6e3a0009, 0x00000000}},  //   kezo_, _apfe, _extb,
  { {0x29000375, 0x6b9b109a, 0x6b820048, 0x00000000}},  //   _soia_, rsug, _dtog,
  { {0x6d59103f, 0xa2ca006e, 0x62952061, 0x00000000}},  //   _thwa, _सॉफ्, _mezo,
  { {0x61f80e2b, 0x6b9b302e, 0x62950032, 0x00000000}},  //   ävli, psug, _lezo,
  { {0x69d8302f, 0x6f010036, 0x2900001a, 0x00000000}},  //   _esve, _kolc, _voia_,
  { {0x26d10020, 0x629504bb, 0x00000000, 0x00000000}},  //   gezo_, _nezo,   ,
  { {0x64a6007e, 0xf8bf009d, 0x68ef0048, 0x00000000}},  //   лава, gnés_, áidí,
  { {0x31bc0010, 0xf4841125, 0x00000000, 0x00000000}},  //   víz_, شاری,   ,
  { {0x629502ae, 0xdce10089, 0x78a40023, 0x00000000}},  // [96e0] _bezo, _atlī, _idiv,
  { {0xb46300e3, 0xdb00053d, 0x31bc004a, 0x00000000}},  //   скул, stmö, tíz_,
  { {0x629501aa, 0xd24f0054, 0x9abc01d5, 0x00000000}},  //   _dezo, كنك_, fiċj,
  { {0x19b60049, 0xc09603d9, 0xe8d90082, 0x00000000}},  //   טפער_, اجات, _phỉ_,
  { {0x316d3030, 0x00000000, 0x00000000, 0x00000000}},  //   _diez_,   ,   ,
  { {0x62953031, 0x6f010b33, 0xa857009b, 0x00000000}},  //   _gezo, _colc, ניסה_,
  { {0x6f010207, 0x6b823032, 0xdb1b00f4, 0x00000000}},  //   _dolc, _stog, ctué,
  { {0xd132004b, 0x78a40020, 0x5d5400ed, 0x00000000}},  //   _امر_, _ndiv, јкит,
  { {0x1016008b, 0x6f010a47, 0x69d801ee, 0x00000000}},  //   _сьвя, _folc, _ssve,
  { {0x78a40b33, 0x6f010f89, 0x6e3a0009, 0x00000000}},  //   _adiv, _golc, _txtb,
  { {0x26d10087, 0x00000000, 0x00000000, 0x00000000}},  //   vezo_,   ,   ,
  { {0x644b006c, 0x3f840022, 0x26d100e7, 0x00000000}},  //   ügik, _ktmu_, wezo_,
  { {0xe8d9001d, 0x6f01014a, 0xdb000051, 0x00000000}},  //   _giờ_, _yolc, armá,
  { {0x8c1b009b, 0xdb1e00f8, 0x78a400fa, 0x00000000}},  //   _אודי, övän, _ediv,
  { {0x62952916, 0x26d1049a, 0x7d02042b, 0x00000000}},  //   _rezo, rezo_, _koos,
  { {0x99830054, 0x7d02224a, 0xf8bf0a39, 0x00000000}},  //   _اليو, _joos, rnés_,
  { {0x26d1008e, 0x6295008e, 0x29190051, 0x00000000}},  // [96f0] pezo_, _pezo, mhsa_,
  { {0x27e9005f, 0x7d02109b, 0x83050044, 0x00000000}},  //   _iran_, _loos, োচ্চ_,
  { {0xe8d90011, 0x629501ed, 0x00000000, 0x00000000}},  //   _nhị_, _vezo,   ,
  { {0x32643033, 0x6f01010f, 0x19b70049, 0x00000000}},  //   стув, _solc, רפאר_,
  { {0x6f010232, 0x4ac401f5, 0x80270379, 0x00000000}},  //   _polc, वभाव, درام,
  { {0x656f000b, 0xaec401fb, 0xa2c101f5, 0x00000000}},  //   _hich, йбіл, र्श्,
  { {0x41e402f0, 0xe8d9001d, 0x656f000b, 0x00000000}},  //   _літа, _chị_, _kich,
  { {0x63ad197d, 0x656f0020, 0x7a13006b, 0x00000000}},  //   oran, _jich, qətə,
  { {0x656f3034, 0x9ed90265, 0x7d02015b, 0x00000000}},  //   _mich, _имат_, _doos,
  { {0x656f15a6, 0x63ad3035, 0x644f00b4, 0x00000000}},  //   _lich, iran, _myci,
  { {0x63ad004f, 0x27e90129, 0x69de0161, 0x00000000}},  //   hran, _aran_, _šper,
  { {0x656f08ba, 0x7d020007, 0xd9460a27, 0x00000000}},  //   _nich, _goos, реми,
  { {0x7bc03036, 0x27e9009d, 0x63ad04eb, 0x00000000}},  //   ctmu, _cran_, jran,
  { {0x63ad016e, 0x65770065, 0x6b890207, 0x00000000}},  //   dran, _buxh, mpeg,
  { {0x27e90211, 0x656f0181, 0x6603003b, 0x00000000}},  //   _eran_, _bich, опра,
  { {0x63ad018e, 0x69c1001c, 0x7de00047, 0x00000000}},  //   fran, mtle, lásá,
  { {0x27e916ca, 0x656f08d3, 0x63ad1d7a, 0x00000000}},  // [9700] _gran_, _dich, gran,
  { {0x656f010f, 0x69c1046a, 0x00000000, 0x00000000}},  //   _eich, otle,   ,
  { {0x656f028c, 0x63ad0e40, 0x69c10322, 0x00000000}},  //   _fich, aran, ntle,
  { {0x2ba603d7, 0x3fe60098, 0x759b009b, 0x00000000}},  //   _खिला, ижев, _ביטח,
  { {0x7d02006c, 0x63ad0375, 0x69c1006c, 0x00000000}},  //   _roos, cran, htle,
  { {0x69c100eb, 0x656f00b5, 0x7d02006c, 0x00000000}},  //   ktle, _zich, _soos,
  { {0x7de00010, 0x80bd0044, 0x644f0036, 0x00000000}},  //   dásá, োয়্, _zyci,
  { {0x9cca008b, 0x61430140, 0x5bb80ae0, 0x00000000}},  //   тыка_, _деса, глия_,
  { {0x69c10046, 0x9abc002b, 0xa06702dc, 0x00000000}},  //   etle, liċi, _вата_,
  { {0xe8d9001d, 0x5b140057, 0x31783037, 0x00000000}},  //   _thị_, смот, _kurz_,
  { {0x13cf0055, 0x257c002a, 0xbca6007a, 0x00000000}},  //   রিয়, _níl_, _نماي,
  { {0x27e90607, 0x63ad014a, 0x98a20089, 0x00000000}},  //   _pran_, yran, tikā_,
  { {0x656f3038, 0xdc5400a1, 0x69c100b4, 0x00000000}},  //   _rich, _اراک, atle,
  { {0x656f001f, 0x63ad014a, 0x257c000c, 0x00000000}},  //   _sich, vran, _bíl_,
  { {0x656f000b, 0x69c100bb, 0x35e401e1, 0x00000000}},  //   _pich, ctle, оцтв,
  { {0x79690036, 0x27e90011, 0x257c00b9, 0x00000000}},  //   _oświ, _tran_, _díl_,
  { {0xd3710380, 0x656f0020, 0x27e90052, 0x00000000}},  // [9710] سها_, _vich, _uran_,
  { {0x656f001f, 0x63ad0238, 0x7c2d0213, 0x00000000}},  //   _wich, rran, _žark,
  { {0xc6920104, 0x644f0036, 0x63ad3039, 0x00000000}},  //   _מאי_, _wyci, sran,
  { {0x63ad0006, 0x7de00010, 0x7a0a006b, 0x00000000}},  //   pran, zásá, mətd,
  { {0x752d303a, 0x6b5d009d, 0x63ad013f, 0x00000000}},  //   miaz, lège, qran,
  { {0x752d0207, 0x2d95013b, 0x00000000, 0x00000000}},  //   liaz, брис,   ,
  { {0x692b0224, 0x518404b6, 0x7de00010, 0x00000000}},  //   vřen, _мута, vásá,
  { {0x752d0027, 0x657a0051, 0xdb09010e, 0x00000000}},  //   niaz, íthi, steü,
  { {0x3015013b, 0x7de00047, 0x2ca6018e, 0x00000000}},  //   _удар, tásá, _ddod_,
  { {0x69c10da6, 0xe9d90077, 0x6b891130, 0x00000000}},  //   ttle, гко_, rpeg,
  { {0x394602d3, 0x6b89002d, 0x6e45039d, 0x00000000}},  //   йног, speg, _انضم,
  { {0x752d0066, 0x69c1114e, 0x6b89010e, 0x00000000}},  //   jiaz, rtle, ppeg,
  { {0x7d1b303b, 0x752d060c, 0x291e0006, 0x00000000}},  //   mhus, diaz, ėta_,
  { {0xb87b1343, 0x7d1b0190, 0x00000000, 0x00000000}},  //   rdía, lhus,   ,
  { {0xba9a00b6, 0x1a650167, 0x7d1b00e7, 0x00000000}},  //   _עסקי, _دیدی_, ohus,
  { {0x7d1b113b, 0x752d303c, 0x2480012d, 0x00000000}},  //   nhus, giaz, ucim_,
  { {0xe2920025, 0xdb09004a, 0x248016b4, 0x00000000}},  // [9720] كذا_, lteñ, rcim_,
  { {0x57fb00b3, 0xd83f0802, 0x7a0a006b, 0x00000000}},  //   _עליו, áček_, bətd,
  { {0x8b56007b, 0x7d1b0039, 0xe612007a, 0x00000000}},  //   ציעס_, khus, _رشد_,
  { {0x752d303d, 0xd83f0059, 0x7ae60089, 0x00000000}},  //   ciaz, šček_, ēkti,
  { {0x7d1b0c7b, 0x00000000, 0x00000000, 0x00000000}},  //   dhus,   ,   ,
  { {0x6e93303e, 0xe457071c, 0x201a0036, 0x00000000}},  //   пишу, _ליכט_, ąpi_,
  { {0xacf8080d, 0x44202339, 0x629e2134, 0x00000000}},  //   инку_, lzi_, mapo,
  { {0x629e04e7, 0xa06a017f, 0x7d1b0503, 0x00000000}},  //   lapo, _баба_, ghus,
  { {0x4420303f, 0x796900b4, 0x00000000, 0x00000000}},  //   nzi_, _uświ,   ,
  { {0xbea301fb, 0x629e1483, 0x752d002d, 0x00000000}},  //   _наук, napo, ziaz,
  { {0x9cca04af, 0xaa581843, 0x7d1b0190, 0x00000000}},  //   _была_, рину_, bhus,
  { {0xe8d90011, 0x629e011c, 0xc7bb007e, 0x00000000}},  //   _thọ_, hapo, лёг_,
  { {0x629e0020, 0x44200010, 0x752d2100, 0x00000000}},  //   kapo, jzi_, viaz,
  { {0x44203040, 0x1ddc01f5, 0xdc3b0049, 0x00000000}},  //   dzi_, _मनात, _געדר,
  { {0x442001d1, 0x758828ba, 0x2499266c, 0x00000000}},  //   ezi_, йств_, _pesm_,
  { {0x7a0a006b, 0x2f0b00ea, 0x25ac0062, 0x00000000}},  //   rətd, _høgt_, ádla_,
  { {0x752d28dc, 0xc299041f, 0x7a0a006b, 0x00000000}},  // [9730] riaz, иках_, sətd,
  { {0x629e1fb8, 0x394b0115, 0x752d0032, 0x00000000}},  //   gapo, locs_, siaz,
  { {0xe5c7003b, 0x752d0035, 0xb87b0051, 0x00000000}},  //   _успо, piaz, ndío,
  { {0x90550e1b, 0xe1f00025, 0x1eea01b2, 0x00000000}},  //   овец, عسل_, یونی_,
  { {0x7d1b0748, 0x692b00b9, 0x44200010, 0x00000000}},  //   vhus, vřel, czi_,
  { {0xa195008b, 0x3f6901ee, 0x645d136e, 0x00000000}},  //   _магч, шило_, _izsi,
  { {0xe8d9001d, 0x7d1b00ab, 0x6d4900d9, 0x00000000}},  //   _nhỏ_, thus, toea,
  { {0x5ba9025f, 0x81681b15, 0xdb851b15, 0x00000000}},  //   аким_, _груб_, огии,
  { {0xfc3106ea, 0x7d1b3041, 0x98a20a62, 0x00000000}},  //   بحث_, rhus, niką_,
  { {0x7d1b0292, 0x212f3042, 0x00000000, 0x00000000}},  //   shus, ligh_,   ,
  { {0x44201a64, 0xb87b3043, 0x212f0048, 0x00000000}},  //   zzi_, rdín, oigh_,
  { {0xc689061e, 0x629e0a14, 0x212f0051, 0x00000000}},  //   _יא_, zapo, nigh_,
  { {0x629e015e, 0x81c10044, 0x69dc0030, 0x00000000}},  //   yapo, ্টি_, ærer,
  { {0x9f440181, 0x212f1706, 0x629e0066, 0x00000000}},  //   _irmã_, high_, xapo,
  { {0x366a012b, 0xe737007e, 0x4420000a, 0x00000000}},  //   раво_, цер_, wzi_,
  { {0x4420022b, 0x7ae33044, 0x81c10055, 0x00000000}},  //   tzi_, _hant, ্টা_,
  { {0x629e006a, 0x66e60ceb, 0x44200020, 0x00000000}},  // [9740] tapo, _допа, uzi_,
  { {0x7ae301a3, 0x68e40035, 0x29020825, 0x00000000}},  //   _jant, _haid, ljka_,
  { {0x26d808d3, 0x629e00b0, 0x44200047, 0x00000000}},  //   mero_, rapo, szi_,
  { {0x7ae30659, 0x25b8001c, 0x26d80211, 0x00000000}},  //   _lant, murl_, lero_,
  { {0x68e40122, 0x25b80050, 0x2fd6002c, 0x00000000}},  //   _maid, lurl_, تتاح,
  { {0x26d80219, 0x63a419bd, 0x7ae30475, 0x00000000}},  //   nero_, msin, _nant,
  { {0x63a4021e, 0x25b80ff3, 0x629c001e, 0x00000000}},  //   lsin, nurl_, _iero,
  { {0x7ae30250, 0x68e40089, 0xf1c30802, 0x00000000}},  //   _aant, _naid, žší_,
  { {0x7ae30149, 0xa2ca03d7, 0x629c0127, 0x00000000}},  //   _bant, स्थ्, _kero,
  { {0x629c00b5, 0x63a400b0, 0x26d80211, 0x00000000}},  //   _jero, isin, jero_,
  { {0x7ae3022b, 0x27e03045, 0x629c03b0, 0x00000000}},  //   _dant, _asin_, _mero,
  { {0xa2ca02f4, 0x7c65007a, 0x68e415a1, 0x00000000}},  //   स्त्, _کامل, _caid,
  { {0x26e40044, 0x26d80197, 0x2fc616e7, 0x00000000}},  //   খানো_, fero_, ntog_,
  { {0x7ae304cb, 0x629c0161, 0x26d80211, 0x00000000}},  //   _gant, _nero, gero_,
  { {0xd49b017a, 0x63a4109a, 0x68e41dec, 0x00000000}},  //   ира_, esin, _faid,
  { {0x68e4001e, 0x7ae301aa, 0x63a40972, 0x00000000}},  //   _gaid, _zant, fsin,
  { {0x63a4009f, 0x26d80207, 0x7ae304be, 0x00000000}},  // [9750] gsin, bero_, _yant,
  { {0x68e4000b, 0x7ae30129, 0x26d81068, 0x00000000}},  //   _zaid, _xant, cero_,
  { {0x629c0863, 0x212f002a, 0x63a400ab, 0x00000000}},  //   _dero, tigh_, asin,
  { {0x6f1a001a, 0x63a43046, 0x69cd007d, 0x00000000}},  //   _altc, bsin, _तहसी,
  { {0x212f0051, 0xdb090181, 0x645d0006, 0x00000000}},  //   righ_, queç, _uzsi,
  { {0x78bd001c, 0x629c0fec, 0x212f0051, 0x00000000}},  //   hgsv, _gero, sigh_,
  { {0x7ae33047, 0x628519b7, 0x6d441afb, 0x00000000}},  //   _rant, mcho, čian,
  { {0x628519dd, 0x26d82d7a, 0x290911d1, 0x00000000}},  //   lcho, zero_, _noaa_,
  { {0x26c10211, 0x629c00e0, 0x26d8004a, 0x00000000}},  //   _ocho_, _yero, yero_,
  { {0x62850071, 0x68f60030, 0x68e40515, 0x00000000}},  //   ncho, _snyd, _said,
  { {0x26d80207, 0x63a42970, 0x68e4006c, 0x00000000}},  //   vero_, zsin, _paid,
  { {0x26c10181, 0x7ae300ab, 0x63a43048, 0x00000000}},  //   _acho_, _want, ysin,
  { {0x7ae30817, 0x68e4143d, 0x25b80061, 0x00000000}},  //   _tant, _vaid, wurl_,
  { {0x25b80009, 0x25ac01ca, 0xbbe900a6, 0x00000000}},  //   turl_, ádlo_, _پرچم_,
  { {0x62850224, 0x26d80211, 0x68e400b0, 0x00000000}},  //   dcho, rero_, _taid,
  { {0xb4e60164, 0x629c2405, 0x26d80e1d, 0x00000000}},  //   पये_, _sero, sero_,
  { {0x26d80211, 0x629c04cb, 0xa5073049, 0x00000000}},  // [9760] pero_, _pero, чета_,
  { {0x63a4011f, 0x25b80061, 0x61ee304a, 0x00000000}},  //   rsin, purl_, _prbl,
  { {0x63a40f44, 0xc8b5025a, 0xf67b009b, 0x00000000}},  //   ssin, _علیک, _לאימ,
  { {0x63a4131c, 0x2fc60725, 0x629c304b, 0x00000000}},  //   psin, ttog_, _wero,
  { {0x6f080652, 0x6aa10239, 0x28c10309, 0x00000000}},  //   _podc, kalf, ष्टि,
  { {0xb87b0010, 0xfe70025a, 0xe8e00082, 0x00000000}},  //   gdíj, نگا_, _trỗi_,
  { {0x3981304c, 0x2fc60091, 0x2b8000f6, 0x00000000}},  //   _nós_, stog_, _sòc_,
  { {0xc0e300a8, 0x38600087, 0x00000000, 0x00000000}},  //   _поск, _ozir_,   ,
  { {0x6aa105f0, 0x6143005e, 0x00000000, 0x00000000}},  //   falf, _чета,   ,
  { {0xfbcf006d, 0xef170057, 0x501b009b, 0x00000000}},  //   اتي_, _ему_, _הומו,
  { {0xe8d90082, 0xa2c1007d, 0x98a2304d, 0x00000000}},  //   _nhể_, र्ट्, likę_,
  { {0x18a4025f, 0xdb1b0161, 0x2ee500bb, 0x00000000}},  //   наџм, rtuá, _zalf_,
  { {0x6aa10009, 0xdb1b00c4, 0x48e4007e, 0x00000000}},  //   balf, stuá, хоўв,
  { {0x3981002a, 0x6aa100d4, 0xf53f0292, 0x00000000}},  //   _fós_, calf, _sjå_,
  { {0x661400b9, 0xe3b30123, 0x00000000, 0x00000000}},  //   _čeká, کرز_,   ,
  { {0xe94500a6, 0x2a3b009b, 0x657e0208, 0x00000000}},  //   _ترتی, _לעומ, _duph,
  { {0x628501aa, 0x00000000, 0x00000000, 0x00000000}},  // [9770] tcho,   ,   ,
  { {0xc354003b, 0x6285009d, 0x212d00ca, 0x00000000}},  //   екуј, ucho, _smeh_,
  { {0x6285018e, 0xcb13007b, 0x69c80129, 0x00000000}},  //   rcho, עלע_, ntde,
  { {0x62850bca, 0xf8bf00f4, 0x69c801d6, 0x00000000}},  //   scho, ngé_, itde,
  { {0xf8bf009d, 0x00000000, 0x00000000, 0x00000000}},  //   liés_,   ,   ,
  { {0xf8bf0047, 0x6622014a, 0x77770066, 0x00000000}},  //   gnéz_, _öykü, _jixx,
  { {0x78ad016c, 0x77770066, 0x692b00b9, 0x00000000}},  //   _odav, _mixx, přeh,
  { {0x3981135c, 0x78ad304e, 0x636200fa, 0x00000000}},  //   _rós_, _ndav, rône,
  { {0x6aa1001c, 0x1c450088, 0xfc310025, 0x00000000}},  //   talf, ьним, ضحة_,
  { {0x39810181, 0xc9a9007c, 0x7777002b, 0x00000000}},  //   _pós_, овое_, _nixx,
  { {0xd94601be, 0x6aa10030, 0xa96a00ed, 0x00000000}},  //   дени, ralf, жина_,
  { {0xf8bf009d, 0x39810ddb, 0x777700f6, 0x00000000}},  //   diés_, _vós_, _aixx,
  { {0x200b00d4, 0x385a284e, 0x00000000, 0x00000000}},  //   _àcid_, تشدد_,   ,
  { {0xdb09002a, 0xf8bf00f4, 0xab640088, 0x00000000}},  //   breá, fiés_, _звіл,
  { {0xbb52035b, 0x69c80009, 0x7bc9009d, 0x00000000}},  //   _جنوب, ctde, lteu,
  { {0x2cbf0004, 0x29190065, 0x7d0b0010, 0x00000000}},  //   ngud_, ërat_, _jogs,
  { {0x7bc91e7d, 0x3a0500a1, 0x130a007e, 0x00000000}},  // [9780] nteu, _رکھی_, онай_,
  { {0xe8d900ad, 0xa3cf02d2, 0x446315c4, 0x00000000}},  //   _thể_, _शहर_, твув,
  { {0xa50a053c, 0xf8bf00f4, 0x425600ed, 0x00000000}},  //   _дена_, ciés_, фтат,
  { {0x7bc91058, 0x7d0b0007, 0x00000000, 0x00000000}},  //   kteu, _nogs,   ,
  { {0x10a301fb, 0xd12f007a, 0xdfd001fa, 0x00000000}},  //   тичн, جمن_, ايت_,
  { {0x6d442198, 0x64460288, 0x00000000, 0x00000000}},  //   čiam, _ixki,   ,
  { {0x7d0b0030, 0x69c81b9d, 0x2d8c00c4, 0x00000000}},  //   _bogs, xtde, _qtde_,
  { {0xfbaa01ab, 0x00000000, 0x00000000, 0x00000000}},  //   отой_,   ,   ,
  { {0xaec6003b, 0x636200c4, 0x00000000, 0x00000000}},  //   _обал, cônc,   ,
  { {0x98a00036, 0x1f6300d7, 0x69c82a1e, 0x00000000}},  //   _imię_, _акум, ttde,
  { {0x69351001, 0x02b7009b, 0x7bc9009d, 0x00000000}},  //   енну, והים_, ateu,
  { {0x27f20016, 0x00000000, 0x00000000, 0x00000000}},  //   _bryn_,   ,   ,
  { {0x7bc9304f, 0x69c80d33, 0xf8bf00f4, 0x00000000}},  //   cteu, stde, rgé_,
  { {0xf8bf009d, 0x92c20044, 0x00000000, 0x00000000}},  //   tiés_, ্যু_,   ,
  { {0xcad7009b, 0x94d5025f, 0x8c3d006b, 0x00000000}},  //   _חוות_, новц, maşa,
  { {0xf8bf00f4, 0x63b60016, 0x8c3d005d, 0x00000000}},  //   riés_, fryn, laşa,
  { {0x29191a2f, 0x2458007c, 0x27f23050, 0x00000000}},  // [9790] ūras_, дать_, _gryn_,
  { {0xd25b0816, 0xf8bf0249, 0x00000000, 0x00000000}},  //   оце_, piés_,   ,
  { {0x5184008b, 0x8575007c, 0x333301f3, 0x00000000}},  //   вуча, _плох, rixx_,
  { {0x3395007e, 0x63b603d0, 0x22580146, 0x00000000}},  //   _памё, bryn, _dyrk_,
  { {0x24b6061e, 0xf8bf00f4, 0x656d3051, 0x00000000}},  //   _אהרן_, chée_, mmah,
  { {0x2f18007c, 0x62830521, 0x2489149f, 0x00000000}},  //   мочь_, žnob, lcam_,
  { {0x6d4200ea, 0x4ea40545, 0x00000000, 0x00000000}},  //   _bjoa, трча,   ,
  { {0x7bc900f4, 0xef190036, 0xeb990bba, 0x00000000}},  //   tteu, _duża_, пии_,
  { {0x656d002d, 0x7bc9009d, 0x2cbf010e, 0x00000000}},  //   imah, uteu, rgud_,
  { {0x7bc900f4, 0x656d0145, 0x2d5300fa, 0x00000000}},  //   rteu, hmah, tães_,
  { {0xf2d2007b, 0x7bc9010f, 0x13d80044, 0x00000000}},  //   נעט_, steu, সিয়,
  { {0x7bc900f4, 0x2d530181, 0x7a0a006b, 0x00000000}},  //   pteu, rães_, mətl,
  { {0x395e0089, 0x248901c3, 0x7a0a006b, 0x00000000}},  //   ēts_, dcam_, lətl,
  { {0x6d5b008d, 0xdb0900d4, 0x00000000, 0x00000000}},  //   llua, dreç,   ,
  { {0xceb2012e, 0x7a0a006b, 0x24f60245, 0x00000000}},  //   טים_, nətl, нчар,
  { {0x656d011c, 0x63b60fed, 0x2edc006e, 0x00000000}},  //   gmah, tryn, _यस्त,
  { {0x6d5b02f6, 0xc2b6003b, 0x7a0a006b, 0x00000000}},  // [97a0] ilua, ељењ, hətl,
  { {0x7a0a006b, 0x63b62601, 0x20ec0082, 0x00000000}},  //   kətl, rryn, _ới_,
  { {0xaac20164, 0x64a60c4e, 0xe0da0a78, 0x00000000}},  //   _शासक, _пана, зве_,
  { {0x92c20055, 0x4fc60242, 0x98ab001a, 0x00000000}},  //   ্যে_, еска, mică_,
  { {0x98ab001a, 0x9f4d00f6, 0xdb0900c4, 0x00000000}},  //   lică_, _creï_, creç,
  { {0xde5805b8, 0xda0f0061, 0x00000000, 0x00000000}},  //   малі_, ाहात_,   ,
  { {0xe357012f, 0x434308d6, 0x78a60119, 0x00000000}},  //   _נשלח_, _серв, kakv,
  { {0xafe6041f, 0x2011006b, 0xdb0900b0, 0x00000000}},  //   _побл, _əziz_, hreä,
  { {0xcf460099, 0xefb3025a, 0x8c3d3052, 0x00000000}},  //   _знай, _مینگ, taşa,
  { {0x7a0a005f, 0xef1901d5, 0xb87b00c4, 0x00000000}},  //   bətl, _tuża_, ndív,
  { {0x673516fb, 0xe89507d0, 0x00000000, 0x00000000}},  //   vizj, кань,   ,
  { {0x60c20006, 0x67350036, 0x98ab001a, 0x00000000}},  //   ngom, wizj, dică_,
  { {0xac970025, 0x29193053, 0xd7fb003b, 0x00000000}},  //   _أنها_, rksa_, чун_,
  { {0x98ab001a, 0xd7630167, 0x7a0a013f, 0x00000000}},  //   fică_, انسی, lətm,
  { {0xaa573054, 0x6d4001d6, 0x67352530, 0x00000000}},  //   _пишу_, onma, rizj,
  { {0x7aea23c7, 0x92bd0055, 0x6d403055, 0x00000000}},  //   _haft, _আসে_, nnma,
  { {0x54370054, 0x6d40021f, 0x24890adb, 0x00000000}},  // [97b0] رررر, inma, rcam_,
  { {0x7a0a006b, 0xdbc7006c, 0xdb090181, 0x00000000}},  //   yətl, _tööp, rreç,
  { {0x6b820207, 0xb87b004a, 0x9758009b, 0x00000000}},  //   _luog, seíd, _איזו_,
  { {0x7524006b, 0x00000000, 0x00000000, 0x00000000}},  //   chiz,   ,   ,
  { {0x5eaa0044, 0x3d040309, 0x6b820006, 0x00000000}},  //   চ্ছে, वाने_, _nuog,
  { {0x4429000b, 0x141a009b, 0x6d40005b, 0x00000000}},  //   mza_, _חושב, enma,
  { {0x442917f4, 0x1ea80025, 0xe5700014, 0x00000000}},  //   lza_, راوي_, _خطی_,
  { {0x7a0a006b, 0x6d400190, 0x5ff50745, 0x00000000}},  //   rətl, gnma, _избу,
  { {0x44290026, 0x6d5b04cb, 0x7aea001a, 0x00000000}},  //   nza_, rlua, _baft,
  { {0x44290032, 0x7aea0093, 0x6d5b135c, 0x00000000}},  //   iza_, _caft, slua,
  { {0x3ea702a4, 0x7aea020c, 0x27260011, 0x00000000}},  //   mant_, _daft, _hông_,
  { {0x3ea700f4, 0x61f50059, 0x27260011, 0x00000000}},  //   lant_, _mrzl, _kông_,
  { {0x7d090209, 0x44290065, 0x3ced0022, 0x00000000}},  //   mjes, jza_, mdev_,
  { {0x3ea7028c, 0x7d090047, 0x442905e1, 0x00000000}},  //   nant_, ljes, dza_,
  { {0x64a6008b, 0x44290211, 0x27260011, 0x00000000}},  //   кава, eza_, _lông_,
  { {0x7d090de8, 0xd047006b, 0x7d1b0006, 0x00000000}},  //   njes, şlən, nkus,
  { {0x7c290fd6, 0x2726001d, 0x7d1b3056, 0x00000000}},  // [97c0] nzer, _nông_, ikus,
  { {0x3ea73057, 0x7524000f, 0x7d1b0934, 0x00000000}},  //   jant_, shiz, hkus,
  { {0x4429000d, 0x7d1b3058, 0x0219007e, 0x00000000}},  //   aza_, kkus, ніць_,
  { {0x6ec4007d, 0x27260011, 0x44290096, 0x00000000}},  //   _राहु, _bông_, bza_,
  { {0x272600ad, 0x44290046, 0x6283016e, 0x00000000}},  //   _công_, cza_, žnoa,
  { {0x3ea70129, 0xef190036, 0x78a4003c, 0x00000000}},  //   gant_, _dużo_, _leiv,
  { {0x2000000d, 0xf98703ec, 0x52d70049, 0x00000000}},  //   ţii_, _خب_, _שולע_,
  { {0x7aea00eb, 0x7d090065, 0x78a40a0e, 0x00000000}},  //   _saft, gjes, _neiv,
  { {0x6aa33059, 0x3ea72df6, 0x98ab0036, 0x00000000}},  //   _benf, bant_, nicą_,
  { {0x3ea71ce2, 0x2d6e0224, 0xf8eb013d, 0x00000000}},  //   cant_, _přes_, _जोड़ा_,
  { {0xc333019b, 0x44292fb6, 0xdb00000c, 0x00000000}},  //   שות_, zza_, gsmá,
  { {0x7d1b00f6, 0x44290890, 0x3f84010e, 0x00000000}},  //   ckus, yza_, _kumu_,
  { {0xead40783, 0x7c290036, 0x78a4008f, 0x00000000}},  //   _боль, czer, _deiv,
  { {0x7bc000e0, 0x6aa32370, 0x3f8417b0, 0x00000000}},  //   mumu, _genf, _mumu_,
  { {0x4b7b071c, 0x44290066, 0xd4c70595, 0x00000000}},  //   _קאוו, wza_, ксап,
  { {0x4429305a, 0x3ea70035, 0x628e305b, 0x00000000}},  //   tza_, zant_, _afbo,
  { {0x3ea700f4, 0x0934023c, 0x7bc0014a, 0x00000000}},  // [97d0] yant_, _خروج, numu,
  { {0x44290046, 0x8c3d01f6, 0x3ea70129, 0x00000000}},  //   rza_, daşl, xant_,
  { {0x3ea7053e, 0x4429268a, 0x8af7005f, 0x00000000}},  //   vant_, sza_, _şəki,
  { {0x7bc0001e, 0x3ea7005b, 0x290b10ec, 0x00000000}},  //   kumu, want_, njca_,
  { {0x7bc0305c, 0x3ea7028c, 0x68ed305d, 0x00000000}},  //   jumu, tant_, _maad,
  { {0x1dd40183, 0x68ed305e, 0x39ae0006, 0x00000000}},  //   _दहशत, _laad, kęs_,
  { {0x657d23d3, 0x3ea703d5, 0xed590373, 0x00000000}},  //   _kish, rant_, нок_,
  { {0x3ea7028c, 0x657d305f, 0x27260011, 0x00000000}},  //   sant_, _jish, _tông_,
  { {0x63ad006a, 0x3ea70fdb, 0x7d093060, 0x00000000}},  //   nsan, pant_, rjes,
  { {0x7d1b2245, 0x645d0039, 0x63ad029c, 0x00000000}},  //   skus, _mysi, isan,
  { {0x68ed0be3, 0x7c290047, 0x645d0ace, 0x00000000}},  //   _baad, szer, _lysi,
  { {0x63ad2375, 0x3ea505fe, 0x8c3d0279, 0x00000000}},  //   ksan, _helt_, laşm,
  { {0xb8ec0201, 0x6aa30066, 0x2d85123c, 0x00000000}},  //   _ला_, _tenf, _hule_,
  { {0x8c1a0097, 0x70e0013d, 0x657d2395, 0x00000000}},  //   _רוסי, _नस्ल, _aish,
  { {0x27e9022b, 0x7ae10b90, 0x657d03a1, 0x00000000}},  //   _esan_, melt, _bish,
  { {0xaacf0164, 0x63ad002b, 0xf495007c, 0x00000000}},  //   त्रक, fsan, ирую,
  { {0x63ad000c, 0x69c11143, 0x636b3061, 0x00000000}},  // [97e0] gsan, lule, künd,
  { {0xb87b0010, 0x7ae10836, 0x68ed10ae, 0x00000000}},  //   rdít, nelt, _zaad,
  { {0x2b89001d, 0x69c11250, 0xe8d9001d, 0x00000000}},  //   _lúc_, nule, _nhớ_,
  { {0x645d0030, 0x657d3062, 0x0cbe0044, 0x00000000}},  //   _fysi, _gish, _আস্ত,
  { {0x63ad094e, 0x7ae102cc, 0x69c1010f, 0x00000000}},  //   csan, kelt, hule,
  { {0x657d0dfc, 0x3ea50af4, 0x2d85008a, 0x00000000}},  //   _zish, _celt_, _bule_,
  { {0x6da3025f, 0x7ae10bf4, 0x657d0009, 0x00000000}},  //   бија, delt, _yish,
  { {0x69c1006c, 0x7bc00089, 0x39ae010a, 0x00000000}},  //   dule, tumu, vęs_,
  { {0x7a0a005f, 0x68ed0b20, 0x7ae10056, 0x00000000}},  //   məti, _raad, felt,
  { {0x68ed0cfc, 0x7bc0011f, 0x6d593063, 0x00000000}},  //   _saad, rumu, _ekwa,
  { {0x69c1009f, 0x2d85004e, 0x28c60316, 0x00000000}},  //   gule, _gule_, _वाशि,
  { {0x7bc00883, 0x63ad0e59, 0x39ae0006, 0x00000000}},  //   pumu, ysan, ręs_,
  { {0x9cd700b6, 0x29000046, 0x68ed01c2, 0x00000000}},  //   _תודה_, _dnia_, _vaad,
  { {0x2d850020, 0x7ae13064, 0x6d440006, 0x00000000}},  //   _yule_, celt, čiau,
  { {0x69c11911, 0xfa55026c, 0xaab70318, 0x00000000}},  //   cule, _پروگ, _صدور_,
  { {0x63ad010f, 0x636b2ab7, 0x291204de, 0x00000000}},  //   tsan, zünd, _goya_,
  { {0x657d003b, 0x2b89001d, 0x27e93065, 0x00000000}},  // [97f0] _vish, _xúc_, _usan_,
  { {0x63ad001f, 0x6b5d0129, 0x60c90197, 0x00000000}},  //   rsan, tègi, _scem,
  { {0x63ad0e8d, 0x645d0a77, 0x7a0a006b, 0x00000000}},  //   ssan, _wysi, fəti,
  { {0x41740025, 0x63ad00b9, 0x645d0036, 0x00000000}},  //   مانس, psan, _tysi,
  { {0x2d850515, 0x636b005d, 0x69c10f4f, 0x00000000}},  //   _sule_, tünd, zule,
  { {0x9f4d0051, 0xdb0000f8, 0x2d853066, 0x00000000}},  //   _breá_, nsmä, _pule_,
  { {0x7a0a006b, 0xdd8e0025, 0x636b3067, 0x00000000}},  //   bəti, ووو_, ründ,
  { {0x3ea5001f, 0x7ae1010f, 0x636b078f, 0x00000000}},  //   _welt_, welt, sünd,
  { {0x7ae1021e, 0xdcfa001e, 0x3ea50f5d, 0x00000000}},  //   telt, _attē, _telt_,
  { {0x69c10004, 0x2d8503b6, 0x29120145, 0x00000000}},  //   tule, _tule_, _soya_,
  { {0x8e840054, 0x38693068, 0x3946004c, 0x00000000}},  //   _المه, _azar_, иног,
  { {0x69c1009f, 0x7ae100b0, 0x1bd50d99, 0x00000000}},  //   rule, selt, _водя,
  { {0x69c11a50, 0x6d440027, 0x98ab0036, 0x00000000}},  //   sule, čiat, nicę_,
  { {0xf7722712, 0x69c10e48, 0xf8630088, 0x00000000}},  //   تاج_, pule, івро,
  { {0xe8d9001d, 0x7a0a006b, 0x2912013f, 0x00000000}},  //   _giữ_, yəti, _toya_,
  { {0x778600d1, 0xe8d90082, 0xb87b004a, 0x00000000}},  //   _клиз, _khờ_, seía,

  { {0xe2ca02be, 0xdb090325, 0xd3873069, 0x00000000}},  // [9800] клад_, queó, ийте_,
  { {0x13030088, 0xdce20082, 0x00000000, 0x00000000}},  //   озум, _khoă,   ,
  { {0x673c0087, 0x00000000, 0x00000000, 0x00000000}},  //   mirj,   ,   ,
  { {0x316d028c, 0xdb0003b1, 0x00000000, 0x00000000}},  //   _chez_, msmå,   ,
  { {0xe8d90011, 0x7a0a006b, 0xdb000ccc, 0x00000000}},  //   _nhờ_, rəti, lsmå,
  { {0x6b84002a, 0x2f5600ed, 0x7a0a006b, 0x00000000}},  //   _éigi, штес, səti,
  { {0x3207021e, 0x98a00087, 0xdb0005fe, 0x00000000}},  //   änyt_, _alič_, nsmå,
  { {0x216a0364, 0x71590216, 0x636b2ba5, 0x00000000}},  //   _риби_, _брус_, rüne,
  { {0x673c08b2, 0xe8d9001d, 0xeb06012c, 0x00000000}},  //   kirj, _chờ_, ачно,
  { {0x661c15b3, 0x7dfc0035, 0xdb00306a, 0x00000000}},  //   kyrk, _păsă, ksmå,
  { {0xdb09008e, 0xd5b10082, 0x5a46007e, 0x00000000}},  //   gueñ, ới_, рэпа,
  { {0xdb0005fe, 0x6d440c6e, 0x00000000, 0x00000000}},  //   dsmå, čias,   ,
  { {0x7d02003b, 0xab940025, 0xdce80006, 0x00000000}},  //   _inos, _التغ, _sudė,
  { {0x7bdb01ce, 0xa2c2006e, 0x3d040061, 0x00000000}},  //   _סקוו, _लाग्, वावे_,
  { {0xdb000737, 0xe45f00b0, 0x20bb0061, 0x00000000}},  //   gsmå, _syö_, ॉलमध,
  { {0x8a7b00b6, 0xd4980e82, 0x38690288, 0x00000000}},  //   _באות, иру_, _tzar_,
  { {0x39590066, 0x00000000, 0x00000000, 0x00000000}},  // [9810] moss_,   ,   ,
  { {0x395901a2, 0x3dde00f6, 0x7d020087, 0x00000000}},  //   loss_, _optw_, _lnos,
  { {0x8c1a0044, 0x9405006b, 0x00000000, 0x00000000}},  //   _তেমন_, _ələ_,   ,
  { {0xe45f00b0, 0xed460014, 0x00000000, 0x00000000}},  //   _työ_, _رپ_,   ,
  { {0x8fe7064b, 0x2f190088, 0x00000000, 0x00000000}},  //   рцед, лодь_,   ,
  { {0xc695007b, 0x7d0200e5, 0x395901a2, 0x00000000}},  //   זאַ_, _anos, hoss_,
  { {0x8c3d0a4b, 0x00000000, 0x00000000, 0x00000000}},  //   maşi,   ,   ,
  { {0x673c00ca, 0xdcf90014, 0x00000000, 0x00000000}},  //   zirj, افظت_,   ,
  { {0x7d020ff1, 0x60db2552, 0x3959004a, 0x00000000}},  //   _dnos, _ibum, doss_,
  { {0x7d0201d9, 0xb87b306b, 0x37bf0044, 0x00000000}},  //   _enos, teín, েবার,
  { {0x5d850054, 0x656f000a, 0x673c0059, 0x00000000}},  //   _الصل, _ohch, virj,
  { {0xe8d90011, 0x395901c5, 0x7d0201ed, 0x00000000}},  //   _thờ_, goss_, _gnos,
  { {0x3d040164, 0xed590059, 0xdb09008e, 0x00000000}},  //   वारे_, mož_, sueñ,
  { {0x6370306c, 0x6b9b0026, 0x6b96009b, 0x00000000}},  //   mäng, mpug, _הכסף_,
  { {0xdb090219, 0x63700002, 0xd6270175, 0x00000000}},  //   queñ, läng, боре_,
  { {0x63620181, 0x8a16009b, 0xdb001ab8, 0x00000000}},  //   môni, _לחצו_, rsmå,
  { {0xd6c304e1, 0x673c0059, 0x636200c4, 0x00000000}},  // [9820] _کمپی, pirj, lôni,
  { {0xadf9007d, 0xed5900b9, 0x60db0093, 0x00000000}},  //   ्मान_, hož_, _abum,
  { {0x63700788, 0x644f00ab, 0xed59306d, 0x00000000}},  //   häng, _exci, kož_,
  { {0x104a1ac0, 0xf992009b, 0xa2d8007d, 0x00000000}},  //   ляли_, פרד_, _नॉर्,
  { {0x33b527f9, 0x00000000, 0x00000000, 0x00000000}},  //   _мёрт,   ,   ,
  { {0x26ca002b, 0x26d8018e, 0xd13200a6, 0x00000000}},  //   ngbo_, nfro_, _کمر_,
  { {0x877b0049, 0xe8d90011, 0x6da301fc, 0x00000000}},  //   נאצי, _nhở_, пија,
  { {0x5bb80ae0, 0x27e0306e, 0x63700788, 0x00000000}},  //   алия_, _opin_, fäng,
  { {0x63700002, 0x8fa3025f, 0x7d020059, 0x00000000}},  //   gäng, _нате, _vnos,
  { {0x63620181, 0x7b3901ca, 0xff240014, 0x00000000}},  //   fôni, lňuj, _ببری,
  { {0xfbcf0167, 0xe8d90011, 0x3959245c, 0x00000000}},  //   وتی_, _chở_, toss_,
  { {0x63700002, 0xd01c0055, 0x6c860054, 0x00000000}},  //   länd, _দেয়_, _الإم,
  { {0x395900ab, 0x7d1d010f, 0x26d82f59, 0x00000000}},  //   ross_, össe, ffro_,
  { {0x81df0044, 0x39591aa3, 0x569402dc, 0x00000000}},  //   তিত_, soss_, зарт,
  { {0xa3cb0164, 0x27e0110f, 0x68e601c3, 0x00000000}},  //   रून_, _epin_, bekd,
  { {0x3eae001f, 0x63700002, 0x6aaa1ef7, 0x00000000}},  //   haft_, händ, _heff,
  { {0x6aaa1864, 0x06e40044, 0x82870025, 0x00000000}},  // [9830] _keff, মাজি, مجال,
  { {0x8c1b009b, 0x7a0a006b, 0x6aaa00ab, 0x00000000}},  //   אומי, bətt, _jeff,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6aaa00b0, 0x7a0a013f, 0xe8d90082, 0x00000000}},  //   _leff, ləts, _khố_,
  { {0x63620181, 0xf8bf009d, 0x6b9b06c2, 0x00000000}},  //   zôni, ckée_, xpug,
  { {0xa2d802d2, 0x2d950264, 0x00000000, 0x00000000}},  //   न्द्, орис,   ,
  { {0x171c007b, 0x8d750025, 0x7bc0306f, 0x00000000}},  //   רווע, يابا, ermu,
  { {0x60db0061, 0xa63c009b, 0x7bc0012d, 0x00000000}},  //   _ubum, טגור, frmu,
  { {0x798a010f, 0x6aaa069d, 0xed5900ca, 0x00000000}},  //   _aufw, _beff, rož_,
  { {0xe9d9012b, 0x63700a5d, 0x63620181, 0x00000000}},  //   ако_, räng, tôni,
  { {0x6aaa005b, 0x752d0032, 0x6b9b0197, 0x00000000}},  //   _deff, khaz, spug,
  { {0xf1b2012f, 0x636200c4, 0x63700210, 0x00000000}},  //   וסט_, rôni, mäne,
  { {0x6d493070, 0xbf87001d, 0xeaae0121, 0x00000000}},  //   mnea, _điển_, _ой_,
  { {0xd5b8001e, 0xe8d90011, 0x6aaa005b, 0x00000000}},  //   šām_, _thở_, _geff,
  { {0x6b8b141a, 0x6b83011c, 0x6d49001a, 0x00000000}},  //   _hugg, _iing, onea,
  { {0x6d49002a, 0x6b830149, 0x39b5001e, 0x00000000}},  //   nnea, _hing, mās_,
  { {0x6d49002a, 0x39b5001e, 0x65640169, 0x00000000}},  // [9840] inea, lās_, rlih,
  { {0x6b8301d5, 0x6d490fff, 0xf772004b, 0x00000000}},  //   _jing, hnea, _تاب_,
  { {0x63700073, 0x39b5001e, 0xe2970147, 0x00000000}},  //   vänd, nās_, цах_,
  { {0x6b8323a5, 0x752d0211, 0x69c10051, 0x00000000}},  //   _ling, chaz, irle,
  { {0x63700a35, 0x69c1010f, 0x6b830032, 0x00000000}},  //   tänd, hrle, _oing,
  { {0x6b830219, 0x39b5001e, 0x44320061, 0x00000000}},  //   _ning, kās_, mzy_,
  { {0x637023df, 0x39b5001e, 0x44200047, 0x00000000}},  //   ränd, jās_, lyi_,
  { {0x39b5001e, 0x637003a2, 0x6d490056, 0x00000000}},  //   dās_, sänd, gnea,
  { {0x44201670, 0x4ae6008b, 0x0ed20061, 0x00000000}},  //   nyi_, оўна, _सापड,
  { {0x6b830494, 0x37d00044, 0xda7a01e0, 0x00000000}},  //   _cing, িবার, иян_,
  { {0x39b5001e, 0x6b5d009d, 0x6b8329e7, 0x00000000}},  //   gās_, tègr, _ding,
  { {0x394d02d5, 0x6b83001f, 0xe8d9001d, 0x00000000}},  //   ões_, _eing, _phố_,
  { {0x6d4000b0, 0x44200061, 0x6b8b13e4, 0x00000000}},  //   mima, jyi_, _gugg,
  { {0x44320036, 0x39b50089, 0x44200173, 0x00000000}},  //   dzy_, bās_, dyi_,
  { {0x2d8c0173, 0x39b50089, 0xdce20036, 0x00000000}},  //   _jude_, cās_, _choć,
  { {0x6d40010a, 0x6b830020, 0x57b50401, 0x00000000}},  //   nima, _zing, _ебит,
  { {0x69c8006c, 0x44200010, 0x2bc20061, 0x00000000}},  // [9850] lude, gyi_, _शिफा,
  { {0x7415026c, 0x2d8c00b5, 0x6d4009bd, 0x00000000}},  //   _ہوجا, _oude_, hima,
  { {0x2d8c001c, 0x6d40010a, 0x7c20018e, 0x00000000}},  //   _nude_, kima, hymr,
  { {0x6d40010a, 0xdb09002a, 0x7c202141, 0x00000000}},  //   jima, iseá, kymr,
  { {0x6d403071, 0x44320046, 0x2d8c0b50, 0x00000000}},  //   dima, czy_, _aude_,
  { {0x2d8c0428, 0x78ad0038, 0xf3ff00c4, 0x00000000}},  //   _bude_, _leav, _irã_,
  { {0x6d490051, 0x69c80203, 0x2d8c016c, 0x00000000}},  //   tnea, jude, _cude_,
  { {0x6d400006, 0x39b5001e, 0xdb1b0129, 0x00000000}},  //   gima, vās_, truï,
  { {0x6d4926c4, 0x3eac0030, 0x6d5b0923, 0x00000000}},  //   rnea, _fedt_, roua,
  { {0x39b5001e, 0x6b83002b, 0x7524002d, 0x00000000}},  //   tās_, _qing, zkiz,
  { {0x6b8306d0, 0x78ad0010, 0x6d40006c, 0x00000000}},  //   _ving, _beav, bima,
  { {0x39b50089, 0x6b8b00f8, 0x6b8305a8, 0x00000000}},  //   rās_, _tugg, _wing,
  { {0x6b83033b, 0x39b50089, 0x3f8d00d4, 0x00000000}},  //   _ting, sās_, _jueu_,
  { {0x6b83000b, 0x7d193072, 0xed3500a1, 0x00000000}},  //   _uing, _hows, _بوچھ,
  { {0xe73719a2, 0x69c80efe, 0x64a607e1, 0x00000000}},  //   чер_, cude, заба,
  { {0x443200f8, 0x78ad00b5, 0x3f85002b, 0x00000000}},  //   tzy_, _geav, _lilu_,
  { {0x39420013, 0x7524002d, 0x1aee0044, 0x00000000}},  // [9860] miks_, rkiz, জারে_,
  { {0x44320941, 0x68f61aa0, 0x7524002d, 0x00000000}},  //   rzy_, _hayd, skiz,
  { {0x44260ba5, 0x44320046, 0x68f6011f, 0x00000000}},  //   šo_, szy_, _kayd,
  { {0x394214f7, 0x7d190036, 0x68f600e7, 0x00000000}},  //   niks_, _nows, _jayd,
  { {0x6d40010a, 0x68f60276, 0xf3ff00c4, 0x00000000}},  //   vima, _mayd, _grã_,
  { {0x2d8c3073, 0x6d403074, 0x3942224c, 0x00000000}},  //   _pude_, wima, hiks_,
  { {0x10a601f9, 0x91e3012b, 0x63b60637, 0x00000000}},  //   _нивн, _поре, lsyn,
  { {0xdb980373, 0x69c801c9, 0x2cea0088, 0x00000000}},  //   ович_, vude, сько_,
  { {0x5f76026c, 0x7bc9146b, 0x63b60190, 0x00000000}},  //   _فائر, gueu, nsyn,
  { {0x69c8027b, 0x81df0055, 0x6d40000b, 0x00000000}},  //   tude, তির_, sima,
  { {0x6d401e4a, 0x78ad006c, 0x7ae80e58, 0x00000000}},  //   pima, _peav, redt,
  { {0x3942006c, 0x63b6268e, 0xdb1b000c, 0x00000000}},  //   giks_, ksyn, stuð,
  { {0x69c80030, 0x68f61811, 0x6f1a013e, 0x00000000}},  //   sude, _dayd, _kotc,
  { {0x63b63075, 0x69c8010e, 0x636b0276, 0x00000000}},  //   dsyn, pude, günl,
  { {0x68f6005a, 0x78ad006c, 0xa4d50451, 0x00000000}},  //   _fayd, _teav, мові,
  { {0x5ec50044, 0x00000000, 0x00000000, 0x00000000}},  //   ল্পে,   ,   ,
  { {0xdcfa001e, 0xb86700a1, 0xe454007e, 0x00000000}},  // [9870] _attī, _ڈاکو, екты,
  { {0x6f1a0133, 0x2b5e0082, 0x00000000, 0x00000000}},  //   _notc, notc_,   ,
  { {0x26d30009, 0x68f60477, 0xa3b90309, 0x00000000}},  //   _icxo_, _yayd, _घटक_,
  { {0x3f850142, 0x6f08041d, 0x81df0044, 0x00000000}},  //   _silu_, _andc, তিল_,
  { {0x7d19001c, 0xe0d001fa, 0x6f1a121e, 0x00000000}},  //   _rows, ازم_, _botc,
  { {0x05b10061, 0xdb1b1c9e, 0xdce101d5, 0x00000000}},  //   _जबाब, truí, _kulħ,
  { {0x7d190046, 0x6f1a1995, 0x272f014a, 0x00000000}},  //   _pows, _dotc, _güne_,
  { {0xa3e1001c, 0xe8d90011, 0x3b9500ed, 0x00000000}},  //   _दहा_, _khổ_, мјот,
  { {0x68f600d2, 0x39420dac, 0x6f1a0667, 0x00000000}},  //   _rayd, viks_, _fotc,
  { {0x81c20055, 0x29093076, 0x68f60279, 0x00000000}},  //   ্বর_, _anaa_, _sayd,
  { {0x13e60055, 0x39423077, 0x00000000, 0x00000000}},  //   নিয়, tiks_,   ,
  { {0x68f6005f, 0xdb090553, 0x186a0088, 0x00000000}},  //   _qayd, rreñ, жами_,
  { {0x3942006c, 0x636b0279, 0x7bc900f4, 0x00000000}},  //   riks_, tünl, queu,
  { {0x29090059, 0x39423078, 0x59c5006e, 0x00000000}},  //   _enaa_, siks_, _विपर,
  { {0x212d0149, 0xd62a005e, 0x63702c31, 0x00000000}},  //   _oleh_, цове_, jäna,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd467017f, 0xc95300b3, 0x06e30044, 0x00000000}},  // [9880] дите_, _שמח_, ময়ি,
  { {0x63b605b7, 0xd7760d3a, 0x212d0145, 0x00000000}},  //   rsyn, _تابع, _aleh_,
  { {0x63b6000c, 0x212d01a3, 0x09db0044, 0x00000000}},  //   ssyn, _bleh_, ধিকা,
  { {0x53a90061, 0x98b90035, 0x2caf0009, 0x00000000}},  //   _चौकश, misă_, _negd_,
  { {0x6f1a3079, 0x00000000, 0x00000000, 0x00000000}},  //   _potc,   ,   ,
  { {0x800b00a1, 0xdd9a00ed, 0x2d860016, 0x00000000}},  //   ترمہ_, оши_, _sioe_,
  { {0x39400035, 0x00000000, 0x00000000, 0x00000000}},  //   _omis_,   ,   ,
  { {0xe73f00c4, 0x00000000, 0x00000000, 0x00000000}},  //   mpõe_,   ,   ,
  { {0x81df0044, 0x98b90035, 0x69c00316, 0x00000000}},  //   তিঃ_, hisă_, _विही,
  { {0x3940028c, 0x7f430197, 0xb87b004a, 0x00000000}},  //   _amis_, cinq, nfíe,
  { {0x2fc6128e, 0x28f90245, 0x8e4a0025, 0x00000000}},  //   lrog_, пень_, _بلاك_,
  { {0x9c2600e2, 0x2548005a, 0x00000000, 0x00000000}},  //   _одед, oğlu_,   ,
  { {0x1bf2007d, 0x290900d9, 0x00000000, 0x00000000}},  //   _अनिल_, _vnaa_,   ,
  { {0xf53f044f, 0x39930181, 0x3940175f, 0x00000000}},  //   _små_, _fãs_, _emis_,
  { {0x6d870010, 0xa5f80121, 0xdef80066, 0x00000000}},  //   _műan, меру_, _maċ_,
  { {0xe8d90011, 0x636b005d, 0x2fc617f1, 0x00000000}},  //   _phổ_, rünm, krog_,
  { {0x69da0516, 0x545502b8, 0x57f4007e, 0x00000000}},  // [9890] ltte, хват, _апыт,
  { {0x2fc601d6, 0xa3cb0316, 0x2d9e0030, 0x00000000}},  //   drog_, रूष_, _otte_,
  { {0x69da00b0, 0x69cf0036, 0x29d8009d, 0x00000000}},  //   ntte, ąceg, néa_,
  { {0x69da021e, 0xe8d90011, 0x2fc6307a, 0x00000000}},  //   itte, _thổ_, frog_,
  { {0x6370307b, 0x7feb0355, 0x9327004b, 0x00000000}},  //   männ, تراف_, _قرآن,
  { {0x7af80059, 0x7df3006b, 0x63700a3c, 0x00000000}},  //   _navt, _həsə, länn,
  { {0xa3cb0316, 0x62830027, 0x7f43006b, 0x00000000}},  //   रूर_, ľnos, rinq,
  { {0x62830387, 0x98a00107, 0xa2d70055, 0x00000000}},  //   žnos, _ilić_, _সফটও,
  { {0x7df3005f, 0x2d9e042b, 0x69da11be, 0x00000000}},  //   _məsə, _ette_, ette,
  { {0x69da03fa, 0x6d5c01e5, 0x00000000, 0x00000000}},  //   ftte, _íran,   ,
  { {0xa96a0256, 0x63700a3c, 0x273404ce, 0x00000000}},  //   зина_, känn, _häng_,
  { {0xfe6e007a, 0x386915c5, 0xf76900a3, 0x00000000}},  //   _اگه_, _byar_, _הק_,
  { {0x69da00b0, 0x636b307c, 0xdb0b0039, 0x00000000}},  //   atte, günk, _avgå,
  { {0xdb1b03b5, 0x8c1a00b3, 0x2734006c, 0x00000000}},  //   bruá, _מוני, _mäng_,
  { {0x7bdb0004, 0x3d040061, 0xd94600ed, 0x00000000}},  //   ltuu, वाचे_, _пеки,
  { {0x98b90035, 0x7df3006b, 0x00000000, 0x00000000}},  //   risă_, _cəsə,   ,
  { {0x68e418a9, 0x7bdb0160, 0xd4090025, 0x00000000}},  // [98a0] _ibid, ntuu, وتكم_,
  { {0x7d0b0022, 0x00000000, 0x00000000, 0x00000000}},  //   _lngs,   ,   ,
  { {0xe8d9001d, 0xf8bf00f4, 0x7bdb00b0, 0x00000000}},  //   _chỗ_, chés_, htuu,
  { {0x7bdb095a, 0x3ced0022, 0xa99a0049, 0x00000000}},  //   ktuu, jeev_, לבער,
  { {0x7f46004c, 0xe73f0181, 0xe3b203d9, 0x00000000}},  //   недж, spõe_, _حرج_,
  { {0x63a40149, 0x69da307d, 0x7d0b05c6, 0x00000000}},  //   mpin, ytte, _angs,
  { {0x68e4307e, 0x63a40273, 0x4ea50088, 0x00000000}},  //   _obid, lpin, тріа,
  { {0x2fc60190, 0x98a90235, 0x68e40066, 0x00000000}},  //   prog_, _plač_, _nbid,
  { {0x63a40315, 0x27340e2b, 0xdef8002b, 0x00000000}},  //   npin, _känd_, _taċ_,
  { {0x30750057, 0x68e4006b, 0x7d0b00f8, 0x00000000}},  //   _русс, _abid, _engs,
  { {0xc333019b, 0x2bc2024c, 0x38690093, 0x00000000}},  //   רות_, _शिवा, _syar_,
  { {0x69da0706, 0x98a90027, 0x2eee113d, 0x00000000}},  //   rtte, _tlač_, leff_,
  { {0x69da211e, 0x629c0065, 0x7bdb00b5, 0x00000000}},  //   stte, _ofro, ctuu,
  { {0x63a4129a, 0x999e0010, 0x68e403b0, 0x00000000}},  //   dpin, sztő_, _ebid,
  { {0x63a40fe8, 0x321300fa, 0xe5c401ab, 0x00000000}},  //   epin, xxxy_, лсто,
  { {0x629c0065, 0x7df3006b, 0x59c5007d, 0x00000000}},  //   _afro, _qəsə, _वितर,
  { {0xf2c70088, 0x6370307f, 0xf8bf291b, 0x00000000}},  // [98b0] есен, ränn, ्लीप,
  { {0x69c802ae, 0xd0110123, 0x27e90022, 0x00000000}},  //   orde, یلا_, _ipan_,
  { {0x7df3006b, 0x200401bc, 0x6d420035, 0x00000000}},  //   _təsə, _armi_, _omoa,
  { {0x629c0016, 0x68fd030e, 0x69c80051, 0x00000000}},  //   _efro, ndsd, irde,
  { {0x8009026c, 0xd25000a1, 0x656d0169, 0x00000000}},  //   براہ_, لنے_, mlah,
  { {0xd0060478, 0x6d4200e0, 0x66051adc, 0x00000000}},  //   теше_, _amoa, _krhk,
  { {0x8d55004c, 0xed59005c, 0xb35400ec, 0x00000000}},  //   ктич, мок_, _скрш,
  { {0x13d50044, 0x68fd1e2e, 0x7bdb00b0, 0x00000000}},  //   _সৈয়, jdsd, ttuu,
  { {0x69c801b5, 0x7f95005e, 0x88b00044, 0x00000000}},  //   erde, _разх, _কালক,
  { {0x59c50183, 0x00000000, 0x00000000, 0x00000000}},  //   _विदर,   ,   ,
  { {0x7bdb3080, 0x81df0055, 0x27e9011c, 0x00000000}},  //   stuu, তিক_, _apan_,
  { {0x63a401d6, 0xd94601ee, 0x672100f8, 0x00000000}},  //   ypin, теми, öljn,
  { {0x69c802ae, 0xf8bf00b9, 0x656d0161, 0x00000000}},  //   arde, ckém_, dlah,
  { {0x07a30088, 0x7bdc001a, 0x81e80044, 0x00000000}},  //   рарн, ărut, বিত_,
  { {0xa3d4001c, 0x63bd01c9, 0x1659041f, 0x00000000}},  //   सून_, _avsn, ерть_,
  { {0x629c3081, 0x2be5013d, 0x656d011c, 0x00000000}},  //   _sfro, _कहां_, glah,
  { {0xb87b0a06, 0x7bc90191, 0x9fbc0044, 0x00000000}},  // [98c0] rfíc, nreu, _আঙ্গ,
  { {0x63a4001e, 0x577a0025, 0x00000000, 0x00000000}},  //   rpin, _تصبح_,   ,
  { {0x63a4163a, 0x7bc900d9, 0x35a60545, 0x00000000}},  //   spin, hreu, _шанг,
  { {0x63a40038, 0xd5b8001e, 0x4fc60d51, 0x00000000}},  //   ppin, šās_, вска,
  { {0xb4ce0309, 0x81e80044, 0xa3ba0d0b, 0x00000000}},  //   रली_, বিধ_, _تاجر_,
  { {0x776e0009, 0xb87b008e, 0x7bc9009d, 0x00000000}},  //   nlbx, nfía, dreu,
  { {0xe1f7007c, 0x41aa01e1, 0x2eee01a2, 0x00000000}},  //   _игр_, _іван_, reff_,
  { {0xed5703f3, 0x7bc93082, 0x2eee000a, 0x00000000}},  //   кој_, freu, seff_,
  { {0x06b80055, 0x9f4d008e, 0x7bc90035, 0x00000000}},  //   _জানি, _creó_, greu,
  { {0x69c80f92, 0x00000000, 0x00000000, 0x00000000}},  //   trde,   ,   ,
  { {0x27e90365, 0x69c801b5, 0xf8bf00b9, 0x00000000}},  //   _span_, urde, ském_,
  { {0xdca6012b, 0x7bc9046a, 0xf8bf0010, 0x00000000}},  //   _ради, breu, mkék_,
  { {0x7bc90115, 0x68fd0056, 0xcc16023c, 0x00000000}},  //   creu, rdsd, _جذاب,
  { {0xcf930476, 0x00000000, 0x00000000, 0x00000000}},  //   יטש_,   ,   ,
  { {0xb8d90044, 0x656d1a16, 0x80d3013d, 0x00000000}},  //   _চা_, tlah, _डाले,
  { {0xdb1b02d5, 0x6441006b, 0x00000000, 0x00000000}},  //   truç, _əlif,   ,
  { {0x4394004d, 0x656d003f, 0x0ed201f5, 0x00000000}},  // [98d0] иатс, rlah, _सांड,
  { {0x656d0020, 0x6fcc0061, 0x764e0010, 0x00000000}},  //   slah, _समजू, ányá,
  { {0x656d010e, 0x672800f8, 0x00000000, 0x00000000}},  //   plah, ödje,   ,
  { {0x59c50204, 0x7bc901a2, 0x00000000, 0x00000000}},  //   _विसर, yreu,   ,
  { {0x3f8c01d5, 0x00000000, 0x00000000, 0x00000000}},  //   _bidu_,   ,   ,
  { {0x543a007b, 0x752d21b3, 0x7bc9009d, 0x00000000}},  //   _טערא, lkaz, vreu,
  { {0x4429163c, 0xc33200a0, 0x02af013d, 0x00000000}},  //   lya_, _פול_, टरीन,
  { {0x7bc9010f, 0x9f4d0026, 0x752d0288, 0x00000000}},  //   treu, _creò_, nkaz,
  { {0xa055008b, 0x7bc900f4, 0xbab50147, 0x00000000}},  //   _сваі, ureu, лёны,
  { {0x89a901e0, 0x7bc91923, 0x442900ea, 0x00000000}},  //   нков_, rreu, iya_,
  { {0x394a0175, 0x5cd5006d, 0x7bc901c3, 0x00000000}},  //   езно_, _مقاط, sreu,
  { {0x7bc9001a, 0x442929ca, 0x798d0093, 0x00000000}},  //   preu, kya_, _ciaw,
  { {0x44290061, 0x59c5013d, 0x798d0658, 0x00000000}},  //   jya_, _विवर, _diaw,
  { {0x44292045, 0x7d1b006c, 0xa03a0049, 0x00000000}},  //   dya_, ljus, געשפ,
  { {0xceb2019b, 0x7c29224b, 0x7c3b3083, 0x00000000}},  //   מים_, lyer, lzur,
  { {0xb4ce024c, 0x44293084, 0x7d1b164d, 0x00000000}},  //   रले_, fya_, njus,
  { {0x6b8d002a, 0x7c29020c, 0x4429020e, 0x00000000}},  // [98e0] _éags, nyer, gya_,
  { {0x57fb00b6, 0x7d1b0004, 0x78b6006b, 0x00000000}},  //   _טלפו, hjus, _heyv,
  { {0xdce21581, 0xf772089d, 0x10a618ea, 0x00000000}},  //   _skoč, _پاک_, гиен,
  { {0x3f8c08b3, 0x00000000, 0x00000000, 0x00000000}},  //   _sidu_,   ,   ,
  { {0x7d1b01ee, 0x78b6005a, 0x6d493085, 0x00000000}},  //   djus, _meyv, diea,
  { {0x78b6004a, 0x00000000, 0x00000000, 0x00000000}},  //   _leyv,   ,   ,
  { {0x7afe0489, 0x3d8a007c, 0x3f8c2a6c, 0x00000000}},  //   _ópti, нщин_, _vidu_,
  { {0x42530151, 0xdb003086, 0x00000000, 0x00000000}},  //   _انفر, nsmö,   ,
  { {0x798d0022, 0xdce211af, 0x00000000, 0x00000000}},  //   _riaw, _ukoč,   ,
  { {0xdfcf0025, 0x798d005b, 0x00000000, 0x00000000}},  //   _ريم_, _siaw,   ,
  { {0x6e930379, 0x5e930054, 0xaa5803c0, 0x00000000}},  //   _الما, _المط, тину_,
  { {0x7c29011c, 0x88b00044, 0xe8d90011, 0x00000000}},  //   byer, _কাউক, _khứ_,
  { {0x386d0030, 0xac970025, 0xab2a17e9, 0x00000000}},  //   æer_, _إنها_, _пода_,
  { {0x7dea005f, 0x7bfb009b, 0x44290020, 0x00000000}},  //   _təsd, _נפוצ, vya_,
  { {0x752d016c, 0x6aba00f8, 0x95c805a5, 0x00000000}},  //   tkaz, matf, лута_,
  { {0x44290148, 0x6aba0010, 0x06c60044, 0x00000000}},  //   tya_, latf, শ্লি,
  { {0x394b03db, 0x44290e6d, 0x93970439, 0x00000000}},  // [98f0] mics_, uya_, اجرا,
  { {0xd25b013b, 0x394b1a86, 0x44290d56, 0x00000000}},  //   нце_, lics_, rya_,
  { {0x44293087, 0x7c3b0197, 0x32070161, 0x00000000}},  //   sya_, zzur, íny_,
  { {0x44293088, 0x394b12a0, 0x7c3b0036, 0x00000000}},  //   pya_, nics_, yzur,
  { {0xe8d9001d, 0x06b80055, 0xa2950088, 0x00000000}},  //   _chứ_, _জাতি, _вагі,
  { {0x394b0133, 0x00000000, 0x00000000, 0x00000000}},  //   hics_,   ,   ,
  { {0x6d491ea7, 0xf204005e, 0x7c290133, 0x00000000}},  //   tiea, _лято, wyer,
  { {0x7c3b002d, 0x68ff01f3, 0x00000000, 0x00000000}},  //   tzur, _naqd,   ,
  { {0x75ec0047, 0x394b0129, 0x60db0009, 0x00000000}},  //   _közö, dics_, _icum,
  { {0xff530025, 0xef67005e, 0x81e80044, 0x00000000}},  //   _اخر_, _събо, বির_,
  { {0x394b0129, 0x7c3b3089, 0x7c290058, 0x00000000}},  //   fics_, szur, syer,
  { {0x394b0129, 0x63700039, 0x8d870269, 0x00000000}},  //   gics_, tänk, _сузд,
  { {0x5ba70140, 0x6aba0030, 0x2cad0787, 0x00000000}},  //   _срез, batf, mbed_,
  { {0xfaa50373, 0x6370308a, 0x2cad1eda, 0x00000000}},  //   _тако, ränk, lbed_,
  { {0x29560265, 0x394b060d, 0x60db0919, 0x00000000}},  //   _въпр, bics_, _ocum,
  { {0x6370053d, 0x2d8f0173, 0x2cad0544, 0x00000000}},  //   mäni, _jige_, nbed_,
  { {0x2900059a, 0x9346025f, 0x29120022, 0x00000000}},  // [9900] _iaia_, анае, _inya_,
  { {0x2d8f0018, 0x60db001a, 0xa87b00a0, 0x00000000}},  //   _lige_, _acum, _באפר,
  { {0x80a60084, 0x4add0309, 0x7dea006b, 0x00000000}},  //   لمان, _मानव, _məsc,
  { {0xdfa606e3, 0x2900002d, 0x81e80044, 0x00000000}},  //   ајко, _jaia_, বিল_,
  { {0xdefa0057, 0x290020c2, 0x636b01a2, 0x00000000}},  //   вый_, _maia_, güns,
  { {0x2d8f002a, 0x29000fc3, 0x60db0035, 0x00000000}},  //   _aige_, _laia_, _ecum,
  { {0x636b0676, 0x6aba0190, 0x637000b0, 0x00000000}},  //   rünt, vatf, jäni,
  { {0xe8d9001d, 0x394b00d4, 0x60db0051, 0x00000000}},  //   _thứ_, xics_, _gcum,
  { {0x8fa30373, 0x2aaa00c0, 0x394b1422, 0x00000000}},  //   _мате, ктно_, vics_,
  { {0x29120010, 0x2d8f0056, 0x7bc6007f, 0x00000000}},  //   _anya_, _eige_, škuo,
  { {0x2bc202d2, 0x394b03db, 0x2900001a, 0x00000000}},  //   _शिका, tics_, _baia_,
  { {0xdd8f031d, 0x38c90167, 0x2900308b, 0x00000000}},  //   _قول_, دادی_, _caia_,
  { {0x394b00ab, 0x20061815, 0x27ed00d4, 0x00000000}},  //   rics_, nvoi_, ïen_,
  { {0x394b0129, 0x28a702fb, 0x29120035, 0x00000000}},  //   sics_, _क्रि, _enya_,
  { {0x394b00ab, 0x68930014, 0xa3d4013d, 0x00000000}},  //   pics_, _ویدئ, सूस_,
  { {0x2900002d, 0xef190036, 0x63a601c3, 0x00000000}},  //   _gaia_, _duży_, _btkn,
  { {0x7bc002e7, 0x394900ca, 0x4498007c, 0x00000000}},  // [9910] nsmu, _imas_, рвую_,
  { {0x27340004, 0x60db001a, 0x63a20051, 0x00000000}},  //   _täna_, _scum, íona,
  { {0x636b010f, 0xa2940088, 0xa2dd006e, 0x00000000}},  //   wüns, іаці, _पाठ्,
  { {0x301502d3, 0x21240051, 0x7bc00006, 0x00000000}},  //   йдер, _comh_, ksmu,
  { {0x2d8f0190, 0x83870783, 0x21240051, 0x00000000}},  //   _rige_, _выве, _domh_,
  { {0x2d8f308c, 0xf1a70216, 0x9f0500a1, 0x00000000}},  //   _sige_, _вран, صوبو,
  { {0x2d8f0030, 0x78bd03b6, 0x7bc200f4, 0x00000000}},  //   _pige_, kasv, _avou,
  { {0x2608001c, 0x28a702d2, 0x26d80107, 0x00000000}},  //   हिती_, _क्लि, zgro_,
  { {0x403409de, 0x2cad08ce, 0x29000020, 0x00000000}},  //   _детс, rbed_, _raia_,
  { {0x7de701fb, 0x7bc200b9, 0x290000c4, 0x00000000}},  //   _відд, _dvou, _saia_,
  { {0xe8d9001d, 0xaa49012c, 0x2900142e, 0x00000000}},  //   _chữ_, упна_, _paia_,
  { {0x7c950025, 0x6f01008e, 0x637004ce, 0x00000000}},  //   _الإص, _halc, räni,
  { {0x6c850054, 0x290000f6, 0x67250145, 0x00000000}},  //   _الشم, _vaia_, _bohj,
  { {0x394904cb, 0x6d500036, 0x00000000, 0x00000000}},  //   _emas_, ądał,   ,
  { {0x6f010059, 0xf743007c, 0xe5a6308d, 0x00000000}},  //   _malc, черо, сиби,
  { {0x6f0100f6, 0x2912011c, 0x00000000, 0x00000000}},  //   _lalc, _unya_,   ,
  { {0x69c103b4, 0xf4840014, 0x7dea006b, 0x00000000}},  // [9920] lsle, زاری, _məsa,
  { {0xa2dd0201, 0x5fd10061, 0x7c240009, 0x00000000}},  //   _पाण्, _समजल, _àire,
  { {0x69c10056, 0xfe65025a, 0x2d8420d6, 0x00000000}},  //   nsle, _آگ_, ymme_,
  { {0x629526f2, 0x69c10048, 0xf77f014a, 0x00000000}},  //   _egzo, isle, rtçe_,
  { {0x572500e9, 0x60180604, 0x7e7a0045, 0x00000000}},  //   _طریق, роля_, _sztp,
  { {0x2ca001d5, 0x69c10006, 0xdce00089, 0x00000000}},  //   _żid_, ksle, domā,
  { {0xa2dd0164, 0xddea067a, 0x20060052, 0x00000000}},  //   _पात्, ارته_, svoi_,
  { {0x69c101e3, 0x7bc60006, 0x7bc000ea, 0x00000000}},  //   dsle, škum, tsmu,
  { {0x6f0102f1, 0x7bc018ef, 0x00000000, 0x00000000}},  //   _falc, usmu,   ,
  { {0x93fb00a0, 0x69c11642, 0x6f01308e, 0x00000000}},  //   נליי, fsle, _galc,
  { {0x69c1000c, 0x995200b9, 0x78bd12e2, 0x00000000}},  //   gsle, lář_, tasv,
  { {0x48ab007c, 0x7d1d01a2, 0x7bc00056, 0x00000000}},  //   ытом_, össt, psmu,
  { {0xc867046c, 0x6725021e, 0x69c30637, 0x00000000}},  //   стни, _pohj, _evne,
  { {0x7d0211cb, 0x69c101c5, 0x28db01f5, 0x00000000}},  //   _haos, bsle, _भावि,
  { {0x69c30009, 0x95770014, 0x63a20048, 0x00000000}},  //   _gvne, مدرض, íonn,
  { {0x39490181, 0xe8d90011, 0x7dea006b, 0x00000000}},  //   _umas_, _khử_, _xəsa,
  { {0x24181036, 0x2a8e006b, 0xa3d40164, 0x00000000}},  // [9930] боты_, ləb_, सूल_,
  { {0x70d1006e, 0x7d02010e, 0x00000000, 0x00000000}},  //   हल्ल, _laos,   ,
  { {0xd09501ab, 0x00000000, 0x00000000, 0x00000000}},  //   ошлы,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f010142, 0x675402fd, 0x68ed0020, 0x00000000}},  //   _palc, _ذخیر, _mbad,
  { {0x63ad0f68, 0xf650026c, 0x7a3f0047, 0x00000000}},  //   mpan, _آئی_, _játé,
  { {0x6f01145e, 0x63ad00eb, 0x7d0201f3, 0x00000000}},  //   _valc, lpan, _baos,
  { {0x6f010036, 0xdce00089, 0x69c700b9, 0x00000000}},  //   _walc, tomā, ájem,
  { {0x63ad0fa8, 0x4ad4001c, 0x60c90466, 0x00000000}},  //   npan, _दाखव, _idem,
  { {0x200d00c4, 0xb178000c, 0x7c2600f8, 0x00000000}},  //   _irei_, _þórð, äkra,
  { {0xf2d20104, 0x61e500ab, 0x7dea006b, 0x00000000}},  //   ועי_, nthl, _təsa,
  { {0x69c11e58, 0xa96a012b, 0x61e50fb8, 0x00000000}},  //   rsle, рима_, ithl,
  { {0x69c10caa, 0x6d4b0869, 0x63ad00d9, 0x00000000}},  //   ssle, _imga, jpan,
  { {0x69c3001e, 0x2a8e006b, 0x63ad00eb, 0x00000000}},  //   _tvne, bəb_, dpan,
  { {0x60c905c5, 0x2a8e013f, 0x00000000, 0x00000000}},  //   _odem, cəb_,   ,
  { {0x9599003b, 0x2cbf00f4, 0xf8bf00c4, 0x00000000}},  //   стру_, naud_, caé_,
  { {0xccf2019b, 0x0326013b, 0x63ad011c, 0x00000000}},  // [9940] וכן_, одан, gpan,
  { {0x60c90958, 0x68ed308f, 0xe3b70245, 0x00000000}},  //   _adem, _zbad, юбу_,
  { {0x6d4b0bc7, 0x63ad0051, 0xdb09008e, 0x00000000}},  //   _omga, apan, nseñ,
  { {0xa50a00d7, 0x200d1aef, 0xbfaa0aed, 0x00000000}},  //   _тема_, _brei_, атке_,
  { {0x200d0e32, 0x60c9005b, 0x272f006b, 0x00000000}},  //   _crei_, _ddem, _süni_,
  { {0x200d010f, 0x60c9014a, 0x7d0201ee, 0x00000000}},  //   _drei_, _edem, _saos,
  { {0x6449009f, 0xdd97007e, 0x995200b9, 0x00000000}},  //   _þeir, ошы_, sář_,
  { {0x200d010f, 0xe0d70088, 0x2cbf0f07, 0x00000000}},  //   _frei_, _мвс_, gaud_,
  { {0x81bc08b7, 0x64400180, 0xff2700a1, 0x00000000}},  //   _আমি_, _ümid, _ڈبلی,
  { {0x68ed2a03, 0xba0a005e, 0x00000000, 0x00000000}},  //   _sbad, ахме_,   ,
  { {0x13b30055, 0x81e80044, 0x06e30044, 0x00000000}},  //   টওয়, বিক_, য়মি,
  { {0xe8d9001d, 0x63ad00ea, 0x68ed0066, 0x00000000}},  //   _thử_, ypan, _qbad,
  { {0x63ad0009, 0x637000b0, 0xb89a07e4, 0x00000000}},  //   xpan, näns, _šťáv,
  { {0x61e5005b, 0x00000000, 0x00000000, 0x00000000}},  //   ythl,   ,   ,
  { {0xe8d9001d, 0xda6f0088, 0xbb830076, 0x00000000}},  //   _chợ_, _ця_, _تلوي,
  { {0x68ed0258, 0x637000f8, 0x29050089, 0x00000000}},  //   _ubad, käns, ēlas_,
  { {0x63700039, 0x00000000, 0x00000000, 0x00000000}},  // [9950] jäns,   ,   ,
  { {0xd37106f1, 0xc7b20476, 0x63ad3090, 0x00000000}},  //   رها_, _רבי_, rpan,
  { {0x63ad060b, 0x63700c43, 0x877c0049, 0x00000000}},  //   span, vänt, _דאזי,
  { {0x61e507be, 0x644001d5, 0x386d002b, 0x00000000}},  //   rthl, _żmie, żeru_,
  { {0x251a00b3, 0xb4d70164, 0x2cbf0e6d, 0x00000000}},  //   _הורא, सली_, vaud_,
  { {0x200d000d, 0xe3b20049, 0xa858009b, 0x00000000}},  //   _vrei_, _אױך_, חידה_,
  { {0x4394003b, 0x09af0055, 0x31c401fc, 0x00000000}},  //   _царс, _কিভা, _оств,
  { {0x200d000d, 0x6441006b, 0x60c90190, 0x00000000}},  //   _trei_, _əlin, _udem,
  { {0xdb1b00c4, 0x00000000, 0x00000000, 0x00000000}},  //   ssuí,   ,   ,
  { {0x0b42008b, 0x2cbf0035, 0x00000000, 0x00000000}},  //   еньн, saud_,   ,
  { {0xc869007b, 0x7a69004d, 0x656d0d17, 0x00000000}},  //   _ען_, синг_, koah,
  { {0x7dea006b, 0x6d4b05e9, 0x00000000, 0x00000000}},  //   _məsl, _umga,   ,
  { {0x4c9a009b, 0x00000000, 0x00000000, 0x00000000}},  //   _הבנו,   ,   ,
  { {0x26080204, 0x00000000, 0x00000000, 0x00000000}},  //   हिली_,   ,   ,
  { {0x7dea006b, 0x6d5b2368, 0xfbbd0044, 0x00000000}},  //   _nəsl, onua, _আমিত,
  { {0xe9a806f1, 0x6d5b22ce, 0xc4d60061, 0x00000000}},  //   _بدون_, nnua, धलेख,
  { {0xf993009b, 0xa2dd01f5, 0x79840058, 0x00000000}},  // [9960] _ארה_, _पाश्, _ihiw,
  { {0xe8d90011, 0x6d5b0051, 0x66170010, 0x00000000}},  //   _thợ_, hnua, égkö,
  { {0xa2dd02fb, 0x27340039, 0xe297007e, 0x00000000}},  //   _पार्, _länk_, чах_,
  { {0x2367016e, 0x6d5b0023, 0x00000000, 0x00000000}},  //   čnja_, jnua,   ,
  { {0x21673091, 0x00000000, 0x00000000, 0x00000000}},  //   чици_,   ,   ,
  { {0x4393007e, 0x63702c31, 0x00000000, 0x00000000}},  //   _паўс, räns,   ,
  { {0xde93003b, 0x44323092, 0x00000000, 0x00000000}},  //   нашњ, lyy_,   ,
  { {0x06c60044, 0x75243093, 0xd6c60044, 0x00000000}},  //   শ্চি, njiz, শ্চয,
  { {0x44200082, 0x64443094, 0xe8d90082, 0x00000000}},  //   nxi_, nzii, _nhỡ_,
  { {0x5a3400e3, 0xbec20089, 0x44200129, 0x00000000}},  //   днот, šība, ixi_,
  { {0x58d50364, 0x6d950006, 0xaadd013d, 0x00000000}},  //   монт, _išan, _मारक,
  { {0x60c20020, 0x443200b0, 0x7524002b, 0x00000000}},  //   naom, kyy_, jjiz,
  { {0x2fc6000c, 0xfc2f03d6, 0x3ae50173, 0x00000000}},  //   nsog_, _محو_, _bňpč_,
  { {0x2d9e0011, 0xaae60014, 0x644401c5, 0x00000000}},  //   _kute_, _رستو, dzii,
  { {0x4b7b009b, 0x60c2170e, 0x3ebe3095, 0x00000000}},  //   _האגו, kaom, _mett_,
  { {0x3ebe3096, 0xb4d70164, 0xda5b009b, 0x00000000}},  //   _lett_, सले_, _לכול,
  { {0x69da0275, 0x7dea006b, 0x2d9e3097, 0x00000000}},  // [9970] lute, _səsl, _lute_,
  { {0x7afa021e, 0x3ebe122f, 0x2bd40309, 0x00000000}},  //   nett, _nett_, _दिना,
  { {0x6515026c, 0x7afa0207, 0x26c30059, 0x00000000}},  //   _ہوگئ, iett, majo_,
  { {0x7afa0c71, 0x26c30059, 0x98a50006, 0x00000000}},  //   hett, lajo_, ėlė_,
  { {0x7afa021e, 0xaadd01f5, 0x3ebe0a35, 0x00000000}},  //   kett, _मालक, _bett_,
  { {0x69da006c, 0x2d9e007f, 0x7afa0056, 0x00000000}},  //   kute, _bute_, jett,
  { {0x69da01d5, 0x7afa0c71, 0x417700a2, 0x00000000}},  //   jute, dett, _فارس,
  { {0x2d9e0756, 0x69da3098, 0x2b4e0022, 0x00000000}},  //   _dute_, dute, _amfc_,
  { {0x7afa0409, 0x3ebe3099, 0x6d5b002d, 0x00000000}},  //   fett, _fett_, rnua,
  { {0x7afa0198, 0x26c301d9, 0x3ebe0039, 0x00000000}},  //   gett, jajo_, _gett_,
  { {0x2d9e001f, 0x26c30059, 0xd6e30044, 0x00000000}},  //   _gute_, dajo_, য়ায,
  { {0x6d40001f, 0x44320058, 0x27340039, 0x00000000}},  //   chma, yyy_, _tänk_,
  { {0x442001d5, 0x7afa153a, 0x2d9e0107, 0x00000000}},  //   xxi_, bett, _zute_,
  { {0x7afa2529, 0xdb0b0039, 0x69da0549, 0x00000000}},  //   cett, _avgö, bute,
  { {0x64a6007e, 0x69da032c, 0x55e3007c, 0x00000000}},  //   даба, cute, корб,
  { {0x7d090d65, 0x4420022b, 0xe3ba00ed, 0x00000000}},  //   ndes, txi_, жба_,
  { {0x26c30219, 0x7dea005f, 0x7d0900f2, 0x00000000}},  // [9980] bajo_, _rəsm, ides,
  { {0x7d0900b0, 0x753d0010, 0x60c20020, 0x00000000}},  //   hdes, _elsz, waom,
  { {0x00e601fb, 0x3f9f0521, 0x3ebe0292, 0x00000000}},  //   джен, _auuu_, _rett_,
  { {0x2d9e23c4, 0x3ebe01e2, 0x7d090065, 0x00000000}},  //   _rute_, _sett_, jdes,
  { {0x7afa014a, 0x8fa30407, 0x69da002d, 0x00000000}},  //   yett, ваче, zute,
  { {0x43750088, 0x69da2f1b, 0x7afa0203, 0x00000000}},  //   _зуст, yute, xett,
  { {0x7afa1bb9, 0x7d090007, 0x3ebe309a, 0x00000000}},  //   vett, fdes, _vett_,
  { {0x6440000c, 0x7d09309b, 0x7afa0125, 0x00000000}},  //   _ýmis, gdes, wett,
  { {0x7afa021e, 0x7dea006b, 0x3ebe309c, 0x00000000}},  //   tett, _kəsk, _tett_,
  { {0x60c00073, 0x6d4008e9, 0x7afa009d, 0x00000000}},  //   _hemm, shma, uett,
  { {0xfe430256, 0x26c30059, 0x60c00b5e, 0x00000000}},  //   _инфо, vajo_, _kemm,
  { {0x7afa0292, 0x69da309d, 0x60c0002b, 0x00000000}},  //   sett, rute, _jemm,
  { {0x7afa0198, 0xb907006e, 0x69da0a0e, 0x00000000}},  //   pett, _पा_, sute,
  { {0x60c00cfc, 0x69da0f7c, 0x629c0065, 0x00000000}},  //   _lemm, pute, _ngro,
  { {0x26c301d9, 0x2d860011, 0xf794007e, 0x00000000}},  //   rajo_, _khoe_, тарэ,
  { {0x629c0181, 0x60c0309e, 0xab5d0036, 0x00000000}},  //   _agro, _nemm, duży,
  { {0x21260521, 0x68fd214c, 0x26c30059, 0x00000000}},  // [9990] djoh_, mesd, pajo_,
  { {0x32110046, 0xd37b008b, 0xdb090181, 0x00000000}},  //   _przy_, іча_, mpeã,
  { {0xd25b0551, 0xe8d900ad, 0xd2510a4f, 0x00000000}},  //   цца_, _chủ_, دنا_,
  { {0x290b001a, 0x629c0145, 0x660524e7, 0x00000000}},  //   ndca_, _egro, _ishk,
  { {0x2eee001c, 0x6aaa0483, 0x7d0924ac, 0x00000000}},  //   ffff_, _offf, vdes,
  { {0x26c1004f, 0xdc140055, 0x32110036, 0x00000000}},  //   _jeho_, িহাস_, _trzy_,
  { {0x60c0028c, 0x7d0900ca, 0x26c11282, 0x00000000}},  //   _femm, tdes, _meho_,
  { {0x60c00030, 0x69c805ad, 0x629c0036, 0x00000000}},  //   _gemm, dsde, _zgro,
  { {0x7bdb0091, 0x69c800d9, 0x7ae30085, 0x00000000}},  //   uuuu, esde, _pcnt,
  { {0x2909309f, 0x7d090a5e, 0x7bdb1c2b, 0x00000000}},  //   _aaaa_, sdes, ruuu,
  { {0x9f8a00b0, 0x7d0930a0, 0x00000000, 0x00000000}},  //   töön_, pdes,   ,
  { {0x186a080d, 0x6aaa0045, 0xdb1b004a, 0x00000000}},  //   зами_, _efff, rruñ,
  { {0x6aaa001c, 0xdd94007e, 0x66050023, 0x00000000}},  //   _ffff, _рацы, _ashk,
  { {0x613a0129, 0x25a10146, 0xe73a0cb3, 0x00000000}},  //   _aïll, _buhl_, чег_,
  { {0xe6170b87, 0xf53f1861, 0xa3e200e8, 0x00000000}},  //   ндр_, _blå_, नून_,
  { {0x68e40035, 0x629c1f3e, 0x68fd004a, 0x00000000}},  //   _ucid, _sgro, cesd,
  { {0x7bc914b3, 0xb386007c, 0xd4670745, 0x00000000}},  // [99a0] nseu, елал, еите_,
  { {0x60c00047, 0xe8d9001d, 0x63a42f17, 0x00000000}},  //   _semm, _phủ_, rqin,
  { {0xf7720123, 0x6f0814a6, 0xda1f007d, 0x00000000}},  //   _لاگ_, _radc, यमित_,
  { {0x7bd50036, 0x7bc930a1, 0x7a4601cc, 0x00000000}},  //   ązuj, kseu, _hété,
  { {0x7bcf0b76, 0x60c00146, 0xed500014, 0x00000000}},  //   ácul, _vemm, یپت_,
  { {0xe8d9001d, 0x629c30a2, 0x69c801d6, 0x00000000}},  //   _thủ_, _ugro, ysde,
  { {0x60c0011f, 0x7a4600f4, 0xe3631023, 0x00000000}},  //   _temm, _mété, _скри,
  { {0xe2970822, 0x7bc901d6, 0x00000000, 0x00000000}},  //   _час_, fseu,   ,
  { {0x6aaa0602, 0x1be7003b, 0x7dea006b, 0x00000000}},  //   _pfff, едњи_, _məsi,
  { {0x3940011c, 0x69c80270, 0x29090173, 0x00000000}},  //   _alis_, tsde, _saaa_,
  { {0x68fd02e1, 0x39400145, 0x00000000, 0x00000000}},  //   tesd, _blis_,   ,
  { {0x69c801d6, 0xfc660265, 0x7dea006b, 0x00000000}},  //   rsde, _пълн, _nəsi,
  { {0x68fd1f10, 0xdceb002b, 0x00000000, 0x00000000}},  //   resd, _sigħ,   ,
  { {0xb9c60054, 0xf53f044f, 0x8c1b0104, 0x00000000}},  //   _كتبه, _slå_, _מודי,
  { {0xbb830025, 0x39402e10, 0x7a46009d, 0x00000000}},  //   _حلوي, _flis_, _dété,
  { {0x394030a3, 0x4a7b009b, 0x2909012d, 0x00000000}},  //   _glis_, _מרוב, _uaaa_,
  { {0x28b40025, 0x26c130a4, 0x00000000, 0x00000000}},  // [99b0] _صحيح, _teho_,   ,
  { {0x8627007e, 0x00000000, 0x00000000, 0x00000000}},  //   _зьме,   ,   ,
  { {0xcad7009b, 0x212d00d9, 0x7dea013f, 0x00000000}},  //   תובת_, _poeh_, _fəsi,
  { {0x7fd50088, 0x00000000, 0x00000000, 0x00000000}},  //   вікі,   ,   ,
  { {0xb4cd0204, 0xe134007e, 0xdee50072, 0x00000000}},  //   रणी_, ынцы, воли,
  { {0xbec20089, 0x3eac009d, 0xb33b00fa, 0x00000000}},  //   šīna, _cfdt_, _fuça,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27340039, 0xfe700380, 0x7bc930a5, 0x00000000}},  //   _hänt_, حده_, tseu,
  { {0x2d8d049b, 0x27340039, 0x752f0036, 0x00000000}},  //   rmee_, _känt_, _mocz,
  { {0xc6bc0044, 0x2d8d0501, 0x78ad0129, 0x00000000}},  //   _অঞ্চ, smee_, _afav,
  { {0xa96a0113, 0x39400263, 0x7bc9028c, 0x00000000}},  //   дина_, _plis_, sseu,
  { {0x9c39012b, 0x7bc901c3, 0xbdf80241, 0x00000000}},  //   _опет_, pseu, _سرما_,
  { {0x69de00ea, 0x394000d9, 0x00000000, 0x00000000}},  //   _åpen, _vlis_,   ,
  { {0x7d0b000c, 0x41d1007d, 0x78ad0c10, 0x00000000}},  //   _hags, _हिंस, _efav,
  { {0xc8b6007c, 0x7a4600f4, 0xb87b008e, 0x00000000}},  //   _испы, _vété, rgía,
  { {0xe8d9001d, 0x7d0b30a6, 0xb4dc0204, 0x00000000}},  //   _phụ_, _jags, ठले_,
  { {0x7d0b006a, 0x7dea006b, 0x752f0036, 0x00000000}},  // [99c0] _mags, _vəsi, _docz,
  { {0x7c260039, 0x7d0b0039, 0xfbd4013d, 0x00000000}},  //   äkri, _lags, _दिसम,
  { {0xb6d9007b, 0x7dea005f, 0x2fcd0173, 0x00000000}},  //   _אַרט, _təsi, _aveg_,
  { {0x7d0b006a, 0xe8d90011, 0x64a604b6, 0x00000000}},  //   _nags, _thụ_, _шама,
  { {0xc0e30077, 0xdb0000ea, 0x00000000, 0x00000000}},  //   рочк, ppmø,   ,
  { {0x2734006c, 0xdbdb000c, 0x4add0061, 0x00000000}},  //   _tänu_, _ráðg, _मागव,
  { {0x7d0b30a7, 0x68f61c10, 0x00000000, 0x00000000}},  //   _bags, _obyd,   ,
  { {0x90a50025, 0x00000000, 0x00000000, 0x00000000}},  //   _محكم,   ,   ,
  { {0x7d0b009f, 0x6aad014a, 0xbb7402ea, 0x00000000}},  //   _dags, _şafa, лгиј,
  { {0x20191471, 0x78ad0197, 0x00000000, 0x00000000}},  //   _ásia_, _sfav,   ,
  { {0x2bd40164, 0x98a70e0d, 0x7d0b1c36, 0x00000000}},  //   _दिवा, šiča_, _fags,
  { {0xa921006b, 0xdd960084, 0xe9450123, 0x00000000}},  //   _şöbə, _شجاع, اردی,
  { {0xf7730084, 0xdb09002a, 0x752f0036, 0x00000000}},  //   لاس_, speá, _rocz,
  { {0x7d000232, 0x752f0036, 0xf093034e, 0x00000000}},  //   lems, _socz, ינר_,
  { {0x752f0046, 0xa4d50cf2, 0x7e8600b9, 0x00000000}},  //   _pocz, лові, _úspě,
  { {0xb4cd01f5, 0x35440088, 0x7d000a3e, 0x00000000}},  //   रणे_, ахув, nems,
  { {0x659402be, 0x24580057, 0x3959011c, 0x00000000}},  // [99d0] рату, вать_, miss_,
  { {0x69da00bb, 0x7d0000f8, 0xdce000b9, 0x00000000}},  //   orte, hems, tomě,
  { {0x10d5007e, 0x752f0036, 0x7d000258, 0x00000000}},  //   гілё, _tocz, kems,
  { {0x69da30a8, 0x06d80055, 0x7d0000b9, 0x00000000}},  //   irte, দ্দি, jems,
  { {0xd250026c, 0x69da010f, 0x7dea006b, 0x00000000}},  //   منے_, hrte, _məsu,
  { {0x7d0b0030, 0xf77f0180, 0xdce0013e, 0x00000000}},  //   _sags, ftçi_, pomě,
  { {0x7d0b011c, 0xb06200b0, 0x00000000, 0x00000000}},  //   _pags, _ääni,   ,
  { {0x6d420781, 0x2bd40309, 0x00000000, 0x00000000}},  //   _cloa, _दिशा,   ,
  { {0xeb9919c9, 0x69da010f, 0xa158003b, 0x00000000}},  //   нии_, erte, _рату_,
  { {0x4add02fb, 0x4b250088, 0x00000000, 0x00000000}},  //   _माओव, умов,   ,
  { {0x52d00055, 0x7d0b17b0, 0x7dea006b, 0x00000000}},  //   স্কৃ, _tags, _səsv,
  { {0x2e3a0049, 0x6d420035, 0x4a420088, 0x00000000}},  //   _אגענ, _gloa, снюв,
  { {0x69da002d, 0xed59013e, 0x00000000, 0x00000000}},  //   arte, miž_,   ,
  { {0x07a30545, 0x656600ea, 0xcc3a0049, 0x00000000}},  //   сарн, _sjkh, _רעסט,
  { {0x39590f22, 0x2d9d00e7, 0x00000000, 0x00000000}},  //   biss_, _kiwe_,   ,
  { {0x2cad0038, 0x2d9d0020, 0x6995007e, 0x00000000}},  //   nced_, _jiwe_, _крых,
  { {0xc95300b6, 0x29020459, 0xf2da03ab, 0x00000000}},  // [99e0] _למה_, meka_, فظات_,
  { {0x29021077, 0x370605c0, 0x2d9d00e7, 0x00000000}},  //   leka_, _спог, _liwe_,
  { {0xe0da012b, 0x26ca015e, 0x8b560049, 0x00000000}},  //   еве_, mabo_, ניעס_,
  { {0x9fca0057, 0x2902023a, 0x26ca30a9, 0x00000000}},  //   егда_, neka_, labo_,
  { {0x43860a4f, 0x00000000, 0x00000000, 0x00000000}},  //   _ملحق,   ,   ,
  { {0x643b0049, 0xde5805b8, 0x69da068f, 0x00000000}},  //   _טעכנ, калі_, yrte,
  { {0x7d001a76, 0x6d42001a, 0x290230aa, 0x00000000}},  //   tems, _ploa, keka_,
  { {0x29020209, 0x69da00b9, 0x6564000c, 0x00000000}},  //   jeka_, vrte, nnih,
  { {0x7dea006b, 0x7d001a91, 0xf06600ed, 0x00000000}},  //   _rəsu, rems, _скап,
  { {0x69da0059, 0x3d190061, 0x7dea006b, 0x00000000}},  //   trte, _मोठे_, _bəst,
  { {0x26ca00d4, 0x69da00bb, 0x63a61d2f, 0x00000000}},  //   dabo_, urte, _lukn,
  { {0x7dea005f, 0x6370010f, 0x2902047b, 0x00000000}},  //   _dəst, gänz, geka_,
  { {0x3f9e30ab, 0xb954007c, 0x395930ac, 0x00000000}},  //   _kitu_, свящ, riss_,
  { {0x26ca0061, 0x3f9e30ad, 0x39590e4e, 0x00000000}},  //   gabo_, _jitu_, siss_,
  { {0x3f9e006c, 0x63a6000c, 0xf99000a2, 0x00000000}},  //   _mitu_, _aukn, تبی_,
  { {0x99d300a1, 0x3f9e2b0e, 0x7dea006b, 0x00000000}},  //   _اتوا, _litu_, _həss,
  { {0x5499007e, 0x26ca0058, 0x36d508fc, 0x00000000}},  // [99f0] тваў_, babo_, _копр,
  { {0xb4db00d4, 0x26ca00fa, 0x3f9e241d, 0x00000000}},  //   _glàn, cabo_, _nitu_,
  { {0x7dea005f, 0x798d04be, 0x05790025, 0x00000000}},  //   _xəst, _khaw, _لمدة_,
  { {0x1128005e, 0x301501ab, 0x82340025, 0x00000000}},  //   лючи_, идер, حركا,
  { {0x752d30ae, 0x32180022, 0xa49b00f6, 0x00000000}},  //   mjaz, _erry_, _caòt,
  { {0x3f9e001e, 0x29020020, 0x752d2530, 0x00000000}},  //   _citu_, zeka_, ljaz,
  { {0x3f9e022b, 0xddc2022a, 0xed5901ca, 0x00000000}},  //   _ditu_, общи, tiž_,
  { {0xd65800b6, 0x752d002b, 0x7aea0093, 0x00000000}},  //   טיות_, njaz, _acft,
  { {0x29020255, 0x2d53001a, 0x44290129, 0x00000000}},  //   veka_, nţei_, nxa_,
  { {0x2902000b, 0x442930af, 0x3f9e0169, 0x00000000}},  //   weka_, ixa_, _gitu_,
  { {0x6f032737, 0x29021bc4, 0x7a6900ed, 0x00000000}},  //   menc, teka_, тинг_,
  { {0x273d00ad, 0x5c750256, 0x6f03201e, 0x00000000}},  //   _hình_, _клет, lenc,
  { {0x2902020c, 0x7bc20263, 0x26ca011c, 0x00000000}},  //   reka_, _gwou, tabo_,
  { {0x6f031697, 0x6d4900c4, 0x6d5b0020, 0x00000000}},  //   nenc, lhea, liua,
  { {0x273d00ad, 0x63a60006, 0x26ca0059, 0x00000000}},  //   _mình_, _sukn, rabo_,
  { {0x26ca30b0, 0x798d002b, 0x63a60091, 0x00000000}},  //   sabo_, _ghaw, _pukn,
  { {0x6f03008d, 0x7c3b04be, 0x7c291374, 0x00000000}},  // [9a00] kenc, nyur, nxer,
  { {0x6f0330b1, 0x6d490050, 0x6d950006, 0x00000000}},  //   jenc, hhea, _išau,
  { {0x6f031e53, 0x0219007e, 0x6d5b30b2, 0x00000000}},  //   denc, ліць_, kiua,
  { {0x3f9e01a3, 0xfbc70379, 0xf9930049, 0x00000000}},  //   _situ_, _وت_, ַרג_,
  { {0x273d001d, 0x6d4930b3, 0x6d5b0065, 0x00000000}},  //   _bình_, dhea, diua,
  { {0x69c30038, 0x9f5305b8, 0x06d80044, 0x00000000}},  //   _owne, овіч, দ্রি,
  { {0x3f9e0020, 0x78a430b4, 0xbd6a026b, 0x00000000}},  //   _vitu_, _ogiv, крие_,
  { {0xc0e30057, 0x6d490fe5, 0x7bc201aa, 0x00000000}},  //   _моск, ghea, _pwou,
  { {0xdee601fc, 0x29d101d5, 0x3f9e0035, 0x00000000}},  //   _вози, eġa_, _titu_,
  { {0x798d0784, 0x637000b0, 0x6da3016c, 0x00000000}},  //   _shaw, täny, _rđav,
  { {0x6d49131d, 0x644d08eb, 0xc98700e2, 0x00000000}},  //   bhea, zzai, иуми,
  { {0x6d4930b5, 0x7bc201aa, 0x6d5b30b6, 0x00000000}},  //   chea, _twou, ciua,
  { {0x442901d5, 0x386d014a, 0x7c3b0009, 0x00000000}},  //   xxa_, çer_, cyur,
  { {0x6d4030b7, 0x79a60478, 0x69c30045, 0x00000000}},  //   lkma, _крие, _fwne,
  { {0x69c3018e, 0xd90f0123, 0x6d400009, 0x00000000}},  //   _gwne, _قید_, okma,
  { {0x644d022b, 0x44290ec8, 0x6f031fe9, 0x00000000}},  //   tzai, txa_, zenc,
  { {0xf8bf04bd, 0xd6db00ed, 0x752d002b, 0x00000000}},  // [9a10] mbé_, _итн_, rjaz,
  { {0xec71007b, 0x44291c6b, 0x6f030f57, 0x00000000}},  //   פֿן_, rxa_, xenc,
  { {0x6f03049a, 0x6d4930b8, 0x55590401, 0x00000000}},  //   venc, yhea, _баня_,
  { {0x6d490061, 0x6d4000bb, 0x00000000, 0x00000000}},  //   xhea, jkma,   ,
  { {0x6f030819, 0x6b81018e, 0x6d490009, 0x00000000}},  //   tenc, yllg, vhea,
  { {0x6d400328, 0x60cb00e0, 0x6d490133, 0x00000000}},  //   ekma, sagm, whea,
  { {0x6d49002a, 0x48e80061, 0xed59041f, 0x00000000}},  //   thea, _झालो_, лок_,
  { {0x7c290948, 0x9f5f000c, 0x236701ed, 0x00000000}},  //   txer, _eruð_, čnju_,
  { {0x273d00ad, 0x6ab80044, 0x6f031a56, 0x00000000}},  //   _tình_, _আয়ো, penc,
  { {0x6aa40676, 0x6d490051, 0x60c900bb, 0x00000000}},  //   _şifr, shea, _heem,
  { {0x60c930b9, 0xdce90645, 0x6d490a47, 0x00000000}},  //   _keem, sleđ, phea,
  { {0x29d1002b, 0xfc330076, 0x200d0022, 0x00000000}},  //   rġa_, _وحش_, _ksei_,
  { {0x8d74031d, 0x6d5930ba, 0x5ba7013b, 0x00000000}},  //   _بالا, _imwa, _трез,
  { {0x2cbf05df, 0x60c901d6, 0x00000000, 0x00000000}},  //   lbud_, _leem,   ,
  { {0x19b510fc, 0x78a901d9, 0xe6430088, 0x00000000}},  //   _احتج, ževa, перп,
  { {0x60c930bb, 0x00000000, 0x00000000, 0x00000000}},  //   _neem,   ,   ,
  { {0x442602d5, 0x66e601ab, 0x00000000, 0x00000000}},  // [9a20] ão_, _лопа,   ,
  { {0x29122ca2, 0xd24f0014, 0x00000000, 0x00000000}},  //   _haya_, کنم_,   ,
  { {0x29120811, 0x60c908ff, 0x6d590009, 0x00000000}},  //   _kaya_, _beem, _omwa,
  { {0xc69300b6, 0x29120169, 0xda7a0049, 0x00000000}},  //   _מאת_, _jaya_, אנער,
  { {0x8ff70054, 0x2912027c, 0xdfcf0379, 0x00000000}},  //   مرور_, _maya_, فين_,
  { {0x291212f4, 0x42530063, 0x6d5900e7, 0x00000000}},  //   _laya_, _کنفر, _amwa,
  { {0x200d0145, 0x00000000, 0x00000000, 0x00000000}},  //   _esei_,   ,   ,
  { {0x29120145, 0x60c900d9, 0xfc460062, 0x00000000}},  //   _naya_, _geem, šími_,
  { {0x6d40169c, 0x00000000, 0x00000000, 0x00000000}},  //   rkma,   ,   ,
  { {0x68ed04b4, 0x6d4000f8, 0x60c900bb, 0x00000000}},  //   _scad, skma, _zeem,
  { {0x8e860025, 0x7c240006, 0x291215dc, 0x00000000}},  //   _الاه, _šird, _baya_,
  { {0xdd8f0025, 0x291201a3, 0x00000000, 0x00000000}},  //   _كول_, _caya_,   ,
  { {0x29120169, 0xf8bf009d, 0xead4054d, 0x00000000}},  //   _daya_, rbé_, _доль,
  { {0x2d8400d9, 0x83030044, 0xf8bf0010, 0x00000000}},  //   llme_, _উচ্চ_, sbé_,
  { {0x2c74026c, 0x29120f65, 0x6d951878, 0x00000000}},  //   _دیکھ_, _faya_, _išar,
  { {0x291230bc, 0x39a50089, 0x657d1617, 0x00000000}},  //   _gaya_, _cēsu_, _qksh,
  { {0x9948057d, 0x60c91261, 0x833500c0, 0x00000000}},  // [9a30] _دليل_, _reem, онах,
  { {0x60c900ab, 0x63ad0d82, 0x2124000a, 0x00000000}},  //   _seem, rqan, _anmh_,
  { {0x39490263, 0xe5350057, 0x29121c39, 0x00000000}},  //   _klas_, _день, _yaya_,
  { {0x0ce30044, 0x657d0023, 0x399b05a0, 0x00000000}},  //   _মস্ত, _uksh, _būsi_,
  { {0x9f9920b5, 0x60c926c7, 0xb4e50963, 0x00000000}},  //   авду_, _veem, नली_,
  { {0x60c90116, 0x8afc0036, 0x2ca600e0, 0x00000000}},  //   _weem, nięd, _agod_,
  { {0x60c90004, 0x394926be, 0x2cbf00f8, 0x00000000}},  //   _teem, _olas_, tbud_,
  { {0x2bd403d7, 0x6d950006, 0x00000000, 0x00000000}},  //   _दिखा, _ašar,   ,
  { {0x2912020c, 0x6fe0007d, 0x2cbf01bf, 0x00000000}},  //   _raya_, _नियं, rbud_,
  { {0x291204be, 0x6d5e00f4, 0x394930bd, 0x00000000}},  //   _saya_, épar, _alas_,
  { {0x7cd9026c, 0x39491625, 0x291201a3, 0x00000000}},  //   _نواز_, _blas_, _paya_,
  { {0x6d5930be, 0x78a90091, 0x394900f8, 0x00000000}},  //   _umwa, ževn, _clas_,
  { {0x29120211, 0x224d00b9, 0x673700d9, 0x00000000}},  //   _vaya_, _řekl_, _boxj,
  { {0x39490181, 0x409a009b, 0xf6260545, 0x00000000}},  //   _elas_, יברס, одго,
  { {0x3949132f, 0x29120058, 0x25a20087, 0x00000000}},  //   _flas_, _taya_, _pikl_,
  { {0x785c0089, 0x67250146, 0x00000000, 0x00000000}},  //   tāvī, _enhj,   ,
  { {0xe57701ff, 0x5eca0044, 0x00000000, 0x00000000}},  // [9a40] ізу_, _রাসে,   ,
  { {0x7c24002a, 0x00000000, 0x00000000, 0x00000000}},  //   _áire,   ,   ,
  { {0x64a6003b, 0xa49b0173, 0x8afc0036, 0x00000000}},  //   _мана, _abòd, sięg,
  { {0x10a60545, 0x00000000, 0x00000000, 0x00000000}},  //   цидн,   ,   ,
  { {0xee0202f4, 0x34a70088, 0x25e6013d, 0x00000000}},  //   लब्ध_, _євро_, जूरी_,
  { {0xcdda025f, 0x5eca0044, 0x00000000, 0x00000000}},  //   ањи_, _রাহে,   ,
  { {0x79460046, 0x1219007e, 0xdd9100a1, 0x00000000}},  //   _równ, _люты_, کوٹ_,
  { {0x387f002b, 0x91030545, 0x7126009e, 0x00000000}},  //   żuri_, _опсе, _برسل,
  { {0xeb06007c, 0x60c200ea, 0x00000000, 0x00000000}},  //   очно, mbom,   ,
  { {0xba54025f, 0x60c2007f, 0x25ba00f6, 0x00000000}},  //   звој, lbom, _otpl_,
  { {0x39490263, 0xb87b00c4, 0xa3ca0061, 0x00000000}},  //   _plas_, ngív, ळीत_,
  { {0x39a401aa, 0x8ba6004d, 0x2ca600e0, 0x00000000}},  //   vèsè_, _дидж, _ugod_,
  { {0xcb6a01f9, 0x39490253, 0xc19b0049, 0x00000000}},  //   _каде_, _vlas_, ישטי,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26da0087, 0xb5950140, 0x00000000, 0x00000000}},  //   _ddpo_, зивш,   ,
  { {0xb4e501f5, 0x39490145, 0x00000000, 0x00000000}},  //   नले_, _ulas_,   ,
  { {0xe87306c6, 0x628e1529, 0x54550ab6, 0x00000000}},  // [9a50] _زندگ, _azbo, чват,
  { {0x2bdd00e8, 0xe8d90082, 0x777c00d4, 0x00000000}},  //   _मिसा, _thỳ_, corx,
  { {0x26d10c8f, 0xd378007e, 0x00000000, 0x00000000}},  //   mazo_, ічу_,   ,
  { {0xdd86025a, 0x26d130bf, 0x60c20058, 0x00000000}},  //   _سو_, lazo_, gbom,
  { {0xf4840888, 0x6fc6007d, 0x00000000, 0x00000000}},  //   _журн, रीलं,   ,
  { {0x26d130c0, 0xdb0b00c4, 0x00000000, 0x00000000}},  //   nazo_, _eugê,   ,
  { {0x5eca0055, 0xd049006b, 0xc33200a3, 0x00000000}},  //   _রাশে, _ənən, _אום_,
  { {0x26d1004a, 0x00000000, 0x00000000, 0x00000000}},  //   hazo_,   ,   ,
  { {0x399b001e, 0x60db1a07, 0x26d130c1, 0x00000000}},  //   _jūsu_, _idum, kazo_,
  { {0x399b001e, 0x26d11caf, 0x7c2400ca, 0x00000000}},  //   _mūsu_, jazo_, _širc,
  { {0xd910026c, 0x26d1008e, 0x98b004eb, 0x00000000}},  //   ہیں_, dazo_, šača_,
  { {0xa96a003b, 0xdb030023, 0x201f0b36, 0x00000000}},  //   сима_, _kinë, _krui_,
  { {0x661e05fa, 0x6d4b0006, 0x7d09006c, 0x00000000}},  //   _srpk, _ilga, mees,
  { {0x26cc02d5, 0x7d0900b0, 0x26d1008e, 0x00000000}},  //   údo_, lees, gazo_,
  { {0xd94626f5, 0x65c6005e, 0x60c2007f, 0x00000000}},  //   _неки, ябва, ybom,
  { {0x7d09021e, 0x2a3a00b6, 0xb33b00c4, 0x00000000}},  //   nees, _לעצמ, _muçu,
  { {0x26d130c2, 0x434600e2, 0x656f25d0, 0x00000000}},  // [9a60] bazo_, пеав, _djch,
  { {0x7d09021e, 0x8afc0036, 0x26d1004a, 0x00000000}},  //   hees, mięc, cazo_,
  { {0x7d0900b0, 0x6d4b01c5, 0xf41f00b0, 0x00000000}},  //   kees, _olga, _erä_,
  { {0xfaf80089, 0x3f87012d, 0x00000000, 0x00000000}},  //   lnīt_, elnu_,   ,
  { {0x8afc0046, 0x98a70091, 0x1b120044, 0x00000000}},  //   nięc, šića_, ়াতে_,
  { {0x6d4b0114, 0x60db010e, 0x22410045, 0x00000000}},  //   _alga, _edum, byhk_,
  { {0x7d090112, 0xb4db0045, 0x290000d9, 0x00000000}},  //   fees, _slài, _obia_,
  { {0x6da301fc, 0x7d090116, 0x5bb8004d, 0x00000000}},  //   нија, gees, олия_,
  { {0x6fb601af, 0x00000000, 0x00000000, 0x00000000}},  //   _رمضا,   ,   ,
  { {0x2900001a, 0xff240014, 0x6d4b0032, 0x00000000}},  //   _abia_, _تبری, _elga,
  { {0xc33300b6, 0x7d091267, 0xf1c30082, 0x00000000}},  //   תות_, bees, _nhớ_,
  { {0x26d10020, 0xdb030173, 0x00000000, 0x00000000}},  //   wazo_, _linè,   ,
  { {0x26d130c3, 0x7c830517, 0x315700a3, 0x00000000}},  //   tazo_, _пуше, ליטן_,
  { {0xd7f81734, 0x00000000, 0x00000000, 0x00000000}},  //   чую_,   ,   ,
  { {0x50cc024c, 0x8afb00b6, 0x26d1231e, 0x00000000}},  //   ाराष, _להגי, razo_,
  { {0xe8d90011, 0x26d11770, 0x69d80066, 0x00000000}},  //   _thự_, sazo_, _ivve,
  { {0x26d1004a, 0xa77501ee, 0x00000000, 0x00000000}},  // [9a70] pazo_, _олич,   ,
  { {0xe9ff0082, 0x290b0036, 0xdb0300f6, 0x00000000}},  //   _hoại_, leca_, _cinè,
  { {0xdb0b01c9, 0x22470010, 0x00000000, 0x00000000}},  //   _utgå, ánk_,   ,
  { {0x2bdd0316, 0x290b1c37, 0xdb0b0f57, 0x00000000}},  //   _मिला, neca_, _eugè,
  { {0xdb1b0219, 0x29d8001d, 0xd25000a1, 0x00000000}},  //   spué, hĩa_, ننے_,
  { {0xe9ff001d, 0x7d0902ae, 0x69d80207, 0x00000000}},  //   _loại_, wees, _ovve,
  { {0x7d09021e, 0x290b0197, 0xed590147, 0x00000000}},  //   tees, keca_, жой_,
  { {0x656d1642, 0x63af0107, 0x0c250153, 0x00000000}},  //   nnah, _kucn, дмин,
  { {0x2bdd001c, 0x69d813f0, 0x7d090052, 0x00000000}},  //   _मिळा, _avve, rees,
  { {0xe9d90517, 0x7d090103, 0x4a450088, 0x00000000}},  //   око_, sees, днов,
  { {0xdb0300b9, 0x63a700b5, 0xdb0b009d, 0x00000000}},  //   _jiné, _mijn, _jugé,
  { {0xdb0330c4, 0x63a700b5, 0x628700e5, 0x00000000}},  //   _miné, _lijn, _myjo,
  { {0x7d56007b, 0x0c25007e, 0xdb03009d, 0x00000000}},  //   _קינד_, _імкн, _liné,
  { {0x63a730c5, 0x4c9a009b, 0x9b450014, 0x00000000}},  //   _nijn, _ובנו, _زنبو,
  { {0x8afc0046, 0x656d084a, 0x00000000, 0x00000000}},  //   sięc, fnah,   ,
  { {0x1987005e, 0x8afc0036, 0x290030c6, 0x00000000}},  //   _общи_, pięc, _ubia_,
  { {0x7984000b, 0x63a700b5, 0x69c130c7, 0x00000000}},  // [9a80] _ikiw, _bijn, lple,
  { {0xdb090211, 0x69c130c8, 0x656d00e7, 0x00000000}},  //   mpeó, ople, anah,
  { {0xdb03028c, 0x69c12e51, 0xb4db00f6, 0x00000000}},  //   _ciné, nple, _alàu,
  { {0x9c820062, 0x20040022, 0xa87a0049, 0x00000000}},  //   íčko, _ppmi_, ֿאַר,
  { {0x63a700b5, 0xb4db00d4, 0x798400e7, 0x00000000}},  //   _fijn, _clàu, _mkiw,
  { {0x290b0107, 0xb5ab00a1, 0xdb0300f6, 0x00000000}},  //   zeca_, _دئیے_, _finé,
  { {0x63af016c, 0x7bcb0066, 0xdb0310c9, 0x00000000}},  //   _zucn, _awgu, _giné,
  { {0x69c130c9, 0x63a700bb, 0x44220471, 0x00000000}},  //   dple, _zijn, _krk_,
  { {0x290b0107, 0x64442552, 0x69c11c2e, 0x00000000}},  //   veca_, nyii, eple,
  { {0x7984000b, 0x5a3400e3, 0x65640883, 0x00000000}},  //   _akiw, енот, hiih,
  { {0x290b06c2, 0x69c130ca, 0xdb0300f6, 0x00000000}},  //   teca_, gple, _xiné,
  { {0x442200f8, 0x4cd600a2, 0x1c4601ee, 0x00000000}},  //   _ork_, _آغاز, _онем,
  { {0xb8d703d7, 0x290b00bb, 0xfc2f006d, 0x00000000}},  //   _जल_, reca_, _نحو_,
  { {0x290b02db, 0x44250161, 0x63af0253, 0x00000000}},  //   seca_, _čl_, _rucn,
  { {0x44320061, 0xd9f2006e, 0x290b30cb, 0x00000000}},  //   exy_, _अमित_, peca_,
  { {0x994401f6, 0x7d020719, 0x3eac0022, 0x00000000}},  //   mış_, _jbos, _lgdt_,
  { {0x63a730cc, 0x656d086d, 0x99440279, 0x00000000}},  // [9a90] _pijn, rnah, lış_,
  { {0x656d127d, 0x44221601, 0xdb0b0ab4, 0x00000000}},  //   snah, _drk_, _pugé,
  { {0x7d0200e5, 0x39920047, 0x99440279, 0x00000000}},  //   _obos, lása_, nış_,
  { {0x63a700b5, 0x44220190, 0x7c221424, 0x00000000}},  //   _wijn, _frk_, _oror,
  { {0x80270054, 0x5ed30044, 0x63bd00ea, 0x00000000}},  //   برام, _সাবে, _utsn,
  { {0x9944014a, 0x69c101d6, 0x39b70035, 0x00000000}},  //   kış_, yple, _lăsa_,
  { {0x753d0c58, 0xc1770879, 0x7c221624, 0x00000000}},  //   _kosz, _قدرت, _aror,
  { {0xa294008b, 0x92940147, 0x7c2202e7, 0x00000000}},  //   _расі, _расц, _bror,
  { {0x7996018e, 0x753d30cd, 0x518402ea, 0x00000000}},  //   _rhyw, _mosz, _рура,
  { {0x7d020016, 0x39920010, 0x69c10007, 0x00000000}},  //   _ebos, dása_, tple,
  { {0x7c2226c4, 0xdcfb00b9, 0x69c101c3, 0x00000000}},  //   _eror, louč, uple,
  { {0x69c100b5, 0x753d108d, 0x00000000, 0x00000000}},  //   rple, _nosz,   ,
  { {0x291e00b9, 0x443200e5, 0xb4db00d4, 0x00000000}},  //   ěta_, xxy_, _llàs,
  { {0xcc3a007b, 0x7d1b0004, 0x79460046, 0x00000000}},  //   _מענט, ldus, _mówi,
  { {0xceb2012f, 0xd040005f, 0xd5b21095, 0x00000000}},  //   ריל_, _demə, افر_,
  { {0x7d1b0004, 0xdb090211, 0x79840d16, 0x00000000}},  //   ndus, mpeñ, _ukiw,
  { {0x0326003b, 0x753d0036, 0x27e625a9, 0x00000000}},  // [9aa0] ндан, _dosz, _íon_,
  { {0x6d49003c, 0x7d190133, 0xe2920025, 0x00000000}},  //   hkea, _laws, هذا_,
  { {0x00e60088, 0xb4db30ce, 0x442201c3, 0x00000000}},  //   ежен, _clàs, _wrk_,
  { {0x61e30047, 0x44220009, 0x6b810090, 0x00000000}},  //   ánla, _trk_, holg,
  { {0x673e25c3, 0x14d700b6, 0xd040006b, 0x00000000}},  //   _kopj, _אוכל_, _yemə,
  { {0x99440180, 0x44200020, 0x00000000, 0x00000000}},  //   yış_, mvi_,   ,
  { {0x9944005f, 0x39920047, 0x6b6600f4, 0x00000000}},  //   xış_, zása_, _légè,
  { {0x78a9037e, 0x7c22016e, 0x4420006c, 0x00000000}},  //   ževi, _pror, ovi_,
  { {0x6b81001f, 0x30760769, 0x442004bd, 0x00000000}},  //   folg, _чувс, nvi_,
  { {0xf063012b, 0x9944005a, 0x442003b6, 0x00000000}},  //   _скуп, tış_, ivi_,
  { {0x4420006c, 0x1b120044, 0x00000000, 0x00000000}},  //   hvi_, ়ালে_,   ,
  { {0x9944027d, 0x39920047, 0x44200119, 0x00000000}},  //   rış_, tása_, kvi_,
  { {0xa49b01aa, 0x6b811e2d, 0x753d30cf, 0x00000000}},  //   _abòn, bolg, _rosz,
  { {0x7d190046, 0x7c2d0521, 0x07a4007e, 0x00000000}},  //   _zaws, _šarg, лаўн,
  { {0x753d0ef6, 0xe61000a1, 0x442030d0, 0x00000000}},  //   _posz, یشہ_, evi_,
  { {0x78ad00e7, 0x6f1a191c, 0x00000000, 0x00000000}},  //   _ugav, _latc,   ,
  { {0x97a7012b, 0xb97c00a0, 0x69da27eb, 0x00000000}},  // [9ab0] _прол, _מנהי, lste,
  { {0x69da00c7, 0x7d1b01ee, 0xb4db30d1, 0x00000000}},  //   oste, zdus, _plàs,
  { {0x6441005f, 0x442021de, 0x00000000, 0x00000000}},  //   _əliy, avi_,   ,
  { {0xf99f01aa, 0x6b810010, 0x291b0066, 0x00000000}},  //   nmè_, zolg, _jaqa_,
  { {0x4420012d, 0x6f1a2f74, 0x69da01a2, 0x00000000}},  //   cvi_, _batc, hste,
  { {0x69da0542, 0x6f1a00ab, 0x7d190271, 0x00000000}},  //   kste, _catc, _saws,
  { {0x6b8130d2, 0x69da30d3, 0x7ed40431, 0x00000000}},  //   volg, jste, ازها,
  { {0x69da1d2f, 0x26d30065, 0x62951da4, 0x00000000}},  //   dste, _lexo_, _izzo,
  { {0x69da04bd, 0x81c30055, 0x6d4930d4, 0x00000000}},  //   este, _এটি_, rkea,
  { {0x69da010f, 0x6d490e38, 0x26d30325, 0x00000000}},  //   fste, skea, _nexo_,
  { {0x2bd10316, 0x28c30204, 0x628b0036, 0x00000000}},  //   _दौरा, _व्हि, ęgow,
  { {0x81c30055, 0x186a004c, 0x8afc0036, 0x00000000}},  //   _এটা_, дами_, wnęt,
  { {0x3959008d, 0x69da0275, 0xdd94008b, 0x00000000}},  //   ërsa_, aste, _сацы,
  { {0x2d8d0275, 0x31660032, 0x00000000, 0x00000000}},  //   llee_, zioz_,   ,
  { {0x291b0a61, 0x9a240379, 0xdce0012d, 0x00000000}},  //   _faqa_, _معين, zimč,
  { {0x442001d9, 0xa2a20316, 0x2d8d2c57, 0x00000000}},  //   tvi_, _कृष्, nlee_,
  { {0xd4670113, 0x7bdb01c2, 0x629530d5, 0x00000000}},  // [9ac0] вите_, nsuu, _azzo,
  { {0x2d8d0061, 0x212d0169, 0x7bdb00b0, 0x00000000}},  //   hlee_, _aneh_, isuu,
  { {0x26d80cd4, 0x2d8d2b48, 0x44200052, 0x00000000}},  //   maro_, klee_, svi_,
  { {0x26d8011c, 0x212d0173, 0x7bdb00b0, 0x00000000}},  //   laro_, _cneh_, ksuu,
  { {0x3940028c, 0x316619e1, 0x2d8d0003, 0x00000000}},  //   _mois_, rioz_, dlee_,
  { {0x26d8180a, 0x394000f4, 0x39520016, 0x00000000}},  //   naro_, _lois_, _llys_,
  { {0x69da0240, 0x2dd70054, 0x216a003b, 0x00000000}},  //   xste, نبية_, _живи_,
  { {0x6f1a0038, 0x39400129, 0x69da0056, 0x00000000}},  //   _watc, _nois_, vste,
  { {0x69da0016, 0x26d80006, 0x315700a0, 0x00000000}},  //   wste, karo_, _סימן_,
  { {0x3940002a, 0x69da1440, 0x26d8008e, 0x00000000}},  //   _aois_, tste, jaro_,
  { {0x394000f4, 0x69da0544, 0x26d80006, 0x00000000}},  //   _bois_, uste, daro_,
  { {0x69da1440, 0x7c2d0209, 0x26d330d6, 0x00000000}},  //   rste, _šare, _sexo_,
  { {0x394030d7, 0x69da001f, 0xdb030181, 0x00000000}},  //   _dois_, sste, _dinâ,
  { {0x26d800f4, 0x7c650318, 0x7bc21139, 0x00000000}},  //   garo_, _حامل, _itou,
  { {0x3940028c, 0x98c7025f, 0x291b002b, 0x00000000}},  //   _fois_, _испл, _taqa_,
  { {0x2d84049a, 0x61fe010f, 0x394000fa, 0x00000000}},  //   nome_, dtpl, _gois_,
  { {0x26d801c5, 0x53991001, 0x7c2400ca, 0x00000000}},  // [9ad0] baro_, евая_, _širj,
  { {0x2d8401a3, 0x61e30010, 0x99520161, 0x00000000}},  //   home_, ánlo, máš_,
  { {0x2d842b24, 0x6d5c010a, 0x02a70888, 0x00000000}},  //   kome_, _įran, трам,
  { {0xe535007c, 0x2d840006, 0x00000000, 0x00000000}},  //   _семь, jome_,   ,
  { {0xb4c10201, 0x2d840089, 0x61fe00d9, 0x00000000}},  //   ुरी_, dome_, atpl,
  { {0x20d1001d, 0x5ed30044, 0xf412009b, 0x00000000}},  //   ại_, _সাহে, _הפך_,
  { {0x7bc203eb, 0xf1a7003b, 0x80d20044, 0x00000000}},  //   _atou, _аран, _হার্,
  { {0x2ee9005f, 0xdb0300c4, 0x2d840091, 0x00000000}},  //   şaf_, _viní, gome_,
  { {0xfc310025, 0x2d8d046a, 0x3940009d, 0x00000000}},  //   صحة_, rlee_, _rois_,
  { {0x394030d8, 0x2d8d0085, 0x26d80032, 0x00000000}},  //   _sois_, slee_, xaro_,
  { {0x394030d9, 0x26d80325, 0x39990010, 0x00000000}},  //   _pois_, varo_, zése_,
  { {0x2d840038, 0x7f410066, 0x26d80045, 0x00000000}},  //   come_, _holq, waro_,
  { {0xeb8e053c, 0x394016c6, 0x26d80211, 0x00000000}},  //   _ги_, _vois_, taro_,
  { {0x7f41002b, 0x00000000, 0x00000000, 0x00000000}},  //   _jolq,   ,   ,
  { {0xa50a005e, 0x26d8064e, 0x25a00173, 0x00000000}},  //   нева_, raro_, tmil_,
  { {0x291e001e, 0x39990047, 0x26d80197, 0x00000000}},  //   ētas_, tése_, saro_,
  { {0x2e17005f, 0x26d800d6, 0x25a030da, 0x00000000}},  // [9ae0] _dəfə_, paro_, rmil_,
  { {0x46f60680, 0xdcf40107, 0x42561020, 0x00000000}},  //   _счит, _čačk, лтет,
  { {0x29d10059, 0x2d84000a, 0xdb0a000a, 0x00000000}},  //   nša_, yome_, _difè,
  { {0xa91b000c, 0xdb0900c4, 0x63140044, 0x00000000}},  //   llþr, mpeõ, সাইট_,
  { {0xe3b200a6, 0x2d8430db, 0x61fe010f, 0x00000000}},  //   _درج_, vome_, stpl,
  { {0x1f73008b, 0x29d12ad6, 0x00000000, 0x00000000}},  //   блія, kša_,   ,
  { {0x5fe002d2, 0x29d11701, 0x06d90044, 0x00000000}},  //   _निकल, jša_, _তামি,
  { {0xe6d10061, 0x00000000, 0x00000000, 0x00000000}},  //   _तज्ज,   ,   ,
  { {0x9b6a00aa, 0x2d8400ab, 0x69c30d90, 0x00000000}},  //   ешна_, rome_, _atne,
  { {0x68e40161, 0x93fb00a3, 0x2d8400ab, 0x00000000}},  //   _adid, עליי, some_,
  { {0x1959045a, 0x4975041f, 0xdb030129, 0x00000000}},  //   ваны_, илос, _dinà,
  { {0x63ae0173, 0x628e01a3, 0x69c30082, 0x00000000}},  //   _libn, _mybo, _dtne,
  { {0x68e40016, 0x69c30197, 0xf7730380, 0x00000000}},  //   _ddid, _etne, ماس_,
  { {0x6d42006c, 0x29d100ca, 0x63ae0066, 0x00000000}},  //   _hooa, bša_, _nibn,
  { {0x3abb00a0, 0x628e1c8c, 0xe5c4005e, 0x00000000}},  //   _אמונ, _nybo, йсто,
  { {0x69c800d4, 0x68e4002b, 0xb4c10316, 0x00000000}},  //   mpde, _gdid, ुरे_,
  { {0x69c80168, 0x2458007c, 0x7afd0521, 0x00000000}},  // [9af0] lpde, гать_, đstv,
  { {0x6e282229, 0x2b99009d, 0x78a9016c, 0x00000000}},  //   _ordb, pèce_, ževs,
  { {0x5ed30055, 0x6db10089, 0xdb0b004a, 0x00000000}},  //   _সালে, _jāat, _jugá,
  { {0xf8bf00f4, 0xdd860025, 0x7ff50688, 0x00000000}},  //   ncé_, _ذو_, لستا,
  { {0x60d90066, 0x00000000, 0x00000000, 0x00000000}},  //   rawm,   ,   ,
  { {0x798600e7, 0x63ae30dc, 0x00000000, 0x00000000}},  //   zokw, _gibn,   ,
  { {0x798600e7, 0x93c60035, 0x7f4130dd, 0x00000000}},  //   yokw, rtăş, _volq,
  { {0xf1a402be, 0x29d110f7, 0x69c300e0, 0x00000000}},  //   _грун, vša_, _rtne,
  { {0x320100ab, 0x6e28010f, 0x1c420147, 0x00000000}},  //   lthy_, _erdb, жным,
  { {0x79860022, 0x3b09003b, 0x00000000, 0x00000000}},  //   wokw, њено_,   ,
  { {0x27e00089, 0x3f87014a, 0x798600e7, 0x00000000}},  //   _svin_, monu_, tokw,
  { {0xb4e402f4, 0xa96a012b, 0xdb030211, 0x00000000}},  //   _नये_, тима_, _diná,
  { {0x2f240010, 0xd7d00061, 0x61e30010, 0x00000000}},  //   ségű_, तींच, ánlj,
  { {0xfaa50c4e, 0x7bc903be, 0x29d1073a, 0x00000000}},  //   _кало, mpeu, pša_,
  { {0x59760783, 0x63ae089f, 0xdb030181, 0x00000000}},  //   _выпу, _ribn, _giná,
  { {0x2c09013d, 0x7c240340, 0xda7a009b, 0x00000000}},  //   _वहां_, _širi, _שנקר,
  { {0x5ee00055, 0x3f870387, 0x3366007e, 0x00000000}},  // [9b00] প্টে, konu_, аваг,
  { {0x3f8701c5, 0xa2e6007c, 0x00000000, 0x00000000}},  //   jonu_, рожд,   ,
  { {0x8afc0036, 0x200d001a, 0x8b560049, 0x00000000}},  //   więk, _apei_, סיעס_,
  { {0xb4db001d, 0x27ed0091, 0x4fc6007e, 0x00000000}},  //   _hoàn, šene_, аска,
  { {0x628e30de, 0x3f87014a, 0x237800fa, 0x00000000}},  //   _wybo, fonu_, _tjrj_,
  { {0x7c24002a, 0x3f87073a, 0x657602e7, 0x00000000}},  //   _áiri, gonu_, lnyh,
  { {0x91e3005e, 0x00000000, 0x00000000, 0x00000000}},  //   _море,   ,   ,
  { {0x2d9d0016, 0x2247010f, 0x65760062, 0x00000000}},  //   _chwe_, änke_, nnyh,
  { {0xef1a00e3, 0xf8bf00f4, 0xa3ca0061, 0x00000000}},  //   _има_, ndée_, ळीच_,
  { {0xd00f0054, 0x3b54026b, 0xda260088, 0x00000000}},  //   _تلك_, скор, аємо,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4c86013b, 0xbc670167, 0xed5900b9, 0x00000000}},  //   _клев, امین_, chž_,
  { {0xdca60098, 0xf8bf009d, 0xdcfb0180, 0x00000000}},  //   _тади, rcé_, lluğ,
  { {0xe78730df, 0x6a4a006b, 0x69c80203, 0x00000000}},  //   румо, vəff, ppde,
  { {0xd5b801e0, 0xdcfb005d, 0xf9c400a6, 0x00000000}},  //   ист_, nluğ, _احتی,
  { {0x4867005e, 0xdce20087, 0x00000000, 0x00000000}},  //   _въоб, _omoč,   ,
  { {0x3f870279, 0x9fe10044, 0x798d0020, 0x00000000}},  // [9b10] yonu_, _মঙ্গ, _ikaw,
  { {0xf2c7007e, 0xdcfb014a, 0x96270089, 0x00000000}},  //   рсан, kluğ, _paņē,
  { {0xd1b80084, 0x877c071c, 0x798d0066, 0x00000000}},  //   لانا_, _באזי, _kkaw,
  { {0xc1050025, 0xe61000a6, 0x320100ab, 0x00000000}},  //   صوتي, _کشی_, rthy_,
  { {0x2cbf006b, 0x656d08a8, 0x798d00e7, 0x00000000}},  //   vcud_, miah, _mkaw,
  { {0x442b00b0, 0x656d023a, 0x6b880107, 0x00000000}},  //   _irc_, liah, jodg,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe678009b, 0x9f46000c, 0x387e001a, 0x00000000}},  //   יתוח_, stoð_, ştri_,
  { {0x442b2a0c, 0x644d0461, 0x63a50051, 0x00000000}},  //   _jrc_, nyai, omhn,
  { {0x798d0020, 0x7bc9110a, 0xdb030288, 0x00000000}},  //   _akaw, rpeu, _minç,
  { {0x39920047, 0x5e950025, 0x63a50051, 0x00000000}},  //   lási_, _الاط, imhn,
  { {0x7bc900f4, 0xe8f70454, 0x6b4d00f6, 0x00000000}},  //   ppeu, блю_, _múgi,
  { {0x4ca50055, 0x442b00bb, 0x656d01a3, 0x00000000}},  //   _গ্রু, _nrc_, diah,
  { {0x798d00e0, 0x6d5b004a, 0x644d0022, 0x00000000}},  //   _ekaw, lhua, dyai,
  { {0xceb2019b, 0xa6e3000c, 0x00000000, 0x00000000}},  //   לים_, íðar,   ,
  { {0x6d5b16b1, 0x00000000, 0x00000000, 0x00000000}},  //   nhua,   ,   ,
  { {0x64a3007e, 0x65760d32, 0xdcfb019a, 0x00000000}},  // [9b20] зата, rnyh, zluğ,
  { {0x39920010, 0x442b0020, 0xf8bf009d, 0x00000000}},  //   dási_, _drc_, rdée_,
  { {0x442b0129, 0xdcfb006b, 0x00000000, 0x00000000}},  //   _erc_, xluğ,   ,
  { {0x00da01f7, 0x10a62015, 0x63a50051, 0x00000000}},  //   ابات_, биен, amhn,
  { {0x5ec90055, 0xfecf0044, 0x6d5b0065, 0x00000000}},  //   _রয়ে, _রাজধ, dhua,
  { {0x212010f7, 0x25ba0087, 0x75240095, 0x00000000}},  //   žih_, _kupl_, ldiz,
  { {0x0ef9008b, 0x7c2b018e, 0xdb0300b0, 0x00000000}},  //   рэчы_, _argr, _minä,
  { {0x2fda007a, 0x75240198, 0x6fb6007a, 0x00000000}},  //   _مورد_, ndiz, _همرا,
  { {0x75240020, 0x60c206b1, 0xe043003b, 0x00000000}},  //   idiz, mcom, _енти,
  { {0x60c200ab, 0x20570049, 0xd00f0644, 0x00000000}},  //   lcom, _הימל_, _سلم_,
  { {0xd91504af, 0x60c20a15, 0x6d5b0051, 0x00000000}},  //   одны, ocom, bhua,
  { {0xf53f0039, 0x6d5b1dec, 0xb4c70061, 0x00000000}},  //   _ihåg_, chua, _उभे_,
  { {0xbfb6001d, 0x286b0517, 0x752430e0, 0x00000000}},  //   _điểm_, урно_, ddiz,
  { {0xac97006d, 0x442b0022, 0x6d4001ee, 0x00000000}},  //   _انها_, _rrc_, ljma,
  { {0x442b0365, 0x26da04cd, 0x39920010, 0x00000000}},  //   _src_, _depo_, zási_,
  { {0x6d400263, 0x6a4a005f, 0x442b01da, 0x00000000}},  //   njma, rəfd, _prc_,
  { {0x60c20009, 0x656d003f, 0xb4b9006e, 0x00000000}},  // [9b30] dcom, riah, _चली_,
  { {0xb87b0285, 0xd25b1123, 0x6d5b0065, 0x00000000}},  //   raíd, лце_, zhua,
  { {0x50b5004c, 0x82150025, 0x442b0471, 0x00000000}},  //   ослу, تواص, _wrc_,
  { {0x39920047, 0xdb0b010f, 0x6d4600b0, 0x00000000}},  //   tási_, _zugä, ökal,
  { {0xd91c0104, 0x442b0035, 0x657d00d9, 0x00000000}},  //   טואל, _urc_, _ijsh,
  { {0x44290311, 0x60c20026, 0xf41f00b0, 0x00000000}},  //   mva_, acom, _isä_,
  { {0x442930e1, 0xe81b007d, 0x6d5b071e, 0x00000000}},  //   lva_, _पैसा_, thua,
  { {0xdb0a1383, 0x60c20207, 0xdd910379, 0x00000000}},  //   _difí, ccom, بوع_,
  { {0x44290232, 0x764e0036, 0x00000000, 0x00000000}},  //   nva_, zyby,   ,
  { {0x7afa001c, 0x6d5b0065, 0x60db0270, 0x00000000}},  //   ggtt, shua, _heum,
  { {0x26da01aa, 0x442901c2, 0xdce90dc6, 0x00000000}},  //   _repo_, hva_, lieč,
  { {0x44290119, 0xdb0300b0, 0x6369006b, 0x00000000}},  //   kva_, _sinä, _dönə,
  { {0x7d0900ea, 0x26da16d8, 0xdce930e2, 0x00000000}},  //   mfes, _pepo_, nieč,
  { {0x44292012, 0x60c20009, 0x5ba70140, 0x00000000}},  //   dva_, zcom, _урез,
  { {0x44290142, 0xd946044b, 0xdce0007f, 0x00000000}},  //   eva_, _меки, simą,
  { {0x27ed0091, 0x7c29068f, 0xdce90006, 0x00000000}},  //   šena_, over, kieč,
  { {0x06d90055, 0x7c2930e3, 0x2b4700ca, 0x00000000}},  // [9b40] _তারি, nver, _konc_,
  { {0x6369006b, 0x75240cc8, 0x2b4702d0, 0x00000000}},  //   _yönə, sdiz, _jonc_,
  { {0x7c292906, 0x8afc0046, 0xe8220309, 0x00000000}},  //   hver, mięt, मिका_,
  { {0x7c29006c, 0x60c200c4, 0xf1a903ec, 0x00000000}},  //   kver, ucom, مانه_,
  { {0x7c292f4a, 0x629c0036, 0x7d090c31, 0x00000000}},  //   jver, _wzro, dfes,
  { {0x60c2029a, 0x6d590038, 0x8afc0036, 0x00000000}},  //   scom, _alwa, nięt,
  { {0x7c2907eb, 0x7d090016, 0x629c0091, 0x00000000}},  //   ever, ffes, _uzro,
  { {0x6da306e3, 0x7c290218, 0x7d092050, 0x00000000}},  //   мија, fver, gfes,
  { {0x7c290007, 0x8b660025, 0x00000000, 0x00000000}},  //   gver, قادم,   ,
  { {0x3f760036, 0x6d5930e4, 0xa3dc0164, 0x00000000}},  //   dług_, _elwa, णीय_,
  { {0x2b47028c, 0x06d90055, 0x44290010, 0x00000000}},  //   _donc_, _তালি, zva_,
  { {0xa9c30088, 0xb4b9006e, 0x4429007f, 0x00000000}},  //   ьськ, _चले_, yva_,
  { {0x200600b0, 0x8b660025, 0x7d7b01ce, 0x00000000}},  //   ntoi_, _واتم, _דראג,
  { {0x2b470087, 0x44290095, 0x81e00044, 0x00000000}},  //   _gonc_, vva_, _দমন_,
  { {0xb4d60316, 0xf41f00b0, 0x356b06f3, 0x00000000}},  //   हरू_, _ssä_, аран_,
  { {0xb87b0181, 0x20060065, 0xe534007e, 0x00000000}},  //   raíb, ktoi_, месь,
  { {0x29190b32, 0x94ab30e5, 0x20060023, 0x00000000}},  // [9b50] mesa_, ртва_, jtoi_,
  { {0x44291c0b, 0x6f1812d6, 0x291911d2, 0x00000000}},  //   rva_, jevc, lesa_,
  { {0x661c001c, 0x559501f9, 0xf7700076, 0x00000000}},  //   cwrk, _наоѓ, _جاي_,
  { {0x7c2905d5, 0xdb1b30e6, 0xa3b60164, 0x00000000}},  //   yver, rqué, _चूक_,
  { {0x67250004, 0x25a930e7, 0xdb1b009d, 0x00000000}},  //   _kahj, mmal_, squé,
  { {0x7c2930e8, 0x39920010, 0x291924e2, 0x00000000}},  //   vver, lást_, hesa_,
  { {0x7c2900bb, 0x2006137a, 0x63bd008a, 0x00000000}},  //   wver, atoi_, _husn,
  { {0x25a9001f, 0x67250bac, 0x63bd096f, 0x00000000}},  //   nmal_, _lahj, _kusn,
  { {0x29190129, 0xc1040054, 0x7c2900f4, 0x00000000}},  //   desa_, _توقي, uver,
  { {0x7d090039, 0x25a9010f, 0x29000197, 0x00000000}},  //   sfes, hmal_, _scia_,
  { {0x291930e9, 0x39490181, 0x2900004a, 0x00000000}},  //   fesa_, _boas_, _pcia_,
  { {0x3949049a, 0x7c292008, 0x291930ea, 0x00000000}},  //   _coas_, pver, gesa_,
  { {0xab290467, 0xdb030142, 0x39920010, 0x00000000}},  //   _гола_, _minú, dást_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ae100b0, 0x29190bbb, 0x63bd010f, 0x00000000}},  //   malt, besa_, _ausn,
  { {0xf9920014, 0x7ae11825, 0x63bd018e, 0x00000000}},  //   _ثبت_, lalt, _busn,
  { {0x29c1001d, 0xf4840014, 0xb4660140, 0x00000000}},  // [9b60] _hóa_, ذاری, чкал,
  { {0x947901ff, 0x62950c95, 0x00000000, 0x00000000}},  //   істу_, _byzo,   ,
  { {0x6360000c, 0xb6bb009b, 0x69c40089, 0x00000000}},  //   _löng, _לציי, _čiek,
  { {0x7ae1001f, 0x63bd0016, 0x80d20044, 0x00000000}},  //   halt, _fusn, _হাঙ্,
  { {0x7ae130eb, 0x63bd0022, 0xf53f00ea, 0x00000000}},  //   kalt, _gusn, _tiår_,
  { {0x20060998, 0x7ae100b0, 0x44220145, 0x00000000}},  //   rtoi_, jalt, _isk_,
  { {0x7ae10dd6, 0x6f180107, 0x2919130b, 0x00000000}},  //   dalt, revc, yesa_,
  { {0x7ae10991, 0x7cf6005d, 0x6f1830ec, 0x00000000}},  //   ealt, dürü, sevc,
  { {0x29190059, 0x7aea00f6, 0x06e20044, 0x00000000}},  //   vesa_, _pdft, _বানি,
  { {0x44220a89, 0x39920010, 0x7ae113ee, 0x00000000}},  //   _msk_, zást_, galt,
  { {0xc333019b, 0x29190207, 0x44270082, 0x00000000}},  //   גות_, tesa_, ̉n_,
  { {0x6360000c, 0x7ae101c2, 0x27f90022, 0x00000000}},  //   _hönd, aalt, tusn_,
  { {0x7ae1022b, 0x6360000c, 0xc7c7053f, 0x00000000}},  //   balt, _göng, ясни,
  { {0x7ae10035, 0x27ed0091, 0x443f002b, 0x00000000}},  //   calt, šeno_, _ħu_,
  { {0x39920047, 0x442200ab, 0x63bd023a, 0x00000000}},  //   tást_, _ask_, _susn,
  { {0x9cfa0044, 0x6360000c, 0x63bd1d1e, 0x00000000}},  //   _আসুন_, _lönd, _pusn,
  { {0x68ed30ed, 0x3f8e0020, 0x1868003b, 0x00000000}},  // [9b70] _idad, kofu_, _наћи_,
  { {0x27e90142, 0x25a9010f, 0x4422013f, 0x00000000}},  //   _ivan_, smal_, _dsk_,
  { {0x29c10011, 0x442210d2, 0x63b501ee, 0x00000000}},  //   _xóa_, _esk_, _vizn,
  { {0x7c22002d, 0x7ae1014a, 0x61e530ee, 0x00000000}},  //   _osor, zalt, rshl,
  { {0xe134008b, 0x442204d2, 0x6360074d, 0x00000000}},  //   энцы, _gsk_, _bönd,
  { {0x7d0212b2, 0x3f8e00e7, 0x00000000, 0x00000000}},  //   _acos, gofu_,   ,
  { {0x7ae100b0, 0x636030ef, 0x68ed0095, 0x00000000}},  //   valt, _söng, _odad,
  { {0xe7ee03d7, 0x301503f3, 0x27e90039, 0x00000000}},  //   _जिला_, _одбр, _ovan_,
  { {0x7ae1001f, 0x60c9004a, 0x00000000, 0x00000000}},  //   talt, _ifem,   ,
  { {0x636001f6, 0x7d0201a3, 0x7cf60180, 0x00000000}},  //   _gönd, _ecos, türü,
  { {0x27e90263, 0x7c220207, 0x09bd0044, 0x00000000}},  //   _avan_, _esor, _আবহা,
  { {0x7ae104bd, 0x7d020051, 0x7cf60276, 0x00000000}},  //   salt, _gcos, rürü,
  { {0xb8d60061, 0x7ae10207, 0x68ed0016, 0x00000000}},  //   _जण_, palt, _ddad,
  { {0x6d4b0211, 0x7d1b03a4, 0x68ed04de, 0x00000000}},  //   _hoga, leus, _edad,
  { {0xab2801f7, 0x6d4b00ca, 0xdb1b30f0, 0x00000000}},  //   _رسول_, _koga, nquí,
  { {0x6d4b02d5, 0xe5a301be, 0x7d1b1684, 0x00000000}},  //   _joga, виси, neus,
  { {0x9f5f095e, 0x6d4b0119, 0x63600039, 0x00000000}},  // [9b80] _aquí_, _moga, _löne,
  { {0x44222313, 0x60c9004a, 0x656f0087, 0x00000000}},  //   _vsk_, _afem, _emch,
  { {0xc7b3012f, 0xc87f010f, 0x6d4b0cb9, 0x00000000}},  //   _שבת_, raße_, _ooga,
  { {0x6d4b0501, 0x63600039, 0x4422066b, 0x00000000}},  //   _noga, _sönd, _tsk_,
  { {0xd0100151, 0x3f8e2c06, 0x801a1880, 0x00000000}},  //   الت_, tofu_, تزاز_,
  { {0x4420000b, 0x7d0207ae, 0x9cfa0044, 0x00000000}},  //   mwi_, _scos, _আসেন_,
  { {0x656f018e, 0x44200016, 0x2cb3006b, 0x00000000}},  //   _ymch, lwi_, əbdə_,
  { {0x6360011f, 0x6d4b0051, 0x7d1b164e, 0x00000000}},  //   _döne, _coga, geus,
  { {0x6d4b0213, 0x44200016, 0x3f8e00e7, 0x00000000}},  //   _doga, nwi_, pofu_,
  { {0x2912000a, 0x6b4d0048, 0x7e56173a, 0x00000000}},  //   _abya_, _súgr, _отец,
  { {0x6d4b30f1, 0xad620011, 0x7d270039, 0x00000000}},  //   _foga, _đươn, örsä,
  { {0x6d4b1141, 0x7d1b009d, 0x442000e7, 0x00000000}},  //   _goga, ceus, kwi_,
  { {0xf7730426, 0xab2a005e, 0x442030f2, 0x00000000}},  //   ناس_, _мода_, jwi_,
  { {0x6360011f, 0x442030f3, 0xc0530049, 0x00000000}},  //   _yöne, dwi_, דזש_,
  { {0x6d4b00f8, 0x2bdf0061, 0xb87b0285, 0x00000000}},  //   _yoga, पीठा, caín,
  { {0x68ed2062, 0x06e20044, 0x7c2d0738, 0x00000000}},  //   _udad, _বাণি, _šari,
  { {0xb87b002a, 0xf9940104, 0x2d5800f4, 0x00000000}},  // [9b90] maío, _ברק_, _réel_,
  { {0xb87b002a, 0x25090167, 0x39990010, 0x00000000}},  //   laío, _کردی_, dési_,
  { {0x2fcd192d, 0x7d1b009d, 0x50f50ab6, 0x00000000}},  //   _steg_, yeus, езет,
  { {0xb87b002a, 0x02a402e9, 0x00000000, 0x00000000}},  //   naío, трум,   ,
  { {0x6d4b1bc1, 0x06e20044, 0x7d1b009d, 0x00000000}},  //   _roga, _বাতি, veus,
  { {0x6d4b010f, 0xb87b0051, 0xeaa600a1, 0x00000000}},  //   _soga, haío, _مٹ_,
  { {0x7d1b30f4, 0x3eb300f8, 0xed5901ab, 0x00000000}},  //   teus, äxt_, зой_,
  { {0xdb1b0841, 0x0c251281, 0x80d90044, 0x00000000}},  //   rquí, емин, _ডাক্,
  { {0x6d4b049a, 0x7d1b00f4, 0xb87b0051, 0x00000000}},  //   _voga, reus, daío,
  { {0x4a45017a, 0x6d4b000a, 0x7d1b0068, 0x00000000}},  //   енов, _woga, seus,
  { {0x6d4b01e5, 0x44200036, 0xa3e6013d, 0x00000000}},  //   _toga, zwi_, _यौन_,
  { {0x2904010e, 0xb87b0048, 0x442007c0, 0x00000000}},  //   üma_, gaío, ywi_,
  { {0xf1b90209, 0x2bb80204, 0x31560049, 0x00000000}},  //   _miš_, _उंचा, גירן_,
  { {0x636001a2, 0xa9240006, 0x00000000, 0x00000000}},  //   _mönc, _ąžuo,   ,
  { {0x6996013b, 0xba520025, 0x39990010, 0x00000000}},  //   _прих, _منوع, zési_,
  { {0xb87b002a, 0x442001aa, 0x25b90197, 0x00000000}},  //   caío, twi_, _cisl_,
  { {0x25b90022, 0x44200058, 0x00000000, 0x00000000}},  // [9ba0] _disl_, uwi_,   ,
  { {0x78a40107, 0x442007c0, 0x1423007e, 0x00000000}},  //   _iziv, rwi_, ыдум,
  { {0xa2a50365, 0x26d802d5, 0x44200697, 0x00000000}},  //   _करण्, mbro_, swi_,
  { {0x290210b6, 0x39990047, 0x4420065e, 0x00000000}},  //   ngka_, tési_, pwi_,
  { {0x26d8016c, 0xc0e70025, 0x00000000, 0x00000000}},  //   obro_, رفون_,   ,
  { {0x80d0007d, 0x00000000, 0x00000000, 0x00000000}},  //   _ड्रे,   ,   ,
  { {0x6383005e, 0xdb030051, 0x39990010, 0x00000000}},  //   _сгра, _ghné, sési_,
  { {0x78a4041a, 0xd00a0888, 0x7dc7006b, 0x00000000}},  //   _oziv, _небе_, _qısa,
  { {0x9f8601e1, 0xfbcf00a6, 0xfd660082, 0x00000000}},  //   _згад, یتی_, _khuế,
  { {0x5a3401f9, 0x00000000, 0x00000000, 0x00000000}},  //   внот,   ,   ,
  { {0xb87b002a, 0x61fe1de7, 0xa49b00f6, 0x00000000}},  //   taío, nupl, _acòl,
  { {0x645a013f, 0x00000000, 0x00000000, 0x00000000}},  //   _ətir,   ,   ,
  { {0x6b9a001c, 0xdd8f023c, 0xb87b002a, 0x00000000}},  //   pltg, _اون_, raío,
  { {0x61fe30f5, 0xb87b002a, 0x78a41b05, 0x00000000}},  //   kupl, saío, _dziv,
  { {0xdb0300b9, 0xb9070044, 0x61fe0089, 0x00000000}},  //   _jiný, _পা_, jupl,
  { {0xba9b00b6, 0x6564006a, 0x1a9b009b, 0x00000000}},  //   _מסוי, ghih, _מיוע,
  { {0x24f8007e, 0x26d80197, 0x61fe01c3, 0x00000000}},  // [9bb0] энты_, bbro_, eupl,
  { {0xd6db0057, 0x4735142c, 0xb87b00fa, 0x00000000}},  //   _эти_, _рнос, naím,
  { {0xa4d9041f, 0x81c90044, 0x78a4012d, 0x00000000}},  //   _одну_, লীন_, _zziv,
  { {0x60b5039d, 0x00000000, 0x00000000, 0x00000000}},  //   نمائ,   ,   ,
  { {0xdb1800c4, 0x753d30f6, 0x00000000, 0x00000000}},  //   _vivê, _insz,   ,
  { {0x21290e0d, 0x8f6a00a1, 0x00000000, 0x00000000}},  //   žah_, ولنے_,   ,
  { {0x61fe0035, 0x00000000, 0x00000000, 0x00000000}},  //   cupl,   ,   ,
  { {0x6a4a006b, 0x69c70428, 0x00000000, 0x00000000}},  //   rəfl, íjem,   ,
  { {0x752d0032, 0xdb180173, 0x00000000, 0x00000000}},  //   idaz, _kivè,   ,
  { {0x799d010f, 0x999f007f, 0x79962c42, 0x00000000}},  //   elsw, kytų_, _skyw,
  { {0x68e60760, 0xc3320104, 0x78a40010, 0x00000000}},  //   takd, בוי_, _sziv,
  { {0x999f0006, 0x4ad1007d, 0x00000000, 0x00000000}},  //   dytų_, _द्रव,   ,
  { {0xf1b2061e, 0x8b2500a5, 0x636000f8, 0x00000000}},  //   יסט_, _адле, _löna,
  { {0x06e20044, 0x29050010, 0x6d5b0f45, 0x00000000}},  //   _বাহি, őlap_, lkua,
  { {0x26d80193, 0x7ae30c4b, 0x6606005e, 0x00000000}},  //   rbro_, _ient, ъпва,
  { {0x7ae30292, 0x26d80058, 0x6d4900e5, 0x00000000}},  //   _hent, sbro_, njea,
  { {0xc95300b6, 0x78a4041a, 0x69c3001a, 0x00000000}},  // [9bc0] _כמה_, _uziv, _hune,
  { {0x68e400b0, 0xd7fb01f8, 0x61fe0209, 0x00000000}},  //   _heid, _קהיל, tupl,
  { {0xdb1801aa, 0x2cb1013e, 0x68e40943, 0x00000000}},  //   _divè, ězdy_, _keid,
  { {0x7ae3042c, 0x61fe0066, 0xb295003b, 0x00000000}},  //   _lent, rupl, ујућ,
  { {0x69c30e1d, 0xdb0b30f7, 0x68e400b0, 0x00000000}},  //   _lune, _bugü, _meid,
  { {0x7ae30715, 0x27e001aa, 0x39990010, 0x00000000}},  //   _nent, _mwin_, lést_,
  { {0x91e30230, 0x69c3061c, 0x4432013e, 0x00000000}},  //   _восе, _nune, lvy_,
  { {0x68e40016, 0x27ed1adc, 0xdce9014a, 0x00000000}},  //   _neid, šeni_, rneğ,
  { {0x7ae30149, 0xe7bd0044, 0xc00602dc, 0x00000000}},  //   _bent, _অব্য, _шпак,
  { {0x7ae30d46, 0x69c327a9, 0xdb180010, 0x00000000}},  //   _cent, _bune, _kivé,
  { {0x68e40a48, 0x63bc11cc, 0x69c30207, 0x00000000}},  //   _beid, _mirn, _cune,
  { {0x629c30f8, 0x7ae30250, 0x68e40016, 0x00000000}},  //   _myro, _eent, _ceid,
  { {0x7ae3119e, 0x60cd008e, 0x39990010, 0x00000000}},  //   _fent, ñami, dést_,
  { {0x63bc11cb, 0x629c00e0, 0x999f0006, 0x00000000}},  //   _nirn, _oyro, tytų_,
  { {0x68e4002a, 0x69c3022b, 0x31660047, 0x00000000}},  //   _feid, _gune, khoz_,
  { {0x7ae308a0, 0x8ab7009b, 0xd944012b, 0x00000000}},  //   _zent, _בלוג_, _већи,
  { {0x63bc2967, 0xe454007e, 0x69c3010f, 0x00000000}},  // [9bd0] _birn, акты, _zune,
  { {0x7ae3027b, 0x629c094f, 0x7ae81222, 0x00000000}},  //   _xent, _byro, nadt,
  { {0x6d5b0023, 0x63bc04eb, 0xdb1800d4, 0x00000000}},  //   ykua, _dirn, _vivè,
  { {0xf99f0173, 0x61ee00f6, 0xe4a7004d, 0x00000000}},  //   nlè_, _dvbl, _арго,
  { {0xb4fa0452, 0xe0d80088, 0x629c009d, 0x00000000}},  //   _אפרי, тві_, _eyro,
  { {0x6360000c, 0x63bc30f9, 0xdb0300f6, 0x00000000}},  //   _hönn, _girn, _linò,
  { {0x636030fa, 0x6f080061, 0x60c40006, 0x00000000}},  //   _könn, _dcdc, žima,
  { {0x69c30056, 0x63600010, 0x63bc30fb, 0x00000000}},  //   _rune, _jönn, _zirn,
  { {0x7ae31305, 0x6d5b30fc, 0x69c324b7, 0x00000000}},  //   _pent, rkua, _sune,
  { {0xe9d901fb, 0x69c330fd, 0x6d5b0ab3, 0x00000000}},  //   нко_, _pune, skua,
  { {0x7ae31ff4, 0xc332007b, 0x68e430fe, 0x00000000}},  //   _vent, זוי_, _peid,
  { {0xf99f01aa, 0x290906c2, 0x7ae30036, 0x00000000}},  //   glè_, _ccaa_, _went,
  { {0x68e430ff, 0x39990f49, 0xe9e90142, 0x00000000}},  //   _veid, vést_, dnúť_,
  { {0xa875007c, 0x68e401a2, 0x2d9f3100, 0x00000000}},  //   рующ, _weid, llue_,
  { {0x68e40ba2, 0x39990010, 0x2bdf013d, 0x00000000}},  //   _teid, tést_, पीरा,
  { {0x63bc0066, 0x09060077, 0x27e03101, 0x00000000}},  //   _sirn, _спин, _twin_,
  { {0xd4670589, 0x39402bab, 0x15b9007e, 0x00000000}},  // [9be0] гите_, _inis_, тыры_,
  { {0x443201ca, 0x629c0471, 0x8726007c, 0x00000000}},  //   rvy_, _pyro, _смож,
  { {0x31660010, 0x00000000, 0x00000000, 0x00000000}},  //   thoz_,   ,   ,
  { {0x629c01ca, 0x636001a2, 0x98a50036, 0x00000000}},  //   _vyro, _gönn, ślą_,
  { {0x63bc2db6, 0x629c0036, 0xdfcf0025, 0x00000000}},  //   _tirn, _wyro, كين_,
  { {0x31660047, 0x8f341662, 0x61ee001b, 0x00000000}},  //   shoz_, рекц, _tvbl,
  { {0x2ee501d6, 0x2d9f03e2, 0x3940014f, 0x00000000}},  //   _delf_, flue_, _onis_,
  { {0x5d54026b, 0xf1aa0014, 0x21763102, 0x00000000}},  //   ркит, _سازه_, _сугр,
  { {0x21670441, 0x7ae801a2, 0x7153023c, 0x00000000}},  //   _сити_, tadt, _انقض,
  { {0x96d40164, 0x2d9f1570, 0x9b5801f9, 0x00000000}},  //   _ब्लॉ, alue_, тиот_,
  { {0x2d9f0061, 0xdb030051, 0x7ae810fa, 0x00000000}},  //   blue_, _ghní, radt,
  { {0x2ee502ae, 0x02b70049, 0x2d9f009d, 0x00000000}},  //   _zelf_, טליך_, clue_,
  { {0x8d930054, 0xec3400a6, 0x9c570014, 0x00000000}},  //   _النش, _خوشگ, _مجوز_,
  { {0x6360000c, 0x394006e6, 0x00000000, 0x00000000}},  //   _sönn, _enis_,   ,
  { {0x58d50265, 0x8b9b08cd, 0x39400146, 0x00000000}},  //   _койт, _רבות, _fnis_,
  { {0x58390ae0, 0xb4d50242, 0x23630022, 0x00000000}},  //   _азия_, ржащ, _sljj_,
  { {0x80cd0044, 0xa9bc009b, 0xe8d8009b, 0x00000000}},  // [9bf0] ারম্, _אזהר, _עוזר_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x77ba009b, 0x93880140, 0x82a701ab, 0x00000000}},  //   _שמתח, уста_, ушае,
  { {0x2ee53103, 0x27ed04eb, 0x90e701fa, 0x00000000}},  //   _self_, šenu_, اسان,
  { {0x50451b15, 0x6360013f, 0x00000000, 0x00000000}},  //   релб, _könl,   ,
  { {0x80d5013d, 0x442b00b4, 0x44392a24, 0x00000000}},  //   _ड्रइ, _isc_, _irs_,
  { {0xf1a7025f, 0x44390211, 0x752f0036, 0x00000000}},  //   _бран, _hrs_, _kacz,
  { {0x52840025, 0x44390036, 0x442b3104, 0x00000000}},  //   _الفك, _krs_, _ksc_,
  { {0x506708fd, 0x2ee5002b, 0xab6502b0, 0x00000000}},  //   _ства, _telf_, ивил,
  { {0xce6b0517, 0x442b04cb, 0xb87b00c4, 0x00000000}},  //   _пред_, _msc_, ibíd,
  { {0x442b06ed, 0x44390ed0, 0xd94600e2, 0x00000000}},  //   _lsc_, _lrs_, аени,
  { {0xc7a90097, 0x44390145, 0x752f0036, 0x00000000}},  //   _חב_, _ors_, _nacz,
  { {0x7db40070, 0x44390ffb, 0x8d5a0097, 0x00000000}},  //   _اصلا, _nrs_, _שכני,
  { {0x7c2b04a5, 0x00000000, 0x00000000, 0x00000000}},  //   _isgr,   ,   ,
  { {0x44392509, 0x442b006b, 0x395200ab, 0x00000000}},  //   _ars_, _asc_, _toys_,
  { {0x394000f4, 0xbdfa0044, 0x00000000, 0x00000000}},  //   _unis_, _আহমদ_,   ,

  { {0x442b0161, 0x25b201c3, 0x00000000, 0x00000000}},  // [9c00] _csc_, rmyl_,   ,
  { {0x4439023a, 0x25a00059, 0x6360014a, 0x00000000}},  //   _drs_, slil_, _gönl,
  { {0x4439018e, 0xe5a601fb, 0x35a602dc, 0x00000000}},  //   _ers_, _вини, _ванг,
  { {0x442b0145, 0x00000000, 0x00000000, 0x00000000}},  //   _fsc_,   ,   ,
  { {0x33d50ee0, 0x6a4a005f, 0x636001df, 0x00000000}},  //   _гіст, rəfi, _yönl,
  { {0x752f0046, 0x75243105, 0x65660022, 0x00000000}},  //   _zacz, leiz, _hlkh,
  { {0x69c10164, 0x224703a9, 0x69ca0204, 0x00000000}},  //   _रंगी, änkt_, _संधी,
  { {0x23720036, 0x4439066d, 0x00000000, 0x00000000}},  //   żają_, _yrs_,   ,
  { {0x442b0009, 0x8c430184, 0x9959013e, 0x00000000}},  //   _xsc_, жење, též_,
  { {0x69ca0164, 0x7524010f, 0x65680023, 0x00000000}},  //   _संदी, heiz, ëdhj,
  { {0x7c2b0efe, 0x19590783, 0xeb9700e2, 0x00000000}},  //   _esgr, ганы_, риќ_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb8cf03d7, 0x68f6018e, 0x752f0036, 0x00000000}},  //   _कर_, _ddyd, _racz,
  { {0x0b9305f3, 0x44391275, 0x661e0022, 0x00000000}},  //   _وجود, _rrs_, _bppk,
  { {0x442b0082, 0x752f0036, 0x99420036, 0x00000000}},  //   _ssc_, _pacz, _dół_,
  { {0x81c408b7, 0x442b0129, 0x7c2b018e, 0x00000000}},  //   _এবং_, _psc_, _ysgr,
  { {0x61fe0112, 0x69da0e5e, 0x291b0066, 0x00000000}},  // [9c10] erpl, lpte, _ibqa_,
  { {0x34a703d7, 0xdb0a0051, 0x442b007f, 0x00000000}},  //   _खरीद, _bhfé, _vsc_,
  { {0x6d42001a, 0x00000000, 0x00000000, 0x00000000}},  //   _onoa,   ,   ,
  { {0xdd860063, 0x442b0061, 0x4439008a, 0x00000000}},  //   _رو_, _tsc_, _trs_,
  { {0x442b027b, 0x44390de1, 0xf7700014, 0x00000000}},  //   _usc_, _urs_, _رای_,
  { {0x44291e5d, 0xf8bf0010, 0xf1c90025, 0x00000000}},  //   mwa_, ldés_, _موسى_,
  { {0x44290263, 0x628e21b3, 0x61fe0166, 0x00000000}},  //   lwa_, _gxbo, crpl,
  { {0xf8bf3106, 0x98a50036, 0x44290036, 0x00000000}},  //   ndés_, ślę_, owa_,
  { {0x44290263, 0xdd2f00b9, 0xeb9910f2, 0x00000000}},  //   nwa_, _těžk, лии_,
  { {0x44290020, 0x201f0288, 0x00000000, 0x00000000}},  //   iwa_, _ipui_,   ,
  { {0x44290390, 0x81c90044, 0xdb030048, 0x00000000}},  //   hwa_, লীর_, _chná,
  { {0x44290518, 0xce6800d7, 0x00000000, 0x00000000}},  //   kwa_, _труд_,   ,
  { {0xa2e80055, 0x7d093107, 0x44290244, 0x00000000}},  //   _পাসও, mges, jwa_,
  { {0x7d093108, 0x7c29063c, 0x59cf02fb, 0x00000000}},  //   lges, mwer, _संपर,
  { {0x7c290168, 0xdb030051, 0x75240c33, 0x00000000}},  //   lwer, _ghná, teiz,
  { {0x442901aa, 0x16a8007d, 0x00000000, 0x00000000}},  //   fwa_, _गरीब,   ,
  { {0x7c2907eb, 0x75240f21, 0x44290020, 0x00000000}},  // [9c20] nwer, reiz, gwa_,
  { {0x06e20055, 0x61fe0bf8, 0x7d0901a2, 0x00000000}},  //   _বাকি, trpl, hges,
  { {0x7c29001f, 0xe1fa0931, 0xb9c10279, 0x00000000}},  //   hwer, уге_, _üçün,
  { {0x44291e5d, 0x7c290112, 0x7d0900bb, 0x00000000}},  //   bwa_, kwer, jges,
  { {0x7bcf3109, 0x63600039, 0x442922b1, 0x00000000}},  //   ícul, _jönk, cwa_,
  { {0x69da0056, 0x7c29310a, 0x7d0901d6, 0x00000000}},  //   ypte, dwer, eges,
  { {0xdef9008b, 0x7c2900bb, 0x7d09010f, 0x00000000}},  //   рыі_, ewer, fges,
  { {0x7c29063c, 0x7d090038, 0xdd90004b, 0x00000000}},  //   fwer, gges, بوب_,
  { {0x80660242, 0x7c291225, 0xb87b0051, 0x00000000}},  //   _уваж, gwer, naít,
  { {0x261903d7, 0x6e3c0e7c, 0xf8bf0010, 0x00000000}},  //   _पहली_, _árbo, zdés_,
  { {0x4429310b, 0x6e960025, 0xdb01009d, 0x00000000}},  //   zwa_, _الضا, illè,
  { {0xd90f06c6, 0x7c290343, 0x44290036, 0x00000000}},  //   ریخ_, bwer, ywa_,
  { {0x34a70061, 0x7c2900d9, 0x00000000, 0x00000000}},  //   _खरेद, cwer,   ,
  { {0x44290263, 0x69da0056, 0xd7f8007c, 0x00000000}},  //   vwa_, ppte, щую_,
  { {0x442901d5, 0x7aea001a, 0x4b7b08cd, 0x00000000}},  //   wwa_, _ieft, _תאוו,
  { {0x44290c28, 0x7aea0304, 0x46d9007d, 0x00000000}},  //   twa_, _heft, _ब्रह,
  { {0xf8bf0047, 0x69ca1e28, 0x3f870016, 0x00000000}},  // [9c30] rdés_, _hufe, ynnu_,
  { {0x4429310c, 0x7aea0091, 0xe2f90088, 0x00000000}},  //   rwa_, _jeft, режі_,
  { {0x44290390, 0x7d090007, 0x201f001a, 0x00000000}},  //   swa_, yges, _spui_,
  { {0x4429310d, 0x3f9e0089, 0xe70500a6, 0x00000000}},  //   pwa_, _aktu_, _اسکی,
  { {0x7c2900d9, 0x00000000, 0x00000000, 0x00000000}},  //   xwer,   ,   ,
  { {0x7aea005f, 0x555200a1, 0x00000000, 0x00000000}},  //   _neft, _ٹھہر,   ,
  { {0x7d090506, 0xc33200a0, 0x7c290112, 0x00000000}},  //   tges, _קול_, wwer,
  { {0x7c2902ae, 0xed5909de, 0x78ad00ca, 0x00000000}},  //   twer, рои_, _ozav,
  { {0x7d09001f, 0x69d8030b, 0x69ca2aca, 0x00000000}},  //   rges, _atve, _aufe,
  { {0x7c2902ae, 0x7d09258a, 0x7aea01ee, 0x00000000}},  //   rwer, sges, _ceft,
  { {0xdce2037e, 0x7c2900ab, 0x7aea014a, 0x00000000}},  //   _zloč, swer, _deft,
  { {0x7bdb00b0, 0xdb01009d, 0xac19310e, 0x00000000}},  //   ppuu, illé, _воду_,
  { {0x6b9a049a, 0x798d0022, 0xb87b0325, 0x00000000}},  //   botg, _djaw, daís,
  { {0xe73a012b, 0xdb0a00f6, 0x78ad012d, 0x00000000}},  //   шег_, _difó, _dzav,
  { {0x7bcb114f, 0x7bc30058, 0x857a00e2, 0x00000000}},  //   _hugu, _iinu, асат_,
  { {0x656d006a, 0x7bc3310f, 0x7bcb14a5, 0x00000000}},  //   ghah, _hinu, _kugu,
  { {0x64a322bb, 0x7bcb3110, 0x7bc3011c, 0x00000000}},  // [9c40] дата, _jugu, _kinu,
  { {0x7bcb0089, 0xdb180047, 0x6360010f, 0x00000000}},  //   _mugu, _kivá, _köni,
  { {0x7bcb006c, 0xb87b0048, 0x24960006, 0x00000000}},  //   _lugu, saít, _žemę_,
  { {0xdce2016e, 0x5a0c0049, 0x02aa013d, 0x00000000}},  //   _ploč, רלאַ, _करीन,
  { {0x2eee002b, 0x644b006c, 0x00000000, 0x00000000}},  //   taff_, ägit,   ,
  { {0x44220093, 0x7bc300e0, 0x00000000, 0x00000000}},  //   _ipk_, _ninu,   ,
  { {0x2eee3111, 0xdbd10181, 0x442201b1, 0x00000000}},  //   raff_, qüên, _hpk_,
  { {0x7bc30004, 0x4422023a, 0x69ca2a9d, 0x00000000}},  //   _ainu, _kpk_, _rufe,
  { {0xa2be0183, 0x7bc3011c, 0x69ca001a, 0x00000000}},  //   _वृत्, _binu, _sufe,
  { {0x7bcb022b, 0xb4db0129, 0x442222df, 0x00000000}},  //   _dugu, _anàl, _mpk_,
  { {0x78ad0047, 0x7bc30058, 0x7aea000c, 0x00000000}},  //   _szav, _dinu, _veft,
  { {0x7bc3009f, 0xdb0300c4, 0xdb180161, 0x00000000}},  //   _einu, _sinô, _divá,
  { {0x7bcb033b, 0x644010ec, 0x7bc3113d, 0x00000000}},  //   _gugu, _šmin, _finu,
  { {0x3f9c037e, 0x7bc3011c, 0x7c220ab2, 0x00000000}},  //   novu_, _ginu, _ipor,
  { {0x69d83112, 0x95cb2015, 0x442200bb, 0x00000000}},  //   _utve, руга_, _apk_,
  { {0x44223113, 0x3f9c0091, 0x7bc3007f, 0x00000000}},  //   _bpk_, hovu_, _zinu,
  { {0x78ad01ca, 0xb87b0489, 0x3f9c0523, 0x00000000}},  // [9c50] _uzav, raís, kovu_,
  { {0x656d000b, 0x68ed167c, 0x7c2202c0, 0x00000000}},  //   shah, _head, _mpor,
  { {0x68ed027e, 0xa2be006e, 0x3f9c0253, 0x00000000}},  //   _kead, _वृद्, dovu_,
  { {0x27e90727, 0x442201c3, 0x41740014, 0x00000000}},  //   _kwan_, _fpk_, وانس,
  { {0xd6bd0055, 0xb97c0049, 0x44220145, 0x00000000}},  //   _অভিয, סנדי, _gpk_,
  { {0xdfce0b59, 0x68ed0038, 0x3f9c0091, 0x00000000}},  //   ديو_, _lead, govu_,
  { {0x7c220779, 0x7bc30207, 0x7bcb006c, 0x00000000}},  //   _apor, _rinu, _sugu,
  { {0x7bcb0129, 0x7bc33114, 0x44223115, 0x00000000}},  //   _pugu, _sinu, _ypk_,
  { {0x7bc3006a, 0x3f9c016e, 0x9c22007c, 0x00000000}},  //   _pinu, bovu_, едыд,
  { {0x59cf0309, 0x3b09003b, 0x7c220087, 0x00000000}},  //   _संदर, љено_, _dpor,
  { {0x68ed1775, 0x7bc33116, 0x27e9003f, 0x00000000}},  //   _bead, _vinu, _awan_,
  { {0xbea8007a, 0x68ed002a, 0x27e900e0, 0x00000000}},  //   _بهمن_, _cead, _bwan_,
  { {0x7bc33117, 0x8d74007a, 0x69c4006c, 0x00000000}},  //   _tinu, _تالا, _viie,
  { {0x81e10055, 0x7d1b0009, 0x27e91560, 0x00000000}},  //   _দিন_, lfus, _dwan_,
  { {0x68ed002a, 0x27e9011c, 0x6d590036, 0x00000000}},  //   _fead, _ewan_, _kowa,
  { {0x3f9c0107, 0x60c90093, 0x68ed00d9, 0x00000000}},  //   zovu_, _ngem, _gead,
  { {0x29120009, 0x27e93118, 0x3f9c0ea6, 0x00000000}},  // [9c60] _icya_, _gwan_, yovu_,
  { {0x083b00b6, 0x6d590020, 0x44221e89, 0x00000000}},  //   _פעיל, _lowa, _vpk_,
  { {0xb6a300f4, 0xa75b009b, 0xdcfb012d, 0x00000000}},  //   éâtr, _הדיר, cnuć,
  { {0x69ce027b, 0x4fc60818, 0x6d590036, 0x00000000}},  //   íbei, пска, _nowa,
  { {0x3f9c0107, 0x8fa61663, 0xdbd10129, 0x00000000}},  //   tovu_, паде, qüèn,
  { {0x60c9014a, 0x00000000, 0x00000000, 0x00000000}},  //   _egem,   ,   ,
  { {0x7c2217fd, 0x7d1b3119, 0x2cc1005f, 0x00000000}},  //   _spor, ffus, ərdə_,
  { {0x3f9c037e, 0x6b81002a, 0x7d780025, 0x00000000}},  //   sovu_, eilg, تمبر_,
  { {0x68ed0038, 0x205500ed, 0x6d590e15, 0x00000000}},  //   _read, _отфр, _dowa,
  { {0x68ed0004, 0x27e90246, 0x3ea500ea, 0x00000000}},  //   _sead, _rwan_, _fylt_,
  { {0x68ed1e85, 0x6d590145, 0x799d311a, 0x00000000}},  //   _pead, _fowa, tosw,
  { {0x27e901aa, 0x4d7609b9, 0x00000000, 0x00000000}},  //   _pwan_, _عطار,   ,
  { {0x7c2217fd, 0x6b81002d, 0x799d004a, 0x00000000}},  //   _upor, bilg, rosw,
  { {0xc7c4007c, 0x6d5900bb, 0x68e0019a, 0x00000000}},  //   есси, _zowa, ımda,
  { {0x68ed0004, 0x356b003b, 0x3a3a0010, 0x00000000}},  //   _tead, бран_, _épp_,
  { {0xc87f01a2, 0x27e900d9, 0x00000000, 0x00000000}},  //   faßt_, _twan_,   ,
  { {0xdcfb0243, 0x394904e7, 0x00000000, 0x00000000}},  // [9c70] snuć, _inas_,   ,
  { {0x81e10044, 0x443b0045, 0x3dc60085, 0x00000000}},  //   _দিব_, rvq_, _liow_,
  { {0x35b50069, 0xa283009e, 0x00000000, 0x00000000}},  //   _обор, ریرو,   ,
  { {0x657d01c3, 0x00000000, 0x00000000, 0x00000000}},  //   _umsh,   ,   ,
  { {0x261700fa, 0x00000000, 0x00000000, 0x00000000}},  //   lço_,   ,   ,
  { {0x9618026c, 0x25a91957, 0xbea500ed, 0x00000000}},  //   _بغیر_, llal_, малк,
  { {0x2617311b, 0x6d590036, 0x6b81043e, 0x00000000}},  //   nço_, _powa, vilg,
  { {0x5f77026c, 0x61fa009f, 0x1c4504b5, 0x00000000}},  //   _کارر, _ætla, дним,
  { {0xd6c50055, 0x6b810056, 0x7d1b0133, 0x00000000}},  //   ্রিয, tilg, rfus,
  { {0x394904be, 0x7c3b08e0, 0x7d1b311c, 0x00000000}},  //   _anas_, rvur, sfus,
  { {0x6d59168b, 0x6e67007c, 0x25a90095, 0x00000000}},  //   _towa, _этаж, klal_,
  { {0x37e20044, 0x394900e5, 0x6b810032, 0x00000000}},  //   _বিবর, _cnas_, silg,
  { {0x02aa0309, 0x2ca60058, 0x6b81010e, 0x00000000}},  //   _कर्न, _gyod_, pilg,
  { {0xae21006e, 0x3ea00035, 0x00000000, 0x00000000}},  //   _महान_, şite_,   ,
  { {0x63720030, 0x46a31cf4, 0x2d8d00e7, 0x00000000}},  //   _hæng, варв, onee_,
  { {0xdb18021e, 0x6995008b, 0x2d8d00b5, 0x00000000}},  //   _eivä, _прых, nnee_,
  { {0xd6cf00a1, 0x2d8d00c4, 0xfc4a000c, 0x00000000}},  // [9c80] اقہ_, inee_, mtíð_,
  { {0x3949037e, 0x63720030, 0x2d9f0dce, 0x00000000}},  //   _znas_, _mæng, houe_,
  { {0x63720018, 0xc8e20061, 0x00000000, 0x00000000}},  //   _læng, पडपट,   ,
  { {0x26d80197, 0x6e3c0285, 0x290f00f8, 0x00000000}},  //   lcro_, _árbi, _ögat_,
  { {0xdfcf0464, 0x92c00044, 0x25a00026, 0x00000000}},  //   لين_, ীরে_, moil_,
  { {0x26d80197, 0x6d5d0039, 0x00000000, 0x00000000}},  //   ncro_, ösan,   ,
  { {0x63600047, 0x216a0478, 0x03a31c4a, 0x00000000}},  //   _dönt, _диви_, _риро,
  { {0x6026012b, 0x25a000e5, 0x316d004a, 0x00000000}},  //   _одба, noil_, _glez_,
  { {0x657a009d, 0x00000000, 0x00000000, 0x00000000}},  //   éthy,   ,   ,
  { {0x6eb60d75, 0xdb0a0051, 0x394920c4, 0x00000000}},  //   _قصائ, _bhfá, _snas_,
  { {0xc333019b, 0x2d8d0126, 0x2d9f0007, 0x00000000}},  //   דות_, bnee_, boue_,
  { {0x63720737, 0x63600039, 0x00000000, 0x00000000}},  //   _hænd, _köns,   ,
  { {0x636026a3, 0x2905005a, 0x63720190, 0x00000000}},  //   _yönt, ğla_, _gæng,
  { {0x2d841109, 0x63600039, 0x2905005d, 0x00000000}},  //   lime_, _möns, şla_,
  { {0x25a00085, 0x636000f8, 0x63720190, 0x00000000}},  //   foil_, _löns, _mænd,
  { {0x261702d5, 0x2d840993, 0x39490211, 0x00000000}},  //   rço_, nime_, _unas_,
  { {0x36d50057, 0x5ec70044, 0x93b5003b, 0x00000000}},  // [9c90] _попр, রুপে, ебац,
  { {0x25a90165, 0x2d840023, 0x316d145e, 0x00000000}},  //   slal_, hime_, _slez_,
  { {0x2d842e92, 0x00000000, 0x00000000, 0x00000000}},  //   kime_,   ,   ,
  { {0x02df02fb, 0x2d84185c, 0x37e20044, 0x00000000}},  //   _प्रभ, jime_, _বিতর,
  { {0x752d001a, 0x2d840c55, 0x6372000c, 0x00000000}},  //   meaz, dime_, _bænd,
  { {0x752d001a, 0x63602c47, 0x00000000, 0x00000000}},  //   leaz, _döns,   ,
  { {0x6da501fb, 0x69ca02fb, 0x2d84088d, 0x00000000}},  //   ника, _संगी, fime_,
  { {0x752d000d, 0x63600039, 0x00000000, 0x00000000}},  //   neaz, _föns,   ,
  { {0x7e99007a, 0x2d9f0007, 0xa2d60164, 0x00000000}},  //   _کنار_, roue_, मुक्,
  { {0xdbdc000c, 0x752d0035, 0x908a00a1, 0x00000000}},  //   ráðh, heaz, _عملے_,
  { {0xdea1025a, 0x2d840065, 0xd91002fd, 0x00000000}},  //   _حیثی, bime_, لیغ_,
  { {0x752d001a, 0x2d84064f, 0xceb201ce, 0x00000000}},  //   jeaz, cime_, _גיב_,
  { {0xeb8e045e, 0x6d4b0ec9, 0x60db000b, 0x00000000}},  //   _би_, _inga, _mfum,
  { {0x3f790049, 0x75dc000a, 0x00000000, 0x00000000}},  //   לאָס, _lčze,   ,
  { {0x69ce008e, 0x00000000, 0x00000000, 0x00000000}},  //   íbet,   ,   ,
  { {0x7dc70010, 0xc6c307d0, 0x00000000, 0x00000000}},  //   _műso, уйск,   ,
  { {0x0903007e, 0x29000288, 0x79860eb0, 0x00000000}},  // [9ca0] _спын, _idia_, mikw,
  { {0x25a006c2, 0x138a0025, 0x656f008e, 0x00000000}},  //   soil_, أخرى_, _elch,
  { {0x6d4b0d48, 0x00000000, 0x00000000, 0x00000000}},  //   _onga,   ,   ,
  { {0x2d84027b, 0x200620eb, 0x798600e7, 0x00000000}},  //   xime_, troi_, nikw,
  { {0x40340200, 0xa067003b, 0x00000000, 0x00000000}},  //   телс, наца_,   ,
  { {0x2006311d, 0xa2d601f5, 0x44320016, 0x00000000}},  //   rroi_, मुख्, mwy_,
  { {0x2d84311e, 0xa3c9006e, 0x290008d3, 0x00000000}},  //   time_, _लूट_, _odia_,
  { {0x6da300ec, 0x44320036, 0x798600e7, 0x00000000}},  //   лија, owy_, jikw,
  { {0x2d84152b, 0x4432018e, 0x79860020, 0x00000000}},  //   rime_, nwy_, dikw,
  { {0x2d840004, 0x752d000d, 0x5c732329, 0x00000000}},  //   sime_, zeaz, ульт,
  { {0x27e0011c, 0x7e9a0445, 0x2a6a0010, 0x00000000}},  //   _atin_, _عنصر_, ább_,
  { {0x67d5189f, 0x752d0035, 0x00000000, 0x00000000}},  //   кому, xeaz,   ,
  { {0x752d001a, 0x00000000, 0x00000000, 0x00000000}},  //   veaz,   ,   ,
  { {0x4432018e, 0x6601134a, 0x672e0374, 0x00000000}},  //   dwy_, álko, gebj,
  { {0x79a709de, 0x752d0507, 0xb8d70044, 0x00000000}},  //   _прие, teaz, _জল_,
  { {0x5558005e, 0x00000000, 0x00000000, 0x00000000}},  //   нася_,   ,   ,
  { {0x7bca000b, 0x752d000d, 0x6aaa018e, 0x00000000}},  // [9cb0] _kifu, reaz, _hyff,
  { {0x752d001a, 0x60db0197, 0x7bca0020, 0x00000000}},  //   seaz, _sfum, _jifu,
  { {0x7bca0020, 0x61ee0016, 0x71f800a1, 0x00000000}},  //   _mifu, _cwbl, فرنس_,
  { {0x7ff5035b, 0xb4db00d4, 0x7bca1be2, 0x00000000}},  //   نستا, _anàv, _lifu,
  { {0xc4282bda, 0xfbe70082, 0x78fc0049, 0x00000000}},  //   _пюре_, _chế_, לפאו,
  { {0x79860020, 0x7bca311f, 0xb4bd0061, 0x00000000}},  //   zikw, _nifu, आधी_,
  { {0xed590a78, 0x61ee0016, 0x6d4b0022, 0x00000000}},  //   дой_, _gwbl, _pnga,
  { {0x92e90044, 0x60db0020, 0x7d7500f3, 0x00000000}},  //   _যায়_, _ufum, ضابط,
  { {0x1004005e, 0x69cb007d, 0x7dd50066, 0x00000000}},  //   _бяхм, _संजी, _iġsm,
  { {0x0b42008b, 0x4a45004c, 0x7bca0023, 0x00000000}},  //   аньн, внов, _cifu,
  { {0x6aaa018e, 0x3f870036, 0x200f25e1, 0x00000000}},  //   _cyff, minu_, lugi_,
  { {0x3f87009f, 0x6aaa0016, 0x69dc0051, 0x00000000}},  //   linu_, _dyff, írea,
  { {0x8d7401d8, 0xd91000a1, 0x798601d6, 0x00000000}},  //   _حالا, لیں_, rikw,
  { {0x7bca0026, 0x00000000, 0x00000000, 0x00000000}},  //   _gifu,   ,   ,
  { {0x6aaa018e, 0x200f006c, 0x798600e7, 0x00000000}},  //   _gyff, hugi_, pikw,
  { {0x7bca0020, 0x3f870066, 0x1614013d, 0x00000000}},  //   _zifu, hinu_, तंबर_,
  { {0xccf200a3, 0xf773007a, 0x3f87000c, 0x00000000}},  // [9cc0] יכן_, _چاپ_, kinu_,
  { {0x4432010b, 0x200f006c, 0x3f870142, 0x00000000}},  //   rwy_, dugi_, jinu_,
  { {0x3f870466, 0xf506003b, 0x7ae50004, 0x00000000}},  //   dinu_, _изно, _õhtu,
  { {0x4a5a00b6, 0xcfe60055, 0xafe6008b, 0x00000000}},  //   ודעו, _নিবন, водл,
  { {0x3f87000c, 0x200f006c, 0x69c30061, 0x00000000}},  //   finu_, gugi_, रगती,
  { {0x3f87000c, 0xa067003b, 0xa2e30cb3, 0x00000000}},  //   ginu_, ђаја_, _ворд,
  { {0x7bca0207, 0x00000000, 0x00000000, 0x00000000}},  //   _rifu,   ,   ,
  { {0xc69300a0, 0xc5f3009b, 0x644600ee, 0x00000000}},  //   יאו_, בדה_, _krki,
  { {0x3f870091, 0x711b009b, 0x10a6073b, 0x00000000}},  //   binu_, _קומפ, _риан,
  { {0x3f87037e, 0xeab000a1, 0x7984004a, 0x00000000}},  //   cinu_, یٹک_, _amiw,
  { {0x7bca0020, 0xe9f8007e, 0x00000000, 0x00000000}},  //   _vifu, энні_,   ,
  { {0x394d07df, 0x644600b4, 0x7bca0045, 0x00000000}},  //   ñes_, _orki, _wifu,
  { {0x7d020181, 0x00000000, 0x00000000, 0x00000000}},  //   _idos,   ,   ,
  { {0x257501e3, 0xc3080044, 0xe7870143, 0x00000000}},  //   _måle_, র্তি_, тумо,
  { {0x0bb70452, 0x64463120, 0xfbb7009b, 0x00000000}},  //   _שלום_, _arki, _שפות_,
  { {0x39150216, 0x3f872ad6, 0x81e10044, 0x00000000}},  //   _смир, zinu_, _দিল_,
  { {0x95c802be, 0x49930014, 0xf8bf009d, 0x00000000}},  // [9cd0] тура_, _میگر, ffée_,
  { {0xdb01009d, 0x41e701ff, 0x47351074, 0x00000000}},  //   golè, віда, _снос,
  { {0x6446002d, 0x3f870091, 0x7d020027, 0x00000000}},  //   _erki, vinu_, _odos,
  { {0x7d02008d, 0x200f0ad1, 0xe4e40088, 0x00000000}},  //   _ndos, tugi_, _вірн,
  { {0x3f873121, 0x2bce0316, 0x25750039, 0x00000000}},  //   tinu_, _हंगा, _våld_,
  { {0x753d0047, 0x7d02002d, 0x200f0093, 0x00000000}},  //   _hasz, _ados, rugi_,
  { {0x13e80044, 0x3f871654, 0x753d108d, 0x00000000}},  //   _পিয়, rinu_, _kasz,
  { {0x3f87000c, 0x442b0bde, 0x22940088, 0x00000000}},  //   sinu_, _kpc_, _тися,
  { {0xcfab025a, 0x753d0ef2, 0x3f870387, 0x00000000}},  //   _قائم_, _masz, pinu_,
  { {0x443900bb, 0x753d3122, 0x75dc000a, 0x00000000}},  //   _mss_, _lasz, _lčza,
  { {0x198a04f9, 0x44391dee, 0x656d3123, 0x00000000}},  //   ебни_, _lss_, kkah,
  { {0x753d0046, 0x4439067e, 0x78ad0009, 0x00000000}},  //   _nasz, _oss_, _byav,
  { {0x291e0036, 0xa2aa0204, 0x6d5b0066, 0x00000000}},  //   ęta_, _जुन्, mjua,
  { {0x63a50085, 0x6d5b0022, 0x00000000, 0x00000000}},  //   john, ljua,   ,
  { {0x442b030c, 0x7bc1010f, 0x4439230d, 0x00000000}},  //   _apc_, mmlu, _ass_,
  { {0x6d5b0149, 0x442b0173, 0x4adf0204, 0x00000000}},  //   njua, _bpc_, पुरव,
  { {0xe3ba01f9, 0x4439001c, 0x3d1b0204, 0x00000000}},  // [9ce0] еба_, _css_, _याने_,
  { {0x68f6005f, 0x4439144f, 0x442b0093, 0x00000000}},  //   _heyd, _dss_, _dpc_,
  { {0x471b007b, 0x753d3124, 0x171b0049, 0x00000000}},  //   _אויג, _fasz, _אויע,
  { {0xdb011339, 0x673e0ca5, 0x7c2b3125, 0x00000000}},  //   solè, _hapj, _opgr,
  { {0x68f6005d, 0x6d5b0ea9, 0x673e2b99, 0x00000000}},  //   _meyd, djua, _kapj,
  { {0x44203126, 0x27f2018e, 0x8fa30793, 0x00000000}},  //   mti_, _mwyn_, баче,
  { {0x09cf03d7, 0x7c2b0089, 0x6b8800f8, 0x00000000}},  //   _संगठ, _apgr, vidg,
  { {0x4420010a, 0x6b880061, 0x6d5b0065, 0x00000000}},  //   oti_, widg, gjua,
  { {0x44203127, 0x442b0009, 0x61fe0239, 0x00000000}},  //   nti_, _xpc_, lspl,
  { {0x44200006, 0x673e0010, 0xf063003b, 0x00000000}},  //   iti_, _napj, _укуп,
  { {0x44200368, 0xdd8f04e1, 0x6b8800ab, 0x00000000}},  //   hti_, _کون_, ridg,
  { {0x44200ebc, 0x61fe0d4d, 0x7d021070, 0x00000000}},  //   kti_, ispl, _udos,
  { {0x44203128, 0x27f20016, 0x6d4000e0, 0x00000000}},  //   jti_, _cwyn_, mdma,
  { {0x442b00c4, 0x61fe00b0, 0x27f20016, 0x00000000}},  //   _rpc_, kspl, _dwyn_,
  { {0x7afa021e, 0xd5bb0256, 0x442b003b, 0x00000000}},  //   matt, еса_, _spc_,
  { {0x442b0011, 0x63a5010f, 0x61fe05d5, 0x00000000}},  //   _ppc_, wohn, dspl,
  { {0x44200006, 0xdb030051, 0x27f20016, 0x00000000}},  // [9cf0] gti_, _ghnó, _gwyn_,
  { {0x7afa00b0, 0x753d0036, 0x2d810010, 0x00000000}},  //   natt, _wasz, éhez_,
  { {0x44200207, 0x443900d9, 0xf8b100a1, 0x00000000}},  //   ati_, _wss_, _دکھ_,
  { {0x442012f7, 0x673e0243, 0x00000000, 0x00000000}},  //   bti_, _zapj,   ,
  { {0xb97c007b, 0x442b0129, 0x442000f6, 0x00000000}},  //   ענדי, _upc_, cti_,
  { {0x6d47001e, 0x61fe0302, 0x7afa00b0, 0x00000000}},  //   ējam, bspl, jatt,
  { {0x7afa1015, 0xff04085f, 0x539a00b3, 0x00000000}},  //   datt, сячн, _יישו,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afa16df, 0x6d5b04cb, 0x2d8601aa, 0x00000000}},  //   fatt, rjua, _dmoe_,
  { {0x7afa29df, 0x6d403129, 0xf53f032e, 0x00000000}},  //   gatt, adma, _skål_,
  { {0x4420312a, 0x68f60477, 0x7bc10239, 0x00000000}},  //   zti_, _peyd, rmlu,
  { {0x68f6005f, 0x4420312b, 0x186a004c, 0x00000000}},  //   _qeyd, yti_, вами_,
  { {0x7c2b00ab, 0x290c0180, 0x4420013f, 0x00000000}},  //   _upgr, ğda_, xti_,
  { {0xcb66013b, 0xcf920049, 0x1ae500ed, 0x00000000}},  //   _ваше_, ַטן_, _токм,
  { {0x24f61123, 0x3333002b, 0x96630a27, 0x00000000}},  //   ичар, dexx_, окре,
  { {0x442013f0, 0x63bc00b9, 0x00000000, 0x00000000}},  //   tti_, _shrn,   ,
  { {0x442004a5, 0x31bc00b9, 0xd46700e3, 0x00000000}},  // [9d00] uti_, níze_, аите_,
  { {0x61fe03a9, 0x39400d28, 0x261e005b, 0x00000000}},  //   tspl, _hais_, pïo_,
  { {0x201f312c, 0x425600ec, 0x644403b6, 0x00000000}},  //   _aqui_, штат, svii,
  { {0x4420312d, 0x61fe00f8, 0x39402075, 0x00000000}},  //   pti_, rspl, _jais_,
  { {0x39400e84, 0x7afa014a, 0x61e9312e, 0x00000000}},  //   _mais_, yatt, _čele,
  { {0x42e701f9, 0x61fe0190, 0x9e06312f, 0x00000000}},  //   _вмро_, pspl, ачил,
  { {0x2cb1013f, 0x00000000, 0x00000000, 0x00000000}},  //   əzdi_,   ,   ,
  { {0x5d540113, 0x3940006a, 0x64430036, 0x00000000}},  //   скит, _nais_, łnie,
  { {0x7afa211e, 0x1be7003b, 0x00000000, 0x00000000}},  //   tatt, адњи_,   ,
  { {0x395204bd, 0x257502e1, 0x7ac610d6, 0x00000000}},  //   _anys_, _måla_, исне,
  { {0x7afa13f0, 0x28f90131, 0xfe720025, 0x00000000}},  //   ratt, лень_, _بدء_,
  { {0x3940018e, 0x6449010a, 0xcc870014, 0x00000000}},  //   _cais_, _šeim, انیه_,
  { {0xc864007c, 0x3940004a, 0xb87b013e, 0x00000000}},  //   отри, _dais_, dcíc,
  { {0xd7f80783, 0x8a1802dc, 0x3ea90035, 0x00000000}},  //   шую_, _бокс_, şate_,
  { {0x394000f4, 0x00000000, 0x00000000, 0x00000000}},  //   _fais_,   ,   ,
  { {0xda5b00b6, 0x39400016, 0x00000000, 0x00000000}},  //   _יכול, _gais_,   ,
  { {0x54b90147, 0x69d800f8, 0x68fd0058, 0x00000000}},  // [9d10] угая_, _huve, masd,
  { {0x69d80065, 0x7af8003b, 0x28c7013d, 0x00000000}},  //   _kuve, _jevt, रेणि,
  { {0x3952018e, 0x637b0035, 0x213f0145, 0x00000000}},  //   _ynys_, _lîng, _pauh_,
  { {0x2919027e, 0x67353130, 0xb87b0010, 0x00000000}},  //   ngsa_, lezj, bbít,
  { {0x504500ed, 0x59d0007d, 0x00000000, 0x00000000}},  //   селб, _संघर,   ,
  { {0x69d8028c, 0x543a0049, 0x7af81ab2, 0x00000000}},  //   _ouve, _געשא, _nevt,
  { {0x69d83131, 0x81e10044, 0x3e3300a1, 0x00000000}},  //   _nuve, _দিক_, تہار,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3940000b, 0x69d800f4, 0x00000000, 0x00000000}},  //   _rais_, _auve,   ,
  { {0x394000f4, 0x4ea70216, 0x69d83132, 0x00000000}},  //   _sais_, _креа, _buve,
  { {0x3940029d, 0xd9460867, 0x69d801ee, 0x00000000}},  //   _pais_, бени, _cuve,
  { {0x69d801d6, 0xdd8f0123, 0x200f0026, 0x00000000}},  //   _duve, _کوچ_, orgi_,
  { {0x394000f4, 0x9cda0049, 0xc19a0049, 0x00000000}},  //   _vais_, _עקספ, רשרי,
  { {0x394000e0, 0xdb1800c4, 0x3a3c00f6, 0x00000000}},  //   _wais_, _divó, _fsvp_,
  { {0x69d8000d, 0x3940061c, 0x2618007d, 0x00000000}},  //   _guve, _tais_, बंधी_,
  { {0x25a90026, 0x7bd90009, 0x68fd0325, 0x00000000}},  //   goal_, _kuwu, casd,
  { {0xb87b2d7d, 0x69d8010f, 0x68e4012d, 0x00000000}},  // [9d20] rcíc, _zuve, _ifid,
  { {0x46f602b8, 0xb87b3133, 0x2618007d, 0x00000000}},  //   _учит, scíc, बंदी_,
  { {0x69d8027b, 0x7bd90093, 0x3e470082, 0x00000000}},  //   _xuve, _luwu, _nđt_,
  { {0xdb010489, 0x25a900fa, 0x00000000, 0x00000000}},  //   dolí, coal_,   ,
  { {0x2d8d01d6, 0x68e400e7, 0x7bd90022, 0x00000000}},  //   diee_, _mfid, _nuwu,
  { {0x7f41049a, 0xb87b008e, 0xb7db01ce, 0x00000000}},  //   _calq, ncía, אקסי,
  { {0x61460888, 0x41b60014, 0x2d8d2405, 0x00000000}},  //   _лева, _همسر, fiee_,
  { {0x69d80052, 0x3a3c0133, 0x00000000, 0x00000000}},  //   _ruve, _rsvp_,   ,
  { {0x69d80004, 0x205602a8, 0x7f4100f6, 0x00000000}},  //   _suve, _утвр, _falq,
  { {0x4f650054, 0x68fd0093, 0xc43b009b, 0x00000000}},  //   _والف, wasd, נתיי,
  { {0x999901f9, 0x6735002b, 0x68e9004a, 0x00000000}},  //   икот_, vezj, ñedo,
  { {0x3f8e000b, 0x61fa000c, 0x5e570049, 0x00000000}},  //   lifu_, _ætlu, _ליבע_,
  { {0xdb180173, 0x68fd3134, 0x7af80087, 0x00000000}},  //   _divò, rasd, _tevt,
  { {0x7f41005f, 0x3f8e0020, 0x6615002d, 0x00000000}},  //   _xalq, nifu_, tuzk,
  { {0x65660479, 0x68fd01c3, 0x00000000, 0x00000000}},  //   _bokh, pasd,   ,
  { {0x6615022b, 0xdb080065, 0x56941023, 0x00000000}},  //   ruzk, kodë, част,
  { {0x9817023c, 0x798f0146, 0xf994009b, 0x00000000}},  // [9d30] _ابعا, micw, _מרק_,
  { {0x63600047, 0x66153135, 0x04e90044, 0x00000000}},  //   _köny, puzk, গণের_,
  { {0xd2510379, 0xa4d503e8, 0x00000000, 0x00000000}},  //   بنا_, _моні,   ,
  { {0x6f083136, 0xdb010010, 0x00000000, 0x00000000}},  //   _addc, volí,   ,
  { {0x3e470082, 0x1ee70123, 0x6f080009, 0x00000000}},  //   _sđt_, موشی_, _bddc,
  { {0x2d9a0010, 0xdb010142, 0x27e90288, 0x00000000}},  //   épen_, tolí, _mtan_,
  { {0xdb180161, 0x6d423137, 0x171c0049, 0x00000000}},  //   _chví, _baoa, אווע,
  { {0x27e91136, 0x637b009d, 0xdb012bd5, 0x00000000}},  //   _otan_, _dîne, rolí,
  { {0x3f8e0020, 0x2d8d07f3, 0x1c420147, 0x00000000}},  //   bifu_, riee_, дным,
  { {0x68e40747, 0xdb010285, 0x3d1b0061, 0x00000000}},  //   _sfid, polí, _यावे_,
  { {0xeab10054, 0x27e9019a, 0xfa5300a2, 0x00000000}},  //   بعة_, _atan_, سردگ,
  { {0x3a98007c, 0x00000000, 0x00000000, 0x00000000}},  //   стью_,   ,   ,
  { {0x65660022, 0x913a0049, 0x7d1b00e7, 0x00000000}},  //   _rokh, בערק, mgus,
  { {0x7d1b006c, 0x257c18c0, 0x81ea0044, 0x00000000}},  //   lgus, _míle_, _মিস_,
  { {0x27e93138, 0x212d1a2d, 0x2ee50022, 0x00000000}},  //   _etan_, _obeh_, _mflf_,
  { {0x7d1b1be1, 0x3f8e016c, 0x00000000, 0x00000000}},  //   ngus, zifu_,   ,
  { {0xf7460d68, 0x61e90087, 0x33660451, 0x00000000}},  // [9d40] _депо, _čela, оваг,
  { {0x25750039, 0xb7d70167, 0x248000c4, 0x00000000}},  //   _håll_, _گویا_, rzim_,
  { {0xe0da3139, 0x00000000, 0x00000000, 0x00000000}},  //   аве_,   ,   ,
  { {0x64430036, 0x27e900f8, 0x00000000, 0x00000000}},  //   łnia, _ytan_,   ,
  { {0x3f8e0d16, 0x257c00b9, 0xa2aa013d, 0x00000000}},  //   tifu_, _cíle_, _जुर्,
  { {0x7d1b11f6, 0xdb0802d0, 0x257c013e, 0x00000000}},  //   egus, codè, _díle_,
  { {0x3f8e12bd, 0x6e93023c, 0xd048006b, 0x00000000}},  //   rifu_, ولها, _ələs,
  { {0x3f8e0020, 0x71760014, 0x6b8a00f6, 0x00000000}},  //   sifu_, _بهرا, _smfg,
  { {0xd7bc0061, 0x09e20061, 0x00000000, 0x00000000}},  //   ोगाच, पऱ्य,   ,
  { {0xe457007b, 0x8afc00b4, 0x00000000, 0x00000000}},  //   קייט_, djęc,   ,
  { {0x27e90b23, 0xa2be0164, 0x637b00e5, 0x00000000}},  //   _stan_, वेच्, _hînc,
  { {0x63720190, 0x00000000, 0x00000000, 0x00000000}},  //   _bænk,   ,   ,
  { {0x7dd50006, 0x798f0016, 0x00000000, 0x00000000}},  //   _išsa, ricw,   ,
  { {0x7d002604, 0xbb430184, 0xb7bb00c4, 0x00000000}},  //   lams, _жељк, rtão,
  { {0xb7bb00c4, 0x5bc30025, 0x29090009, 0x00000000}},  //   stão, _تقول, _tdaa_,
  { {0x7d000eb0, 0x00000000, 0x00000000, 0x00000000}},  //   nams,   ,   ,
  { {0x27e9313a, 0xd375003b, 0x00000000, 0x00000000}},  // [9d50] _utan_, плаћ,   ,
  { {0x97150a78, 0x7d1b313b, 0x6b9a01a2, 0x00000000}},  //   _эмоц, zgus, nntg,
  { {0x7d00000c, 0x7d1b014a, 0x257c0399, 0x00000000}},  //   kams, ygus, _síle_,
  { {0xf5590054, 0x363402fd, 0xdb0801a2, 0x00000000}},  //   _الحب_, _کریس, lldä,
  { {0xdee5007c, 0xdb010048, 0x00000000, 0x00000000}},  //   поли, holá,   ,
  { {0xdb0113a5, 0xd0062d6f, 0x3fab003b, 0x00000000}},  //   kolá, чеше_, шњем_,
  { {0x7d000016, 0xdb08313c, 0x798d00b4, 0x00000000}},  //   fams, codé, _omaw,
  { {0xf2d200a0, 0x7d1b0006, 0x7c3b01a2, 0x00000000}},  //   _טעם_, ugus, twur,
  { {0x7d1b006c, 0xdbd60934, 0x00000000, 0x00000000}},  //   rgus, jään,   ,
  { {0x547c009b, 0x798d0009, 0x7c3b0d18, 0x00000000}},  //   יטחו, _amaw, rwur,
  { {0xd94600ed, 0x63720030, 0xdb010010, 0x00000000}},  //   пени, _sænk, golá,
  { {0xac1903c8, 0xdb0a0051, 0x644f03e2, 0x00000000}},  //   _году_, _bhfó, _orci,
  { {0x5ed00044, 0xb87b04bc, 0x00000000, 0x00000000}},  //   _স্পে, scín,   ,
  { {0xc3110044, 0x61e9047c, 0x752f1938, 0x00000000}},  //   স্তি_, _čeln, _abcz,
  { {0x644f2100, 0xdb01008e, 0x28ae0061, 0x00000000}},  //   _arci, colá, _घडवि,
  { {0x06ab0055, 0x63720018, 0x18a600c2, 0x00000000}},  //   _গৃহি, _tænk, _найм,
  { {0xd5af0d3a, 0x130a007e, 0x9f5f00f6, 0x00000000}},  // [9d60] افق_, йнай_, _avuí_,
  { {0x29020127, 0x04fc0044, 0x6e2d0036, 0x00000000}},  //   laka_, ইলের_, łaby,
  { {0x11d60014, 0x7dc5008e, 0x69d60689, 0x00000000}},  //   ستاد, mósf, _kiye,
  { {0x2902006a, 0xe5a60242, 0x6a9a0049, 0x00000000}},  //   naka_, _хими, זשענ,
  { {0x69d6011c, 0xdb010010, 0x69c40066, 0x00000000}},  //   _miye, zolá, _mhie,
  { {0x29020020, 0x00000000, 0x00000000, 0x00000000}},  //   haka_,   ,   ,
  { {0x290203b0, 0x6fb600a1, 0x7d000020, 0x00000000}},  //   kaka_, _ہمرا, tams,
  { {0x290212e0, 0xdb0101ca, 0x69c40011, 0x00000000}},  //   jaka_, volá, _nhie,
  { {0x29021a71, 0x321a01ca, 0xd6c40044, 0x00000000}},  //   daka_, lupy_, ্ডিয,
  { {0xfc2f0076, 0x7d001fbc, 0x307b009b, 0x00000000}},  //   احي_, sams, _האמנ,
  { {0x69d6011c, 0x29020020, 0x7d000032, 0x00000000}},  //   _biye, faka_, pams,
  { {0x644a001e, 0x69c4051b, 0xdc2a0014, 0x00000000}},  //   āfij, _chie, _هسته_,
  { {0x69d6011f, 0x6c3402fd, 0xdb010010, 0x00000000}},  //   _diye, _آفتا, solá,
  { {0x321a0941, 0xdb01313d, 0x69d600e0, 0x00000000}},  //   kupy_, polá, _eiye,
  { {0x29020073, 0x644f01ed, 0x69d6000a, 0x00000000}},  //   baka_, _srci, _fiye,
  { {0x29020107, 0x79a4007e, 0xdbd600b0, 0x00000000}},  //   caka_, _прые, sään,
  { {0x2458007c, 0x24f8007e, 0x03d50451, 0x00000000}},  // [9d70] пать_, янты_, джаю,
  { {0xd25b008b, 0xa87c009b, 0xf2c700ed, 0x00000000}},  //   йце_, _לאחר, псен,
  { {0x32070a50, 0x69d6014a, 0xe3b00025, 0x00000000}},  //   ény_, _yiye, ارق_,
  { {0x63730676, 0x644f057c, 0x69c4002b, 0x00000000}},  //   _sını, _trci, _xhie,
  { {0xb4d90201, 0x799d01c3, 0x644f04bb, 0x00000000}},  //   ाशी_, insw, _urci,
  { {0x29022145, 0x644d0035, 0x00000000, 0x00000000}},  //   zaka_, mvai,   ,
  { {0x44290f3c, 0x29020045, 0xc332007b, 0x00000000}},  //   lta_, yaka_, _שול_,
  { {0x44290ecb, 0xd65800b6, 0xdea40167, 0x00000000}},  //   ota_, ליות_, رینی,
  { {0x644d089e, 0x69c4018e, 0x2d830006, 0x00000000}},  //   nvai, _rhie, ėje_,
  { {0x442906d5, 0x69d60e6a, 0x29020ea6, 0x00000000}},  //   ita_, _siye, waka_,
  { {0x2902000b, 0x4429313e, 0x6f030baa, 0x00000000}},  //   taka_, hta_, manc,
  { {0x6f030127, 0xdde90014, 0x00000000, 0x00000000}},  //   lanc, _هرچه_,   ,
  { {0x2902000b, 0x3b09313f, 0x8c45022a, 0x00000000}},  //   raka_, _дело_, _целе,
  { {0x2902001e, 0x6d49022b, 0x44290eb6, 0x00000000}},  //   saka_, ldea, dta_,
  { {0x2902011c, 0x752d0197, 0x69c40a60, 0x00000000}},  //   paka_, ffaz, _thie,
  { {0x44291c45, 0x6d49022b, 0x60db09bd, 0x00000000}},  //   fta_, ndea, _ngum,
  { {0x4429001c, 0x6f03001e, 0x6d49002a, 0x00000000}},  // [9d80] gta_, kanc, idea,
  { {0x7c29010f, 0x60db185b, 0x6f030091, 0x00000000}},  //   iter, _agum, janc,
  { {0x7c292e0e, 0x44292820, 0x673c01d9, 0x00000000}},  //   hter, ata_, merj,
  { {0x27e0021e, 0x4429002b, 0x673c1ed5, 0x00000000}},  //   _kuin_, bta_, lerj,
  { {0x27e0028c, 0xc483008b, 0x7c2901ee, 0x00000000}},  //   _juin_, _аляк, jter,
  { {0x29003140, 0x673c3141, 0x6d5924ed, 0x00000000}},  //   _leia_, nerj, _anwa,
  { {0x661c0052, 0x7c291440, 0x20060026, 0x00000000}},  //   nurk, eter, ssoi_,
  { {0x7c293142, 0x27ed001a, 0x673c000c, 0x00000000}},  //   fter, ţeni_, herj,
  { {0x6f03011f, 0x673c0149, 0x2b4718f2, 0x00000000}},  //   banc, kerj, _banc_,
  { {0x6f03028c, 0x2d980047, 0x661c182b, 0x00000000}},  //   canc, őre_, kurk,
  { {0x44290010, 0xaa580872, 0x6d490146, 0x00000000}},  //   zta_, чину_, bdea,
  { {0xed630006, 0x661c1bbb, 0x29000f6e, 0x00000000}},  //   gužė_, durk, _ceia_,
  { {0x442902d5, 0x29000948, 0xdb08073f, 0x00000000}},  //   xta_, _deia_, lodí,
  { {0x27e03143, 0xe8e00082, 0x779300a1, 0x00000000}},  //   _duin_, _muội_, ئیدا,
  { {0x29000a06, 0x356b003b, 0x67d4007c, 0x00000000}},  //   _feia_, оран_, тору,
  { {0x6f030627, 0x628500ca, 0x644d1487, 0x00000000}},  //   zanc, vzho, tvai,
  { {0x442900b0, 0x6f032b25, 0x644d00f4, 0x00000000}},  // [9d90] uta_, yanc, uvai,
  { {0x44290149, 0x394901d6, 0x644d0dd9, 0x00000000}},  //   rta_, _haas_, rvai,
  { {0x44290f3c, 0x6f030038, 0x7c293144, 0x00000000}},  //   sta_, vanc, zter,
  { {0x44290127, 0x6f03023a, 0x76450061, 0x00000000}},  //   pta_, wanc, _ishy,
  { {0x7c2900f8, 0x3949109a, 0xd4790049, 0x00000000}},  //   xter, _maas_, _זאָל,
  { {0x39490007, 0x70520d0b, 0xa29505b8, 0x00000000}},  //   _laas_, انوا, _загі,
  { {0x6d49001a, 0x7c293145, 0x00000000, 0x00000000}},  //   tdea, wter,   ,
  { {0x6f0300f4, 0x3dc60784, 0x1c45019d, 0x00000000}},  //   sanc, _chow_, еним,
  { {0x6d491cc3, 0x7c29010a, 0xfc480011, 0x00000000}},  //   rdea, uter, _cử_,
  { {0x7c290292, 0x3dc600ab, 0x29000056, 0x00000000}},  //   rter, _ehow_, _seia_,
  { {0x7bd80576, 0x673c3146, 0xc3320049, 0x00000000}},  //   _divu, verj, נוט_,
  { {0x6d590016, 0x7aea00ea, 0x127a0049, 0x00000000}},  //   _unwa, _efft, פארע,
  { {0x673c11b2, 0x290006c2, 0x27e00129, 0x00000000}},  //   terj, _veia_, _quin_,
  { {0xfaa5007e, 0xfbc5007c, 0x00000000, 0x00000000}},  //   _пало, _ябло,   ,
  { {0x29000181, 0xcb12009b, 0x8f9a009b, 0x00000000}},  //   _teia_, _עלה_, לישי,
  { {0x673c0059, 0x27e001b5, 0x2d9f00f4, 0x00000000}},  //   serj, _tuin_, nnue_,
  { {0x673c01d5, 0xfc48001d, 0x66e6022a, 0x00000000}},  // [9da0] perj, _xử_, _попа,
  { {0xe3b7003b, 0x74130025, 0x661c0052, 0x00000000}},  //   ебу_, اولا, purk,
  { {0x317f0823, 0x00000000, 0x00000000, 0x00000000}},  //   _bluz_,   ,   ,
  { {0xa87a0049, 0xc0e60a85, 0x00000000, 0x00000000}},  //   ּאַר, ходк,   ,
  { {0x26c700b9, 0x25a00910, 0x201d0058, 0x00000000}},  //   _únor_, mnil_, guwi_,
  { {0x3dc60038, 0xdfcf2aea, 0x6446045d, 0x00000000}},  //   _show_, مين_, _iski,
  { {0xfc48001d, 0x03a302e9, 0x6f013147, 0x00000000}},  //   _sử_, _сиро, _delc,
  { {0x7bd8021e, 0x5d5400e3, 0x25a03148, 0x00000000}},  //   _sivu, ткит, nnil_,
  { {0x10a303f4, 0x394901d6, 0x6f011a1d, 0x00000000}},  //   _битн, _raas_, _felc,
  { {0x39490052, 0xf8bf00f4, 0x25a000ca, 0x00000000}},  //   _saas_, ngée_, hnil_,
  { {0xc333019b, 0x7bd83149, 0xf99f01aa, 0x00000000}},  //   אות_, _vivu, tnè_,
  { {0xfc48001d, 0x4c86005e, 0xbfa50011, 0x00000000}},  //   _tử_, _плев, hiệ,
  { {0x7a36006b, 0xdb0800c4, 0xec130076, 0x00000000}},  //   _bütö, godã, _موند,
  { {0x394900d9, 0x00000000, 0x00000000, 0x00000000}},  //   _waas_,   ,   ,
  { {0x3949314a, 0x644600ab, 0x00000000, 0x00000000}},  //   _taas_, _aski,   ,
  { {0xd5b801fb, 0x7abb00a0, 0x25a00059, 0x00000000}},  //   есу_, _מצוו, gnil_,
  { {0x68ed005d, 0x00000000, 0x00000000, 0x00000000}},  // [9db0] _ifad,   ,   ,
  { {0x889c009b, 0x2c130061, 0x7d0204e7, 0x00000000}},  //   _מבחי, _दिसू_, _leos,
  { {0x6446014a, 0x22590025, 0x76450009, 0x00000000}},  //   _eski, بلاد_, _ushy,
  { {0x7d02049c, 0x00000000, 0x00000000, 0x00000000}},  //   _neos,   ,   ,
  { {0x2d84314b, 0x6f01012d, 0x68ed00e7, 0x00000000}},  //   dhme_, _pelc, _mfad,
  { {0x7bdf028c, 0x3b05005f, 0x656f001f, 0x00000000}},  //   _équi, xalq_, _hoch,
  { {0x6372000c, 0xb87b0010, 0x7d02314c, 0x00000000}},  //   _vænt, gbíz, _beos,
  { {0x6f0123b9, 0x7dd50006, 0x656f1440, 0x00000000}},  //   _welc, _išsk, _joch,
  { {0x656f00b5, 0x7d02001a, 0x6f01008e, 0x00000000}},  //   _moch, _deos, _telc,
  { {0x656f0051, 0x6720013d, 0x68ed00e7, 0x00000000}},  //   _loch, _बाइक_, _afad,
  { {0xfaa50373, 0x6a86028c, 0x443901a3, 0x00000000}},  //   тано, _réfé, _lps_,
  { {0x656f314d, 0x7d02013f, 0xdc530167, 0x00000000}},  //   _noch, _geos, _مرتک,
  { {0xec6e0256, 0x8ccd013d, 0x00000000, 0x00000000}},  //   _тп_, देशो,   ,
  { {0x6d4b0211, 0x2489314e, 0xfc46013e, 0x00000000}},  //   _haga, dzam_, řích_,
  { {0x6d4b006a, 0x44390030, 0x656f164b, 0x00000000}},  //   _kaga, _aps_, _boch,
  { {0x656f226e, 0x6d4b006c, 0x4439023a, 0x00000000}},  //   _coch, _jaga, _bps_,
  { {0x6d4b314f, 0x44390253, 0x442b00c4, 0x00000000}},  // [9dc0] _maga, _cps_, _cqc_,
  { {0x6d4b3150, 0x656f0051, 0x25ad0e3b, 0x00000000}},  //   _laga, _eoch, čela_,
  { {0xf8bf009d, 0x656f0051, 0x6372000c, 0x00000000}},  //   rgée_, _foch, _sæns,
  { {0x6d4b006a, 0x4439014a, 0x656f0761, 0x00000000}},  //   _naga, _fps_, _goch,
  { {0x44390387, 0x7d02010e, 0x24890036, 0x00000000}},  //   _gps_, _reos, czam_,
  { {0x44203151, 0x7d02017b, 0xdb080010, 0x00000000}},  //   mui_, _seos, kodá,
  { {0x44201305, 0x6d4b186e, 0x2d8400f4, 0x00000000}},  //   lui_, _baga, thme_,
  { {0x75240020, 0x44201de2, 0x6d4b0efe, 0x00000000}},  //   ngiz, oui_, _caga,
  { {0x44200006, 0x61e90209, 0x98be00b9, 0x00000000}},  //   nui_, _čeli, ětě_,
  { {0x2d84008d, 0x6d4b002a, 0x00000000, 0x00000000}},  //   shme_, _eaga,   ,
  { {0x831b0452, 0x4420020c, 0x3d1b0061, 0x00000000}},  //   וויז, hui_, _याचे_,
  { {0x6d4b2384, 0x442009cf, 0x7dc50489, 0x00000000}},  //   _gaga, kui_, rósc,
  { {0x656f002a, 0x4420242a, 0x2575068f, 0x00000000}},  //   _roch, jui_, _målt_,
  { {0x6d400dda, 0x442001aa, 0x6d4b0821, 0x00000000}},  //   lema, dui_, _zaga,
  { {0x35e401fb, 0xda6f0265, 0x44393152, 0x00000000}},  //   ицтв, _тя_, _sps_,
  { {0x6d400114, 0x68ed00e7, 0x88c800b9, 0x00000000}},  //   nema, _ufad, _stěž,
  { {0x545504af, 0x442004bd, 0x656f00b5, 0x00000000}},  // [9dd0] ыват, gui_, _voch,
  { {0x6d400004, 0x656f001f, 0x1b140055, 0x00000000}},  //   hema, _woch, ত্রে_,
  { {0x6d4027d2, 0x24890036, 0x656f164b, 0x00000000}},  //   kema, szam_, _toch,
  { {0x4420000d, 0x6d401bc1, 0xf67a0049, 0x00000000}},  //   bui_, jema, _נארמ,
  { {0x6d4b0198, 0x6d4000ab, 0x4420001a, 0x00000000}},  //   _raga, dema, cui_,
  { {0x6d4b001e, 0x7dd5010a, 0x00000000, 0x00000000}},  //   _saga, _išsi,   ,
  { {0x6d4b010a, 0x00000000, 0x00000000, 0x00000000}},  //   _paga,   ,   ,
  { {0x26dc08cd, 0x00000000, 0x00000000, 0x00000000}},  //   וקומ,   ,   ,
  { {0x7bca0195, 0x6d4b02d5, 0xc6bf0055, 0x00000000}},  //   _bhfu, _vaga, _আলোচ,
  { {0x9ee90054, 0xc0c8005e, 0x20090e3f, 0x00000000}},  //   _أفضل_, _русе_, šais_,
  { {0x6d4b0b1a, 0xadf501e0, 0x7dc70010, 0x00000000}},  //   _taga, _спеш, _műsz,
  { {0x6d403153, 0xdb083154, 0x29040cd3, 0x00000000}},  //   cema, rodá, úma_,
  { {0xd910026c, 0xdb080010, 0xdb2300a2, 0x00000000}},  //   میں_, sodá, _نوشی,
  { {0x3ced01d9, 0x44203155, 0x7d090e98, 0x00000000}},  //   lcev_, vui_, laes,
  { {0x98a4005d, 0x69c4013d, 0xdbd1006c, 0x00000000}},  //   ımı_, रतदी, _müüj,
  { {0x4420042c, 0x3ced0059, 0x7d090091, 0x00000000}},  //   tui_, ncev_, naes,
  { {0x79840020, 0x39423156, 0x26180316, 0x00000000}},  // [9de0] _iliw, meks_, बूजी_,
  { {0x394214b9, 0x442024b7, 0x6d402645, 0x00000000}},  //   leks_, rui_, zema,
  { {0xeb96007b, 0x4420244a, 0x6b7a0049, 0x00000000}},  //   נדער_, sui_, ערענ,
  { {0x3942006c, 0x673b0091, 0x6d400032, 0x00000000}},  //   neks_, đuje, xema,
  { {0x6d402370, 0x442009f7, 0xe3b100a1, 0x00000000}},  //   vema, qui_, صرے_,
  { {0x39420004, 0x6d40298f, 0x79840016, 0x00000000}},  //   heks_, wema, _lliw,
  { {0x79840036, 0x3942010e, 0x63ab3157, 0x00000000}},  //   _oliw, keks_, égne,
  { {0xdd900379, 0x644d006c, 0xf6570097, 0x00000000}},  //   توب_, _üliõ, רסקי_,
  { {0x6d400004, 0x3942006c, 0xd1b3007a, 0x00000000}},  //   rema, deks_, _اینک,
  { {0x6d400004, 0x6d870819, 0xff24026c, 0x00000000}},  //   sema, _añad, _خبری,
  { {0xee290025, 0xfca90014, 0x6d40010e, 0x00000000}},  //   _لأنه_, _یاهو_, pema,
  { {0x984b007e, 0x3942006c, 0x7d09004a, 0x00000000}},  //   няга_, geks_, caes,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xead4132a, 0x394d007f, 0x00000000, 0x00000000}},  //   _коль, žes_,   ,
  { {0x5b7b0049, 0x6b9a30ac, 0x00000000, 0x00000000}},  //   _ארגא, mitg,   ,
  { {0x25ad0e3b, 0x79840036, 0x6b9a00f6, 0x00000000}},  //   čelo_, _gliw, litg,
  { {0x290b037e, 0x33f40025, 0xa49b00d4, 0x00000000}},  // [9df0] maca_, مسلس, _geòl,
  { {0x290b016c, 0x69df0065, 0x98b90089, 0x00000000}},  //   laca_, _hiqe, cesā_,
  { {0x3ebe067e, 0xdb08000c, 0x69cd0022, 0x00000000}},  //   _nytt_, lldó, _khae,
  { {0x290b3158, 0x31350088, 0x354701ff, 0x00000000}},  //   naca_, редр, _схов,
  { {0x3ced0059, 0x69df0065, 0x00000000, 0x00000000}},  //   vcev_, _miqe,   ,
  { {0x88c70055, 0x69df0065, 0x3ebe01c9, 0x00000000}},  //   _এলাক, _liqe, _bytt_,
  { {0xd5ae026c, 0x2778009b, 0x7d090052, 0x00000000}},  //   _رہے_, רגון_, taes,
  { {0x290b003b, 0x3f870066, 0x656d0169, 0x00000000}},  //   jaca_, shnu_, njah,
  { {0x0d820106, 0xe7e1006e, 0xdd8e0025, 0x00000000}},  //   ільн, _गंगा_, بوي_,
  { {0x2eee0009, 0x30840025, 0x3ced00ca, 0x00000000}},  //   ccff_, _الكف, scev_,
  { {0x39420004, 0x49ca003b, 0x3ced0059, 0x00000000}},  //   teks_, клон_, pcev_,
  { {0x69cd0016, 0x7f433159, 0x290b00f5, 0x00000000}},  //   _chae, lenq, gaca_,
  { {0x6b65004c, 0x7dc50d4e, 0x6d7a009b, 0x00000000}},  //   _вкла, lóso, _שאנח,
  { {0x3942061f, 0x87b900e3, 0x8c1a00a0, 0x00000000}},  //   seks_, густ_, _יוני,
  { {0x290b04cb, 0x7f4300f6, 0x00000000, 0x00000000}},  //   baca_, ienq,   ,
  { {0x69cd002a, 0x290b0020, 0x79840020, 0x00000000}},  //   _ghae, caca_, _uliw,
  { {0x3f8500b0, 0x9f440026, 0x19bb009b, 0x00000000}},  // [9e00] _ollu_, _fumè_, _במקב,
  { {0x7bc1018e, 0x425600ed, 0x6e2302fc, 0x00000000}},  //   nllu, итет, kunb,
  { {0x00e601fb, 0x171b0049, 0x7bc1315a, 0x00000000}},  //   ажен, _בויע, illu,
  { {0x3f850016, 0x3160008e, 0x7ae30288, 0x00000000}},  //   _allu_, ñiz_, _lgnt,
  { {0x60c90036, 0x33d60088, 0x1b1d0044, 0x00000000}},  //   _czem, _вівт, ব্যে_,
  { {0x60c90089, 0x6e2302d4, 0x00000000, 0x00000000}},  //   _dzem, funb,   ,
  { {0x443200ab, 0xe8e00011, 0x6b9a00d4, 0x00000000}},  //   lty_, _muối_, vitg,
  { {0xe817001c, 0xad660025, 0x290b008e, 0x00000000}},  //   _तिला_, شابه, xaca_,
  { {0x6b9a001c, 0x290b0091, 0x3b070082, 0x00000000}},  //   titg, vaca_, _benq_,
  { {0x69cd01f3, 0x61e001bf, 0x6e230093, 0x00000000}},  //   _shae, _himl, bunb,
  { {0x61e0047f, 0x443213b3, 0x3f9c0020, 0x00000000}},  //   _kiml, hty_, mivu_,
  { {0x443208e2, 0x3f9c0020, 0x60c000b0, 0x00000000}},  //   kty_, livu_, _kymm,
  { {0x290b0213, 0xdbdc00b9, 0x63bc0bf8, 0x00000000}},  //   raca_, lšíh, _okrn,
  { {0xe8e0001d, 0x68e4007f, 0xaa5800a1, 0x00000000}},  //   _cuối_, _egid, _ملتا_,
  { {0x443200b4, 0x290b04eb, 0x656d03e1, 0x00000000}},  //   ety_, paca_, tjah,
  { {0xaadb00a0, 0x61e001f3, 0x7dc512c3, 0x00000000}},  //   _בחור, _niml, jósl,
  { {0x799d0066, 0x656d01a2, 0x443201d6, 0x00000000}},  // [9e10] misw, rjah, gty_,
  { {0x799d0116, 0x656d010f, 0x3f9c315b, 0x00000000}},  //   lisw, sjah, jivu_,
  { {0x60c90047, 0x44320036, 0x3267315c, 0x00000000}},  //   _szem, aty_, штав,
  { {0x799d0173, 0x27e90145, 0xdceb002b, 0x00000000}},  //   nisw, _kuan_, _imgħ,
  { {0x27e92352, 0x7bc11e06, 0x7f43010f, 0x00000000}},  //   _juan_, yllu, tenq,
  { {0x2d86315d, 0x60c900ca, 0x43850025, 0x00000000}},  //   _aloe_, _vzem, _السق,
  { {0x27e90065, 0xceb4006b, 0x7f4300d4, 0x00000000}},  //   _luan_, şən_, renq,
  { {0x6e23002d, 0xee36007e, 0x4d651649, 0x00000000}},  //   runb, ёны_, скив,
  { {0x60c9315e, 0x6e230032, 0x60c008c9, 0x00000000}},  //   _uzem, sunb, _gymm,
  { {0x5f740054, 0x6f0800d9, 0x00000000, 0x00000000}},  //   _والر, _gedc,   ,
  { {0xe9da0265, 0xe7e1013d, 0x9f95010e, 0x00000000}},  //   лко_, _गंजा_, _müün_,
  { {0x4432270b, 0x186a041f, 0x27e9315f, 0x00000000}},  //   yty_, гами_, _buan_,
  { {0x44323160, 0xf71a007e, 0x00000000, 0x00000000}},  //   xty_, лівы_,   ,
  { {0x27e90065, 0xd62a0175, 0x291e014a, 0x00000000}},  //   _duan_, логе_, şta_,
  { {0xc9f501f7, 0xfaa2019d, 0x44320253, 0x00000000}},  //   _استع, _нашо, wty_,
  { {0x3f9c0bf8, 0x443227dd, 0xb6a3053f, 0x00000000}},  //   zivu_, tty_, числ,
  { {0x61e012d8, 0xd467026b, 0x443200ab, 0x00000000}},  // [9e20] _riml, бите_, uty_,
  { {0x212d023a, 0x09cd0044, 0xdb011db2, 0x00000000}},  //   _aceh_, _রূপা, moló,
  { {0x44320652, 0x06d60055, 0x649e002b, 0x00000000}},  //   sty_, _ত্রি, _sħiħ,
  { {0x443207ff, 0x2c180061, 0x3aba0049, 0x00000000}},  //   pty_, _दिलं_, אמענ,
  { {0xb87b285a, 0x3a250250, 0xdb010321, 0x00000000}},  //   ncíp, hulp_, noló,
  { {0xe82002d2, 0x44200065, 0x39520133, 0x00000000}},  //   _बिना_, mri_, _lays_,
  { {0xa24800e9, 0x3f9c0066, 0x44202848, 0x00000000}},  //   _خیال_, rivu_, lri_,
  { {0x44200015, 0x3f9c021e, 0xdbdc013e, 0x00000000}},  //   ori_, sivu_, ršíh,
  { {0x799d000a, 0x40960025, 0x00000000, 0x00000000}},  //   visw, _الذر,   ,
  { {0x4420009f, 0xdb0111c8, 0x27e90ccd, 0x00000000}},  //   iri_, doló, _ruan_,
  { {0x4420014a, 0xed060014, 0x7dea0036, 0x00000000}},  //   hri_, _هواپ, _męsk,
  { {0x442001aa, 0x27e9288b, 0x8afc0036, 0x00000000}},  //   kri_, _puan_, ejęt,
  { {0x27e90a91, 0x39520038, 0x8c43004d, 0x00000000}},  //   _quan_, _days_, _неце,
  { {0x799d04fa, 0x27e90065, 0x00000000, 0x00000000}},  //   sisw, _vuan_,   ,
  { {0x44200daa, 0x7d25000c, 0x00000000, 0x00000000}},  //   eri_, _útsý,   ,
  { {0x44203161, 0xe9a401fc, 0xb8cf0044, 0x00000000}},  //   fri_, _најп, _কর_,
  { {0x4420009f, 0xdb01029d, 0x53990147, 0x00000000}},  // [9e30] gri_, coló, авая_,
  { {0xdce90243, 0xdb0100f6, 0x00000000, 0x00000000}},  //   vječ, lolò,   ,
  { {0x26c70027, 0x0736009b, 0x00000000, 0x00000000}},  //   _áno_, _ואתם_,   ,
  { {0x44201b45, 0xdce90243, 0xdb013162, 0x00000000}},  //   bri_, tječ, nolò,
  { {0xa069003b, 0xa3d50751, 0x25a9001a, 0x00000000}},  //   рала_, _момч, mnal_,
  { {0xfe700014, 0xdce90166, 0x66fb0309, 0x00000000}},  //   کده_, rječ, ्रिक_,
  { {0x25a90ac4, 0xdce9016e, 0x877c01ce, 0x00000000}},  //   onal_, sječ, ראוי,
  { {0x4c8501fb, 0x25a93163, 0xee36008b, 0x00000000}},  //   жлив, nnal_, іны_,
  { {0x39522a24, 0x25a90544, 0xdb0100d4, 0x00000000}},  //   _rays_, inal_, dolò,
  { {0x39520038, 0xeb99012b, 0xdceb0035, 0x00000000}},  //   _says_, рио_, _bogă,
  { {0x3952028c, 0x89aa0057, 0x8cf5007e, 0x00000000}},  //   _pays_, иков_, _дзец,
  { {0x44203164, 0x645d0066, 0xdb0103b5, 0x00000000}},  //   yri_, _orsi, toló,
  { {0x77770066, 0x4420006b, 0xe8e00082, 0x00000000}},  //   _boxx, xri_, _ruồi_,
  { {0x44200263, 0xdb0110fa, 0xc31f0044, 0x00000000}},  //   vri_, roló, ন্তি_,
  { {0x645d11a7, 0x644f0207, 0xdb013165, 0x00000000}},  //   _arsi, _asci, soló,
  { {0x44201b3e, 0x25a900ab, 0xdb013166, 0x00000000}},  //   tri_, gnal_, colò,
  { {0x44200bd5, 0x7d0b3167, 0x00000000, 0x00000000}},  // [9e40] uri_, _megs,   ,
  { {0x44200756, 0x7d0b0010, 0x69c601e5, 0x00000000}},  //   rri_, _legs, llke,
  { {0x644f06c2, 0x44200d92, 0x645d14c9, 0x00000000}},  //   _esci, sri_, _ersi,
  { {0x637b0035, 0x00000000, 0x00000000, 0x00000000}},  //   _sînt,   ,   ,
  { {0xf9930104, 0x69c60032, 0x00000000, 0x00000000}},  //   ורא_, ilke,   ,
  { {0xdfcf0379, 0xceb4006b, 0x2b800173, 0x00000000}},  //   نين_, şəm_, _gòch_,
  { {0xed5000a1, 0xa3d7007d, 0x00000000, 0x00000000}},  //   ٹھا_, ागर_,   ,
  { {0x25a02bd0, 0x61fe3168, 0xc31f0044, 0x00000000}},  //   niil_, mppl, ন্দি_,
  { {0x8c4300ed, 0xb14301e1, 0x5f2a01ab, 0x00000000}},  //   дење, _інфл, _возм_,
  { {0x25ad0e3b, 0x25a90b41, 0x61fe0056, 0x00000000}},  //   čeli_, znal_, oppl,
  { {0xa2a0013d, 0x00000000, 0x00000000, 0x00000000}},  //   _गेम्,   ,   ,
  { {0x2d8d0145, 0x00000000, 0x00000000, 0x00000000}},  //   chee_,   ,   ,
  { {0xb8f3024c, 0xdb010129, 0xf99f0026, 0x00000000}},  //   _वर_, rolò, riè_,
  { {0x68f60016, 0x656602d4, 0x00000000, 0x00000000}},  //   _efyd, _ankh,   ,
  { {0x693300b9, 0xdb23000c, 0x68f60016, 0x00000000}},  //   _přeč, _þrát, _ffyd,
  { {0x481506e1, 0x645d0142, 0x2d84007f, 0x00000000}},  //   _емис, _prsi, nkme_,
  { {0x25a90038, 0xe8e00011, 0x6fca01f5, 0x00000000}},  // [9e50] rnal_, _buổi_, ितां,
  { {0xd25b26f5, 0x645d0107, 0x656600bb, 0x00000000}},  //   ице_, _vrsi, _enkh,
  { {0xed590107, 0x25a0006c, 0x6fc400d4, 0x00000000}},  //   lože_, biil_, còci,
  { {0x2b8001aa, 0x645d016c, 0x6d870288, 0x00000000}},  //   _wòch_, _trsi, _añan,
  { {0x644f0207, 0x7d0b0007, 0x645d1290, 0x00000000}},  //   _usci, _regs, _ursi,
  { {0x44290149, 0xd3430167, 0x752d04de, 0x00000000}},  //   mua_, _تفسی, lgaz,
  { {0x44292cbb, 0x2d8d0270, 0x29020036, 0x00000000}},  //   lua_, thee_, ybka_,
  { {0x752d000b, 0x3cf7013d, 0x44293169, 0x00000000}},  //   ngaz, ीरें_, oua_,
  { {0x7d0b0635, 0x644d005b, 0x00000000, 0x00000000}},  //   _vegs, nwai,   ,
  { {0x7d0b316a, 0x291b00f6, 0x2d8d2134, 0x00000000}},  //   _wegs, _adqa_, shee_,
  { {0x442900b0, 0x644d005b, 0x00000000, 0x00000000}},  //   hua_, hwai,   ,
  { {0x44290459, 0x66150036, 0x2d840146, 0x00000000}},  //   kua_, dszk, ckme_,
  { {0x442928d3, 0x2d9d0009, 0x22430022, 0x00000000}},  //   jua_, _imwe_, _lpjk_,
  { {0x4429316b, 0x752d0207, 0x644d0016, 0x00000000}},  //   dua_, egaz, dwai,
  { {0x7c2905b7, 0xdb1a0023, 0x00000000, 0x00000000}},  //   luer, zotë,   ,
  { {0x44290020, 0x25080014, 0x291e0006, 0x00000000}},  //   fua_, ترسی_, ėtas_,
  { {0x442928f4, 0x7c290056, 0xd467005e, 0x00000000}},  // [9e60] gua_, nuer, пите_,
  { {0x25a003d8, 0xf74a0025, 0x00000000, 0x00000000}},  //   siil_, _الدي_,   ,
  { {0x24860142, 0x24920046, 0xb77b00b6, 0x00000000}},  //   šom_, szym_, _האיש,
  { {0x7c2900eb, 0x44292340, 0x3cf7013d, 0x00000000}},  //   kuer, bua_, ीरों_,
  { {0xe8e0001d, 0x4429316c, 0xf9930049, 0x00000000}},  //   _tuổi_, cua_, ערד_,
  { {0xfbc705f3, 0x2d9d0009, 0x7c29316d, 0x00000000}},  //   _ست_, _amwe_, duer,
  { {0x39400026, 0x67eb002b, 0x2d9d0146, 0x00000000}},  //   _obis_, _iżje, _bmwe_,
  { {0x7c290211, 0x2ca90006, 0x3218009d, 0x00000000}},  //   fuer, _žada_, _ivry_,
  { {0x7c2904bd, 0x2c1c0061, 0x8e200088, 0x00000000}},  //   guer, _मिळू_, рiв_,
  { {0x5ede0055, 0x61ee1bd7, 0x394004cb, 0x00000000}},  //   নুষে, _kubl, _abis_,
  { {0x4429316e, 0x61ee2849, 0xfbcf0025, 0x00000000}},  //   zua_, _jubl, دتي_,
  { {0xed59004f, 0x63be01ca, 0x7c290056, 0x00000000}},  //   tože_, hopn, buer,
  { {0x7c290211, 0x61ee0036, 0x4429002d, 0x00000000}},  //   cuer, _lubl, xua_,
  { {0x61ee028c, 0x4429316f, 0x00000000, 0x00000000}},  //   _oubl, vua_,   ,
  { {0x7bda009f, 0xc668003b, 0x61ee1f51, 0x00000000}},  //   mmtu, пште_, _nubl,
  { {0x44291e3a, 0x7bc801e5, 0x644d0544, 0x00000000}},  //   tua_, lldu, twai,
  { {0x3f8c01f6, 0x798d0058, 0x752d0232, 0x00000000}},  // [9e70] _oldu_, _ilaw, rgaz,
  { {0x4429022b, 0xe97300a1, 0x394b00f6, 0x00000000}},  //   rua_, _آنکھ, lecs_,
  { {0x4429022b, 0x213f00e0, 0x61fc02d1, 0x00000000}},  //   sua_, _pbuh_, _ctrl,
  { {0x61ee006c, 0x7dc5029d, 0xdd8605d4, 0x00000000}},  //   _dubl, pósi, _شو_,
  { {0x44290207, 0x3218009d, 0xe8e00082, 0x00000000}},  //   qua_, _evry_, _duỗi_,
  { {0x798d018e, 0x394b009d, 0x3f9e0145, 0x00000000}},  //   _llaw, hecs_, _cmtu_,
  { {0x6442009d, 0xdb1a00d6, 0x61ee04eb, 0x00000000}},  //   çoiv, coté, _gubl,
  { {0x7c29277a, 0x7bc80277, 0xe46a014a, 0x00000000}},  //   tuer, eldu, ıköğ,
  { {0x32010178, 0x5ede0044, 0x00000000, 0x00000000}},  //   lphy_, নুলে,   ,
  { {0x798d3170, 0x7c29003a, 0x79860022, 0x00000000}},  //   _alaw, ruer, wkkw,
  { {0x7c290058, 0x394a00d7, 0x32010b3d, 0x00000000}},  //   suer, озно_, nphy_,
  { {0x7c293171, 0x2d9d0061, 0x798d3172, 0x00000000}},  //   puer, _umwe_, _claw,
  { {0x7c2906c0, 0xd91000a1, 0x76450026, 0x00000000}},  //   quer, نیں_, _aphy,
  { {0x61fb0521, 0x00000000, 0x00000000, 0x00000000}},  //   _čuln,   ,   ,
  { {0x798d0133, 0xe737007c, 0x2bba0061, 0x00000000}},  //   _flaw, ьер_, ईकरा,
  { {0x9952010a, 0xe8170061, 0x61ee016e, 0x00000000}},  //   ršų_, _तिचा_, _rubl,
  { {0x63be0059, 0x64a30c27, 0x61fc00ca, 0x00000000}},  // [9e80] topn, вата, _strl,
  { {0x387f01a2, 0x7dea0006, 0x00000000, 0x00000000}},  //   äure_, _kęst,   ,
  { {0x63be0395, 0x7dc50010, 0x00000000, 0x00000000}},  //   ropn, lósu,   ,
  { {0x2f0a0036, 0x63be01d6, 0xdb1a220d, 0x00000000}},  //   _mógł_, sopn, roté,
  { {0x7bc8009f, 0x7bc3023a, 0x9f4501aa, 0x00000000}},  //   yldu, _oknu, _kilè_,
  { {0x61ee006c, 0xdfd00076, 0xdb1a0161, 0x00000000}},  //   _tubl, ديت_, poté,
  { {0x69c405fd, 0x00000000, 0x00000000, 0x00000000}},  //   _okie,   ,   ,
  { {0x2dd70025, 0xdb01000c, 0x6e2a01a2, 0x00000000}},  //   وبية_, nnlæ, rufb,
  { {0x7e870006, 0x21a3012c, 0xdb010023, 0x00000000}},  //   _įspū, _ритм, cilë,
  { {0x798d0a77, 0x69c40020, 0x00000000, 0x00000000}},  //   _slaw, _akie,   ,
  { {0xd0130055, 0x394b00d4, 0xe9f803e8, 0x00000000}},  //   _সময়_, tecs_, янні_,
  { {0x1ea90076, 0x69d601aa, 0x644600d9, 0x00000000}},  //   _عالي_, _chye, _opki,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x394b00f6, 0x00000000, 0x00000000, 0x00000000}},  //   secs_,   ,   ,
  { {0x9f450173, 0x52bf0164, 0x7dea00b4, 0x00000000}},  //   _dilè_, _्रेस, _gęst,
  { {0x58d501ab, 0x999900b4, 0x00000000, 0x00000000}},  //   _пойт, żyła_,   ,
  { {0x9f450173, 0xdb013173, 0x00000000, 0x00000000}},  // [9e90] _filè_, rolö,   ,
  { {0x6d97001a, 0x58d8007e, 0xdb010190, 0x00000000}},  //   nţar, _ідэя_, anlæ,
  { {0x644600f6, 0x00000000, 0x00000000, 0x00000000}},  //   _epki,   ,   ,
  { {0x32013174, 0x7dc5008e, 0xe5070318, 0x00000000}},  //   rphy_, nóst, _تبدي,
  { {0x3f6901fc, 0x69dd0051, 0x92c10044, 0x00000000}},  //   зило_, imse, ুশে_,
  { {0x443b0009, 0x7e6100f6, 0x9f4500d4, 0x00000000}},  //   mtq_, _prlp, _xilè_,
  { {0xee39103e, 0x657d3175, 0x68ed016c, 0x00000000}},  //   їни_, _kosh, _ogad,
  { {0x657d21b4, 0x68ed0591, 0x6d870a02, 0x00000000}},  //   _josh, _ngad, _iñak,
  { {0x657d0a9e, 0xed5901ee, 0xdb010068, 0x00000000}},  //   _mosh, rdž_, lilé,
  { {0x69c40d31, 0x61e90270, 0x657d01ee, 0x00000000}},  //   _skie, _hiel, _losh,
  { {0x61e9021e, 0xa2d30061, 0x6285278e, 0x00000000}},  //   _kiel, भेच्, nyho,
  { {0x657d0061, 0xf9920380, 0x63a50052, 0x00000000}},  //   _nosh, ابد_, hihn,
  { {0x61e9021e, 0x44390065, 0xdb083176, 0x00000000}},  //   _miel, _nqs_, godó,
  { {0x61e9001e, 0x6d593177, 0x7c3b0065, 0x00000000}},  //   _liel, _hawa, mtur,
  { {0x6d590127, 0x657d0065, 0x69d60065, 0x00000000}},  //   _kawa, _bosh, _thye,
  { {0x6d5b2092, 0x61e93178, 0x6d59020c, 0x00000000}},  //   ndua, _niel, _jawa,
  { {0x6d591bc5, 0xa49b0009, 0x60c93179, 0x00000000}},  // [9ea0] _mawa, _seòr, _nyem,
  { {0x6d5901a3, 0x68ed1070, 0x7c3b0032, 0x00000000}},  //   _lawa, _zgad, itur,
  { {0x61e914ae, 0x657d0065, 0xdcdd0082, 0x00000000}},  //   _biel, _fosh, _sỉlẻ_,
  { {0x6d5911ad, 0x7c3b0292, 0x61e903fd, 0x00000000}},  //   _nawa, ktur, _ciel,
  { {0x4fc6317a, 0x61e9317b, 0x7bc1317c, 0x00000000}},  //   нска, _diel, kolu,
  { {0x7c3b0190, 0x6d590058, 0x2912196c, 0x00000000}},  //   dtur, _aawa, _leya_,
  { {0x61e90038, 0x6d59317d, 0xd04e005f, 0x00000000}},  //   _fiel, _bawa, _ədəb,
  { {0xdd970057, 0x7c3b20f0, 0x6d5921e6, 0x00000000}},  //   ешь_, ftur, _cawa,
  { {0x6d591b40, 0x7c3b011c, 0x68ed00d9, 0x00000000}},  //   _dawa, gtur, _rgad,
  { {0x61e9317e, 0x09c902f4, 0x1e96017a, 0x00000000}},  //   _ziel, रत्य, _прер,
  { {0x200d001f, 0x0c730167, 0x61e9317f, 0x00000000}},  //   _zwei_, ندید, _yiel,
  { {0x6d59006a, 0x67eb0066, 0x7c3b1f37, 0x00000000}},  //   _gawa, _ażja, btur,
  { {0x7bc1011c, 0xcb6a003b, 0x69dd0c4c, 0x00000000}},  //   bolu, _наде_, rmse,
  { {0x6d592da9, 0x7bc1000d, 0xef0e007e, 0x00000000}},  //   _zawa, colu, амi_,
  { {0xa2a0001c, 0x657d008d, 0x8624004c, 0x00000000}},  //   _गेल्, _posh, льте,
  { {0xdb010f07, 0x68ed016c, 0x657d05ff, 0x00000000}},  //   vilé, _ugad, _qosh,
  { {0x61e91f38, 0x93270014, 0xf99401ce, 0x00000000}},  // [9eb0] _riel, فران, _תרפ_,
  { {0x61e93180, 0x25a20022, 0x60c90045, 0x00000000}},  //   _siel, _emkl_, _ryem,
  { {0x61e92e3f, 0x657d14ee, 0xe139007e, 0x00000000}},  //   _piel, _tosh, дзеі_,
  { {0x61e90065, 0x1c210061, 0x7c3b007f, 0x00000000}},  //   _qiel, _मिलल_, ytur,
  { {0x61e93181, 0x29d9002a, 0x6d59003f, 0x00000000}},  //   _viel, méad_, _rawa,
  { {0x61e90046, 0xdce90182, 0xa066003b, 0x00000000}},  //   _wiel, ljeć, таша_,
  { {0x44290092, 0x6d400109, 0x61e93182, 0x00000000}},  //   lra_, ffma, _tiel,
  { {0x7c3b13f0, 0x4429111b, 0x1c450088, 0x00000000}},  //   ttur, ora_, вним,
  { {0x442901f6, 0x7bc110fb, 0x6d5b3183, 0x00000000}},  //   nra_, tolu, rdua,
  { {0x44291160, 0x6d5904d4, 0xdb2300a2, 0x00000000}},  //   ira_, _wawa, دودی,
  { {0x44293184, 0x09d60055, 0x6d590d56, 0x00000000}},  //   hra_, _সংবা, _tawa,
  { {0x44290047, 0x7c3b0585, 0x00000000, 0x00000000}},  //   kra_, ptur,   ,
  { {0x2912011f, 0x44293185, 0x7d0901a3, 0x00000000}},  //   _veya_, jra_, mbes,
  { {0x44293186, 0x7afa001c, 0x70130044, 0x00000000}},  //   dra_, cctt, _সমাজ_,
  { {0x44293187, 0x65b301d5, 0x395b00ab, 0x00000000}},  //   era_, għho, _faqs_,
  { {0x7d093188, 0x8936031d, 0xf8660ceb, 0x00000000}},  //   nbes, _شعبا, _авио,
  { {0x44293189, 0xd706005e, 0x28de013d, 0x00000000}},  // [9ec0] gra_, _изпи, नेशि,
  { {0x78ad00b9, 0xdb0801e5, 0x06860139, 0x00000000}},  //   šová, yndí, _агон,
  { {0x44291d24, 0x7c29001f, 0x7d090007, 0x00000000}},  //   ara_, hrer, kbes,
  { {0x29d90051, 0x7d09318a, 0x6fcd1866, 0x00000000}},  //   céad_, jbes, lúch,
  { {0x317f01aa, 0x7d090190, 0x00000000, 0x00000000}},  //   _douz_, dbes,   ,
  { {0x7c2900d4, 0xce6a0fd8, 0x7d0920bf, 0x00000000}},  //   drer, дрид_, ebes,
  { {0x7d09021f, 0xf3f40044, 0x7c2901a2, 0x00000000}},  //   fbes, _ছবির_, erer,
  { {0x7d0918ee, 0x7c2900c4, 0x6ce601ff, 0x00000000}},  //   gbes, frer, кіпе,
  { {0xc0450151, 0x00000000, 0x00000000, 0x00000000}},  //   _مخلو,   ,   ,
  { {0xf41300b6, 0x7d0901c3, 0x00000000, 0x00000000}},  //   ספת_, abes,   ,
  { {0xc333019b, 0x7d092c04, 0x7c290843, 0x00000000}},  //   בות_, bbes, arer,
  { {0x7c290219, 0x44290635, 0x6f180059, 0x00000000}},  //   brer, yra_, lavc,
  { {0x6602016c, 0x4429002b, 0x7c290068, 0x00000000}},  //   _čoka, xra_, crer,
  { {0x44292b2b, 0x6f1801ee, 0x60180051, 0x00000000}},  //   vra_, navc, _zúmá,
  { {0x4429002b, 0x2b921125, 0x00000000, 0x00000000}},  //   wra_, _میکس,   ,
  { {0xa9c40088, 0x00000000, 0x00000000, 0x00000000}},  //   _вськ,   ,   ,
  { {0x44290a16, 0x29190127, 0xf8bf318b, 0x00000000}},  // [9ed0] ura_, masa_, rgés_,
  { {0x4429318c, 0x29190169, 0x69cf0270, 0x00000000}},  //   rra_, lasa_, llce,
  { {0x6f18037e, 0x44290ec9, 0x29d90051, 0x00000000}},  //   davc, sra_, péad_,
  { {0x4429000d, 0x29190051, 0x32640d68, 0x00000000}},  //   pra_, nasa_, штув,
  { {0x3a3e0846, 0x4429002b, 0x656f0585, 0x00000000}},  //   http_, qra_, _inch,
  { {0x25a9001c, 0x2919020c, 0x2d82318d, 0x00000000}},  //   lial_, hasa_, öken_,
  { {0x68fd001c, 0x29190032, 0xf77400a0, 0x00000000}},  //   kcsd, kasa_, יקס_,
  { {0x7c29001a, 0x61f5012d, 0x29190415, 0x00000000}},  //   trer, _iuzl, jasa_,
  { {0x7c2900eb, 0x6d950010, 0x2919013f, 0x00000000}},  //   urer, _ráad, dasa_,
  { {0x7c290ed6, 0x7d09010f, 0x656f0009, 0x00000000}},  //   rrer, sbes, _lnch,
  { {0x656f255a, 0x6fcd0027, 0x7d090116, 0x00000000}},  //   _onch, júci, pbes,
  { {0x29190058, 0x7c291f7c, 0xdb011ad4, 0x00000000}},  //   gasa_, prer, milí,
  { {0x31560049, 0x9b4506b4, 0x25a90133, 0x00000000}},  //   נישן_, _منشو, dial_,
  { {0x656f051b, 0x69cf00ca, 0x2d8d00b0, 0x00000000}},  //   _anch, alce, lkee_,
  { {0x2919006a, 0x6fcd318e, 0x00000000, 0x00000000}},  //   basa_, rúch,   ,
  { {0x29192a8f, 0x6fc50061, 0x6fcd0048, 0x00000000}},  //   casa_, ाकडू, súch,
  { {0x2bf60049, 0x69c60006, 0x036a02dc, 0x00000000}},  // [9ee0] ָמען_, moke, ниак_,
  { {0x69c6184d, 0x656f318f, 0x25bf3190, 0x00000000}},  //   loke, _ench, čula_,
  { {0x201f04bd, 0xb226007e, 0x6f183191, 0x00000000}},  //   _avui_, умел, vavc,
  { {0x05560069, 0xf67b0049, 0x69c619a7, 0x00000000}},  //   _стоя, _נאכמ, noke,
  { {0xdefa0057, 0xa0670c27, 0x80cc0044, 0x00000000}},  //   ный_, лаца_, ়েন্,
  { {0x44321a16, 0xdb1a0010, 0xcf260025, 0x00000000}},  //   muy_, kotá, ارشي,
  { {0x29191f77, 0x69cf0146, 0x69c600b0, 0x00000000}},  //   yasa_, ylce, koke,
  { {0x69c6023a, 0xdb0800c4, 0x99420036, 0x00000000}},  //   joke, cidê, _cóż_,
  { {0x69c60020, 0x4127005e, 0x443200e0, 0x00000000}},  //   doke, _щото_, nuy_,
  { {0x40930054, 0x2919252e, 0x25a93192, 0x00000000}},  //   _الكر, wasa_, zial_,
  { {0x2919003b, 0x44320082, 0xc333009b, 0x00000000}},  //   tasa_, huy_, זות_,
  { {0xdb010181, 0x61e2005b, 0x69c60032, 0x00000000}},  //   gilâ, nmol, goke,
  { {0x29193193, 0x25a906c2, 0x4432008e, 0x00000000}},  //   rasa_, vial_, juy_,
  { {0x29190020, 0x443203e5, 0x61e20cba, 0x00000000}},  //   sasa_, duy_, hmol,
  { {0x2919015e, 0x69c605ad, 0x25a90388, 0x00000000}},  //   pasa_, boke, tial_,
  { {0x555802f0, 0x69c60022, 0xdb0300f6, 0x00000000}},  //   лася_, coke, _amnè,
  { {0xdb080181, 0xe315025f, 0x3949004a, 0x00000000}},  // [9ef0] vidê, имањ, _ibas_,
  { {0x25a93194, 0x44270c8a, 0x05150044, 0x00000000}},  //   sial_, čn_, িলের_,
  { {0xd2510379, 0x7ceb0047, 0x3255007c, 0x00000000}},  //   تنا_, _körü, рвер,
  { {0x3d0e013d, 0x44323195, 0xbbd00061, 0x00000000}},  //   सरों_, buy_, हतुक,
  { {0x6536007b, 0x39490065, 0xf3ff0181, 0x00000000}},  //   _דארף_, _mbas_, _irão_,
  { {0xdb080181, 0x8e85025f, 0x61f505f9, 0x00000000}},  //   sidê, игле, _tuzl,
  { {0xed591001, 0x6d870032, 0x09d60044, 0x00000000}},  //   вой_, _oñat, _সংসা,
  { {0x9f4c01aa, 0x38690035, 0x2d8d0133, 0x00000000}},  //   _lidè_, _orar_, ukee_,
  { {0x69c63196, 0xff250014, 0x2d8d0052, 0x00000000}},  //   voke, _نبای, rkee_,
  { {0x257c00b9, 0x8b2500ed, 0x39490089, 0x00000000}},  //   _díly_, јдне, _abas_,
  { {0x69c6000b, 0xa2cb02f4, 0x2fc73197, 0x00000000}},  //   toke, _तुम्, mong_,
  { {0x2fc7066d, 0x4e940025, 0x00000000, 0x00000000}},  //   long_, _اشكر,   ,
  { {0x69c600b5, 0xa2a702d2, 0x7d1b00f2, 0x00000000}},  //   roke, _टेस्, maus,
  { {0x7d1b009f, 0x2fc7006a, 0x386902e1, 0x00000000}},  //   laus, nong_, _drar_,
  { {0x66e63198, 0x69c6000b, 0x61e20628, 0x00000000}},  //   рова, poke, ymol,
  { {0x7ceb01f6, 0x6b83050c, 0x2fc7006a, 0x00000000}},  //   _görü, _hong, hong_,
  { {0x6b833199, 0x2fc71312, 0xd6d90036, 0x00000000}},  // [9f00] _kong, kong_, ęła_,
  { {0x6b83015c, 0x2fc71372, 0xb6a60216, 0x00000000}},  //   _jong, jong_, _виол,
  { {0x2fc7006a, 0x7d1b2e23, 0xf3c9023c, 0x00000000}},  //   dong_, kaus, ابقه_,
  { {0x614601e9, 0x7d1b0997, 0x6b83319a, 0x00000000}},  //   реда, jaus, _long,
  { {0x61e2002b, 0x20560920, 0x7d1b007f, 0x00000000}},  //   rmol, ртер, daus,
  { {0x7996018e, 0x2fc7006a, 0x4420023a, 0x00000000}},  //   _llyw, gong_, msi_,
  { {0x4420000c, 0x91e615c4, 0x257c01dc, 0x00000000}},  //   lsi_, _вове, _síly_,
  { {0x44200006, 0x442200b5, 0x7d1b0006, 0x00000000}},  //   osi_, _kvk_, gaus,
  { {0x4420008a, 0x6b83000b, 0x2fc7006a, 0x00000000}},  //   nsi_, _bong, bong_,
  { {0x4420021e, 0x23c6013d, 0xbea60245, 0x00000000}},  //   isi_, वविद, _казк,
  { {0x7d1b0171, 0x6e210009, 0x799601d6, 0x00000000}},  //   baus, _gvlb, _blyw,
  { {0x4420319b, 0x7d1b0038, 0x8c46004c, 0x00000000}},  //   ksi_, caus, _веде,
  { {0xfce61281, 0x6b830f57, 0x44200161, 0x00000000}},  //   _тодо, _fong, jsi_,
  { {0x6b830056, 0x395f0dec, 0x8c1b00a3, 0x00000000}},  //   _gong, žus_, _יודי,
  { {0x7c22137b, 0x61410047, 0x7bc8002d, 0x00000000}},  //   _hvor, náló, modu,
  { {0x4420000b, 0x3915003b, 0x7c2201ee, 0x00000000}},  //   fsi_, _умир, _kvor,
  { {0x2fc7006a, 0xe4e701fb, 0x6b8304e2, 0x00000000}},  // [9f10] yong_, рівн, _yong,
  { {0x7d1b0006, 0x47353139, 0x7bc80145, 0x00000000}},  //   zaus, _унос, nodu,
  { {0x4420319c, 0x7d1b0045, 0x2fc702d4, 0x00000000}},  //   asi_, yaus, vong_,
  { {0xf650026c, 0xdb080129, 0x2fc709f3, 0x00000000}},  //   _کئی_, sidè, wong_,
  { {0x44200047, 0x2fc7319d, 0x55760049, 0x00000000}},  //   csi_, tong_, _הערן_,
  { {0x645d319e, 0x7d0200e5, 0x00000000, 0x00000000}},  //   _issi, _afos,   ,
  { {0x2fc7006a, 0x22950054, 0xce18008b, 0x00000000}},  //   rong_, _الأس, ацыі_,
  { {0x2fc7319f, 0x6b8300ab, 0x56b8009b, 0x00000000}},  //   song_, _song, יפון_,
  { {0x7d1b0109, 0x6b830211, 0x2fc70760, 0x00000000}},  //   raus, _pong, pong_,
  { {0x7c2204a9, 0x6b9a01aa, 0x7d1b010f, 0x00000000}},  //   _dvor, ghtg, saus,
  { {0x7d1b0778, 0x6b8301e5, 0x44200458, 0x00000000}},  //   paus, _vong, zsi_,
  { {0x44200e34, 0x645d01bc, 0x3f8501e5, 0x00000000}},  //   ysi_, _ossi, _holu_,
  { {0x4420005f, 0x8d5a009b, 0x31560049, 0x00000000}},  //   xsi_, _תכני, זירן_,
  { {0x4420037e, 0x6b83000b, 0x6b9a111d, 0x00000000}},  //   vsi_, _uong, chtg,
  { {0x645d0335, 0x7c220521, 0xdb1a0051, 0x00000000}},  //   _assi, _zvor, altó,
  { {0x7d19000a, 0xe5a30867, 0xdb080232, 0x00000000}},  //   _jews, писи, vidé,
  { {0x7b060047, 0x4420010a, 0x03261969, 0x00000000}},  // [9f20] _érté, usi_, йдан,
  { {0x44201b3e, 0x4422037f, 0xdb08009d, 0x00000000}},  //   rsi_, _vvk_, tidé,
  { {0x216a2d6f, 0x442201c3, 0x00000000, 0x00000000}},  //   лижи_, _wvk_,   ,
  { {0xf1a501fb, 0x29020450, 0x765e00e0, 0x00000000}},  //   орін, ncka_, _ispy,
  { {0x442031a0, 0x3f85014a, 0x629e0f88, 0x00000000}},  //   qsi_, _bolu_, szpo,
  { {0xd8d70049, 0x6d4b010f, 0xdb080051, 0x00000000}},  //   זונט_, _abga, pidé,
  { {0x7c220006, 0x3f8531a1, 0x644400b0, 0x00000000}},  //   _svor, _dolu_, ltii,
  { {0x6564011c, 0x61430816, 0x7bc80036, 0x00000000}},  //   ndih, _неса, wodu,
  { {0x91e30001, 0x61fe001c, 0x64440943, 0x00000000}},  //   _хоте, lqpl, ntii,
  { {0x69df0065, 0x29020024, 0x7c200009, 0x00000000}},  //   _shqe, ecka_, rsmr,
  { {0x7bc801d5, 0x64d502fb, 0x644400b0, 0x00000000}},  //   rodu, _दर्श, htii,
  { {0x7c220027, 0x644408b2, 0x7bc80035, 0x00000000}},  //   _tvor, ktii, sodu,
  { {0x399b008d, 0xa3d8062e, 0x3f850279, 0x00000000}},  //   _nëse_, ाता_, _yolu_,
  { {0x0a9417fa, 0xaa940fd8, 0x6f1a0068, 0x00000000}},  //   _малю, _милч, _jetc,
  { {0x5694008b, 0xa143001e, 0x644f012d, 0x00000000}},  //   парт, šķir, _spci,
  { {0x6f1a0062, 0x69cd1126, 0x7df10089, 0x00000000}},  //   _letc, _ukae, _jāsp,
  { {0x765e0173, 0x64440058, 0x5fba007d, 0x00000000}},  // [9f30] _espy, gtii, ेवाल,
  { {0x6f1a0082, 0xed5900ca, 0x6d9c0048, 0x00000000}},  //   _netc, roži_, _héad,
  { {0x72b90025, 0xd6d90014, 0xa5f9012b, 0x00000000}},  //   جهاز_, _خودش_, _њему_,
  { {0x8f6a00a1, 0x3f850095, 0x00000000, 0x00000000}},  //   یلنے_, _solu_,   ,
  { {0x6d9c0051, 0x3f85150d, 0x6444001a, 0x00000000}},  //   _méad, _polu_, ctii,
  { {0x3f690088, 0x7a010089, 0x2a97013f, 0x00000000}},  //   рико_, _lēta, səbə_,
  { {0xfebb01ef, 0x29020039, 0x62341969, 0x00000000}},  //   داشت_, ycka_, _неру,
  { {0x7dc50010, 0x236300e7, 0x6f1a00d9, 0x00000000}},  //   lósz, _hajj_, _eetc,
  { {0xa2b9007d, 0x60db164f, 0xeb9900aa, 0x00000000}},  //   ्थव्, _uzum, иии_,
  { {0x6f1a0061, 0x5ba90140, 0x3a25030d, 0x00000000}},  //   _getc, рком_, омог,
  { {0xdcfb0f3a, 0xc33200a0, 0x2fc00051, 0x00000000}},  //   ljuč, ווי_, éige_,
  { {0x6d9c2d2e, 0x644400b0, 0x00000000, 0x00000000}},  //   _réag, ytii,   ,
  { {0xe45f021e, 0x29020145, 0x00000000, 0x00000000}},  //   _myös_, rcka_,   ,
  { {0x1af30044, 0x6d490048, 0x6d9c009d, 0x00000000}},  //   _আজকে_, lfea, _péag,
  { {0xba77007a, 0x6d9c002a, 0x00000000, 0x00000000}},  //   _داشت, _féad,   ,
  { {0x6444021e, 0x29d90051, 0xf50a041f, 0x00000000}},  //   ttii, néal_, рнал_,
  { {0x92d60055, 0xd467026b, 0x6d490051, 0x00000000}},  // [9f40] _হলে_, оите_, ifea,
  { {0x32d60373, 0x3860002b, 0x6444010e, 0x00000000}},  //   оцес, _isir_, rtii,
  { {0x64440368, 0x66e60a7c, 0x00000000, 0x00000000}},  //   stii, _фона,   ,
  { {0x6f1a0009, 0x644431a2, 0x00000000, 0x00000000}},  //   _setc, ptii,   ,
  { {0xe0560151, 0x6f1a121e, 0x29d90051, 0x00000000}},  //   تخاب, _petc, déal_,
  { {0x44320016, 0x9e06013b, 0x68e9013f, 0x00000000}},  //   mry_, очил, ümdə,
  { {0xdd9a0175, 0x59ca0204, 0x44320531, 0x00000000}},  //   иши_, रवार, lry_,
  { {0x443200ab, 0x127b0049, 0x6d490048, 0x00000000}},  //   ory_, _דאלע, gfea,
  { {0x61fc009d, 0x6d9c0ea5, 0x4432112b, 0x00000000}},  //   _hurl, _réad, nry_,
  { {0x0b8a022a, 0x39400089, 0x44320145, 0x00000000}},  //   рсии_, _acis_, iry_,
  { {0x9d460001, 0x443204bb, 0x8aa302d3, 0x00000000}},  //   _межд, hry_, дряд,
  { {0x44320343, 0x61fc005b, 0x29d90051, 0x00000000}},  //   kry_, _murl, céal_,
  { {0x92d60055, 0x9f4c00b9, 0xf77303e6, 0x00000000}},  //   _হলো_, _lidí_, واس_,
  { {0x44320395, 0xdceb0089, 0x61fc0068, 0x00000000}},  //   dry_, _ungā, _ourl,
  { {0x99d70a4f, 0x44320339, 0x67d40256, 0x00000000}},  //   _وتعا, ery_, фору,
  { {0x62831469, 0x44320395, 0x00000000, 0x00000000}},  //   änom, fry_,   ,
  { {0xb9c40054, 0x443231a3, 0x395923d6, 0x00000000}},  // [9f50] _تقيي, gry_, mess_,
  { {0x39590038, 0xef1f0036, 0xb4db00f6, 0x00000000}},  //   less_, ążka_, _acàc,
  { {0xe7f9001c, 0x443200ab, 0x61fc03ce, 0x00000000}},  //   ंदवा_, ary_, _curl,
  { {0x39590038, 0x443218d5, 0xe1f8008b, 0x00000000}},  //   ness_, bry_, ігі_,
  { {0xf99400b3, 0xd0ab00ed, 0xa2cb006e, 0x00000000}},  //   ורף_, јтед_, _तुर्,
  { {0x61fc00ca, 0xa3d30061, 0xf8380104, 0x00000000}},  //   _furl, _हीच_, קנות_,
  { {0x61fc103f, 0xfe5700a1, 0xc7b4009b, 0x00000000}},  //   _gurl, تیاب_, ובס_,
  { {0x39590ee1, 0xc1770123, 0x00000000, 0x00000000}},  //   jess_, _بدست,   ,
  { {0x29d900f4, 0x6d490051, 0x9f8901e5, 0x00000000}},  //   réal_, rfea, búð_,
  { {0x290d002d, 0xeb99003b, 0x6d490d28, 0x00000000}},  //   ñean_, сио_, sfea,
  { {0xa96a003b, 0x3860002b, 0x8a0500a5, 0x00000000}},  //   бина_, _ssir_, язне,
  { {0x76470030, 0x499a004d, 0xc7a9009b, 0x00000000}},  //   dtjy, стоя_, _גב_,
  { {0x3d110061, 0xdb0100b0, 0x00000000, 0x00000000}},  //   _ध्ये_, tilä,   ,
  { {0xfaa51023, 0xed5931a4, 0x44320007, 0x00000000}},  //   _нало, lež_, vry_,
  { {0xa596005e, 0x395901c5, 0x70b8007d, 0x00000000}},  //   пращ, bess_, _अश्ल,
  { {0x39590038, 0xf99f31a5, 0x39400035, 0x00000000}},  //   cess_, chè_, _ucis_,
  { {0x44321882, 0x38600022, 0x2d9f004a, 0x00000000}},  // [9f60] ury_, _usir_, ihue_,
  { {0x4432190f, 0x61fc0190, 0x00000000, 0x00000000}},  //   rry_, _purl,   ,
  { {0xe71700b6, 0x7f58001c, 0xdb0800c4, 0x00000000}},  //   _מחיר_, vevq, lidã,
  { {0xc693007b, 0x7c2609fc, 0x0f14006e, 0x00000000}},  //   _נאר_, škri, डर्स_,
  { {0xed592794, 0x6d9c0051, 0x6566000a, 0x00000000}},  //   dež_, _léac, _iakh,
  { {0x8fa301fb, 0xa2a7006e, 0x8f340264, 0x00000000}},  //   наче, _टेक्, фекц,
  { {0xaff600a1, 0x6d9c0ea5, 0x9f4411c4, 0x00000000}},  //   _کہتا_, _réab, _sumó_,
  { {0x25a01372, 0xfe6f0257, 0x7a010089, 0x00000000}},  //   nhil_, ادو_, _pētn,
  { {0x6566003f, 0xf0440123, 0xdb08004a, 0x00000000}},  //   _makh, _تعزی, sidí,
  { {0x65660010, 0x25bf2dff, 0x00000000, 0x00000000}},  //   _lakh, čuli_,   ,
  { {0x395901d5, 0x25a00145, 0x00000000, 0x00000000}},  //   tess_, khil_,   ,
  { {0x65660085, 0x2d9f0068, 0x00000000, 0x00000000}},  //   _nakh, chue_,   ,
  { {0xf3ff0011, 0x6d42001a, 0x25a001a3, 0x00000000}},  //   _trãi_, _icoa, dhil_,
  { {0x6d9c002a, 0x39590e40, 0x65660087, 0x00000000}},  //   _féac, sess_, _aakh,
  { {0x1db001f5, 0x65660145, 0x395930a3, 0x00000000}},  //   _जगात, _bakh, pess_,
  { {0x98b90089, 0xdb0800d4, 0x1dcc0204, 0x00000000}},  //   nesī_, lidà, ावित,
  { {0x69cf0062, 0x76470030, 0x7a0800b9, 0x00000000}},  // [9f70] moce, stjy, _děte,
  { {0x69cf31a6, 0x889c009b, 0x00000000, 0x00000000}},  //   loce, _לבחי,   ,
  { {0x65660145, 0xdb1a0023, 0x00000000, 0x00000000}},  //   _fakh, entë,   ,
  { {0x25a000b5, 0x69cf0781, 0x00000000, 0x00000000}},  //   chil_, noce,   ,
  { {0x1b220055, 0xed590bf8, 0x2378016c, 0x00000000}},  //   _মানে_, vež_, _fnrj_,
  { {0x6566191a, 0x69cf0062, 0x00000000, 0x00000000}},  //   _zakh, hoce,   ,
  { {0x443b2cfa, 0x69cf016c, 0xdb0800f6, 0x00000000}},  //   luq_, koce, didà,
  { {0x6d9c00f4, 0x96270089, 0x7c950081, 0x00000000}},  //   _réac, _ieņē, дроц,
  { {0xcc890014, 0x16040061, 0x1c42007c, 0x00000000}},  //   زنده_, _शंभर_, вным,
  { {0x7d030010, 0x6d4200fa, 0xdb0800c4, 0x00000000}},  //   _bíró, _ecoa, vidã,
  { {0x69cf013e, 0x52db006e, 0x7e7e0039, 0x00000000}},  //   foce, _भरोस, äppt,
  { {0x69cf00ca, 0xdb0800c4, 0x2d8218ee, 0x00000000}},  //   goce, tidã, öket_,
  { {0x656627da, 0x6d5b00e7, 0x66e70010, 0x00000000}},  //   _rakh, meua, yéké,
  { {0x6d9c0051, 0xdb0800c4, 0x7c3b044e, 0x00000000}},  //   _téac, ridã, muur,
  { {0xd5b20025, 0x656605a6, 0x69cf00e5, 0x00000000}},  //   نفس_, _pakh, boce,
  { {0x69cf00d4, 0xdb1a00f4, 0x00000000, 0x00000000}},  //   coce, entè,   ,
  { {0xb9b30025, 0xdb0812dd, 0x98a6003b, 0x00000000}},  // [9f80] _جميع, lidá, _ципе,
  { {0x61b80201, 0x6d5b0016, 0x25a00023, 0x00000000}},  //   ेक्ष, heua, shil_,
  { {0x656631a7, 0x7c3b00bb, 0x57da0061, 0x00000000}},  //   _takh, huur, णतीह,
  { {0xe0da0265, 0x7c3b01b1, 0x00000000, 0x00000000}},  //   ове_, kuur,   ,
  { {0x9fca007c, 0x4fc603e0, 0x75241eca, 0x00000000}},  //   огда_, мска, maiz,
  { {0x09bb02f4, 0x6d42000d, 0x75240e07, 0x00000000}},  //   _उद्य, _scoa, laiz,
  { {0x7e2a007e, 0x00000000, 0x00000000, 0x00000000}},  //   ціла_,   ,   ,
  { {0x71760a90, 0x75240459, 0x00000000, 0x00000000}},  //   _تهرا, naiz,   ,
  { {0x69cf31a8, 0xe0430242, 0x7c3b017d, 0x00000000}},  //   voce, _инти, guur,
  { {0x547b01ce, 0x752431a9, 0x2d9d01c3, 0x00000000}},  //   קטיו, haiz, _elwe_,
  { {0x69cf00d0, 0xd33700b6, 0x3f9b009d, 0x00000000}},  //   toce, וריה_, êque_,
  { {0x38720039, 0x443b006b, 0x497416e8, 0x00000000}},  //   _bryr_, yuq_, влюс,
  { {0x3f8c078f, 0xc3240044, 0x7dde0065, 0x00000000}},  //   _kodu_, _পানি_, lëso,
  { {0xeaaf01ef, 0xac97007a, 0xd90f00a6, 0x00000000}},  //   اعی_, _تنها_, دیک_,
  { {0x69cf0107, 0x3f8c002d, 0x7dde0023, 0x00000000}},  //   poce, _modu_, nëso,
  { {0x7bda056d, 0x693600b9, 0x75240032, 0x00000000}},  //   lltu, _přež, gaiz,
  { {0xdb1a009d, 0x7dde0023, 0x3375007e, 0x00000000}},  // [9f90] enté, hëso, нгар,
  { {0x7dde0065, 0xdce20091, 0x443b2cfa, 0x00000000}},  //   këso, _naoč, ruq_,
  { {0xe3c30044, 0x200d31aa, 0x443b0066, 0x00000000}},  //   ্গলব, _stei_, suq_,
  { {0x59f9007b, 0x3f9e0e57, 0x00000000, 0x00000000}},  //   פּעד, _altu_,   ,
  { {0x443b006b, 0x3f8c0161, 0x00000000, 0x00000000}},  //   quq_, _bodu_,   ,
  { {0x44291a7b, 0xdee5004d, 0x6d400116, 0x00000000}},  //   msa_, ноли, egma,
  { {0x5334012b, 0xdb0831ab, 0x6d870288, 0x00000000}},  //   _јест, xidá, _iñaz,
  { {0x7c3b02ae, 0x6d4000f8, 0x7bda00bb, 0x00000000}},  //   tuur, ggma, eltu,
  { {0x442931ac, 0x442b0253, 0x6d5b005b, 0x00000000}},  //   nsa_, _jvc_, reua,
  { {0x442902d5, 0x2d820039, 0xdaa90081, 0x00000000}},  //   isa_, öker_, звод_,
  { {0xd94601be, 0x752f0036, 0x442b00bb, 0x00000000}},  //   нени, _odcz, _lvc_,
  { {0x3f87037e, 0xa96a003b, 0x442b0042, 0x00000000}},  //   ljnu_, чима_, _ovc_,
  { {0xaacf02d2, 0xb90802fb, 0x75240006, 0x00000000}},  //   _सुरक, _भर_, vaiz,
  { {0x7d090420, 0x44290142, 0x57da0061, 0x00000000}},  //   lces, dsa_, णतेह,
  { {0x7c290193, 0x44290207, 0xdce20089, 0x00000000}},  //   lser, esa_, _bloķ,
  { {0x7d09051b, 0x44291fbc, 0x442b2b32, 0x00000000}},  //   nces, fsa_, _bvc_,
  { {0x4429000c, 0x75240032, 0xb4ea0061, 0x00000000}},  // [9fa0] gsa_, raiz, मधे_,
  { {0x68e40059, 0x6d9c00f4, 0x00000000, 0x00000000}},  //   _izid, _néan,   ,
  { {0x44290127, 0x7d090036, 0x442b2886, 0x00000000}},  //   asa_, kces, _evc_,
  { {0x7d090ebe, 0x442931ad, 0x7c290056, 0x00000000}},  //   jces, bsa_, kser,
  { {0x44290010, 0xe8140061, 0x7c290190, 0x00000000}},  //   csa_, तीचा_, jser,
  { {0x7c2931ae, 0x6d9c002a, 0x7dde0065, 0x00000000}},  //   dser, _céan, tëso,
  { {0x6d9c002a, 0x3f8c0209, 0xa3b5006e, 0x00000000}},  //   _déan, _vodu_, _जगत_,
  { {0x7dde0065, 0x7bc301f3, 0x26080061, 0x00000000}},  //   rëso, _ajnu, _ांनी_,
  { {0x6d4000f8, 0x00000000, 0x00000000, 0x00000000}},  //   rgma,   ,   ,
  { {0x6d9c009d, 0x8c530379, 0x1fb501fc, 0x00000000}},  //   _géan, ائيا, _исхр,
  { {0x53370049, 0x44290148, 0x7dde0065, 0x00000000}},  //   ענטן_, zsa_, qëso,
  { {0x442925e1, 0x7c290056, 0x7d09130f, 0x00000000}},  //   ysa_, bser, cces,
  { {0x4429006b, 0x7c290010, 0xc173009b, 0x00000000}},  //   xsa_, cser, אחר_,
  { {0x5c97008b, 0x499300a1, 0x69d60009, 0x00000000}},  //   _якія_, ئیکر, _ekye,
  { {0x36d5025f, 0x6be30025, 0x442931af, 0x00000000}},  //   товр, _حكوم, wsa_,
  { {0x44291e17, 0xfa7700a0, 0xd0080044, 0x00000000}},  //   tsa_, _טעות_, রীয়_,
  { {0x442931b0, 0x2458007c, 0xf3f900ed, 0x00000000}},  // [9fb0] usa_, нать_, днаш_,
  { {0x4429081d, 0x69dd0129, 0x61c902f4, 0x00000000}},  //   rsa_, llse, िक्ष,
  { {0x44290f3c, 0xa2d4007d, 0x290b0026, 0x00000000}},  //   ssa_, _बुद्, occa_,
  { {0x442931b1, 0x518401be, 0x6d9c2d2e, 0x00000000}},  //   psa_, луча, _séan,
  { {0x3f69003b, 0x657d0cd1, 0x4429178e, 0x00000000}},  //   дило_, _insh, qsa_,
  { {0x644d0995, 0x656d06ce, 0x00000000, 0x00000000}},  //   mtai, ldah,   ,
  { {0x7c290bc7, 0x644d31b2, 0x8fa2007c, 0x00000000}},  //   wser, ltai, раще,
  { {0x656d027c, 0x67271fec, 0xdb1a115b, 0x00000000}},  //   ndah, hajj, kotó,
  { {0x644d032c, 0xdd8e0025, 0x6d9c0051, 0x00000000}},  //   ntai, توي_, _téan,
  { {0x7d090197, 0x644d00f4, 0x6727008e, 0x00000000}},  //   sces, itai, jajj,
  { {0x644d31b2, 0x657d0066, 0x61e90068, 0x00000000}},  //   htai, _onsh, _khel,
  { {0x7c2901ee, 0x61fb0cb6, 0x644d31b3, 0x00000000}},  //   pser, _jiul, ktai,
  { {0x8c4500ed, 0x201f000a, 0x61e9005b, 0x00000000}},  //   _реле, _jwui_, _mhel,
  { {0x69dd006c, 0x2d8f00b5, 0x644d2d60, 0x00000000}},  //   alse, _hoge_, dtai,
  { {0x644d0006, 0x9f450051, 0xfaf80089, 0x00000000}},  //   etai, _chlé_, udīt_,
  { {0x656d1fe8, 0x61fb00e7, 0x00000000, 0x00000000}},  //   gdah, _niul,   ,
  { {0x60db000b, 0x644d05a0, 0x2d8f31b4, 0x00000000}},  // [9fc0] _nyum, gtai, _moge_,
  { {0x61e9006c, 0x93cb00a1, 0xf53f0190, 0x00000000}},  //   _ahel, والہ_, _småt_,
  { {0x23a40039, 0x60db03e5, 0x644d0051, 0x00000000}},  //   _nöje_, _ayum, atai,
  { {0x61e9001a, 0x60db0dfc, 0x2d8f0059, 0x00000000}},  //   _chel, _byum, _noge_,
  { {0xd0070265, 0x60db0009, 0x1b220044, 0x00000000}},  //   вече_, _cyum, _মাসে_,
  { {0xdefa0057, 0x61e902fa, 0xdb010048, 0x00000000}},  //   мый_, _ehel, bhlé,
  { {0x764e0061, 0x2d8f00ea, 0x29000032, 0x00000000}},  //   ntby, _boge_, _ogia_,
  { {0x61fb0207, 0x91e60072, 0x2d8f008e, 0x00000000}},  //   _giul, _робе, _coge_,
  { {0x2d8f04c6, 0x9f4c00b0, 0x2a670145, 0x00000000}},  //   _doge_, _pidä_, _asnb_,
  { {0x61e931b5, 0x00000000, 0x00000000, 0x00000000}},  //   _zhel,   ,   ,
  { {0x6b9a054e, 0x644d2efd, 0x2d8f00c4, 0x00000000}},  //   rktg, ztai, _foge_,
  { {0x20040020, 0x61e90065, 0xf2d300b3, 0x00000000}},  //   _kumi_, _xhel, יעת_,
  { {0x1d07012b, 0x69dd0190, 0x7e680082, 0x00000000}},  //   _речи_, rlse, _hsdp,
  { {0xa2cb001c, 0x2900002d, 0xc7c4007c, 0x00000000}},  //   _तुझ्, _egia_, асси,
  { {0x6d9c002a, 0xb9090044, 0xdb1a0048, 0x00000000}},  //   _léam, _বল_, nntí,
  { {0x644d021e, 0x67270869, 0xa3b503d7, 0x00000000}},  //   ttai, sajj, _जगह_,
  { {0x6d9c0ad5, 0x657d0011, 0x656d01a3, 0x00000000}},  // [9fd0] _réal, _vnsh, rdah,
  { {0x799d0142, 0x61e900ab, 0x61fb0006, 0x00000000}},  //   lksw, _shel, _siul,
  { {0x720500a1, 0x644d31b6, 0xe9df0048, 0x00000000}},  //   اہرہ_, stai, olú_,
  { {0x656d001c, 0x200404cb, 0x657d0784, 0x00000000}},  //   qdah, _bumi_, _unsh,
  { {0x200431b7, 0x7dde0065, 0x63b70045, 0x00000000}},  //   _cumi_, mësh, pixn,
  { {0x60db08c1, 0x889c009b, 0x20040058, 0x00000000}},  //   _vyum, ובדי, _dumi_,
  { {0x61e9008d, 0x28da0164, 0x6d9c0051, 0x00000000}},  //   _thel, _युनि, _téal,
  { {0x61e931b8, 0x20040197, 0x60c90e65, 0x00000000}},  //   _uhel, _fumi_, _txem,
  { {0xa3d80061, 0x60db014a, 0x20040232, 0x00000000}},  //   ातच_, _uyum, _gumi_,
  { {0xceeb0151, 0x3949005b, 0x7dde0023, 0x00000000}},  //   _قران_, _acas_, hësh,
  { {0x7dde0065, 0x2d8f31b9, 0x38691aa1, 0x00000000}},  //   kësh, _toge_, _asar_,
  { {0x98b202b9, 0xcd2b00a6, 0x200431ba, 0x00000000}},  //   _sayı_, _آسان_, _yumi_,
  { {0x7d1b2340, 0x98b2019a, 0x6725032e, 0x00000000}},  //   mbus, _payı_, _behj,
  { {0x7d1b139b, 0x6c3200a1, 0x366a007e, 0x00000000}},  //   lbus, _افوا, наго_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xceb20097, 0x764e31bb, 0x7c3b00bb, 0x00000000}},  //   צין_, rtby, orur,
  { {0x69db007b, 0x29d9009d, 0x764e31bc, 0x00000000}},  // [9fe0] _אַזו, réat_, stby,
  { {0x6d9c31bd, 0x1c1b007d, 0x20040b55, 0x00000000}},  //   _réam, पीएल_, _rumi_,
  { {0x77f7012e, 0xdb9a0049, 0x20040087, 0x00000000}},  //   _תמיד_, עסער, _sumi_,
  { {0x200431be, 0x32170014, 0x29d931bf, 0x00000000}},  //   _pumi_, ايند_, léar_,
  { {0x25d7012e, 0x7d1b0a5e, 0xdfda005e, 0x00000000}},  //   _תוכן_, dbus, нък_,
  { {0x7dde0023, 0x7c3b0288, 0x44220145, 0x00000000}},  //   mësi, drur, _iwk_,
  { {0x7dde0065, 0x4422109d, 0x7526000a, 0x00000000}},  //   lësi, _hwk_, _kekz,
  { {0x6d9c002a, 0xcbc00044, 0x20040145, 0x00000000}},  //   _téam, _উঠেছ, _tumi_,
  { {0x5b26045a, 0x7dde0065, 0x394900d9, 0x00000000}},  //   льна, nësi, _rcas_,
  { {0x7d1b00e0, 0x44221b1f, 0x4a5401ee, 0x00000000}},  //   abus, _mwk_, акос,
  { {0x7dde0065, 0xdee6034b, 0x00000000, 0x00000000}},  //   hësi, _сожи,   ,
  { {0x7dde0065, 0x7c3b00e7, 0x7d1d01e5, 0x00000000}},  //   kësi, brur, ðsst,
  { {0x7c3b001a, 0x799d01d6, 0xe9df0051, 0x00000000}},  //   crur, rksw, rlú_,
  { {0x6605042b, 0xa49b0082, 0x2fc00048, 0x00000000}},  //   _puhk, _ngòa, éigh_,
  { {0x8af6006b, 0x442201a3, 0x7dde0065, 0x00000000}},  //   şəbb, _awk_, tësh,
  { {0x7c2217a9, 0x39491e11, 0x442201a3, 0x00000000}},  //   _kwor, _ucas_, _bwk_,
  { {0x38690df3, 0x7dde0065, 0x7d0200e7, 0x00000000}},  // [9ff0] _usar_, rësh, _mgos,
  { {0x1755005e, 0x660505e0, 0x44f406b6, 0x00000000}},  //   _твоя, _tuhk, спус,
  { {0x316d004a, 0x00000000, 0x00000000, 0x00000000}},  //   _paez_,   ,   ,
  { {0xd567017a, 0xf99f01aa, 0x7dde0023, 0x00000000}},  //   _стоп, nkè_, bësi,
  { {0xa0690175, 0xc3240055, 0x656f0016, 0x00000000}},  //   тала_, _পারি_, _iach,
  { {0x656f1063, 0x645d00e7, 0x25a901a3, 0x00000000}},  //   _hach, _ipsi, lhal_,
  { {0x656f0263, 0x244f1abf, 0x7d1b0a34, 0x00000000}},  //   _kach, lüm_, tbus,
  { {0x7c3b0a16, 0x25a900c4, 0x7c220f36, 0x00000000}},  //   trur, nhal_, _bwor,
  { {0x656f31c0, 0x7d1b08a8, 0x244f014a, 0x00000000}},  //   _mach, rbus, nüm_,
  { {0x656f0263, 0xeb99012b, 0x7d1b0bf3, 0x00000000}},  //   _lach, тио_, sbus,
  { {0x244f006b, 0xdd8e02fd, 0x7d1b00f6, 0x00000000}},  //   hüm_, سوی_, pbus,
  { {0x656f001f, 0x645d1915, 0xdb010051, 0x00000000}},  //   _nach, _opsi, mhlí,
  { {0x25a90022, 0x6d590009, 0x93e50061, 0x00000000}},  //   dhal_, _ibwa, कताच_,
  { {0xdca2003b, 0x656f31c1, 0x2d8d01d6, 0x00000000}},  //   _фаши, _aach, ljee_,
  { {0x645d010a, 0xb8fd0164, 0xdb0101aa, 0x00000000}},  //   _apsi, _तु_, bilò,
  { {0x7dde008d, 0x25a90232, 0x4422033b, 0x00000000}},  //   tësi, ghal_, _pwk_,

  { {0x656f1440, 0x6fdf00f4, 0x04460088, 0x00000000}},  // [a000] _dach, pêch, резн,
  { {0x7dde008d, 0x656f0051, 0xd76402fd, 0x00000000}},  //   rësi, _each, _اندی,
  { {0x656f31c2, 0x6d5931c3, 0x25a90051, 0x00000000}},  //   _fach, _obwa, bhal_,
  { {0xd2e603d7, 0x25a90161, 0x7dde0065, 0x00000000}},  //   _करीब_, chal_, pësi,
  { {0x7dde0065, 0x69c60232, 0x442201c3, 0x00000000}},  //   qësi, inke, _uwk_,
  { {0x656f0395, 0x0877007b, 0x65640706, 0x00000000}},  //   _zach, יענט_, leih,
  { {0x7c220133, 0x00000000, 0x00000000, 0x00000000}},  //   _swor,   ,   ,
  { {0x25a027d6, 0xdceb014a, 0x65a3006c, 0x00000000}},  //   nkil_, _algı, _lõhn,
  { {0x7f860167, 0xa06700d7, 0x9da7005e, 0x00000000}},  //   _پلان, _ката_, ръща_,
  { {0x61e20ba0, 0x2912000b, 0x6d5900e7, 0x00000000}},  //   llol, _afya_, _ebwa,
  { {0xc33301f8, 0x7ac60088, 0xa4e30309, 0x00000000}},  //   חות_, рспе, _खर्च_,
  { {0x7c220046, 0x61e2011c, 0x7d020166, 0x00000000}},  //   _twor, nlol, _ugos,
  { {0xdd8f0439, 0xf99f0026, 0xa49b00f6, 0x00000000}},  //   _تون_, rkè_, _agòn,
  { {0x656f001f, 0x69c60190, 0x00000000, 0x00000000}},  //   _sach, anke,   ,
  { {0x656f001a, 0x25f30061, 0x25a90d29, 0x00000000}},  //   _pach, ंगली_, thal_,
  { {0xaacf0061, 0x244f0095, 0x00000000, 0x00000000}},  //   _सुटक, tüm_,   ,
  { {0x656f009d, 0x25a90279, 0x9f450051, 0x00000000}},  // [a010] _vach, rhal_, _shlí_,
  { {0x656f31c4, 0x9f5e008d, 0x0a51026c, 0x00000000}},  //   _wach, _ditë_, _بھیج,
  { {0x656f0016, 0xed5931c5, 0x7dde0023, 0x00000000}},  //   _tach, liže_, lësu,
  { {0x656f0051, 0x61e20058, 0xeaa600a1, 0x00000000}},  //   _uach, glol, _ہٹ_,
  { {0xed59016c, 0x7dde0065, 0x2067003b, 0x00000000}},  //   niže_, nësu, рђев,
  { {0xeaa600a1, 0x94f6009b, 0x00000000, 0x00000000}},  //   _فٹ_, _לצרף_,   ,
  { {0xed590a78, 0x61e2014a, 0x2d8d00d9, 0x00000000}},  //   гой_, blol, tjee_,
  { {0xf1a700ed, 0xdb1a31c6, 0x0d850088, 0x00000000}},  //   _тргн, litè, слин,
  { {0x2d8d086a, 0x00000000, 0x00000000, 0x00000000}},  //   rjee_,   ,   ,
  { {0xed5904eb, 0x2d9f316d, 0x4a4531c7, 0x00000000}},  //   diže_, skue_, бнов,
  { {0x752d0020, 0x7bca00f6, 0xc8690104, 0x00000000}},  //   kaaz, _djfu, _רן_,
  { {0x6d5931c8, 0xfe700014, 0x00000000, 0x00000000}},  //   _ubwa, _زدم_,   ,
  { {0x69c601e5, 0xf1b20049, 0x7dde0023, 0x00000000}},  //   rnke, לסט_, tësv,
  { {0x6d4926d1, 0x656401a2, 0x00000000, 0x00000000}},  //   lgea, weih,   ,
  { {0x78c1005f, 0x66e6007c, 0xdb1a0065, 0x00000000}},  //   _əvvə, сова, zitë,
  { {0x6d4907cd, 0x7a1300e5, 0x00000000, 0x00000000}},  //   ngea, _căte,   ,
  { {0x6d490051, 0x65641744, 0xf746003b, 0x00000000}},  // [a020] igea, reih, _лепо,
  { {0x25a014f7, 0x7dde0023, 0x00000000, 0x00000000}},  //   skil_, qësv,   ,
  { {0xb5ca03ec, 0x61e20087, 0xa56401b2, 0x00000000}},  //   _مودم_, tlol, _وگرن,
  { {0x614631c9, 0xd76402fd, 0x7a130035, 0x00000000}},  //   седа, _انگی, _găte,
  { {0x205601bd, 0xe3b1026c, 0x61e20058, 0x00000000}},  //   стер, سرے_, rlol,
  { {0xdb1a0065, 0xe0850025, 0x33d50088, 0x00000000}},  //   ritë, تجمي, _діст,
  { {0x9abc002b, 0x91e602dc, 0x00000000, 0x00000000}},  //   paċi, _гове,   ,
  { {0xdb1a263c, 0xb8000044, 0x7d9831ca, 0x00000000}},  //   mité, ্ঠিত_, рвис_,
  { {0xdb1a31cb, 0x44320665, 0xfd0f0076, 0x00000000}},  //   lité, nsy_, رجي_,
  { {0x6d490009, 0x798400d9, 0x4432009d, 0x00000000}},  //   agea, _aniw, isy_,
  { {0xdb1a009d, 0xaa582c00, 0x38600058, 0x00000000}},  //   nité, шину_, _apir_,
  { {0x394d31cc, 0x7dde0065, 0x63be244a, 0x00000000}},  //   ües_, tësu, hipn,
  { {0xac94005e, 0x80da0044, 0x629e1fc2, 0x00000000}},  //   _фалш, _বৃত্, hypo,
  { {0x7dde008d, 0x44320343, 0x81c00044, 0x00000000}},  //   rësu, dsy_, ুতি_,
  { {0x9f5e00f4, 0x7bda1254, 0x2fde0026, 0x00000000}},  //   _cité_, motu, _mktg_,
  { {0x7bda0e33, 0xb88600b9, 0x2b4e033f, 0x00000000}},  //   lotu, _spíš, _hcfc_,
  { {0x7dde0065, 0xe45001b7, 0xdb010051, 0x00000000}},  // [a030] qësu, فضل_, mhlá,
  { {0x68ed2ad2, 0x7bda00b0, 0xdce00ed9, 0x00000000}},  //   _izad, notu, jemč,
  { {0x7bc8121f, 0x69cd00eb, 0x3e4e006b, 0x00000000}},  //   indu, _kjae, _xətt_,
  { {0xa15931cd, 0x76470009, 0x7bda0052, 0x00000000}},  //   раду_, mujy, hotu,
  { {0x7bda00b0, 0x19580049, 0x00000000, 0x00000000}},  //   kotu, מבאל_,   ,
  { {0x8cdc013d, 0xdb1a1e50, 0x00000000, 0x00000000}},  //   _पड़ो, bité,   ,
  { {0x35f800d3, 0xdb1a00f4, 0x7bda00b0, 0x00000000}},  //   _خرید_, cité, dotu,
  { {0xd0d5005e, 0x8db5007e, 0xa2b8007d, 0x00000000}},  //   _добъ, ўскі, ्पर्,
  { {0x6d49002a, 0x77ab006b, 0x7bc8000c, 0x00000000}},  //   rgea, _müxb, fndu,
  { {0x212f0022, 0xdfdb005e, 0x00000000, 0x00000000}},  //   lagh_, _съб_,   ,
  { {0x68ed005f, 0x00000000, 0x00000000, 0x00000000}},  //   _azad,   ,   ,
  { {0x212f00ea, 0x7bc80f9b, 0x00000000, 0x00000000}},  //   nagh_, andu,   ,
  { {0xa3d90201, 0x629e0036, 0x7bda0089, 0x00000000}},  //   ावा_, zypo, botu,
  { {0x6b830056, 0x7bda004a, 0x00000000, 0x00000000}},  //   _unng, cotu,   ,
  { {0x672e0337, 0x44320036, 0xa50a17be, 0x00000000}},  //   rabj, wsy_, иева_,
  { {0x44320007, 0xdb1a028c, 0xdb010051, 0x00000000}},  //   tsy_, vité, chlá,
  { {0xe3ba003b, 0x290500b9, 0x32180007, 0x00000000}},  // [a040] аба_, ělat_, _stry_,
  { {0x44320036, 0x16662e00, 0x629e0832, 0x00000000}},  //   rsy_, _двом, typo,
  { {0x4432001c, 0x7a0800b9, 0x63be0085, 0x00000000}},  //   ssy_, _pěti, ripn,
  { {0x00e60001, 0xdb1a00f4, 0x7ae30056, 0x00000000}},  //   ожен, rité, _mynt,
  { {0x7bda0020, 0x7bc8000c, 0xdb1a009d, 0x00000000}},  //   yotu, yndu, sité,
  { {0x2d990e42, 0x8fa3003b, 0x63be0065, 0x00000000}},  //   ösen_, маче, qipn,
  { {0x59ca0309, 0xf8bf009d, 0x7bda0052, 0x00000000}},  //   ाचार, mbée_, votu,
  { {0x5f7600a1, 0xdc1e0044, 0xb4db00f6, 0x00000000}},  //   _ڈائر, _দিবস_, _icàr,
  { {0xc5f301f8, 0x7bda31ce, 0x27170224, 0x00000000}},  //   ודה_, totu, nění_,
  { {0x68ed0036, 0xa3ea006e, 0xdfa60379, 0x00000000}},  //   _rzad, मति_, _بحري,
  { {0x7ae3018e, 0x7bda00b0, 0x68e40173, 0x00000000}},  //   _cynt, rotu, _ayid,
  { {0x6d9c0048, 0x7bda31cf, 0x00000000, 0x00000000}},  //   _céat, sotu,   ,
  { {0x7bda27ab, 0xddc8012d, 0x320400f6, 0x00000000}},  //   potu, _krdž, _mimy_,
  { {0x271700b9, 0xdb010051, 0x7ae301c3, 0x00000000}},  //   dění_, shlá, _fynt,
  { {0xd5bb0265, 0x7ae3018e, 0xb5c90025, 0x00000000}},  //   аса_, _gynt, موسم_,
  { {0xdb01010e, 0x00000000, 0x00000000, 0x00000000}},  //   gilõ,   ,   ,
  { {0x6d9c0051, 0x68ed0180, 0x27ed0dce, 0x00000000}},  // [a050] _héas, _uzad, ïens_,
  { {0x69dd000d, 0xd3710379, 0xdb08004a, 0x00000000}},  //   lose, عها_, midó,
  { {0xdb010bac, 0xc3240044, 0x65a3010e, 0x00000000}},  //   silö, _পাখি_, _jõhk,
  { {0xe0d30a90, 0x6b9805b7, 0xc6920049, 0x00000000}},  //   وزش_, _lovg, _נאכ_,
  { {0x65a3006c, 0x212f26e2, 0x6d9c05f4, 0x00000000}},  //   _lõhk, ragh_, _léas,
  { {0x1b220055, 0x623502ea, 0x7e610022, 0x00000000}},  //   _মাঝে_, _негу, _pplp,
  { {0x69dd0020, 0xc22500a1, 0x00000000, 0x00000000}},  //   kose, _رکاو,   ,
  { {0xdceb01d5, 0x69dd01ee, 0x9f4c00f6, 0x00000000}},  //   _jogħ, jose, _bidó_,
  { {0x65a30004, 0x7ae30e2d, 0xcc350025, 0x00000000}},  //   _põhj, _synt, أربع,
  { {0x5ba9102a, 0xdceb01d5, 0x7ae3068f, 0x00000000}},  //   ском_, _logħ, _pynt,
  { {0xe9da005e, 0x69dd0253, 0x539c0049, 0x00000000}},  //   йко_, fose, ייזו,
  { {0x2005000b, 0x186a004c, 0x69dd0d61, 0x00000000}},  //   _hili_, бами_, gose,
  { {0x26d30c0d, 0x2005107e, 0x6d5b0020, 0x00000000}},  //   _axxo_, _kili_, mfua,
  { {0x8c1a00b3, 0x200500e7, 0xfd4700a1, 0x00000000}},  //   _הוסי, _jili_, _ایکٹ_,
  { {0xcb1200b6, 0x69dd03d2, 0xdceb002b, 0x00000000}},  //   _אלו_, bose, _bogħ,
  { {0x2005002b, 0xf99205d4, 0x7bc131d0, 0x00000000}},  //   _lili_, _سبب_, lilu,
  { {0x02c401f5, 0xddc10089, 0x00000000, 0x00000000}},  // [a060] वप्न, _aplū,   ,
  { {0x64561241, 0x287b009b, 0x7bc10052, 0x00000000}},  //   rtyi, _פנימ, nilu,
  { {0x479b007b, 0x179b007b, 0x6d9c0051, 0x00000000}},  //   _הייס, _הייב, _méar,
  { {0x6d9c002a, 0x80da0055, 0x271700b9, 0x00000000}},  //   _léar, _বৃষ্, pění_,
  { {0xd12f00b8, 0x200531d1, 0x75240020, 0x00000000}},  //   امه_, _bili_, mbiz,
  { {0x4420021e, 0x200531d2, 0x69dd01ee, 0x00000000}},  //   mpi_, _cili_, zose,
  { {0xa3d90183, 0x20051544, 0x7bc101ee, 0x00000000}},  //   ावर_, _dili_, dilu,
  { {0x77ab005f, 0xdceb31d3, 0x660601d5, 0x00000000}},  //   _müxa, _xogħ, _jikk,
  { {0x6d9c31d4, 0x660631d5, 0x69dd0943, 0x00000000}},  //   _béar, _mikk, vose,
  { {0x0b8a0057, 0x20050066, 0x6d9c0051, 0x00000000}},  //   ссии_, _gili_, _céar,
  { {0x69dd31d6, 0x6d9c0051, 0x200d0032, 0x00000000}},  //   tose, _déar, _zuei_,
  { {0x7524002b, 0x6d9c008e, 0x44200022, 0x00000000}},  //   jbiz, _véas, kpi_,
  { {0x5887008b, 0x7bc105ea, 0xdb1a31d7, 0x00000000}},  //   чына, bilu, lití,
  { {0x6d9c0051, 0x64441487, 0x69dd0052, 0x00000000}},  //   _géar, drii, sose,
  { {0x6a130054, 0x69dd030a, 0xe3c40044, 0x00000000}},  //   _كبير, pose, ্তাব,
  { {0x66060047, 0x00000000, 0x00000000, 0x00000000}},  //   _cikk,   ,   ,
  { {0x6606011f, 0x53990783, 0x870900a1, 0x00000000}},  // [a070] _dikk, овая_, _وعدہ_,
  { {0x660612de, 0x212d0022, 0xdb1a00fa, 0x00000000}},  //   _eikk, _seeh_, litâ,
  { {0x35f502e9, 0xdb01010f, 0x44201449, 0x00000000}},  //   _опор, chlä, api_,
  { {0x6444006c, 0x200500ca, 0x777701f3, 0x00000000}},  //   brii, _sili_, _haxx,
  { {0x2005000b, 0x200d0207, 0x7777002b, 0x00000000}},  //   _pili_, _quei_, _kaxx,
  { {0xedf70164, 0xdee5003b, 0x4439214c, 0x00000000}},  //   ुद्ध_, моли, _ivs_,
  { {0x7bc101d5, 0x44390022, 0x3cff0061, 0x00000000}},  //   vilu, _hvs_, शेने_,
  { {0x7db4007e, 0x20050058, 0x3333002b, 0x00000000}},  //   есьц, _wili_, laxx_,
  { {0x7bc10f45, 0x752f0036, 0xdce00089, 0x00000000}},  //   tilu, _mecz, temā,
  { {0x752f0036, 0x77770066, 0x4439013f, 0x00000000}},  //   _lecz, _naxx, _mvs_,
  { {0xd9461074, 0x7bc11da2, 0x4420002d, 0x00000000}},  //   мени, rilu, zpi_,
  { {0x7bc113af, 0x44201bd3, 0xc7a9034e, 0x00000000}},  //   silu, ypi_, _דב_,
  { {0x6d9c002a, 0x660603b6, 0x7bc1001a, 0x00000000}},  //   _téar, _rikk, pilu,
  { {0x66060378, 0x77770026, 0x80da0044, 0x00000000}},  //   _sikk, _caxx, বেক্,
  { {0x66e3317a, 0x66060368, 0x7a080224, 0x00000000}},  //   вора, _pikk, _děts,
  { {0x3dcd31d8, 0x443901d6, 0x644403b6, 0x00000000}},  //   nnew_, _bvs_, trii,
  { {0xa3d90061, 0xdb1a2773, 0x7524002d, 0x00000000}},  // [a080] ावं_, zití, rbiz,
  { {0x4439062c, 0x66061245, 0x6444010e, 0x00000000}},  //   _dvs_, _wikk, rrii,
  { {0x660601d5, 0x6444006c, 0x443931d9, 0x00000000}},  //   _tikk, srii, _evs_,
  { {0x442016df, 0x644424b7, 0x443900fa, 0x00000000}},  //   ppi_, prii, _fvs_,
  { {0x2f180604, 0xd4360379, 0x443900e5, 0x00000000}},  //   поль_, _تعجب, _gvs_,
  { {0x43750679, 0x00000000, 0x00000000, 0x00000000}},  //   _пуст,   ,   ,
  { {0xa3db0164, 0x7c2b0016, 0x63a331da, 0x00000000}},  //   डकर_, _awgr, önne,
  { {0x5c7419ea, 0x65a30004, 0xdd900025, 0x00000000}},  //   елит, _põhi, اوة_,
  { {0x443905d2, 0x00000000, 0x00000000, 0x00000000}},  //   _xvs_,   ,   ,
  { {0x7ac601ee, 0x00000000, 0x00000000, 0x00000000}},  //   дсме,   ,   ,
  { {0x3ddf00b5, 0x7c2d002b, 0x2d9a009d, 0x00000000}},  //   bouw_, _ħare, êpes_,
  { {0x9e65026c, 0x2378000a, 0x00000000, 0x00000000}},  //   _سامن, _larj_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xead40454, 0x443900bb, 0x2cb0005d, 0x00000000}},  //   _поль, _rvs_, ıldı_,
  { {0xbd0500f4, 0xf8ae0167, 0x442b00d2, 0x00000000}},  //   _théâ, لکی_, _swc_,
  { {0xfaa70014, 0xdb1a00d4, 0x63ae22cb, 0x00000000}},  //   _تجهی, lità, _albn,
  { {0x94ab02f0, 0x2458007c, 0xdb0a0b32, 0x00000000}},  // [a090] цтва_, мать_, _alfé,
  { {0x44391f9d, 0xdb1a0129, 0x08f80426, 0x00000000}},  //   _vvs_, nità, _غريب_,
  { {0x33330066, 0x69cf0026, 0x26080061, 0x00000000}},  //   raxx_, once, _ांची_,
  { {0x443900c4, 0x77b00039, 0x34950954, 0x00000000}},  //   _tvs_, _växe, _замр,
  { {0x442b01f3, 0x6d9c009d, 0x656d00e7, 0x00000000}},  //   _uwc_, _réap, meah,
  { {0x673503b2, 0xf41f00b0, 0x25a90058, 0x00000000}},  //   nazj, _itä_, lkal_,
  { {0x644d31b2, 0x9ea904dd, 0x5214007e, 0x00000000}},  //   luai, явка_, _адст,
  { {0x25a90007, 0xf41f0039, 0x7c9500e2, 0x00000000}},  //   nkal_, _träd_, ероц,
  { {0x644d028c, 0x3ddf00bb, 0x67350066, 0x00000000}},  //   nuai, rouw_, kazj,
  { {0x69cf0549, 0x3dcd0009, 0x00000000, 0x00000000}},  //   ence, snew_,   ,
  { {0x25a90047, 0x644d0051, 0x39ea0a1e, 0x00000000}},  //   kkal_, huai, здно_,
  { {0x65a3006c, 0xf2d20049, 0x6dc7083e, 0x00000000}},  //   _kõhu, רעט_, _غزال,
  { {0x2904225c, 0x673e0022, 0xeaae009e, 0x00000000}},  //   äma_, _pdpj, لٹی_,
  { {0x2d9d31db, 0x644d0b26, 0x69cf0133, 0x00000000}},  //   _howe_, duai, ance,
  { {0x7a0900b9, 0x25b20133, 0x2d9d0022, 0x00000000}},  //   _větr, thyl_, _kowe_,
  { {0x65aa0428, 0xdb1a00c4, 0x644d0051, 0x00000000}},  //   _výho, pitã, fuai,
  { {0xd4670200, 0xdb1a1db2, 0x644d0181, 0x00000000}},  // [a0a0] ните_, litá, guai,
  { {0x69c6006c, 0x32d600e3, 0x67f2000c, 0x00000000}},  //   like, нцес, bæja,
  { {0xdb1a0181, 0x81460025, 0xb14601ee, 0x00000000}},  //   nitá, فنان, енел,
  { {0x2d9d0046, 0x00000000, 0x00000000, 0x00000000}},  //   _nowe_,   ,   ,
  { {0x765c02e7, 0x2378004a, 0x00000000, 0x00000000}},  //   ltry, _tarj_,   ,
  { {0x69c6066f, 0x7bcf009d, 0x00000000, 0x00000000}},  //   hike, écul,   ,
  { {0x765c0542, 0x412a00e3, 0x3940033f, 0x00000000}},  //   ntry, _ново_, _odis_,
  { {0xc693012e, 0x2c260088, 0x7c240279, 0x00000000}},  //   ראה_, ньог, _çirk,
  { {0x69c60056, 0x2d9d01d6, 0x9f5e00f6, 0x00000000}},  //   dike, _dowe_, _tità_,
  { {0x765c0036, 0x61e2006c, 0x39400087, 0x00000000}},  //   ktry, lool, _adis_,
  { {0x69c60039, 0x61e2231b, 0xdb1a31dc, 0x00000000}},  //   fike, oool, gitá,
  { {0x248031dd, 0xed5a0256, 0x765c1f9d, 0x00000000}},  //   kvim_, _ход_, dtry,
  { {0xe78500a1, 0xfbcf0014, 0x644d0181, 0x00000000}},  //   پلزپ, شتی_, xuai,
  { {0x8c1b00bd, 0x61e2066a, 0x36d50088, 0x00000000}},  //   _צווי, hool, вогр,
  { {0x61e20004, 0xdb1a0d95, 0x765c02e1, 0x00000000}},  //   kool, citá, gtry,
  { {0x644d15a3, 0x3f9e1cc7, 0xf0a60011, 0x00000000}},  //   tuai, _lotu_, _đành_,
  { {0x798d31de, 0x6735002b, 0x5964005e, 0x00000000}},  // [a0b0] _inaw, pazj, _съща,
  { {0x25a90c35, 0x386931df, 0x644d0051, 0x00000000}},  //   skal_, _ipar_, ruai,
  { {0x32550373, 0x644d1584, 0x00000000, 0x00000000}},  //   твер, suai,   ,
  { {0x3f8c0066, 0x7aea0023, 0x24720173, 0x00000000}},  //   _andu_, _myft, _fņm_,
  { {0x7aea31e0, 0x798d00e7, 0x75360049, 0x00000000}},  //   _lyft, _mnaw, _בארד_,
  { {0x69c6002d, 0xdb1a2926, 0x27e331e1, 0x00000000}},  //   zike, litæ, nojn_,
  { {0x61e22131, 0x6115007e, 0xb1aa000c, 0x00000000}},  //   bool, _адбу, þýðu,
  { {0x61e20a86, 0xfc3f01ca, 0xdb1a10fa, 0x00000000}},  //   cool, ším_, vitá,
  { {0x69c603af, 0x3f9e00f6, 0x27e30023, 0x00000000}},  //   vike, _fotu_, kojn_,
  { {0x09ca0365, 0x798d31e2, 0x2d9d0009, 0x00000000}},  //   ाच्य, _anaw, _wowe_,
  { {0x2fc70837, 0x3869001a, 0x06c60044, 0x00000000}},  //   ming_, _apar_, _শুনি,
  { {0xdb1a1db2, 0x00000000, 0x00000000, 0x00000000}},  //   ritá,   ,   ,
  { {0x69c631e3, 0x2fc7009d, 0xdb1a31e4, 0x00000000}},  //   rike, oing_, sitá,
  { {0x2fc70901, 0xdb1a0387, 0x44240006, 0x00000000}},  //   ning_, pitá, _įm_,
  { {0x66e602e9, 0x3ea7018e, 0x7bc323b4, 0x00000000}},  //   това, nynt_, _imnu,
  { {0x2fc71f9c, 0xceb2019b, 0x7d1b0213, 0x00000000}},  //   hing_, ביל_, ncus,
  { {0x2fc71f9c, 0xe8fa0265, 0x765c0036, 0x00000000}},  // [a0c0] king_, _юли_, stry,
  { {0x2fc701a3, 0x7d1b0009, 0x61e20146, 0x00000000}},  //   jing_, hcus, wool,
  { {0x2480037e, 0x2fc7066a, 0x61e22836, 0x00000000}},  //   svim_, ding_, tool,
  { {0x3ea7018e, 0x7c3b010e, 0x2fc70133, 0x00000000}},  //   dynt_, ksur, eing_,
  { {0x61e20004, 0x2480006b, 0x7c3b016c, 0x00000000}},  //   rool, qvim_, jsur,
  { {0x2fc7066d, 0x7c3b0146, 0x61e231e5, 0x00000000}},  //   ging_, dsur, sool,
  { {0x61e2006c, 0x8fa3012b, 0x44220190, 0x00000000}},  //   pool, раје, _htk_,
  { {0x44220020, 0x69d60009, 0x00000000, 0x00000000}},  //   _ktk_, _njye,   ,
  { {0x2fc7006a, 0x7aea0039, 0xe817013d, 0x00000000}},  //   bing_, _syft, _धंधा_,
  { {0x2fc70498, 0x69c40855, 0xef8301fc, 0x00000000}},  //   cing_, _amie, _клуп,
  { {0x38690030, 0x7c3b00ab, 0x195900a5, 0x00000000}},  //   _spar_, asur, наны_,
  { {0x79a70264, 0x200c0020, 0x9f4501aa, 0x00000000}},  //   трое, _hidi_, _aklè_,
  { {0x27e30023, 0x7bc300f6, 0x44220082, 0x00000000}},  //   tojn_, _fmnu, _ntk_,
  { {0x7c220d3f, 0x65660032, 0x69c400d9, 0x00000000}},  //   _itor, _abkh, _emie,
  { {0xf8bf02d5, 0x200c00f4, 0x4422211b, 0x00000000}},  //   mbém_, _midi_, _atk_,
  { {0x7c2213a1, 0x798d1a60, 0x2fc700ab, 0x00000000}},  //   _ktor, _unaw, zing_,
  { {0x2fc70038, 0x386900c4, 0xdb1a31e6, 0x00000000}},  // [a0d0] ying_, _upar_, ritæ,
  { {0x69c431e7, 0x02a701fb, 0x61db0164, 0x00000000}},  //   _zmie, крем, यक्ष,
  { {0x2fc7066a, 0x9f5e021e, 0x75d5031d, 0x00000000}},  //   ving_, _mitä_, _ميدا,
  { {0xc69200bd, 0x7c2231e8, 0x2fc700fe, 0x00000000}},  //   _האט_, _otor, wing_,
  { {0x2fc72c41, 0x200c0061, 0x3ea70016, 0x00000000}},  //   ting_, _bidi_, wynt_,
  { {0x657d1166, 0x2fc701d6, 0xdb1a010f, 0x00000000}},  //   _hash, uing_, nitä,
  { {0x7c220a0a, 0x657d0020, 0x6e950380, 0x00000000}},  //   _ator, _kash, العا,
  { {0x657d008d, 0x7c3b011c, 0xec7901ee, 0x00000000}},  //   _jash, tsur, епи_,
  { {0x657d1de9, 0x7c3b0207, 0x200c002b, 0x00000000}},  //   _mash, usur, _fidi_,
  { {0x2fc731e9, 0x7c3b001a, 0x657d0065, 0x00000000}},  //   qing_, rsur, _lash,
  { {0x7c22022b, 0x7c3b06d7, 0xdb1a31ea, 0x00000000}},  //   _etor, ssur, entó,
  { {0xdea3026c, 0x657d0020, 0x7c3b0035, 0x00000000}},  //   _میڈی, _nash, psur,
  { {0x8c4500ed, 0x7bc831eb, 0x2d8f27a1, 0x00000000}},  //   _селе, bidu, _inge_,
  { {0x7bc80035, 0x44220023, 0x00000000, 0x00000000}},  //   cidu, _rtk_,   ,
  { {0x657d008d, 0x44220030, 0x69c4002b, 0x00000000}},  //   _bash, _stk_, _tmie,
  { {0x69c41191, 0x60db006b, 0x44222434, 0x00000000}},  //   _umie, _oxum, _ptk_,
  { {0x81cc0044, 0x657d071e, 0x6287008e, 0x00000000}},  // [a0e0] রকম_, _dash, _arjo,
  { {0x5503132a, 0x61fb002d, 0x00000000, 0x00000000}},  //   спуб, _ahul,   ,
  { {0x200c0197, 0x2d8f01c3, 0x61fb0048, 0x00000000}},  //   _ridi_, _onge_, _bhul,
  { {0x61fb1d59, 0x657d0023, 0x200c0aa0, 0x00000000}},  //   _chul, _gash, _sidi_,
  { {0x8fa60088, 0x44221444, 0x200c006c, 0x00000000}},  //   ладе, _utk_, _pidi_,
  { {0x2d8f31ec, 0xa2e60407, 0x657d01ee, 0x00000000}},  //   _ange_, _богд, _zash,
  { {0x200c2610, 0x657d0ea6, 0xb4db00f6, 0x00000000}},  //   _vidi_, _yash, _jdàn,
  { {0x9f5e021e, 0x7bc831ed, 0xdb1a010f, 0x00000000}},  //   _sitä_, widu, zitä,
  { {0xf53f03b1, 0x00000000, 0x00000000, 0x00000000}},  //   _klår_,   ,   ,
  { {0x99860006, 0x2ea500a1, 0x2d8f0e42, 0x00000000}},  //   kslų_, _چھٹی_, _enge_,
  { {0x7bc80004, 0xdb1a010f, 0x7c220036, 0x00000000}},  //   ridu, vitä, _wtor,
  { {0x7bc81a35, 0x2eb002d2, 0x61fb0023, 0x00000000}},  //   sidu, जनीत, _xhul,
  { {0x7c2231ee, 0x657d01a3, 0x7bc82c2c, 0x00000000}},  //   _utor, _rash, pidu,
  { {0x657d1b8e, 0x00000000, 0x00000000, 0x00000000}},  //   _sash,   ,   ,
  { {0x657d008d, 0xdb1a0706, 0x8b650014, 0x00000000}},  //   _pash, ritä, _خانم,
  { {0xca470025, 0xdb1a31ef, 0x657d0023, 0x00000000}},  //   _إليه_, sitä, _qash,
  { {0x657d0007, 0xdb1a0ba4, 0x645d0009, 0x00000000}},  // [a0f0] _vash, pitä, _qqsi,
  { {0x61fb000b, 0x657d2068, 0x61e9046e, 0x00000000}},  //   _shul, _wash, _skel,
  { {0x657d2d3d, 0x92590057, 0x00000000, 0x00000000}},  //   _tash, тает_,   ,
  { {0x657d0a9e, 0x2a570049, 0x00000000, 0x00000000}},  //   _uash, רבאן_,   ,
  { {0x752d000b, 0xf53f0146, 0x00000000, 0x00000000}},  //   mbaz, _flår_,   ,
  { {0x6617002d, 0x9f4701ca, 0x752d151d, 0x00000000}},  //   _kuxk, plní_, lbaz,
  { {0xfd110025, 0x61e9002b, 0x644d0048, 0x00000000}},  //   يجة_, _tkel, lrai,
  { {0x1c45003b, 0x644d0051, 0xada5007c, 0x00000000}},  //   аним, orai, раил,
  { {0x644d002a, 0x44290149, 0xdb180039, 0x00000000}},  //   nrai, npa_, _omvä,
  { {0x660f0541, 0x5ba903c0, 0x44290181, 0x00000000}},  //   _lick, тком_, ipa_,
  { {0x644d31f0, 0xaa4902dc, 0x44290095, 0x00000000}},  //   hrai, ъпна_, hpa_,
  { {0x2d8f0018, 0x660f114e, 0x644d007f, 0x00000000}},  //   _unge_, _nick, krai,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x644d1321, 0x7c290971, 0x44290082, 0x00000000}},  //   drai, mper, dpa_,
  { {0xe7370069, 0x644d009d, 0x442900c8, 0x00000000}},  //   рес_, erai, epa_,
  { {0x644d018e, 0x7c290197, 0xf53f03bd, 0x00000000}},  //   frai, oper, _slår_,
  { {0x660f2af8, 0xb4250a4f, 0x644d07cd, 0x00000000}},  // [a100] _dick, معلو, grai,
  { {0xcb120049, 0xdb010698, 0xdcfb01ed, 0x00000000}},  //   ַלד_, rklæ, jduč,
  { {0x673c2db6, 0x442901d1, 0x660f05b4, 0x00000000}},  //   marj, apa_, _fick,
  { {0x644d31f1, 0x673c0059, 0x644b0b33, 0x00000000}},  //   brai, larj, ágic,
  { {0x660408b2, 0x644d0051, 0x44290085, 0x00000000}},  //   mmik, crai, cpa_,
  { {0x673c0233, 0x660400b0, 0x7c2931f2, 0x00000000}},  //   narj, lmik, dper,
  { {0x7c2900bb, 0xe297174e, 0xdb010203, 0x00000000}},  //   eper, _кар_, nklä,
  { {0x91e30794, 0xef180089, 0x261c008e, 0x00000000}},  //   _досе, _daļa_, _mío_,
  { {0x673c31f3, 0x7c2900ea, 0x261c008e, 0x00000000}},  //   karj, gper, _lío_,
  { {0xeb06012c, 0x673c31f4, 0x2d9931f5, 0x00000000}},  //   ично, jarj, öser_,
  { {0x673c31f6, 0xdb01010f, 0x77b00039, 0x00000000}},  //   darj, chlü, _växl,
  { {0x4429000c, 0x7c290066, 0x644d0bcd, 0x00000000}},  //   ypa_, bper, yrai,
  { {0xf773006d, 0x98b2000a, 0x660405d2, 0x00000000}},  //   ياس_, _feyč_, dmik,
  { {0x644d028c, 0x673c00ca, 0x261c008e, 0x00000000}},  //   vrai, garj, _bío_,
  { {0x660f00ab, 0x6b9c000c, 0x659500ed, 0x00000000}},  //   _pick, örgu, баву,
  { {0x644d028c, 0xd5b80839, 0x3860002b, 0x00000000}},  //   trai, асу_, _fqir_,
  { {0x673c00ca, 0x4429000c, 0xdb010051, 0x00000000}},  // [a110] barj, upa_, bhló,
  { {0x644d0a49, 0x442931f7, 0x673c31f8, 0x00000000}},  //   rrai, rpa_, carj,
  { {0x660f01ac, 0x7c290032, 0x644d0048, 0x00000000}},  //   _tick, zper, srai,
  { {0xf5950d75, 0xd76300a1, 0xf99f01aa, 0x00000000}},  //   _الحج, _انھی, njè_,
  { {0x7c290039, 0x70220044, 0xe0d00076, 0x00000000}},  //   xper, _নিউজ_, وزه_,
  { {0x9f470065, 0xa29505b8, 0x32180133, 0x00000000}},  //   monë_, _лагі, _fury_,
  { {0x7c2900d9, 0x87b80049, 0x98ab00b4, 0x00000000}},  //   wper, שלוס_, racę_,
  { {0x7c29138f, 0x98b201aa, 0x673c1168, 0x00000000}},  //   tper, _seyč_, zarj,
  { {0xb4f502fb, 0x7c2900f6, 0xf99f01aa, 0x00000000}},  //   _आरोप_, uper, djè_,
  { {0x7c2931f9, 0x2b5c00f6, 0x66040e90, 0x00000000}},  //   rper, _ccvc_, zmik,
  { {0x673c01d9, 0x23b6009f, 0x00000000, 0x00000000}},  //   varj, _jæja_,   ,
  { {0x261c0211, 0xc7a90097, 0x7c29086a, 0x00000000}},  //   _río_, _אב_, pper,
  { {0x673c01d5, 0xa2f40061, 0x3e610010, 0x00000000}},  //   tarj, _अर्ज_, lót_,
  { {0x261c31fa, 0xab260b86, 0xd6c90044, 0x00000000}},  //   _pío_, _лоша_, _ষড়য,
  { {0x673c31fb, 0x6604010e, 0x00000000, 0x00000000}},  //   rarj, tmik,   ,
  { {0x673c00b0, 0xd01f0044, 0xdb010a35, 0x00000000}},  //   sarj, নীয়_, rklä,
  { {0x66040010, 0xdb0104ce, 0x673c00ca, 0x00000000}},  // [a120] rmik, sklä, parj,
  { {0x261c008e, 0xe29a01ee, 0x7ccb01c5, 0x00000000}},  //   _tío_, лаз_, mērī,
  { {0x9f4c001d, 0x5b3a0049, 0xdd1101f3, 0x00000000}},  //   _đoàn_, רגעק, _ażżm,
  { {0x9f4701aa, 0x3e61134d, 0xdcff013e, 0x00000000}},  //   lonè_, dót_, ávěr,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc05901fb, 0xdefa007c, 0xd9a50164, 0x00000000}},  //   рії_, лый_, _ऑक्ट,
  { {0x877b0049, 0xf773009b, 0x645600e0, 0x00000000}},  //   ראצי, פקה_, luyi,
  { {0x25a031fc, 0x657631fd, 0x00000000, 0x00000000}},  //   njil_, neyh,   ,
  { {0x5bb801e0, 0xe0da012b, 0x77b00039, 0x00000000}},  //   илия_, _сва_, _växj,
  { {0xf8bf00f4, 0x7f43007c, 0xdb03000a, 0x00000000}},  //   ncée_, _неуж, _konè,
  { {0x77ab005f, 0xc33300b3, 0x65760052, 0x00000000}},  //   _müxt, הות_, keyh,
  { {0xdb030065, 0x64560058, 0xada3004d, 0x00000000}},  //   _zonë, kuyi, _нахл,
  { {0xacf604e8, 0xdb03000a, 0x9992000a, 0x00000000}},  //   _اسات, _lonè, _miyň_,
  { {0x7bcf00f4, 0x00000000, 0x00000000, 0x00000000}},  //   écut,   ,   ,
  { {0x7bca0dfc, 0x9a260257, 0x15f70025, 0x00000000}},  //   _imfu, _اعتن, مسرح,
  { {0x2d841beb, 0x58d5005e, 0xf993006d, 0x00000000}},  //   ndme_, _мойт, _ربع_,
  { {0x69cf04ea, 0x64a400ed, 0x3494007e, 0x00000000}},  // [a130] mice, паѓа, патр,
  { {0x261a013d, 0xdb03000a, 0x00000000, 0x00000000}},  //   _मूवी_, _bonè,   ,
  { {0xdb030129, 0x02d91298, 0x00000000, 0x00000000}},  //   _conè, جواب_,   ,
  { {0x9f4c0011, 0x645600e0, 0x00000000, 0x00000000}},  //   _đoán_, buyi,   ,
  { {0x3dcd0038, 0x8fa50242, 0x00000000, 0x00000000}},  //   view_, жале,   ,
  { {0x69cf016c, 0x3e610010, 0xdb031b43, 0x00000000}},  //   hice, tót_, _fonè,
  { {0x99890036, 0x39490173, 0x24891290, 0x00000000}},  //   _miał_, _odas_, lvam_,
  { {0x69cf01ee, 0x0c25007c, 0xec4900ed, 0x00000000}},  //   jice, омин, азил_,
  { {0x9f4701aa, 0x61eb0091, 0x00000000, 0x00000000}},  //   yonè_, mogl,   ,
  { {0x4a450088, 0x61eb014a, 0xfbc50088, 0x00000000}},  //   онов, logl, ібно,
  { {0xe9da012b, 0x69cf2f16, 0x61eb0146, 0x00000000}},  //   ико_, fice, oogl,
  { {0x61eb00ca, 0x69cf0173, 0xe81e0061, 0x00000000}},  //   nogl, gice, _यंदा_,
  { {0x7a13000d, 0x30790049, 0x3e450089, 0x00000000}},  //   _cătr, באָנ, lēt_,
  { {0xd5b10082, 0x6d5b0032, 0xab2929d2, 0x00000000}},  //   ến_, lgua, _тока_,
  { {0x69cf01ee, 0x3e450089, 0xe9a600e2, 0x00000000}},  //   bice, nēt_, _макп,
  { {0x28c503d7, 0x6d5b0838, 0x69cf01ee, 0x00000000}},  //   _लेकि, ngua, cice,
  { {0x6b8317f6, 0x63a70626, 0x61eb0087, 0x00000000}},  // [a140] _kang, _bojn, dogl,
  { {0x6b830149, 0x7c24002a, 0x79841b1d, 0x00000000}},  //   _jang, _éire, _haiw,
  { {0x6b83004e, 0x61eb042d, 0xf8bf009d, 0x00000000}},  //   _mang, fogl, rcée_,
  { {0x61eb0207, 0xdb030efe, 0x3e450089, 0x00000000}},  //   gogl, _coné, dēt_,
  { {0x92aa0044, 0x7984011c, 0x00da00f9, 0x00000000}},  //   গছে_, _maiw, جبات_,
  { {0x6b83006a, 0x5f93025f, 0x69cf001a, 0x00000000}},  //   _nang, дишт, zice,
  { {0xdb1a008d, 0x179b009b, 0x644401b1, 0x00000000}},  //   shtë, ייסב, lsii,
  { {0x6b83049b, 0x61eb0207, 0x798431fe, 0x00000000}},  //   _aang, cogl, _naiw,
  { {0x6b83020c, 0x644431ff, 0x69cf00ab, 0x00000000}},  //   _bang, nsii, vice,
  { {0x6b83049a, 0x7053007a, 0x6444021e, 0x00000000}},  //   _cang, _آنلا, isii,
  { {0x39490285, 0x6b8302f1, 0x69cf00ab, 0x00000000}},  //   _pdas_, _dang, tice,
  { {0x6444021e, 0x628e3200, 0x7bcf009d, 0x00000000}},  //   ksii, _mrbo, écur,
  { {0x69cf049a, 0x6d400811, 0x6b832b13, 0x00000000}},  //   rice, mama, _fang,
  { {0x6b83124e, 0xcb67012b, 0x69cf3201, 0x00000000}},  //   _gang, _даље_, sice,
  { {0x69cf3202, 0xb5a70131, 0x00000000, 0x00000000}},  //   pice, орай,   ,
  { {0x6b830020, 0x89390184, 0x3949012d, 0x00000000}},  //   _zang, _упис_, _udas_,
  { {0x6b83000b, 0x5fdb0061, 0x5455005e, 0x00000000}},  // [a150] _yang, _बदलल, яват,
  { {0x6d4004cb, 0xc2e90055, 0x7bda000c, 0x00000000}},  //   hama, _কৃষি_, nntu,
  { {0x6d401084, 0x250904e1, 0x65aa01ca, 0x00000000}},  //   kama, _گردی_, _výhr,
  { {0xf67a007b, 0x1a9b007b, 0x05b900a1, 0x00000000}},  //   _פארמ, ייבע, _اگست_,
  { {0x6d402a94, 0x61eb3203, 0x859a00b6, 0x00000000}},  //   dama, rogl, _השרו,
  { {0x442b0093, 0x3e450089, 0x61eb00ca, 0x00000000}},  //   _itc_, tēt_, sogl,
  { {0x442b0c26, 0x628e0107, 0x313500ed, 0x00000000}},  //   _htc_, _grbo, _невр,
  { {0x6b8304d4, 0x753d0046, 0x6d40027c, 0x00000000}},  //   _sang, _jesz, gama,
  { {0x6b830b9a, 0x6d5b008d, 0x3e4501c5, 0x00000000}},  //   _pang, rgua, sēt_,
  { {0x69dd028c, 0x6d5b027b, 0x753d1a53, 0x00000000}},  //   éren, sgua, _lesz,
  { {0x656f3204, 0x6b83006c, 0x9ee90a4f, 0x00000000}},  //   _obch, _vang, _افضل_,
  { {0x6b83000b, 0x6d400390, 0x7bda021e, 0x00000000}},  //   _wang, cama, antu,
  { {0x3f8501a3, 0x442b0f02, 0x44393205, 0x00000000}},  //   _kalu_, _ntc_, _nws_,
  { {0x78a9006c, 0x6b830729, 0x61a8007d, 0x00000000}},  //   äeva, _uang, _कक्ष,
  { {0x753d0047, 0x3f8501a3, 0xcf920049, 0x00000000}},  //   _besz, _malu_, עטל_,
  { {0x3f850149, 0x644401c2, 0x442b3206, 0x00000000}},  //   _lalu_, tsii, _btc_,
  { {0x39420004, 0x75240207, 0xa50702be, 0x00000000}},  // [a160] maks_, rciz, зета_,
  { {0xb903007c, 0x442024e5, 0x3942006c, 0x00000000}},  //   _язык, rqi_, laks_,
  { {0x6d40066b, 0x6444003c, 0x753d0010, 0x00000000}},  //   yama, ssii, _fesz,
  { {0x44393207, 0x442b0232, 0x628e16d0, 0x00000000}},  //   _fws_, _ftc_, _vrbo,
  { {0x6d40006c, 0x442b00ca, 0x3f850032, 0x00000000}},  //   vama, _gtc_, _balu_,
  { {0x6d4b0018, 0x68f600b0, 0x628e0059, 0x00000000}},  //   _adga, _myyd, _trbo,
  { {0x7c2b0089, 0x3f850016, 0x394204fe, 0x00000000}},  //   _atgr, _dalu_, kaks_,
  { {0xdef9008b, 0x3942006c, 0x3c2001aa, 0x00000000}},  //   цыі_, jaks_, _pòv_,
  { {0x6d400127, 0x3942224c, 0x3f853208, 0x00000000}},  //   rama, daks_, _falu_,
  { {0x6d403209, 0x3f85320a, 0x248200e0, 0x00000000}},  //   sama, _galu_, _mskm_,
  { {0x21fc0224, 0xb8260044, 0x394200ca, 0x00000000}},  //   ního_, _বিগত_, faks_,
  { {0xdb1a010e, 0x3942010e, 0x00000000, 0x00000000}},  //   litü, gaks_,   ,
  { {0x2ac200f4, 0x753d0ef2, 0xed570088, 0x00000000}},  //   _bébé_, _resz, _хоч_,
  { {0x443900d9, 0x00000000, 0x00000000, 0x00000000}},  //   _rws_,   ,   ,
  { {0x661e016c, 0x3942225c, 0x21fc00b9, 0x00000000}},  //   _cupk, baks_, jího_,
  { {0x44390462, 0x00000000, 0x00000000, 0x00000000}},  //   _pws_,   ,   ,
  { {0x753d0047, 0x69dd01e2, 0xdb180068, 0x00000000}},  // [a170] _vesz, mnse, _alvé,
  { {0x6ad00055, 0x442b0011, 0x443926b3, 0x00000000}},  //   _সুযো, _vtc_, _vws_,
  { {0x753d0047, 0x442b19a7, 0x22470010, 0x00000000}},  //   _tesz, _wtc_, énk_,
  { {0x3f85320b, 0x442b00f4, 0x31350500, 0x00000000}},  //   _salu_, _ttc_, федр,
  { {0x442b215e, 0x69dd021f, 0x3f850352, 0x00000000}},  //   _utc_, inse, _palu_,
  { {0x69dd0635, 0x14080061, 0xdfd10025, 0x00000000}},  //   hnse, वगृह_, ضيع_,
  { {0x21fc00b9, 0x63a3000c, 0x3f85006c, 0x00000000}},  //   cího_, önnu, _valu_,
  { {0x69dd320c, 0x656d010f, 0x629a11af, 0x00000000}},  //   jnse, nfah, _štog,
  { {0xfc050517, 0x3f85320d, 0x39420004, 0x00000000}},  //   мпио, _talu_, vaks_,
  { {0xdb1a0181, 0x76550036, 0x00000000, 0x00000000}},  //   ditó, krzy,   ,
  { {0x8eb500a6, 0x3942006c, 0x29000010, 0x00000000}},  //   _تماش, taks_, _szia_,
  { {0x6d4b0018, 0x7f431529, 0xbcb50242, 0x00000000}},  //   _udga, lanq, _обещ,
  { {0xe87c01f6, 0x656d010f, 0x21fc00b9, 0x00000000}},  //   _düşü, dfah, zího_,
  { {0x69dd08e0, 0x39420004, 0xdb080048, 0x00000000}},  //   anse, saks_, ghdó,
  { {0xe9d20025, 0x7bc10048, 0x7a42013e, 0x00000000}},  //   _لغة_, mhlu, _vítá,
  { {0x29000032, 0x656d01a2, 0x68f600b0, 0x00000000}},  //   _tzia_, gfah, _tyyd,
  { {0xd4670200, 0x0443026b, 0x60040129, 0x00000000}},  // [a180] мите_, кетн, lòme,
  { {0x7bc1320e, 0x76550036, 0x6722007d, 0x00000000}},  //   nhlu, brzy, _मलिक_,
  { {0x38cb007a, 0xa3af0061, 0x9f4700d4, 0x00000000}},  //   _هایی_, _ओकर_, goní_,
  { {0x2005027e, 0x765c320f, 0x02de00e8, 0x00000000}},  //   _ahli_, mury, _मशीन,
  { {0x3940109a, 0x7bc13210, 0x00000000, 0x00000000}},  //   _meis_, khlu,   ,
  { {0x39400195, 0x4432039b, 0xdce00089, 0x00000000}},  //   _leis_, mpy_, zemē,
  { {0x2e4a005e, 0x44320253, 0xdb0300d4, 0x00000000}},  //   цяло_, lpy_, _boní,
  { {0x44320093, 0xdb0300f6, 0x248d016c, 0x00000000}},  //   opy_, _coní, _šemi_,
  { {0xa06a026b, 0x7f4302d0, 0x6143025f, 0x00000000}},  //   _фаза_, banq, _шета,
  { {0x7bc1002a, 0x0a6a005e, 0x5a340b49, 0x00000000}},  //   ghlu, орми_, ннот,
  { {0x59f9007e, 0x8aa30088, 0x68fa006b, 0x00000000}},  //   зеня_, вряд, ətdi,
  { {0x7e6a001c, 0x8d930025, 0x69dd08ed, 0x00000000}},  //   mtfp, _للمش, unse,
  { {0x69dd010f, 0x39400051, 0x29d2016c, 0x00000000}},  //   rnse, _deis_, pšan_,
  { {0x76550046, 0x7bc1010f, 0x7d020ecc, 0x00000000}},  //   trzy, chlu, _izos,
  { {0xdb1a0e03, 0x656d3211, 0xcc880082, 0x00000000}},  //   sitó, tfah, _hớ_,
  { {0x69d60010, 0x00000000, 0x00000000, 0x00000000}},  //   ézet,   ,   ,
  { {0x656d010f, 0xa4c00180, 0xe9df0142, 0x00000000}},  // [a190] rfah, rüşü_, mnú_,
  { {0x765c055e, 0x76550036, 0x656d010f, 0x00000000}},  //   bury, przy, sfah,
  { {0x77b00039, 0x33f40039, 0xe9df0048, 0x00000000}},  //   _växt, växt_, onú_,
  { {0x397c0049, 0x9f4707f0, 0xe9df0611, 0x00000000}},  //   ַטונ, roní_, nnú_,
  { {0xe4e70088, 0x7f43038e, 0x660d00b0, 0x00000000}},  //   _цінн, tanq, mmak,
  { {0x01c9026c, 0xe9df3212, 0x660d014a, 0x00000000}},  //   _کورٹ_, hnú_, lmak,
  { {0xfe71035b, 0x7f43008e, 0xd3460014, 0x00000000}},  //   ادت_, ranq, _سینه_,
  { {0x2247004f, 0x660d3213, 0x4c8504b6, 0x00000000}},  //   ánku_, nmak, елив,
  { {0x39400168, 0x7c2d002b, 0xcc880082, 0x00000000}},  //   _reis_, _ħars, _cớ_,
  { {0x39403214, 0x660d010e, 0xdd1d00e5, 0x00000000}},  //   _seis_, hmak, _fâşi,
  { {0xa3b70061, 0x660d014a, 0x765c00e5, 0x00000000}},  //   _जवन_, kmak, xury,
  { {0x3ce00091, 0x660d3215, 0x7bc101e5, 0x00000000}},  //   _žive_, jmak, shlu,
  { {0x777c049a, 0x39403216, 0x00000000, 0x00000000}},  //   terx, _veis_,   ,
  { {0x660d010e, 0x394001a2, 0x765c0036, 0x00000000}},  //   emak, _weis_, tury,
  { {0x66e32239, 0x7f41052a, 0x6e2100f8, 0x00000000}},  //   гора, _melq, _julb,
  { {0x660d01d6, 0x64560541, 0x38690066, 0x00000000}},  //   gmak, tryi, _fqar_,
  { {0x765c0537, 0xe4060a85, 0x00000000, 0x00000000}},  // [a1a0] sury, езап,   ,
  { {0x26cc0181, 0xb4e00061, 0x43860025, 0x00000000}},  //   údos_, _तशी_, علاق,
  { {0x443218d5, 0x660d00d9, 0xdb0300f6, 0x00000000}},  //   spy_, bmak, _jonà,
  { {0xe04600e3, 0x64a6007e, 0x4432112b, 0x00000000}},  //   енди, _зама, ppy_,
  { {0x351b009b, 0xf1a903ec, 0x00000000, 0x00000000}},  //   _מוכנ, باله_,   ,
  { {0x8fa3019d, 0x44223217, 0xf41f00b0, 0x00000000}},  //   лаче, _iuk_, _eräs_,
  { {0x539b00b6, 0x44220145, 0x7e680009, 0x00000000}},  //   _צילו, _huk_, _qqdp,
  { {0x4422194d, 0x6e210fd1, 0xf41f00f8, 0x00000000}},  //   _kuk_, _dulb, _gräs_,
  { {0x4422010a, 0x63ae11af, 0xe9df0142, 0x00000000}},  //   _juk_, _kobn, vnú_,
  { {0x660d0089, 0x4f84026c, 0x7ac600ed, 0x00000000}},  //   zmak, _جارہ, есме,
  { {0x44220030, 0x6e210089, 0x2ec60b6c, 0x00000000}},  //   _luk_, _gulb, _ثقاف,
  { {0xcc880011, 0xdb0300f6, 0x3e4c013e, 0x00000000}},  //   _tớ_, _donà, mět_,
  { {0x4422048a, 0x98b8005e, 0xe9df0142, 0x00000000}},  //   _nuk_, елят_, rnú_,
  { {0x2b450009, 0xc5fb007d, 0x8c1b009b, 0x00000000}},  //   calc_, ्ष्य_, _זוגי,
  { {0x4422000c, 0x660d1907, 0xf8ae00a1, 0x00000000}},  //   _auk_, tmak, مکی_,
  { {0x7c2200b0, 0x00000000, 0x00000000, 0x00000000}},  //   _kuor,   ,   ,
  { {0x660d0127, 0x63ae00ca, 0x6d4f0051, 0x00000000}},  // [a1b0] rmak, _bobn, ócai,
  { {0x44222075, 0x660d0056, 0x7c220207, 0x00000000}},  //   _duk_, smak, _muor,
  { {0xd25000a1, 0xd13113d9, 0x660d3218, 0x00000000}},  //   ینے_, لما_, pmak,
  { {0xa2d5001c, 0x3e4c0224, 0x6d4200e5, 0x00000000}},  //   _येण्, dět_, _neoa,
  { {0x7c222334, 0x7f410065, 0x4422002d, 0x00000000}},  //   _nuor, _pelq, _guk_,
  { {0x25a931f3, 0x6e213219, 0x7f410023, 0x00000000}},  //   ljal_, _pulb, _qelq,
  { {0x4422002d, 0x6d42012d, 0x00000000, 0x00000000}},  //   _zuk_, _beoa,   ,
  { {0x25a9321a, 0x44220093, 0xc6940097, 0x00000000}},  //   njal_, _yuk_, ראק_,
  { {0x7c220207, 0x6d42001a, 0xa2d50061, 0x00000000}},  //   _cuor, _deoa, _येत्,
  { {0x2cc70011, 0x6e21001a, 0x25a9006c, 0x00000000}},  //   _đtdđ_, _tulb, hjal_,
  { {0x25a90443, 0x00000000, 0x00000000, 0x00000000}},  //   kjal_,   ,   ,
  { {0x7c220198, 0x6d42001a, 0x25a9321b, 0x00000000}},  //   _fuor, _geoa, jjal_,
  { {0xef180089, 0xbb850025, 0x600400f6, 0x00000000}},  //   _daļu_, _للشي, lòma,
  { {0x44220007, 0x5a9528d2, 0x00000000, 0x00000000}},  //   _ruk_, _ариф,   ,
  { {0xf74308d6, 0x442201a3, 0x7c2201a2, 0x00000000}},  //   ресо, _suk_, _zuor,
  { {0x63ae07a0, 0x645f0065, 0x4422049c, 0x00000000}},  //   _sobn, fuqi, _puk_,
  { {0x6295008e, 0x00000000, 0x00000000, 0x00000000}},  // [a1c0] _arzo,   ,   ,
  { {0x4422037e, 0x600401aa, 0xd6cf00a1, 0x00000000}},  //   _vuk_, kòma, حقہ_,
  { {0x20020006, 0xdb030010, 0x00000000, 0x00000000}},  //   _ūkio_, _elnö,   ,
  { {0x4422205f, 0x2c6b0030, 0x3e4c00b9, 0x00000000}},  //   _tuk_, kød_, vět_,
  { {0x69a30061, 0xf9930097, 0x64430166, 0x00000000}},  //   गाती, ירא_, ćnic,
  { {0x60040263, 0x6d420085, 0x9f8a006c, 0x00000000}},  //   fòma, _seoa, _lööb_,
  { {0x7c22021e, 0xe1260072, 0x6e941095, 0x00000000}},  //   _suor, _амби, البا,
  { {0x65640058, 0x00000000, 0x00000000, 0x00000000}},  //   ngih,   ,   ,
  { {0x6d42006c, 0xdb1a014a, 0x7dde01c5, 0x00000000}},  //   _veoa, nitö, nīsi,
  { {0x7c2200b0, 0x61e200ca, 0x00000000, 0x00000000}},  //   _vuor, lnol,   ,
  { {0xdea30167, 0x5ea60355, 0x600400f6, 0x00000000}},  //   _نیوی, _جمال, còma,
  { {0x61e216af, 0x6bd7025a, 0x7c2200b0, 0x00000000}},  //   nnol, _یونس_, _tuor,
  { {0x3f8c129d, 0x7c2d005a, 0x6c5406e3, 0x00000000}},  //   _kadu_, _çarp, _склу,
  { {0x61e2321c, 0x7dde0089, 0x6b8a0190, 0x00000000}},  //   hnol, dīsi, _uafg,
  { {0x8c1b0097, 0xf1b90059, 0xdb7b0097, 0x00000000}},  //   _קווי, _hiše_, _חנוכ,
  { {0x69c6001f, 0xdb1a321d, 0xf1b90166, 0x00000000}},  //   chke, chtá, _kiše_,
  { {0x33750017, 0x25a9321e, 0xa5f80793, 0x00000000}},  // [a1d0] лгар, rjal_, тету_,
  { {0x3f8c0091, 0x62950036, 0x389a009b, 0x00000000}},  //   _nadu_, _przo, _ניתנ,
  { {0x798d011c, 0x2d8d00e7, 0x3f8e1ecf, 0x00000000}},  //   _kaaw, ydee_, ddfu_,
  { {0x61e2321f, 0xfb150049, 0x798d0093, 0x00000000}},  //   gnol, אַנט_, _jaaw,
  { {0x80cd03d7, 0x7fd50ee0, 0x3f8c002d, 0x00000000}},  //   _देखे, лікі, _badu_,
  { {0x644d0020, 0x661d3220, 0x3f8c00c4, 0x00000000}},  //   msai, _hisk, _cadu_,
  { {0x4429178e, 0x661d0010, 0x2f540088, 0x00000000}},  //   lqa_, _kisk, ртіс,
  { {0x61e2049a, 0x661d1524, 0x798d0058, 0x00000000}},  //   cnol, _jisk, _naaw,
  { {0x661d0a23, 0x644d00b0, 0x53b70164, 0x00000000}},  //   _misk, nsai, _आकाश,
  { {0x3f8c3221, 0x09dc001c, 0xdaa91376, 0x00000000}},  //   _gadu_, मच्य, евод_,
  { {0xd9460057, 0xa96a0072, 0x06d80044, 0x00000000}},  //   лени, нина_, _দুনি,
  { {0x644d0089, 0x7c9505d4, 0x3f8c0640, 0x00000000}},  //   ksai, _مشتا, _zadu_,
  { {0xeb8e00c0, 0x798d0020, 0x256d0010, 0x00000000}},  //   _ли_, _daaw, zóló_,
  { {0x69c60065, 0x661d3222, 0x6d4900f6, 0x00000000}},  //   shke, _aisk, laea,
  { {0x4429002b, 0xfbd00014, 0xe9da00e2, 0x00000000}},  //   eqa_, _بتن_, _пкк_,
  { {0x61e2005f, 0x88860679, 0x661d0ebd, 0x00000000}},  //   xnol, _ближ, _cisk,
  { {0x661d0387, 0x69c41111, 0x7c290065, 0x00000000}},  // [a1e0] _disk, _ilie, nqer,
  { {0x798d0036, 0xdb0300f4, 0xdb1a006c, 0x00000000}},  //   _zaaw, _conç, ritö,
  { {0x50d6007a, 0x3f8c26b5, 0xdb1a0ad1, 0x00000000}},  //   گزار, _radu_, sitö,
  { {0x3f8c145e, 0x14d50061, 0xd5b10011, 0x00000000}},  //   _sadu_, _ठेवण, ết_,
  { {0x7bc30004, 0x61e23223, 0x644d0327, 0x00000000}},  //   _olnu, rnol, csai,
  { {0xdb030181, 0x7f2a00a1, 0x661d04bb, 0x00000000}},  //   _gonç, رستِ_, _zisk,
  { {0x03d7012f, 0x69c43224, 0xa5bb00f6, 0x00000000}},  //   _עולם_, _olie, _fiód,
  { {0xf1b90059, 0xf99f01aa, 0x7bc30288, 0x00000000}},  //   _piše_, nmèt_, _alnu,
  { {0x7bc60dec, 0x6b8101a2, 0x9b6a02dc, 0x00000000}},  //   ūkum, felg, ншна_,
  { {0xf1b90119, 0xef91007a, 0x6b813225, 0x00000000}},  //   _više_, _ویند, gelg,
  { {0x69c405c4, 0x387b0026, 0xdd8f01f2, 0x00000000}},  //   _blie, _spqr_, _лш_,
  { {0x3166002d, 0x7bc33226, 0x201e1eb7, 0x00000000}},  //   ngoz_, _elnu, _hiti_,
  { {0x201e3227, 0x6b810455, 0x6fb80164, 0x00000000}},  //   _kiti_, belg, _अवां,
  { {0x661d3228, 0xdb180010, 0x00000000, 0x00000000}},  //   _sisk, _elvá,   ,
  { {0x7bda021e, 0x201e0020, 0x69c41a7f, 0x00000000}},  //   mitu, _miti_, _flie,
  { {0xa8a7005e, 0x644d1f2e, 0x986500a1, 0x00000000}},  //   _брок, tsai, _پیسے_,
  { {0x661d010a, 0x24580057, 0x03d51969, 0x00000000}},  // [a1f0] _visk, лать_, ажаю,
  { {0x4429002b, 0x201e0059, 0x661d01bb, 0x00000000}},  //   rqa_, _niti_, _wisk,
  { {0x661d0aaa, 0x644d02af, 0x57fc0049, 0x00000000}},  //   _tisk, ssai, _אלזו,
  { {0xa1190054, 0x7bda3229, 0x50b500ed, 0x00000000}},  //   نقاط_, hitu, ислу,
  { {0x629a049a, 0x201e01d9, 0x442912d7, 0x00000000}},  //   _áton, _biti_, qqa_,
  { {0x201e1d52, 0x7bda0632, 0x9028008b, 0x00000000}},  //   _citi_, jitu, уцца_,
  { {0x7bda2828, 0xda050061, 0x6b81007f, 0x00000000}},  //   ditu, रतात_, velg,
  { {0xf2d2019b, 0x201e0006, 0x394b00f6, 0x00000000}},  //   _ועל_, _eiti_, jacs_,
  { {0xfce5004c, 0x61fb0020, 0x201e322a, 0x00000000}},  //   ропо, _ikul, _fiti_,
  { {0x7bda065c, 0x69c4322b, 0x201e0009, 0x00000000}},  //   gitu, _slie, _giti_,
  { {0x69c40142, 0x61e90292, 0x8d770647, 0x00000000}},  //   _plie, _kjel, _ماشا,
  { {0x7cd600a1, 0x6b811341, 0x764e2c31, 0x00000000}},  //   اویز_, selg, vsby,
  { {0x69c401b5, 0x61fb0020, 0x6b81010e, 0x00000000}},  //   _vlie, _mkul, pelg,
  { {0x7bda0c1f, 0x201e322c, 0x2d8f00ea, 0x00000000}},  //   citu, _xiti_, _hage_,
  { {0x61fb011f, 0x69c401d5, 0x2d8f068f, 0x00000000}},  //   _okul, _tlie, _kage_,
  { {0x69c4002b, 0xceb200b6, 0x3936008b, 0x00000000}},  //   _ulie, חיל_, _тэкс,
  { {0x2d8f00f8, 0x6fc5001c, 0x9f5e00b0, 0x00000000}},  // [a200] _mage_, वसां, _yhtä_,
  { {0x2d8f322d, 0x80a60167, 0x61fb0f7c, 0x00000000}},  //   _lage_, یمان, _akul,
  { {0x61e90166, 0xa75b009b, 0xf10e0963, 0x00000000}},  //   _bjel, _בדיר, िध्द_,
  { {0xea76007b, 0x201e322e, 0x61e90243, 0x00000000}},  //   יגער_, _siti_, _cjel,
  { {0x61e90209, 0x201e322f, 0x25a23230, 0x00000000}},  //   _djel, _piti_, _inkl_,
  { {0x3ce000ee, 0x7c24002a, 0xdfcf0380, 0x00000000}},  //   _živo_, _éiri, وين_,
  { {0x201e2b84, 0x7bda006c, 0x61e90056, 0x00000000}},  //   _viti_, vitu, _fjel,
  { {0x27f81642, 0x61e9080e, 0xdcea00ca, 0x00000000}},  //   horn_, _gjel, šiče,
  { {0x2d8f0018, 0xbc670054, 0x201e011c, 0x00000000}},  //   _dage_, لمين_, _titi_,
  { {0x90e50063, 0x201e3231, 0x2b470087, 0x00000000}},  //   _اسفن, _uiti_, _cenc_,
  { {0x7bda3232, 0xbeaa007a, 0xf1b90059, 0x00000000}},  //   ritu, _جهان_, _hiša_,
  { {0x7bda021e, 0xdebb00a3, 0x2d8f2afd, 0x00000000}},  //   situ, _שמאל, _gage_,
  { {0x6e28004f, 0x6c340014, 0x2d840095, 0x00000000}},  //   _hudb, _افتا, meme_,
  { {0xf1b90209, 0x2d84011f, 0xdd8e00a1, 0x00000000}},  //   _miša_, leme_, _روڈ_,
  { {0x69dd1339, 0x7bd80009, 0x66b400e2, 0x00000000}},  //   éres, _imvu, обру,
  { {0xdcfb047f, 0x59d40025, 0xf99f0129, 0x00000000}},  //   nduğ, _وغير, rmès_,
  { {0x69dd29e8, 0xf1b901ee, 0x600d13ac, 0x00000000}},  // [a210] mise, _niša_, lúme,
  { {0x61e93233, 0x69dd0114, 0xa3b70061, 0x00000000}},  //   _sjel, lise, _जवळ_,
  { {0xe6950054, 0x600d000c, 0xdb030039, 0x00000000}},  //   _الجد, núme, _tonå,
  { {0x2d84047c, 0x69dd0056, 0xa5bb008e, 0x00000000}},  //   jeme_, nise, _dióc,
  { {0x2d8f062a, 0x2d840161, 0x39490051, 0x00000000}},  //   _rage_, deme_, _meas_,
  { {0x69dd006c, 0x39490051, 0x7dde001e, 0x00000000}},  //   hise, _leas_, zīst,
  { {0x320d0038, 0x2d8f030a, 0x61e90166, 0x00000000}},  //   _they_, _page_, _tjel,
  { {0x2d840190, 0x69dd1b20, 0x61e900ca, 0x00000000}},  //   geme_, jise, _ujel,
  { {0x69dd0004, 0x61f90036, 0x00000000, 0x00000000}},  //   dise, mowl,   ,
  { {0x6e28021d, 0x5ba9013b, 0x78bd00b0, 0x00000000}},  //   _fudb, уком_, dysv,
  { {0x2d8f1390, 0x7dde001e, 0x63b505fd, 0x00000000}},  //   _tage_, tīst, _mozn,
  { {0x69dd3234, 0x63b501ee, 0x39490035, 0x00000000}},  //   gise, _lozn, _ceas_,
  { {0x27f83235, 0xec350049, 0x39490051, 0x00000000}},  //   torn_, _פאַר_, _deas_,
  { {0xdc36007b, 0x7c3b033b, 0x69dd3236, 0x00000000}},  //   _האסט_, mpur, aise,
  { {0x7c3b000c, 0x69dd08a7, 0x3949004a, 0x00000000}},  //   lpur, bise, _feas_,
  { {0x249f0091, 0x7bc100f8, 0x2a360025, 0x00000000}},  //   _šuma_, lklu, _اكيد_,
  { {0x27f80061, 0x61f90036, 0x2489000a, 0x00000000}},  // [a220] porn_, dowl, gwam_,
  { {0x7bc101d5, 0xd8d701ce, 0x79860020, 0x00000000}},  //   nklu, _לופט_, lekw,
  { {0xce950089, 0xdceb0089, 0x63b5016e, 0x00000000}},  //   šējā_, _angļ, _dozn,
  { {0x629a0b33, 0x6e283237, 0x7f4801f3, 0x00000000}},  //   _átom, _rudb, _sedq,
  { {0x6e280091, 0x9053007e, 0xdfda005e, 0x00000000}},  //   _sudb, звіц, лък_,
  { {0x824a03ab, 0x6604011f, 0xdfd0006d, 0x00000000}},  //   _مشرف_, llik, بيت_,
  { {0x6f01018e, 0x2d84010f, 0x6604139b, 0x00000000}},  //   _cylc, teme_, olik,
  { {0x6604011f, 0x63b50027, 0x629c00b0, 0x00000000}},  //   nlik, _zozn, _irro,
  { {0x2d840059, 0xe3bf027b, 0x66040007, 0x00000000}},  //   reme_, _xuño_, ilik,
  { {0x3949006c, 0xdee601fc, 0x67210295, 0x00000000}},  //   _seas_, _лози, žlji,
  { {0x660411b2, 0x69dd021e, 0x3949006c, 0x00000000}},  //   klik, tise, _peas_,
  { {0x798601c3, 0x629c00d9, 0x24890036, 0x00000000}},  //   gekw, _mrro, ywam_,
  { {0x66041693, 0x3949008e, 0x600d3238, 0x00000000}},  //   dlik, _veas_, súme,
  { {0x7bc1001f, 0x69dd127b, 0x6604006c, 0x00000000}},  //   cklu, sise, elik,
  { {0x98a5027d, 0x66040007, 0x7d02118a, 0x00000000}},  //   ğlı_, flik, _hyos,
  { {0x443b001c, 0x660426c3, 0x98a5038c, 0x00000000}},  //   tpq_, glik, şlı_,
  { {0x545501fb, 0x9327025a, 0x629c3239, 0x00000000}},  // [a230] юват, مران, _arro,
  { {0xe9df0051, 0x6604323a, 0x6e220048, 0x00000000}},  //   liú_, alik, _liob,
  { {0x63b50059, 0x7c3b323b, 0x00000000, 0x00000000}},  //   _vozn, zpur,   ,
  { {0xe9df002a, 0x225c01ca, 0x63b50190, 0x00000000}},  //   niú_, ávka_, _wozn,
  { {0x628e2dad, 0x1be80061, 0x61f9323c, 0x00000000}},  //   _esbo, टचाल_, rowl,
  { {0x44390038, 0x442b00fa, 0xe9df0048, 0x00000000}},  //   _its_, _iuc_, hiú_,
  { {0x6e2200f8, 0x442b00f6, 0x44390253, 0x00000000}},  //   _biob, _huc_, _hts_,
  { {0x442302ae, 0x7d020061, 0xf8bf1697, 0x00000000}},  //   _hij_, _byos, ncés_,
  { {0xdb1a002a, 0x656f0093, 0x7d020009, 0x00000000}},  //   chtú, _mcch, _cyos,
  { {0x4423323d, 0x66040213, 0x79860020, 0x00000000}},  //   _jij_, zlik, wekw,
  { {0x442302ae, 0xf9860594, 0x656f0198, 0x00000000}},  //   _mij_, огно, _occh,
  { {0x64430107, 0x7c3b0dc9, 0x6e220eba, 0x00000000}},  //   ćnij, ppur, _giob,
  { {0x79860fb6, 0xf98a0014, 0x442b0035, 0x00000000}},  //   rekw, هنگي_, _nuc_,
  { {0xaa450364, 0x61b6007d, 0x6d4b002d, 0x00000000}},  //   _декл, _अक्ष, _hega,
  { {0x44390006, 0x66040004, 0x6d4b003f, 0x00000000}},  //   _ats_, tlik, _kega,
  { {0xe5a304f9, 0x660401d6, 0x443900f4, 0x00000000}},  //   миси, ulik, _bts_,
  { {0x6d4b0047, 0x44230662, 0x6604323e, 0x00000000}},  // [a240] _mega, _bij_, rlik,
  { {0x66040004, 0x6d4b323f, 0x442b3240, 0x00000000}},  //   slik, _lega, _duc_,
  { {0x66043241, 0x44390129, 0xe29701e1, 0x00000000}},  //   plik, _ets_, жах_,
  { {0x6d4b033b, 0xf653009b, 0x44390009, 0x00000000}},  //   _nega, _קצר_, _fts_,
  { {0x44390471, 0x7c2b1750, 0x1047005e, 0x00000000}},  //   _gts_, _nugr, оящи_,
  { {0x6d593242, 0xc05901fb, 0x6d4b006c, 0x00000000}},  //   _adwa, сії_, _aega,
  { {0x600404bd, 0x628e011c, 0x7c2b01c3, 0x00000000}},  //   nòmi, _usbo, _augr,
  { {0x442302ae, 0x5d54053c, 0x6d4b3243, 0x00000000}},  //   _zij_, чкит, _cega,
  { {0x6d4b0bc1, 0xe0da005e, 0x24820022, 0x00000000}},  //   _dega, _тва_, _jpkm_,
  { {0x6d5907be, 0x32061c7e, 0x3f87055a, 0x00000000}},  //   _edwa, lloy_, cenu_,
  { {0xc33301f8, 0xa3dc0061, 0xe9df0051, 0x00000000}},  //   וות_, तोय_, tiú_,
  { {0x7c23084a, 0x78a212d5, 0x6e22012d, 0x00000000}},  //   _einr, _šova, _uiob,
  { {0xe9df3244, 0xec7700ed, 0x1d07003b, 0x00000000}},  //   riú_, _мпц_, _деци_,
  { {0x443901ee, 0x2905001e, 0xe9df0051, 0x00000000}},  //   _rts_, āla_, siú_,
  { {0x442b3245, 0x7c2b3246, 0xa3ae006e, 0x00000000}},  //   _suc_, _zugr, कान_,
  { {0x442b0a06, 0xa4d50088, 0x3f87199a, 0x00000000}},  //   _puc_, побі, zenu_,
  { {0x92e70055, 0xf8bf3247, 0x443900fa, 0x00000000}},  // [a250] _পরে_, rcés_, _qts_,
  { {0x29150036, 0x6b8800f8, 0xa5bb0082, 0x00000000}},  //   ądać_, nedg, _gión,
  { {0x44390300, 0x1b1c0044, 0x44230065, 0x00000000}},  //   _wts_, পুরে_, _vij_,
  { {0x442302ae, 0x442b0011, 0x44390145, 0x00000000}},  //   _wij_, _tuc_, _tts_,
  { {0x4423008d, 0x8fa50822, 0x3f8700f4, 0x00000000}},  //   _tij_, зале, tenu_,
  { {0x6d4b033b, 0x94ba00b6, 0x9f4700f4, 0x00000000}},  //   _sega, _המשת, onné_,
  { {0x925800d7, 0x6d4b020c, 0xed590a78, 0x00000000}},  //   _март_, _pega, бой_,
  { {0x3f87016c, 0x656d09f3, 0x7c23004a, 0x00000000}},  //   senu_, ngah, _sinr,
  { {0x6d4b3248, 0x2054007c, 0x3f8701ee, 0x00000000}},  //   _vega, _октя, penu_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf1b921e8, 0x6d4b04cb, 0x76550036, 0x00000000}},  //   _koš_, _tega, jszy,
  { {0xf1b90119, 0x22470428, 0x9f5e01aa, 0x00000000}},  //   _još_, ánky_, _aktè_,
  { {0xeaae00a1, 0xd7a70061, 0xa3ae0309, 0x00000000}},  //   نٹی_, खांच, काम_,
  { {0x4c9a0104, 0xf1b90091, 0x9d1a00b3, 0x00000000}},  //   _לבנו, _loš_, _פוסט,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x25a60219, 0xb0bd0204, 0x3ce00059, 0x00000000}},  //   ñol_, ्नाग, _živi_,
  { {0x2ea8013d, 0x00000000, 0x00000000, 0x00000000}},  // [a260] _कप्त,   ,   ,
  { {0xdb03028c, 0x389b00a3, 0x317f001a, 0x00000000}},  //   _anné, _פיינ, _abuz_,
  { {0xd36f06f1, 0xf1b90059, 0x91e601ee, 0x00000000}},  //   اهم_, _boš_, поже,
  { {0x69c6021e, 0x00000000, 0x00000000, 0x00000000}},  //   nkke,   ,   ,
  { {0x92bc0044, 0xd00a0140, 0x69c622c1, 0x00000000}},  //   ইছে_, беде_, ikke,
  { {0xdb030010, 0x61eb0122, 0x00000000, 0x00000000}},  //   _enné, angl,   ,
  { {0x09cc001c, 0x59cc0061, 0x20020006, 0x00000000}},  //   ासाठ, ासार, _ūkis_,
  { {0x20070340, 0x799601c3, 0x00000000, 0x00000000}},  //   alni_, _nayw,   ,
  { {0x69dd00f4, 0x6b880146, 0x5c06007e, 0x00000000}},  //   èrem, tedg, зяна,
  { {0x61e22ecb, 0x5a340256, 0x6f6600ed, 0x00000000}},  //   liol, мнот, _ѕвез,
  { {0x7f3b00b6, 0x79960058, 0x765a0006, 0x00000000}},  //   _העבו, _bayw, štyj,
  { {0x61e20de6, 0x394d004a, 0x9f5c0023, 0x00000000}},  //   niol, úes_, kovë_,
  { {0x60c20010, 0x1da90164, 0x76550036, 0x00000000}},  //   nyom, कारत, wszy,
  { {0x61e20016, 0xfbcf0025, 0xa6d80044, 0x00000000}},  //   hiol, _متى_, _দুইট,
  { {0x4b7b00b3, 0x61e21622, 0xdb7b009b, 0x00000000}},  //   _האוו, kiol, _הנוכ,
  { {0xb8e308b7, 0x76550036, 0x69c601a2, 0x00000000}},  //   _এই_, rszy, ckke,
  { {0x57f5107f, 0x656d0279, 0x69df01f3, 0x00000000}},  // [a270] _опит, rgah, _imqe,
  { {0xa3d7013d, 0x76550036, 0x656d0058, 0x00000000}},  //   ़ों_, pszy, sgah,
  { {0x27e33249, 0x69cd324a, 0x59e10061, 0x00000000}},  //   mijn_, _klae, _पगार,
  { {0x61e20197, 0x27e300b5, 0x68e20006, 0x00000000}},  //   giol, lijn_, _žodi,
  { {0x2fcc324b, 0x60c20010, 0x69cd0016, 0x00000000}},  //   _bldg_, gyom, _mlae,
  { {0xa3ae0061, 0x69cd0016, 0x8b0700b9, 0x00000000}},  //   काण_, _llae, _jiří,
  { {0xdd91009c, 0xc33201f8, 0x69c6324c, 0x00000000}},  //   ہوں_, _יום_, ykke,
  { {0xf194041f, 0x27e300bb, 0xf1b90087, 0x00000000}},  //   _пись, hijn_, _mišk_,
  { {0xdd9100a1, 0x3a3c00ca, 0x00000000, 0x00000000}},  //   فوں_, _atvp_,   ,
  { {0x0ae9007c, 0x69cd006c, 0x3e570035, 0x00000000}},  //   ждой_, _alae, păt_,
  { {0xa3ae0164, 0x69cd018e, 0x198a13e7, 0x00000000}},  //   कात_, _blae, обни_,
  { {0x69cd0039, 0x88e62cf1, 0xdb180173, 0x00000000}},  //   _clae, джме, _movè,
  { {0x31560049, 0x69c600b0, 0x00000000, 0x00000000}},  //   וירן_, rkke,   ,
  { {0x61e2002d, 0x81e30044, 0x69cd324d, 0x00000000}},  //   ziol, নকি_, _elae,
  { {0xf772089d, 0x2bca001c, 0x2bda007a, 0x00000000}},  //   _یاد_, िसरा, _بانک_,
  { {0x9f5c0023, 0x69cd1e28, 0xc9f60025, 0x00000000}},  //   tovë_, _glae, _تستع,
  { {0x3d110061, 0x00000000, 0x00000000, 0x00000000}},  // [a280] देचे_,   ,   ,
  { {0x27e300b5, 0x60c20d16, 0x61e2324e, 0x00000000}},  //   cijn_, vyom, wiol,
  { {0x9f5c008d, 0x61e20052, 0x75490010, 0x00000000}},  //   sovë_, tiol, észü,
  { {0x9f5c01ca, 0x2fde0022, 0xdb0300fa, 0x00000000}},  //   mové_, _smtg_, _honó,
  { {0x61e20056, 0x9f5c004f, 0x00000000, 0x00000000}},  //   riol, lové_,   ,
  { {0x2f14007e, 0xd8d70049, 0x00000000, 0x00000000}},  //   ндлё, וונט_,   ,
  { {0x9f5c01ca, 0xdb030b33, 0x61e20052, 0x00000000}},  //   nové_, _monó, piol,
  { {0x27e300b5, 0x68f6009d, 0x00000000, 0x00000000}},  //   zijn_, _oxyd,   ,
  { {0x63bc0209, 0x91030069, 0x9f5c0161, 0x00000000}},  //   _korn, _апте, hové_,
  { {0x63bc052d, 0x9f5c004f, 0xdfa60d3a, 0x00000000}},  //   _jorn, kové_, _تحري,
  { {0x2fd7007a, 0x63bc00ab, 0x69cd324f, 0x00000000}},  //   _تولد_, _morn, _plae,
  { {0x63bc0a71, 0x9f5c01ca, 0xceb300a3, 0x00000000}},  //   _lorn, dové_, _שיף_,
  { {0xae1b0049, 0x63bc0007, 0x27e300bb, 0x00000000}},  //   _וואכ, _oorn, tijn_,
  { {0xdb03008e, 0xe7840fa0, 0x63bc3250, 0x00000000}},  //   _conó, кусо, _norn,
  { {0xd5bb0256, 0x9f5c01ca, 0x27e300bb, 0x00000000}},  //   оса_, gové_, rijn_,
  { {0xdb1801ca, 0xca290049, 0x6b9800ea, 0x00000000}},  //   _nové, _צופֿ, _havg,
  { {0x63bc0030, 0x8415005e, 0x27e300bb, 0x00000000}},  // [a290] _born, емах, pijn_,
  { {0x6b9a0030, 0x9f5c0161, 0x29090022, 0x00000000}},  //   ndtg, bové_, _iyaa_,
  { {0x63bc001a, 0xddc3001a, 0xf1b90059, 0x00000000}},  //   _dorn, nunţ, _hiši_,
  { {0xf1b904eb, 0x00000000, 0x00000000, 0x00000000}},  //   _kiši_,   ,   ,
  { {0x25ab0270, 0x653a0049, 0x00000000, 0x00000000}},  //   _incl_, _מערד,   ,
  { {0x63bc0247, 0x1e951fa3, 0x9f4b006b, 0x00000000}},  //   _gorn, ерир, _ölüb_,
  { {0xed593251, 0x9f470026, 0x00000000, 0x00000000}},  //   пой_, fonò_,   ,
  { {0xdceb01d5, 0x63bc0032, 0x63b10059, 0x00000000}},  //   _jagħ, _zorn, šenč,
  { {0x9c250517, 0xdceb01d5, 0x9f5c01ca, 0x00000000}},  //   ндид, _magħ, zové_,
  { {0xdceb0066, 0x63bc004a, 0x9f47004a, 0x00000000}},  //   _lagħ, _xorn, ronó_,
  { {0x5fac0061, 0x25bf0061, 0x63b80039, 0x00000000}},  //   चारल, _एकूण, övni,
  { {0xf99f0263, 0x9f470051, 0xdceb002b, 0x00000000}},  //   blèm_, inní_, _nagħ,
  { {0x48ce0044, 0x3a2900fa, 0x00000000, 0x00000000}},  //   রপ্র, _diap_,   ,
  { {0x9f5c0428, 0x6aae0051, 0x2c7901aa, 0x00000000}},  //   tové_, óifí, mèd_,
  { {0xb90703d7, 0xa3ae02fb, 0xdceb002b, 0x00000000}},  //   _ये_, कास_, _bagħ,
  { {0xceb20104, 0x98ac006b, 0x9f5c0161, 0x00000000}},  //   נין_, şdı_, rové_,
  { {0x63bc26ee, 0x7de80224, 0x9f5c01ca, 0x00000000}},  // [a2a0] _porn, měst, sové_,
  { {0xdb1a3252, 0x2d8d0487, 0xdcea04eb, 0x00000000}},  //   chtó, heee_, šiće,
  { {0x63bc010f, 0x395200ab, 0xa3dc0309, 0x00000000}},  //   _vorn, _keys_, तोष_,
  { {0x78a40119, 0xfb160049, 0x00000000, 0x00000000}},  //   _kriv, ײַבט_,   ,
  { {0x63bc059a, 0x66063253, 0x6731013e, 0x00000000}},  //   _torn, _ikkk, řejň,
  { {0x64440103, 0xdb0300f6, 0x74160076, 0x00000000}},  //   mpii, _anní, _سوزا,
  { {0x442a00d4, 0x660600c4, 0x628b0036, 0x00000000}},  //   _iib_, _kkkk, łgor,
  { {0x2d8d00e0, 0x442a0177, 0x249f0166, 0x00000000}},  //   geee_, _hib_, _šumi_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3a2904cb, 0xcbce0044, 0x9d13007e, 0x00000000}},  //   _siap_, িচ্ছ, ыдыч,
  { {0x78a40173, 0x442a0197, 0x2d8d3254, 0x00000000}},  //   _ariv, _mib_, beee_,
  { {0x442a0263, 0x78a42a6c, 0x3e7a0065, 0x00000000}},  //   _lib_, _briv, mët_,
  { {0x3e7a008d, 0xdd8f0054, 0x78a40851, 0x00000000}},  //   lët_, _دون_, _criv,
  { {0x78a40038, 0x7aeb0010, 0x79840009, 0x00000000}},  //   _driv, áltá, _ebiw,
  { {0x3e7a0065, 0x3a2904cb, 0x78a4006c, 0x00000000}},  //   nët_, _tiap_, _eriv,
  { {0x78a40d2b, 0x659420e7, 0x442a230b, 0x00000000}},  //   _friv, ласу, _aib_,
  { {0x442a01aa, 0x24f80a78, 0x3e7a0065, 0x00000000}},  // [a2b0] _bib_, енты_, hët_,
  { {0x3e7a008d, 0x442a04c9, 0x66720014, 0x00000000}},  //   kët_, _cib_, دگیر,
  { {0xdceb0f68, 0x3e7a0065, 0x170500a1, 0x00000000}},  //   _tagħ, jët_, _شہری_,
  { {0x799d0168, 0x200500ea, 0x3e7a0023, 0x00000000}},  //   ndsw, _skli_, dët_,
  { {0x660d0020, 0x442a0173, 0x799d0116, 0x00000000}},  //   mlak, _fib_, idsw,
  { {0x660d021e, 0xdee5012b, 0x442a01a2, 0x00000000}},  //   llak, коли, _gib_,
  { {0xa3ae02fb, 0x3e7a0065, 0x660d0032, 0x00000000}},  //   कार_, gët_, olak,
  { {0x4ce20055, 0x4c85007c, 0x660d0058, 0x00000000}},  //   _পড়ু, влив, nlak,
  { {0x7c2a000c, 0x7de800b9, 0x00000000, 0x00000000}},  //   _bifr, věst,   ,
  { {0x3e7a0065, 0x660d200f, 0x7ae70010, 0x00000000}},  //   bët_, hlak, újto,
  { {0x7c2a0124, 0xa96a0517, 0x78a4214c, 0x00000000}},  //   _difr, мина_, _sriv,
  { {0x601600c4, 0x660d0091, 0x8d740014, 0x00000000}},  //   râme, jlak, _ماها,
  { {0x1a6504e1, 0x6d490b50, 0x660d04eb, 0x00000000}},  //   ریکی_, mbea, dlak,
  { {0x6a85007e, 0x290c0089, 0x660d0032, 0x00000000}},  //   _алка, āda_, elak,
  { {0x07a303f3, 0x660d01a3, 0x645d00f8, 0x00000000}},  //   јасн, flak, _avsi,
  { {0x442a01d5, 0x660d011c, 0x3f8e012d, 0x00000000}},  //   _sib_, glak, zefu_,
  { {0xa3ae0309, 0x3e7a0065, 0xdb0a0173, 0x00000000}},  // [a2c0] काल_, zët_, _anfè,
  { {0xa3dc03d7, 0x7c2a0129, 0x6d490085, 0x00000000}},  //   तों_, _xifr, hbea,
  { {0x660d3255, 0x64443256, 0x00000000, 0x00000000}},  //   blak, spii,   ,
  { {0x442a0390, 0x3aba0049, 0x504606e3, 0x00000000}},  //   _wib_, ומענ, ведб,
  { {0x6d490146, 0x442a1dbf, 0xdb0a0173, 0x00000000}},  //   dbea, _tib_, _enfè,
  { {0x3e7a008d, 0xa3ae0061, 0x442a3257, 0x00000000}},  //   tët_, काळ_, _uib_,
  { {0x6e2b0061, 0x3f8e0012, 0x6d490f10, 0x00000000}},  //   _bigb, refu_, fbea,
  { {0x3e7a008d, 0x2bca0164, 0x3f8e0020, 0x00000000}},  //   rët_, िस्थ, sefu_,
  { {0x6e2b01d6, 0xdb0a00f4, 0x3e7a0065, 0x00000000}},  //   _digb, _infé, sët_,
  { {0x3e7a0023, 0x00000000, 0x00000000, 0x00000000}},  //   pët_,   ,   ,
  { {0x9e6502fd, 0x2ba6001c, 0x9f5c3258, 0x00000000}},  //   _مانن, _कोणा, noví_,
  { {0x7a3e0089, 0x00000000, 0x00000000, 0x00000000}},  //   _rītd,   ,   ,
  { {0x799d3259, 0x09e4007e, 0x7c2a0066, 0x00000000}},  //   rdsw, роўн, _tifr,
  { {0x5ba30265, 0x2ca6012d, 0x6e2b1c7e, 0x00000000}},  //   _връз, _irod_, _zigb,
  { {0x660d1038, 0x27ed0119, 0x45d500ed, 0x00000000}},  //   tlak, đen_, говс,
  { {0x5967005e, 0x27ed0010, 0x66040032, 0x00000000}},  //   _ръка, ően_, goik,
  { {0x660d027e, 0x2458007c, 0x629a050f, 0x00000000}},  // [a2d0] rlak, кать_, _štop,
  { {0x93270014, 0x660d0052, 0x9cd700a0, 0x00000000}},  //   نران, slak, דומה_,
  { {0x6d490324, 0x660d016e, 0x660401c3, 0x00000000}},  //   ybea, plak, boik,
  { {0x78a20107, 0xf99f01aa, 0x6d4900f6, 0x00000000}},  //   _šovi, ndè_, xbea,
  { {0x07f80014, 0xe0d00380, 0xa0690147, 0x00000000}},  //   _سریع_, يزه_, хала_,
  { {0x9f470065, 0x6e2b325a, 0x26170061, 0x00000000}},  //   minë_, _sigb, _भीती_,
  { {0xc2930014, 0x7dd5325b, 0x2eb4005e, 0x00000000}},  //   _خیاب, _láse, исъс,
  { {0x2ca6036a, 0xf1a4025f, 0xf1b90091, 0x00000000}},  //   _brod_, _крун, _pišu_,
  { {0x6d492c62, 0x9f470065, 0x395901a2, 0x00000000}},  //   rbea, ninë_, dass_,
  { {0x660400ea, 0xdb03134d, 0x60c400b0, 0x00000000}},  //   zoik, _anná, äime,
  { {0x39ea0467, 0x44210051, 0x9f470065, 0x00000000}},  //   едно_, imh_, hinë_,
  { {0x186a004c, 0xceb2071c, 0x9f470065, 0x00000000}},  //   нами_, _ליב_, kinë_,
  { {0xed590059, 0x8d5a034e, 0x9f470023, 0x00000000}},  //   maž_, _נכסי, jinë_,
  { {0xaae40014, 0xed59325c, 0x2d9d01d6, 0x00000000}},  //   اسیو, laž_, _hawe_,
  { {0x39591f4c, 0xf743005e, 0x6604002d, 0x00000000}},  //   bass_, сесо, toik,
  { {0x2d9f218c, 0x2956005e, 0x9f470023, 0x00000000}},  //   ndue_, _съкр, finë_,
  { {0xd4670200, 0x08e20044, 0x2d9d0020, 0x00000000}},  // [a2e0] лите_, _গুরু_, _mawe_,
  { {0x66041619, 0x248b0026, 0x3ce60061, 0x00000000}},  //   soik, _dpcm_, _जइसे_,
  { {0x8b56007b, 0xa9050752, 0x9f470173, 0x00000000}},  //   ריעס_, _مبین, minè_,
  { {0xc693007b, 0x4421002a, 0x2d9d10a6, 0x00000000}},  //   _פאר_, amh_, _nawe_,
  { {0x18360049, 0x9f470065, 0x63ae0022, 0x00000000}},  //   נאַל_, cinë_, _tnbn,
  { {0x2480037e, 0x25a0006c, 0xa5bb10c9, 0x00000000}},  //   mtim_, ldil_, _chóf,
  { {0x2480023a, 0x74130123, 0xdb1801dc, 0x00000000}},  //   ltim_, _طوفا, _poví,
  { {0x2ca6325d, 0x25a01462, 0x225c01ca, 0x00000000}},  //   _prod_, ndil_, ávku_,
  { {0x7f4600d7, 0x25a0325e, 0x2d9d00d2, 0x00000000}},  //   _безж, idil_, _dawe_,
  { {0x395900e0, 0x248000e0, 0x394000e5, 0x00000000}},  //   wass_, itim_, _afis_,
  { {0x7ac60072, 0x2480325f, 0x9f470065, 0x00000000}},  //   успе, htim_, zinë_,
  { {0x24800f99, 0x2e160025, 0x2d9d3260, 0x00000000}},  //   ktim_, _صباح, _gawe_,
  { {0x24800065, 0x3f9e0032, 0x00000000, 0x00000000}},  //   jtim_, _katu_,   ,
  { {0x7d06006c, 0x9f470023, 0x2d9d0045, 0x00000000}},  //   üksu, vinë_, _zawe_,
  { {0x2bb10204, 0x3f9e0089, 0x2d9d0020, 0x00000000}},  //   जारा, _matu_, _yawe_,
  { {0x9f470065, 0x3f9e0089, 0xf993083e, 0x00000000}},  //   tinë_, _latu_, _طبع_,
  { {0x248000e0, 0x44210022, 0x00000000, 0x00000000}},  // [a2f0] gtim_, tmh_,   ,
  { {0x9f47008d, 0x6fa40061, 0x3f9e253f, 0x00000000}},  //   rinë_, _गोलं, _natu_,
  { {0x06bf0055, 0x9f47008d, 0x69aa0164, 0x00000000}},  //   _উইকি, sinë_, _जोडी,
  { {0xe45f000c, 0x7dd50285, 0x9f470408, 0x00000000}},  //   _tvö_, _másc, pinë_,
  { {0xe4c7008b, 0x3f9e2a96, 0x25f40164, 0x00000000}},  //   _сённ, _batu_, ्करी_,
  { {0x76450065, 0x3f9e12aa, 0x8fa531c9, 0x00000000}},  //   _kthy, _catu_, раке,
  { {0x3f9e0f21, 0x00000000, 0x00000000, 0x00000000}},  //   _datu_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61eb0198, 0x2d9f06fa, 0xed5911e4, 0x00000000}},  //   migl, rdue_, raž_,
  { {0xa5bb0051, 0x61eb0190, 0x2d9d0020, 0x00000000}},  //   _fhóg, ligl, _wawe_,
  { {0x20070129, 0x7dd51a1c, 0x2d9d005b, 0x00000000}},  //   moni_, _cásc, _tawe_,
  { {0x61eb0207, 0x82760049, 0x9f5c0161, 0x00000000}},  //   nigl, סערע_, mová_,
  { {0xc2ec0055, 0x20070004, 0x7645000c, 0x00000000}},  //   _করছি_, ooni_, _athy,
  { {0x6d5b14f0, 0x20070041, 0xfaa51deb, 0x00000000}},  //   laua, noni_, _вако,
  { {0x9f5c0161, 0x7bc3001a, 0x65c6005e, 0x00000000}},  //   nová_, _ionu, абва,
  { {0x7bc3009f, 0x2480014a, 0x69cf00d9, 0x00000000}},  //   _honu, ttim_, ckce,
  { {0x7bc33261, 0x69d60047, 0x20071ac5, 0x00000000}},  // [a300] _konu, _ilye, koni_,
  { {0x20070f68, 0x24803262, 0x9f5c004f, 0x00000000}},  //   joni_, rtim_, ková_,
  { {0x24802aee, 0x20073263, 0x9f4700f4, 0x00000000}},  //   stim_, doni_, ciné_,
  { {0x3f9e0149, 0x69c43264, 0x24803265, 0x00000000}},  //   _satu_, _joie, ptim_,
  { {0x81cd0044, 0x69c40133, 0x00000000, 0x00000000}},  //   ষোভ_, _moie,   ,
  { {0x33d5008b, 0xbf210061, 0x2617009d, 0x00000000}},  //   _ліст, मधून_, nçon_,
  { {0x61eb26df, 0xd176007c, 0xda060061, 0x00000000}},  //   bigl, _вызы, रवात_,
  { {0x3f9e0020, 0x69c43266, 0xdb18015f, 0x00000000}},  //   _watu_, _noie, _nová,
  { {0x3f9e000b, 0xdb0a01a2, 0x00000000, 0x00000000}},  //   _tatu_, _wofü,   ,
  { {0xa5bb0051, 0x69d601aa, 0x20070197, 0x00000000}},  //   _thóg, _alye, coni_,
  { {0x1fb501be, 0x98a2005f, 0x7bc33267, 0x00000000}},  //   _устр, dakı_, _donu,
  { {0x69c400f6, 0x6d5b3268, 0x644604eb, 0x00000000}},  //   _coie, caua, _otki,
  { {0x2b0601f5, 0x69cf014a, 0x629c01f3, 0x00000000}},  //   _सुरु_, rkce, _lsro,
  { {0x628e01b5, 0x7dd50a87, 0x69d60173, 0x00000000}},  //   _opbo, _tásc, _elye,
  { {0x8c1b0097, 0x35e7008b, 0xdb18000c, 0x00000000}},  //   _שווי, ацав, _alvö,
  { {0x69c4002d, 0x6d402121, 0x69d601c3, 0x00000000}},  //   _goie, ncma, _glye,
  { {0xf94a007b, 0x61eb0207, 0x200714a5, 0x00000000}},  // [a310] _געפֿ, vigl, yoni_,
  { {0xd7950054, 0xdb0a3269, 0x69c400b5, 0x00000000}},  //   _الدخ, _infâ, _zoie,
  { {0x6446011f, 0x61eb0a7e, 0x76450039, 0x00000000}},  //   _etki, tigl, _uthy,
  { {0x201e05e0, 0x00000000, 0x00000000, 0x00000000}},  //   _ahti_,   ,   ,
  { {0x20071dad, 0xf99f04bd, 0x61eb0197, 0x00000000}},  //   toni_, llès_, rigl,
  { {0x61eb25e1, 0x44392066, 0x9f5c0161, 0x00000000}},  //   sigl, _ius_, tová_,
  { {0x20071c28, 0x44390d2b, 0xe61f0011, 0x00000000}},  //   roni_, _hus_, _khô_,
  { {0x7bc3005a, 0x44390004, 0x9f5c01ca, 0x00000000}},  //   _sonu, _kus_, rová_,
  { {0x7bc30027, 0x44390006, 0x61e90087, 0x00000000}},  //   _ponu, _jus_, _imel,
  { {0x4439010a, 0x69c400f4, 0x61fb0c7b, 0x00000000}},  //   _mus_, _soie, _hjul,
  { {0x15f902f4, 0x443101aa, 0x4439193b, 0x00000000}},  //   ्कार_, _miz_, _lus_,
  { {0x44390129, 0xe61f0082, 0xf9920025, 0x00000000}},  //   _ous_, _nhô_, أبد_,
  { {0x7bc30035, 0x69c40601, 0x44390666, 0x00000000}},  //   _tonu, _voie, _nus_,
  { {0x7bda125d, 0x6d59326a, 0x44310aa9, 0x00000000}},  //   chtu, _hewa, _niz_,
  { {0x443908ba, 0xdb180010, 0x61e90093, 0x00000000}},  //   _aus_, _tová, _omel,
  { {0x4439010a, 0x44310089, 0x61e90240, 0x00000000}},  //   _bus_, _aiz_, _nmel,
  { {0x4431326b, 0x6d5904cb, 0x3a200058, 0x00000000}},  // [a320] _biz_, _mewa, _ihip_,
  { {0x61e90047, 0x4439326c, 0x6d592381, 0x00000000}},  //   _amel, _dus_, _lewa,
  { {0x443102d5, 0x44391d47, 0x479b00a3, 0x00000000}},  //   _diz_, _eus_, _גייס,
  { {0x1219007e, 0x39420203, 0x261700c4, 0x00000000}},  //   аючы_, ncks_, nçol_,
  { {0x4fc6326d, 0x44310181, 0x2fc50048, 0x00000000}},  //   йска, _fiz_, _bolg_,
  { {0x61e9326e, 0x161c006e, 0x4375017a, 0x00000000}},  //   _emel, _भीतर_, _муст,
  { {0x6d5900b5, 0x4439326f, 0x2fc500ca, 0x00000000}},  //   _bewa, _zus_, _dolg_,
  { {0x7e9600a1, 0x7dd53270, 0x44310087, 0x00000000}},  //   لنڈر_, _pása, _ziz_,
  { {0x6d59020c, 0xbda600a1, 0xea010082, 0x00000000}},  //   _dewa, لحکو, _quậy_,
  { {0x9b5801f9, 0x6d4000d2, 0xa3dc0061, 0x00000000}},  //   шиот_, scma, तोच_,
  { {0x29120022, 0xfba7007c, 0x7995013b, 0x00000000}},  //   _ayya_, стый_, оинф,
  { {0x7bda008d, 0x6d591955, 0xf2d30049, 0x00000000}},  //   shtu, _gewa, פער_,
  { {0xae1b009b, 0x657d1a65, 0x00000000, 0x00000000}},  //   _עודכ, _rcsh,   ,
  { {0x44393271, 0xa3a8007d, 0x00000000, 0x00000000}},  //   _rus_, _खोल_,   ,
  { {0x44390af5, 0x4431009d, 0xe61f0082, 0x00000000}},  //   _sus_, _riz_, _phô_,
  { {0x443101f6, 0x4439001a, 0xdb0a0129, 0x00000000}},  //   _siz_, _pus_, _infà,
  { {0x44310066, 0x69dd0051, 0x9f470026, 0x00000000}},  // [a330] _piz_, mhse, finì_,
  { {0x443900f4, 0x61e9124c, 0xdcf3016c, 0x00000000}},  //   _vus_, _smel, šaće,
  { {0x443100b9, 0xe5351001, 0xe61f0011, 0x00000000}},  //   _viz_, _мень, _thô_,
  { {0x44390219, 0x44311c7e, 0x3f8c0041, 0x00000000}},  //   _tus_, _wiz_, _abdu_,
  { {0x44390004, 0xe05700a1, 0x6d5900ab, 0x00000000}},  //   _uus_, صیات_, _rewa,
  { {0x644d020c, 0x78ad040d, 0x6d59003f, 0x00000000}},  //   mpai, _mrav, _sewa,
  { {0x2fc500c7, 0x644d021e, 0x321f0011, 0x00000000}},  //   _volg_, lpai, _thuy_,
  { {0x1c45005e, 0x2d8a0010, 0x61e90142, 0x00000000}},  //   оним, őben_, _umel,
  { {0x644d02f6, 0x78ad00d0, 0xdbf1006b, 0x00000000}},  //   npai, _nrav, nəçi,
  { {0x7ff70151, 0x3a201b2a, 0x6d590093, 0x00000000}},  //   _اسرا, _ship_, _wewa,
  { {0x6d590169, 0x00000000, 0x00000000, 0x00000000}},  //   _tewa,   ,   ,
  { {0xee2e0c50, 0x62850016, 0xdb1a0036, 0x00000000}},  //   _ін_, itho, ektó,
  { {0x798d0022, 0x261703d1, 0x394d004a, 0x00000000}},  //   _dbaw, rçol_, ñesa_,
  { {0x78ad0627, 0xdbf1005f, 0xab290726, 0x00000000}},  //   _drav, dəçi, _кола_,
  { {0x78ad3272, 0x69dd0048, 0x00000000, 0x00000000}},  //   _erav, bhse,   ,
  { {0x69dd001f, 0x7dd50047, 0x628511f0, 0x00000000}},  //   chse, _máso, dtho,
  { {0x6285018e, 0xa3ea00e2, 0x644d0058, 0x00000000}},  // [a340] etho, адаа_, gpai,
  { {0xe3b70088, 0xa5bb0051, 0x317f00e5, 0x00000000}},  //   обу_, _phóc, _acuz_,
  { {0xe29a0c4e, 0x78ad0059, 0x62850146, 0x00000000}},  //   рае_, _zrav, gtho,
  { {0x63a51270, 0x00000000, 0x00000000, 0x00000000}},  //   adhn,   ,   ,
  { {0x92bc0055, 0x62850048, 0x00000000, 0x00000000}},  //   েছে_, atho,   ,
  { {0x66163273, 0x6e3a146c, 0x62850066, 0x00000000}},  //   llyk, _putb, btho,
  { {0x7d15006b, 0xcdda0098, 0x628502d4, 0x00000000}},  //   əzsi, ињи_, ctho,
  { {0x85480006, 0x00000000, 0x00000000, 0x00000000}},  //   brėž,   ,   ,
  { {0x6ea800a1, 0x00000000, 0x00000000, 0x00000000}},  //   _گناہ_,   ,   ,
  { {0x3dc600e5, 0x00000000, 0x00000000, 0x00000000}},  //   _woow_,   ,   ,
  { {0x69dd0065, 0x2905005d, 0xed46007c, 0x00000000}},  //   thse, ğlam_, _днеп,
  { {0x644d0943, 0x00000000, 0x00000000, 0x00000000}},  //   ypai,   ,   ,
  { {0x6e222b6f, 0x7dd504bb, 0x764e01c3, 0x00000000}},  //   _ihob, _záso, epby,
  { {0x7ddc00f4, 0x6285005b, 0x261700c4, 0x00000000}},  //   _dése, ytho, rçom_,
  { {0x06e10044, 0x6e2200e0, 0x66160039, 0x00000000}},  //   _মুজি, _khob, flyk,
  { {0x78ad3274, 0x7dd5004f, 0xd5b802b8, 0x00000000}},  //   _trav, _násl, осу_,
  { {0x78ad0627, 0x04590025, 0xe9df0051, 0x00000000}},  // [a350] _urav, صلاة_, mhú_,
  { {0x57f4007c, 0x644d0051, 0x62852d0f, 0x00000000}},  //   _опыт, rpai, ttho,
  { {0x644d11e8, 0x661601d6, 0x6440009d, 0x00000000}},  //   spai, blyk, _émin,
  { {0x6285018e, 0x7ddc0d7b, 0x7df3001a, 0x00000000}},  //   rtho, _lésb, năst,
  { {0x62853275, 0x644b00d6, 0x55ba009b, 0x00000000}},  //   stho, ígid, _המרו,
  { {0x628508f0, 0x94050014, 0x660d22d1, 0x00000000}},  //   ptho, _روزه, loak,
  { {0x6e220058, 0x00000000, 0x00000000, 0x00000000}},  //   _bhob,   ,   ,
  { {0xbca50054, 0x317f005d, 0xb222000c, 0x00000000}},  //   كمبي, _ucuz_, áætl,
  { {0x2bb90025, 0x2b5c0925, 0x96270089, 0x00000000}},  //   مادة_, _bevc_, _izņē,
  { {0x7ddc028c, 0x9c22008b, 0x00000000, 0x00000000}},  //   _rése, ндыд,   ,
  { {0xe8e1001d, 0x3b090594, 0x660d0f45, 0x00000000}},  //   _đều_, сено_, koak,
  { {0x44230009, 0xf2d20049, 0x6e220048, 0x00000000}},  //   _lhj_, געט_, _ghob,
  { {0x2d8f00c4, 0x6e290637, 0x3935007e, 0x00000000}},  //   _ibge_, mmeb, дэрс,
  { {0x2bbb0054, 0x59c80061, 0x6e2906ec, 0x00000000}},  //   _خاصة_, _लवकर, lmeb,
  { {0xe9df0051, 0x290c0036, 0xf62601ee, 0x00000000}},  //   bhú_, łda_, здво,
  { {0x6e290325, 0xb9020044, 0x00000000, 0x00000000}},  //   nmeb, _দশ_,   ,
  { {0x75d30025, 0x9992007f, 0x00000000, 0x00000000}},  // [a360] ريكا, ūzų_,   ,
  { {0x66160056, 0x44230082, 0x2d8f0145, 0x00000000}},  //   slyk, _chj_, _lbge_,
  { {0xe297005e, 0x8c1a009b, 0x44230023, 0x00000000}},  //   зах_, צועי, _dhj_,
  { {0x216701fc, 0x68e20006, 0xf41f1ff7, 0x00000000}},  //   зици_, _žody, _spät_,
  { {0xf53700b6, 0x6e29006c, 0xdd990062, 0x00000000}},  //   _מרכז_, dmeb, deň_,
  { {0x6e22176e, 0x9f4700f6, 0x00000000, 0x00000000}},  //   _shob, ginà_,   ,
  { {0x6e22016d, 0xcf260054, 0x60160181, 0x00000000}},  //   _phob, أرشي, nâmi,
  { {0x21a310d8, 0xade30088, 0x00000000, 0x00000000}},  //   _писм, ецьк,   ,
  { {0xbf360257, 0xaf36023c, 0x60d600ea, 0x00000000}},  //   _فراغ, _فرات, øymd,
  { {0xdb030173, 0x00000000, 0x00000000, 0x00000000}},  //   _kanè,   ,   ,
  { {0xe9df002a, 0x6e220048, 0xbeaa03ec, 0x00000000}},  //   thú_, _thob, _دهان_,
  { {0x7d02002d, 0x2617014a, 0x3ddf00bb, 0x00000000}},  //   _txos, rçok_, chuw_,
  { {0x9ac4002b, 0x7de50025, 0x05000044, 0x00000000}},  //   _suċċ, _تسلم, ্ধুর_,
  { {0xdc37007b, 0xa5bb3276, 0xaa66005e, 0x00000000}},  //   _זאגט_, _chón, _етик,
  { {0x660d0059, 0xeaaf0025, 0x9ac4002b, 0x00000000}},  //   toak, _معي_, _quċċ,
  { {0x6b9a121b, 0x7bca00ea, 0x442301a3, 0x00000000}},  //   letg, _hofu, _shj_,
  { {0x2b470009, 0x660d1293, 0x200e00e7, 0x00000000}},  // [a370] _yfnc_, roak, kofi_,
  { {0xdd9901ca, 0x38690056, 0x660d002d, 0x00000000}},  //   zeň_, _ivar_, soak,
  { {0x3869000c, 0x75480010, 0x00000000, 0x00000000}},  //   _hvar_, észí,   ,
  { {0xd1310137, 0x41e4008b, 0x3869067e, 0x00000000}},  //   نما_, ніча, _kvar_,
  { {0x92bd0044, 0xdd990161, 0xb457025a, 0x00000000}},  //   ইনে_, veň_, _ریاض_,
  { {0x25a90047, 0x24890461, 0x2eb5109f, 0x00000000}},  //   ldal_, mtam_, дсис,
  { {0x24890047, 0x9294005e, 0x00000000, 0x00000000}},  //   ltam_, _парц,   ,
  { {0x53340265, 0x9627001e, 0x25a93277, 0x00000000}},  //   _чест, _uzņē, ndal_,
  { {0x24891589, 0x7dd5009f, 0xea000011, 0x00000000}},  //   ntam_, _hásk, _ngại_,
  { {0x320f0038, 0xeb99025f, 0x7bca00f6, 0x00000000}},  //   logy_, цио_, _cofu,
  { {0x7bca009d, 0x3ed50647, 0x25a90058, 0x00000000}},  //   _dofu, _تقار, kdal_,
  { {0x24893278, 0x7dd50010, 0x00000000, 0x00000000}},  //   ktam_, _másk,   ,
  { {0xa5bb0011, 0xb87b0047, 0xdb0a010f, 0x00000000}},  //   _phón, szín, _anfä,
  { {0x63a70027, 0x0c2401fb, 0x24890010, 0x00000000}},  //   _najn, _змін, dtam_,
  { {0x16a70200, 0x38690061, 0x2cad00ab, 0x00000000}},  //   мври_, _evar_, lved_,
  { {0xcb1200b6, 0x60160181, 0x200e2cb2, 0x00000000}},  //   _שלה_, râmi, zofi_,
  { {0x63a70010, 0x224d0091, 0x00000000, 0x00000000}},  // [a380] _bajn, _čeka_,   ,
  { {0x66092ebb, 0x63a70de5, 0x78a4272f, 0x00000000}},  //   čeka, _cajn, _isiv,
  { {0xea010082, 0x05000044, 0x25a919e3, 0x00000000}},  //   _quầy_, ্ধের_, bdal_,
  { {0x320f1ee1, 0xe3b100a1, 0x00000000, 0x00000000}},  //   gogy_, پرے_,   ,
  { {0x63a70036, 0x24891a8a, 0xdb0301ca, 0x00000000}},  //   _fajn, ctam_, _dané,
  { {0xb03301fb, 0xdfd00025, 0x5f930545, 0x00000000}},  //   вніш, طيب_, вишт,
  { {0xc24300d7, 0x2d8d192b, 0x2cad00ab, 0x00000000}},  //   _анск, ffee_, eved_,
  { {0x443807b5, 0xec6a0088, 0x7bca0483, 0x00000000}},  //   _hir_, орок_, _sofu,
  { {0x7ddc00d6, 0x44380e61, 0x2383000c, 0x00000000}},  //   _césa, _kir_, _þrjá_,
  { {0x61e201bf, 0x7ddc00f4, 0x6f0d005d, 0x00000000}},  //   lhol, _désa, şaca,
  { {0x4438001f, 0x386904d7, 0x33771aac, 0x00000000}},  //   _mir_, _svar_, ועים_,
  { {0xc33301f8, 0x61e20292, 0x44382555, 0x00000000}},  //   כות_, nhol, _lir_,
  { {0xdd8f00a6, 0x6fc20067, 0x443816b8, 0x00000000}},  //   _خون_, लापू, _oir_,
  { {0x3f9c00e7, 0x61e2017b, 0xc7bb007e, 0x00000000}},  //   nevu_, hhol, цём_,
  { {0x38c5008d, 0x63a70066, 0xe6130054, 0x00000000}},  //   _bërë_, _rajn, نشر_,
  { {0x44380971, 0x24890047, 0x63a70047, 0x00000000}},  //   _air_, ttam_, _sajn,
  { {0x443801f6, 0x61e20018, 0xb4d9013d, 0x00000000}},  // [a390] _bir_, dhol, ़ने_,
  { {0x3f9c037e, 0x24893278, 0x6fd40129, 0x00000000}},  //   jevu_, rtam_, _fàci,
  { {0x44381fdc, 0x6564011c, 0x3f9c3279, 0x00000000}},  //   _dir_, baih, devu_,
  { {0x7c38128c, 0x61e20190, 0x248908a4, 0x00000000}},  //   _livr, ghol, ptam_,
  { {0x63a70466, 0x24440039, 0x4438086a, 0x00000000}},  //   _tajn, _göm_, _fir_,
  { {0x44380292, 0xe43300a1, 0x187c00b3, 0x00000000}},  //   _gir_, _شہاد, קטוב,
  { {0x7ddc24d5, 0x68200010, 0x61e201a2, 0x00000000}},  //   _sésa, ködn, bhol,
  { {0x61e21af5, 0x6fdd0129, 0x6e920025, 0x00000000}},  //   chol, _dèca, اليا,
  { {0x60390173, 0x8b07013e, 0x6b830085, 0x00000000}},  //   _fňma, _ohří, _pcng,
  { {0x2cad0038, 0x7dd50047, 0x3f9c0107, 0x00000000}},  //   rved_, _mási, cevu_,
  { {0x656f13a6, 0x7c3801c5, 0x291e0036, 0x00000000}},  //   _odch, _divr, ętam_,
  { {0x799d327a, 0xc332009b, 0x7dd500fa, 0x00000000}},  //   gesw, טוי_, _oási,
  { {0x9f47014a, 0x26170181, 0x656400b0, 0x00000000}},  //   ginç_, nçou_, vaih,
  { {0x38c50065, 0x6d490035, 0x60c40103, 0x00000000}},  //   _sërë_, lcea, äimi,
  { {0x66e60cb7, 0x61e20875, 0x443800c4, 0x00000000}},  //   хова, yhol, _rir_,
  { {0x7dd5029d, 0xa3a803d7, 0x443802f1, 0x00000000}},  //   _bási, _खोज_, _sir_,
  { {0x44380006, 0x1426003b, 0x6d490051, 0x00000000}},  // [a3a0] _pir_, едам, icea,
  { {0x0857019b, 0x6fd400f6, 0x6564327b, 0x00000000}},  //   _רבים_, _tàci, saih,
  { {0x44381273, 0x38c50065, 0x00000000, 0x00000000}},  //   _vir_, _tërë_,   ,
  { {0x4438327c, 0x3f85327d, 0x2a6a0010, 0x00000000}},  //   _wir_, _aclu_, ábbi_,
  { {0x4438018e, 0x61e202cc, 0x3f9c217f, 0x00000000}},  //   _tir_, rhol, tevu_,
  { {0x6d4b006c, 0x442c01aa, 0x61e20905, 0x00000000}},  //   _afga, _òd_, shol,
  { {0x61e20030, 0xe297003b, 0x3f9c0b4a, 0x00000000}},  //   phol, _пар_, revu_,
  { {0x291e0036, 0xbef70025, 0x7c380095, 0x00000000}},  //   ętaj_, عروض_, _sivr,
  { {0xdb1800c4, 0x98ab005d, 0x32070010, 0x00000000}},  //   _invé, yacı_, énye_,
  { {0xdb571255, 0x6d490085, 0x3ea90036, 0x00000000}},  //   нюю_, acea, łata_,
  { {0x7c3800f4, 0xf99f01aa, 0x799d327e, 0x00000000}},  //   _vivr, nnèg_, tesw,
  { {0x225c01ca, 0x6136005d, 0x00000000, 0x00000000}},  //   ávky_, _gülü,   ,
  { {0x799d327f, 0x00000000, 0x00000000, 0x00000000}},  //   resw,   ,   ,
  { {0xb8c903d7, 0x2ca60016, 0x799d3280, 0x00000000}},  //   _गई_, _isod_, sesw,
  { {0x7a3e0006, 0x9c17009b, 0x98ab019a, 0x00000000}},  //   _būte, _רחוק_, racı_,
  { {0x34953281, 0x7ddc0f57, 0x660916d0, 0x00000000}},  //   кабр, _méso, čeko,
  { {0x3a2900e0, 0xe4e70088, 0x00000000, 0x00000000}},  // [a3b0] _ihap_, хівн,   ,
  { {0xdb0300f6, 0x7c2d0026, 0x00000000, 0x00000000}},  //   _innò, _èart,   ,
  { {0x79ea00a1, 0xc87f01a2, 0x6d490d28, 0x00000000}},  //   _رویہ_, luß_, ycea,
  { {0xcb13007b, 0x7ae5006c, 0x2ca60016, 0x00000000}},  //   אלע_, _ühte, _osod_,
  { {0xf99400b6, 0x10a50794, 0x6f1a000a, 0x00000000}},  //   טרף_, тилн, _aytc,
  { {0x61e0006b, 0x261700c4, 0xdb18000a, 0x00000000}},  //   _elml, rçou_, _envé,
  { {0x24990022, 0x5f05005e, 0x628b0035, 0x00000000}},  //   _hpsm_, ъзка, ăgos,
  { {0x7ddc00f4, 0x3a290082, 0x22430022, 0x00000000}},  //   _déso, _nhap_, _iujk_,
  { {0x6d490c3c, 0xf204008b, 0xfce50364, 0x00000000}},  //   rcea, _сяро, топо,
  { {0x6d490ea5, 0x1a6502fd, 0x386b1c7e, 0x00000000}},  //   scea, نیتی_, dscr_,
  { {0x26171396, 0x9f5c0161, 0xdb03000a, 0x00000000}},  //   nços_, nový_, _annò,
  { {0x186a004c, 0x3a290011, 0x9f4700b0, 0x00000000}},  //   мами_, _chap_, sinä_,
  { {0xb8830861, 0x9f5c0161, 0x00000000, 0x00000000}},  //   šíns, hový_,   ,
  { {0x9f5c01ca, 0x00000000, 0x00000000, 0x00000000}},  //   kový_,   ,   ,
  { {0xfaa51a02, 0x9663022a, 0x62830129, 0x00000000}},  //   _райо, икре, ànol,
  { {0x98be014a, 0x2d9f0c3f, 0x7e8a006b, 0x00000000}},  //   ştı_, neue_, _qəpi,
  { {0xd4670113, 0xdb030d8e, 0xb3863282, 0x00000000}},  // [a3c0] ките_, _maní, клал,
  { {0x2d9f01d6, 0xf53f0190, 0x00000000, 0x00000000}},  //   heue_, _egå_,   ,
  { {0x66e600ed, 0x78b600e5, 0x2777009b, 0x00000000}},  //   _рона, _hryv, _בגין_,
  { {0x7ddc00f4, 0xdb180428, 0x6fd400f6, 0x00000000}},  //   _réso, _nový, _làct,
  { {0xe0e00055, 0x7bda000c, 0x00000000, 0x00000000}},  //   বপ্ন, yktu,   ,
  { {0xdfcf057d, 0x25a000f4, 0xb4de013d, 0x00000000}},  //   يين_, leil_, तनी_,
  { {0x6fdd04bd, 0x79960036, 0x39401e89, 0x00000000}},  //   _tècn, _obyw, _ogis_,
  { {0x23270478, 0x27f801a2, 0xdb03004a, 0x00000000}},  //   _роси_, hirn_, _caní,
  { {0xc5f300b6, 0xdb010f4b, 0xdb033283, 0x00000000}},  //   ידה_, ndlæ, _daní,
  { {0x442a01d6, 0x25a03284, 0x9f5e000a, 0x00000000}},  //   _jhb_, heil_, _ektò_,
  { {0xe9f90822, 0x5a351666, 0x0d8600a5, 0x00000000}},  //   енні_, лнот, _ален,
  { {0x3940004a, 0x442a0544, 0x00000000, 0x00000000}},  //   _cgis_, _lhb_,   ,
  { {0x386d028c, 0xc864007c, 0x6fd400f6, 0x00000000}},  //   éer_, итри, _fàct,
  { {0xd7c90014, 0x442a00d9, 0x24803285, 0x00000000}},  //   روزه_, _nhb_, duim_,
  { {0x1af00044, 0x25a00056, 0x88cb0044, 0x00000000}},  //   _ঘুরে_, feil_, _লেখক,
  { {0x2d840011, 0xa9070014, 0x644b00c4, 0x00000000}},  //   ngme_, _لبخن, ígio,
  { {0x80be03d7, 0x24803286, 0x38600016, 0x00000000}},  // [a3d0] ्हों, guim_, _gwir_,
  { {0x9f5c0161, 0x6fdd00d4, 0xa5bb0051, 0x00000000}},  //   tový_, _rèco, _mhói,
  { {0x69dd3287, 0x9388005e, 0x00000000, 0x00000000}},  //   okse, ъста_,   ,
  { {0x26170a0a, 0x9f5c0161, 0x00000000, 0x00000000}},  //   rços_, rový_,   ,
  { {0x7dd5008e, 0xdfd50a78, 0x31640087, 0x00000000}},  //   _mást, лоды, _demz_,
  { {0x7dd5008e, 0x442a00d9, 0xfddb0061, 0x00000000}},  //   _lást, _ghb_, बस्फ,
  { {0x4e950054, 0xf1a700e3, 0x2b4c0009, 0x00000000}},  //   اشتر, _иран, dcdc_,
  { {0x7db4008b, 0x7dd50428, 0x764501a3, 0x00000000}},  //   асьц, _nást, _muhy,
  { {0xa5bb002a, 0x7c2a0051, 0xbfab0088, 0x00000000}},  //   _chói, _bhfr, _отже_,
  { {0x7aa50069, 0x5ac9312f, 0xa5bb0051, 0x00000000}},  //   гиоз, елом_, _dhói,
  { {0xdb030010, 0x1603007d, 0x76450288, 0x00000000}},  //   _taní, रचार_, _nuhy,
  { {0x601600c4, 0xa5bb0048, 0x61f900e0, 0x00000000}},  //   lâmp, _fhói, niwl,
  { {0x6d5b0149, 0xfd44008b, 0x25a0009d, 0x00000000}},  //   mbua, _тэхн, veil_,
  { {0xaae5004b, 0x291e001e, 0x2a6c0300, 0x00000000}},  //   _مسعو, āta_, bsdb_,
  { {0x66e302a8, 0x25a0010f, 0x7dd50051, 0x00000000}},  //   бора, teil_, _fást,
  { {0x2905005a, 0x248002a6, 0x7dd50b33, 0x00000000}},  //   ğlar_, tuim_, _gást,
  { {0x26de3288, 0x2905038c, 0x25a000f4, 0x00000000}},  // [a3e0] što_, şlar_, reil_,
  { {0x7dd501ca, 0x25a0021f, 0x24800007, 0x00000000}},  //   _zást, seil_, ruim_,
  { {0x1bf60049, 0xdb0a00f6, 0x00000000, 0x00000000}},  //   נצער_, _cafè,   ,
  { {0x00e60595, 0x067b01ce, 0x7a3e0089, 0x00000000}},  //   лжен, _אנטל, _jūta,
  { {0x6604266a, 0x248009f7, 0x8a17009b, 0x00000000}},  //   mnik, quim_, נחנו_,
  { {0x660414d4, 0xdce00089, 0x656600e0, 0x00000000}},  //   lnik, jamā, _hekh,
  { {0x69dd021e, 0xdb01152c, 0xa5bb0051, 0x00000000}},  //   ykse, ndlä, _shói,
  { {0x5c740081, 0x6446000b, 0x66040ac2, 0x00000000}},  //   алит, _kuki, nnik,
  { {0x600a0200, 0x6604006c, 0xa3e8006e, 0x00000000}},  //   _знам_, inik, _बता_,
  { {0x66041263, 0xda7a01fb, 0x7dd50051, 0x00000000}},  //   hnik, ням_, _sást,
  { {0xd00f05d4, 0x644600b0, 0x66041e3a, 0x00000000}},  //   _علم_, _luki, knik,
  { {0x69dd021e, 0x7c86004d, 0x63ae3289, 0x00000000}},  //   ukse, _буке, _labn,
  { {0x5c5600aa, 0x69dd0056, 0x64460b53, 0x00000000}},  //   _стеф, rkse, _nuki,
  { {0x69dd010e, 0x5fc70061, 0xdb0300d4, 0x00000000}},  //   skse, लायल, _fanà,
  { {0xd5bb00ed, 0x7dd50051, 0x6446328a, 0x00000000}},  //   нса_, _tást, _auki,
  { {0x644601a3, 0x66040fb6, 0x63ae0146, 0x00000000}},  //   _buki, gnik, _aabn,
  { {0x629c0bc0, 0xd37b01fc, 0xf9900025, 0x00000000}},  // [a3f0] _apro, ече_, _ربي_,
  { {0x64460521, 0x5eea0044, 0x6604010e, 0x00000000}},  //   _duki, _কখনও_, anik,
  { {0x660401d9, 0xdb030d86, 0x64460032, 0x00000000}},  //   bnik, _kaná, _euki,
  { {0x6d420011, 0x64460173, 0xdb0a0f07, 0x00000000}},  //   _ngoa, _fuki, _café,
  { {0xdceb01d5, 0x6016001a, 0x64460009, 0x00000000}},  //   _ibgħ, tâmp, _guki,
  { {0x629c0061, 0xd47a01ce, 0x3d18013d, 0x00000000}},  //   _fpro, _באשל, _पड़े_,
  { {0x6d5b005f, 0xd34400a1, 0x4433002b, 0x00000000}},  //   tbua, _اہمی, mmx_,
  { {0x8db5007e, 0x02e10061, 0x60390173, 0x00000000}},  //   рскі, पनीन, _kňmk,
  { {0x6d5b04cb, 0xdb0100c4, 0x629c00b9, 0x00000000}},  //   rbua, celê, _zpro,
  { {0x66040059, 0xdb180819, 0xabd50080, 0x00000000}},  //   znik, _enví, рциј,
  { {0x3b090467, 0x1a06005e, 0xceb80036, 0x00000000}},  //   тено_, ипом, _grę_,
  { {0x6604005f, 0x601f0181, 0x1d190077, 0x00000000}},  //   xnik, dêmi, _июль_,
  { {0x660400ee, 0x00000000, 0x00000000, 0x00000000}},  //   vnik,   ,   ,
  { {0x66040046, 0xdb03002a, 0x64460020, 0x00000000}},  //   wnik, _eaná, _ruki,
  { {0x09e6328b, 0xdb030b33, 0x6446093c, 0x00000000}},  //   _войн, _faná, _suki,
  { {0x395f000c, 0x63ae00d9, 0xe9df0027, 0x00000000}},  //   ðust_, _sabn, ckú_,

  { {0x7ddc009d, 0x00000000, 0x00000000, 0x00000000}},  // [a400] _désh,   ,   ,
  { {0x66040213, 0x629c002b, 0x68200010, 0x00000000}},  //   snik, _ppro, ködi,
  { {0x65660093, 0x63060025, 0x660402db, 0x00000000}},  //   _tekh, جوال, pnik,
  { {0x644604ff, 0xe0da012b, 0xfc480011, 0x00000000}},  //   _tuki, кве_, _lửa_,
  { {0x4fc60517, 0x629c0036, 0x63ae0009, 0x00000000}},  //   иска, _wpro, _tabn,
  { {0xfc480011, 0x00000000, 0x00000000, 0x00000000}},  //   _nửa_,   ,   ,
  { {0x7ddc00f4, 0x539b009b, 0x5ed90044, 0x00000000}},  //   _hési, _שילו, _ভেবে,
  { {0x9fa3000c, 0x7dd5008e, 0xdb010173, 0x00000000}},  //   síðu_, _básq, melè,
  { {0x644000f4, 0xdb010023, 0x00000000, 0x00000000}},  //   _émis, belë,   ,
  { {0xfc48001d, 0x60e80279, 0x66090091, 0x00000000}},  //   _cửa_, ırmı, čeki,
  { {0xb4db001d, 0x625301d5, 0x7ddc009d, 0x00000000}},  //   _ngàn, _għod, _lési,
  { {0xed5a09b2, 0x32060aa0, 0x996700e2, 0x00000000}},  //   _род_, nnoy_, штол,
  { {0xfbcf06c6, 0x6fdd0173, 0x00000000, 0x00000000}},  //   ستی_, _bèch,   ,
  { {0xd7fb03f3, 0x00000000, 0x00000000, 0x00000000}},  //   тум_,   ,   ,
  { {0xdb030047, 0x00000000, 0x00000000, 0x00000000}},  //   _taná,   ,   ,
  { {0xdb1800f6, 0x3c2b08c8, 0x00000000, 0x00000000}},  //   _invà, røve_,   ,
  { {0x22a8011f, 0xb87b0010, 0x44210032, 0x00000000}},  // [a410] _aşk_, gzít, tlh_,
  { {0x7ddc00f4, 0x69cf050f, 0xdce2049c, 0x00000000}},  //   _dési, ljce, _neoč,
  { {0xdb0a1acf, 0xa5bb0051, 0x00000000, 0x00000000}},  //   _infó, _bhót,   ,
  { {0xc24401e1, 0x4433004a, 0x00000000, 0x00000000}},  //   інік, smx_,   ,
  { {0xc1040025, 0xdb0301a2, 0xdb0a01a2, 0x00000000}},  //   يومي, _unnö, _anfü,
  { {0x656d2eed, 0x225a0022, 0xdce00035, 0x00000000}},  //   laah, bppk_, zamă,
  { {0xfc480011, 0x3f87016c, 0x63a50645, 0x00000000}},  //   _rửa_, rgnu_, mehn,
  { {0xfc48001d, 0x62850058, 0x7205025a, 0x00000000}},  //   _sửa_, muho, _اورم,
  { {0x62850058, 0xdb0126f7, 0x00000000, 0x00000000}},  //   luho, melé,   ,
  { {0x656d0058, 0x7dd5008e, 0x63a50910, 0x00000000}},  //   haah, _vásq, nehn,
  { {0xa96a00aa, 0xae7801fb, 0xaa5600a1, 0x00000000}},  //   лина_, _всіх_, یلیا_,
  { {0xdb0302d5, 0x6fdd00f4, 0x98a6073b, 0x00000000}},  //   _lanç, _sèch, биме,
  { {0xeb99026b, 0x91ba009b, 0x9916007e, 0x00000000}},  //   _бил_, אמרי, сьні,
  { {0x7ddc00f4, 0xdb0300f6, 0x661d01c3, 0x00000000}},  //   _rési, _nanç, _aksk,
  { {0x320617e5, 0x67290224, 0xdb010047, 0x00000000}},  //   ynoy_, řejn, kelé,
  { {0x6285016c, 0xbb3a0049, 0x7ddc008e, 0x00000000}},  //   duho, _געצי, _pési,
  { {0x69c40197, 0x78ad0087, 0xdb180cd3, 0x00000000}},  // [a420] _inie, _gsav, _invá,
  { {0xdb030a0a, 0x656d0487, 0x6039000a, 0x00000000}},  //   _canç, aaah, _fňmi,
  { {0xb87b0047, 0x69c40007, 0xdb030181, 0x00000000}},  //   szít, _knie, _danç,
  { {0xc8b5026c, 0x69d60299, 0x3d180061, 0x00000000}},  //   _الیک, _joye, _पडले_,
  { {0x69d6028c, 0x69c40046, 0xa5bb000c, 0x00000000}},  //   _moye, _mnie, _skóg,
  { {0x6285025e, 0x69d6009d, 0xdb0301a2, 0x00000000}},  //   buho, _loye, _kanä,
  { {0x7ddc00d4, 0x00000000, 0x00000000, 0x00000000}},  //   _mésv,   ,   ,
  { {0x7bc32529, 0x200716a3, 0x69d6328c, 0x00000000}},  //   _annu, anni_, _noye,
  { {0xf1c30802, 0x61e200b9, 0x8afc0036, 0x00000000}},  //   šší_, mkol, zbęd,
  { {0x61e20337, 0x24800051, 0x00000000, 0x00000000}},  //   lkol, irim_,   ,
  { {0x441b007b, 0x69c401d5, 0x539b0049, 0x00000000}},  //   רויס, _bnie, נסטא,
  { {0x61e2002b, 0x14c8024c, 0x7bc3044e, 0x00000000}},  //   nkol, रमाण, _ennu,
  { {0xdca30113, 0x69d6009d, 0x69c400b4, 0x00000000}},  //   _наци, _doye, _dnie,
  { {0xdb010047, 0xb8d10316, 0x656d00e7, 0x00000000}},  //   zelé, _ऐन_, waah,
  { {0xdb0a0263, 0x61e20ae4, 0x69d600f4, 0x00000000}},  //   _enfò, kkol, _foye,
  { {0xdb0300c4, 0x69c40036, 0x200c016c, 0x00000000}},  //   _sanç, _gnie, _ljdi_,
  { {0x63a5006c, 0xdb012fef, 0x656d0c2c, 0x00000000}},  // [a430] tehn, velé, raah,
  { {0xa5bb0051, 0x7d1d010f, 0x628518fb, 0x00000000}},  //   _chór, üssi, tuho,
  { {0xa6ab004b, 0xdb010010, 0x45d500ed, 0x00000000}},  //   _صادق_, telé, _донс,
  { {0x201e0089, 0x24800091, 0x61e20058, 0x00000000}},  //   _akti_, brim_, gkol,
  { {0xa5bb0051, 0x7ddc00f4, 0xdb010010, 0x00000000}},  //   _fhór, _jésu, relé,
  { {0xf2e701be, 0x7e5500e3, 0x660904eb, 0x00000000}},  //   _любо, отиц, čeku,
  { {0xb7dc0049, 0xdb012b25, 0x00000000, 0x00000000}},  //   רקוי, pelé,   ,
  { {0xec7900ed, 0xa194007c, 0x62530066, 0x00000000}},  //   апи_, _насч, _tħob,
  { {0x61fb0058, 0x201e0022, 0x1be9004d, 0x00000000}},  //   _imul, _fkti_, идии_,
  { {0x69c4001e, 0x69d600f4, 0x9f4500f6, 0x00000000}},  //   _snie, _soye, _ollé_,
  { {0xab29007e, 0x69c40251, 0xdb010190, 0x00000000}},  //   рона_, _pnie, ndlø,
  { {0x5ed20055, 0x27fa023a, 0x5fc70061, 0x00000000}},  //   _থেকে, _smpn_, लावल,
  { {0x69d600f4, 0x776e006b, 0x9f45009d, 0x00000000}},  //   _voye, tabx, _allé_,
  { {0x61e9049a, 0x61e20036, 0x9f47328d, 0x00000000}},  //   _llel, zkol, minó_,
  { {0x61e20030, 0x61fb328e, 0xf74300da, 0x00000000}},  //   ykol, _omul, деро,
  { {0x69c40168, 0x24800065, 0x9f5c0065, 0x00000000}},  //   _unie, trim_, tivë_,
  { {0x22582351, 0xe61701ff, 0x765c0c6b, 0x00000000}},  // [a440] _strk_, іду_, spry,
  { {0x24800065, 0x00000000, 0x00000000, 0x00000000}},  //   rrim_,   ,   ,
  { {0x61e2328f, 0x00000000, 0x00000000, 0x00000000}},  //   tkol,   ,   ,
  { {0x24800065, 0x61e90026, 0xea8c0049, 0x00000000}},  //   prim_, _clel, רנאָ,
  { {0x61e202bb, 0x7ddc0325, 0x75fa013e, 0x00000000}},  //   rkol, _mést, hůzk,
  { {0x88bb01ce, 0xd3720439, 0x00000000, 0x00000000}},  //   יזני, _زهر_,   ,
  { {0xc3070088, 0xfe6f0464, 0x65360014, 0x00000000}},  //   _держ_, ندي_, _درگذ,
  { {0x934301fb, 0x7ddc02a0, 0x00000000, 0x00000000}},  //   _інте, _nést,   ,
  { {0x9f47008e, 0x2906012d, 0x00000000, 0x00000000}},  //   ginó_, _žoan_,   ,
  { {0x7ddc028c, 0x3a200022, 0x00000000, 0x00000000}},  //   _résu, _akip_,   ,
  { {0x3eb80010, 0x201c0091, 0x00000000, 0x00000000}},  //   _ért_, movi_,   ,
  { {0x201c037e, 0xec3500a1, 0x2cbd005b, 0x00000000}},  //   lovi_, _ہونگ, _frwd_,
  { {0xc173009b, 0x9f470555, 0x7ddc009d, 0x00000000}},  //   וחר_, minò_, _dést,
  { {0xbebc001e, 0x3a2001aa, 0x201c0119, 0x00000000}},  //   _dzīv, _ekip_, novi_,
  { {0x3dc60038, 0x356b0751, 0xc5fb00ed, 0x00000000}},  //   _know_, иран_, аѓа_,
  { {0x7a12001e, 0x7bd80292, 0x5455007c, 0x00000000}},  //   tāte, _hovu, зват,
  { {0x201c01cd, 0x3494007c, 0x94ab0184, 0x00000000}},  // [a450] kovi_, матр, штва_,
  { {0x61fb0006, 0x7bd801f3, 0x00000000, 0x00000000}},  //   _smul, _jovu,   ,
  { {0x7afc002a, 0x201c0091, 0x7ddc00c4, 0x00000000}},  //   úrth, dovi_, _jéss,
  { {0xdb1800f8, 0x00000000, 0x00000000, 0x00000000}},  //   _invä,   ,   ,
  { {0xf7f4007a, 0x3ebe0207, 0x201c09fc, 0x00000000}},  //   _رسید, _artt_, fovi_,
  { {0x201c01cd, 0xa2a6013d, 0x44251573, 0x00000000}},  //   govi_, _टैक्, _ól_,
  { {0x3f9e0022, 0x24893290, 0x61e90087, 0x00000000}},  //   _dbtu_, luam_, _tlel,
  { {0x61fb3291, 0x9f470048, 0xee39003b, 0x00000000}},  //   _umul, mhní_, љни_,
  { {0x63b50f3a, 0x201c0091, 0x24893292, 0x00000000}},  //   _kazn, bovi_, nuam_,
  { {0x3a2000ab, 0x321d0036, 0x201c0142, 0x00000000}},  //   _skip_, lowy_, covi_,
  { {0x7bd80207, 0x6297002d, 0x9f47004a, 0x00000000}},  //   _dovu, ntxo, sinó_,
  { {0x63b50107, 0x316d01f3, 0x3d950751, 0x00000000}},  //   _lazn, _jeez_, _хидр,
  { {0xdb180073, 0xdb03009f, 0x25a93293, 0x00000000}},  //   _anvä, _janú, deal_,
  { {0x38690f68, 0x63b5040d, 0x9f5c3294, 0x00000000}},  //   _dwar_, _nazn, tivé_,
  { {0xfaa20265, 0x321d0036, 0xdb033295, 0x00000000}},  //   _защо, kowy_, _lanú,
  { {0xceb20104, 0x9f5c3296, 0x3a200300, 0x00000000}},  //   עין_, rivé_, _ukip_,
  { {0x64a301f9, 0x321d0046, 0x63b50089, 0x00000000}},  // [a460] ната, dowy_, _bazn,
  { {0x61350010, 0x00000000, 0x00000000, 0x00000000}},  //   zülé,   ,   ,
  { {0x3869010f, 0x25a9000a, 0xe7db009b, 0x00000000}},  //   _zwar_, beal_, _הקיש,
  { {0x0446007c, 0x25a93297, 0xdb0300f6, 0x00000000}},  //   _немн, ceal_, _banú,
  { {0x25d7007b, 0x201c0091, 0x55bb009b, 0x00000000}},  //   _זוכן_, tovi_, _המכו,
  { {0xdb0a0073, 0x741602fd, 0x3dc600ab, 0x00000000}},  //   _infö, _روزا, _snow_,
  { {0x201c0142, 0x321d0036, 0x2cad0133, 0x00000000}},  //   rovi_, bowy_, ewed_,
  { {0xf1d00204, 0x2d8d01d6, 0xdb030142, 0x00000000}},  //   _सचिन, ggee_, _fanú,
  { {0x7bd80091, 0x201c0091, 0xdb0800c4, 0x00000000}},  //   _povu, povi_, cedê,
  { {0x9f470197, 0x50b5007e, 0x7ddc00c4, 0x00000000}},  //   sinò_, _ўсту, _péss,
  { {0x61350010, 0x39490022, 0x24890023, 0x00000000}},  //   pülé, _pgas_, zuam_,
  { {0x80b3013d, 0x00000000, 0x00000000, 0x00000000}},  //   _इनमे,   ,   ,
  { {0x7bd83298, 0x25a92082, 0x00000000, 0x00000000}},  //   _tovu, veal_,   ,
  { {0x3f8e3299, 0xca470014, 0x321d0036, 0x00000000}},  //   ngfu_, _کليه_, zowy_,
  { {0x752f0046, 0x63b50c1e, 0x25a90048, 0x00000000}},  //   _szcz, _razn, teal_,
  { {0x63b50119, 0x752f0009, 0x7c3a00ea, 0x00000000}},  //   _sazn, _pzcz, lmtr,
  { {0x63b50c02, 0x73d90407, 0x7c28329a, 0x00000000}},  // [a470] _pazn, одар_, oldr,
  { {0x672500b0, 0x25a90048, 0x68ef005a, 0x00000000}},  //   _tyhj, seal_, ındı,
  { {0x25a92b35, 0x98b901f6, 0x63b5041a, 0x00000000}},  //   peal_, ması_, _vazn,
  { {0x6297022b, 0x7a3f0d90, 0x2295067e, 0x00000000}},  //   rtxo, _būti, råk_,
  { {0x656f018e, 0x321d0036, 0x7a120089, 0x00000000}},  //   _iech, rowy_, nāta,
  { {0x656f0219, 0x98b90279, 0x443a041d, 0x00000000}},  //   _hech, nası_, cmp_,
  { {0x660d002d, 0x44230022, 0x321d00b4, 0x00000000}},  //   onak, _ikj_, powy_,
  { {0x660d0004, 0x6447002b, 0x644f01a3, 0x00000000}},  //   nnak, _hiji, _kuci,
  { {0x98b9038c, 0x6447000b, 0x660d2645, 0x00000000}},  //   kası_, _kiji, inak,
  { {0x64472379, 0x656f0a6d, 0x644f014a, 0x00000000}},  //   _jiji, _lech, _muci,
  { {0x64471ac6, 0xdb080129, 0xc9aa2c00, 0x00000000}},  //   _miji, nedè, овне_,
  { {0x645d08b2, 0x656f004f, 0xf2d20049, 0x00000000}},  //   _otsi, _nech, דעט_,
  { {0x660d1f15, 0x7ae100ea, 0x6e29004e, 0x00000000}},  //   dnak, sylt, mleb,
  { {0x6e2901bf, 0xdca2025f, 0x657d00ca, 0x00000000}},  //   lleb, _раши, _adsh,
  { {0x645d010a, 0x656f0016, 0x00000000, 0x00000000}},  //   _atsi, _bech,   ,
  { {0x644f007f, 0x656f0036, 0x660d0058, 0x00000000}},  //   _buci, _cech, gnak,
  { {0x656f018e, 0x644f329b, 0x6447329c, 0x00000000}},  // [a480] _dech, _cuci, _biji,
  { {0x9f45056b, 0x64470107, 0x644f11cb, 0x00000000}},  //   _allí_, _ciji, _duci,
  { {0x656f0977, 0x645d021e, 0xe2970121, 0x00000000}},  //   _fech, _etsi, дах_,
  { {0x6d4b10ed, 0xf1a3025f, 0x656f0270, 0x00000000}},  //   _ngga, вршн, _gech,
  { {0x6447329d, 0x6e290987, 0x660400b0, 0x00000000}},  //   _fiji, dleb, miik,
  { {0x6604003c, 0x6d4b2191, 0x6e2201ee, 0x00000000}},  //   liik, _agga, _skob,
  { {0x656f000a, 0xdb080129, 0x81b60044, 0x00000000}},  //   _yech, cedè, জাব_,
  { {0x98b90279, 0x6e2901e3, 0x7ddc008e, 0x00000000}},  //   zası_, gleb, _césp,
  { {0x98b9005f, 0x316600e7, 0x7ddc004a, 0x00000000}},  //   yası_, mboz_, _désp,
  { {0x660d0142, 0x7a120089, 0xc0a903e6, 0x00000000}},  //   znak, vāta, _عاقل_,
  { {0x660d011f, 0x6e2902d1, 0x7c3a0190, 0x00000000}},  //   ynak, bleb, rmtr,
  { {0x6e29329e, 0x7c6601f7, 0x38af0066, 0x00000000}},  //   cleb, _قاتل, _pżr_,
  { {0x656f08ea, 0x98b9005a, 0x660d0027, 0x00000000}},  //   _rech, tası_, vnak,
  { {0x6e200219, 0x656f010f, 0x2ca6329f, 0x00000000}},  //   lomb, _sech, _ipod_,
  { {0x656f32a0, 0x98b901f6, 0xa3d202fb, 0x00000000}},  //   _pech, rası_, वान_,
  { {0x6e200cd4, 0x44230107, 0x644701a3, 0x00000000}},  //   nomb, _skj_, _siji,
  { {0x656f000d, 0x660d04cb, 0xd7f10025, 0x00000000}},  // [a490] _vech, rnak, _مكة_,
  { {0x656f010f, 0xd3710380, 0x644f003b, 0x00000000}},  //   _wech, اها_, _vuci,
  { {0x6e2023d3, 0x625301d5, 0x644732a1, 0x00000000}},  //   komb, _għol, _viji,
  { {0x3e7a001e, 0xd1310025, 0xdb080010, 0x00000000}},  //   dīt_, هما_, gedé,
  { {0xa0690121, 0x645d01c9, 0xe001007e, 0x00000000}},  //   чала_, _utsi, лькi_,
  { {0x7a36013e, 0x00000000, 0x00000000, 0x00000000}},  //   máte,   ,   ,
  { {0xfc4800ad, 0x2bd2001c, 0x2ca60802, 0x00000000}},  //   _gửi_, ताना, _apod_,
  { {0x442101d9, 0x6e200020, 0x24860006, 0x00000000}},  //   loh_, gomb, šome_,
  { {0x3015008b, 0x6e29033b, 0xdb01120f, 0x00000000}},  //   _здар, rleb, delá,
  { {0xa3d2024c, 0x44210145, 0xeb99003b, 0x00000000}},  //   वाय_, noh_, чио_,
  { {0xf99f0207, 0x6e2907b8, 0xdd000089, 0x00000000}},  //   ffè_, pleb, ātāj,
  { {0x61f9047f, 0x7bca0299, 0x44210052, 0x00000000}},  //   _çalı, _enfu, hoh_,
  { {0x4421023a, 0xc3260044, 0x660400b0, 0x00000000}},  //   koh_, _বলছি_, viik,
  { {0xcc760097, 0x44210145, 0x00000000, 0x00000000}},  //   _טענה_, joh_,   ,
  { {0x442101a3, 0x6604021e, 0xe73716c4, 0x00000000}},  //   doh_, tiik, еер_,
  { {0xf1b90059, 0x00000000, 0x00000000, 0x00000000}},  //   _naš_,   ,   ,
  { {0x660401c2, 0x225f145e, 0x3e7a0089, 0x00000000}},  // [a4a0] riik, _čuka_, zīt_,
  { {0x6604021e, 0x261701d5, 0x442132a2, 0x00000000}},  //   siik, għob_, goh_,
  { {0xf1b910c1, 0x6e2032a3, 0x68e600e0, 0x00000000}},  //   _baš_, yomb, lykd,
  { {0x62530066, 0x00000000, 0x00000000, 0x00000000}},  //   _għom,   ,   ,
  { {0xf12307ca, 0xf1b900ee, 0x9f450129, 0x00000000}},  //   льшо, _daš_, _allà_,
  { {0x3e7a001e, 0x442101a3, 0x657632a4, 0x00000000}},  //   tīt_, coh_, layh,
  { {0x4438001f, 0x6e20001a, 0x2ca614a6, 0x00000000}},  //   _ihr_, tomb, _spod_,
  { {0x3e7a001e, 0xe2a6000c, 0x32070010, 0x00000000}},  //   rīt_, öðum_, ényt_,
  { {0x3e7a001e, 0x6e200020, 0x200e0022, 0x00000000}},  //   sīt_, romb, pnfi_,
  { {0x44380085, 0x3e7a01c5, 0x7c2132a5, 0x00000000}},  //   _jhr_, pīt_, golr,
  { {0xda770783, 0x6e200059, 0x00000000, 0x00000000}},  //   няя_, pomb,   ,
  { {0xddea03ec, 0x443806ed, 0x4421016c, 0x00000000}},  //   _عرضه_, _lhr_, zoh_,
  { {0xebe632a6, 0xf8bf00f4, 0x44210022, 0x00000000}},  //   _подп, uvé_, yoh_,
  { {0x7bca003b, 0xf8bf00f4, 0xf99f01aa, 0x00000000}},  //   _unfu, rvé_, sfè_,
  { {0x25a00016, 0x4421016c, 0x2cb80089, 0x00000000}},  //   ffil_, voh_, ārdu_,
  { {0x44382a53, 0xd5b80839, 0x48fc0061, 0x00000000}},  //   _ahr_, нсу_, _लेको_,
  { {0x44210062, 0x69cd0020, 0x443801f3, 0x00000000}},  // [a4b0] toh_, _inae, _bhr_,
  { {0x44380240, 0x16020061, 0x7a362550, 0x00000000}},  //   _chr_, रोबर_, ráte,
  { {0x4421008a, 0x443800bb, 0xa5f90175, 0x00000000}},  //   roh_, _dhr_, _жену_,
  { {0x44210145, 0x225c0861, 0x69df0023, 0x00000000}},  //   soh_, ívka_, _joqe,
  { {0xf1b901d9, 0x7c38006c, 0x44210145, 0x00000000}},  //   _vaš_, _ohvr, poh_,
  { {0x9f450211, 0x248932a7, 0x00000000, 0x00000000}},  //   _allá_, mram_,   ,
  { {0xf1a70c4e, 0x00000000, 0x00000000, 0x00000000}},  //   _пран,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00db1739, 0x00000000, 0x00000000, 0x00000000}},  //   _عبرت_,   ,   ,
  { {0xa5bb009f, 0x69cd0020, 0x248900c4, 0x00000000}},  //   _skól, _anae, iram_,
  { {0x2007000b, 0xa3d20183, 0x05e1013d, 0x00000000}},  //   mini_, वात_, _नवंब,
  { {0x2007014a, 0x24891129, 0xdd1d0035, 0x00000000}},  //   lini_, kram_, _câţi,
  { {0x7c21023a, 0x248932a8, 0x20070026, 0x00000000}},  //   polr, jram_, oini_,
  { {0x20070020, 0x24891e8f, 0xfc480082, 0x00000000}},  //   nini_, dram_, _bửu_,
  { {0xd62a005e, 0xfc480011, 0xa5960735, 0x00000000}},  //   дове_, _cửu_, кращ,
  { {0x2007000b, 0x44380058, 0x6d5b1e18, 0x00000000}},  //   hini_, _shr_, ncua,
  { {0x20070be3, 0xb90708b7, 0x25a00d26, 0x00000000}},  // [a4c0] kini_, _যে_, rfil_,
  { {0x200716d6, 0x25a003b1, 0x7ae5006c, 0x00000000}},  //   jini_, sfil_, _ühts,
  { {0x248900c4, 0xd2590451, 0x00000000, 0x00000000}},  //   aram_, еці_,   ,
  { {0x248900c4, 0x00000000, 0x00000000, 0x00000000}},  //   bram_,   ,   ,
  { {0xa3d202fb, 0x20070263, 0x4096007c, 0x00000000}},  //   वाद_, fini_, трет,
  { {0x4438001f, 0x200732a9, 0x78fb009b, 0x00000000}},  //   _uhr_, gini_, ופנו,
  { {0x63bc32aa, 0x0eec013d, 0xe7a401f5, 0x00000000}},  //   _iarn, जनेस_, ख्यप,
  { {0xf99f01aa, 0x531b009b, 0x61eb06d3, 0x00000000}},  //   nnèt_, _חולצ, ckgl,
  { {0x61e0002a, 0xa3d60061, 0x91e30517, 0x00000000}},  //   _ioml, _ाचा_, _тоте,
  { {0x2007003b, 0x2bb7001c, 0x63bc0161, 0x00000000}},  //   cini_, _असणा, _jarn,
  { {0x229c004f, 0x63bc0068, 0xd00f0188, 0x00000000}},  //   ník_, _marn, _ظلم_,
  { {0x24890279, 0x8b0700b9, 0x6d5b0011, 0x00000000}},  //   yram_, _skří, ccua,
  { {0xcdf7009b, 0x2cb80089, 0x6ba70039, 0x00000000}},  //   _במאי_, ārds_, ärgå,
  { {0x69cd018e, 0xdb0316b8, 0x629e0b05, 0x00000000}},  //   _wnae, _canó, ktpo,
  { {0x2bb7001c, 0xdceb0089, 0xdb010210, 0x00000000}},  //   _असता, _iegā, gelä,
  { {0x20070263, 0x2489001c, 0xfde00044, 0x00000000}},  //   zini_, tram_, _বগুড,
  { {0x20072f77, 0x63bc32ab, 0x04950070, 0x00000000}},  // [a4d0] yini_, _barn, طلاح,
  { {0x44270011, 0x248900c4, 0x60c21a7d, 0x00000000}},  //   ôn_, rram_, dvom,
  { {0x63bc011c, 0x00000000, 0x00000000, 0x00000000}},  //   _darn,   ,   ,
  { {0xf650026c, 0x61e016b1, 0x248900ca, 0x00000000}},  //   _گئی_, _coml, pram_,
  { {0x3c3900f4, 0x2489006b, 0x61e000b9, 0x00000000}},  //   lève_, qram_, _doml,
  { {0x27e100ab, 0xb4df0061, 0x1e950517, 0x00000000}},  //   _john_, तही_, грир,
  { {0xed590eb1, 0x200701f6, 0x3a2932ac, 0x00000000}},  //   ной_, rini_, _okap_,
  { {0x63bc01c5, 0x27e101a2, 0xdb180068, 0x00000000}},  //   _zarn, _lohn_, _gavé,
  { {0xdd91026c, 0xdd11038c, 0x20070059, 0x00000000}},  //   لوں_, _düşm, pini_,
  { {0x6d5b029a, 0x3a29020e, 0x2007071f, 0x00000000}},  //   scua, _akap_, qini_,
  { {0x81b60055, 0x224d010a, 0xba750014, 0x00000000}},  //   জার_, _kiek_, داخت,
  { {0x7bda0065, 0x75ea00b9, 0x6ec00204, 0x00000000}},  //   ajtu, _výzk, विरु,
  { {0x224732ad, 0xdb0300d4, 0x224d00d9, 0x00000000}},  //   ínky_, _canò, _miek_,
  { {0x224d27dc, 0x00000000, 0x00000000, 0x00000000}},  //   _liek_,   ,   ,
  { {0xa3d202fb, 0x98a5001e, 0xd7570167, 0x00000000}},  //   वास_, ālā_, الفت_,
  { {0x229c009f, 0x63bc006c, 0xdb010039, 0x00000000}},  //   vík_, _sarn, relä,
  { {0x61e01dbb, 0xdb0100b0, 0xd5751e2c, 0x00000000}},  // [a4e0] _roml, selä, русь,
  { {0x61e006d4, 0x229c32ae, 0x629e0203, 0x00000000}},  //   _soml, tík_, ttpo,
  { {0x63bc00bf, 0x179b01ce, 0x61e00059, 0x00000000}},  //   _varn, _אייב, _poml,
  { {0xa3d2007d, 0x63bc09d5, 0xbbe0007d, 0x00000000}},  //   वाह_, _warn, _पक्क,
  { {0x63bc32af, 0x629e0c75, 0x224d01c3, 0x00000000}},  //   _tarn, stpo, _diek_,
  { {0xb4c202d2, 0xceba003b, 0xb4c0007d, 0x00000000}},  //   ्मी_, ељи_, ंटी_,
  { {0x644e011c, 0xa2e3013b, 0x61e02f3d, 0x00000000}},  //   _iibi, _лорд, _toml,
  { {0x5d54026b, 0x798400e7, 0x20ce01e5, 0x00000000}},  //   шкит, _ndiw, gðið_,
  { {0x7ddc0047, 0x25d7007b, 0x644e15f4, 0x00000000}},  //   _kész, רופן_, _kibi,
  { {0x644e13e1, 0x224d00b5, 0x3a2901e5, 0x00000000}},  //   _jibi, _ziek_, _skap_,
  { {0xc3fb0049, 0x93fb0097, 0x442a0f5d, 0x00000000}},  //   גליש, גליי, _mkb_,
  { {0xf2d3007b, 0x75f800b9, 0x27e1010f, 0x00000000}},  //   צער_, _jízd, _sohn_,
  { {0x7984018e, 0x442a0065, 0x7d7b0049, 0x00000000}},  //   _ddiw, _okb_, _טראג,
  { {0x644e32b0, 0xf41f0039, 0x7a3632b1, 0x00000000}},  //   _nibi, _iväg_, ráta,
  { {0xd90f0014, 0x7a36013e, 0x00000000, 0x00000000}},  //   تیک_, mátn,   ,
  { {0x442a32b2, 0xb4c2007d, 0x27e101a2, 0x00000000}},  //   _akb_, ्मू_, _wohn_,
  { {0x644e006a, 0x442a0022, 0x3c390173, 0x00000000}},  // [a4f0] _bibi, _bkb_, sève_,
  { {0x224d32b3, 0x69dd01ee, 0x644e32b4, 0x00000000}},  //   _siek_, ljse, _cibi,
  { {0x644e0281, 0x41e70451, 0x4155132e, 0x00000000}},  //   _dibi, ліда, авес,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x656d1535, 0x7a3601ca, 0x442a24a8, 0x00000000}},  //   mbah, kátn, _fkb_,
  { {0x9f510477, 0x224d0036, 0xdceb001a, 0x00000000}},  //   _özü_, _wiek_, _legă,
  { {0xa3d202fb, 0x224d0ebc, 0xb3d2001c, 0x00000000}},  //   वार_, _tiek_, सारख,
  { {0x644e1925, 0x656d14c9, 0x78ad01dc, 0x00000000}},  //   _zibi, nbah, _opav,
  { {0x20ce000c, 0x4f8500a1, 0xec760930, 0x00000000}},  //   rðið_, _نااہ, апы_,
  { {0x7a120089, 0x60c90285, 0xa3ab007d, 0x00000000}},  //   māti, _irem, _कॉम_,
  { {0xa96a0175, 0x78ad0089, 0xfaa501ee, 0x00000000}},  //   кина_, _apav, шано,
  { {0xcfaa0044, 0xd94632b5, 0x656d012d, 0x00000000}},  //   _গোপন, иени, jbah,
  { {0x7a120089, 0x69d80316, 0x00000000, 0x00000000}},  //   nāti, याबी,   ,
  { {0x60c90020, 0x9f470051, 0x1867026b, 0x00000000}},  //   _mrem, dhnú_, рари_,
  { {0x7ddc0047, 0xf7460e09, 0x644e02db, 0x00000000}},  //   _rész, рево, _ribi,
  { {0x644e001a, 0x0566005e, 0x442a266c, 0x00000000}},  //   _sibi, рван, _skb_,
  { {0x9f470051, 0x442a2d1a, 0x7a3613aa, 0x00000000}},  // [a500] ghnú_, _pkb_, láto,
  { {0x7bc120a9, 0x7a120089, 0x187b0049, 0x00000000}},  //   ndlu, dāti, _שטיב,
  { {0xe29a008b, 0x60c90093, 0x237700a2, 0x00000000}},  //   тае_, _arem, شمند_,
  { {0x71a6008b, 0x60c9010f, 0x506603e0, 0x00000000}},  //   радз, _brem, атка,
  { {0x9f4732b6, 0x7ddc0010, 0x92d60044, 0x00000000}},  //   chnú_, _tész, িনে_,
  { {0x7644014a, 0x7a3d0010, 0x24800089, 0x00000000}},  //   lmiy, méte, msim_,
  { {0x444406e5, 0xd335008b, 0x60c9022b, 0x00000000}},  //   mm_, _гэты, _erem,
  { {0x60c90018, 0x806601fb, 0x661600b0, 0x00000000}},  //   _frem, _вваж, nnyk,
  { {0x2b5e001c, 0x60c90059, 0x44440aba, 0x00000000}},  //   tctc_, _grem, om_,
  { {0x444432b7, 0xed5901ee, 0x8c4300e2, 0x00000000}},  //   nm_, rdža_, оење,
  { {0x444432b8, 0x78ad0119, 0x225800bb, 0x00000000}},  //   im_, _spav, _jurk_,
  { {0x24800a3e, 0x261701d5, 0x444401a2, 0x00000000}},  //   ksim_, għol_, hm_,
  { {0x444407e7, 0xfd120123, 0x98b80ae0, 0x00000000}},  //   km_, _بجا_, алят_,
  { {0xdb1832b9, 0x44440065, 0x7a3d009d, 0x00000000}},  //   _haví, jm_, déte,
  { {0xc9870057, 0x0cb6013d, 0x89d900a6, 0x00000000}},  //   _купи, _अनुम, _موثر_,
  { {0x44440580, 0x81ab08b7, 0x80ad0044, 0x00000000}},  //   em_, _কোন_, চিত্,
  { {0x656d1c57, 0x44440035, 0xdb23000c, 0x00000000}},  // [a510] rbah, fm_, ásög,
  { {0x638000b9, 0x44440093, 0x7c280790, 0x00000000}},  //   vání, gm_, nodr,
  { {0x60c9003b, 0x752f0036, 0x248000e0, 0x00000000}},  //   _srem, _wycz, asim_,
  { {0x44440114, 0xdb1801dc, 0xb5a70887, 0x00000000}},  //   am_, _naví, _трой,
  { {0x69d8001c, 0x7c280065, 0x7a3d008e, 0x00000000}},  //   याती, kodr, céte,
  { {0x60c90119, 0x660d184d, 0xafe2007c, 0x00000000}},  //   _vrem, liak, зошл,
  { {0x7c280471, 0x75ea0161, 0xe7ff013d, 0x00000000}},  //   dodr, _výzv, _उतना_,
  { {0x660d022b, 0x443301f3, 0xd087007c, 0x00000000}},  //   niak, llx_, _выжи,
  { {0xd0e9026c, 0xdb18000c, 0x60c90020, 0x00000000}},  //   _حکام_, _daví, _urem,
  { {0x660d022b, 0x64450051, 0xdb0329f9, 0x00000000}},  //   hiak, nmhi, _manö,
  { {0x7bc1006c, 0x660d117f, 0x6253002b, 0x00000000}},  //   rdlu, kiak, _għot,
  { {0x7a3608aa, 0x186a041f, 0x69d80309, 0x00000000}},  //   ráto, лами_, याधी,
  { {0xfd5600b6, 0x660d020c, 0x7c281f39, 0x00000000}},  //   _השני_, diak, bodr,
  { {0x7a3d0047, 0x7c28008e, 0xdb180062, 0x00000000}},  //   véte, codr, _zaví,
  { {0x444400ca, 0xe45f0039, 0xaa950025, 0x00000000}},  //   vm_, _dröm_, _العث,
  { {0x444432ba, 0x660d002d, 0x6a640025, 0x00000000}},  //   wm_, giak, _بطول,
  { {0x44441042, 0x7644014a, 0x00000000, 0x00000000}},  // [a520] tm_, rmiy,   ,
  { {0x3ea90036, 0x44330026, 0x7a3d01e6, 0x00000000}},  //   łaty_, glx_, réte,
  { {0x24802790, 0x833a18ea, 0x660d32bb, 0x00000000}},  //   ssim_, учат_, biak,
  { {0x44440544, 0x7a3d01e6, 0x635500b9, 0x00000000}},  //   sm_, péte, třní,
  { {0x23780022, 0x00000000, 0x00000000, 0x00000000}},  //   _terj_,   ,   ,
  { {0x225802ba, 0xf3e60152, 0x237800c4, 0x00000000}},  //   _turk_, _ужго, _uerj_,
  { {0xadd832bc, 0x00000000, 0x00000000, 0x00000000}},  //   имку_,   ,   ,
  { {0x7c280016, 0x21a3003b, 0x00000000, 0x00000000}},  //   wodr, _нисм,   ,
  { {0xb87b0010, 0x7c280062, 0x00000000, 0x00000000}},  //   nyít, todr,   ,
  { {0x660d002d, 0x2cbd0058, 0x00000000, 0x00000000}},  //   ziak, _dswd_,   ,
  { {0x7c2832bd, 0x3f9e00d9, 0x00000000, 0x00000000}},  //   rodr, _ictu_,   ,
  { {0x7f3b007b, 0x200e006b, 0x1e57009b, 0x00000000}},  //   _געבו, lifi_, _השאר_,
  { {0xe9df0010, 0x81ab0044, 0x00000000, 0x00000000}},  //   rjú_, _কোড_,   ,
  { {0x625301f3, 0x00000000, 0x00000000, 0x00000000}},  //   _xħos,   ,   ,
  { {0xa3cc0201, 0x96f800ed, 0x6b7b0097, 0x00000000}},  //   _शोध_, берт_, _גרונ,
  { {0x59d00061, 0x9635279d, 0x00000000, 0x00000000}},  //   _तोपर, інац,   ,
  { {0x660d1e3a, 0x045b0014, 0xb87b0010, 0x00000000}},  // [a530] riak, اجرت_, gyít,
  { {0x660d00b0, 0x44330068, 0x00000000, 0x00000000}},  //   siak, ulx_,   ,
  { {0x44330009, 0x660d044e, 0x3169004a, 0x00000000}},  //   rlx_, piak, ñazo_,
  { {0x3f9e00f4, 0xdb0101e3, 0xa4d503e8, 0x00000000}},  //   _actu_, relø, _домі,
  { {0xdb01068f, 0x661d00bb, 0x00000000, 0x00000000}},  //   selø, _ijsk,   ,
  { {0x645f0009, 0x00000000, 0x00000000, 0x00000000}},  //   mqqi,   ,   ,
  { {0xfe450131, 0xdb1800d4, 0x00000000, 0x00000000}},  //   онко, _navà,   ,
  { {0xdb0a010f, 0xee3901fc, 0xbc650131, 0x00000000}},  //   _dafü, јни_, овик,
  { {0x3869023a, 0x6e290168, 0x20260026, 0x00000000}},  //   _ntar_, roeb, èviè_,
  { {0x6b9a001c, 0x200e00f6, 0x62530066, 0x00000000}},  //   ggtg, cifi_, _għor,
  { {0xa3ab0164, 0xbf150025, 0x3ebe01a3, 0x00000000}},  //   क्य_, _بواب, _gstt_,
  { {0x7a3600b9, 0x394a0331, 0x661d0087, 0x00000000}},  //   mátk, изно_, _njsk,
  { {0x8936031d, 0xd7d50061, 0x91bf0082, 0x00000000}},  //   تعدا, दांच, _chủ_,
  { {0xcb690088, 0xb9020061, 0x7a120089, 0x00000000}},  //   _таке_, _नऊ_, vātu,
  { {0x26cc32be, 0x7bc3001a, 0x65c6005e, 0x00000000}},  //   ído_, _ianu, обва,
  { {0x7bc30253, 0x00000000, 0x00000000, 0x00000000}},  //   _hanu,   ,   ,
  { {0x7bc332bf, 0x69d60211, 0x00000000, 0x00000000}},  // [a540] _kanu, _inye,   ,
  { {0x69c4022b, 0x38a432c0, 0x245f0016, 0x00000000}},  //   _haie, mör_, _dîm_,
  { {0x7bc30971, 0x0576006d, 0xf746005e, 0x00000000}},  //   _manu, _واحد, _фено,
  { {0x69c60010, 0x7bc304be, 0x69c42d32, 0x00000000}},  //   ndke, _lanu, _jaie,
  { {0x7a3d32c1, 0x3869006b, 0x38a422ae, 0x00000000}},  //   néta, _xtar_, nör_,
  { {0x69c4006c, 0x7bc30058, 0xbe8a01e0, 0x00000000}},  //   _laie, _nanu, асие_,
  { {0x38a40002, 0x81e60055, 0x69d60020, 0x00000000}},  //   hör_, যোগ_, _onye,
  { {0x85f70049, 0x38a418ee, 0x69c41342, 0x00000000}},  //   ַציע_, kör_, _naie,
  { {0x6b9a001c, 0x7bc30314, 0x62830161, 0x00000000}},  //   tgtg, _banu, ánov,
  { {0x69d60263, 0x7a360ddf, 0x290205fd, 0x00000000}},  //   _anye, láth, dzka_,
  { {0x69c404f8, 0x80c20067, 0xe7de0061, 0x00000000}},  //   _baie, लिके, मानप,
  { {0x38a432c2, 0x61e2016e, 0x69c432c3, 0x00000000}},  //   för_, njol, _caie,
  { {0x7bc30640, 0x7a3d00f4, 0x38a40039, 0x00000000}},  //   _fanu, géta, gör_,
  { {0x7bc3006a, 0x9f5c0026, 0x61e200b0, 0x00000000}},  //   _ganu, tivù_, hjol,
  { {0x45d500ed, 0x61e20190, 0x98ac0089, 0x00000000}},  //   повс, kjol, ādā_,
  { {0x2c6001aa, 0x69c4002d, 0x7bc300b4, 0x00000000}},  //   _kòd_, _gaie, _zanu,
  { {0x29020046, 0x8ccd013d, 0x7bc3013f, 0x00000000}},  // [a550] czka_, तियो, _yanu,
  { {0x69a702fb, 0x2c6001aa, 0x69c4002d, 0x00000000}},  //   ट्री, _mòd_, _zaie,
  { {0x2c600263, 0x77ba009b, 0x67ba009b, 0x00000000}},  //   _lòd_, _המתח, _המתק,
  { {0x5bb70164, 0x799d010f, 0x245f018e, 0x00000000}},  //   _अस्व, ngsw, _tîm_,
  { {0x3f6901ee, 0x00000000, 0x00000000, 0x00000000}},  //   било_,   ,   ,
  { {0x657d1b1c, 0x00000000, 0x00000000, 0x00000000}},  //   _hesh,   ,   ,
  { {0x657d23d3, 0xfd4c001d, 0x533404ef, 0x00000000}},  //   _kesh, _triể, _жерт,
  { {0x645d000b, 0xf076026c, 0x657d000b, 0x00000000}},  //   _kusi, _کیوں_, _jesh,
  { {0x7bc312e8, 0x657d0065, 0x64550cd7, 0x00000000}},  //   _panu, _mesh, _kizi,
  { {0x7bc3005f, 0x7a3632c4, 0x1c421001, 0x00000000}},  //   _qanu, máti, нным,
  { {0x69c432c5, 0x64551731, 0x645d0129, 0x00000000}},  //   _paie, _mizi, _lusi,
  { {0xa3ab02fb, 0x657d037e, 0x3d0f0061, 0x00000000}},  //   क्त_, _nesh, _तेथे_,
  { {0x645d010a, 0xc955008b, 0x7bc31dba, 0x00000000}},  //   _nusi, дтры, _tanu,
  { {0x62852279, 0x7a3d06d2, 0x61fb00d4, 0x00000000}},  //   ksho, réta, _llul,
  { {0x61fb0004, 0x645d1395, 0x29020036, 0x00000000}},  //   _olul, _ausi, szka_,
  { {0xd90d007a, 0x645d0038, 0x6285032e, 0x00000000}},  //   ایی_, _busi, dsho,
  { {0x657d03c3, 0x64552f69, 0xdb0a009f, 0x00000000}},  // [a560] _desh, _bizi, _hafð,
  { {0x6b810089, 0x7a360181, 0x645500b9, 0x00000000}},  //   nalg, dáti, _cizi,
  { {0x1dbd0201, 0x6455011f, 0x628505a6, 0x00000000}},  //   ्यात, _dizi, gsho,
  { {0x61e90181, 0x6d59183c, 0x6b810058, 0x00000000}},  //   _coel, _ngwa, halg,
  { {0x61e901b5, 0x61e200b0, 0x6b8100eb, 0x00000000}},  //   _doel, rjol, kalg,
  { {0x62852a54, 0x6d590058, 0x61fb006c, 0x00000000}},  //   bsho, _agwa, _elul,
  { {0x0443213f, 0x6b810211, 0xe297005e, 0x00000000}},  //   _черн, dalg, _нар_,
  { {0x645506fe, 0x645d006b, 0x61e92996, 0x00000000}},  //   _zizi, _yusi, _goel,
  { {0x6b810675, 0x6b8a000a, 0xc0590088, 0x00000000}},  //   falg, _pdfg, _діє_,
  { {0xcfaa007a, 0xe7d70044, 0x61e901d6, 0x00000000}},  //   _دارم_, _হত্য, _zoel,
  { {0xdfa50464, 0x61e92378, 0x00000000, 0x00000000}},  //   _تحقي, _yoel,   ,
  { {0x6d590045, 0x00000000, 0x00000000, 0x00000000}},  //   _ggwa,   ,   ,
  { {0x657d0023, 0x6b810885, 0xc86704dd, 0x00000000}},  //   _resh, balg, ятни,
  { {0x645d005f, 0x9cd70097, 0x9f4500d4, 0x00000000}},  //   _rusi, _מודה_, _solé_,
  { {0x645d1750, 0xa3e002d2, 0x657d008d, 0x00000000}},  //   _susi, थान_, _pesh,
  { {0x6455038c, 0x657d0065, 0xa4d50088, 0x00000000}},  //   _sizi, _qesh, мобі,
  { {0x657d008d, 0x62850052, 0x61e900c7, 0x00000000}},  // [a570] _vesh, wsho, _roel,
  { {0x78fc009b, 0x61e91372, 0x7bc800f8, 0x00000000}},  //   _לפחו, _soel, nddu,
  { {0x64550e7d, 0x2bae001c, 0x31660009, 0x00000000}},  //   _vizi, ज्या, fcoz_,
  { {0x645d1a20, 0x62852c63, 0x2fc52cba, 0x00000000}},  //   _tusi, rsho, _salg_,
  { {0x645d021e, 0x61e900b5, 0xf3f30025, 0x00000000}},  //   _uusi, _voel, _كأس_,
  { {0x61e90546, 0x7a360161, 0x62830010, 0x00000000}},  //   _woel, ráti, ános,
  { {0x61e900c7, 0x2fc501e3, 0x3e7a0089, 0x00000000}},  //   _toel, _valg_, gūt_,
  { {0x7a362ff2, 0x798d01f3, 0x2fc501c3, 0x00000000}},  //   páti, _ndaw, _walg_,
  { {0x6b81002b, 0xed5911e4, 0xe0df00f6, 0x00000000}},  //   talg, ndži_, _çò_,
  { {0x3e7a001e, 0x9f63021e, 0x798d02ef, 0x00000000}},  //   būt_, ävät_, _adaw,
  { {0x6b8101d6, 0x7a3d0161, 0xfc4600b9, 0x00000000}},  //   ralg, rétn, _říct_,
  { {0x6b811ef5, 0x7bd8008e, 0x6d59002b, 0x00000000}},  //   salg, _envu, _ugwa,
  { {0xa3c20316, 0xb4bc03d7, 0x6b81006c, 0x00000000}},  //   ्यम_, _आने_, palg,
  { {0xfd10031d, 0x2d9f0181, 0x1c440088, 0x00000000}},  //   _حجم_, lgue_, _знім,
  { {0x798d0066, 0x46a3005e, 0x00000000, 0x00000000}},  //   _fdaw, карв,   ,
  { {0xa3ab02d2, 0x2d9f319a, 0xceb20104, 0x00000000}},  //   क्स_, ngue_, כיל_,
  { {0xd040005f, 0x69c0009d, 0x7a0b00b4, 0x00000000}},  // [a580] _ermə, ômeu, jęty,
  { {0x798d00b4, 0x00000000, 0x00000000, 0x00000000}},  //   _zdaw,   ,   ,
  { {0x91e6007c, 0x3860008e, 0xdce001c5, 0x00000000}},  //   може, _huir_, tamī,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bc80a2d, 0x00000000, 0x00000000, 0x00000000}},  //   yddu,   ,   ,
  { {0x386032c6, 0x2d9f004a, 0x00000000, 0x00000000}},  //   _muir_, egue_,   ,
  { {0x4ea600e2, 0x00000000, 0x00000000, 0x00000000}},  //   фрла,   ,   ,
  { {0x25a014f7, 0xd6c00044, 0x9f4500d4, 0x00000000}},  //   ngil_, _উপায, _alló_,
  { {0x80a604e8, 0x06370049, 0x7a120089, 0x00000000}},  //   _زمان, ונקט_, vātp,
  { {0x2d9f0133, 0x00000000, 0x00000000, 0x00000000}},  //   ague_,   ,   ,
  { {0x78b60006, 0x59d00061, 0x7bc80016, 0x00000000}},  //   _apyv, _तोहर, rddu,
  { {0xdde30035, 0xe811007d, 0xdb1a0023, 0x00000000}},  //   ărţi, डोना_, letë,
  { {0x38602dc6, 0xd90f00d3, 0x2d840a76, 0x00000000}},  //   _cuir_, شید_, mame_,
  { {0x2d840c55, 0x6d420087, 0x00000000, 0x00000000}},  //   lame_, _izoa,   ,
  { {0x0bb700a0, 0xdcc80082, 0x2bdb01f5, 0x00000000}},  //   _חלום_, _hỉ_, बारा,
  { {0x2d841e89, 0x7c3a009f, 0xdcc80011, 0x00000000}},  //   name_, lltr, _kỉ_,
  { {0xb9550088, 0xd8470088, 0xdb1a0023, 0x00000000}},  // [a590] _явищ, _охоп, ketë,
  { {0x59dd0067, 0x2d8431d9, 0xdb1a0065, 0x00000000}},  //   यावर, hame_, jetë,
  { {0xa3ab02f4, 0x8707008b, 0x6fdd001c, 0x00000000}},  //   क्ष_, _цяпе, पासू,
  { {0x2d840006, 0x6e220026, 0x0b150049, 0x00000000}},  //   jame_, _njob, ײַער_,
  { {0xb0680025, 0xdcc80082, 0x2d8432c7, 0x00000000}},  //   وصول_, _nỉ_, dame_,
  { {0x764d005d, 0x24890be4, 0x8fa20088, 0x00000000}},  //   lmay, msam_, гаше,
  { {0x9f450129, 0x2d840253, 0xf1a70a85, 0x00000000}},  //   _allò_, fame_, _оран,
  { {0x2d84262d, 0x764d005d, 0xada5003b, 0x00000000}},  //   game_, nmay, хаил,
  { {0x2d9f038e, 0x248905b4, 0xe134007e, 0x00000000}},  //   rgue_, nsam_, _анты,
  { {0x44230061, 0x3ec4021e, 0x5ba9003b, 0x00000000}},  //   _jjj_, ästä_, чком_,
  { {0x3d0f013d, 0x764d014a, 0x7a280477, 0x00000000}},  //   _तेरे_, kmay, yıtd,
  { {0xc7a9019b, 0x24891a85, 0x2d8400ab, 0x00000000}},  //   _לב_, ksam_, came_,
  { {0xe8f70069, 0x7e6101b5, 0x9f4500d4, 0x00000000}},  //   еля_, _hulp, _molí_,
  { {0x7e610032, 0xb6c800a1, 0x291e0035, 0x00000000}},  //   _kulp, وازے_, ăta_,
  { {0xf62601fc, 0x45d60478, 0x24460068, 0x00000000}},  //   едво, нцат, nôme_,
  { {0xdb1a0065, 0x38600026, 0x7a3600c4, 0x00000000}},  //   zetë, _tuir_, tátu,
  { {0x25a00938, 0x798632c8, 0x44230052, 0x00000000}},  // [a5a0] rgil_, makw, _bjj_,
  { {0x7a3600f1, 0x2d841c71, 0x36c601fc, 0x00000000}},  //   rátu, zame_, _због,
  { {0x2bf6007b, 0x6e3b225c, 0x1bf60049, 0x00000000}},  //   עמען_, klub, עצער_,
  { {0xeac9001d, 0x7986254f, 0xa5bb000c, 0x00000000}},  //   _mẹ_, nakw, _hjón,
  { {0xdb1a0065, 0x24890016, 0x2d840142, 0x00000000}},  //   tetë, csam_, vame_,
  { {0x6e9400ed, 0xdcc80082, 0xe7e3013d, 0x00000000}},  //   вику, _rỉ_, खाया_,
  { {0x7e610325, 0x2d8406aa, 0x81b50044, 0x00000000}},  //   _culp, tame_, জয়_,
  { {0x433b007b, 0x63be001c, 0xb14804e1, 0x00000000}},  //   _זעלב, lepn, _قیام_,
  { {0x2d84001c, 0x1aed0044, 0x798601a3, 0x00000000}},  //   rame_, _ছেলে_, dakw,
  { {0x2d841ec2, 0xdb1a32c9, 0x2d8f00ab, 0x00000000}},  //   same_, leté, _edge_,
  { {0xed5900ee, 0x629e0be4, 0x7a360010, 0x00000000}},  //   veže_, nupo, játs,
  { {0xdb1a0047, 0xdcc80011, 0x6e3b00c4, 0x00000000}},  //   neté, _tỉ_, club,
  { {0xa3c20183, 0x60c20061, 0x660432ca, 0x00000000}},  //   ्या_, nwom, dhik,
  { {0x629e0b41, 0x2bd7006e, 0x7793025a, 0x00000000}},  //   kupo, _भोपा, دیدا,
  { {0x764d005d, 0x629e00ca, 0x798632cb, 0x00000000}},  //   tmay, jupo, bakw,
  { {0xed5908fb, 0xdb1a009d, 0x629e010e, 0x00000000}},  //   seže_, jeté, dupo,
  { {0xdbf90046, 0x764d32cc, 0x7a36000c, 0x00000000}},  // [a5b0] _głów, rmay, rátt,
  { {0xdd8600a1, 0x248932cd, 0x7bca2923, 0x00000000}},  //   _ھو_, rsam_, _jafu,
  { {0x7bca000b, 0x24890181, 0x764d01df, 0x00000000}},  //   _mafu, ssam_, pmay,
  { {0x7bca0016, 0x66040a64, 0xdb1a0010, 0x00000000}},  //   _lafu, chik, geté,
  { {0x8fa501a4, 0x7e610133, 0x00000000, 0x00000000}},  //   вале, _sulp,   ,
  { {0x7bca2a3c, 0x2446009d, 0x7e6132ce, 0x00000000}},  //   _nafu, tôme_, _pulp,
  { {0x629e0068, 0x00000000, 0x00000000, 0x00000000}},  //   cupo,   ,   ,
  { {0xed591036, 0x443317f4, 0x7e610035, 0x00000000}},  //   мой_, lox_, _vulp,
  { {0x9f5c0197, 0x7bca21a4, 0x6e3b008a, 0x00000000}},  //   rivò_, _bafu, rlub,
  { {0x7e610ef7, 0x6e3b0ad1, 0x798600e7, 0x00000000}},  //   _tulp, slub, wakw,
  { {0xda78008b, 0x91f50309, 0x79860020, 0x00000000}},  //   няў_, _आवाज_, takw,
  { {0xa5bb009f, 0xc33200a0, 0x3f870213, 0x00000000}},  //   _sjón, שוט_, lanu_,
  { {0x798632cf, 0xdb010010, 0x6d5c00b9, 0x00000000}},  //   rakw, jelö, ěrat,
  { {0xdb1a0047, 0xc2e70044, 0xe85600a1, 0x00000000}},  //   zeté, _গেছি_, ئنسد,
  { {0x4433121e, 0xe7370081, 0x2cad07fb, 0x00000000}},  //   dox_, вер_, lted_,
  { {0x6b8306d5, 0x3f870016, 0xdb01010f, 0x00000000}},  //   _heng, hanu_, rflä,
  { {0x2cad1fd8, 0x443332d0, 0x6b830065, 0x00000000}},  // [a5c0] nted_, fox_, _keng,
  { {0x389b007b, 0x660406b7, 0xa5bb000c, 0x00000000}},  //   _קיינ, shik, _hjól,
  { {0x6b83020c, 0xf626008b, 0x3f870209, 0x00000000}},  //   _meng, _адно, danu_,
  { {0x629e002b, 0x44210082, 0x9f470023, 0x00000000}},  //   rupo, anh_, ajnë_,
  { {0x629e011c, 0x3f870107, 0x443332d1, 0x00000000}},  //   supo, fanu_, box_,
  { {0x3f870127, 0x443300d4, 0x6b83065c, 0x00000000}},  //   ganu_, cox_, _neng,
  { {0xa2e30088, 0x5299005e, 0x44380725, 0x00000000}},  //   _корд, _пътя_, _ikr_,
  { {0x645c022b, 0x2cad00ab, 0x9f45000a, 0x00000000}},  //   _hiri, fted_, _dolà_,
  { {0x645c0390, 0x6b83033b, 0xf06301f9, 0x00000000}},  //   _kiri, _beng, _вкуп,
  { {0x69a5001c, 0x3f870b94, 0x645c0173, 0x00000000}},  //   _काही, canu_, _jiri,
  { {0x6b830149, 0x645c0119, 0xcfa905f3, 0x00000000}},  //   _deng, _miri, _سالم_,
  { {0xc33300b6, 0x645c0636, 0x7bca000b, 0x00000000}},  //   יות_, _liri, _wafu,
  { {0x2cad0038, 0x6b83009f, 0x7bca000b, 0x00000000}},  //   cted_, _feng, _tafu,
  { {0x6b8332d2, 0x645c0066, 0x443301f3, 0x00000000}},  //   _geng, _niri, xox_,
  { {0x4433009d, 0x7a3d009d, 0x6595195e, 0x00000000}},  //   vox_, héti, лаву,
  { {0x645c0006, 0xed5902aa, 0x6b83014a, 0x00000000}},  //   _airi, leža_, _zeng,
  { {0x645c038c, 0x73d903e0, 0x443800bb, 0x00000000}},  // [a5d0] _biri, ндар_, _bkr_,
  { {0x33740265, 0x939401b7, 0x69cd0146, 0x00000000}},  //   игур, لجما, _haae,
  { {0x645c0198, 0x89340123, 0x7d090197, 0x00000000}},  //   _diri, _معیا, zzes,
  { {0xa2940106, 0x645c32d3, 0x69cf00f8, 0x00000000}},  //   раці, _eiri, ndce,
  { {0x3f87016e, 0x2cad01f3, 0xe134007e, 0x00000000}},  //   tanu_, xted_, анцы,
  { {0x645c011f, 0x13a702fd, 0x9ea9034b, 0x00000000}},  //   _giri, _جنسی_, евка_,
  { {0x6b83010a, 0x3f87047c, 0xed59089f, 0x00000000}},  //   _reng, ranu_, deža_,
  { {0x2cad167c, 0x6b8304cb, 0x7a3d1055, 0x00000000}},  //   tted_, _seng, béti,
  { {0x6b83020c, 0x765d0263, 0x3f871609, 0x00000000}},  //   _peng, _misy, panu_,
  { {0x2cad0038, 0x60c913e1, 0x645c0c2f, 0x00000000}},  //   rted_, _isem, _xiri,
  { {0x2cad0038, 0x6b830207, 0x7d091a53, 0x00000000}},  //   sted_, _veng, szes,
  { {0x6b83000b, 0x2cad00ab, 0x765d0178, 0x00000000}},  //   _weng, pted_, _nisy,
  { {0x60c932d4, 0x6b8804e7, 0xed5901c5, 0x00000000}},  //   _jsem, badg, beža_,
  { {0x9d1a007b, 0x60c91ac6, 0xab29003b, 0x00000000}},  //   _אונט, _msem, _пола_,
  { {0x443832d5, 0x7bc11a03, 0x645c0093, 0x00000000}},  //   _rkr_, melu, _riri,
  { {0x443827f1, 0x7bc132d6, 0x6253002b, 0x00000000}},  //   _skr_, lelu, _għox,
  { {0x645c2bfa, 0x443801a3, 0x765d09f3, 0x00000000}},  // [a5e0] _piri, _pkr_, _disy,
  { {0xdb080010, 0x645c0350, 0x200700ca, 0x00000000}},  //   yedü, _qiri, jhni_,
  { {0x60c91254, 0x645c0b60, 0x20070065, 0x00000000}},  //   _asem, _viri, dhni_,
  { {0x645c0016, 0x7a3d0489, 0xd2590088, 0x00000000}},  //   _wiri, téti, вці_,
  { {0x645c32d7, 0x7bc104cb, 0x3206008e, 0x00000000}},  //   _tiri, kelu, rhoy_,
  { {0x3f850832, 0x7a3d00f4, 0xccf90036, 0x00000000}},  //   _celu_, réti, dyś_,
  { {0x60c932d8, 0x7bc12509, 0x3f850059, 0x00000000}},  //   _esem, delu, _delu_,
  { {0x7c3800b9, 0x7a3d009d, 0xeda6013b, 0x00000000}},  //   _skvr, péti, ушко,
  { {0xed590243, 0xa0c90025, 0x2dd70025, 0x00000000}},  //   teža_, _لذلك_, طبية_,
  { {0x7bc1037f, 0x20070c0f, 0xd704007d, 0x00000000}},  //   gelu, chni_, रनाथ_,
  { {0xd437007b, 0xa5bb000c, 0x6b880240, 0x00000000}},  //   רטיי_, _sjóm, radg,
  { {0xfe4100a1, 0xccf900b4, 0x00000000, 0x00000000}},  //   _وکٹی, byś_,   ,
  { {0x7bc132d9, 0x69cf00f8, 0xdb1a004a, 0x00000000}},  //   belu, rdce, metí,
  { {0xdb1a1526, 0x7bc10035, 0xb8ed013d, 0x00000000}},  //   letí, celu, _रन_,
  { {0xf3f9001a, 0xdb08004a, 0x765d00e0, 0x00000000}},  //   _îţi_, redó, _pisy,
  { {0xe4e701e1, 0xd4e7041f, 0x99800276, 0x00000000}},  //   лізн, люзи, _imiş_,
  { {0x7afa00b0, 0x765d0173, 0xf9940104, 0x00000000}},  // [a5f0] lytt, _visy, _פרץ_,
  { {0x59dd0164, 0x32040145, 0x00000000, 0x00000000}},  //   याकर, _almy_,   ,
  { {0x753d0046, 0x7afa02cc, 0x60c90066, 0x00000000}},  //   _wysz, nytt, _ssem,
  { {0x3f850091, 0x9564005e, 0x7bc10035, 0x00000000}},  //   _selu_, _гърд, zelu,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60c90059, 0x1e9500d7, 0xdfd10380, 0x00000000}},  //   _vsem, арир, زيع_,
  { {0x7bc1001a, 0x3f850873, 0x2c690142, 0x00000000}},  //   velu, _velu_, _súd_,
  { {0x8cb50256, 0x9db9007e, 0xb5fb0010, 0x00000000}},  //   асоч, тыку_, _hiáb,
  { {0xdd91026c, 0xb8820224, 0x7bc116c7, 0x00000000}},  //   موں_, říze, telu,
  { {0x5e87008b, 0x25b9012d, 0x7afa0374, 0x00000000}},  //   _будз, _lbsl_, fytt,
  { {0xa7200044, 0xab2901e0, 0x2005002b, 0x00000000}},  //   _ধর্ম_, тона_, _illi_,
  { {0x186a0373, 0x7bc104cb, 0x6da5003b, 0x00000000}},  //   ками_, selu, _ђила,
  { {0x39490046, 0x6aa10133, 0xdb0a01a2, 0x00000000}},  //   _czas_, sulf, _abfä,
  { {0x68e201d5, 0x7afa0b09, 0x225f1a37, 0x00000000}},  //   _ġodd, bytt, _liuk_,
  { {0xe73a05f6, 0x9f4500d4, 0xf41b0044, 0x00000000}},  //   тев_, _dolç_, তকার_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd4670113, 0xa3d1013d, 0x20050836, 0x00000000}},  // [a600] иите_, वयं_, _olli_,
  { {0x673e00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _typj,   ,   ,
  { {0x25ab0009, 0x00000000, 0x00000000, 0x00000000}},  //   _fccl_,   ,   ,
  { {0x64a6008b, 0x224d32da, 0x2005008e, 0x00000000}},  //   _кама, _chek_, _alli_,
  { {0x23670295, 0x66060052, 0xdb1a0344, 0x00000000}},  //   žnja_, _ilkk, vetí,
  { {0x7afa00b0, 0x6037007e, 0x224d2fdd, 0x00000000}},  //   yytt, апіў_, _ehek_,
  { {0x225f0e03, 0x9e0632db, 0x00000000, 0x00000000}},  //   _fiuk_, ичил,   ,
  { {0x200506b5, 0x7afa00b0, 0x291e0095, 0x00000000}},  //   _elli_, vytt, ştay_,
  { {0xafe600ed, 0xa06a0604, 0x2cbd00d9, 0x00000000}},  //   _коал, _раза_, _cpwd_,
  { {0x34b700b6, 0x7afa00b0, 0x9f4c0062, 0x00000000}},  //   ספים_, tytt, _hodí_,
  { {0x8aa302d3, 0x3f67013b, 0xa3ab007d, 0x00000000}},  //   оряд, _тихо_, क्ट_,
  { {0xf2d3007b, 0x13cf0044, 0xf99f01aa, 0x00000000}},  //   קער_, রায়, chèl_,
  { {0xc31a0055, 0x1bd40265, 0x79960016, 0x00000000}},  //   _তুমি_, _голя, _ddyw,
  { {0x9f4c0062, 0x25ab00d4, 0x201c0068, 0x00000000}},  //   _lodí_, _sccl_, nivi_,
  { {0xc66801fc, 0xf8ae0167, 0x3a2900fa, 0x00000000}},  //   иште_, وکی_, _tjap_,
  { {0x7a28014a, 0x442a32dc, 0x8c3d15ec, 0x00000000}},  //   nıtl, _ajb_, muşa,
  { {0xf367053c, 0x201c32dd, 0x24f80783, 0x00000000}},  // [a610] атен, kivi_, анты_,
  { {0x201c0295, 0x224d0065, 0x442a32de, 0x00000000}},  //   jivi_, _shek_, _cjb_,
  { {0x93190025, 0x9f4c00f6, 0x8c3d014a, 0x00000000}},  //   دقاء_, _bodí_, nuşa,
  { {0xb5fb00fa, 0xf1e1013d, 0x386901a3, 0x00000000}},  //   _diác, फाइन, _kuar_,
  { {0x83870a78, 0x629e00d9, 0xd4e701ab, 0x00000000}},  //   _выбе, arpo, _тюни,
  { {0x7e680190, 0x386901a3, 0x25a92aa7, 0x00000000}},  //   _budp, _muar_, lgal_,
  { {0x3869020c, 0xa2940088, 0x9294007e, 0x00000000}},  //   _luar_, _марі, _марц,
  { {0x25a91740, 0xf2d20049, 0x7db4007e, 0x00000000}},  //   ngal_, _צען_, осьц,
  { {0x814500a1, 0x2024000c, 0x61ed00b0, 0x00000000}},  //   _اچان, ðrið_, öalu,
  { {0x201c32df, 0x60db0288, 0x7ff40644, 0x00000000}},  //   civi_, _irum, _وسلا,
  { {0x3946198c, 0x00000000, 0x00000000, 0x00000000}},  //   _šos_,   ,   ,
  { {0xa3de001c, 0x60db32e0, 0xf769009b, 0x00000000}},  //   _दोन_, _krum, _טק_,
  { {0xeaae00a1, 0x2a60006c, 0xf99f0173, 0x00000000}},  //   وٹی_, _viib_, chèm_,
  { {0x6d4b32e1, 0x38690065, 0x186700ed, 0x00000000}},  //   _izga, _duar_, сари_,
  { {0xa3ab013d, 0x00000000, 0x00000000, 0x00000000}},  //   क्छ_,   ,   ,
  { {0x201c016c, 0x25a90010, 0x38692d82, 0x00000000}},  //   zivi_, ggal_, _fuar_,
  { {0x7a3d009f, 0xe3ba0794, 0x69c60010, 0x00000000}},  // [a620] rétt, лба_, meke,
  { {0x69c61483, 0x25a9002a, 0x201c006b, 0x00000000}},  //   leke, agal_, xivi_,
  { {0x7a3d32e2, 0x7a28014a, 0xa3b90061, 0x00000000}},  //   métr, yıtl, _अउर_,
  { {0x7a3d32e3, 0x69c632e4, 0x71a6007e, 0x00000000}},  //   létr, neke, садз,
  { {0x201c0198, 0x10a301fb, 0x76440180, 0x00000000}},  //   tivi_, зичн, mliy,
  { {0x60db001a, 0x7644005d, 0x69c60bd5, 0x00000000}},  //   _drum, lliy, heke,
  { {0x201c0207, 0x69c632e5, 0x44441b91, 0x00000000}},  //   rivi_, keke, ml_,
  { {0x44440f68, 0x60db2e3d, 0x201c0207, 0x00000000}},  //   ll_, _frum, sivi_,
  { {0x69c60047, 0x60db0065, 0x444402f1, 0x00000000}},  //   deke, _grum, ol_,
  { {0xda7a01e0, 0x3869027b, 0x443a0168, 0x00000000}},  //   лям_, _ruar_, nop_,
  { {0x7644005a, 0x6d4b0032, 0x3869008a, 0x00000000}},  //   kliy, _ezga, _suar_,
  { {0x4444001f, 0x69c62c77, 0x3f8e0020, 0x00000000}},  //   hl_, geke, lafu_,
  { {0x63bc0a0f, 0x4444013e, 0x7644006b, 0x00000000}},  //   _obrn, kl_, dliy,
  { {0x444402ae, 0x06c00044, 0x3f8e005b, 0x00000000}},  //   jl_, _উপজি, nafu_,
  { {0x69c600c7, 0x444432e6, 0x2bb7009b, 0x00000000}},  //   beke, dl_, _הפוך_,
  { {0x3f8e32e7, 0x7c3a0253, 0x9f4c0026, 0x00000000}},  //   hafu_, lotr, _modà_,
  { {0x6fa90061, 0x44441820, 0x60c4005a, 0x00000000}},  // [a630] _घालू, fl_, çiml,
  { {0xf36701fb, 0x4444000c, 0x443a32e8, 0x00000000}},  //   стан, gl_, gop_,
  { {0x764432e9, 0x7c28029c, 0x236708fb, 0x00000000}},  //   bliy, indr, žnjo_,
  { {0xddc1001a, 0x7a28006b, 0x7c3a0253, 0x00000000}},  //   _mulţ, yıtm, hotr,
  { {0x4444018e, 0x443a0203, 0x7c3a04eb, 0x00000000}},  //   bl_, bop_, kotr,
  { {0x7c3a057c, 0x4444005b, 0x69c60e24, 0x00000000}},  //   jotr, cl_, zeke,
  { {0x7e620324, 0x69c60010, 0x00000000, 0x00000000}},  //   _biop, yeke,   ,
  { {0x644506be, 0x171c0049, 0xd3460014, 0x00000000}},  //   llhi, טווע, _بیمه_,
  { {0x69c60344, 0x60db0032, 0xdb1a068f, 0x00000000}},  //   veke, _urum, netæ,
  { {0x69c60020, 0x76440477, 0x7c3a0213, 0x00000000}},  //   weke, zliy, gotr,
  { {0x5fae0061, 0x2fc72081, 0x39ea017f, 0x00000000}},  //   _घातल, meng_, адно_,
  { {0x2fc7170b, 0x3ea70129, 0xef180089, 0x00000000}},  //   leng_, munt_, _ceļu_,
  { {0x69c608a5, 0x29040047, 0x443a011c, 0x00000000}},  //   reke, áma_, yop_,
  { {0x69c604e7, 0x7c3a0035, 0x2fc70b9a, 0x00000000}},  //   seke, cotr, neng_,
  { {0x69c60010, 0x44440030, 0xdb1a285a, 0x00000000}},  //   peke, vl_, petá,
  { {0x2fc70058, 0xe57a026b, 0x443a0173, 0x00000000}},  //   heng_, рза_, wop_,
  { {0x443a02cc, 0x7644005f, 0x44440016, 0x00000000}},  // [a640] top_, rliy, tl_,
  { {0x4444000d, 0xa3e70164, 0x2fc70093, 0x00000000}},  //   ul_, भाष_, jeng_,
  { {0x443a0168, 0x4444001c, 0x2fc7011c, 0x00000000}},  //   rop_, rl_, deng_,
  { {0x660d1ae4, 0xe0da0407, 0x443a01d6, 0x00000000}},  //   chak, иве_, sop_,
  { {0x2fc72240, 0x4444115e, 0xc5f30104, 0x00000000}},  //   feng_, pl_, _חדר_,
  { {0x2bae02fb, 0x7e62016d, 0xdc390279, 0x00000000}},  //   ज्ञा, _siop, kçıl,
  { {0xe29700c0, 0x23270265, 0x3f8e0020, 0x00000000}},  //   _мар_, _дори_, rafu_,
  { {0x66040052, 0xdcba005e, 0x6e29068f, 0x00000000}},  //   nkik, ащо_, gneb,
  { {0xf65300b6, 0xd7ca0061, 0x2fc700e0, 0x00000000}},  //   וצה_, ाजाच, beng_,
  { {0x224601d5, 0x60cd153d, 0x3ea70c10, 0x00000000}},  //   llok_, çame, bunt_,
  { {0x7c280065, 0x660400b0, 0xdd8f003b, 0x00000000}},  //   rndr, kkik, _ош_,
  { {0x7c3a0219, 0x8c3d01df, 0x5ce60025, 0x00000000}},  //   sotr, luşl, _وكال,
  { {0x7c3a000d, 0x7e7a2513, 0xfbcf00a6, 0x00000000}},  //   potr, _http, رتی_,
  { {0x6e201bc6, 0x3945001e, 0x66040032, 0x00000000}},  //   limb, āls_, ekik,
  { {0x4b7b0049, 0x22460058, 0x7bc8010e, 0x00000000}},  //   _דאוו, klok_, medu,
  { {0x7bc800ca, 0x6e2004cb, 0xa5bb000c, 0x00000000}},  //   ledu, nimb, _njót,
  { {0x2fc7020e, 0x660d0ed1, 0x22460058, 0x00000000}},  // [a650] yeng_, rhak, dlok_,
  { {0x6e20000d, 0x660d0ea6, 0xd7b20061, 0x00000000}},  //   himb, shak, _जायच,
  { {0x6e20000b, 0xc7b20104, 0x6e290016, 0x00000000}},  //   kimb, _אבי_, yneb,
  { {0x6e3b027b, 0xdce901a8, 0x7bc832ea, 0x00000000}},  //   xoub, zbeđ, hedu,
  { {0x2fc70b36, 0x7bc80145, 0x6e290190, 0x00000000}},  //   teng_, kedu, vneb,
  { {0x3f8c32df, 0x3ea700d9, 0x224632eb, 0x00000000}},  //   _cedu_, tunt_, alok_,
  { {0x44210059, 0x2fc704cb, 0x63b401ca, 0x00000000}},  //   mih_, reng_, žený,
  { {0x44210149, 0xed590059, 0x2fc7011c, 0x00000000}},  //   lih_, leži_, seng_,
  { {0x6e2901e3, 0x6e3b00b9, 0x2fc7027c, 0x00000000}},  //   rneb, roub, peng_,
  { {0x442100ee, 0x3ea732ec, 0xdc390279, 0x00000000}},  //   nih_, punt_, tçıl,
  { {0xf8a900a0, 0x661d2280, 0x6e200145, 0x00000000}},  //   _תש_, _omsk, bimb,
  { {0xdeba00b6, 0x442101a3, 0xdb1a00b0, 0x00000000}},  //   _למעל, hih_, detä,
  { {0x442132ed, 0x3e7132ee, 0xa5bb009f, 0x00000000}},  //   kih_, _hát_, _ljós,
  { {0x44211c18, 0x913a0049, 0xd7f20025, 0x00000000}},  //   jih_, מערק, ركز_,
  { {0x26de027b, 0x66e30920, 0x8c3d014a, 0x00000000}},  //   íto_, нора, nuşm,
  { {0x3e710011, 0x8afa009b, 0x9663007c, 0x00000000}},  //   _mát_, _להצי, ексе,
  { {0x660432ef, 0x3e7132f0, 0x4421002b, 0x00000000}},  // [a660] rkik, _lát_, fih_,
  { {0x442101d9, 0x66040343, 0x69d60253, 0x00000000}},  //   gih_, skik, _haye,
  { {0xe646003b, 0xa1c600e1, 0xdb1a014a, 0x00000000}},  //   _неоп, збед, retç,
  { {0x2372001e, 0x7bc8002d, 0x69d61624, 0x00000000}},  //   _šajā_, zedu, _jaye,
  { {0x44210149, 0x38b632f1, 0x200e0022, 0x00000000}},  //   bih_, nær_, thfi_,
  { {0x4421021c, 0x3e7132f2, 0x69d60339, 0x00000000}},  //   cih_, _bát_, _laye,
  { {0xc059103e, 0x3e710011, 0x7bc8066e, 0x00000000}},  //   ції_, _cát_, vedu,
  { {0x64670010, 0x23ac006e, 0x6aa802e1, 0x00000000}},  //   _óriá, _चाँद, vudf,
  { {0x6e2012aa, 0x7bc82248, 0x38b60190, 0x00000000}},  //   rimb, tedu, jær_,
  { {0x6e200922, 0x798d2e8d, 0x38b60190, 0x00000000}},  //   simb, _seaw, dær_,
  { {0x69d6010f, 0x7bc80032, 0x600f00ea, 0x00000000}},  //   _baye, redu, _dømd,
  { {0x69d61adb, 0x7bc81330, 0x38b61ab4, 0x00000000}},  //   _caye, sedu, fær_,
  { {0xb5fb32f3, 0x5c060265, 0x9f4501aa, 0x00000000}},  //   _diál, _няка, _anlè_,
  { {0xdb1a00b0, 0x661d0062, 0x00000000, 0x00000000}},  //   tetä, _smsk,   ,
  { {0x44210bf8, 0x3bbb00b3, 0x98be0089, 0x00000000}},  //   vih_, _המוד, ātā_,
  { {0x38b6137b, 0x69d6014a, 0x4421008a, 0x00000000}},  //   bær_, _gaye, wih_,
  { {0xa5bb000c, 0x00000000, 0x00000000, 0x00000000}},  // [a670] _bjór,   ,   ,
  { {0xb88300b9, 0x2a7c0288, 0x00000000, 0x00000000}},  //   říst, _ktvb_,   ,
  { {0x442132f4, 0x5694007e, 0x8c41010f, 0x00000000}},  //   rih_, _паэт, äßig,
  { {0x44210149, 0x200c002d, 0x3e7132f5, 0x00000000}},  //   sih_, _aldi_, _rát_,
  { {0x3e71001d, 0x92ad0055, 0xa5bb000c, 0x00000000}},  //   _sát_, কবে_, _fjór,
  { {0xc4d2009b, 0x3e7100b9, 0x00000000, 0x00000000}},  //   _שגם_, _pát_,   ,
  { {0x290215b1, 0x44310087, 0x7c2101a2, 0x00000000}},  //   zyka_, _ijz_, vilr,
  { {0xf2d20452, 0xcfcd0044, 0xec79005e, 0x00000000}},  //   _בעל_, লাইন, опи_,
  { {0x61e90035, 0x4c35007e, 0x69d600cc, 0x00000000}},  //   _inel, дэнт, _raye,
  { {0x69d6014a, 0x3e710082, 0x61fb0e9d, 0x00000000}},  //   _saye, _tát_, _houl,
  { {0x61fb32f6, 0x69d632f7, 0x61e900bb, 0x00000000}},  //   _koul, _paye, _knel,
  { {0x29020046, 0x61fb021e, 0x38b601e3, 0x00000000}},  //   tyka_, _joul, tær_,
  { {0x9f580010, 0x61fb032c, 0x6f030544, 0x00000000}},  //   özök_, _moul, lync,
  { {0xb8f60164, 0xb5fb008e, 0x29020036, 0x00000000}},  //   _सन_, _diám, ryka_,
  { {0x61e90032, 0xa3de0309, 0x32060058, 0x00000000}},  //   _onel, _दोष_, ykoy_,
  { {0x23781088, 0x61fb32f8, 0x24800022, 0x00000000}},  //   _sfrj_, _noul, tpim_,
  { {0x2d8f32f9, 0x443100d9, 0x00000000, 0x00000000}},  // [a680] _mege_, _bjz_,   ,
  { {0x61e91f5a, 0x2d8f28f8, 0xb4ce0204, 0x00000000}},  //   _anel, _lege_, _शनी_,
  { {0x61fb0c69, 0x443132fa, 0x316a1c4a, 0x00000000}},  //   _boul, _djz_, ошло_,
  { {0x61fb030a, 0xed590bf8, 0x2d8f32fb, 0x00000000}},  //   _coul, ležu_, _nege_,
  { {0x61fb023f, 0xe7e301f5, 0x00000000, 0x00000000}},  //   _doul, खाचा_,   ,
  { {0xd12f03ec, 0x237800c4, 0xdbcc000c, 0x00000000}},  //   جمه_, _ufrj_, jóðu,
  { {0x61fb00f4, 0x2d8f3028, 0x00000000, 0x00000000}},  //   _foul, _bege_,   ,
  { {0x3ea00224, 0x61fb0f07, 0x00000000, 0x00000000}},  //   čit_, _goul,   ,
  { {0x2d8f0023, 0x00000000, 0x00000000, 0x00000000}},  //   _dege_,   ,   ,
  { {0x61fb1339, 0x3a20013f, 0x00000000, 0x00000000}},  //   _zoul, _amip_,   ,
  { {0xfff500a2, 0xed590e54, 0xa3ac01f5, 0x00000000}},  //   _سکوت_, dežu_, _गाई_,
  { {0x2d8f32fc, 0x1ea90025, 0x00000000, 0x00000000}},  //   _gege_, _رامي_,   ,
  { {0xb4bd0365, 0x9cb30025, 0x00000000, 0x00000000}},  //   _आहे_, _لمنت,   ,
  { {0x2367092f, 0x36d502e9, 0x2d8f32fd, 0x00000000}},  //   žnji_, ногр, _zege_,
  { {0xc5fb00ed, 0x683f00b9, 0x80d5013d, 0x00000000}},  //   оѓа_, vádě, _मैने,
  { {0x7bd8014a, 0x7bda13bc, 0x99670545, 0x00000000}},  //   _havu, ldtu, _отпл,
  { {0x61fb00f4, 0x7bd8014a, 0x5455007c, 0x00000000}},  // [a690] _roul, _kavu, еват,
  { {0x61fb32fe, 0x61e902ae, 0x7bda0240, 0x00000000}},  //   _soul, _snel, ndtu,
  { {0x61fb218c, 0x7bd80020, 0x08f800a6, 0x00000000}},  //   _poul, _mavu, _فریب_,
  { {0xf99f01aa, 0x50b51c4a, 0x7bd80943, 0x00000000}},  //   chèt_, еску, _lavu,
  { {0x61fb028c, 0x2d8f12e9, 0xd4790049, 0x00000000}},  //   _voul, _rege_, _מאָל,
  { {0x61fb0038, 0x7bd80091, 0x2d8f01d6, 0x00000000}},  //   _woul, _navu, _sege_,
  { {0x61fb32ff, 0x2007000c, 0x2d8f0190, 0x00000000}},  //   _toul, rkni_, _pege_,
  { {0x61e9000d, 0xdd9100a1, 0x63ad001a, 0x00000000}},  //   _unel, چوں_, şină,
  { {0xdd91026c, 0x7bd83300, 0x6f0300bb, 0x00000000}},  //   نوں_, _bavu, sync,
  { {0xaf0703f3, 0x2d8f010f, 0x00000000, 0x00000000}},  //   _очек, _wege_,   ,
  { {0x39490093, 0x7bd8005d, 0x5f9400e2, 0x00000000}},  //   _ayas_, _davu, _рихт,
  { {0x7afc0039, 0x13d80044, 0xb5fb0010, 0x00000000}},  //   ärta, সায়, _diák,
  { {0xa3c102fb, 0x2a690e6d, 0x7bd8002b, 0x00000000}},  //   ्जा_, _diab_, _favu,
  { {0x7bd80006, 0x3d18013d, 0x660f00c4, 0x00000000}},  //   _gavu, _बेटे_, _alck,
  { {0x2a690026, 0x7bc30145, 0x2cad0133, 0x00000000}},  //   _fiab_, _ibnu, lued_,
  { {0xdb013301, 0x7bd804eb, 0x00000000, 0x00000000}},  //   rglä, _zavu,   ,
  { {0x7bd80c07, 0x2cad24f1, 0x64a3007e, 0x00000000}},  // [a6a0] _yavu, nued_, лата,
  { {0xa3e70164, 0x68e4002b, 0x93c8026c, 0x00000000}},  //   भाग_, _irid, بارہ_,
  { {0xf99f01aa, 0x786b0066, 0x22440022, 0x00000000}},  //   chès_, _iżva, _pkmk_,
  { {0x69c4002b, 0xa2d5006e, 0xf99f00f6, 0x00000000}},  //   _jbie, णिज्, lhèr_,
  { {0x69c40a61, 0x68e4002b, 0x63ab3302, 0x00000000}},  //   _mbie, _jrid, álné,
  { {0x2ab80047, 0xe8d90011, 0x27170044, 0x00000000}},  //   yéb_, _ngờ_, _দুটো_,
  { {0x69c43303, 0xdc12006b, 0xa2e3005e, 0x00000000}},  //   _obie, xşıl, _йорд,
  { {0x6ed3005f, 0x7bd83304, 0x387f0035, 0x00000000}},  //   _xəbə, _savu, ţuri_,
  { {0x628e3305, 0x7bd80253, 0x2cad0133, 0x00000000}},  //   _hwbo, _pavu, gued_,
  { {0x69c420c1, 0x9f45004a, 0x00000000, 0x00000000}},  //   _abie, _coló_,   ,
  { {0x62580051, 0x645e00b0, 0xdd31006b, 0x00000000}},  //   ríof, impi, _təşv,
  { {0xdc1201f6, 0xc333012e, 0x68e400ab, 0x00000000}},  //   rşıl, טות_, _brid,
  { {0x6e2203c7, 0x68e40129, 0x7bd83306, 0x00000000}},  //   _imob, _crid, _tavu,
  { {0x6ed3005f, 0xd7f8007c, 0x68e40065, 0x00000000}},  //   _səbə, нус_, _drid,
  { {0x0587003b, 0x35e7007e, 0x00000000, 0x00000000}},  //   еузм, нцав,   ,
  { {0x6ed3006b, 0x39490022, 0x62580051, 0x00000000}},  //   _qəbə, _tyas_, níod,
  { {0x629c005f, 0x68e40207, 0x69cf3307, 0x00000000}},  // [a6b0] _avro, _grid, mece,
  { {0x69cf011f, 0x69dd23fc, 0x69c405fd, 0x00000000}},  //   lece, ldse, _zbie,
  { {0x81da0044, 0xdb1a0030, 0x78bd010f, 0x00000000}},  //   ়ান_, getø, ltsv,
  { {0x69cf014a, 0x645e00b0, 0x60cd00c4, 0x00000000}},  //   nece, ampi, çamo,
  { {0x629c3308, 0x78bd00ea, 0xd3a700ed, 0x00000000}},  //   _evro, ntsv, _првп,
  { {0x63550256, 0x764d0180, 0x63b50036, 0x00000000}},  //   _авгу, llay, _uczn,
  { {0x69cf1c57, 0x628e005b, 0x00000000, 0x00000000}},  //   kece, _gwbo,   ,
  { {0x7ceb000c, 0x628500ab, 0x764d005d, 0x00000000}},  //   jörð, mpho, nlay,
  { {0x62852467, 0x4ec30044, 0x44230145, 0x00000000}},  //   lpho, ্মেল, _kmj_,
  { {0x23670091, 0x62850190, 0x68e40226, 0x00000000}},  //   žnju_, opho, _rrid,
  { {0x764d011f, 0x62850011, 0x2cad00ab, 0x00000000}},  //   klay, npho, sued_,
  { {0x68e40cce, 0xf2d2007b, 0x78bd01c9, 0x00000000}},  //   _prid, בעט_, ftsv,
  { {0xe8f702d3, 0x6aa80c95, 0xc19a00b3, 0x00000000}},  //   вля_, ardf, ושרי,
  { {0x68e43309, 0x7e6b0058, 0x60c900e7, 0x00000000}},  //   _vrid, _higp, _mpem,
  { {0x69cf0b33, 0x78bd2f5d, 0x80b30164, 0x00000000}},  //   bece, atsv, उंडे,
  { {0x940c005f, 0x69cf0190, 0x7bc1330a, 0x00000000}},  //   ələr_, cece, lflu,
  { {0x6fe1001c, 0x0566005e, 0x657d012d, 0x00000000}},  // [a6c0] पयां, тван, _dfsh,
  { {0x7bc10218, 0x62850009, 0x6d4b0602, 0x00000000}},  //   nflu, fpho, _myga,
  { {0xe29701e1, 0x628500e0, 0x6d4b330b, 0x00000000}},  //   вах_, gpho, _lyga,
  { {0x764d008e, 0xdb1a0030, 0xb87b004a, 0x00000000}},  //   clay, retø, lvía,
  { {0x442301f3, 0x216704f9, 0x6d4b1a96, 0x00000000}},  //   _fmj_, вици_, _nyga,
  { {0x638300e3, 0x69cf330c, 0xb87b004a, 0x00000000}},  //   _вгра, zece, nvía,
  { {0x4444330d, 0x69cf011f, 0x8c3d014a, 0x00000000}},  //   mo_, yece, nuşu,
  { {0xade303e8, 0xe6bb006b, 0x6d4b0190, 0x00000000}},  //   ацьк, şaçı, _byga,
  { {0x625803d1, 0x7ceb000c, 0x4444016e, 0x00000000}},  //   ríod, vörð, oo_,
  { {0x444405d3, 0x1dae0061, 0x7afc0039, 0x00000000}},  //   no_, _टाकत, ärto,
  { {0x4444220a, 0x69cf27b5, 0x60140129, 0x00000000}},  //   io_, tece, _càme,
  { {0x44440428, 0x78bd05ad, 0x764d006b, 0x00000000}},  //   ho_, ttsv, xlay,
  { {0x44440756, 0x69cf27b5, 0x69dd006c, 0x00000000}},  //   ko_, rece, rdse,
  { {0x44440ecf, 0x3e780047, 0x62852228, 0x00000000}},  //   jo_, _két_, ypho,
  { {0x4444306b, 0x764d014a, 0x78bd00f8, 0x00000000}},  //   do_, tlay, stsv,
  { {0x4444203d, 0x3e78330e, 0x3ce60ec4, 0x00000000}},  //   eo_, _mét_, _krov_,
  { {0x764d0279, 0x9f5e0065, 0x3e78000c, 0x00000000}},  // [a6d0] rlay, _botë_, _lét_,
  { {0x4444330f, 0xf8bf00f4, 0x628502d4, 0x00000000}},  //   go_, mté_, tpho,
  { {0xf8bf00f4, 0x3e780011, 0x8c3d014a, 0x00000000}},  //   lté_, _nét_, muşt,
  { {0x4444027b, 0x68e2001e, 0xe9df008e, 0x00000000}},  //   ao_, _šodi, ndú_,
  { {0x444413a1, 0xf8bf028c, 0x628500ab, 0x00000000}},  //   bo_, nté_, spho,
  { {0xf8bf00f4, 0x8c3d014a, 0x44233310, 0x00000000}},  //   ité_, nuşt, _umj_,
  { {0xa294007e, 0x9976006b, 0x229404dd, 0x00000000}},  //   _васі, _nəşr_, _вися,
  { {0x6445011c, 0x660d0010, 0x9f5e01aa, 0x00000000}},  //   lohi, nkak, _motè_,
  { {0x626c0035, 0x60c900e7, 0x9f5e0173, 0x00000000}},  //   _uşoa, _upem, _lotè_,
  { {0xabd50098, 0x64450403, 0xe8d90082, 0x00000000}},  //   уциј, nohi, _ngố_,
  { {0x7bc11642, 0x660d021e, 0xdd9103ec, 0x00000000}},  //   rflu, kkak, _هوا_,
  { {0x44443311, 0x62580051, 0x7bc10218, 0x00000000}},  //   zo_, míoc, sflu,
  { {0x44440258, 0x62580051, 0x64450bbb, 0x00000000}},  //   yo_, líoc, kohi,
  { {0x3156007b, 0x444405bc, 0x6e29010f, 0x00000000}},  //   טירן_, xo_, lieb,
  { {0x7d090010, 0x3e78001d, 0x8c1a00b6, 0x00000000}},  //   lyes, _xét_, _רוצי,
  { {0x44440046, 0x660d006a, 0x6e29008e, 0x00000000}},  //   wo_, gkak, nieb,
  { {0x4444024e, 0x7d09000b, 0xe45a00e3, 0x00000000}},  // [a6e0] to_, nyes, ежа_,
  { {0x6e29010f, 0x4444005b, 0x644500e0, 0x00000000}},  //   hieb, uo_, gohi,
  { {0x44440fb3, 0x91e60069, 0x2cbf0004, 0x00000000}},  //   ro_, ложе, htud_,
  { {0x44440c2e, 0x7e78001c, 0x80c80044, 0x00000000}},  //   so_, vqvp, লিস্,
  { {0x859b019b, 0x6e290fcf, 0x3e780011, 0x00000000}},  //   _אשכו, dieb, _sét_,
  { {0xddcb0dec, 0x7d1b012d, 0xa067142c, 0x00000000}},  //   _figū, dzus, гача_,
  { {0x6258002a, 0x7c281715, 0x2cbf3312, 0x00000000}},  //   ríob, vidr, etud_,
  { {0x629e0095, 0x3e780082, 0x7c2801a2, 0x00000000}},  //   mspo, _vét_, widr,
  { {0x7c283313, 0x7d093314, 0x26da0022, 0x00000000}},  //   tidr, gyes, _lspo_,
  { {0xd12f05d4, 0x22460173, 0xdd8f00a1, 0x00000000}},  //   _عمل_, look_, _ہوم_,
  { {0x5a3500ed, 0x645c0016, 0x79962b11, 0x00000000}},  //   инот, _mhri, _beyw,
  { {0xf8bf01e6, 0x22460145, 0x7c28007f, 0x00000000}},  //   tté_, nook_, sidr,
  { {0xf8bf028c, 0x645c0142, 0xe9df3315, 0x00000000}},  //   uté_, _ohri, rdú_,
  { {0xf8bf00f4, 0x629e1b22, 0x9f5e0026, 0x00000000}},  //   rté_, kspo, _potè_,
  { {0xf8bf0371, 0x6b7b00a3, 0xdce0005a, 0x00000000}},  //   sté_, _ארונ, mamı,
  { {0x629e0193, 0xdce0005d, 0xf8bf00f4, 0x00000000}},  //   dspo, lamı, pté_,
  { {0x660d022b, 0x645c0051, 0x64453316, 0x00000000}},  // [a6f0] rkak, _bhri, tohi,
  { {0x645c0aba, 0x6b9a04bd, 0xdce0005d, 0x00000000}},  //   _chri, natg, namı,
  { {0x629e1cce, 0x644504f4, 0x7c2f009d, 0x00000000}},  //   gspo, rohi, écri,
  { {0xa2940088, 0x64450058, 0xdb1a00b4, 0x00000000}},  //   саці, sohi, letó,
  { {0x69df008d, 0xdce0005d, 0x6e290bd3, 0x00000000}},  //   _maqe, kamı, vieb,
  { {0x62580051, 0x287c0049, 0x7d1b006b, 0x00000000}},  //   tíoc, ענומ, vzus,
  { {0x6e2923c3, 0x290b0016, 0xf2e40088, 0x00000000}},  //   tieb, hyca_, _люто,
  { {0x82370054, 0x6258002a, 0x69df0023, 0x00000000}},  //   _إرسا, ríoc, _naqe,
  { {0x6e290d78, 0x1fa70467, 0x62580051, 0x00000000}},  //   rieb, _брег, síoc,
  { {0x6e29021f, 0x60db011c, 0xb5fb0051, 0x00000000}},  //   sieb, _isum, _fhág,
  { {0x7d1b010f, 0x7d093317, 0x2cbf006c, 0x00000000}},  //   szus, syes, stud_,
  { {0xaa46189c, 0x00000000, 0x00000000, 0x00000000}},  //   ремл,   ,   ,
  { {0xc9560a78, 0x2d8d0020, 0x6b9a12ec, 0x00000000}},  //   ртны, mbee_, batg,
  { {0x6b9a001c, 0xb8ee02d2, 0x2d8d0066, 0x00000000}},  //   catg, _रह_, lbee_,
  { {0x69df0065, 0x9f5e00b9, 0x2cad004a, 0x00000000}},  //   _faqe, _poté_, lred_,
  { {0x78a901d9, 0x629e17f1, 0x645c00ab, 0x00000000}},  //   ševa, vspo, _shri,
  { {0x645c0124, 0x9f5e009d, 0x14262cb4, 0x00000000}},  // [a700] _phri, _voté_, адам,
  { {0x629e22b0, 0x389b01ce, 0x6d5901c3, 0x00000000}},  //   tspo, _שיינ, _mzwa,
  { {0x60db3318, 0x81df0044, 0x032600ec, 0x00000000}},  //   _asum, তান_, јден,
  { {0x629e00b5, 0x00e60069, 0x600f08e0, 0x00000000}},  //   rspo, ижен, _dømm,
  { {0x22460ace, 0xdce00279, 0x629e0322, 0x00000000}},  //   rook_, yamı, sspo,
  { {0xa2e60057, 0x6443016e, 0x629e0f0f, 0x00000000}},  //   _когд, čnic, pspo,
  { {0xe2970057, 0xdce0005a, 0x22460ace, 0x00000000}},  //   _вас_, vamı, pook_,
  { {0xadf40cad, 0x601400f6, 0x2cad086a, 0x00000000}},  //   спиш, _dàma, fred_,
  { {0x6b9a04bd, 0x2cad003b, 0x6d590036, 0x00000000}},  //   tatg, gred_, _czwa,
  { {0x61e0003b, 0x60c219cf, 0xbea603e8, 0x00000000}},  //   _haml, mtom, _важк,
  { {0x337700b6, 0x6b9a0129, 0x69df0065, 0x00000000}},  //   יעים_, ratg, _paqe,
  { {0x61e20047, 0x2cad0066, 0x6b9a0129, 0x00000000}},  //   ndol, bred_, satg,
  { {0x61e00020, 0x63bc0107, 0x3e710091, 0x00000000}},  //   _maml, _ocrn, _išta_,
  { {0x61e2021e, 0xbb840025, 0x3f9c006c, 0x00000000}},  //   hdol, _الغي, navu_,
  { {0xd5bb0242, 0xdb1a3319, 0x298b1c4a, 0x00000000}},  //   кса_, retó, _испо_,
  { {0xbafb0097, 0x24890093, 0x600f06ec, 0x00000000}},  //   _יהוש, tpam_, _rømm,
  { {0x61e2018e, 0x81df0044, 0x799d0117, 0x00000000}},  // [a710] ddol, তাম_, masw,
  { {0x3f9c04a9, 0x4ada0164, 0x6b98331a, 0x00000000}},  //   javu_, _बनाव, _jevg,
  { {0xb5fb331b, 0x24890062, 0x2cad183b, 0x00000000}},  //   _diár, spam_, zred_,
  { {0x799d331c, 0x61e20232, 0x27e101a2, 0x00000000}},  //   nasw, gdol, _hahn_,
  { {0x9508026c, 0x69bc04da, 0x8467005e, 0x00000000}},  //   _پہلے_, ष्टी, _въве,
  { {0x3f9c01c5, 0x600f08e0, 0x1e9529a1, 0x00000000}},  //   gavu_, _tømm, брир,
  { {0x61e20026, 0x6d590036, 0x62580048, 0x00000000}},  //   bdol, _szwa, míon,
  { {0x62580051, 0xed590a78, 0x60db0058, 0x00000000}},  //   líon, лой_, _tsum,
  { {0xa3ab0754, 0x2cad331d, 0x3f9c0626, 0x00000000}},  //   _गया_, ured_, bavu_,
  { {0x2cad00ab, 0x40590355, 0x62580051, 0x00000000}},  //   rred_, _صلاح_, níon,
  { {0x9cf908b7, 0x81da0055, 0x8f550025, 0x00000000}},  //   েছেন_, ়ার_, _اناش,
  { {0x2cad041a, 0xc3320104, 0x20050016, 0x00000000}},  //   pred_, לוי_, _holi_,
  { {0xeb8e012b, 0x78a91e34, 0x6c850379, 0x00000000}},  //   _ни_, ševn, _التم,
  { {0x200500f4, 0x99990027, 0x61e2014a, 0x00000000}},  //   _joli_, vosť_, zdol,
  { {0x61e20adc, 0x62580048, 0x3a290045, 0x00000000}},  //   ydol, díon, _fmap_,
  { {0x3f9c05fa, 0x2005013f, 0x60c2007f, 0x00000000}},  //   zavu_, _loli_, ytom,
  { {0x2aa3005f, 0x32040058, 0x61e001a3, 0x00000000}},  // [a720] lıb_, _romy_, _raml,
  { {0x61e001c4, 0x68fb009b, 0xd6cf00a1, 0x00000000}},  //   _saml, _עליה, بقہ_,
  { {0xe80d03d7, 0x2aa3005f, 0xb5fb00c4, 0x00000000}},  //   _सकता_, nıb_, _viár,
  { {0x60c2021e, 0x7afc09b0, 0x27e101a2, 0x00000000}},  //   ttom, ärti, _zahn_,
  { {0x20050027, 0x81da0044, 0x61e200b4, 0x00000000}},  //   _boli_, ়াল_, rdol,
  { {0x20050675, 0x60c200b0, 0x66061cd3, 0x00000000}},  //   _coli_, rtom, _hokk,
  { {0x6ab602fb, 0x66060004, 0x60c20038, 0x00000000}},  //   _अमेर, _kokk, stom,
  { {0x6b9801f6, 0x60c2031e, 0x2aa3006b, 0x00000000}},  //   _sevg, ptom, dıb_,
  { {0x8fa602be, 0x20052cb2, 0x442a0022, 0x00000000}},  //   _газе, _foli_, _kmb_,
  { {0xb5fb001d, 0x660608e0, 0xdbf000b9, 0x00000000}},  //   _khác, _lokk, _tříd,
  { {0xe9f90822, 0x0dca01fb, 0x799d0173, 0x00000000}},  //   анні_, _були_, tasw,
  { {0x6606009f, 0x9e6604b6, 0x786b01d5, 0x00000000}},  //   _nokk, _увед, _iżvi,
  { {0x799d0093, 0xb4d701f5, 0x8c46142c, 0x00000000}},  //   rasw, _ाने_, _леде,
  { {0x78a90107, 0x3d2b025a, 0xb87b000c, 0x00000000}},  //   ševo, _حتمی_, lvík,
  { {0x799d000b, 0x66060007, 0xab68002b, 0x00000000}},  //   pasw, _bokk, _biżż,
  { {0x442a120d, 0xd0fa01f5, 0xb5fb0051, 0x00000000}},  //   _amb_, ्हाण_, _sháb,
  { {0x26c30059, 0x5399007c, 0x66060376, 0x00000000}},  // [a730] stjo_, ивая_, _dokk,
  { {0x68ed1fe0, 0x7e7a00ab, 0xb367007c, 0x00000000}},  //   _irad, _outp, бъек,
  { {0x68ed004f, 0x2005042e, 0x6258002a, 0x00000000}},  //   _hrad, _roli_, ríon,
  { {0x09ab0055, 0x20050207, 0x3abb0049, 0x00000000}},  //   গ্রা, _soli_, רמאנ,
  { {0xed46026c, 0x09e30055, 0x2aa3005f, 0x00000000}},  //   _آپ_, যাপা, zıb_,
  { {0x2aa3005f, 0xa29502f0, 0x68ed0020, 0x00000000}},  //   yıb_, _магі, _mrad,
  { {0x20050207, 0x2aa3006b, 0x59a90061, 0x00000000}},  //   _voli_, xıb_, कणार,
  { {0xf2d200bd, 0x68ed331e, 0x62580051, 0x00000000}},  //   _קען_, _orad, níol,
  { {0xee36008b, 0x20050006, 0xec760a7c, 0x00000000}},  //   ўны_, _toli_, опы_,
  { {0x5ac9013b, 0x2aa3005f, 0x62580051, 0x00000000}},  //   алом_, tıb_, híol,
  { {0x68ed047f, 0x78a90091, 0x7860331f, 0x00000000}},  //   _arad, ševl, növe,
  { {0x68ed049c, 0x2aa3006b, 0xdd1e01dc, 0x00000000}},  //   _brad, rıb_, _síťo,
  { {0x78600073, 0x6e2b3320, 0x7e7a00bb, 0x00000000}},  //   höve, _imgb, _zutp,
  { {0x660604d8, 0x68ed1194, 0x78600010, 0x00000000}},  //   _sokk, _drad, köve,
  { {0x442a002b, 0x66e300ed, 0xba3d0006, 0x00000000}},  //   _rmb_, мора, grįs,
  { {0x68ed16ec, 0x78a41f9d, 0x2d9f01a2, 0x00000000}},  //   _frad, _tviv, naue_,
  { {0x68ed0213, 0x64433321, 0x442a0093, 0x00000000}},  // [a740] _grad, čnin, _pmb_,
  { {0xb5fb0082, 0x2d9f01a2, 0x00000000, 0x00000000}},  //   _phác, haue_,   ,
  { {0x6606071b, 0x86460242, 0x59c10309, 0x00000000}},  //   _tokk, _множ, ष्कर,
  { {0x3f850035, 0x4b4c0049, 0x625800f6, 0x00000000}},  //   _aflu_, נגאַ, cíol,
  { {0x25a0083a, 0x10a31b49, 0x442a0b32, 0x00000000}},  //   mail_, дичн, _tmb_,
  { {0x4aa9001c, 0xf503007e, 0xb5fb0011, 0x00000000}},  //   _किंव, _ўзро, _thác,
  { {0x09b20044, 0x24800cb8, 0xdefa0930, 0x00000000}},  //   ট্যা, lqim_, рыл_,
  { {0x614600ed, 0x6ca6041f, 0x2dd3005e, 0x00000000}},  //   _деба, орож, джър,
  { {0x6258002a, 0xb87b000c, 0x09e30044, 0x00000000}},  //   níom, rvík, যামা,
  { {0x9b6a08f3, 0x68ed0065, 0x25a00fff, 0x00000000}},  //   ишна_, _rrad, hail_,
  { {0xa5bb02d5, 0x68ed0026, 0x24800065, 0x00000000}},  //   _imóv, _srad, hqim_,
  { {0x68ed010a, 0xba2b0088, 0x6d5c006b, 0x00000000}},  //   _prad, ріод_, əran,
  { {0xcd3604e8, 0x0e6903ec, 0x25a00051, 0x00000000}},  //   _براب, _اصلي_, dail_,
  { {0x7c2a0218, 0x00000000, 0x00000000, 0x00000000}},  //   _umfr,   ,   ,
  { {0x09d00055, 0xdb4f0088, 0x25a02801, 0x00000000}},  //   িয়া, _цю_, fail_,
  { {0x7afc006c, 0x25a00048, 0xddc20036, 0x00000000}},  //   ärtu, gail_, _ukoń,
  { {0x68ed0925, 0xd37b0265, 0x7c3a0048, 0x00000000}},  // [a750] _urad, аче_, ontr,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x25a0002a, 0x4cd30055, 0x7c3a010f, 0x00000000}},  //   bail_, তিযু, intr,
  { {0x25a0002a, 0x9259007c, 0x00000000, 0x00000000}},  //   cail_, щает_,   ,
  { {0xc5fa009b, 0x443a05ae, 0xf07500a1, 0x00000000}},  //   _הפרט, bnp_, سیاں_,
  { {0xdb1a006c, 0x7e620288, 0x00000000, 0x00000000}},  //   letõ, _ahop,   ,
  { {0xa19501fb, 0x82a401fc, 0x160f013d, 0x00000000}},  //   _навч, _оште, _सवार_,
  { {0x7c3a008e, 0x09e30044, 0x00000000, 0x00000000}},  //   entr, যাডা,   ,
  { {0x7a360e07, 0x81191023, 0x00000000, 0x00000000}},  //   nšte, _ужас_,   ,
  { {0x4b250245, 0x00000000, 0x00000000, 0x00000000}},  //   змов,   ,   ,
  { {0xc949009b, 0x00000000, 0x00000000, 0x00000000}},  //   _עמ_,   ,   ,
  { {0x6eca006b, 0x7a360006, 0x25a0006b, 0x00000000}},  //   _məbl, kšte, xail_,
  { {0x25a0028c, 0x7e6926e0, 0x7a360087, 0x00000000}},  //   vail_, mmep, jšte,
  { {0x601d01aa, 0x7c940014, 0x25a000e0, 0x00000000}},  //   _fème, _آشنا, wail_,
  { {0x81b30044, 0xe3b200a1, 0x601d000a, 0x00000000}},  //   জ্য_, ہرا_, _gème,
  { {0x6e3b000c, 0xdb1a010e, 0x00000000, 0x00000000}},  //   nnub, tetö,   ,
  { {0x25a0005d, 0xe9440bb6, 0x00000000, 0x00000000}},  // [a760] rail_, _ترغی,   ,
  { {0x2d9d0343, 0x62580051, 0x25a03322, 0x00000000}},  //   _lewe_, ríom, sail_,
  { {0x5186092b, 0x877b009b, 0xb77b009b, 0x00000000}},  //   пула, _לאיי, _לאיש,
  { {0xdb1a006c, 0x2d9d01d6, 0x00000000, 0x00000000}},  //   petö, _newe_,   ,
  { {0x3dc30055, 0xb5fb001d, 0x7760013f, 0x00000000}},  //   ্যাল, _khán, əmxa,
  { {0x7e620498, 0x932602fd, 0x6e3b0009, 0x00000000}},  //   _shop, _فرزن, enub,
  { {0xeab60055, 0x877b0049, 0x2d9d01d6, 0x00000000}},  //   _জন্ম, זאצי, _bewe_,
  { {0x6604183a, 0x2d9d023a, 0x333b00b3, 0x00000000}},  //   njik, _cewe_, _התלמ,
  { {0x2ba60224, 0x75243323, 0x2d9d0022, 0x00000000}},  //   jící_, nziz, _dewe_,
  { {0x7c3a0035, 0xb5fb0011, 0x7e6210c5, 0x00000000}},  //   untr, _nhán, _whop,
  { {0x81df0055, 0xfbcf00a1, 0xeee40014, 0x00000000}},  //   তার_, ھتی_, _تغذی,
  { {0xa5bb004a, 0x2ca6009d, 0x00000000, 0x00000000}},  //   _ilóg, _tvod_,   ,
  { {0x3f9e008d, 0x5e2500a1, 0x78a606a1, 0x00000000}},  //   _ketu_, _تعلق, gskv,
  { {0x7afc0210, 0xb5fb0011, 0x7a36120f, 0x00000000}},  //   ärts, _chán, všte,
  { {0x3f9e010a, 0x7bda0004, 0xddc80107, 0x00000000}},  //   _metu_, metu, _mudž,
  { {0x3f9e09c4, 0x6604008d, 0x7bda006c, 0x00000000}},  //   _letu_, gjik, letu,
  { {0x70bb0164, 0xd944003b, 0x00000000, 0x00000000}},  // [a770] _ईमेल, _пећи,   ,
  { {0x7bda03b6, 0xa4e4007e, 0x7a3604eb, 0x00000000}},  //   netu, эўск, ršte,
  { {0x7bda3324, 0x00000000, 0x00000000, 0x00000000}},  //   ietu,   ,   ,
  { {0x7bda0004, 0x7a36003b, 0xe8d90082, 0x00000000}},  //   hetu, pšte, _ngừ_,
  { {0xddc83325, 0x7bda01a3, 0xd00900ec, 0x00000000}},  //   _budž, ketu, желе_,
  { {0x2d9d0007, 0x7bda0023, 0x6eca006b, 0x00000000}},  //   _sewe_, jetu, _təbl,
  { {0x44330142, 0x7bda048f, 0x6e3b011c, 0x00000000}},  //   mix_, detu, tnub,
  { {0x2bcf0061, 0xcc890745, 0x31c40d15, 0x00000000}},  //   त्ना, обие_, _псув,
  { {0x7e690039, 0x7bda0035, 0x442100e0, 0x00000000}},  //   rmep, fetu, ohh_,
  { {0x4433218e, 0x2d9d000b, 0x7bda001a, 0x00000000}},  //   nix_, _wewe_, getu,
  { {0xa3cf0309, 0x6e3b00e0, 0x2d9d01c3, 0x00000000}},  //   व्य_, pnub, _tewe_,
  { {0x44210760, 0x3f9e000b, 0x44330066, 0x00000000}},  //   hhh_, _zetu_, hix_,
  { {0x3f9e000b, 0x64430091, 0x7bda033b, 0x00000000}},  //   _yetu_, čnij, betu,
  { {0x7bda0f2c, 0x78a600ea, 0xdb1a00c4, 0x00000000}},  //   cetu, rskv, tetô,
  { {0x59c6001c, 0x92c10044, 0x44330860, 0x00000000}},  //   _वापर, ্টু_, dix_,
  { {0x44333326, 0x7524002d, 0x9655003b, 0x00000000}},  //   eix_, tziz, еђуј,
  { {0xb5fb001d, 0x64a3007e, 0x00000000, 0x00000000}},  // [a780] _thán, ката,   ,
  { {0x661d1d44, 0xdb0100c4, 0x443301de, 0x00000000}},  //   _elsk, valê, gix_,
  { {0x2bcf0183, 0x9f450065, 0x7bc30145, 0x00000000}},  //   त्या, _dalë_, _mcnu,
  { {0x2240006c, 0xc693009b, 0x4421033b, 0x00000000}},  //   õik_, _שאר_, ahh_,
  { {0x7bda0020, 0x9f450065, 0xb5fb0048, 0x00000000}},  //   yetu, _falë_, _mhál,
  { {0x68e40418, 0xd01001b7, 0xd007003b, 0x00000000}},  //   _msid, طلب_, деље_,
  { {0x7bda01ee, 0xc3340049, 0xb87b000c, 0x00000000}},  //   vetu, _װוּ_, lvít,
  { {0x78a9037e, 0x3f9e000b, 0x9f4501aa, 0x00000000}},  //   ševi, _wetu_, _malè_,
  { {0x7bda3327, 0xed57012b, 0x7bc33328, 0x00000000}},  //   tetu, моћ_, _bcnu,
  { {0x69c412a3, 0x81da0044, 0xf063007e, 0x00000000}},  //   _acie, ়াও_, _акуп,
  { {0x83b7009b, 0xaa59312f, 0x00000000, 0x00000000}},  //   ופיע_, зину_,   ,
  { {0xdd900380, 0x7bda006c, 0x200c00ca, 0x00000000}},  //   _صوت_, setu, _hodi_,
  { {0x200c0ba3, 0x00000000, 0x00000000, 0x00000000}},  //   _kodi_,   ,   ,
  { {0x64430059, 0x200c0263, 0x44332067, 0x00000000}},  //   čnik, _jodi_, xix_,
  { {0x200c0a19, 0x45d500ed, 0xf65300a1, 0x00000000}},  //   _modi_, новс, نئر_,
  { {0x200c31a6, 0x59c6006e, 0x786000f8, 0x00000000}},  //   _lodi_, _वायर, röva,
  { {0x69dd0004, 0x443301eb, 0x9f450023, 0x00000000}},  // [a790] mese, tix_, _palë_,
  { {0x69dd001f, 0x200c018e, 0xc8670379, 0x00000000}},  //   lese, _nodi_, _تطبي,
  { {0x4433005f, 0x81e80044, 0x7a3601ee, 0x00000000}},  //   rix_, বান_, lšta,
  { {0x201e3329, 0xa29401fb, 0x44210145, 0x00000000}},  //   _alti_, таці, shh_,
  { {0x629c0562, 0x44330253, 0x78bd0b32, 0x00000000}},  //   _ewro, pix_, nusv,
  { {0x85740099, 0x649a00b6, 0x200c2f25, 0x00000000}},  //   _шлях, _מישה, _codi_,
  { {0x63a50169, 0x69dd0004, 0x7a36016c, 0x00000000}},  //   mahn, kese, hšta,
  { {0x261c002a, 0x7a360006, 0x63a504cb, 0x00000000}},  //   _líon_, kšta, lahn,
  { {0x69dd0119, 0x61fb0058, 0x629c0036, 0x00000000}},  //   dese, _inul, _zwro,
  { {0x69c4028a, 0x200c0016, 0x63a504be, 0x00000000}},  //   _scie, _godi_, nahn,
  { {0x69dd00ea, 0x61e9006c, 0x61fb0039, 0x00000000}},  //   fese, _kael, _knul,
  { {0x69dd0090, 0x320d0007, 0x20070295, 0x00000000}},  //   gese, _joey_, ljni_,
  { {0x61e9000b, 0xdb010263, 0x9f4501aa, 0x00000000}},  //   _mael, zalè, _salè_,
  { {0xfaa501fb, 0x9f4501aa, 0xe61f03ad, 0x00000000}},  //   _зако, _palè_, _alô_,
  { {0x8c1a00b6, 0x63a52755, 0x69dd0144, 0x00000000}},  //   _מוסי, dahn, bese,
  { {0x69dd0314, 0x9f4501aa, 0x85b5012b, 0x00000000}},  //   cese, _valè_, кључ,
  { {0xb4660ae0, 0x2edc007d, 0x261c0051, 0x00000000}},  // [a7a0] екал, _मन्त, _fíon_,
  { {0x61fb332a, 0x6fd3011f, 0x7bc1000c, 0x00000000}},  //   _anul, nıcı, nglu,
  { {0x23c60164, 0x3a20014a, 0x443104b7, 0x00000000}},  //   र्गद, _klip_, _dmz_,
  { {0x64552d3f, 0x2bcf024c, 0x1a9a0049, 0x00000000}},  //   _ekzi, त्ता, פינע,
  { {0x200c2a1a, 0x601d01aa, 0x61e90146, 0x00000000}},  //   _podi_, _sèma, _dael,
  { {0x601d01aa, 0x69dd2258, 0x63a50022, 0x00000000}},  //   _pèma, zese, cahn,
  { {0x69dd0010, 0x200c0059, 0x6fd3006b, 0x00000000}},  //   yese, _vodi_, dıcı,
  { {0x61e9002a, 0xadf406e3, 0x6d590036, 0x00000000}},  //   _gael, тпиш, _bywa,
  { {0x69dd0010, 0x59a703d7, 0x200c0197, 0x00000000}},  //   vese, _ख़बर, _todi_,
  { {0x69dd010f, 0x7bc100f8, 0x09a90061, 0x00000000}},  //   wese, gglu, कण्य,
  { {0x69dd0047, 0x3a2000b4, 0x600f0190, 0x00000000}},  //   tese, _blip_, _tømr,
  { {0x3a2002d4, 0xf2d3007b, 0x78bd03b6, 0x00000000}},  //   _clip_, נער_, tusv,
  { {0x69dd02d5, 0x63a504be, 0x09e30044, 0x00000000}},  //   rese, yahn, যালা,
  { {0x69dd0881, 0x7a360006, 0x9f4c15b3, 0x00000000}},  //   sese, ršta, _endå_,
  { {0x69dd0010, 0xc221006e, 0x44310087, 0x00000000}},  //   pese, _मतलब_, _rmz_,
  { {0x7a36332b, 0x44310020, 0x3a20332c, 0x00000000}},  //   pšta, _smz_, _glip_,
  { {0xdb0101ca, 0x63a50145, 0x3e4501c5, 0x00000000}},  // [a7b0] valé, tahn, nēta_,
  { {0x8707007e, 0x00000000, 0x00000000, 0x00000000}},  //   _зяме,   ,   ,
  { {0xa85800b6, 0x08f804e1, 0x61e918bd, 0x00000000}},  //   _איזה_, _قریب_, _pael,
  { {0x63a50085, 0x92b40025, 0x6fd30095, 0x00000000}},  //   sahn, احلا, zıcı,
  { {0xf8bf009d, 0x6fd3005d, 0xc0e5007c, 0x00000000}},  //   nué_, yıcı, толк,
  { {0x61e90246, 0xe0570167, 0xdb010285, 0x00000000}},  //   _wael, ریات_, salé,
  { {0x660f0209, 0x6d5901c3, 0x00000000, 0x00000000}},  //   _kock, _sywa,   ,
  { {0x660f00f8, 0xe8d9001d, 0x9258030d, 0x00000000}},  //   _jock, _ngữ_, _заст_,
  { {0x6fd301df, 0x00000000, 0x00000000, 0x00000000}},  //   tıcı,   ,   ,
  { {0x660f1f59, 0xea8900e2, 0x00000000, 0x00000000}},  //   _lock, мбол_,   ,
  { {0x7bc100f8, 0xab291023, 0x6fd30180, 0x00000000}},  //   rglu, фона_, rıcı,
  { {0xdd95008b, 0x8d870401, 0x660f06f2, 0x00000000}},  //   _рады, _чужд, _nock,
  { {0xf8bf332d, 0x261c0051, 0x3e4501c5, 0x00000000}},  //   gué_, _díol_, cēta_,
  { {0x6eca013f, 0x00000000, 0x00000000, 0x00000000}},  //   _səbi,   ,   ,
  { {0xc7a301f9, 0x00000000, 0x00000000, 0x00000000}},  //   риск,   ,   ,
  { {0xceb2012f, 0xf8bf009d, 0x6eca006b, 0x00000000}},  //   ייל_, bué_, _qəbi,
  { {0x69d6332e, 0x45831b0b, 0x00000000, 0x00000000}},  // [a7c0] _ibye, ргув,   ,
  { {0x99890059, 0x00000000, 0x00000000, 0x00000000}},  //   _imaš_,   ,   ,
  { {0x6eca005f, 0xa76601e1, 0x3e450089, 0x00000000}},  //   _təbi, _шкод, zēta_,
  { {0x68f60030, 0x6fc40061, 0x00000000, 0x00000000}},  //   _kryd, _राहू,   ,
  { {0x0cbc0055, 0x2cbf006c, 0xa3cf0061, 0x00000000}},  //   _অন্ত, juud_, व्ह_,
  { {0x09d60055, 0x9053008b, 0x7a360006, 0x00000000}},  //   _তোমা, авіц, kšto,
  { {0x69d619ab, 0x9e3402dc, 0x660f1cbf, 0x00000000}},  //   _obye, лекч, _yock,
  { {0x036701e0, 0x2bcf007d, 0x6ced006e, 0x00000000}},  //   _риск_, त्सा, जिंग_,
  { {0x81e80055, 0x2486002a, 0x7860332f, 0x00000000}},  //   বাদ_, íomh_, tövl,
  { {0x2bc20061, 0x69d6000a, 0x3e450089, 0x00000000}},  //   _शाळा, _abye, rēta_,
  { {0x0c730025, 0x6d440027, 0x78ad0538, 0x00000000}},  //   جديد, _žiad, _svav,
  { {0xf8bf00f4, 0x68f6022c, 0x00000000, 0x00000000}},  //   tué_, _bryd,   ,
  { {0x1bd40364, 0x6e220032, 0x00000000, 0x00000000}},  //   _боля, _ilob,   ,
  { {0x660f0039, 0xd9180057, 0x69d600de, 0x00000000}},  //   _sock, тью_, _ebye,
  { {0x660f00ab, 0xf8bf00d6, 0x00000000, 0x00000000}},  //   _pock, sué_,   ,
  { {0xd5b801ff, 0x6281009d, 0x00000000, 0x00000000}},  //   ксу_, _éloi,   ,
  { {0x2bcf0183, 0xf8bf3106, 0x68f60030, 0x00000000}},  // [a7d0] त्वा, qué_, _gryd,
  { {0x6e220129, 0xb5fb0051, 0x00000000, 0x00000000}},  //   _llob, _mhái,   ,
  { {0xe7ec006e, 0xe2980088, 0x9f450026, 0x00000000}},  //   _छोटा_, ває_, _calì_,
  { {0x9f450026, 0x00000000, 0x00000000, 0x00000000}},  //   _dalì_,   ,   ,
  { {0x25a92e34, 0x6d4e010f, 0x9f4c0026, 0x00000000}},  //   maal_, ßbal, _indù_,
  { {0x1ec909de, 0x3f69003b, 0xe2930084, 0x00000000}},  //   елки_, нило_, _نذر_,
  { {0x6e220066, 0x7a26000c, 0x1ea80014, 0x00000000}},  //   _blob, _hóte, نايي_,
  { {0x25a93330, 0xdb0300f4, 0xa3cf0164, 0x00000000}},  //   naal_, _fenê, व्र_,
  { {0xb5fb0051, 0xf53f0056, 0xacf50070, 0x00000000}},  //   _chái, _idås_, اسبت,
  { {0xdab9008b, 0x25a901bb, 0xb5fb0051, 0x00000000}},  //   нымі_, haal_, _dhái,
  { {0xa9a60a85, 0x6e220253, 0xe807013d, 0x00000000}},  //   линд, _flob, शाना_,
  { {0xb5fb002a, 0x68f6018e, 0x7a360006, 0x00000000}},  //   _fhái, _pryd, ršto,
  { {0x25a90a2a, 0xdb013331, 0xb5fb0048, 0x00000000}},  //   daal_, malí, _ghái,
  { {0x0136007b, 0x68f60007, 0x60db0455, 0x00000000}},  //   אָלט_, _vryd, _mpum,
  { {0x186705f6, 0x2cad3332, 0xa3aa013d, 0x00000000}},  //   уари_, lsed_, _गजब_,
  { {0x2bcf0201, 0x68f60016, 0x25a90112, 0x00000000}},  //   त्रा, _tryd, gaal_,
  { {0x05663333, 0x2cad00ab, 0x30be0044, 0x00000000}},  // [a7e0] уван, nsed_, _ইন্স,
  { {0x389b00a3, 0x442300f6, 0xb97b01ce, 0x00000000}},  //   _ריינ, _clj_, _אנפי,
  { {0x3ce503d7, 0x81e80055, 0xe2970121, 0x00000000}},  //   _जैसे_, বাস_, гах_,
  { {0x69c604cb, 0x2cad006c, 0xa50a0fd8, 0x00000000}},  //   ngke, ksed_, _зема_,
  { {0xc05a008b, 0x9f4500d4, 0x3e4c00b9, 0x00000000}},  //   нік_, _dalí_, něte_,
  { {0x6e2204a9, 0xd0071281, 0x2d8f01c3, 0x00000000}},  //   _slob, лече_, _afge_,
  { {0x44440073, 0x6e2208f0, 0x942301fc, 0x00000000}},  //   mn_, _plob, _умре,
  { {0x443a066b, 0x44440495, 0x201c10c1, 0x00000000}},  //   lip_, ln_, skvi_,
  { {0x4444028a, 0xdb0800c4, 0xa5bb00f6, 0x00000000}},  //   on_, cadê, _olón,
  { {0x44441446, 0x443a066b, 0x61e2006c, 0x00000000}},  //   nn_, nip_, leol,
  { {0x44440e2d, 0x2cad00ab, 0xe45701ce, 0x00000000}},  //   in_, ased_, רייט_,
  { {0xc333019b, 0x6eca005f, 0x443a3334, 0x00000000}},  //   מות_, _qəbu, hip_,
  { {0x443a3335, 0x25a90abf, 0xdddb005d, 0x00000000}},  //   kip_, vaal_, lmuş,
  { {0x44443336, 0x443a01aa, 0x8c431e03, 0x00000000}},  //   jn_, jip_, _лече,
  { {0x25a90100, 0x7c3a1ab0, 0x61e20056, 0x00000000}},  //   taal_, mitr, keol,
  { {0x44440f3c, 0x5eb90055, 0x6eca006b, 0x00000000}},  //   en_, _আহমে, _həbs,
  { {0x61e2011f, 0x44443337, 0x25a92b6c, 0x00000000}},  // [a7f0] deol, fn_, raal_,
  { {0x44440365, 0x7c3a0016, 0x25a92667, 0x00000000}},  //   gn_, nitr, saal_,
  { {0x25a901bb, 0x60db0420, 0x2d8d0ace, 0x00000000}},  //   paal_, _spum, ycee_,
  { {0x7c3a0087, 0x2c6b0030, 0x7aea05f0, 0x00000000}},  //   hitr, møde_, _msft,
  { {0x44440690, 0x9f4700b9, 0x7c3a0052, 0x00000000}},  //   bn_, rdní_, kitr,
  { {0x660d0004, 0xb5fb0211, 0x443a12d9, 0x00000000}},  //   ljak, _cháv, cip_,
  { {0xdb031923, 0x9294007e, 0x26d1002d, 0x00000000}},  //   _genè, _гасц, ntzo_,
  { {0xed590ecd, 0x6457049a, 0x61e20051, 0x00000000}},  //   кой_, loxi, ceol,
  { {0xac8501f9, 0x0c2500ed, 0x10d805f3, 0x00000000}},  //   јгол, имин, _مبلغ_,
  { {0x2cad2b35, 0x660d0103, 0x7c3a007f, 0x00000000}},  //   rsed_, hjak, gitr,
  { {0x7f8406ea, 0x81e80055, 0x2cad0038, 0x00000000}},  //   _المن, বার_, ssed_,
  { {0x26c3008e, 0xc8690104, 0xda79007e, 0x00000000}},  //   dujo_, _חן_, ляў_,
  { {0xeb8e1ef9, 0x4444055f, 0x660d3338, 0x00000000}},  //   _ми_, yn_, djak,
  { {0x63a700b9, 0x07a303e0, 0x7c3a009d, 0x00000000}},  //   _nejn, жарн, citr,
  { {0x444402cc, 0x64570035, 0x81ab0044, 0x00000000}},  //   vn_, doxi, _খান_,
  { {0xe8fa045e, 0x44443339, 0x660d04be, 0x00000000}},  //   _али_, wn_, gjak,

  { {0x6287028c, 0x7d1b0169, 0xddc9011f, 0x00000000}},  // [a800] _aujo, nyus, zleş,
  { {0x4444333a, 0x26c30211, 0x62870035, 0x00000000}},  //   un_, bujo_, _bujo,
  { {0x4444001f, 0x61e200b0, 0xdb03167d, 0x00000000}},  //   rn_, teol, _bené,
  { {0x4444333b, 0xe7d20164, 0x62870006, 0x00000000}},  //   sn_, द्रप, _dujo,
  { {0x64570052, 0x4444184b, 0x61e20048, 0x00000000}},  //   boxi, pn_, reol,
  { {0x443a008d, 0xe29600ed, 0x61e20051, 0x00000000}},  //   qip_, _враќ, seol,
  { {0x21200aeb, 0x60c20f38, 0x6e29333c, 0x00000000}},  //   ših_, suom, fheb,
  { {0xfe6f13d9, 0xddc9011f, 0xdb03029d, 0x00000000}},  //   ودي_, rleş, _gené,
  { {0x7c2807be, 0x394d0046, 0x9c46004c, 0x00000000}},  //   thdr, żesz_, ихол,
  { {0xdb030010, 0x7ed60088, 0xe8d90082, 0x00000000}},  //   _zené, _відч, _ngỡ_,
  { {0x752d13f0, 0x62800924, 0x443800ca, 0x00000000}},  //   zzaz, _kimo, _mmr_,
  { {0xdd8f01d8, 0x6cd600a1, 0x7c3a0006, 0x00000000}},  //   _قوم_, _نقصا, sitr,
  { {0x7c940054, 0x62800b41, 0x940c005f, 0x00000000}},  //   _التص, _mimo, şlər_,
  { {0x44380133, 0x00000000, 0x00000000, 0x00000000}},  //   _nmr_,   ,   ,
  { {0xb5a7333d, 0x63a70059, 0x660d333e, 0x00000000}},  //   ирай, _rejn, tjak,
  { {0x645c333f, 0x4b7b061e, 0x6d5c0676, 0x00000000}},  //   _akri, _באוו, ğraf,
  { {0x69cd00f6, 0x9f450161, 0x63a70a0f, 0x00000000}},  // [a810] _icae, _malá_, _pejn,
  { {0x660d0039, 0x7bc82315, 0x62870129, 0x00000000}},  //   sjak, ngdu, _pujo,
  { {0x2bd80061, 0xdb031db2, 0x62803340, 0x00000000}},  //   ब्या, _pené, _bimo,
  { {0x628705fa, 0x645c01aa, 0x44380145, 0x00000000}},  //   _vujo, _ekri, _emr_,
  { {0x62800207, 0x14f4007e, 0x2eec01b1, 0x00000000}},  //   _dimo, _дзяў, _asdf_,
  { {0x7a26056f, 0x09e30044, 0xb97c00a3, 0x00000000}},  //   _móta, যাটা, דנדי,
  { {0x6e2900bb, 0xdb03008e, 0x00000000, 0x00000000}},  //   theb, _tené,   ,
  { {0xf2d200b3, 0x7c38016c, 0x62800032, 0x00000000}},  //   _מעל_, _amvr, _gimo,
  { {0x7a260051, 0x6e29127d, 0xdb010010, 0x00000000}},  //   _nóta, rheb, dalá,
  { {0x40840265, 0xf8bf0181, 0x62800036, 0x00000000}},  //   _футб, dré_, _zimo,
  { {0x682b02b9, 0x44210518, 0xdce701f6, 0x00000000}},  //   _müdd, ikh_, ımız,
  { {0x6eca005f, 0xdb010010, 0xf8bf00d4, 0x00000000}},  //   _təbr, galá, fré_,
  { {0xc9560057, 0xf8bf00f4, 0x7a360062, 0x00000000}},  //   стны, gré_, nšti,
  { {0x765d2900, 0x2cbf0022, 0x00000000, 0x00000000}},  //   _aksy, mrud_,   ,
  { {0xd62a1447, 0x68ed3341, 0xf8bf06c2, 0x00000000}},  //   гове_, _esad, aré_,
  { {0xf8bf0161, 0x7a360006, 0x7afc0030, 0x00000000}},  //   bré_, kšti, ærte,
  { {0xcc88001d, 0x62800207, 0xf8bf00f4, 0x00000000}},  // [a820] _lớn_, _rimo, cré_,
  { {0x601d00f6, 0xb4d801f5, 0x00000000, 0x00000000}},  //   _fèmi, _ाही_,   ,
  { {0x644b01cc, 0x22462042, 0xb5fb0048, 0x00000000}},  //   égia, tnok_, _chás,
  { {0xd2590cf2, 0x443800bb, 0x00000000, 0x00000000}},  //   аці_, _wmr_,   ,
  { {0x25a0027e, 0x62800b33, 0x09e30044, 0x00000000}},  //   mbil_, _vimo, যাচা,
  { {0x20b9008b, 0x645c00e7, 0x25a0070d, 0x00000000}},  //   рыць_, _ukri, lbil_,
  { {0x62800263, 0xe29700ed, 0xaf03007e, 0x00000000}},  //   _timo, _гас_, зчык,
  { {0x25a000f8, 0x3f850288, 0x00000000, 0x00000000}},  //   nbil_, _eglu_,   ,
  { {0xc5f3009b, 0xb53b0049, 0x00000000, 0x00000000}},  //   לדה_, ָגיש,   ,
  { {0xf8bf00f4, 0x2d9f0026, 0x09d60044, 0x00000000}},  //   vré_, abue_, _তোলা,
  { {0xdb010047, 0xddc9145e, 0x7a26077b, 0x00000000}},  //   talá, smeš, _sóta,
  { {0x5d860054, 0xf8bf00f4, 0x2cbf0190, 0x00000000}},  //   _الإل, tré_, brud_,
  { {0xfdf7009b, 0x44210020, 0xf8bf0666, 0x00000000}},  //   _לצאת_, ykh_, uré_,
  { {0xf8bf00f4, 0x7a2605f4, 0x601d01aa, 0x00000000}},  //   rré_, _vóta, _pèmi,
  { {0xdc3b0049, 0x501b009b, 0x6fda013d, 0x00000000}},  //   _געגר, נולו, प्यू,
  { {0xe8d9001d, 0x7e910089, 0x682b01a2, 0x00000000}},  //   _ngủ_, _jāpa, _südd,
  { {0x68ed3342, 0x2bcf0309, 0xb5fb0051, 0x00000000}},  // [a830] _usad, त्का, _shás,
  { {0x44273343, 0x3ce0007d, 0xfa890082, 0x00000000}},  //   ón_, _कहने_, _mẫn_,
  { {0xfa890011, 0x3a2900c7, 0x25a00066, 0x00000000}},  //   _lẫn_, _klap_, bbil_,
  { {0xa5f914dd, 0x9259007c, 0x00000000, 0x00000000}},  //   _тему_, шает_,   ,
  { {0x7a360166, 0x44210022, 0x00000000, 0x00000000}},  //   ušti, pkh_,   ,
  { {0xd5bf0089, 0x7a360006, 0xb5fb0048, 0x00000000}},  //   žādu_, ršti, _thás,
  { {0xb4e9013d, 0x00000000, 0x00000000, 0x00000000}},  //   _मनु_,   ,   ,
  { {0x7a36037e, 0x2cbf00f6, 0xd2640089, 0x00000000}},  //   pšti, trud_, tiņš_,
  { {0x814500a1, 0x9f5e0129, 0xc0cb00e2, 0x00000000}},  //   _بچان, _botó_, _љубе_,
  { {0xfa89001d, 0x5ba90aed, 0x2ca901d5, 0x00000000}},  //   _dẫn_, шком_, _ħadd_,
  { {0xcb690256, 0x7d04002b, 0x00000000, 0x00000000}},  //   ране_, _ġise,   ,
  { {0x3a290145, 0x2ca60173, 0x248300bb, 0x00000000}},  //   _clap_, _fwod_, _lijm_,
  { {0x9f5e0010, 0x9f4500f6, 0x224d0023, 0x00000000}},  //   _fotó_, _balç_, _mjek_,
  { {0x30790049, 0xa5bb000c, 0x9f4500f6, 0x00000000}},  //   יאָנ, _flók, _calç_,
  { {0x4b790049, 0x224d0093, 0x98ab0089, 0x00000000}},  //   _דאַו, _ojek_, ājās_,
  { {0xb5fb0051, 0x20050045, 0x682b01a2, 0x00000000}},  //   _shár, _lnli_, _rüde,
  { {0xa70a0055, 0x25a03344, 0x3ea00166, 0x00000000}},  // [a840] রনেম_, rbil_, ćiti_,
  { {0x25a03345, 0x7d040051, 0xa6e604dd, 0x00000000}},  //   sbil_, _áise, _джол,
  { {0x248b00f6, 0x3cef012d, 0x25ab02d4, 0x00000000}},  //   _eucm_, _lsgv_, _fecl_,
  { {0x20d2001a, 0x7a26000c, 0x00000000, 0x00000000}},  //   tâi_, _móto,   ,
  { {0x9f5e0026, 0x3e450089, 0x00000000, 0x00000000}},  //   _notò_, cēti_,   ,
  { {0x443e0010, 0x26080061, 0x33d503e8, 0x00000000}},  //   _öt_, हावी_, _ніст,
  { {0x9f4c3346, 0x73f90049, 0x09b00044, 0x00000000}},  //   _andò_, _פּשו, _কানা,
  { {0xdb0301dc, 0x629e0943, 0x00000000, 0x00000000}},  //   _cení, mppo,   ,
  { {0xdb0300b9, 0x629e00b0, 0xecfa0044, 0x00000000}},  //   _dení, lppo, েন্স_,
  { {0xfa89001d, 0xbfc301fc, 0x2a600022, 0x00000000}},  //   _vẫn_, _обук, _akib_,
  { {0x7e910089, 0x60c20190, 0x442a0133, 0x00000000}},  //   _tāpa, lrom, _mlb_,
  { {0x2d92011f, 0xed5a0153, 0x0dc700c0, 0x00000000}},  //   _üye_, _кое_, _души_,
  { {0x442a01c3, 0xf1b3009b, 0xe8070309, 0x00000000}},  //   _olb_, וסר_, शाला_,
  { {0xe8d90011, 0x442a0059, 0xdb08013e, 0x00000000}},  //   _ngụ_, _nlb_, ladí,
  { {0x261c0195, 0x60c201ca, 0x5694007e, 0x00000000}},  //   _níos_, hrom, даст,
  { {0x442a001a, 0x60c20428, 0x682b006b, 0x00000000}},  //   _alb_, krom, _büdc,
  { {0x98be001a, 0x6b8d006b, 0x00000000, 0x00000000}},  // [a850] ătă_, _şagi,   ,
  { {0x442a001d, 0xf36700ed, 0x3e450089, 0x00000000}},  //   _clb_, отен, rēti_,
  { {0x7afa001c, 0x261c0051, 0x20050544, 0x00000000}},  //   nvtt, _cíos_, _rnli_,
  { {0x60c20019, 0x9f4c00d4, 0x442a2828, 0x00000000}},  //   from, _cadí_, _elb_,
  { {0x2608007d, 0x09b00044, 0x60c200b4, 0x00000000}},  //   हारी_, _কামা, grom,
  { {0xd3e30167, 0x629800c4, 0x442a0009, 0x00000000}},  //   _تقسی, ívoc, _glb_,
  { {0xd00e0054, 0xdb0300b9, 0x224d0030, 0x00000000}},  //   الى_, _pení, _tjek_,
  { {0x3e61000c, 0x9f470023, 0x92581001, 0x00000000}},  //   jótt_, lenë_, _даст_,
  { {0x60c2016b, 0xdb03008e, 0xa5bb0051, 0x00000000}},  //   crom, _vení, _clói,
  { {0x6fd201f5, 0x98a20036, 0x1fa70121, 0x00000000}},  //   _सायं, czkę_, _фраг,
  { {0xdb0315ab, 0xa3dd03d7, 0x98b00091, 0x00000000}},  //   _tení, थ्य_, đača_,
  { {0x9f5e0197, 0xdb0806c2, 0x00000000, 0x00000000}},  //   _totò_, cadí,   ,
  { {0xdb0a1259, 0x6fd20164, 0x78720190, 0x00000000}},  //   _lefè, _सामं, hæve,
  { {0x3ce0013d, 0x261c0051, 0xfe7900b9, 0x00000000}},  //   _कहते_, _níor_, lmů_,
  { {0x44ed0428, 0x09b00044, 0xdbc6010e, 0x00000000}},  //   _až_, _কাঠা, töök,
  { {0x261c0211, 0x442a3347, 0xf8bf0010, 0x00000000}},  //   _ríos_, _slb_, gzés_,
  { {0x261c002a, 0x442a1e89, 0xdb180173, 0x00000000}},  // [a860] _síos_, _plb_, _advè,
  { {0x29000181, 0xb46300ed, 0x7a26000c, 0x00000000}},  //   _iria_, екул, _mótm,
  { {0xf8bf0010, 0x38c2000c, 0xdcf4016c, 0x00000000}},  //   szét_, _færð_, _đači,
  { {0x60c20010, 0x7aba00b6, 0xcc880011, 0x00000000}},  //   trom, מצעו, _sớm_,
  { {0x26d80555, 0x261c0051, 0xdb0300f6, 0x00000000}},  //   ltro_, _fíor_, _lenà,
  { {0x261c0b51, 0x442a03be, 0x00000000, 0x00000000}},  //   _tíos_, _ulb_,   ,
  { {0xdb083348, 0x60c20944, 0x645e0cff, 0x00000000}},  //   tadí, srom, mopi,
  { {0x682b027d, 0x11da0025, 0x60c2016e, 0x00000000}},  //   _müda, _دورة_, prom,
  { {0xdb080161, 0x26ca00e0, 0xfa890082, 0x00000000}},  //   radí, hubo_, _dẫm_,
  { {0x628e3349, 0x26d80161, 0x645e0052, 0x00000000}},  //   _kubo, ktro_, nopi,
  { {0x0d860c96, 0x29000207, 0xdb080181, 0x00000000}},  //   _елен, _aria_, dadã,
  { {0x2900000a, 0xdb0300c4, 0x628e22dc, 0x00000000}},  //   _bria_, _senã, _mubo,
  { {0x628e011c, 0x29000181, 0x26d80197, 0x00000000}},  //   _lubo, _cria_, etro_,
  { {0x629c334a, 0xb8f502d2, 0x7d1d0cba, 0x00000000}},  //   _otro, _हम_, ässe,
  { {0x629c06be, 0x45d500ed, 0x645e1712, 0x00000000}},  //   _ntro, мовс, dopi,
  { {0x2900334b, 0x3e450089, 0x7e62002b, 0x00000000}},  //   _fria_, bētu_, _jkop,
  { {0x629c0ebc, 0x7e620020, 0xf8bf0010, 0x00000000}},  // [a870] _atro, _mkop, rzés_,
  { {0x628e1163, 0x69dd00bb, 0x44ed2c1b, 0x00000000}},  //   _bubo, lfse, _vž_,
  { {0x41d1013d, 0x26ca334c, 0x628e0b33, 0x00000000}},  //   _हादस, cubo_, _cubo,
  { {0x628e0091, 0x237400f3, 0x00000000, 0x00000000}},  //   _dubo, رالح,   ,
  { {0x44ed334d, 0x7a36016c, 0xdb0a00f6, 0x00000000}},  //   _už_, oštr, _defé,
  { {0x4425018e, 0x23c3028c, 0x9f470161, 0x00000000}},  //   _ôl_, _déjà_, lené_,
  { {0x81e80044, 0x3e4501c5, 0x00000000, 0x00000000}},  //   বাজ_, zētu_,   ,
  { {0x9f470027, 0x13b20044, 0xdb030161, 0x00000000}},  //   nené_, _চায়, _nená,
  { {0xdb011994, 0x628e0253, 0x61eb00ea, 0x00000000}},  //   mblé, _zubo, megl,
  { {0x09c60061, 0x4b250088, 0x61eb0036, 0x00000000}},  //   वल्य, дмов, legl,
  { {0x69dd0d33, 0x68e40905, 0x60cb0058, 0x00000000}},  //   ffse, _spid, lugm,
  { {0x2574009f, 0x29000390, 0x61eb1ef5, 0x00000000}},  //   _júlí_, _pria_, negl,
  { {0x682b050d, 0x645e000b, 0x9f4706b8, 0x00000000}},  //   _süda, yopi, dené_,
  { {0x3e45001e, 0x26d80207, 0x66e60121, 0x00000000}},  //   rētu_, ttro_, мога,
  { {0x645e11e4, 0x68300039, 0x2ba3007d, 0x00000000}},  //   vopi, _rädd, _ख्या,
  { {0x29000129, 0x764d011c, 0x26d800eb, 0x00000000}},  //   _tria_, gnay, rtro_,
  { {0x629c0df0, 0x628e0119, 0x29001175, 0x00000000}},  // [a880] _stro, _subo, _uria_,
  { {0xd7ca007a, 0xdb0810fa, 0xe2a30082, 0x00000000}},  //   _بوده_, ladá, _thứ_,
  { {0x645e1d24, 0x9f4706b8, 0x3e450089, 0x00000000}},  //   ropi, bené_, nēts_,
  { {0x7e692a89, 0x61eb0030, 0x63ae0142, 0x00000000}},  //   jlep, gegl, _webn,
  { {0x645e00e7, 0x7e6905d2, 0x60cb0058, 0x00000000}},  //   popi, dlep, gugm,
  { {0x7e62002b, 0xe3b21298, 0x00000000, 0x00000000}},  //   _skop, _جرح_,   ,
  { {0x629c0030, 0xe7e002fb, 0x61eb003b, 0x00000000}},  //   _utro, ख्या_, begl,
  { {0x44440be3, 0x6489334e, 0x7e690010, 0x00000000}},  //   li_, _užic, glep,
  { {0xdb08049a, 0x01d70d0b, 0x1b1b0044, 0x00000000}},  //   dadá, _توقع_, _ফেলে_,
  { {0x4444334f, 0x9f4701ca, 0xdb0301ca, 0x00000000}},  //   ni_, zené_, _sená,
  { {0xcc8800ad, 0x59f9008b, 0x764d0180, 0x00000000}},  //   _mới_, пеня_, ynay,
  { {0x444409bf, 0x7e691560, 0xdb080010, 0x00000000}},  //   hi_, clep, gadá,
  { {0x69dd000c, 0x9f470161, 0x7e6004be, 0x00000000}},  //   rfse, vené_, momp,
  { {0x44440f68, 0x61eb0046, 0x7e6004cb, 0x00000000}},  //   ji_, zegl, lomp,
  { {0x444409f5, 0x2bf30061, 0x3e450089, 0x00000000}},  //   di_, _असतं_, cēts_,
  { {0x444404f4, 0x66160065, 0x683031f5, 0x00000000}},  //   ei_, gjyk, _räde,
  { {0x798d3350, 0x61eb0026, 0x96010044, 0x00000000}},  // [a890] _igaw, vegl, _একদম_,
  { {0x4444061f, 0x764d0c2c, 0x6830006c, 0x00000000}},  //   gi_, snay, _päde,
  { {0xf1b90363, 0x7a260051, 0x64890006, 0x00000000}},  //   _loše_, _bóth, _džia,
  { {0x44440736, 0x7d02042d, 0x68300039, 0x00000000}},  //   ai_, _oros, _väde,
  { {0x7e6001d6, 0x798d254f, 0x3f8c012d, 0x00000000}},  //   domp, _mgaw, _bgdu_,
  { {0x661d01d6, 0x61eb0059, 0xdb0813f4, 0x00000000}},  //   _hosk, segl, zadá,
  { {0x661d021e, 0x6445036b, 0x2129089f, 0x00000000}},  //   _kosk, mihi, šah_,
  { {0x7d02018e, 0x6445006a, 0x661d021e, 0x00000000}},  //   _bros, lihi, _josk,
  { {0x661d3351, 0x7d0200ab, 0xdfdb005e, 0x00000000}},  //   _mosk, _cros, _мъж_,
  { {0xa2c4001c, 0x7d020016, 0x6445006a, 0x00000000}},  //   ांच्, _dros, nihi,
  { {0x7d02022b, 0x7a6a0745, 0xdb033066, 0x00000000}},  //   _eros, зинг_, _menç,
  { {0x44441077, 0x6445006a, 0xc86900b6, 0x00000000}},  //   zi_, hihi, _הן_,
  { {0x44443352, 0x644512e8, 0xfce501fb, 0x00000000}},  //   yi_, kihi, _чоло,
  { {0x7c281fd8, 0x6e290030, 0x644500e7, 0x00000000}},  //   ckdr, lkeb, jihi,
  { {0xcf920104, 0x66e3003b, 0x661d137e, 0x00000000}},  //   רטל_, лора, _bosk,
  { {0x44443353, 0x661d01ee, 0x62890036, 0x00000000}},  //   wi_, _cosk, _nieo,
  { {0x661d05fd, 0x69d60009, 0xdb0300c4, 0x00000000}},  // [a8a0] _dosk, _icye, _benç,
  { {0x44440006, 0x64450145, 0x00000000, 0x00000000}},  //   ui_, gihi,   ,
  { {0xf2a6025f, 0x6e290190, 0x661d000a, 0x00000000}},  //   хиеп, kkeb, _fosk,
  { {0xcc8800ad, 0x09c70044, 0xa49b00d4, 0x00000000}},  //   _với_, ষ্ঠা, _iròn,
  { {0x47b30055, 0x6445006a, 0xa06a3354, 0x00000000}},  //   _জাতী, bihi, пада_,
  { {0xcc88001d, 0x44442f17, 0xdb03014a, 0x00000000}},  //   _tới_, qi_, _genç,
  { {0xdb0a0030, 0x00000000, 0x00000000, 0x00000000}},  //   _udfø,   ,   ,
  { {0x6fd20164, 0xb87b004a, 0x5fd20061, 0x00000000}},  //   _सावं, ctíf, _सावल,
  { {0x2bd401f5, 0xed5000a1, 0x7e6001a3, 0x00000000}},  //   _दादा, جھا_, romp,
  { {0x224619be, 0x7e600aa0, 0x7d1d3355, 0x00000000}},  //   liok_, somp, ässa,
  { {0x200c005f, 0xaa5926f0, 0x7c2800bb, 0x00000000}},  //   _indi_, дину_, rkdr,
  { {0x7d021014, 0xfe7200a2, 0xf1b9016e, 0x00000000}},  //   _tros, _صدا_, _toše_,
  { {0x661d3356, 0x201e00b0, 0x7d022503, 0x00000000}},  //   _rosk, _koti_, _uros,
  { {0x201e00e7, 0xdb0300f8, 0x661d007f, 0x00000000}},  //   _joti_, _benä, _sosk,
  { {0x661d0387, 0x201e166f, 0xadf4013d, 0x00000000}},  //   _posk, _moti_, _आसान_,
  { {0x201e331a, 0x78ad0a5f, 0x798d00e7, 0x00000000}},  //   _loti_, _twav, _ugaw,
  { {0x644512e8, 0x200c0087, 0x78ad0ea6, 0x00000000}},  // [a8b0] tihi, _ondi_, _uwav,
  { {0x201e0a19, 0xd37b0517, 0x00000000, 0x00000000}},  //   _noti_, пче_,   ,
  { {0x6445011f, 0x661d0065, 0xdb031052, 0x00000000}},  //   rihi, _tosk, _venç,
  { {0x200c023a, 0x6445011c, 0x78720030, 0x00000000}},  //   _andi_, sihi, nævn,
  { {0x25a9170b, 0x68300bfe, 0xa5bb1db2, 0x00000000}},  //   mbal_, _häda, _flór,
  { {0xa5bb0181, 0x2898009b, 0x628900b5, 0x00000000}},  //   _glór, עדון_, _wieo,
  { {0xe4540783, 0x201e0e11, 0x545400ed, 0x00000000}},  //   _скры, _doti_, _сврт,
  { {0x60c4010a, 0x7e910089, 0x682b01a2, 0x00000000}},  //   šima, _jāpi, _südl,
  { {0x6e2904d4, 0x9f473357, 0xec790364, 0x00000000}},  //   rkeb, mení_, мпи_,
  { {0x6b9a001c, 0x9f4701c8, 0x61fb0052, 0x00000000}},  //   gctg, lení_, _haul,
  { {0x68300004, 0xbf151847, 0x61fb0020, 0x00000000}},  //   _näda, _جواب, _kaul,
  { {0x201e008d, 0x61fb04de, 0x9f470142, 0x00000000}},  //   _zoti_, _jaul, není_,
  { {0x25a9003b, 0x29040a82, 0x91ba009b, 0x00000000}},  //   dbal_, íma_, ומרי,
  { {0x6b9a001c, 0x69a20201, 0x61fb3358, 0x00000000}},  //   cctg, _क्री, _laul,
  { {0xdb0307c4, 0x25a901c3, 0x00000000, 0x00000000}},  //   _benå, fbal_,   ,
  { {0x9f4701c8, 0xdb0300b0, 0xcfca0044, 0x00000000}},  //   jení_, _venä, ল্পন,
  { {0x44310ffb, 0x9f470428, 0xf8bf0010, 0x00000000}},  // [a8c0] _blz_, dení_, lyén_,
  { {0x61fb0022, 0xa49b3359, 0x64890006, 0x00000000}},  //   _aaul, _tròn, _džio,
  { {0x201e033b, 0x61fb01a2, 0x64550087, 0x00000000}},  //   _roti_, _baul, _djzi,
  { {0x201e0263, 0xfb1a0049, 0x72290088, 0x00000000}},  //   _soti_, וועמ, нців_,
  { {0x201e0214, 0x61fb335a, 0x22460032, 0x00000000}},  //   _poti_, _daul, riok_,
  { {0x03a301fb, 0x200c0026, 0x61fb0288, 0x00000000}},  //   _виро, _qndi_, _eaul,
  { {0x201e335b, 0x04430088, 0x9f470802, 0x00000000}},  //   _voti_, _терн, bení_,
  { {0x9f470224, 0x61fb009d, 0x69a2006e, 0x00000000}},  //   cení_, _gaul, _क्ली,
  { {0x6b9a001c, 0x201e000d, 0x61e200eb, 0x00000000}},  //   tctg, _toti_, mfol,
  { {0xfa8a001d, 0x200c01a3, 0xe9df0051, 0x00000000}},  //   _mẫu_, _undi_, giún_,
  { {0x61e20009, 0x3a320146, 0x00000000, 0x00000000}},  //   ofol, _blyp_,   ,
  { {0xf2d3007b, 0x61e2138a, 0x6aba335c, 0x00000000}},  //   סער_, nfol, rstf,
  { {0xcc880011, 0x2e3700b3, 0x9f450161, 0x00000000}},  //   _bớt_, _בראש_, _malý_,
  { {0x9f4713c7, 0x36d5026b, 0x683001a2, 0x00000000}},  //   zení_, логр, _päda,
  { {0x25a90027, 0x61e200ea, 0xf1b90091, 0x00000000}},  //   tbal_, kfol, _loša_,
  { {0xe6540088, 0x61e2335d, 0x00000000, 0x00000000}},  //   авсь, jfol,   ,
  { {0x25a9023a, 0x9f4701c8, 0x25a60211, 0x00000000}},  // [a8d0] rbal_, vení_, ñola_,
  { {0x61fb0ebc, 0x25a90129, 0x57f50072, 0x00000000}},  //   _saul, sbal_, _спот,
  { {0x61fb02d5, 0x61e2335e, 0xa3c4013d, 0x00000000}},  //   _paul, ffol, _एयर_,
  { {0x61e2068f, 0xf1b911cb, 0x2c790bf2, 0x00000000}},  //   gfol, _boša_, mède_,
  { {0xdca60054, 0xfa8a0011, 0x2c79335f, 0x00000000}},  //   _دى_, _gẫu_, lède_,
  { {0x9f470802, 0x61fb00e7, 0xf1b901ed, 0x00000000}},  //   sení_, _waul, _doša_,
  { {0x78bd001c, 0x61fb0129, 0x9f470802, 0x00000000}},  //   hssv, _taul, pení_,
  { {0xc6940049, 0x3f9e0022, 0x00000000, 0x00000000}},  //   סאפ_, _eftu_,   ,
  { {0x4bd9008b, 0x3155008b, 0x7a26000c, 0x00000000}},  //   ньня_, _сваё, _mótt,
  { {0x2a6901aa, 0x629500e7, 0x6e950401, 0x00000000}},  //   _akab_, _kuzo, _бижу,
  { {0xcc880011, 0x2bd40204, 0x63b5013e, 0x00000000}},  //   _rớt_, _दारा, _mezn,
  { {0xe9df002a, 0x7a26000c, 0xa49b00d4, 0x00000000}},  //   siún_, _nótt, _pròl,
  { {0xfd100380, 0xec6e00e2, 0x78bd01e5, 0x00000000}},  //   _وجه_, _гп_, gssv,
  { {0x63b50209, 0xdb030b32, 0x7a263360, 0x00000000}},  //   _nezn, _menú, _rótu,
  { {0xae1701f5, 0xe9df000c, 0xcc880082, 0x00000000}},  //   थापन_, gnús_, _vớt_,
  { {0xe643007e, 0x67210894, 0x00000000, 0x00000000}},  //   бесп, älja,   ,
  { {0x6295002d, 0x7a26000c, 0x69c43361, 0x00000000}},  // [a8e0] _auzo, _dótt, _idie,
  { {0x63b50107, 0x78a400ca, 0x00000000, 0x00000000}},  //   _cezn, _itiv,   ,
  { {0x61e200ea, 0x2c79009d, 0x316d009d, 0x00000000}},  //   tfol, cède_, _ayez_,
  { {0x78a400ea, 0x316d0026, 0x7afc08c8, 0x00000000}},  //   _ktiv, _byez_, ærti,
  { {0x61e2010f, 0x7d1d01a2, 0x00000000, 0x00000000}},  //   rfol, ässl,   ,
  { {0x61e20190, 0xdb03153d, 0x60c4016c, 0x00000000}},  //   sfol, _denú, šimo,
  { {0x69c40197, 0x61e20023, 0x9e140088, 0x00000000}},  //   _odie, pfol, идкі,
  { {0x69c40065, 0x63b5150d, 0xf1b9016c, 0x00000000}},  //   _ndie, _zezn, _toša_,
  { {0x2fd60054, 0xb87b00c4, 0x8fa601fc, 0x00000000}},  //   _متاح, ntíc, _базе,
  { {0x69c4022b, 0x09bf0164, 0x5ec30044, 0x00000000}},  //   _adie, ्ल्य, _শহরে,
  { {0x78a402d5, 0x6f930025, 0x69c4002b, 0x00000000}},  //   _ativ, _المض, _bdie,
  { {0xa2cc03d7, 0x00000000, 0x00000000, 0x00000000}},  //   _हिन्,   ,   ,
  { {0xd90f00a2, 0x9f470161, 0x78a426b3, 0x00000000}},  //   سید_, mená_, _ctiv,
  { {0x9f4701ca, 0x62820145, 0x7a26000c, 0x00000000}},  //   lená_, hmoo, _sótt,
  { {0x63b50253, 0x682b01a2, 0xae09013d, 0x00000000}},  //   _rezn, _jüdi, वाचन_,
  { {0x63b50aaa, 0x682b006b, 0xadf9013d, 0x00000000}},  //   _sezn, _müdi, ्ययन_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [a8f0]   ,   ,   ,
  { {0x68ed011c, 0xb87b0b32, 0xdb031052, 0x00000000}},  //   _ipad, stíb, _renú,
  { {0xe2980088, 0xf8bf009d, 0x64890006, 0x00000000}},  //   гає_, lsé_, _užim,
  { {0xa4d501fb, 0xdb031b0f, 0x6e22031c, 0x00000000}},  //   _комі, _penú, _noob,
  { {0x90e4023c, 0xf8bf12a3, 0x629a00f4, 0x00000000}},  //   مسون, nsé_, _éton,
  { {0x41260057, 0x1aeb0044, 0xe3cc0044, 0x00000000}},  //   рошо_, টিতে_, র্বব,
  { {0x6e223362, 0x44230061, 0x59c50061, 0x00000000}},  //   _boob, _ioj_, वणार,
  { {0x68ed0036, 0x6e220197, 0x44230039, 0x00000000}},  //   _opad, _coob, _hoj_,
  { {0x61e9045d, 0x9f450026, 0x6e220253, 0x00000000}},  //   _ibel, _calò_, _doob,
  { {0x44230119, 0x3ce502d2, 0x1c450f71, 0x00000000}},  //   _joj_, _कहीं_, рном,
  { {0x44230c06, 0x9f450047, 0x6e220515, 0x00000000}},  //   _moj_, _való_, _foob,
  { {0xa2d602fb, 0x9f450026, 0x61e901f3, 0x00000000}},  //   मंत्, _falò_, _jbel,
  { {0x61e9000b, 0xdb013363, 0x67210039, 0x00000000}},  //   _mbel, taló, äljn,
  { {0x80cd0309, 0xc0520049, 0x5d3a00b3, 0x00000000}},  //   _सिने, ַזן_, _בתנא,
  { {0x61e9003b, 0xbb420088, 0x7c230051, 0x00000000}},  //   _obel, _мешк, _ionr,
  { {0x7c2329a6, 0x656f1700, 0x69c40ec0, 0x00000000}},  //   _honr, _bych, _udie,
  { {0x656f0016, 0x7c2320de, 0x44230b41, 0x00000000}},  // [a900] _cych, _konr, _boj_,
  { {0x61e9027b, 0x656f0e14, 0x9f4701ca, 0x00000000}},  //   _abel, _dych, zená_,
  { {0x7c232336, 0x44233364, 0xb87b3365, 0x00000000}},  //   _monr, _doj_, stíc,
  { {0xcc88001d, 0x91e6026b, 0x2cbf3366, 0x00000000}},  //   _lớp_, роде, ksud_,
  { {0x62820168, 0x6fb60025, 0x6f080161, 0x00000000}},  //   rmoo, لمشا, _srdc,
  { {0x3ec60057, 0x62820abf, 0x61e90190, 0x00000000}},  //   асиб, smoo, _ebel,
  { {0xb87b008e, 0x6e220235, 0x9f450026, 0x00000000}},  //   ntía, _poob, _salò_,
  { {0x81e40055, 0x25a03367, 0x2cbf0066, 0x00000000}},  //   _ভোর_, ncil_, fsud_,
  { {0x10a309f1, 0x80a6035b, 0x7c2300f6, 0x00000000}},  //   _митн, _ضمان, _bonr,
  { {0x7c230051, 0x00000000, 0x00000000, 0x00000000}},  //   _conr,   ,   ,
  { {0x68ed0036, 0xdfcf0025, 0x29050089, 0x00000000}},  //   _spad, _زين_, ālam_,
  { {0xade2006e, 0xdb012964, 0x6c3402fd, 0x00000000}},  //   क्शन_, talò, _گفتا,
  { {0xf99f0129, 0x984b005e, 0xf8bf009d, 0x00000000}},  //   rcè_, вява_, usé_,
  { {0x656f01c8, 0xf8bf1a0f, 0x9f5e0065, 0x00000000}},  //   _rych, rsé_, _natë_,
  { {0xf8bf257b, 0x87042e54, 0x442301ee, 0x00000000}},  //   ssé_, ояте, _roj_,
  { {0x7a360006, 0x00000000, 0x00000000, 0x00000000}},  //   kšty,   ,   ,
  { {0x68ed2145, 0xdb1a0065, 0xd498003b, 0x00000000}},  // [a910] _upad, katë, арх_,
  { {0x656f01ca, 0x7c3a0082, 0x601d000a, 0x00000000}},  //   _vych, nhtr, _fèmy,
  { {0x656f0036, 0x9f5e0065, 0xd7dc013d, 0x00000000}},  //   _wych, _datë_, _बातच,
  { {0x44230036, 0xed590ce4, 0x656f0871, 0x00000000}},  //   _woj_, laže_, _tych,
  { {0x44232ec8, 0x181a0123, 0x91050242, 0x00000000}},  //   _toj_, _شریک_, спле,
  { {0x73c50025, 0xdb1a0023, 0x3dc60146, 0x00000000}},  //   _ديسم, gatë, _adow_,
  { {0xf8380104, 0x7c2306d2, 0x24990145, 0x00000000}},  //   שנות_, _ronr, _husm_,
  { {0x7c233368, 0xa3b800a1, 0x61e90020, 0x00000000}},  //   _sonr, _ماہر_, _ubel,
  { {0xdd91026c, 0x9f5e0263, 0xeb990517, 0x00000000}},  //   _ہوا_, _latè_, лип_,
  { {0x4ee70c50, 0x6a760b33, 0x2d9f0133, 0x00000000}},  //   _відз, táfo, scue_,
  { {0xf1b901ee, 0x7ded007f, 0x00000000, 0x00000000}},  //   _keš_, _pėsč,   ,
  { {0x8d950025, 0xf1b91a7d, 0x00000000, 0x00000000}},  //   _الإش, _ješ_,   ,
  { {0xbca5023c, 0x7c230022, 0x443a01cf, 0x00000000}},  //   _امتي, _tonr, yhp_,
  { {0x7c3a0bf5, 0x07a300d7, 0xdb0a0210, 0x00000000}},  //   chtr, зарн, _befä,
  { {0xfb87007e, 0xe73702b0, 0xf1d8013d, 0x00000000}},  //   _тыдн, бер_, _डालन,
  { {0xe9da0ad9, 0xf1b9016e, 0xdb1a0065, 0x00000000}},  //   _ски_, _neš_, zatë,
  { {0xe57a0517, 0x14c80014, 0x25a03369, 0x00000000}},  // [a920] уза_, شهای_, rcil_,
  { {0x8ccf03d7, 0x09b00044, 0x9f470129, 0x00000000}},  //   _दिनो, _কাটা, cenç_,
  { {0xfdf90201, 0xdb0a010f, 0x764d04be, 0x00000000}},  //   ्यास_, _gefä, biay,
  { {0xd5b90057, 0xd1ba0025, 0xb87b0142, 0x00000000}},  //   _всё_, اااا_, ntín,
  { {0x51181969, 0x660408a9, 0x69db0049, 0x00000000}},  //   ролю_, mdik, אַוו,
  { {0x64a30264, 0x33d501fb, 0xdfcf0b59, 0x00000000}},  //   _хара, _міст, فيه_,
  { {0x81c20055, 0xdb1a0065, 0x2ca605d5, 0x00000000}},  //   ্ভব_, ratë, _stod_,
  { {0x6604336a, 0x91e309bb, 0x6e3b0058, 0x00000000}},  //   ndik, _носе, ghub,
  { {0x09df0044, 0x6da3025f, 0xdb1a336b, 0x00000000}},  //   _বোঝা, чиња, maté,
  { {0xdb1a336c, 0x60c20da4, 0x26c507fd, 0x00000000}},  //   laté, msom, álok_,
  { {0x6e960054, 0x60c200eb, 0x7d0b00c7, 0x00000000}},  //   _الصا, lsom, _ergs,
  { {0xc333019b, 0x7c3a008d, 0x443800e5, 0x00000000}},  //   פור_, shtr, _llr_,
  { {0x9e650025, 0x60c200f4, 0x63be023a, 0x00000000}},  //   _بالن, nsom, kapn,
  { {0x9f5e0026, 0x60c20908, 0x6d5c01a2, 0x00000000}},  //   _patè_, isom, ßrau,
  { {0x9f47336d, 0xed59016e, 0x63be21e6, 0x00000000}},  //   renç_, raže_, dapn,
  { {0x5b57012f, 0x44380022, 0x60c2336e, 0x00000000}},  //   _לשון_, _alr_, ksom,
  { {0x5fc8006e, 0x6fc80061, 0x44380145, 0x00000000}},  // [a930] रणाल, रणां, _blr_,
  { {0x7bda336f, 0x60c20039, 0x44381651, 0x00000000}},  //   ngtu, dsom, _clr_,
  { {0x64890626, 0x65950930, 0xf1b900ca, 0x00000000}},  //   _oživ, _ману, _peš_,
  { {0x9f5e000a, 0x44380203, 0x00000000, 0x00000000}},  //   _gaté_, _elr_,   ,
  { {0xf1b90059, 0x60c20239, 0xd14b0014, 0x00000000}},  //   _veš_, gsom, دشان_,
  { {0xc6010055, 0x9ea90256, 0x1ef90025, 0x00000000}},  //   _একটা_, авка_, لعبة_,
  { {0x62350057, 0xd24e00a1, 0x6e3b00e7, 0x00000000}},  //   _деву, رچہ_, thub,
  { {0x82370070, 0x7bda01b5, 0x4e293370, 0x00000000}},  //   _ارسا, egtu, роин_,
  { {0x3c19008b, 0x7e690250, 0x6e3b04cb, 0x00000000}},  //   аўня_, roep, rhub,
  { {0x6e3b1a0b, 0x9f4700b0, 0x3e7a0023, 0x00000000}},  //   shub, tenä_, rëta_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa2cc006e, 0xc7a900a0, 0x00000000, 0x00000000}},  //   _हिस्, _יב_,   ,
  { {0xb87b0779, 0x9f4700b0, 0xdb03014a, 0x00000000}},  //   rtín, senä_, _henü,
  { {0xdb1a0010, 0x2cad00ab, 0x8c230044, 0x00000000}},  //   zaté, mped_, যোজন_,
  { {0x7d09006c, 0x96950242, 0x2cad00ab, 0x00000000}},  //   lves, зруш, lped_,
  { {0x443800ca, 0x27ed0091, 0x85050309, 0x00000000}},  //   _slr_, đena_, रिंट_,
  { {0x7d09002b, 0x142600ed, 0x443800fa, 0x00000000}},  // [a940] nves, одам, _plr_,
  { {0x2aed02d2, 0x66040093, 0xf77200a6, 0x00000000}},  //   _जहाँ_, sdik, _ياد_,
  { {0x6d400173, 0x66043371, 0x63be0145, 0x00000000}},  //   zzma, pdik, rapn,
  { {0x26d80ba0, 0xe4da00a2, 0x60c200b0, 0x00000000}},  //   muro_, _پوست_, tsom,
  { {0xdb1a3372, 0x60c20006, 0x26d80016, 0x00000000}},  //   raté, usom, luro_,
  { {0x60c201bf, 0x27f80a35, 0x7d093278, 0x00000000}},  //   rsom, nern_, dves,
  { {0x26d8011c, 0x63bc0035, 0x00000000, 0x00000000}},  //   nuro_, _iern,   ,
  { {0x27f81153, 0x60c2068f, 0x60cd320a, 0x00000000}},  //   hern_, psom, šama,
  { {0x629c082a, 0x27f803a9, 0x26d83207, 0x00000000}},  //   _huro, kern_, huro_,
  { {0x629c0ba5, 0x27f80030, 0x26d824e7, 0x00000000}},  //   _kuro, jern_, kuro_,
  { {0x29003373, 0x629c0181, 0x27f83374, 0x00000000}},  //   _asia_, _juro, dern_,
  { {0x64890224, 0x26d80016, 0x63bc010f, 0x00000000}},  //   _uživ, duro_, _lern,
  { {0x32040832, 0x27f8010f, 0x8b0700b9, 0x00000000}},  //   _mamy_, fern_, _poří,
  { {0xdb183375, 0xb87b0051, 0x27f803a9, 0x00000000}},  //   _levé, rtío, gern_,
  { {0x26d81a16, 0xd5bb013b, 0x629c010a, 0x00000000}},  //   guro_, иса_, _nuro,
  { {0x26cd0091, 0xdb180010, 0x8b3b009b, 0x00000000}},  //   čeo_, _nevé, _כתוצ,
  { {0x63bc0127, 0x629c00f4, 0xdb032bc9, 0x00000000}},  // [a950] _bern, _auro, _fenó,
  { {0x629c027b, 0xf1d803d7, 0x63bc001a, 0x00000000}},  //   _buro, _डाउन, _cern,
  { {0x63bc028c, 0x26d82682, 0xdb081a43, 0x00000000}},  //   _dern, curo_, madó,
  { {0x629c21ad, 0x7d0923a1, 0x320400e5, 0x00000000}},  //   _duro, yves, _camy_,
  { {0x361a019b, 0xddc80046, 0x62980325, 0x00000000}},  //   _הורד, łośc, ívor,
  { {0x63bc3376, 0x629c0207, 0xdb083377, 0x00000000}},  //   _gern, _furo, nadó,
  { {0x629c3378, 0xa49b00d4, 0xf1b904eb, 0x00000000}},  //   _guro, _eròt, _loši_,
  { {0xf1bf0359, 0x63bc0032, 0x27f801a2, 0x00000000}},  //   _þá_, _zern, zern_,
  { {0x27f8010f, 0x225f0022, 0x26d800ca, 0x00000000}},  //   yern_, _ijuk_, zuro_,
  { {0x69dd224a, 0x7d092a6b, 0x63a501a2, 0x00000000}},  //   egse, rves, nchn,
  { {0x63a5010f, 0x7d09003b, 0xcb69017f, 0x00000000}},  //   ichn, sves, сане_,
  { {0x2005000b, 0xdb03027b, 0x2cad00ab, 0x00000000}},  //   _hali_, _senó, pped_,
  { {0x27f8001f, 0x200521c4, 0xdb080051, 0x00000000}},  //   tern_, _kali_, fadó,
  { {0xfbd302fd, 0x200701ee, 0x27f8010f, 0x00000000}},  //   _آتش_, ndni_, uern_,
  { {0xe737008b, 0x7bc10004, 0x63bc0521, 0x00000000}},  //   пер_, malu, _rern,
  { {0x7bc10149, 0x629a00f4, 0x26d82b63, 0x00000000}},  //   lalu, _étoi, ruro_,
  { {0x63bc020c, 0x29000169, 0xdb180efe, 0x00000000}},  // [a960] _pern, _usia_, _revé,
  { {0x7bc1163a, 0x629c1a16, 0x32040062, 0x00000000}},  //   nalu, _puro, _samy_,
  { {0x682b006c, 0xe7b7009b, 0x179b0097, 0x00000000}},  //   _tüdr, _מהיר_, _לייב,
  { {0x7bc1011c, 0xd36f0380, 0x63bc010f, 0x00000000}},  //   halu, دهم_, _wern,
  { {0x20050574, 0xe572004b, 0x63bc020c, 0x00000000}},  //   _bali_, _سطح_, _tern,
  { {0x660608a1, 0x2005008e, 0x7bc106aa, 0x00000000}},  //   _hakk, _cali_, jalu,
  { {0x5f9302a8, 0x7bc10211, 0x644e011c, 0x00000000}},  //   ништ, dalu, _imbi,
  { {0x225a0054, 0x6aaa0044, 0x442a01a2, 0x00000000}},  //   _الرد_, _কিলো, _hob_,
  { {0x6606023b, 0x442a01aa, 0x20050091, 0x00000000}},  //   _makk, _kob_, _fali_,
  { {0x2005010a, 0x648901ca, 0x09c50183, 0x00000000}},  //   _gali_, _užit, वण्य,
  { {0xed591032, 0x2bdd0309, 0xe9f903e8, 0x00000000}},  //   raža_, _मारा, онні_,
  { {0x660623b5, 0x0e9b009b, 0x1e860783, 0x00000000}},  //   _nakk, _השאל, _элем,
  { {0x58871036, 0x9f5e0129, 0x20053379, 0x00000000}},  //   зыва, _matí_, _yali_,
  { {0x27ed0091, 0x7bc10035, 0x7d02337a, 0x00000000}},  //   đeno_, calu, _isos,
  { {0x12d70044, 0x7dd60276, 0x00000000, 0x00000000}},  //   _সন্দ, cüsü,   ,
  { {0x442a0bc7, 0xf4a80044, 0x7c2a005b, 0x00000000}},  //   _aob_, _ওয়েব, _hofr,
  { {0x81c20055, 0x6a7d0845, 0x7ae8001c, 0x00000000}},  // [a970] ংলা_, léfo, ltdt,
  { {0x7c2a00d4, 0x225f0039, 0x224d337b, 0x00000000}},  //   _jofr, _sjuk_, _smek_,
  { {0x63a5018e, 0x442a13f4, 0x66060066, 0x00000000}},  //   rchn, _dob_, _fakk,
  { {0x63a5010f, 0xe9df337c, 0x20050c01, 0x00000000}},  //   schn, ngú_, _sali_,
  { {0x20050091, 0x44e60559, 0xfbdd0061, 0x00000000}},  //   _pali_, cô_, _मालम,
  { {0x7c2a1566, 0x660600bb, 0x6a761f1e, 0x00000000}},  //   _nofr, _zakk, ráfi,
  { {0x7bc124b7, 0x7d02134e, 0x2005006c, 0x00000000}},  //   valu, _asos, _vali_,
  { {0x2005023a, 0x2d9905b7, 0x442a00ca, 0x00000000}},  //   _wali_, øse_, _zob_,
  { {0x7bc1120d, 0x2005337d, 0x4c8500ed, 0x00000000}},  //   talu, _tali_, млив,
  { {0x7c2a018e, 0x69cd0016, 0xcac9007c, 0x00000000}},  //   _cofr, _adae, огое_,
  { {0x37e308b7, 0x7bc10c0e, 0x60c40006, 0x00000000}},  //   য়ার, ralu, šimt,
  { {0x7bc1006a, 0xdb1a00c4, 0x00000000, 0x00000000}},  //   salu, catí,   ,
  { {0x7bc11c68, 0xec6e003b, 0x6606182c, 0x00000000}},  //   palu, _ап_, _rakk,
  { {0x7c2a018e, 0x66060056, 0x7bc7000c, 0x00000000}},  //   _gofr, _sakk, ðjud,
  { {0x442a2ea8, 0x66060004, 0xe73a007c, 0x00000000}},  //   _rob_, _pakk, цев_,
  { {0x442a0181, 0xb9040044, 0x98a200b4, 0x00000000}},  //   _sob_, _নন_, zykę_,
  { {0x442a018e, 0xa49b00f6, 0x0903007e, 0x00000000}},  // [a980] _pob_, _bròq, _апын,
  { {0x660600c7, 0x6e2b0b38, 0xa49b00d4, 0x00000000}},  //   _wakk, _logb, _pròr,
  { {0x660608f8, 0x60c9012d, 0x1aeb0044, 0x00000000}},  //   _takk, _avem, টিকে_,
  { {0x7df9007d, 0x442a00d9, 0x47d30044, 0x00000000}},  //   ्योग_, _wob_, দ্দী,
  { {0x442a01d6, 0x10a300ed, 0x98a200b4, 0x00000000}},  //   _tob_, вичн, tykę_,
  { {0x60c90059, 0x442a0022, 0x00000000, 0x00000000}},  //   _dvem, _uob_,   ,
  { {0xd37206f1, 0xdb1a337e, 0xe80f03d7, 0x00000000}},  //   _شهر_, tatí, ायता_,
  { {0x7c2a0181, 0x2498010e, 0x00000000, 0x00000000}},  //   _sofr, _hirm_,   ,
  { {0xab5c0089, 0xed5000a1, 0x6e2b00d9, 0x00000000}},  //   daļa, دھا_, _dogb,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x29120093, 0xdb1a073f, 0x03d7009b, 0x00000000}},  //   _arya_, patí, ווים_,
  { {0x629a009d, 0x00000000, 0x00000000, 0x00000000}},  //   _étou,   ,   ,
  { {0x3e6b026c, 0xf8ae02fd, 0xcd360257, 0x00000000}},  //   _بجلی_, یکی_, _تراب,
  { {0xdc5600a1, 0xe9df0051, 0x00000000, 0x00000000}},  //   _کرچک, giúr_,   ,
  { {0x7641010a, 0xfa8a0082, 0x291200e0, 0x00000000}},  //   ūlym, _lẫy_, _erya_,
  { {0x6a8400ed, 0x24980051, 0x7d0d00d0, 0x00000000}},  //   _илја, _airm_, _šasi,
  { {0x6a76000c, 0xdb1a00c4, 0x29050089, 0x00000000}},  // [a990] gáfu, batã, ālas_,
  { {0xd37b0931, 0x00000000, 0x00000000, 0x00000000}},  //   оче_,   ,   ,
  { {0x60c90119, 0x00000000, 0x00000000, 0x00000000}},  //   _svem,   ,   ,
  { {0xdb1801dc, 0xfa8a0082, 0xd049013f, 0x00000000}},  //   _neví, _bẫy_, ənəc,
  { {0x24980652, 0x25d6009b, 0xe4a402b3, 0x00000000}},  //   _firm_, _אורן_, _арсо,
  { {0x7516007b, 0x9f050025, 0xf07500a1, 0x00000000}},  //   _אַלע_, فوتو, ریاں_,
  { {0x20d5009f, 0x9f5e00f6, 0x00000000, 0x00000000}},  //   _búið_, _catà_,   ,
  { {0xb87b0181, 0xfde6005e, 0x00000000, 0x00000000}},  //   luíd, едък_,   ,
  { {0xdb1804bb, 0x00000000, 0x00000000, 0x00000000}},  //   _deví,   ,   ,
  { {0x9989050f, 0x4b25142c, 0x51840139, 0x00000000}},  //   _blaž_, емов, _руса,
  { {0xeaae026c, 0xab5c0089, 0x00000000, 0x00000000}},  //   یٹی_, taļa,   ,
  { {0xade90014, 0xa96a003b, 0x00000000, 0x00000000}},  //   _رفتم_, зима_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe3d50044, 0x7e7b044e, 0x68300039, 0x00000000}},  //   স্তব, llup, _räds,
  { {0x96660098, 0xcc3a0049, 0x186700c0, 0x00000000}},  //   екве, _מעסט, хари_,
  { {0xdb03010f, 0xa49b0129, 0x7e7b0058, 0x00000000}},  //   _benö, _pròp, nlup,
  { {0x69c600b5, 0x2c140061, 0xdb1a0232, 0x00000000}},  // [a9a0] make, _थोडं_, matá,
  { {0x69c6022b, 0xdb1a0010, 0xfa8a0082, 0x00000000}},  //   lake, latá, _rẫy_,
  { {0xe29a008b, 0x67350036, 0x6aab0035, 0x00000000}},  //   чае_, cyzj, _înfă,
  { {0xe646004c, 0x25a9031e, 0x69c6002d, 0x00000000}},  //   _чемп, ccal_, nake,
  { {0x7656005f, 0xb87b0181, 0xe61f0011, 0x00000000}},  //   miyy, buíd, _khôn_,
  { {0x7656005f, 0x69c600b5, 0x38a60016, 0x00000000}},  //   liyy, hake, _môr_,
  { {0x44440195, 0x69c60007, 0xd9e60061, 0x00000000}},  //   mh_, kake, _काढत_,
  { {0x7656005f, 0x44440129, 0x69c60142, 0x00000000}},  //   niyy, lh_, jake,
  { {0x40a8026c, 0x44441ebf, 0x69c6022b, 0x00000000}},  //   _آخری_, oh_, dake,
  { {0x444400ad, 0x7656005f, 0x61e200ca, 0x00000000}},  //   nh_, hiyy, lgol,
  { {0x3fc9007a, 0x444414c3, 0x764400e0, 0x00000000}},  //   _آگهی_, ih_, khiy,
  { {0xb5fb0047, 0x61e2337f, 0xdb1a0047, 0x00000000}},  //   _aján, ngol, gatá,
  { {0x7656005f, 0x76440d92, 0x38a60016, 0x00000000}},  //   diyy, dhiy, _côr_,
  { {0x2c1603d7, 0x4444002b, 0x79840036, 0x00000000}},  //   ताओं_, jh_, _dziw,
  { {0x44440195, 0x69c63380, 0xb87b2b90, 0x00000000}},  //   dh_, bake, ktív,
  { {0x4444002b, 0xd0090055, 0xb8f70044, 0x00000000}},  //   eh_, লায়_, _সহ_,
  { {0x25a90129, 0xb87b0181, 0x68300039, 0x00000000}},  // [a9b0] rcal_, tuíd, _vädr,
  { {0x44440531, 0x7c3a2635, 0x2c7901aa, 0x00000000}},  //   gh_, nktr, tèdi_,
  { {0xb87b00c4, 0x7656006b, 0xa3e2007d, 0x00000000}},  //   ruíd, biyy, _धार_,
  { {0x44440127, 0x76443381, 0xd6d80088, 0x00000000}},  //   ah_, chiy, _ять_,
  { {0x44440195, 0x661d3382, 0x660d005d, 0x00000000}},  //   bh_, _insk, mdak,
  { {0x44440a48, 0x69c6022b, 0x660d0d49, 0x00000000}},  //   ch_, zake, ldak,
  { {0xd9d90055, 0xe822006e, 0x69c60145, 0x00000000}},  //   ধ্যম, माता_, yake,
  { {0x29020036, 0x9f473383, 0x69c63384, 0x00000000}},  //   ywka_, menü_, xake,
  { {0x7e7b003f, 0x69c60ac2, 0x660d0f45, 0x00000000}},  //   rlup, vake, idak,
  { {0x7656005f, 0x6457167b, 0x69c60d65, 0x00000000}},  //   ziyy, nixi, wake,
  { {0xdb1a0047, 0x2fc718a8, 0x69c61646, 0x00000000}},  //   tatá, mang_, take,
  { {0x2fc71ccf, 0x44440065, 0x3eaa0161, 0x00000000}},  //   lang_, zh_, žité_,
  { {0x1d0905a7, 0x7656005f, 0x69c60315, 0x00000000}},  //   _цели_, viyy, rake,
  { {0x2fc71463, 0x6d45005f, 0x69c601c9, 0x00000000}},  //   nang_, _əhal, sake,
  { {0x69c600b0, 0x61e20203, 0x7bc300e5, 0x00000000}},  //   pake, ygol, _ienu,
  { {0x2fc71312, 0x05ac0061, 0xadf9007d, 0x00000000}},  //   hang_, टुंब, ्यटन_,
  { {0x444402f1, 0x7656005f, 0x2fc7317d, 0x00000000}},  // [a9c0] th_, riyy, kang_,
  { {0xb5fb009f, 0x661d3385, 0x7656006b, 0x00000000}},  //   _hjál, _ensk, siyy,
  { {0x7bc30149, 0x2fc7020c, 0x444401e5, 0x00000000}},  //   _menu, dang_, rh_,
  { {0x78a4003c, 0x62890051, 0xb87b00c4, 0x00000000}},  //   _kuiv, _cheo, cuíb,
  { {0x2fc7010f, 0x61e204cb, 0x69c4006c, 0x00000000}},  //   fang_, rgol, _meie,
  { {0x2fc7006a, 0x69c40343, 0x7bc30006, 0x00000000}},  //   gang_, _leie, _nenu,
  { {0x2d800dec, 0x9f47008e, 0xb87b008e, 0x00000000}},  //   _šie_, denó_, quíe,
  { {0x6289094e, 0x69c4001e, 0x27ed0091, 0x00000000}},  //   _gheo, _neie, đeni_,
  { {0x2fc7006a, 0x7bc3001f, 0xa0a60069, 0x00000000}},  //   bang_, _benu, _разд,
  { {0x2fc70169, 0xdb1a014a, 0x7bc309e3, 0x00000000}},  //   cang_, natç, _cenu,
  { {0x201e0f68, 0x7bc30325, 0x7aea0061, 0x00000000}},  //   _inti_, _denu, _qqft,
  { {0x200c000b, 0x7c3a00eb, 0xdb1a0276, 0x00000000}},  //   _hadi_, sktr, hatç,
  { {0xe80f001c, 0x6a7d27de, 0x78a40b50, 0x00000000}},  //   ायला_, néfi, _cuiv,
  { {0x200c06a7, 0xd7f8005e, 0x7bc33386, 0x00000000}},  //   _jadi_, кус_, _genu,
  { {0x7bc816c3, 0x69c43387, 0x200c01aa, 0x00000000}},  //   madu, _feie, _madi_,
  { {0xb0d20316, 0xf64401fb, 0xb7e30044, 0x00000000}},  //   _सिंग, ахун, য়েট,
  { {0x2fc721fb, 0x6289018e, 0x660d014a, 0x00000000}},  // [a9d0] yang_, _rheo, rdak,
  { {0x6289002a, 0x200c2755, 0x7bc80d49, 0x00000000}},  //   _sheo, _nadi_, nadu,
  { {0x64573388, 0x2fc700c7, 0x78a400bb, 0x00000000}},  //   rixi, vang_, _zuiv,
  { {0x2fc721fb, 0x7bc83389, 0x661d1c79, 0x00000000}},  //   wang_, hadu, _unsk,
  { {0x2fc72544, 0x7bc8338a, 0xb87b338b, 0x00000000}},  //   tang_, kadu, btít,
  { {0x7bc8006c, 0xab5c0089, 0x200c1ca9, 0x00000000}},  //   jadu, taļl, _cadi_,
  { {0x2fc71451, 0x7bc3106f, 0x628900ab, 0x00000000}},  //   rang_, _renu, _theo,
  { {0xc332007b, 0x2fc71577, 0x6d49022b, 0x00000000}},  //   _פון_, sang_, tzea,
  { {0x2fc72940, 0x7bc3020c, 0x4431338c, 0x00000000}},  //   pang_, _penu, _koz_,
  { {0xb5fb009f, 0x69c404b2, 0x200c0089, 0x00000000}},  //   _sjál, _seie, _gadi_,
  { {0x78a4028c, 0x3ced338d, 0x29090146, 0x00000000}},  //   _suiv, stev_, _asaa_,
  { {0x2fc50039, 0x8c43006b, 0xcf5600b3, 0x00000000}},  //   _helg_, _əşya, _גבעת_,
  { {0x7bc31017, 0x7bc80d88, 0xfe7001f7, 0x00000000}},  //   _tenu, badu, _بدل_,
  { {0x6cd20084, 0x7bc80207, 0x69c40007, 0x00000000}},  //   _اقوا, cadu, _weie,
  { {0x61e9338e, 0x461a007e, 0x69c4338f, 0x00000000}},  //   _ocel, нцаў_, _teie,
  { {0x7ae1121e, 0x3ea5000d, 0xdb180030, 0x00000000}},  //   mult, _mult_, _bevæ,
  { {0xdb0a009f, 0x3a201c39, 0x448a1020, 0x00000000}},  // [a9e0] _hefð, _inip_, ебан_,
  { {0x61e9000d, 0x657d0065, 0x480601ff, 0x00000000}},  //   _acel, _dysh, _спов,
  { {0x200c0119, 0xddc91279, 0x7ae10b90, 0x00000000}},  //   _radi_, dlež, nult,
  { {0xb87b01ca, 0x2fc50087, 0x64550095, 0x00000000}},  //   stít, _aelg_, _emzi,
  { {0x200c04cb, 0x7ae1010f, 0x44310181, 0x00000000}},  //   _padi_, hult, _foz_,
  { {0x3ea50168, 0x648b00c4, 0x53a3007e, 0x00000000}},  //   _bult_, güid, _гарб,
  { {0xa3e90183, 0x7bc80006, 0x7ae108c8, 0x00000000}},  //   _यात_, vadu, jult,
  { {0x7ae10ec6, 0x7bc7000c, 0x9f470026, 0x00000000}},  //   dult, ðjun, tenò_,
  { {0x5166008b, 0x7bc80907, 0x2167012b, 0x00000000}},  //   _сваб, tadu, _бити_,
  { {0x61e900b9, 0x629800b9, 0x30760920, 0x00000000}},  //   _zcel, ůvod, _субс,
  { {0x7bc8309d, 0x450a0044, 0x3ea504d3, 0x00000000}},  //   radu, রমিক_, _gult_,
  { {0x6da6157b, 0x00000000, 0x00000000, 0x00000000}},  //   _сида,   ,   ,
  { {0xd7fb02d3, 0x3ea500b5, 0x7bc8008a, 0x00000000}},  //   нув_, _zult_, padu,
  { {0xb5fb01ca, 0xe7e30055, 0x7ae13390, 0x00000000}},  //   _ukáz, য়্য, bult,
  { {0x81dc0055, 0x44310035, 0xb87b008e, 0x00000000}},  //   ত্য_, _roz_, guía,
  { {0x29090058, 0x44310276, 0x35b50780, 0x00000000}},  //   _tsaa_, _soz_, рбар,
  { {0x54550256, 0xa3e9062e, 0x3dc60487, 0x00000000}},  // [a9f0] ават, _याद_, _meow_,
  { {0x61e93391, 0xb87b3392, 0xa3d50088, 0x00000000}},  //   _scel, dríg, рожч,
  { {0x44310489, 0x61e901a8, 0x657d0007, 0x00000000}},  //   _voz_, _pcel, _wysh,
  { {0xb6ba009b, 0x4431214e, 0x27ed0091, 0x00000000}},  //   _שצרי, _woz_, đenu_,
  { {0x3ea53393, 0x4431026d, 0x00000000, 0x00000000}},  //   _sult_, _toz_,   ,
  { {0xdb1800b0, 0xc4f60049, 0x645501a2, 0x00000000}},  //   _kevä, _דזשי_, _umzi,
  { {0x2fc50292, 0x44ef014a, 0x27e701e5, 0x00000000}},  //   _velg_, lü_, _önnu_,
  { {0xa2a20164, 0x81dc0044, 0x660f00ab, 0x00000000}},  //   गदर्, ত্ব_, _jack,
  { {0x7ae10061, 0x1c450cee, 0x2d993394, 0x00000000}},  //   wult, иним, äse_,
  { {0x1c1f03d7, 0x2a69006c, 0x3a201c7e, 0x00000000}},  //   बाइल_, _ajab_, _snip_,
  { {0xcb6900c0, 0xff530318, 0xda210061, 0x00000000}},  //   тане_, _اخذ_, यांत_,
  { {0x660f0002, 0x7ae13395, 0x00000000, 0x00000000}},  //   _nack, rult,   ,
  { {0xfe700137, 0xe8220309, 0x2a690173, 0x00000000}},  //   _عدم_, माला_, _djab_,
  { {0x7ae100b0, 0x2bcb003b, 0x5d840025, 0x00000000}},  //   pult, _чудо_, _الهل,
  { {0x660f0866, 0x4b790049, 0x66d90986, 0x00000000}},  //   _back, _באַו, льтр_,
  { {0x660f0107, 0xe5a3213f, 0x75d60025, 0x00000000}},  //   _cack, жити, شيطا,
  { {0x290c0089, 0x00000000, 0x00000000, 0x00000000}},  // [aa00] ādas_,   ,   ,
  { {0x29370049, 0x61fd014a, 0xb87b013e, 0x00000000}},  //   _כאפן_, _ısla, stír,
  { {0x660f28fa, 0x0ef40061, 0xed59179b, 0x00000000}},  //   _fack, _आहेस_, mažu_,
  { {0xed5904eb, 0xb87b00c4, 0x95c7007e, 0x00000000}},  //   lažu_, nuín, _клюб_,
  { {0x03a60088, 0x05940014, 0x3eb90035, 0x00000000}},  //   _виго, _دادگ, _ăsta_,
  { {0x6604009f, 0x660f0740, 0xc076012b, 0x00000000}},  //   leik, _zack, шћењ,
  { {0xe7ee03d7, 0x1c1f0164, 0x23270594, 0x00000000}},  //   _जाना_, बाईल_, _кори_,
  { {0xddc90036, 0x7d0b000a, 0x7d19005b, 0x00000000}},  //   mieś, _bsgs, _brws,
  { {0x6143012b, 0x62820112, 0x2ca60026, 0x00000000}},  //   _дета, mloo, _quod_,
  { {0x69d600e0, 0x66043396, 0x7d19005b, 0x00000000}},  //   _adye, heik, _drws,
  { {0xddc90036, 0xa3e901f5, 0x6282006c, 0x00000000}},  //   nieś, _यास_, oloo,
  { {0x62820222, 0x62510027, 0x2ca60058, 0x00000000}},  //   nloo, sťov, _tuod_,
  { {0x6e2206c0, 0xdb1800f8, 0xa49b00f6, 0x00000000}},  //   _inob, _sevä, _isòv,
  { {0xd7c90076, 0x76460133, 0x00000000, 0x00000000}},  //   طوره_, _alky,   ,
  { {0x660f00ab, 0x6282095a, 0x6e2201a2, 0x00000000}},  //   _pack, kloo, _knob,
  { {0xd5b803c0, 0xe61f0011, 0x9f5c00b9, 0x00000000}},  //   ису_, _khôi_, jeví_,
  { {0x660f0039, 0x62820007, 0x95c80b7a, 0x00000000}},  // [aa10] _vack, dloo, руса_,
  { {0x660f0e42, 0x673c0635, 0x628200d9, 0x00000000}},  //   _wack, byrj, eloo,
  { {0xa2f500a5, 0x660f0aa4, 0x00000000, 0x00000000}},  //   спеч, _tack,   ,
  { {0x62820116, 0x80db006e, 0xd1b80439, 0x00000000}},  //   gloo, _निदे, لاها_,
  { {0xe3e900a6, 0x6f1a1651, 0xdb0a01a2, 0x00000000}},  //   _مکان_, _artc, _gefö,
  { {0x6e221f3e, 0x8596009b, 0x00000000, 0x00000000}},  //   _anob, _לדרג_,   ,
  { {0x628201bb, 0x64470066, 0x72d40088, 0x00000000}},  //   bloo, _ilji, _морф,
  { {0xf99f2475, 0x11d40025, 0x00000000, 0x00000000}},  //   ndès_, _وتقد,   ,
  { {0x61fb0058, 0x00000000, 0x00000000, 0x00000000}},  //   _ibul,   ,   ,
  { {0x30850054, 0x1c453397, 0x6604007f, 0x00000000}},  //   _الطف, сном, zeik,
  { {0x78b600f8, 0x00000000, 0x00000000, 0x00000000}},  //   _styv,   ,   ,
  { {0xd356009b, 0x7d19005b, 0x00000000, 0x00000000}},  //   מיתי_, _trws,   ,
  { {0x6604010a, 0x61fb0065, 0x8e740025, 0x00000000}},  //   veik, _mbul, _بالض,
  { {0x7d0900e0, 0x673c12e2, 0xfbde0044, 0x00000000}},  //   mwes, tyrj, ব্বত,
  { {0x66041104, 0x61fb0061, 0x7c230fdc, 0x00000000}},  //   teik, _obul, _innr,
  { {0x44230173, 0xb87b00c4, 0xdb36009b, 0x00000000}},  //   _anj_, quín, _לנצח_,
  { {0x66043398, 0xddc90036, 0xab5c0089, 0x00000000}},  // [aa20] reik, wieś, vaļi,
  { {0x61fb0058, 0x44230181, 0x232a017a, 0x00000000}},  //   _abul, _cnj_, лози_,
  { {0x7d091153, 0x656f00ab, 0x6a68014a, 0x00000000}},  //   hwes, _exch, yıfl,
  { {0xb87b1d59, 0x6b7a0049, 0x7d0911ac, 0x00000000}},  //   críb, ארענ, kwes,
  { {0xc05a01ff, 0xe77900a1, 0x628226c5, 0x00000000}},  //   лік_, _ملیں_, rloo,
  { {0x7d0905af, 0x64470ce4, 0x62823399, 0x00000000}},  //   dwes, _glji, sloo,
  { {0x645e1449, 0x7ff30025, 0x62820a2a, 0x00000000}},  //   mipi, سسوا, ploo,
  { {0x645e066d, 0x6f1a0059, 0xbe8a007c, 0x00000000}},  //   lipi, _vrtc, ысле_,
  { {0xa49b0129, 0x217600e2, 0x7d0901d6, 0x00000000}},  //   _pròx, _ѓубр, gwes,
  { {0x61fb0065, 0x645e011c, 0x9411006b, 0x00000000}},  //   _zbul, nipi, _bizə_,
  { {0x7f860025, 0x29000035, 0x547b009b, 0x00000000}},  //   _الان, _apia_, רטיו,
  { {0xc333019b, 0x7a3f008d, 0xe61f001d, 0x00000000}},  //   לות_, _këti, _thôi_,
  { {0x6da30070, 0x645e0020, 0x00000000, 0x00000000}},  //   _عموم, kipi,   ,
  { {0x4d7b0049, 0x645e00e7, 0x244400f8, 0x00000000}},  //   _ערגע, jipi, _sömn_,
  { {0x2bf700b3, 0x644b0065, 0x27180087, 0x00000000}},  //   _המון_, ëgim, _cčn_,
  { {0x7bca0359, 0x64470107, 0x00000000, 0x00000000}},  //   _hefu, _slji,   ,
  { {0x69cf0211, 0xdb030666, 0x4423339a, 0x00000000}},  // [aa30] mace, _agnè, _pnj_,
  { {0x69cf0211, 0x645e12e8, 0x6aaa0190, 0x00000000}},  //   lace, gipi, _kuff,
  { {0xe7ee02d2, 0xe9f9001d, 0x6aaa07a5, 0x00000000}},  //   _जाता_, _giả_, _juff,
  { {0x04060044, 0xb87b00c4, 0x38af339b, 0x00000000}},  //   রাগী_, bríc, _kür_,
  { {0x44230022, 0x7bd804eb, 0x00000000, 0x00000000}},  //   _tnj_, _odvu,   ,
  { {0x02a7008b, 0x645e0c1f, 0x69cf339c, 0x00000000}},  //   _грам, cipi, hace,
  { {0x80db007d, 0x69cf10b1, 0xd1bb0025, 0x00000000}},  //   _निवे, kace, _ماذا_,
  { {0xee3900aa, 0x764d0058, 0x798d0082, 0x00000000}},  //   рни_, nhay, _ozaw,
  { {0x6aaa010f, 0x9411006b, 0x82340151, 0x00000000}},  //   _auff, _sizə_, _عرفا,
  { {0x7d09037f, 0xdfd102fd, 0x7bca0087, 0x00000000}},  //   rwes, _آيا_, _cefu,
  { {0x20070214, 0x7bca0c42, 0x6aaa2525, 0x00000000}},  //   meni_, _defu, _cuff,
  { {0x20070209, 0x13d20044, 0x645e002d, 0x00000000}},  //   leni_, ালয়, zipi,
  { {0x38af006b, 0xfe420088, 0x7e7b0618, 0x00000000}},  //   _cür_, _іншо, moup,
  { {0x7bca2dc9, 0x7e7b339d, 0xbb45007c, 0x00000000}},  //   _gefu, loup, _мелк,
  { {0x69cf0211, 0x07a3007e, 0x7bc1001a, 0x00000000}},  //   bace, дарн, mblu,
  { {0x38af08ba, 0x2007339e, 0xb81a03d7, 0x00000000}},  //   _für_, heni_, _फोरम_,
  { {0x645e011c, 0x80db0164, 0x20070453, 0x00000000}},  // [aa40] tipi, _निषे, keni_,
  { {0x200700ee, 0xb87b052d, 0xe45f000c, 0x00000000}},  //   jeni_, rríc, _svör_,
  { {0xe5a60072, 0x20070209, 0x41aa026b, 0x00000000}},  //   _мини, deni_, авен_,
  { {0x645e0006, 0x764d0173, 0xb5fb000c, 0x00000000}},  //   sipi, chay, _sjáv,
  { {0x6b830030, 0xe80f0061, 0x645e011c, 0x00000000}},  //   _lyng, ायचा_, pipi,
  { {0x20070020, 0xdfd00379, 0x76440279, 0x00000000}},  //   geni_, ريب_, lkiy,
  { {0x44f4021e, 0x7bc10922, 0x4444339f, 0x00000000}},  //   lä_, dblu, mk_,
  { {0x4438002d, 0x66160a62, 0x7bca33a0, 0x00000000}},  //   _hor_, ndyk, _sefu,
  { {0xc69301f8, 0x44f4021e, 0x69cf0b30, 0x00000000}},  //   ואה_, nä_, vace,
  { {0x44380093, 0xddc2012d, 0x7bc5010e, 0x00000000}},  //   _jor_, _djoš, _õhul,
  { {0x444422c7, 0x6b83018e, 0x44382c6d, 0x00000000}},  //   ik_, _cyng, _mor_,
  { {0x81dc0055, 0xb5fb0219, 0x4438000d, 0x00000000}},  //   ত্র_, _imág, _lor_,
  { {0x44381273, 0x44f4021e, 0x44440292, 0x00000000}},  //   _oor_, jä_, kk_,
  { {0x444402ae, 0x69cf01c5, 0x6aaa0039, 0x00000000}},  //   jk_, sace, _tuff,
  { {0x69cf00f4, 0x6d400006, 0x6b8333a1, 0x00000000}},  //   pace, lyma, _gyng,
  { {0x38af085e, 0x444433a2, 0x44380058, 0x00000000}},  //   _tür_, ek_, _aor_,
  { {0x443801bf, 0x6d40007f, 0x764d008a, 0x00000000}},  // [aa50] _bor_, nyma, rhay,
  { {0x443809f7, 0x7e60008a, 0xb87b008e, 0x00000000}},  //   _cor_, himp, bría,
  { {0x44381f5b, 0x6d4033a3, 0xf8bf1339, 0x00000000}},  //   _dor_, hyma, lpé_,
  { {0x44440238, 0x645c3265, 0x6d40010a, 0x00000000}},  //   ak_, _emri, kyma,
  { {0x443833a4, 0x20070047, 0xd49b00ed, 0x00000000}},  //   _for_, teni_, _врв_,
  { {0x44440a8a, 0x6d400006, 0x443833a5, 0x00000000}},  //   ck_, dyma, _gor_,
  { {0x20070091, 0x7e7b00b9, 0x7d0233a6, 0x00000000}},  //   reni_, toup, _apos,
  { {0x200703b6, 0x4438014a, 0xe68e006b, 0x00000000}},  //   seni_, _zor_, _məşğ,
  { {0x200726bb, 0x7bc10d33, 0x7e7b0145, 0x00000000}},  //   peni_, tblu, roup,
  { {0xbebc0089, 0x4438013f, 0x20070023, 0x00000000}},  //   _brīd, _xor_, qeni_,
  { {0x7c380198, 0x7d0204d3, 0x3b09081e, 0x00000000}},  //   _dovr, _epos, щено_,
  { {0x60c90117, 0x6d401506, 0x7e60008a, 0x00000000}},  //   _kwem, byma, cimp,
  { {0x7bc133a7, 0x44440032, 0x6b8333a8, 0x00000000}},  //   pblu, yk_, _wyng,
  { {0x44f4021e, 0x60c909c7, 0x6b83093b, 0x00000000}},  //   vä_, _mwem, _tyng,
  { {0xcb66041f, 0xbebc0089, 0x444400ca, 0x00000000}},  //   _наше_, _grīd, vk_,
  { {0x44f4021e, 0x4438165e, 0xe61a0184, 0x00000000}},  //   tä_, _sor_, љда_,
  { {0x44380325, 0x764401f6, 0x6e39002b, 0x00000000}},  // [aa60] _por_, rkiy, _mowb,
  { {0x4444046a, 0xd91b0049, 0x291204be, 0x00000000}},  //   uk_, _פויל, _isya_,
  { {0x443833a9, 0xf626026b, 0x6d400036, 0x00000000}},  //   _vor_, _едно, zyma,
  { {0x444405d5, 0x64a60113, 0xe297005c, 0x00000000}},  //   sk_, _нама, пах_,
  { {0x443807f9, 0xf1a9007a, 0x444433aa, 0x00000000}},  //   _tor_, زانه_, pk_,
  { {0x645c016e, 0x64450203, 0x62991238, 0x00000000}},  //   _umri, ckhi, amwo,
  { {0x7d020046, 0x76550010, 0x00000000, 0x00000000}},  //   _spos, _ügyé,   ,
  { {0x6d400a66, 0x7c381982, 0x7ae8093b, 0x00000000}},  //   tyma, _sovr, vudt,
  { {0x7c380868, 0x7e6027d2, 0xc0e301fc, 0x00000000}},  //   _povr, rimp, _потк,
  { {0x7e600169, 0x6d4010fd, 0xd64a00e2, 0x00000000}},  //   simp, ryma, jнов,
  { {0x2912066b, 0x78ad0b76, 0x60c900b5, 0x00000000}},  //   _asya_, _suav, _zwem,
  { {0x224633ab, 0x00000000, 0x00000000, 0x00000000}},  //   nkok_,   ,   ,
  { {0xdcf7007a, 0x2e37009b, 0x7c380059, 0x00000000}},  //   _فروش_, _מראש_, _tovr,
  { {0xac9800a1, 0xb905006e, 0x00000000, 0x00000000}},  //   _بنتا_, _पट_,   ,
  { {0xabfb009b, 0xf1cc0164, 0x41cc01f5, 0x00000000}},  //   _ההור, ारान, ारास,
  { {0x80d20044, 0xf8bf00f4, 0x78ad004a, 0x00000000}},  //   _সমন্, ppé_, _tuav,
  { {0x3a290093, 0x3ea60c28, 0x9f5c00b0, 0x00000000}},  // [aa70] _inap_, _miot_, levä_,
  { {0xdb1a014a, 0x60c90045, 0xe3b00439, 0x00000000}},  //   katü, _rwem, هرم_,
  { {0x3a290030, 0xdb1a0036, 0x64450127, 0x00000000}},  //   _knap_, mató, rkhi,
  { {0xdb1a0181, 0x60c90173, 0x3cdd013d, 0x00000000}},  //   lató, _pwem, _खिले_,
  { {0xe1f00076, 0xb5fb009f, 0xe8220061, 0x00000000}},  //   اسم_, _fjár, माचा_,
  { {0xdb1a21e7, 0xc9180104, 0xfaf80089, 0x00000000}},  //   nató, פחות_, ktī_,
  { {0xae1e007d, 0x3ea60068, 0xb87b0048, 0x00000000}},  //   _मोहन_, _biot_, hrío,
  { {0x7d1b006c, 0xda1d0061, 0x60c9002b, 0x00000000}},  //   tvus, _बोलत_, _twem,
  { {0xd7bf001c, 0xe7ee0061, 0x3ea6002d, 0x00000000}},  //   ्राच, _जाला_, _diot_,
  { {0xbb45058e, 0x9e67025a, 0x5ee5013d, 0x00000000}},  //   деок, _کائن, _टिप्_,
  { {0x7d1b03b6, 0xdb1a00fa, 0x00000000, 0x00000000}},  //   svus, dató,   ,
  { {0xb87b0051, 0x00000000, 0x00000000, 0x00000000}},  //   frío,   ,   ,
  { {0xdb0a03a2, 0x80cf0044, 0xac190140, 0x00000000}},  //   _affä, হূর্, _моду_,
  { {0xdb1a0854, 0x6b650131, 0x3a2900d6, 0x00000000}},  //   gató, _окла, _enap_,
  { {0x81e508b7, 0x98a301ee, 0x224d010e, 0x00000000}},  //   ব্য_, тире, _olek_,
  { {0x2ca70004, 0xb87b0051, 0x3eb80010, 0x00000000}},  //   _hind_, brío, _érte_,
  { {0x2ca71936, 0xdb1a00c4, 0xb87b0051, 0x00000000}},  // [aa80] _kind_, bató, crío,
  { {0xdb1a00c4, 0x225f0022, 0x2ca700e5, 0x00000000}},  //   cató, _amuk_, _jind_,
  { {0x38b40901, 0x2ca733ac, 0x224d0173, 0x00000000}},  //   _här_, _mind_, _blek_,
  { {0x2ca70065, 0xdb030051, 0x38b400f8, 0x00000000}},  //   _lind_, _ngní, _kär_,
  { {0xa2aa013d, 0x3ea60133, 0x00000000, 0x00000000}},  //   _जंक्, _riot_,   ,
  { {0x224612c9, 0x38b408e8, 0xceba003b, 0x00000000}},  //   skok_, _mär_, ољи_,
  { {0x38b40039, 0x644e12d7, 0x00000000, 0x00000000}},  //   _lär_, _ilbi,   ,
  { {0x9d14013b, 0x224d0022, 0xdb1a0e03, 0x00000000}},  //   едич, _glek_, zató,
  { {0x38b40073, 0x2ca70292, 0x21670088, 0x00000000}},  //   _när_, _bind_, _жити_,
  { {0x3a2900b5, 0x2ca7001a, 0x9f5c0052, 0x00000000}},  //   _snap_, _cind_, tevä_,
  { {0x60c200b0, 0x9f5e00d4, 0xdb1a00fd, 0x00000000}},  //   lpom, _obté_, vató,
  { {0x38b40a5d, 0x2ca733ad, 0xb87b0051, 0x00000000}},  //   _bär_, _eind_, trío,
  { {0x2ca71fbe, 0xdb1a162f, 0x644e0197, 0x00000000}},  //   _find_, tató, _olbi,
  { {0x38b40073, 0x9c570025, 0x0ec50061, 0x00000000}},  //   _där_, _يجوز_, ळीकड,
  { {0xdb1a285a, 0x442d33ae, 0x00000000, 0x00000000}},  //   rató, _đe_,   ,
  { {0x644e022b, 0x56940cb7, 0xb5fb01e5, 0x00000000}},  //   _albi, васт, _smáb,
  { {0xdb1a33af, 0x60c20235, 0x442a33b0, 0x00000000}},  // [aa90] catò, jpom, _bnb_,
  { {0xe8d8009b, 0x225f0030, 0x4cc30044, 0x00000000}},  //   _חוזר_, _smuk_, _শিমু,
  { {0x224d06b2, 0x7afa00e0, 0x00000000, 0x00000000}},  //   _plek_, nttt,   ,
  { {0x644e014a, 0x442a01d6, 0x81cf0044, 0x00000000}},  //   _elbi, _enb_, _শাহ_,
  { {0x3858025a, 0x224d0640, 0x442a33b1, 0x00000000}},  //   _رشید_, _vlek_, _fnb_,
  { {0x442a0173, 0x3af80010, 0x64900bac, 0x00000000}},  //   _gnb_, kép_, läin,
  { {0x2ca70cea, 0x00000000, 0x00000000, 0x00000000}},  //   _rind_,   ,   ,
  { {0x2ca708ba, 0x43941036, 0x7c2a010f, 0x00000000}},  //   _sind_, _расс, _anfr,
  { {0x11670752, 0x2ca72370, 0x00000000, 0x00000000}},  //   _غلطی_, _pind_,   ,
  { {0xfc310054, 0x2ca70065, 0x628b074e, 0x00000000}},  //   احة_, _qind_, llgo,
  { {0x2ca7046a, 0x3af80010, 0xb87b000c, 0x00000000}},  //   _vind_, gép_, grím,
  { {0xee2e008b, 0x2ca700fe, 0x38b400f8, 0x00000000}},  //   _ён_, _wind_, _pär_,
  { {0xed4e1b70, 0x7afa001c, 0x660d002d, 0x00000000}},  //   _со_, attt, deak,
  { {0x26de0166, 0x60db00e7, 0xccf200b3, 0x00000000}},  //   štom_, _mvum, _עכו_,
  { {0x7afa001c, 0xe73a005e, 0x969600ed, 0x00000000}},  //   cttt, чев_, ераш,
  { {0x660d00eb, 0x00000000, 0x00000000, 0x00000000}},  //   geak,   ,   ,
  { {0x442a33b2, 0x1426004c, 0x999e0006, 0x00000000}},  // [aaa0] _pnb_, ндам, ėtų_,
  { {0x78fb00b6, 0x3957019b, 0x628b33b3, 0x00000000}},  //   _צפיו, _נשים_, elgo,
  { {0x64e20061, 0x442a0082, 0x00000000, 0x00000000}},  //   _पिवळ, _vnb_,   ,
  { {0xdb010d7b, 0x237700a2, 0xdb0a009d, 0x00000000}},  //   lcló, رمند_, _affû,
  { {0xa3e9001c, 0x442a0145, 0x5183007c, 0x00000000}},  //   _याच_, _tnb_, луша,
  { {0xd8d700a0, 0xf99300a0, 0x442a00c4, 0x00000000}},  //   גוסט_, ארד_, _unb_,
  { {0x91e60113, 0x7777027b, 0x60c209fc, 0x00000000}},  //   _пове, _xxxx, spom,
  { {0xb87b1b0f, 0x60c2059f, 0x00000000, 0x00000000}},  //   quív, ppom,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afa001c, 0x8fa600ed, 0x6e2b032e, 0x00000000}},  //   tttt, _зазе, _engb,
  { {0x6282016e, 0x26de016c, 0xdb180d7b, 0x00000000}},  //   oooo, štoj_, _revó,
  { {0x628201ed, 0x224d0066, 0xdc3c04eb, 0x00000000}},  //   nooo, _ċekk_, _išču,
  { {0x7afa001c, 0x8c460867, 0x2eee00f8, 0x00000000}},  //   sttt, _педе, luff_,
  { {0x62820058, 0x7c2a1bfd, 0xb87b004a, 0x00000000}},  //   hooo, _unfr, prím,
  { {0x3333027b, 0x45d500ed, 0x660d0b79, 0x00000000}},  //   xxxx_, ковс, teak,
  { {0xe9df000c, 0xe3cd0044, 0x00000000, 0x00000000}},  //   rhús_, _লাইব,   ,
  { {0x660d002d, 0x62821d12, 0x649000b0, 0x00000000}},  // [aab0] reak, dooo, räin,
  { {0xd13102fd, 0x14190025, 0x64900052, 0x00000000}},  //   یما_, بيئة_, säin,
  { {0xf69901f9, 0x28b702fb, 0xd3710025, 0x00000000}},  //   _овој_, _इंडि, جها_,
  { {0x249800d9, 0x26c100d9, 0x00000000, 0x00000000}},  //   _ehrm_, _itho_,   ,
  { {0x52740025, 0x68fd2370, 0x6f0800f6, 0x00000000}},  //   دالز, ntsd, _apdc,
  { {0x7e62000a, 0x200e0026, 0xb144007e, 0x00000000}},  //   _amop, gefi_, ыніл,
  { {0x439400ed, 0x628233b4, 0x00000000, 0x00000000}},  //   _барс, booo,   ,
  { {0xa295008b, 0x2909012d, 0xdb030048, 0x00000000}},  //   _рабі, _opaa_, _ngná,
  { {0x60db0020, 0x6ba6006b, 0x320f0010, 0x00000000}},  //   _uvum, əsgə, megy_,
  { {0x26de0344, 0x1c45004c, 0x00000000, 0x00000000}},  //   átok_, тном,   ,
  { {0x9f040151, 0x00000000, 0x00000000, 0x00000000}},  //   _مولو,   ,   ,
  { {0xa96a012b, 0xb6c800a1, 0x68fd0da6, 0x00000000}},  //   дима_, ہارے_, ftsd,
  { {0x7ae81e2e, 0xf4cc0044, 0x2d820010, 0x00000000}},  //   ardt, _লম্ব, üket_,
  { {0xed56012b, 0x66e601f9, 0x1d06026b, 0x00000000}},  //   _још_, кога, _реши_,
  { {0xb5fb000c, 0x1779007c, 0x68fd0bed, 0x00000000}},  //   _smáa, есть_, atsd,
  { {0x80d20055, 0xe5f3001a, 0xceb20097, 0x00000000}},  //   _সমস্, văţă, שין_,
  { {0xb87b33b5, 0x46a3007e, 0x00000000, 0x00000000}},  // [aac0] tuít, ратв,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3e7a0089, 0x00000000, 0x00000000, 0x00000000}},  //   līte_,   ,   ,
  { {0xbebc0089, 0xb87b33b6, 0x68e909c6, 0x00000000}},  //   _brīn, suít, šede,
  { {0x2444000c, 0x62820032, 0x200e00f6, 0x00000000}},  //   _sömu_, rooo, tefi_,
  { {0xdcf500b9, 0x6282004a, 0xb87b00c4, 0x00000000}},  //   ůběh, sooo, luír,
  { {0xe8e00011, 0x200e0016, 0xe8040164, 0x00000000}},  //   _ước_, refi_, श्या_,
  { {0xf773009b, 0x00000000, 0x00000000, 0x00000000}},  //   יקו_,   ,   ,
  { {0x5ea30025, 0xdb1a33b7, 0x00000000, 0x00000000}},  //   جميل, natö,   ,
  { {0xe7ee024c, 0xb87b000c, 0x515b00a3, 0x00000000}},  //   _जागा_, rrík, _חכמו,
  { {0x3d17013d, 0xb87b000c, 0x00000000, 0x00000000}},  //   _बैठे_, srík,   ,
  { {0x68fd00ea, 0x81c20044, 0xb87b0027, 0x00000000}},  //   ttsd, ূলক_, prík,
  { {0xb87b004a, 0x00000000, 0x00000000, 0x00000000}},  //   nsíg,   ,   ,
  { {0x68fd04fb, 0x00000000, 0x00000000, 0x00000000}},  //   rtsd,   ,   ,
  { {0x44d00046, 0x386d0182, 0x98a000d0, 0x00000000}},  //   eń_, đer_, _grič_,
  { {0x64902427, 0x00000000, 0x00000000, 0x00000000}},  //   säil,   ,   ,
  { {0x35b4007c, 0x9a680025, 0xdb0a0190, 0x00000000}},  // [aad0] рбур, _جميل_, _affø,
  { {0x7bc5006c, 0x54540451, 0x798d004a, 0x00000000}},  //   _õhut, авут, _iyaw,
  { {0xd3a70245, 0x6aad0020, 0x320f00ab, 0x00000000}},  //   трап, _kiaf, tegy_,
  { {0xe45f0039, 0x1fcf0044, 0x798d0045, 0x00000000}},  //   _stöd_, _রাইস, _kyaw,
  { {0xf1b91e34, 0xc7b80107, 0x91050783, 0x00000000}},  //   _naše_, žđe_, упле,
  { {0x244400f8, 0x00000000, 0x00000000, 0x00000000}},  //   _döms_,   ,   ,
  { {0x661d1bbf, 0x44fd0026, 0x6490006c, 0x00000000}},  //   _kask, lì_, käij,
  { {0x7658010a, 0x80d20044, 0xa5bb0051, 0x00000000}},  //   _įvyk, _সমর্, _gnót,
  { {0x798d003f, 0x44fd0026, 0xdbcd004a, 0x00000000}},  //   _nyaw, nì_, _añád,
  { {0x661d098a, 0x64570082, 0x98a000ca, 0x00000000}},  //   _lask, nhxi, _prič_,
  { {0x15e30061, 0x798d00e0, 0x765600b0, 0x00000000}},  //   गणार_, _ayaw, yhyy,
  { {0xceb200b6, 0x1cb90054, 0x661d008a, 0x00000000}},  //   _היא_, _كاتب_, _nask,
  { {0xfce5004c, 0x798d0009, 0x82760049, 0x00000000}},  //   _соло, _cyaw, רערע_,
  { {0x6e3b0f3a, 0x7e69010a, 0x44fd0207, 0x00000000}},  //   ljub, liep, dì_,
  { {0xcfd80055, 0x661d33b8, 0x869a0478, 0x00000000}},  //   _সামন, _bask, етат_,
  { {0x661d01ee, 0xe3cd0044, 0x6e3b01e5, 0x00000000}},  //   _cask, _লাগব, njub,
  { {0x6d490022, 0x661d04eb, 0xe3b201d8, 0x00000000}},  // [aae0] nyea, _dask, مرا_,
  { {0xf8bf00f4, 0xdb1a3142, 0x69d6014a, 0x00000000}},  //   uvée_, ratö, _heye,
  { {0xf8bf009d, 0x3775007c, 0x6d4900d9, 0x00000000}},  //   rvée_, _выяс, hyea,
  { {0x661d002b, 0x629b0212, 0x7e6933b9, 0x00000000}},  //   _gask, _chuo, jiep,
  { {0x91e31548, 0xf77202fd, 0xa06a00c0, 0x00000000}},  //   соче, _خاک_, нада_,
  { {0x69d60211, 0x661d0871, 0x6d490253, 0x00000000}},  //   _leye, _zask, dyea,
  { {0xe29600ed, 0x661d0022, 0x09da0044, 0x00000000}},  //   _браќ, _yask, _থানা,
  { {0x798903b2, 0xe804006e, 0xf1b91032, 0x00000000}},  //   żewi, श्ता_, _paše_,
  { {0xacb4012b, 0x6aad1a48, 0x75240023, 0x00000000}},  //   јбољ, _riaf, nviz,
  { {0xf1b91e34, 0x4cc30044, 0x6aad33ba, 0x00000000}},  //   _vaše_, _শিশু, _siaf,
  { {0xaa592672, 0x69d60056, 0x3f8c014a, 0x00000000}},  //   вину_, _beye, _uydu_,
  { {0xc33300b6, 0x201e1636, 0x00000000, 0x00000000}},  //   צור_, _hati_,   ,
  { {0x201e000b, 0x69d6006b, 0x9a8407d0, 0x00000000}},  //   _kati_, _deye, суэл,
  { {0x661d001e, 0x75240107, 0x201e04cb, 0x00000000}},  //   _sask, dviz, _jati_,
  { {0x7bda0004, 0x661d33bb, 0x201e033b, 0x00000000}},  //   matu, _pask, _mati_,
  { {0x7bda168e, 0x201e1a99, 0x69d605eb, 0x00000000}},  //   latu, _lati_, _geye,
  { {0x661d0030, 0xdddb093f, 0x764d033b, 0x00000000}},  // [aaf0] _vask, nouš, rkay,
  { {0x7d1d0030, 0x201e038d, 0xd37b00c0, 0x00000000}},  //   æssi, _nati_, нче_,
  { {0xd5b103ab, 0x629b0011, 0x44fd0197, 0x00000000}},  //   _وفد_, _phuo, sì_,
  { {0x7bda006c, 0x1af70049, 0x44fd0026, 0x00000000}},  //   hatu, רמאל_, pì_,
  { {0x7bda2355, 0x201e1635, 0xf8b50164, 0x00000000}},  //   katu, _bati_, ंदिय,
  { {0x7bda1ab1, 0xd2d703ab, 0xd0090175, 0x00000000}},  //   jatu, _مغرب, теке_,
  { {0x7bda0004, 0x201e0198, 0x7e6900b5, 0x00000000}},  //   datu, _dati_, tiep,
  { {0xb87b2346, 0xddc20046, 0x6d5b022b, 0x00000000}},  //   nsíb, _iloś, tzua,
  { {0x69d60211, 0xee3600a5, 0x7e690190, 0x00000000}},  //   _reye, рны_, riep,
  { {0x7bda0c0e, 0x201e0065, 0x442100f8, 0x00000000}},  //   gatu, _gati_, ndh_,
  { {0x44210195, 0xbf1502fd, 0x66040036, 0x00000000}},  //   idh_, _خواب, yfik,
  { {0x201e33bc, 0x3cee0061, 0x00000000, 0x00000000}},  //   _zati_, _आमचे_,   ,
  { {0x7bda168e, 0x8e840025, 0xed1600a1, 0x00000000}},  //   batu, _النه, _نہيں_,
  { {0x7bda2702, 0x6c790049, 0x8d5a009b, 0x00000000}},  //   catu, _שאַפ, _בכני,
  { {0x07a6012b, 0x45d60113, 0x61fb0325, 0x00000000}},  //   равн, ицат, _ocul,
  { {0x645500d4, 0x443118ce, 0xc87f01a2, 0x00000000}},  //   _alzi, _anz_, wußt_,
  { {0xb4660269, 0x660401a3, 0x4466007e, 0x00000000}},  // [ab00] акал, rfik, авав,
  { {0x752433bd, 0x3eaf00b5, 0x61fb1fcb, 0x00000000}},  //   rviz, _ligt_, _acul,
  { {0x3a200736, 0x201e002b, 0xdddb00b9, 0x00000000}},  //   _kaip_, _rati_, dluž,
  { {0x4421002a, 0x201e0363, 0x7bda002d, 0x00000000}},  //   adh_, _sati_, zatu,
  { {0x201e0263, 0x7c21001c, 0x7bda09f5, 0x00000000}},  //   _pati_, kdlr, yatu,
  { {0x3ced24c0, 0x7ee6007c, 0x3e7a0089, 0x00000000}},  //   drev_, ацие, dīta_,
  { {0x7bda143d, 0x201e01ee, 0xa2e301ab, 0x00000000}},  //   vatu, _vati_, _морд,
  { {0xf53f0afc, 0x7bda0020, 0x201e08e3, 0x00000000}},  //   _igår_, watu, _wati_,
  { {0x7bda24c3, 0xdd97007c, 0x777e03e2, 0x00000000}},  //   tatu, ишь_, _lxpx,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bda022b, 0xfee90025, 0xddc90089, 0x00000000}},  //   ratu, _معنى_, sneš,
  { {0x7bda24c3, 0x3ced0c7b, 0xdddb00b9, 0x00000000}},  //   satu, brev_, pouš,
  { {0x7bda2092, 0xf1b90087, 0x00000000, 0x00000000}},  //   patu, _jaša_,   ,
  { {0x5887008b, 0x27ed001f, 0xdca3003b, 0x00000000}},  //   рыма, ßen_, _дачи,
  { {0x27ed014a, 0x00000000, 0x00000000, 0x00000000}},  //   ğen_,   ,   ,
  { {0xe65401fb, 0x27ed014a, 0x00000000, 0x00000000}},  //   овсь, şen_,   ,
  { {0x69dd0004, 0x26c50006, 0xa49b01aa, 0x00000000}},  // [ab10] mase, ūlo_, _opòt,
  { {0x69dd0004, 0x57f500aa, 0x03c70f62, 0x00000000}},  //   lase, _упот, рсам,
  { {0x94a800ed, 0x44210065, 0xa6ab03ab, 0x00000000}},  //   ртта_, rdh_, _لاحق_,
  { {0x69dd1448, 0x7bd8009d, 0x44310190, 0x00000000}},  //   nase, _levu, _wnz_,
  { {0xe4a700ed, 0x44310087, 0xe4e405b8, 0x00000000}},  //   _врво, _tnz_, _мірн,
  { {0x69dd2222, 0xe2d9026c, 0xf1b92782, 0x00000000}},  //   hase, _مارچ_, _daša_,
  { {0x69dd33be, 0x2d8f0030, 0x2a69010e, 0x00000000}},  //   kase, _syge_, _omab_,
  { {0xdddb0340, 0x3e7a0089, 0xa49b000a, 0x00000000}},  //   služ, tīta_, _epòt,
  { {0x69dd33bf, 0x7bd80197, 0x4bd91e2c, 0x00000000}},  //   dase, _bevu, льня_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69dd0109, 0x7bd812b9, 0x3b09003b, 0x00000000}},  //   fase, _devu, ћемо_,
  { {0x69dd009f, 0x7a3f0065, 0x7bce000c, 0x00000000}},  //   gase, _këty, ðbur,
  { {0xa3d70164, 0x2f012704, 0x7e7e0010, 0x00000000}},  //   सरा_, lóg_, éppe,
  { {0x7bd801b5, 0x2902016e, 0x2a69000a, 0x00000000}},  //   _gevu, rtka_, _emab_,
  { {0x3a20010a, 0x69dd0292, 0x29021712, 0x00000000}},  //   _taip_, base, stka_,
  { {0x69dd0f6a, 0x69c100b9, 0xaac403ec, 0x00000000}},  //   case, ělec, _بتون,
  { {0xe5a301bd, 0x69c401f3, 0x291e0089, 0x00000000}},  // [ab20] зити, _ifie, ātas_,
  { {0xb87b0285, 0xb3e90380, 0x2eee0016, 0x00000000}},  //   rsíc, لعمل_, yrff_,
  { {0xf1b9016c, 0x68e40018, 0xa49b00d4, 0x00000000}},  //   _saša_, _hvid, _apòs,
  { {0xf1b90089, 0xa49b0173, 0x2007000c, 0x00000000}},  //   _paša_, _spòt, efni_,
  { {0xcfcf0055, 0x7bc100f8, 0x68e40087, 0x00000000}},  //   _রাজন, kclu, _jvid,
  { {0xf1b90465, 0xfc220044, 0x3ae3014a, 0x00000000}},  //   _vaša_, _পক্ষ_, kıp_,
  { {0x7bd800f4, 0x69dd014a, 0x7646010a, 0x00000000}},  //   _revu, yase, _koky,
  { {0x68e4001a, 0xf1b900d0, 0x5d5402dc, 0x00000000}},  //   _ovid, _taša_, жкит,
  { {0x7646010a, 0x69dd006c, 0x7bd801ee, 0x00000000}},  //   _moky, vase, _pevu,
  { {0x40960054, 0x69c40016, 0xb4d6006e, 0x00000000}},  //   _الطر, _afie, _सबै_,
  { {0x68e4117e, 0x6a151079, 0x00000000, 0x00000000}},  //   _avid, омну,   ,
  { {0x76460173, 0x7bc3000c, 0x00000000, 0x00000000}},  //   _noky, _efnu,   ,
  { {0xd90f007a, 0x64430039, 0x69dd33c0, 0x00000000}},  //   رید_, önik, rase,
  { {0x69dd03b6, 0x68e40006, 0x9f450048, 0x00000000}},  //   sase, _dvid, _gcló_,
  { {0xf77306dd, 0x69dd001a, 0x7ac6003b, 0x00000000}},  //   ساس_, pase, _усле,
  { {0x8afc0036, 0xda7b02dc, 0x00000000, 0x00000000}},  //   rzęd, _щял_,   ,
  { {0x26de139d, 0x764612f4, 0x6e2200ea, 0x00000000}},  // [ab30] átor_, _doky, _maob,
  { {0xa3a701fc, 0xe8b50061, 0x00000000, 0x00000000}},  //   бјек, ंदीच,   ,
  { {0x80d20044, 0x00000000, 0x00000000, 0x00000000}},  //   _সমগ্,   ,   ,
  { {0x09ad0055, 0x99890ce4, 0x8afb0049, 0x00000000}},  //   _ক্যা, _znaš_, רלאז,
  { {0x7bc100bb, 0x3ae30095, 0x68e414f9, 0x00000000}},  //   yclu, zıp_, _xvid,
  { {0x3ae3014a, 0x7bc133c1, 0x7ff50014, 0x00000000}},  //   yıp_, xclu, زستا,
  { {0xee39012b, 0x8fa2026b, 0x2007012d, 0x00000000}},  //   инк_, маше, rfni_,
  { {0x44231555, 0x6e2212a9, 0x2f011e72, 0x00000000}},  //   _haj_, _caob, róg_,
  { {0x64470119, 0x442301d9, 0x628b09f4, 0x00000000}},  //   _koji, _kaj_, mogo,
  { {0x628b0036, 0x60c90038, 0x3d09013d, 0x00000000}},  //   logo, _item, _वहीं_,
  { {0x3b090216, 0x64470119, 0xeb990256, 0x00000000}},  //   шено_, _moji, рин_,
  { {0x628b016c, 0x6447185b, 0x442301aa, 0x00000000}},  //   nogo, _loji, _laj_,
  { {0xe8f701e1, 0x7bc100bb, 0x7e6b0009, 0x00000000}},  //   оля_, pclu, _imgp,
  { {0x44230b9f, 0x6e220142, 0x6490006c, 0x00000000}},  //   _naj_, _zaob, näit,
  { {0x61e9003b, 0xa7aa33c2, 0xf1b90059, 0x00000000}},  //   _odel, рква_, _našo_,
  { {0x68e402b6, 0x61e908ff, 0x7c230de7, 0x00000000}},  //   _tvid, _ndel, _hanr,
  { {0x68e40161, 0x628b0016, 0x64470091, 0x00000000}},  // [ab40] _uvid, dogo, _boji,
  { {0x61e9206d, 0x6447008e, 0x442333c3, 0x00000000}},  //   _adel, _coji, _caj_,
  { {0x26050316, 0x7c230129, 0xb724007a, 0x00000000}},  //   _हॉकी_, _manr, _عکسه,
  { {0x7afd0046, 0xd62a012b, 0x6b7a0049, 0x00000000}},  //   ństw, _томе_, ברענ,
  { {0x61e90016, 0x44231204, 0xfe7900b9, 0x00000000}},  //   _ddel, _faj_, dnů_,
  { {0x61e9021e, 0x2912000b, 0x6e22003b, 0x00000000}},  //   _edel, _mpya_, _saob,
  { {0xcf260025, 0xddc200e5, 0x00000000, 0x00000000}},  //   ترشي, _cloş,   ,
  { {0x7c2301b5, 0x442333c4, 0x00000000, 0x00000000}},  //   _aanr, _zaj_,   ,
  { {0x212d10c1, 0x7c230a47, 0x998000b9, 0x00000000}},  //   _greh_, _banr, _aniž_,
  { {0x4cc30055, 0x61e90059, 0x7c230016, 0x00000000}},  //   _শিখু, _zdel, _canr,
  { {0x6e22002a, 0x7c231e36, 0x61e90030, 0x00000000}},  //   _taob, _danr, _ydel,
  { {0xbebc001e, 0xf1b1013d, 0x00000000, 0x00000000}},  //   _brīv, ुँचन,   ,
  { {0xd91000a1, 0x649000b0, 0x7eb50006, 0x00000000}},  //   نیٹ_, näis, _išpa,
  { {0x7c230016, 0x00000000, 0x00000000, 0x00000000}},  //   _ganr,   ,   ,
  { {0x44230089, 0xe9f90011, 0x466b007e, 0x00000000}},  //   _raj_, _chả_, арам_,
  { {0x442333c5, 0x644700ca, 0xf1b90006, 0x00000000}},  //   _saj_, _soji, _rašo_,
  { {0x44230263, 0x64470224, 0x628b0091, 0x00000000}},  // [ab50] _paj_, _poji, vogo,
  { {0xe94400a1, 0x8afc0036, 0xb87b0051, 0x00000000}},  //   _آرٹی, częc, msío,
  { {0x64470107, 0xb87b0051, 0x442333c6, 0x00000000}},  //   _voji, lsío, _vaj_,
  { {0xb87b0181, 0xf1b90059, 0xb5fb00fa, 0x00000000}},  //   juíz, _vašo_, _amáv,
  { {0x44230119, 0x628b33c7, 0x6490006c, 0x00000000}},  //   _taj_, rogo, täit,
  { {0x44b4005e, 0x37d90044, 0x628b0145, 0x00000000}},  //   _обяс, _তাঁর, sogo,
  { {0x13590025, 0x29041a6f, 0x0018007e, 0x00000000}},  //   _الأخ_, çmaz_, іўшы_,
  { {0x7c230207, 0x5214003b, 0xa77c009b, 0x00000000}},  //   _sanr, _одст, ירופ,
  { {0x60c900d0, 0x61e4000c, 0xa158085f, 0x00000000}},  //   _utem, ðile, _дату_,
  { {0xf8bf01e5, 0x00000000, 0x00000000, 0x00000000}},  //   rvél_,   ,   ,
  { {0xf98900bd, 0x7c231e5f, 0xdce7014a, 0x00000000}},  //   _ער_, _vanr, ğlık,
  { {0xc869019b, 0xdce7014a, 0x69c10036, 0x00000000}},  //   _גן_, şlık, ślen,
  { {0x7c23005d, 0x00000000, 0x00000000, 0x00000000}},  //   _tanr,   ,   ,
  { {0x6490003c, 0xe9f90082, 0xccf90036, 0x00000000}},  //   häir, _phả_, muś_,
  { {0x2bd1001c, 0x186701fc, 0x07a300ed, 0x00000000}},  //   _द्या, чари_, еарн,
  { {0x6b9c010f, 0x7e7b006c, 0x98a0012d, 0x00000000}},  //   ürge, nnup, _orić_,
  { {0xcaa505f3, 0x05660605, 0x29120020, 0x00000000}},  // [ab60] _تصوي, чван, _upya_,
  { {0xe9f90011, 0x69c60240, 0xb87b00c4, 0x00000000}},  //   _thả_, lcke, nsíl,
  { {0xdc9a0049, 0x69450123, 0x00000000, 0x00000000}},  //   ציעל, _فضیل,   ,
  { {0x6490021e, 0xcfd80044, 0xf1260088, 0x00000000}},  //   täis, _সাইন, зько,
  { {0xc5f300a3, 0x00000000, 0x00000000, 0x00000000}},  //   _אדר_,   ,   ,
  { {0x649000b0, 0x5f940fd8, 0x859b009b, 0x00000000}},  //   räis, милт, _לשכו,
  { {0x6383025f, 0x443833c8, 0x98a0016c, 0x00000000}},  //   _згра, _inr_, _erić_,
  { {0x444401d9, 0x649033c9, 0x76440009, 0x00000000}},  //   lj_, päis, njiy,
  { {0x443833ca, 0x4444179b, 0x628000d9, 0x00000000}},  //   _knr_, oj_, _ijmo,
  { {0x444401d9, 0xfd0f0379, 0x7e7b00f6, 0x00000000}},  //   nj_, اجي_, anup,
  { {0x44380007, 0x444400bb, 0x4f660076, 0x00000000}},  //   _mnr_, ij_, _عاطف,
  { {0x7f3b00b6, 0x6aa400f4, 0x61e2087c, 0x00000000}},  //   _לעבו, _chif, naol,
  { {0x81e10044, 0x3ebe1ad0, 0x5a34005e, 0x00000000}},  //   _দাম_, _hutt_, хнят,
  { {0x8c43005e, 0x98a9050f, 0x3ebe0cfd, 0x00000000}},  //   _пече, _trač_, _kutt_,
  { {0x44440232, 0x3ebe006c, 0x7c3833cb, 0x00000000}},  //   dj_, _jutt_, _invr,
  { {0x44440046, 0x7afa0052, 0x61e2006c, 0x00000000}},  //   ej_, mutt, jaol,
  { {0x7afa021e, 0x4438001a, 0xe97300a1, 0x00000000}},  // [ab70] lutt, _bnr_, _سندھ,
  { {0x7c28018d, 0x44380197, 0x444433cc, 0x00000000}},  //   nddr, _cnr_, gj_,
  { {0x2c0e0061, 0x7afa0374, 0x443833cd, 0x00000000}},  //   त्यू_, nutt, _dnr_,
  { {0x44440065, 0x645c00d4, 0x27e3002b, 0x00000000}},  //   aj_, _elri, lajn_,
  { {0x44440061, 0x7afa0dcd, 0x92b401d8, 0x00000000}},  //   bj_, hutt, رحما,
  { {0x7afa33ce, 0x443800c4, 0x3ebe0133, 0x00000000}},  //   kutt, _gnr_, _butt_,
  { {0x9ea90256, 0x69c60039, 0x7afa33cf, 0x00000000}},  //   овка_, ycke, jutt,
  { {0x7afa33d0, 0xa29401fb, 0x7c280328, 0x00000000}},  //   dutt, _засі, eddr,
  { {0x3e6a007a, 0x6aa40016, 0xc212009b, 0x00000000}},  //   تجوی_, _rhif, _בהן_,
  { {0x6aa4166d, 0x8b0700b9, 0x7afa1b8a, 0x00000000}},  //   _shif, _naří, futt,
  { {0x28b701f5, 0x7afa06d3, 0x00000000, 0x00000000}},  //   _इंजि, gutt,   ,
  { {0x60db0045, 0x00000000, 0x00000000, 0x00000000}},  //   _kwum,   ,   ,
  { {0x752d0107, 0xb5fb01ca, 0x6d4606ec, 0x00000000}},  //   jvaz, _mlád, økat,
  { {0x7afa0056, 0xed16026c, 0x6e290016, 0x00000000}},  //   butt, _کہیں_, ldeb,
  { {0x66e60088, 0x3ebe002b, 0x7afa0095, 0x00000000}},  //   ьова, _xutt_, cutt,
  { {0x6e291d47, 0x44440061, 0x44380253, 0x00000000}},  //   ndeb, wj_, _snr_,
  { {0xa507003b, 0xfaa70123, 0xc9860025, 0x00000000}},  // [ab80] мета_, _تجوی, _تشغي,
  { {0xa3ba0025, 0x44440089, 0x7d090a59, 0x00000000}},  //   زائر_, uj_, ites,
  { {0x0206008b, 0x7d0933d1, 0x44442678, 0x00000000}},  //   дзен, htes, rj_,
  { {0x8b070224, 0x7d0920a7, 0x44440944, 0x00000000}},  //   _zaří, ktes, sj_,
  { {0x7d090065, 0x5183012b, 0x61e20051, 0x00000000}},  //   jtes, куша, raol,
  { {0x645c06d3, 0xdfcf057d, 0x3ebe0f51, 0x00000000}},  //   _ulri, ليه_, _putt_,
  { {0x61e20026, 0x08770049, 0x98aa0006, 0x00000000}},  //   paol, ועסט_, škės_,
  { {0x27e30626, 0x7d090065, 0x7afa00b0, 0x00000000}},  //   zajn_, ftes, vutt,
  { {0x7eb50006, 0x7d090010, 0xc0060999, 0x00000000}},  //   _išpl, gtes, _опак,
  { {0x61e00039, 0x7afa08a6, 0x3ebe0197, 0x00000000}},  //   _heml, tutt, _tutt_,
  { {0x93f700b3, 0x201c33d2, 0x7d0900ab, 0x00000000}},  //   וציא_, mevi_, ates,
  { {0x60c033d3, 0x7afa0409, 0xd9ad0055, 0x00000000}},  //   _kumm, rutt, _ক্ষম,
  { {0x27e301ee, 0x61e0014a, 0x7d0933d4, 0x00000000}},  //   tajn_, _meml, ctes,
  { {0x60c000b0, 0x7afa00b0, 0xa8a400ed, 0x00000000}},  //   _mumm, putt, врск,
  { {0xf794008b, 0x27e301d5, 0x60c0010e, 0x00000000}},  //   варэ, rajn_, _lumm,
  { {0x61e0068f, 0xb5fb0051, 0x00000000, 0x00000000}},  //   _neml, _amár,   ,
  { {0xddc90089, 0xd9ad0044, 0x660d006b, 0x00000000}},  // [ab90] nieš, _ক্রম, rfak,
  { {0x752d01bc, 0x201c0166, 0x660d00b4, 0x00000000}},  //   rvaz, jevi_, sfak,
  { {0xd37106f1, 0xa3a903d7, 0xc7d600b6, 0x00000000}},  //   دها_, खें_, _אותי_,
  { {0x3a2900b5, 0xa4d50088, 0xd3a405f6, 0x00000000}},  //   _jaap_, _помі, труп,
  { {0xb5fb0428, 0x7bca03e2, 0x3a2904be, 0x00000000}},  //   _vlád, _offu, _maap_,
  { {0x8fa501bd, 0x60c004fb, 0x78fc009b, 0x00000000}},  //   нале, _dumm, קלופ,
  { {0x2eb500ed, 0xd00e0379, 0x6e2933d5, 0x00000000}},  //   нсис, صلي_, tdeb,
  { {0x6d250113, 0x26c10087, 0x60db0009, 0x00000000}},  //   едиз, _muho_, _twum,
  { {0x6fca02d2, 0x6e290007, 0x26c10058, 0x00000000}},  //   _स्कू, rdeb, _luho_,
  { {0x61e014d5, 0x201c33d6, 0xf1b907ac, 0x00000000}},  //   _zeml, cevi_, _naši_,
  { {0x09ad0055, 0x7d0933d7, 0x224d33d8, 0x00000000}},  //   _ক্লা, stes, _koek_,
  { {0x60c0013f, 0x7bca0912, 0x7d0929b5, 0x00000000}},  //   _yumm, _effu, ptes,
  { {0x3ead0374, 0xddc9001e, 0x68fd0022, 0x00000000}},  //   mmet_, cieš, gusd,
  { {0x3ead0010, 0x26c1004a, 0x224d00d9, 0x00000000}},  //   lmet_, _buho_, _loek_,
  { {0x5a9600ed, 0x60130279, 0x6a960088, 0x00000000}},  //   _приф, mımı, _приє,
  { {0x09da0055, 0x3a290725, 0xb5fb0092, 0x00000000}},  //   _থাকা, _gaap_, _aláb,
  { {0xceb20097, 0x33f617b1, 0x3ead22c1, 0x00000000}},  // [aba0] רין_, ечес, imet_,
  { {0x60c00193, 0x3ead011f, 0x6013005d, 0x00000000}},  //   _rumm, hmet_, nımı,
  { {0x224d0100, 0x60c00038, 0x779402fd, 0x00000000}},  //   _boek_, _summ, _شیرا,
  { {0x3ead0065, 0x27e1010f, 0x20050026, 0x00000000}},  //   jmet_, _zehn_, _acli_,
  { {0x645b0047, 0x201c33d9, 0x3ead0027, 0x00000000}},  //   áció, tevi_, dmet_,
  { {0xddc90e3f, 0xe4d70025, 0x3ea600ab, 0x00000000}},  //   vieš, _سوفت_, _shot_,
  { {0x53a3005e, 0x201c014a, 0x5f9319e9, 0x00000000}},  //   _барб, revi_, лишт,
  { {0x442a001f, 0x60c00bf4, 0xaf3300a1, 0x00000000}},  //   _hab_, _tumm, اروت,
  { {0x644e0046, 0x442a0f2d, 0x201c08eb, 0x00000000}},  //   _kobi, _kab_, pevi_,
  { {0x224d02ae, 0xddc91fb9, 0x442a01a3, 0x00000000}},  //   _zoek_, rieš, _jab_,
  { {0x442a030c, 0x3ea60065, 0x59f9005e, 0x00000000}},  //   _mab_, _thot_, меня_,
  { {0x2456000c, 0x68fd0894, 0x2a600048, 0x00000000}},  //   _dæmi_, tusd, _clib_,
  { {0x2bd103d7, 0x442a0181, 0xf1b90089, 0x00000000}},  //   _द्वा, _oab_, _paši_,
  { {0x644e0207, 0x442a0145, 0x6013005a, 0x00000000}},  //   _nobi, _nab_, cımı,
  { {0xf1b91504, 0x443f33da, 0x7c2a298f, 0x00000000}},  //   _vaši_, _đu_, _iafr,
  { {0x442a0030, 0x3a290319, 0x7c2a0fe9, 0x00000000}},  //   _aab_, _uaap_, _hafr,
  { {0x442a033b, 0x59d40025, 0x644e2b5a, 0x00000000}},  // [abb0] _bab_, _صغير, _bobi,
  { {0x442a0675, 0x224d0343, 0x644e16ab, 0x00000000}},  //   _cab_, _soek_, _cobi,
  { {0x644e0213, 0x7c2a33db, 0x225f01d6, 0x00000000}},  //   _dobi, _mafr, _pluk_,
  { {0x7c2a01aa, 0x442a0032, 0x41b51289, 0x00000000}},  //   _lafr, _eab_, نمار,
  { {0x442a3059, 0x998033dc, 0x60130279, 0x00000000}},  //   _fab_, _kaiš_, yımı,
  { {0x644e0219, 0x80d30055, 0x442a33dd, 0x00000000}},  //   _gobi, _সিদ্, _gab_,
  { {0x3ead0023, 0x00000000, 0x00000000, 0x00000000}},  //   tmet_,   ,   ,
  { {0x3eb90203, 0x68ed00ca, 0x7c2a006c, 0x00000000}},  //   öst_, _ovad, _aafr,
  { {0x3ead053e, 0x5187017f, 0x60130279, 0x00000000}},  //   rmet_, _чува, tımı,
  { {0x09e10055, 0x3ead0006, 0x69cd0016, 0x00000000}},  //   _ভাষা, smet_, _afae,
  { {0x601301f6, 0x68ed33de, 0x7c2a12f0, 0x00000000}},  //   rımı, _avad, _dafr,
  { {0x161100e8, 0x68ed0146, 0x00000000, 0x00000000}},  //   _डॉलर_, _bvad,   ,
  { {0xed4e102a, 0x60130095, 0x68ed00e5, 0x00000000}},  //   _то_, pımı, _cvad,
  { {0x68ed31ee, 0x315601ce, 0x38a40039, 0x00000000}},  //   _dvad, דישן_, föra_,
  { {0x644e0620, 0x6b6633df, 0x68ed0035, 0x00000000}},  //   _robi, _végé, _evad,
  { {0x644e33e0, 0xdbe2009d, 0x7c2a016e, 0x00000000}},  //   _sobi, _rééd, _zafr,
  { {0xd040005f, 0x644e33e1, 0x6e2b006a, 0x00000000}},  // [abc0] _etmə, _pobi, _magb,
  { {0x446301f9, 0x42d601ff, 0x037a01b7, 0x00000000}},  //   авув, віду, وحات_,
  { {0x644e000a, 0x442a0203, 0xf206007e, 0x00000000}},  //   _vobi, _vab_, вяло,
  { {0x6e2b006a, 0xd2590088, 0x90e60014, 0x00000000}},  //   _nagb, нці_, نستن,
  { {0x442a09e0, 0xa06a01ee, 0x00000000, 0x00000000}},  //   _tab_, мада_,   ,
  { {0x442a010a, 0x627c01dc, 0x644e0091, 0x00000000}},  //   _uab_, jčov, _uobi,
  { {0x7c2a33e2, 0x6e2b0190, 0xe9f90082, 0x00000000}},  //   _rafr, _bagb, _chẻ_,
  { {0x7c2a1529, 0x6604027e, 0x387801a2, 0x00000000}},  //   _safr, ngik, hirr_,
  { {0xa3d6007d, 0xdbdc000c, 0x6282109a, 0x00000000}},  //   _सभा_, _báðu, mnoo,
  { {0x3fcb1125, 0x00000000, 0x00000000, 0x00000000}},  //   _قدمی_,   ,   ,
  { {0x6fd80164, 0x68ed3190, 0x6e2b0637, 0x00000000}},  //   _न्यू, _svad, _fagb,
  { {0x6f79007b, 0x628200c7, 0xfee90025, 0x00000000}},  //   _אָנג, nnoo, _أعلى_,
  { {0x6e2033e3, 0xe0c00044, 0xd8770379, 0x00000000}},  //   memb, _উবুন, ناسب,
  { {0x6e200be2, 0x58d40256, 0x7d00030e, 0x00000000}},  //   lemb, рорт, mums,
  { {0x7e6200b5, 0x8c1b009b, 0x6e2b00e0, 0x00000000}},  //   _klop, _חווי, _yagb,
  { {0x6e2004d4, 0x80d30044, 0x66040176, 0x00000000}},  //   nemb, _সিস্, ggik,
  { {0xa5070057, 0x39440039, 0x5507005e, 0x00000000}},  // [abd0] ъявл, ämst_, ъчва,
  { {0x07eb026c, 0x6e200145, 0xd37b00e3, 0x00000000}},  //   _کرکٹ_, hemb, мче_,
  { {0x6e2033e4, 0x623500ed, 0x764f0016, 0x00000000}},  //   kemb, лежу, _tocy,
  { {0x7d0016aa, 0x625300c4, 0xcb130049, 0x00000000}},  //   kums, _açor, ילע_,
  { {0xed46025a, 0x7d001e5f, 0xe4e40088, 0x00000000}},  //   _اپ_, jums, _вісн,
  { {0xaa2003d7, 0x6e2b00ea, 0x628201d6, 0x00000000}},  //   _बस्छ_, _sagb, anoo,
  { {0x4421012d, 0x6e2b006a, 0xdbdc000c, 0x00000000}},  //   meh_, _pagb, _ráðu,
  { {0x4421027e, 0x7e62001a, 0x3e7a0089, 0x00000000}},  //   leh_, _clop, dīts_,
  { {0xf1b90089, 0x7d000089, 0x00000000, 0x00000000}},  //   _pašu_, gums,   ,
  { {0xe9f9001d, 0x44210059, 0x7e620145, 0x00000000}},  //   _thẻ_, neh_, _elop,
  { {0xf1b933e5, 0x09e60069, 0x6e201baa, 0x00000000}},  //   _vašu_, лонн, bemb,
  { {0xcd3504e8, 0x44212c76, 0x7d000240, 0x00000000}},  //   _مرتب, heh_, bums,
  { {0x9f470065, 0x4421008a, 0xdea1025a, 0x00000000}},  //   kanë_, keh_, _پیکی,
  { {0x44210209, 0x6c790049, 0x00000000, 0x00000000}},  //   jeh_, _ראַפ,   ,
  { {0x44210229, 0x91e301f5, 0x7c2101d6, 0x00000000}},  //   deh_, खराज_, melr,
  { {0x7874006b, 0x00000000, 0x00000000, 0x00000000}},  //   _müvə,   ,   ,
  { {0xe9f90011, 0x85060025, 0x9f4c0026, 0x00000000}},  // [abe0] _nhẹ_, طوان, _addì_,
  { {0x6e2033e6, 0x29020169, 0x44210145, 0x00000000}},  //   zemb, muka_, geh_,
  { {0x6e20011c, 0x29020091, 0x628201d6, 0x00000000}},  //   yemb, luka_, tnoo,
  { {0x26d808d3, 0xa77b0097, 0xe6460256, 0x00000000}},  //   mpro_, _טריפ, _семп,
  { {0x29020027, 0x6282066a, 0xb87b00c4, 0x00000000}},  //   nuka_, rnoo, rsív,
  { {0x3cf903d7, 0xb87b02d5, 0x628200bb, 0x00000000}},  //   ोंने_, ssív, snoo,
  { {0x29020569, 0xda0a0061, 0x7e620035, 0x00000000}},  //   huka_, _वाढत_, _plop,
  { {0x7d00176f, 0x2902055b, 0xe3c1005d, 0x00000000}},  //   tums, kuka_, ğış_,
  { {0x127b007b, 0x6e200461, 0x9be6008b, 0x00000000}},  //   _נאמע, remb, лінк,
  { {0x7d001e49, 0x13e80055, 0x7ea50047, 0x00000000}},  //   rums, _পাড়, rópa,
  { {0x6e201f0f, 0x7d000433, 0x7d090065, 0x00000000}},  //   pemb, sums, _përç,
  { {0x442107b9, 0x29020020, 0xfce6025f, 0x00000000}},  //   zeh_, fuka_, _бодо,
  { {0x6e930025, 0x3e7a0089, 0x29020020, 0x00000000}},  //   _النا, sīts_, guka_,
  { {0x6d4600b0, 0x00000000, 0x00000000, 0x00000000}},  //   äkau,   ,   ,
  { {0x395f08ad, 0xab27025f, 0x4421037a, 0x00000000}},  //   šus_, _боја_, veh_,
  { {0xf8bf00f4, 0xaa0900a1, 0x9f4501d6, 0x00000000}},  //   uvés_, _شعبے_, _belê_,
  { {0xf8bf00f4, 0x628300f4, 0x442101a3, 0x00000000}},  // [abf0] rvés_, énom, teh_,
  { {0x225d0093, 0xb5fb008e, 0xe3b30025, 0x00000000}},  //   wkwk_, _glán, مرض_,
  { {0x9f470065, 0x69dd00e0, 0x6aad0022, 0x00000000}},  //   ranë_, obse, _khaf,
  { {0x64480263, 0x60cd00dc, 0x442101a3, 0x00000000}},  //   _òdin, íamo, seh_,
  { {0x44210059, 0x9f450007, 0x614501fc, 0x00000000}},  //   peh_, _gelê_, рела,
  { {0x00840088, 0x645e0f10, 0x3f9e2041, 0x00000000}},  //   бліо, ckpi, _bytu_,
  { {0x29020020, 0x02a7007e, 0x656d010f, 0x00000000}},  //   zuka_, _брам, lzah,
  { {0xee3900d7, 0x43840025, 0x29021658, 0x00000000}},  //   тни_, _الفق, yuka_,
  { {0x656d31c1, 0x7c210232, 0x7db4007e, 0x00000000}},  //   nzah, telr, йсьц,
  { {0x9f6b0265, 0x5c550264, 0x61eb095b, 0x00000000}},  //   _през_, ртиф, lagl,
  { {0x29020009, 0x68fd1225, 0x656d01a2, 0x00000000}},  //   wuka_, ersd, hzah,
  { {0xdef601f8, 0x6aad0246, 0xb5fb002a, 0x00000000}},  //   _כמעט_, _chaf, _slán,
  { {0x8c4500ed, 0x6f03023a, 0xb5fb0161, 0x00000000}},  //   _веле, lunc, _plán,
  { {0x2902045e, 0x61eb33e7, 0x200701e5, 0x00000000}},  //   ruka_, hagl, ngni_,
  { {0x6f030198, 0xfaa60057, 0x7ea50181, 0x00000000}},  //   nunc, _како, nópo,
  { {0x7afc076b, 0xdeef007e, 0x29020020, 0x00000000}},  //   árte, цыi_, puka_,

  { {0x69c404b4, 0x61eb0197, 0x26d800ea, 0x00000000}},  // [ac00] _igie, dagl, spro_,
  { {0x68e40009, 0xe45f00f8, 0x69c401f3, 0x00000000}},  //   _iwid, _stör_, _hgie,
  { {0x6f030951, 0x0326026b, 0x87fb0049, 0x00000000}},  //   junc, рден, _בליץ,
  { {0xb87b0010, 0x61eb0197, 0x6aad0065, 0x00000000}},  //   ssít, gagl, _xhaf,
  { {0x7bc30207, 0x00000000, 0x00000000, 0x00000000}},  //   _ognu,   ,   ,
  { {0xa07301fb, 0x00000000, 0x00000000, 0x00000000}},  //   огіч,   ,   ,
  { {0x6f03071a, 0x61eb0197, 0xdc21002b, 0x00000000}},  //   gunc, bagl, _eċċi,
  { {0xa2cb0201, 0x62890065, 0x61eb0026, 0x00000000}},  //   _तंत्, _gjeo, cagl,
  { {0xbebc0089, 0x5c98005e, 0x90460014, 0x00000000}},  //   _krīz, лкия_, _پناه,
  { {0x9f47120f, 0x229c000c, 0x6aad24f6, 0x00000000}},  //   zané_, ríku_, _shaf,
  { {0xe9f9001d, 0x6f030026, 0xd4370097, 0x00000000}},  //   _chế_, cunc, בריק_,
  { {0xc33300b6, 0x7e6900bb, 0x644100f6, 0x00000000}},  //   קור_, chep, _òliv,
  { {0x9f470428, 0xdd920076, 0x27270016, 0x00000000}},  //   vané_, _بوش_, _sŵn_,
  { {0xdc080089, 0x78620027, 0x68e40022, 0x00000000}},  //   _rēķi, _dôvo, _dwid,
  { {0xe816024c, 0xe9f90011, 0x683c00f8, 0x00000000}},  //   द्धा_, _ghế_, _sådä,
  { {0x656d010f, 0xb8fd0044, 0x9f450173, 0x00000000}},  //   tzah, _ডি_, _delè_,
  { {0x61eb0ef1, 0x611a0089, 0x68e4002b, 0x00000000}},  // [ac10] vagl, nālā, _gwid,
  { {0x9865026c, 0xea000011, 0x6f03005a, 0x00000000}},  //   _ایسے_, _trải_, yunc,
  { {0x61eb129e, 0x656d010f, 0xbebc0089, 0x00000000}},  //   tagl, szah, _drīz,
  { {0x09bb0055, 0x7e690023, 0xb5fb01e5, 0x00000000}},  //   _অ্যা, xhep, _klám,
  { {0x61eb33e8, 0x200c0045, 0x00000000, 0x00000000}},  //   ragl, _bcdi_,   ,
  { {0x6f0326e4, 0x00000000, 0x00000000, 0x00000000}},  //   tunc,   ,   ,
  { {0x61eb33e9, 0x443133ea, 0xb5fb008e, 0x00000000}},  //   pagl, _iaz_, _llám,
  { {0x6f03027b, 0x443133eb, 0x6d49022b, 0x00000000}},  //   runc, _haz_, txea,
  { {0x443114fe, 0xee3600a5, 0x7ea533ec, 0x00000000}},  //   _kaz_, сны_, sópo,
  { {0x3c650057, 0x443101d9, 0xac180088, 0x00000000}},  //   ског, _jaz_, ацює_,
  { {0x61e90004, 0x64553322, 0x2012005f, 0x00000000}},  //   _keel, _mozi, əyi_,
  { {0x60c1000c, 0x64550213, 0x78620027, 0x00000000}},  //   _hilm, _lozi, _pôvo,
  { {0x61e90004, 0x60c10006, 0xdcc80082, 0x00000000}},  //   _meel, _kilm, _tỉa_,
  { {0xe9f900ad, 0x64550089, 0x44310b79, 0x00000000}},  //   _thế_, _nozi, _naz_,
  { {0xec120439, 0x00000000, 0x00000000, 0x00000000}},  //   _رويد,   ,   ,
  { {0x9f4501ca, 0x68e40719, 0xcf9200a3, 0x00000000}},  //   _celé_, _twid, פטן_,
  { {0x443101aa, 0x62990036, 0x05aa005e, 0x00000000}},  // [ac20] _baz_, dowo, увай_,
  { {0x64550181, 0x4431001a, 0x48060088, 0x00000000}},  //   _cozi, _caz_, _упов,
  { {0x6455037e, 0x61e933ed, 0xddcb0036, 0x00000000}},  //   _dozi, _beel, _mogł,
  { {0xdb9a0049, 0x171b0049, 0x44310288, 0x00000000}},  //   אסער, _גוטע, _eaz_,
  { {0x60c1038c, 0x443102d5, 0x61e901b5, 0x00000000}},  //   _bilm, _faz_, _deel,
  { {0xd259001e, 0x84590098, 0x60c90197, 0x00000000}},  //   _viņa_, _крст_, _duem,
  { {0x26c2107e, 0x60c10181, 0x61e900ab, 0x00000000}},  //   _kiko_, _dilm, _feel,
  { {0x61e901d6, 0x62990036, 0xe29a1079, 0x00000000}},  //   _geel, cowo, _саб_,
  { {0x4431047f, 0xe9f90082, 0xdc3c002b, 0x00000000}},  //   _yaz_, _chẽ_, _aġġu,
  { {0x26c20006, 0x60c100c4, 0x61e900b5, 0x00000000}},  //   _liko_, _gilm, _zeel,
  { {0xfd0f0167, 0xb4db0129, 0x6a6601e5, 0x00000000}},  //   وجی_, _gràf, _sófa,
  { {0x26c22924, 0x00000000, 0x00000000, 0x00000000}},  //   _niko_,   ,   ,
  { {0x2e37009b, 0x1dac007d, 0x60c10095, 0x00000000}},  //   _לראש_, _चरित, _yilm,
  { {0x26c2082c, 0x67d40072, 0x00000000, 0x00000000}},  //   _aiko_, зору,   ,
  { {0x27ff038c, 0x44310620, 0xeac90011, 0x00000000}},  //   ğun_, _raz_, _hẹn_,
  { {0x645533ee, 0x4431057e, 0xea000011, 0x00000000}},  //   _sozi, _saz_, _trại_,
  { {0x54550057, 0x61e90030, 0x44310489, 0x00000000}},  // [ac30] оват, _reel, _paz_,
  { {0x4431005f, 0x62990c28, 0x628a00f6, 0x00000000}},  //   _qaz_, wowo, éfon,
  { {0x64551b3b, 0x94a80265, 0x4431006b, 0x00000000}},  //   _vozi, стта_, _vaz_,
  { {0x60c108b2, 0x443101a2, 0x00000000, 0x00000000}},  //   _silm, _waz_,   ,
  { {0x44311515, 0xe3e80055, 0x61e90277, 0x00000000}},  //   _taz_, _পারব, _veel,
  { {0x81e10055, 0x212d01d9, 0x26c20020, 0x00000000}},  //   _দাও_, _vseh_, _ziko_,
  { {0x786b011f, 0x60c103c9, 0x61e9006c, 0x00000000}},  //   _güve, _vilm, _teel,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60c10018, 0x2bda01f5, 0x60c9006c, 0x00000000}},  //   _tilm, _म्हा, _uuem,
  { {0x2a690058, 0xb4db00d4, 0x2f4000e5, 0x00000000}},  //   _alab_, _tràf, _băgă_,
  { {0x2dd50aef, 0xb4db00d4, 0xaa4a09e6, 0x00000000}},  //   _джер, _fràg, апна_,
  { {0x753d0047, 0x2a690026, 0x7afc296d, 0x00000000}},  //   _orsz, _clab_, árta,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26c20058, 0x2a69006c, 0xb7da0014, 0x00000000}},  //   _siko_, _elab_, شورا_,
  { {0x18a3008b, 0x81ea0044, 0x26c20c8a, 0x00000000}},  //   фарм, _মাস_, _piko_,
  { {0x8afc0036, 0x2a6900e0, 0x00000000, 0x00000000}},  //   rzęt, _glab_,   ,
  { {0xa50a0216, 0xeac90011, 0xe5a30088, 0x00000000}},  // [ac40] реза_, _kẹo_, дити,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xeac90011, 0x26c205a0, 0x00000000, 0x00000000}},  //   _mẹo_, _tiko_,   ,
  { {0xe29a007e, 0xe816006e, 0x00000000, 0x00000000}},  //   шае_, द्रा_,   ,
  { {0x764601c3, 0x00000000, 0x00000000, 0x00000000}},  //   _inky,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xed50026c, 0x42d60245, 0x00000000, 0x00000000}},  //   کھا_, _фігу,   ,
  { {0xbe8a012b, 0x2000001a, 0x42d533ef, 0x00000000}},  //   јске_, şii_, _хіру,
  { {0xddc20036, 0xd2590089, 0xd00a003b, 0x00000000}},  //   _umoż, _ziņo_, _везе_,
  { {0x09e3001c, 0x0bf30057, 0x2a692509, 0x00000000}},  //   पर्य, мпью, _slab_,
  { {0x20d0001d, 0x2c6001aa, 0x4e2a00ed, 0x00000000}},  //   _hài_, _jòdi_, _воен_,
  { {0x61e2002d, 0xb5fb01ca, 0x00000000, 0x00000000}},  //   nbol, _vlák,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x20d00011, 0xd7c90379, 0x7eb5016c, 0x00000000}},  //   _mài_, صوره_, _ušpr,
  { {0x61e233f0, 0x7c281e3d, 0xdcc80011, 0x00000000}},  //   kbol, medr, _mỉm_,
  { {0x61e200ee, 0xfb870014, 0x20d00082, 0x00000000}},  //   jbol, _بدهی, _oài_,
  { {0x61e20018, 0x9f47120f, 0x20d00082, 0x00000000}},  // [ac50] dbol, vaní_, _nài_,
  { {0xa3a7012b, 0x7c2801ee, 0x764601aa, 0x00000000}},  //   ојек, nedr, _enky,
  { {0x8c250055, 0xd49801ff, 0x00000000, 0x00000000}},  //   বাচন_, іру_,   ,
  { {0x20d000ad, 0x7c280133, 0x00000000, 0x00000000}},  //   _bài_, hedr,   ,
  { {0xdd860054, 0x20d0001d, 0x71270076, 0x00000000}},  //   _أو_, _cài_, ترال,
  { {0x20d0001d, 0x55ba00b6, 0x7c281220, 0x00000000}},  //   _dài_, _למרו, jedr,
  { {0x61e233f1, 0xdb03004f, 0x644700f0, 0x00000000}},  //   bbol, _ozná, _inji,
  { {0x660d04d4, 0x290200d8, 0x69db0b6d, 0x00000000}},  //   ngak, yrka_, ñuel,
  { {0x6447092f, 0xb5fb0051, 0x61fb188a, 0x00000000}},  //   _knji, _clái, _idul,
  { {0x7c280168, 0x60db00e7, 0x00000000, 0x00000000}},  //   gedr, _itum,   ,
  { {0x628b0020, 0xfaa600c0, 0xbb4502d3, 0x00000000}},  //   ongo, зано, ченк,
  { {0x752d0020, 0xce380025, 0x213f02db, 0x00000000}},  //   kwaz, _وأنا_, _kruh_,
  { {0x7c2800b5, 0x20d00011, 0x752d32ac, 0x00000000}},  //   bedr, _xài_, jwaz,
  { {0x60db000b, 0x7d0907ed, 0x9f4700c4, 0x00000000}},  //   _mtum, mues, canã_,
  { {0xa7aa0057, 0x7d090efc, 0xf743007c, 0x00000000}},  //   сква_, lues, неро,
  { {0x644704cb, 0xc6c333f2, 0xf53f02e1, 0x00000000}},  //   _anji, ейск, _brå_,
  { {0x7d090065, 0x2bd2006e, 0xb4db00d4, 0x00000000}},  // [ac60] nues, _सलमा, _aràb,
  { {0x39400051, 0x61fb0472, 0x628b044a, 0x00000000}},  //   _iris_, _adul, engo,
  { {0x20d00011, 0xf8b3009b, 0x60db047b, 0x00000000}},  //   _sài_, _רשת_, _atum,
  { {0x39400263, 0xf53f0c64, 0x7d090065, 0x00000000}},  //   _kris_, _frå_, kues,
  { {0x463b0049, 0xc243007e, 0xf53f0c88, 0x00000000}},  //   _העכע, энцк, _grå_,
  { {0x20d0001d, 0x61fb00b0, 0x7d090065, 0x00000000}},  //   _vài_, _edul, dues,
  { {0x7c28049a, 0x91e6012b, 0xb5fb002a, 0x00000000}},  //   vedr, _нове, _slái,
  { {0x20d0001d, 0x786b006b, 0x78700039, 0x00000000}},  //   _tài_, _müva, _hävd,
  { {0x7d090181, 0x2ab20047, 0x62820103, 0x00000000}},  //   gues, kább_, mioo,
  { {0xf04400a6, 0x628207a4, 0xdfcf0025, 0x00000000}},  //   _تعری, lioo, _ميك_,
  { {0x7c2800eb, 0x3940008a, 0x2fd70014, 0x00000000}},  //   redr, _aris_, _روند_,
  { {0xaf490054, 0xcf250025, 0x3940005b, 0x00000000}},  //   _بشكل_, _تركي, _bris_,
  { {0x7d090211, 0x7c2800d4, 0xb5fb01ca, 0x00000000}},  //   cues, pedr, _kláv,
  { {0x80e10044, 0xd918007c, 0x00000000, 0x00000000}},  //   _নিম্, чью_,   ,
  { {0x628b0016, 0xec37009b, 0xba3b0685, 0x00000000}},  //   yngo, _מאגר_, toïd,
  { {0x752d30f3, 0x443f011f, 0x394000bb, 0x00000000}},  //   twaz, _şu_, _fris_,
  { {0x39401697, 0x6fcc0061, 0x660d006c, 0x00000000}},  // [ac70] _gris_, ाशां, rgak,
  { {0x628b0016, 0x752d0251, 0x7ea51c3e, 0x00000000}},  //   wngo, rwaz, rópi,
  { {0x290b33f3, 0x7d090065, 0x2919002d, 0x00000000}},  //   luca_, zues, ltsa_,
  { {0xe3b00054, 0x628b33f4, 0x6282006c, 0x00000000}},  //   ارك_, ungo, gioo,
  { {0x2919002d, 0x7d090065, 0x628b0ede, 0x00000000}},  //   ntsa_, xues, rngo,
  { {0xf994007b, 0x8fa500e3, 0x6e290009, 0x00000000}},  //   ערס_, мале, weeb,
  { {0x9028007e, 0xe81f01f5, 0x6e2901c3, 0x00000000}},  //   яцца_, म्या_, teeb,
  { {0x7d0933f5, 0xb4db04bd, 0x7bd801c3, 0x00000000}},  //   tues, _gràc, _afvu,
  { {0x60db000b, 0x290b0181, 0x63a70065, 0x00000000}},  //   _utum, juca_, _hyjn,
  { {0x7d09008d, 0x290b0035, 0x787000b0, 0x00000000}},  //   rues, duca_, _käve,
  { {0x6ee701b7, 0x2ab20047, 0x7d09008d, 0x00000000}},  //   _رسال, vább_, sues,
  { {0x39400018, 0x7d090219, 0x38a4010f, 0x00000000}},  //   _pris_, pues, hört_,
  { {0x7d090a2c, 0x290b0107, 0x786b33f6, 0x00000000}},  //   ques, guca_, _süva,
  { {0x04030044, 0xcb69003b, 0x66090089, 0x00000000}},  //   র্তী_, _мале_, _ķeka,
  { {0x07a3012b, 0xb8d50316, 0xc7950641, 0x00000000}},  //   варн, _छी_, ерты,
  { {0x39400006, 0x38a4000c, 0xd9f20309, 0x00000000}},  //   _tris_, vöru_, _अजित_,
  { {0x14c8007a, 0x3940041d, 0xe45a0c4e, 0x00000000}},  // [ac80] سهای_, _uris_, ожа_,
  { {0x26cc32f3, 0xa2e6007c, 0x88c60025, 0x00000000}},  //   ídos_, дожд, _تتعل,
  { {0xb4db0129, 0x3e7a0089, 0x62820052, 0x00000000}},  //   _pràc, sūti_, tioo,
  { {0xb87b153d, 0x41aa05f6, 0xb5fb04bb, 0x00000000}},  //   mpía, овен_, _sláv,
  { {0xb5fb00f7, 0x9f470428, 0x6282006c, 0x00000000}},  //   _cláu, vaná_, rioo,
  { {0x62820004, 0xa3c80164, 0x00000000, 0x00000000}},  //   sioo, _उलट_,   ,
  { {0x44381c92, 0x645c0026, 0x7ea5000c, 0x00000000}},  //   _iar_, _iori, hópu,
  { {0x645c022b, 0x44380cb2, 0x1d340001, 0x00000000}},  //   _hori, _har_, ения,
  { {0x645c0119, 0x443801d9, 0x9f4702d5, 0x00000000}},  //   _kori, _kar_, raná_,
  { {0x645c1a8f, 0x6aa40020, 0x515b009b, 0x00000000}},  //   _jori, _akif, _וכמו,
  { {0x44380195, 0x09e00044, 0x00000000, 0x00000000}},  //   _mar_, _ভয়া,   ,
  { {0x44382ac3, 0x6ab6018e, 0xaacf007d, 0x00000000}},  //   _lar_, _chyf, _संरक,
  { {0x443800f6, 0x394d0181, 0x6e220058, 0x00000000}},  //   _oar_, ães_, _ibob,
  { {0x645c010a, 0x4438002b, 0x29190032, 0x00000000}},  //   _nori, _nar_, rtsa_,
  { {0x25ad1556, 0x60c833f7, 0x628001f3, 0x00000000}},  //   _šel_, _midm, _ommo,
  { {0x6d4232fc, 0x443805a6, 0x60c833f8, 0x00000000}},  //   _kroa, _aar_, _lidm,
  { {0x7c38014a, 0x38b60030, 0x69cd0051, 0x00000000}},  // [ac90] _kavr, færd_, _igae,
  { {0x62800a19, 0x645c1c37, 0x4438030a, 0x00000000}},  //   _ammo, _cori, _car_,
  { {0x443833f9, 0x645c000d, 0x7c380059, 0x00000000}},  //   _dar_, _dori, _mavr,
  { {0x23df02fb, 0x53df02f4, 0x68ed002b, 0x00000000}},  //   _प्रद, _प्रश, _kwad,
  { {0x60250001, 0x645c1183, 0x6d44010a, 0x00000000}},  //   едла, _fori, _šian,
  { {0x645c0059, 0x7c3801ca, 0x4438010f, 0x00000000}},  //   _gori, _navr, _gar_,
  { {0x8fa20175, 0x765d1e89, 0x60c80006, 0x00000000}},  //   лаше, _kosy, _didm,
  { {0x645c33fa, 0x9f4501ca, 0x6d4200ab, 0x00000000}},  //   _zori, _celá_, _broa,
  { {0xddc225c2, 0x38b605b7, 0x6ab60016, 0x00000000}},  //   _ploš, lære_, _rhyf,
  { {0x6aa4068f, 0x7c3833fb, 0x44380d82, 0x00000000}},  //   _skif, _cavr, _xar_,
  { {0x09c801f5, 0x6d4233fc, 0x7c38005a, 0x00000000}},  //   रख्य, _eroa, _davr,
  { {0x6d42027b, 0xdb1e00b9, 0x765d2059, 0x00000000}},  //   _froa, áván, _nosy,
  { {0x7c380190, 0x44230387, 0x6d42001a, 0x00000000}},  //   _favr, _obj_, _groa,
  { {0x60c8005f, 0x7e690146, 0x7ea5000c, 0x00000000}},  //   _xidm, lkep, rópu,
  { {0x7d1b014a, 0x645c2ef6, 0xd5b70082, 0x00000000}},  //   ltus, _rori, ếng_,
  { {0x4438002b, 0x7c380119, 0x645c1c68, 0x00000000}},  //   _sar_, _zavr, _sori,
  { {0x443833fd, 0xeb1f02d2, 0x645c0027, 0x00000000}},  // [aca0] _par_, _बहुत_, _pori,
  { {0x7d1b00b0, 0xb5fb000c, 0x7e69010e, 0x00000000}},  //   itus, _slát, hkep,
  { {0x44380635, 0x645c049b, 0x020601f9, 0x00000000}},  //   _var_, _vori, езен,
  { {0xe29702be, 0x443803a1, 0x7d1b0010, 0x00000000}},  //   нах_, _war_, ktus,
  { {0x443821b3, 0x216704f9, 0x645c0207, 0x00000000}},  //   _tar_, ници_, _tori,
  { {0xdfcf006d, 0x68fb0181, 0x6e220026, 0x00000000}},  //   ميه_, áudi, _sbob,
  { {0x60c833fe, 0x7d1b006c, 0x00000000, 0x00000000}},  //   _vidm, etus,   ,
  { {0xb65b007b, 0x6d42001a, 0x7c380119, 0x00000000}},  //   ִדיש, _proa, _savr,
  { {0xb5fb000c, 0x2dd70025, 0x6e39000a, 0x00000000}},  //   _klár, ربية_, _dawb,
  { {0x20c9023c, 0x00000000, 0x00000000, 0x00000000}},  //   _قبلي_,   ,   ,
  { {0x141b007b, 0x68ed1987, 0x7c3a063d, 0x00000000}},  //   הויב, _swad, rdtr,
  { {0x79a70088, 0xed5a05f6, 0x6d42005b, 0x00000000}},  //   ерге, _ное_, _troa,
  { {0x765d33ff, 0x3ea61876, 0x984b005e, 0x00000000}},  //   _rosy, _ikot_, пява_,
  { {0x765d3400, 0xd259001e, 0x00000000, 0x00000000}},  //   _sosy, _viņi_,   ,
  { {0x36d5003b, 0xf794007e, 0x00000000, 0x00000000}},  //   тобр, гарэ,   ,
  { {0x68ed0870, 0xb5fb0327, 0x44230082, 0x00000000}},  //   _twad, _alár, _sbj_,
  { {0x44230022, 0xa3d50930, 0x00000000, 0x00000000}},  // [acb0] _pbj_, возч,   ,
  { {0xb5fb3401, 0x7bda00e5, 0xb4ab013d, 0x00000000}},  //   _clár, nctu, खते_,
  { {0xf990025a, 0x7219041f, 0x430b007e, 0x00000000}},  //   _نبی_, джер_, яхам_,
  { {0x38b61565, 0x00000000, 0x00000000, 0x00000000}},  //   rære_,   ,   ,
  { {0x865a00b3, 0x229c0802, 0xe0d80088, 0x00000000}},  //   _חדרי, níky_, еві_,
  { {0x1ae60044, 0x7afa00ea, 0x644300fa, 0x00000000}},  //   _কিনে_, kstt, ônid,
  { {0x201a0129, 0x7ff4023c, 0xd00e0379, 0x00000000}},  //   òpia_, اسها, زلي_,
  { {0x7d1b0ad1, 0xfe4500ed, 0x7bda001a, 0x00000000}},  //   ttus, тнио, ectu,
  { {0x6e3b00b9, 0xee3600a5, 0x26d30181, 0x00000000}},  //   rdub, тны_, _luxo_,
  { {0x7d1b224a, 0x3ea600f8, 0xbc62007c, 0x00000000}},  //   rtus, _ekot_, ивык,
  { {0x7d1b0cfc, 0x6e3900e7, 0x00000000, 0x00000000}},  //   stus, _tawb,   ,
  { {0x26cb0007, 0x225f0263, 0x7ea53402, 0x00000000}},  //   _nico_, _jouk_, róps,
  { {0x3ead0374, 0x3ebf0052, 0x4e7a0049, 0x00000000}},  //   mlet_, mmut_, _קאנצ,
  { {0x3ea01144, 0x7d091331, 0x3ebf010f, 0x00000000}},  //   čite_, mres, lmut_,
  { {0x44ef0046, 0x07a602a8, 0x7d0923fd, 0x00000000}},  //   eż_, тавн, lres,
  { {0x7aed0036, 0x7d0900ab, 0x225f00d9, 0x00000000}},  //   _łatw, ores, _nouk_,
  { {0x7d090129, 0x26cb27b9, 0xdb2300a1, 0x00000000}},  // [acc0] nres, _dico_, _شوکی,
  { {0xb4db3403, 0x3ead0066, 0x7d0904a5, 0x00000000}},  //   _tràn, hlet_, ires,
  { {0x3ead30c7, 0x7d09010f, 0x26cb12a1, 0x00000000}},  //   klet_, hres, _fico_,
  { {0x7d09326f, 0x6d44010a, 0x518603e0, 0x00000000}},  //   kres, _šiam, кула,
  { {0xc05a0088, 0x7d090146, 0x224d00d9, 0x00000000}},  //   дій_, jres, _dnek_,
  { {0x7d090322, 0x80e10055, 0xdc080089, 0x00000000}},  //   dres, _নিশ্, _mēģi,
  { {0x3ead001a, 0x644e3404, 0x7d090197, 0x00000000}},  //   flet_, _inbi, eres,
  { {0x7d09018e, 0x80e10055, 0x539b00a0, 0x00000000}},  //   fres, _নির্, _חילו,
  { {0x7d090781, 0x8cf3008b, 0x27f83405, 0x00000000}},  //   gres, азыц, karn_,
  { {0x3ead0796, 0x225f009d, 0x2a600146, 0x00000000}},  //   alet_, _zouk_, _aoib_,
  { {0x3ead0374, 0xe7bd0044, 0x7d090052, 0x00000000}},  //   blet_, _অভ্য, ares,
  { {0x9e66091b, 0x7d090919, 0x3ead02d0, 0x00000000}},  //   _швед, bres, clet_,
  { {0x26cb1595, 0x7d090207, 0x7afa00e0, 0x00000000}},  //   _rico_, cres, sstt,
  { {0xd77700f3, 0x290518e2, 0x5c730088, 0x00000000}},  //   نازع, čla_, _кліт,
  { {0xd259001e, 0x26cb0325, 0x25ae006b, 0x00000000}},  //   _ziņu_, _pico_, əfli_,
  { {0x644e001f, 0x88e20044, 0xdce9012d, 0x00000000}},  //   _anbi, _বিরক, uzeć,
  { {0x26cb0197, 0x00000000, 0x00000000, 0x00000000}},  // [acd0] _vico_,   ,   ,
  { {0x291e001a, 0x3ead0010, 0x225f0068, 0x00000000}},  //   ătat_, zlet_, _souk_,
  { {0x3e71009f, 0x7d0901ee, 0x3ea43406, 0x00000000}},  //   _láta_, zres, komt_,
  { {0x69dd0010, 0x644e2cab, 0x7d090056, 0x00000000}},  //   ncse, _enbi, yres,
  { {0x3ead014a, 0x7d090203, 0x00000000, 0x00000000}},  //   vlet_, xres,   ,
  { {0x7d093407, 0x644e0173, 0x38610085, 0x00000000}},  //   vres, _gnbi, _johr_,
  { {0x28da013d, 0xeaca0011, 0xf2c702dc, 0x00000000}},  //   _यूनि, _kẹt_, _асан,
  { {0x7d090073, 0x224d0022, 0x3ead0068, 0x00000000}},  //   tres, _unek_, ulet_,
  { {0x3ead2d0f, 0x2d993265, 0x7d09007f, 0x00000000}},  //   rlet_, çse_, ures,
  { {0x3e710611, 0xd259001e, 0xbed5025f, 0x00000000}},  //   _dáta_, _viņu_, _божј,
  { {0xba3b3408, 0x27f80203, 0x290b00f6, 0x00000000}},  //   roïn, varn_, erca_,
  { {0x3f7a007b, 0x00000000, 0x00000000, 0x00000000}},  //   _אָדע,   ,   ,
  { {0x3236007b, 0x38613409, 0xf99201b7, 0x00000000}},  //   נטשן_, _bohr_, صبح_,
  { {0xe73a1001, 0x8c6701fc, 0x81ea0044, 0x00000000}},  //   нег_, _штед, _মাছ_,
  { {0xdbd1006c, 0x27f800ca, 0xdc9a0097, 0x00000000}},  //   _müük, rarn_, _איסל,
  { {0x2bdf01f5, 0x644e00e0, 0x69dd0010, 0x00000000}},  //   पुरा, _snbi, ccse,
  { {0x26c01f5a, 0xa5070780, 0xa96a073b, 0x00000000}},  // [ace0] rmio_, лета_, _чипа_,
  { {0x2ca5006c, 0x26c00c3b, 0x9f4c0062, 0x00000000}},  //   nold_, smio_, _sedí_,
  { {0xd9fa0061, 0xa3b9013d, 0x9f4c008e, 0x00000000}},  //   _्यात_, _चरण_, _pedí_,
  { {0x2ca5004e, 0x00000000, 0x00000000, 0x00000000}},  //   hold_,   ,   ,
  { {0x644302d5, 0x6a66000c, 0x00000000, 0x00000000}},  //   ônic, _hófs,   ,
  { {0x3e71340a, 0xd8d70049, 0x2ca50190, 0x00000000}},  //   _ráta_, אוסט_, jold_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61ed000c, 0x00000000, 0x00000000, 0x00000000}},  //   ðalt,   ,   ,
  { {0x2ca50e40, 0x614303e0, 0xa2a1013d, 0x00000000}},  //   fold_, _лета, गकर्,
  { {0x3ea40737, 0x1dc0007d, 0x00000000, 0x00000000}},  //   somt_, शेषत,   ,
  { {0x68e4010a, 0x386101a2, 0x29000471, 0x00000000}},  //   _atid, _rohr_, _avia_,
  { {0xf41a0044, 0x290b00ca, 0xdd00014a, 0x00000000}},  //   ড়ির_, trca_, ştık,
  { {0x2ca50030, 0x6c5401f9, 0x786b006c, 0x00000000}},  //   bold_, _вклу, _hüvi,
  { {0x6d3b009b, 0x91820082, 0x7e620114, 0x00000000}},  //   _נתונ, _mềm_, _hoop,
  { {0x7e6200b5, 0x68e401aa, 0x99990047, 0x00000000}},  //   _koop, _etid, reső_,
  { {0x58d50265, 0x00000000, 0x00000000, 0x00000000}},  //   _коит,   ,   ,
  { {0xb4db04bd, 0xeaca0082, 0xd7fb003b, 0x00000000}},  // [acf0] _tràm, _vẹt_, _пун_,
  { {0x78700039, 0x39490145, 0x7e6205d0, 0x00000000}},  //   _jävl, _iras_, _loop,
  { {0xe7eb001c, 0x7e6200c4, 0x998d0036, 0x00000000}},  //   _ज्या_, _ooop, żeń_,
  { {0x394901aa, 0x7e6200d9, 0x00000000, 0x00000000}},  //   _kras_, _noop,   ,
  { {0x61f90066, 0xc5fa009b, 0x00000000, 0x00000000}},  //   rawl, _בפרט,   ,
  { {0xd006026b, 0x00000000, 0x00000000, 0x00000000}},  //   аеше_,   ,   ,
  { {0x2ca50190, 0x27010006, 0x7e620203, 0x00000000}},  //   vold_, nėn_, _boop,
  { {0x3949340b, 0x7e620b25, 0x0e6500c0, 0x00000000}},  //   _oras_, _coop, ркин,
  { {0x7ae4057c, 0x2ca500b4, 0x7e62340c, 0x00000000}},  //   _čita, told_, _doop,
  { {0x4c85017f, 0x4b25132e, 0x3ea00ecc, 0x00000000}},  //   рлов, амов, čita_,
  { {0x68e4037e, 0x2ca501a2, 0x39491c50, 0x00000000}},  //   _stid, rold_, _aras_,
  { {0xfaa6008b, 0x628b0016, 0xa96a012b, 0x00000000}},  //   рамо, nigo, вима_,
  { {0x394900c4, 0x999e00b9, 0xec6e0088, 0x00000000}},  //   _cras_, ětů_, _дп_,
  { {0x78700039, 0x628b0058, 0x3949340d, 0x00000000}},  //   _gävl, higo, _dras_,
  { {0x44330472, 0xb8fd02f4, 0x3949008e, 0x00000000}},  //   dex_, _तू_, _eras_,
  { {0x7e620869, 0xc7a300ed, 0x5ed70055, 0x00000000}},  //   _xoop, циск, _সবাই,
  { {0x39491129, 0x628b0489, 0x443301d6, 0x00000000}},  // [ad00] _gras_, digo, fex_,
  { {0x44330541, 0x2701007f, 0x78a701c3, 0x00000000}},  //   gex_, bėn_, cojv,
  { {0x8c3c0180, 0x212d0010, 0x00000000, 0x00000000}},  //   doğl, _apeh_,   ,
  { {0xd36f0025, 0x366a0745, 0x9f4c04bb, 0x00000000}},  //   بهم_, _рамо_, _nedá_,
  { {0x20050009, 0x7e620052, 0x90c62a14, 0x00000000}},  //   _bdli_, _roop, абде,
  { {0x443300fa, 0x201a006c, 0x7e621c87, 0x00000000}},  //   cex_, üpi_, _soop,
  { {0x628b0058, 0x7e620471, 0x00000000, 0x00000000}},  //   bigo, _poop,   ,
  { {0xf2a30069, 0x0dca003b, 0x290c0036, 0x00000000}},  //   _дисп, купи_, ądaj_,
  { {0x61ed008e, 0xf8bf009d, 0x69da00b9, 0x00000000}},  //   ñale, ltée_, ětel,
  { {0xceea0088, 0x5c740069, 0x442a00d9, 0x00000000}},  //   _адже_, слот, _jbb_,
  { {0xf8bf00f4, 0x00000000, 0x00000000, 0x00000000}},  //   ntée_,   ,   ,
  { {0xbd8701ef, 0x1bf200e8, 0xfe7900b9, 0x00000000}},  //   انین_, _आजकल_, chů_,
  { {0x78700073, 0xcd36035b, 0x95fc0044, 0x00000000}},  //   _tävl, _خراب, ইলাম_,
  { {0xe9df340e, 0x44330066, 0x442a00fa, 0x00000000}},  //   scú_, xex_, _nbb_,
  { {0x1cbb0476, 0x4433340f, 0x26180061, 0x00000000}},  //   _שמוע, vex_, _फाशी_,
  { {0x39490211, 0x442a01a2, 0xaa2d00b0, 0x00000000}},  //   _tras_, _abb_, ämää_,
  { {0x442a1c30, 0x628b00b0, 0x6aad1b87, 0x00000000}},  // [ad10] _bbb_, vigo, _ikaf,
  { {0xc3cb0025, 0xeaca0011, 0x00000000, 0x00000000}},  //   نظام_, _hẹp_,   ,
  { {0x44331c76, 0x628b02d5, 0x389c0476, 0x00000000}},  //   rex_, tigo, _ביזנ,
  { {0xdb070010, 0x442a062a, 0x00000000, 0x00000000}},  //   ülék, _ebb_,   ,
  { {0xc244008b, 0x628b1327, 0x44330253, 0x00000000}},  //   ўнік, rigo, pex_,
  { {0x442a0bca, 0x656d00e0, 0x00000000, 0x00000000}},  //   _gbb_, myah,   ,
  { {0x8c3c005a, 0x628b00f6, 0xf8bf009d, 0x00000000}},  //   roğl, pigo, ctée_,
  { {0x7c2a01a2, 0x00000000, 0x00000000, 0x00000000}},  //   _abfr,   ,   ,
  { {0x656d0145, 0x628917e7, 0xc212009b, 0x00000000}},  //   nyah, _imeo, _מהן_,
  { {0x7d020ed8, 0x6aad0020, 0x3e710027, 0x00000000}},  //   _dvos, _akaf, _táto_,
  { {0x7c640025, 0x7d0204f4, 0xdce701df, 0x00000000}},  //   تايل, _evos, ılım,
  { {0xc869052f, 0x2d7f0036, 0x753d0010, 0x00000000}},  //   _אן_, _płeć_, _ossz,
  { {0xeaca0082, 0x81c90044, 0x656d0009, 0x00000000}},  //   _dẹp_, লুর_, jyah,
  { {0xec6b004d, 0x656d0022, 0xfb88009e, 0x00000000}},  //   _шрек_, dyah, ائیو_,
  { {0x62890197, 0x753d0010, 0x66e60088, 0x00000000}},  //   _omeo, _assz, соба,
  { {0x442a0127, 0xaad0013d, 0x00000000, 0x00000000}},  //   _sbb_, _सूचक,   ,
  { {0x442a033b, 0x69d60010, 0x6d5b0082, 0x00000000}},  // [ad20] _pbb_, _igye, nxua,
  { {0x29020059, 0x98a90006, 0x62890020, 0x00000000}},  //   mska_, _ypač_, _ameo,
  { {0x29020046, 0xf8bf00f4, 0x442a0082, 0x00000000}},  //   lska_, utée_, _vbb_,
  { {0x786b005f, 0xf1fa01af, 0xf8bf00f4, 0x00000000}},  //   _qüvv, اعات_, rtée_,
  { {0x29023410, 0x656d0009, 0xf8bf00f4, 0x00000000}},  //   nska_, cyah, stée_,
  { {0x442a0061, 0x76440477, 0xf8bf00f4, 0x00000000}},  //   _ubb_, ldiy, ptée_,
  { {0x6d4b022b, 0x44440376, 0x68f60016, 0x00000000}},  //   _arga, md_, _lwyd,
  { {0x22960054, 0x3ea0037e, 0x76443411, 0x00000000}},  //   _الرس, čito_, ndiy,
  { {0x290201d9, 0x44440038, 0x75240211, 0x00000000}},  //   jska_, od_, ntiz,
  { {0x2902037e, 0x61e20207, 0x6aad02e1, 0x00000000}},  //   dska_, lcol, _skaf,
  { {0x6d4b010f, 0x29023412, 0x68f60016, 0x00000000}},  //   _erga, eska_, _awyd,
  { {0x6d44010a, 0x6d8900a1, 0x68f60016, 0x00000000}},  //   _šiau, امیہ_, _bwyd,
  { {0xd041006b, 0x298b04b6, 0x76440279, 0x00000000}},  //   _ailə, усно_, ddiy,
  { {0x69d60047, 0xd041005f, 0x444402ae, 0x00000000}},  //   _egye, _bilə, jd_,
  { {0x44440bc4, 0xaae6031d, 0x1bfb00b3, 0x00000000}},  //   dd_, _استو, _גלוב,
  { {0xd6d80264, 0x29020d0a, 0xd041006b, 0x00000000}},  //   стр_, bska_, _dilə,
  { {0x61e20061, 0x444400b5, 0x68f6018e, 0x00000000}},  // [ad30] dcol, fd_, _gwyd,
  { {0x80dc03d7, 0x444402ae, 0x656d0058, 0x00000000}},  //   _पढ़े, gd_, ryah,
  { {0x656d1ecd, 0x45d50679, 0xd1d90745, 0x00000000}},  //   syah, _монс, адец_,
  { {0x44440bc4, 0x61e20009, 0x73c40025, 0x00000000}},  //   ad_, gcol, سينم,
  { {0x44443413, 0x752400e5, 0xf65f0190, 0x00000000}},  //   bd_, ctiz, _diæt_,
  { {0x26da0020, 0x4444018c, 0x00000000, 0x00000000}},  //   _yupo_, cd_,   ,
  { {0x64552a84, 0x6d470089, 0x61e2004a, 0x00000000}},  //   _inzi, ājam, bcol,
  { {0x61e2051b, 0x62890020, 0x6d5b002d, 0x00000000}},  //   ccol, _umeo, txua,
  { {0xec790072, 0x00000000, 0x00000000, 0x00000000}},  //   ипи_,   ,   ,
  { {0x6445002b, 0x61fb0678, 0x7e7b1575, 0x00000000}},  //   ndhi, _heul, shup,
  { {0x7644005f, 0x68f6018e, 0x29020046, 0x00000000}},  //   ydiy, _swyd, wska_,
  { {0x29020209, 0x60db3414, 0x444413ae, 0x00000000}},  //   tska_, _kuum, zd_,
  { {0x444407be, 0x61fb07f3, 0x787003b6, 0x00000000}},  //   yd_, _meul, _hävi,
  { {0x6ff90049, 0x38b60030, 0x60db3415, 0x00000000}},  //   יפֿג, mærk_, _muum,
  { {0xe73a00e3, 0x44440056, 0xf743007c, 0x00000000}},  //   шев_, vd_, меро,
  { {0x64550207, 0x61fb0706, 0x75240766, 0x00000000}},  //   _anzi, _neul, ttiz,
  { {0x7644005f, 0x9f470428, 0x44440541, 0x00000000}},  // [ad40] rdiy, vaný_, td_,
  { {0x62990007, 0x444402f1, 0x61e20009, 0x00000000}},  //   enwo, ud_, wcol,
  { {0x752402f5, 0x673e0182, 0x61e20e9c, 0x00000000}},  //   stiz, _uspj, tcol,
  { {0x75240391, 0x644500e7, 0x60c100eb, 0x00000000}},  //   ptiz, adhi, _ahlm,
  { {0xddc206ac, 0x61e20198, 0x61ed0211, 0x00000000}},  //   _slož, rcol, ñala,
  { {0x61e20207, 0x1df2007d, 0xb87b00b9, 0x00000000}},  //   scol, घर्ष_, spív,
  { {0xdfcf0b59, 0x61e209fb, 0x6e291a96, 0x00000000}},  //   نيه_, pcol, ffeb,
  { {0xddc21310, 0x39400093, 0x61fb0dda, 0x00000000}},  //   _vlož, _osis_, _geul,
  { {0x22460061, 0x3eb80089, 0x91030098, 0x00000000}},  //   mdok_, ērt_, _опте,
  { {0x22460058, 0x80e10044, 0x14aa0061, 0x00000000}},  //   ldok_, _নিচ্, कविण,
  { {0xddc20428, 0x3940007f, 0xee3a007c, 0x00000000}},  //   _ulož, _asis_, _вне_,
  { {0x0dca0216, 0xb4db00f6, 0x00000000, 0x00000000}},  //   _кули_, _kràt,   ,
  { {0x21260149, 0x394d02a0, 0x7aed0e0d, 0x00000000}},  //   ntoh_, íes_, _čate,
  { {0xfbcf01ef, 0x3ea90059, 0xa5bb0048, 0x00000000}},  //   عتی_, čate_, _mbót,
  { {0x64430181, 0x3940008e, 0x9f4501d6, 0x00000000}},  //   ônim, _esis_, _aflê_,
  { {0xcb1301f8, 0x9865026c, 0x9f5c01aa, 0x00000000}},  //   _חלק_, _کیسے_, ravè_,
  { {0x95cb00e3, 0x39400058, 0xddd9000a, 0x00000000}},  // [ad50] рува_, _gsis_, _fowņ,
  { {0x61fb028c, 0x60db01c2, 0x2cac0016, 0x00000000}},  //   _seul, _ruum, nodd_,
  { {0x3e71002a, 0x25a20210, 0x2919237d, 0x00000000}},  //   _fáth_, _exkl_, lusa_,
  { {0x9f450428, 0x2a6901aa, 0x2cac3416, 0x00000000}},  //   _celý_, _joab_, hodd_,
  { {0x2a6901aa, 0x61fb249f, 0x629900d9, 0x00000000}},  //   _moab_, _veul, rnwo,
  { {0x38b60030, 0xe0420088, 0x26c917c9, 0x00000000}},  //   værk_, енши, lmao_,
  { {0x9028008b, 0x2cac018e, 0x61fb018e, 0x00000000}},  //   юцца_, dodd_, _teul,
  { {0xe1ff009f, 0x60db03b6, 0x8d6515c4, 0x00000000}},  //   _þó_, _tuum, звие,
  { {0x2cac018e, 0xfd110025, 0x226404bb, 0x00000000}},  //   fodd_, رجة_, žská_,
  { {0x6d49027b, 0x2919001a, 0x2cac018e, 0x00000000}},  //   rvea, dusa_, godd_,
  { {0xf4120049, 0x3a3900c4, 0xb3ad0044, 0x00000000}},  //   עפט_, fesp_, _কৃতজ,
  { {0x39400022, 0x3a3900fa, 0x00000000, 0x00000000}},  //   _psis_, gesp_,   ,
  { {0x2eaa026c, 0x5ed20055, 0x8c64025a, 0x00000000}},  //   _اپنی_, _সবচে, سطین,
  { {0x26c20065, 0x00000000, 0x00000000, 0x00000000}},  //   _shko_,   ,   ,
  { {0x38ca00a1, 0xeb96003b, 0x3a3900c4, 0x00000000}},  //   لاڑی_, _ниш_, besp_,
  { {0xe9a601e1, 0xb906005e, 0xf11b0061, 0x00000000}},  //   _найп, _език, _नमूद_,
  { {0x29190207, 0x3ae1000c, 0x00000000, 0x00000000}},  // [ad60] cusa_, _hóp_,   ,
  { {0xdbe3009d, 0x63b5013e, 0x00000000, 0x00000000}},  //   _déçu, _byzn,   ,
  { {0xb7db00b3, 0x00000000, 0x00000000, 0x00000000}},  //   _לקיי,   ,   ,
  { {0xf8bf0010, 0x7ebe0065, 0x82890088, 0x00000000}},  //   ntén_, këpa, осіб_,
  { {0xb4db00f6, 0x25d7009b, 0x00000000, 0x00000000}},  //   _dràs, _מוכן_,   ,
  { {0x38b6000c, 0x55bb009b, 0xa505007e, 0x00000000}},  //   færi_, _למכו, _ўяўл,
  { {0x274700b9, 0x443a00fa, 0x29193417, 0x00000000}},  //   míná_, mep_, zusa_,
  { {0x443a0046, 0x2cac0016, 0x539b00b3, 0x00000000}},  //   lep_, wodd_, _הילו,
  { {0x29190061, 0x7646014a, 0x2cac005b, 0x00000000}},  //   xusa_, _maky, todd_,
  { {0x443a3418, 0x3ae10011, 0x95880036, 0x00000000}},  //   nep_, _bóp_, ciąż,
  { {0x59a502fb, 0x200c3419, 0x2cac0016, 0x00000000}},  //   _गुजर, _iddi_, rodd_,
  { {0x6e960025, 0x2cac0016, 0x37c40044, 0x00000000}},  //   _علشا, sodd_, ্ডার,
  { {0x443a0093, 0x3d13013d, 0x6480010e, 0x00000000}},  //   kep_, _दिये_, _köid,
  { {0x29192390, 0x443a016e, 0xdd3b009b, 0x00000000}},  //   rusa_, jep_, _לעדכ,
  { {0x3ae1001d, 0xf77301f7, 0x291900ea, 0x00000000}},  //   _góp_, راس_, susa_,
  { {0x291908a4, 0x8aa4007e, 0xfbb7009b, 0x00000000}},  //   pusa_, _прыд, _מפות_,
  { {0x200c018e, 0xf48500a1, 0x3e7801dc, 0x00000000}},  // [ad70] _oddi_, وائی, _léto_,
  { {0x443a0232, 0x68ed341a, 0x26c900fa, 0x00000000}},  //   gep_, _itad, smao_,
  { {0x61ed004a, 0x00000000, 0x00000000, 0x00000000}},  //   ñalo,   ,   ,
  { {0x6d4233ea, 0xa507007e, 0x63b50161, 0x00000000}},  //   _osoa, _нягл, _vyzn,
  { {0x7c3a0239, 0x504500ed, 0x63b50036, 0x00000000}},  //   ketr, делб, _wyzn,
  { {0x443a149f, 0x6e22204c, 0x9401006b, 0x00000000}},  //   cep_, _acob, yihə_,
  { {0x7c3a0bc7, 0x443100f6, 0x764600e0, 0x00000000}},  //   detr, _ibz_, _yaky,
  { {0x68ed05fa, 0xece9007c, 0x644700a9, 0x00000000}},  //   _otad, одил_, _haji,
  { {0x7ae1001c, 0x1c18001c, 0x64470127, 0x00000000}},  //   wqlt, _दाखल_, _kaji,
  { {0x64470209, 0x7c3a0125, 0xeb99003b, 0x00000000}},  //   _jaji, getr, жио_,
  { {0x6447000b, 0x68ed008e, 0xe817006e, 0x00000000}},  //   _maji, _atad, _ताजा_,
  { {0x64470b60, 0xdd8e00a6, 0x443a1dff, 0x00000000}},  //   _laji, اوی_, zep_,
  { {0xda1f02d2, 0x5d690a94, 0x7646020c, 0x00000000}},  //   _भारत_, _филм_, _raky,
  { {0x644712e0, 0x764616fd, 0x7d1b01c2, 0x00000000}},  //   _naji, _saky, muus,
  { {0x7d1b003b, 0x68ed0173, 0x764617c1, 0x00000000}},  //   luus, _etad, _paky,
  { {0x4423000a, 0x44310861, 0x00000000, 0x00000000}},  //   _acj_, _abz_,   ,
  { {0x443a0093, 0x443100d9, 0x644702e0, 0x00000000}},  // [ad80] tep_, _bbz_, _baji,
  { {0x3ea00ed8, 0xe73a012b, 0x6447008e, 0x00000000}},  //   čiti_, _део_, _caji,
  { {0x36c6013b, 0x366a1192, 0x7e6b0116, 0x00000000}},  //   _обог, _дано_, _oogp,
  { {0xe297012b, 0x443a04bd, 0x7d1b0bac, 0x00000000}},  //   мах_, sep_, kuus,
  { {0xd13004e8, 0x6604002d, 0x443a002b, 0x00000000}},  //   امت_, maik, pep_,
  { {0x66040bce, 0x64470107, 0x6e22175b, 0x00000000}},  //   laik, _gaji, _scob,
  { {0xdfd00025, 0x44e4074d, 0x7e6b07c4, 0x00000000}},  //   ديث_, _hö_, _bogp,
  { {0x667b341b, 0x64470224, 0x660404cb, 0x00000000}},  //   ַװיג, _zaji, naik,
  { {0x9f5e008d, 0x2d840107, 0x7c3a1c28, 0x00000000}},  //   _ketë_, uzme_, tetr,
  { {0x9f5e008d, 0x3e780224, 0x3ea900ca, 0x00000000}},  //   _jetë_, _této_, čata_,
  { {0xeb9700ed, 0x660401a3, 0x44e400f8, 0x00000000}},  //   диќ_, kaik, _lö_,
  { {0x62820116, 0xed5a0769, 0x7d1b0277, 0x00000000}},  //   nhoo, _мое_, buus,
  { {0x941e03d7, 0x660404be, 0x44e403e1, 0x00000000}},  //   _पांच_, daik, _nö_,
  { {0x628200e0, 0xa3c001f5, 0x39520190, 0x00000000}},  //   hhoo, ुधा_, _drys_,
  { {0x644701a3, 0x8c1b0049, 0xe8200204, 0x00000000}},  //   _raji, _וווי, _बारा_,
  { {0x644703bf, 0x660401a3, 0x3952341c, 0x00000000}},  //   _saji, gaik, _frys_,
  { {0x644723c6, 0x39520007, 0x68ed00e7, 0x00000000}},  // [ad90] _paji, _grys_, _utad,
  { {0x3e71009f, 0x44e40039, 0x628201c3, 0x00000000}},  //   _hátt_, _dö_, ehoo,
  { {0xa5bb002a, 0xf8bf0181, 0x660404cb, 0x00000000}},  //   _gcón, ntém_, baik,
  { {0x6447341d, 0xd5b000a1, 0xfd5e0011, 0x00000000}},  //   _waji, افے_, _quyể,
  { {0xc61600b6, 0x64470020, 0x50b5341e, 0x00000000}},  //   _אחרי_, _taji, нску,
  { {0x26d9341f, 0x7d1b00b0, 0x00000000, 0x00000000}},  //   _hiso_, vuus,   ,
  { {0xfd5e001d, 0x38b605b7, 0xd00e0025, 0x00000000}},  //   _tuyể, mært_, حلى_,
  { {0x628200b5, 0x7d1b1fc7, 0x38b601e3, 0x00000000}},  //   choo, tuus, lært_,
  { {0xdc3a005f, 0x26d916d0, 0x0c950930, 0x00000000}},  //   _açıq, _miso_, ешня,
  { {0x0d82007e, 0x66040142, 0x7d1b0103, 0x00000000}},  //   ульн, zaik, ruus,
  { {0x44210195, 0x7d1b0103, 0x3e7101e5, 0x00000000}},  //   igh_, suus, _sátu_,
  { {0x26d901d9, 0x39523420, 0xef18007e, 0x00000000}},  //   _niso_, _prys_, _імі_,
  { {0x6604042c, 0xceb2009b, 0xfe7900b9, 0x00000000}},  //   vaik, _גיא_, mků_,
  { {0x44210066, 0x3f87016c, 0x7d09006c, 0x00000000}},  //   jgh_, oznu_, mses,
  { {0x6ab60373, 0x7d092cba, 0x6604010a, 0x00000000}},  //   _псих, lses, taik,
  { {0x39520006, 0x442101f3, 0x7bc30091, 0x00000000}},  //   _trys_, egh_, _iznu,
  { {0x7d090056, 0x66043421, 0x00000000, 0x00000000}},  // [ada0] nses, raik,   ,
  { {0x7d09021e, 0x6604033b, 0xe72a005e, 0x00000000}},  //   ises, saik, _еоод_,
  { {0x9f5e3422, 0x6604021e, 0x628200bb, 0x00000000}},  //   _vetë_, paik, thoo,
  { {0x7d09021e, 0x23660091, 0x91e6026b, 0x00000000}},  //   kses, ćoj_, ходе,
  { {0x62820168, 0x9f5c0802, 0xfe7900b9, 0x00000000}},  //   rhoo, raví_, dků_,
  { {0xe3b1026c, 0x65760009, 0x00000000, 0x00000000}},  //   ارے_, myyh,   ,
  { {0x64a3012b, 0x645c3423, 0x37db0049, 0x00000000}},  //   _сара, _inri, פֿגע,
  { {0x9f5e2a41, 0x1d34005e, 0x5d662337, 0x00000000}},  //   _jeté_, вния, етоз,
  { {0x6280021e, 0xdd90007a, 0x7d0912e8, 0x00000000}},  //   _ilmo, شود_, gses,
  { {0x3e71000c, 0x6aa400e7, 0x00000000, 0x00000000}},  //   _sátt_, _ajif,   ,
  { {0x69c40198, 0xfe7900b9, 0xa5bb0325, 0x00000000}},  //   _azie, bků_, _acól,
  { {0x7d090dda, 0x69c40066, 0xc333009b, 0x00000000}},  //   bses, _bzie, נור_,
  { {0xf8bf004f, 0x26d90197, 0x3a740920, 0x00000000}},  //   stém_, _riso_, уляр,
  { {0x69c409a0, 0x26d9016c, 0x60da0066, 0x00000000}},  //   _dzie, _siso_, _jitm,
  { {0x60da12b8, 0x26d93424, 0x779300a2, 0x00000000}},  //   _mitm, _piso_, ایجا,
  { {0xba770774, 0xdb23000c, 0x00000000, 0x00000000}},  //   _ساعت, _árás,   ,
  { {0x26d93425, 0x9f5e00f6, 0x38b6068f, 0x00000000}},  // [adb0] _viso_, _deté_, tært_,
  { {0x44210038, 0x62801044, 0x7d1d0129, 0x00000000}},  //   ugh_, _almo, àssi,
  { {0x442100ab, 0xad9d0036, 0x38b606ec, 0x00000000}},  //   rgh_, jaźn, rært_,
  { {0xa3cd0201, 0x7d090190, 0x290b0048, 0x00000000}},  //   शेष_, yses, osca_,
  { {0xfe790224, 0x60da0284, 0x765d01a3, 0x00000000}},  //   vků_, _bitm, _insy,
  { {0x62800010, 0x22490ecc, 0x752d11f3, 0x00000000}},  //   _elmo, žak_, mtaz,
  { {0x752d01bc, 0xfe7900b9, 0x60da00bb, 0x00000000}},  //   ltaz, tků_, _ditm,
  { {0x764d014a, 0x7d09006c, 0x72d402dc, 0x00000000}},  //   nday, tses, _босф,
  { {0x752d0198, 0x290b0036, 0x7d09001a, 0x00000000}},  //   ntaz, jsca_, uses,
  { {0x60da011f, 0x6ab601b6, 0x752d0197, 0x00000000}},  //   _gitm, _skyf, itaz,
  { {0x2007000b, 0x78bc001c, 0x5f79007a, 0x00000000}},  //   mani_, vlrv, _تماس_,
  { {0x20070d92, 0x7d092c3c, 0x26f00055, 0x00000000}},  //   lani_, pses, _ছিলো_,
  { {0xf2d20049, 0x752d0846, 0x764d0045, 0x00000000}},  //   יעט_, jtaz, dday,
  { {0x765d0263, 0x6288010a, 0xd7f20025, 0x00000000}},  //   _ansy, _įdom, شكر_,
  { {0x290b001a, 0x66e6003b, 0xe72700ed, 0x00000000}},  //   asca_, тоба, корд_,
  { {0x20070020, 0x7e7b0065, 0x7e690059, 0x00000000}},  //   hani_, nkup, njep,
  { {0x2007000b, 0xa507026b, 0x7ae300ab, 0x00000000}},  // [adc0] kani_, кета_, _hunt,
  { {0x200701d9, 0x7ae33426, 0xba3b0016, 0x00000000}},  //   jani_, _kunt, mnïa,
  { {0x7ae30325, 0x68e401b5, 0x20070020, 0x00000000}},  //   _junt, _huid, dani_,
  { {0x7ae30a16, 0x68e40004, 0xf5060216, 0x00000000}},  //   _munt, _kuid, _измо,
  { {0x7ae33373, 0x7e6911b8, 0x7e7b0268, 0x00000000}},  //   _lunt, djep, dkup,
  { {0x443e009f, 0x68e408b2, 0xf1a903ec, 0x00000000}},  //   _út_, _muid, رانه_,
  { {0x7ae3001a, 0x68e401b5, 0x6e9401fc, 0x00000000}},  //   _nunt, _luid, лику,
  { {0xf8bf0047, 0x60da0007, 0xad9d0036, 0x00000000}},  //   tték_, _witm, raźn,
  { {0xc693019b, 0x20070041, 0xc0e60088, 0x00000000}},  //   יאה_, bani_, _розк,
  { {0x7ae33427, 0x200704b4, 0x60da00c7, 0x00000000}},  //   _bunt, cani_, _uitm,
  { {0x441b007b, 0x8fa30088, 0x7ae3002a, 0x00000000}},  //   וויס, _кафе, _cunt,
  { {0x7e7b0436, 0xeaf700a1, 0x68e40adf, 0x00000000}},  //   ckup, کریت_, _buid,
  { {0x68e42582, 0x61ed008e, 0x7ae30288, 0x00000000}},  //   _cuid, ñali, _eunt,
  { {0xa8a40265, 0x7ae3022b, 0x68e4049b, 0x00000000}},  //   арск, _funt, _duid,
  { {0x7ae30089, 0xd6db007e, 0x764d0022, 0x00000000}},  //   _gunt, дта_, tday,
  { {0x0bb700b6, 0x34db001c, 0x752d0282, 0x00000000}},  //   _שלהם_, बद्द, ttaz,
  { {0x2007020e, 0x764d0169, 0x7ae30de2, 0x00000000}},  // [add0] yani_, rday, _zunt,
  { {0x752d01d5, 0x764d13cd, 0x39490544, 0x00000000}},  //   rtaz, sday, _isas_,
  { {0x2007012b, 0x752d0198, 0x7ae3049a, 0x00000000}},  //   vani_, staz, _xunt,
  { {0x3d13001c, 0x20073428, 0xf6790049, 0x00000000}},  //   _दिले_, wani_, _נאָמ,
  { {0x20070047, 0x9564005e, 0x00000000, 0x00000000}},  //   tani_, _кърд,   ,
  { {0xb97c009b, 0x34950c27, 0x63bc01e5, 0x00000000}},  //   ונדי, _сагр, _fyrn,
  { {0x200701d9, 0x61e401a8, 0x7e7b0107, 0x00000000}},  //   rani_, žila, tkup,
  { {0xdd91026c, 0x7ae324ed, 0x3949006c, 0x00000000}},  //   یوں_, _runt, _osas_,
  { {0x7e7b25c3, 0x7ae312e9, 0x7e690ec2, 0x00000000}},  //   rkup, _sunt, rjep,
  { {0x7e7b0626, 0x68e40211, 0x3a290460, 0x00000000}},  //   skup, _ruid, _acap_,
  { {0xb0b6007b, 0x68e40007, 0x39490127, 0x00000000}},  //   _עפעס_, _suid, _asas_,
  { {0x2005006c, 0x68e401c2, 0x7e7b0065, 0x00000000}},  //   _heli_, _puid, qkup,
  { {0x20050006, 0x00000000, 0x00000000, 0x00000000}},  //   _keli_,   ,   ,
  { {0x7ae30f80, 0x3ebf021e, 0x2005013e, 0x00000000}},  //   _tunt, llut_, _jeli_,
  { {0x394933eb, 0x20050020, 0xe7370783, 0x00000000}},  //   _esas_, _meli_, лер_,
  { {0x224d04be, 0xcf920049, 0x8ee50044, 0x00000000}},  //   _naek_, צטן_, _নবাগ,
  { {0x320401a3, 0xee5c000c, 0x7d1b04fd, 0x00000000}},  // [ade0] _remy_, æðið_, nrus,
  { {0x2005006c, 0x44330048, 0x00000000, 0x00000000}},  //   _neli_, gfx_,   ,
  { {0x25ab0b38, 0x224d008a, 0x7d1b0203, 0x00000000}},  //   _excl_, _baek_, hrus,
  { {0x7d1b00ea, 0x979b0049, 0xa49b0173, 0x00000000}},  //   krus, _טשיק, _pwòc,
  { {0x2005020c, 0x00000000, 0x00000000, 0x00000000}},  //   _beli_,   ,   ,
  { {0x20050a0f, 0x26c0175e, 0xc3060025, 0x00000000}},  //   _celi_, llio_, _مبرو,
  { {0x20050947, 0xd8d70049, 0x442a00f6, 0x00000000}},  //   _deli_, נוצט_, _icb_,
  { {0xb5fb00c4, 0x26c00026, 0x9d14003b, 0x00000000}},  //   _inác, nlio_, адич,
  { {0x644e1bc5, 0x66060337, 0xd291025a, 0x00000000}},  //   _kabi, _mekk, _بینظ,
  { {0x66063429, 0x9b5801f9, 0xdee6012b, 0x00000000}},  //   _lekk, виот_, _божи,
  { {0x644e11ad, 0x26c00006, 0xf4110044, 0x00000000}},  //   _mabi, klio_, স্কর_,
  { {0x644e010a, 0x2005037e, 0x7d1b006c, 0x00000000}},  //   _labi, _zeli_, brus,
  { {0x443807e4, 0x442a00f6, 0x7d1b038e, 0x00000000}},  //   _obr_, _ocb_, crus,
  { {0xac1801fb, 0x644e0d58, 0x443800c4, 0x00000000}},  //   _року_, _nabi, _nbr_,
  { {0x6606000c, 0x00000000, 0x00000000, 0x00000000}},  //   _bekk,   ,   ,
  { {0x26c00198, 0x44381261, 0x3a2904be, 0x00000000}},  //   glio_, _abr_, _ucap_,
  { {0x39490cfd, 0x66060056, 0x44380190, 0x00000000}},  // [adf0] _usas_, _dekk, _bbr_,
  { {0x442a00c4, 0x45b80783, 0x88830014, 0x00000000}},  //   _ccb_, угую_, _ایسن,
  { {0x644e184d, 0x26c000ea, 0x442a00d9, 0x00000000}},  //   _dabi, blio_, _dcb_,
  { {0x6235342a, 0x61e40059, 0x660600bb, 0x00000000}},  //   реду, žiln, _gekk,
  { {0x200500b0, 0x3ce60026, 0x9f5e0142, 0x00000000}},  //   _peli_, _nuov_, _detí_,
  { {0x644e0065, 0x44250637, 0x8f150242, 0x00000000}},  //   _gabi, _øl_, афич,
  { {0x2005016e, 0xb5fb0051, 0x764f1134, 0x00000000}},  //   _veli_, _gnác, _kacy,
  { {0x644e11fc, 0x7d020a5f, 0xcee8039d, 0x00000000}},  //   _zabi, _bwos, درون_,
  { {0x644e0009, 0x645a00c4, 0x4dd80044, 0x00000000}},  //   _yabi, _ótic, _ধ্বং,
  { {0x3ebf342b, 0x7d1b006c, 0x644e002d, 0x00000000}},  //   slut_, rrus, _xabi,
  { {0xda66029b, 0x26c00016, 0x3ebf0035, 0x00000000}},  //   авни, ylio_, plut_,
  { {0xeb96007c, 0x7d1b006c, 0x764f0b69, 0x00000000}},  //   рию_, prus, _nacy,
  { {0x66060292, 0x7d0201aa, 0x00000000, 0x00000000}},  //   _rekk, _gwos,   ,
  { {0x6d5904be, 0x26c00016, 0x8d740879, 0x00000000}},  //   _irwa, wlio_, _داما,
  { {0x644e342c, 0x660600b0, 0x764f0009, 0x00000000}},  //   _rabi, _pekk, _bacy,
  { {0x644e236a, 0x7ebe0065, 0x4438000c, 0x00000000}},  //   _sabi, tëpi, _sbr_,
  { {0x644e011c, 0x2d8d02c2, 0x7bc7002b, 0x00000000}},  // [ae00] _pabi, nzee_, żjud,
  { {0x4463342d, 0x26c00091, 0xf8bf00f4, 0x00000000}},  //   овув, slio_, tuée_,
  { {0x6606006c, 0x26c00211, 0x644e0059, 0x00000000}},  //   _tekk, plio_, _vabi,
  { {0x44380061, 0x644e06fe, 0x673e002b, 0x00000000}},  //   _wbr_, _wabi, _ippj,
  { {0x644e14d7, 0xa06a012b, 0x201a00c4, 0x00000000}},  //   _tabi, када_, ópio_,
  { {0x7d020009, 0x442a0386, 0x3e78000c, 0x00000000}},  //   _rwos, _ucb_, _létt_,
  { {0x4444048a, 0x6d59030c, 0xf8bf00f4, 0x00000000}},  //   me_, _arwa, quée_,
  { {0x44440938, 0x7d020263, 0xa5bb0048, 0x00000000}},  //   le_, _pwos, _scói,
  { {0x2259000c, 0x44440258, 0x00000000, 0x00000000}},  //   _óska_, oe_,   ,
  { {0x444405d3, 0x00000000, 0x00000000, 0x00000000}},  //   ne_,   ,   ,
  { {0x44440343, 0x6d59010f, 0x752400c7, 0x00000000}},  //   ie_, _erwa, huiz,
  { {0x4444342e, 0xd00b0055, 0x1eda0d75, 0x00000000}},  //   he_, _রায়_, _شباب_,
  { {0x81e80044, 0x673e00d4, 0xdca601ee, 0x00000000}},  //   _মজা_, _appj, _кади,
  { {0x44440466, 0x75242ecf, 0x00000000, 0x00000000}},  //   je_, duiz,   ,
  { {0x7e62046a, 0xc6d70688, 0x00000000, 0x00000000}},  //   _knop, لترت,   ,
  { {0x9f5e0207, 0x6d4b0016, 0x83670123, 0x00000000}},  //   _metà_, _ysga, یدال,
  { {0x444403a1, 0x75241595, 0x00000000, 0x00000000}},  // [ae10] fe_, guiz,   ,
  { {0x7c2816a7, 0x3ea90ed8, 0x764f0045, 0x00000000}},  //   ngdr, čati_, _wacy,
  { {0xf367025f, 0x7e620116, 0x00000000, 0x00000000}},  //   штан, _onop,   ,
  { {0x4b3700b6, 0x7bd90049, 0x00000000, 0x00000000}},  //   שראל_, אַנק,   ,
  { {0x660d02ae, 0x463a007b, 0x7f5a00f6, 0x00000000}},  //   maak, _גערע, _artq,
  { {0x7e623015, 0x660d16a6, 0x00000000, 0x00000000}},  //   _anop, laak,   ,
  { {0xf8bf19cd, 0x64450020, 0x3e7800d4, 0x00000000}},  //   ltés_, mehi, _néts_,
  { {0x7ebe008d, 0xc33200b6, 0x6445011c, 0x00000000}},  //   këpu, _מול_, lehi,
  { {0xf8bf19cd, 0x3e78009f, 0x00000000, 0x00000000}},  //   ntés_, _rétt_,   ,
  { {0x4c850216, 0x70740025, 0xcc890014, 0x00000000}},  //   слов, _والذ, انده_,
  { {0x908a026c, 0x5f79039d, 0x09e60aef, 0x00000000}},  //   _حملے_, _حماس_, йонн,
  { {0x44440224, 0x6d590036, 0xff5000a6, 0x00000000}},  //   ze_, _trwa, _زخم_,
  { {0x4444342f, 0x6d5931c3, 0xec6e0517, 0x00000000}},  //   ye_, _urwa, _еп_,
  { {0x4444081d, 0x6e290270, 0x3ff90049, 0x00000000}},  //   xe_, lgeb, טפֿע,
  { {0x17790805, 0x6d49107b, 0x64450ac2, 0x00000000}},  //   асть_, lwea, dehi,
  { {0x444427ef, 0x07a33430, 0x6e293431, 0x00000000}},  //   we_, часн, ngeb,
  { {0x6d490133, 0x00000000, 0x00000000, 0x00000000}},  // [ae20] nwea,   ,   ,
  { {0x44440038, 0x752401f3, 0x39400058, 0x00000000}},  //   ue_, ruiz, _ipis_,
  { {0x1877019b, 0x6e290328, 0x660d3432, 0x00000000}},  //   _העיר_, kgeb, baak,
  { {0x366a0200, 0x2c210061, 0x00000000, 0x00000000}},  //   _само_, _माझं_,   ,
  { {0x44440e6d, 0xf8bf0005, 0x75240325, 0x00000000}},  //   pe_, ctés_, quiz,
  { {0x7e6200f8, 0x44440065, 0x6e290434, 0x00000000}},  //   _snop, qe_, egeb,
  { {0x43860054, 0x6e290a9b, 0xf8bf000c, 0x00000000}},  //   _الأق, fgeb, bréf_,
  { {0x8cf4029b, 0x39401e02, 0x6e290125, 0x00000000}},  //   озиц, _opis_, ggeb,
  { {0xf653009b, 0xdb1801ca, 0x6d4900e0, 0x00000000}},  //   לצה_, _vyví, gwea,
  { {0x628200b9, 0x8fa601e0, 0x5b1400e2, 0x00000000}},  //   lkoo, _лазе, омот,
  { {0x2d8201d9, 0x394011d1, 0x200e1ec4, 0x00000000}},  //   ške_, _apis_, mafi_,
  { {0x62822b9e, 0x2bce0061, 0x20c91a13, 0x00000000}},  //   nkoo, हेगा, núin_,
  { {0x62823433, 0x660d02c8, 0x644500e7, 0x00000000}},  //   ikoo, vaak, yehi,
  { {0xd918007c, 0x660d0112, 0x200e0145, 0x00000000}},  //   щью_, waak, nafi_,
  { {0x6445001a, 0x5c3700b3, 0x39400173, 0x00000000}},  //   vehi, _הטוב_, _epis_,
  { {0xf96b0265, 0xfaa4025f, 0x5694007c, 0x00000000}},  //   _брой_, _најо, паст,
  { {0x5499008b, 0xf8bf00f4, 0x62821787, 0x00000000}},  // [ae30] аваў_, utés_, dkoo,
  { {0xf807012b, 0xf8bf2b25, 0x69cd002d, 0x00000000}},  //   _учин, rtés_, _izae,
  { {0x64453434, 0xf8bf0353, 0x628b005b, 0x00000000}},  //   rehi, stés_, thgo,
  { {0xaac90201, 0x7aea01a3, 0xf8bf009d, 0x00000000}},  //   रतिक, _muft, ptés_,
  { {0x7aea008d, 0x216902e9, 0x6aad008d, 0x00000000}},  //   _luft, рили_, _mjaf,
  { {0x7bc60036, 0x11d4023c, 0x00000000, 0x00000000}},  //   ękuj, ستند,   ,
  { {0x6e29333c, 0x287c0049, 0x7aea0022, 0x00000000}},  //   tgeb, רנומ, _nuft,
  { {0x6d490133, 0x00000000, 0x00000000, 0x00000000}},  //   twea,   ,   ,
  { {0x6e29147c, 0x7aea010f, 0x4d6501e1, 0x00000000}},  //   rgeb, _auft, іков,
  { {0x6e29010f, 0x7aea0035, 0x00000000, 0x00000000}},  //   sgeb, _buft,   ,
  { {0x62893435, 0x3df5007e, 0x3b09003b, 0x00000000}},  //   _kleo, _дзес, јемо_,
  { {0xc86901f8, 0x7aea3436, 0x00000000, 0x00000000}},  //   _בן_, _duft,   ,
  { {0x3eb80047, 0x6dc703d9, 0x6aad0022, 0x00000000}},  //   _írta_, _ازال, _djaf,
  { {0x6289018e, 0x39400059, 0xf41f0044, 0x00000000}},  //   _lleo, _vpis_, ন্তর_,
  { {0x869a00ed, 0x62890cec, 0x39400036, 0x00000000}},  //   атат_, _oleo, _wpis_,
  { {0x6aad000c, 0x4df90049, 0x00000000, 0x00000000}},  //   _gjaf, שפּא,   ,
  { {0x61e4112e, 0x394004eb, 0x00000000, 0x00000000}},  // [ae40] žilk, _upis_,   ,
  { {0xa3d6006e, 0x03a6022a, 0xb5fb004a, 0x00000000}},  //   ाइल_, оизо, _unán,
  { {0x7ae401b0, 0xeaaf00a1, 0x083b0049, 0x00000000}},  //   _kiit, _سٹی_, _דעיל,
  { {0x62891092, 0x09de0044, 0x7bc301d6, 0x00000000}},  //   _cleo, _ভ্যা, _mynu,
  { {0x628201b5, 0x7ae405e0, 0x787000b0, 0x00000000}},  //   rkoo, _miit, _sävy,
  { {0x7ae40368, 0x67210825, 0x62823437, 0x00000000}},  //   _liit, šlje, skoo,
  { {0x200e0056, 0x00000000, 0x00000000, 0x00000000}},  //   rafi_,   ,   ,
  { {0xf41f0055, 0x7ae4021e, 0x200e00e7, 0x00000000}},  //   ন্দর_, _niit, safi_,
  { {0x10a6078d, 0x78bc0ac2, 0x2b5c0045, 0x00000000}},  //   _диан, korv, _srvc_,
  { {0xb5fb029d, 0x7bc30022, 0x7d1d0010, 0x00000000}},  //   _anál, _bynu, ássa,
  { {0x7bc3018e, 0xaa590e82, 0x78bc0f5d, 0x00000000}},  //   _cynu, бину_, dorv,
  { {0xe8d9001d, 0x81de0044, 0x69c4000a, 0x00000000}},  //   _trị_, _দ্য_, _byie,
  { {0x78bc08c8, 0x7ae40022, 0x200c014a, 0x00000000}},  //   forv, _diit, _kedi_,
  { {0x200c27c7, 0x7aea3438, 0x6d420026, 0x00000000}},  //   _jedi_, _tuft, _ipoa,
  { {0x200c2f25, 0x7bc30016, 0x20c90051, 0x00000000}},  //   _medi_, _gynu, dúil_,
  { {0x7c3a01c3, 0x893500a1, 0xf8bf009d, 0x00000000}},  //   lftr, _فٹبا, drée_,
  { {0xa5bb00c4, 0x78bc199f, 0x200c0016, 0x00000000}},  // [ae50] _acór, borv, _oedi_,
  { {0x78bc0026, 0x28d2013d, 0x629b0026, 0x00000000}},  //   corv, _दीपि, _smuo,
  { {0x62890035, 0xf8bf009d, 0x96070025, 0x00000000}},  //   _pleo, grée_, _وبحم,
  { {0x68ed0065, 0x6abd00d4, 0xd6270025, 0x00000000}},  //   _kuad, nosf, _بعدي,
  { {0x200c0032, 0x4104007e, 0x1a9c0049, 0x00000000}},  //   _bedi_, дзів, סידע,
  { {0x37df0044, 0x3dd00044, 0x68ed0020, 0x00000000}},  //   _ব্যর, াখাল, _muad,
  { {0x200c01f6, 0xa5bb0051, 0xf8bf009d, 0x00000000}},  //   _dedi_, _gcór, crée_,
  { {0x64553439, 0x313501ee, 0x629b00e7, 0x00000000}},  //   _hazi, _небр, _umuo,
  { {0x7ae4021e, 0x61e91293, 0x7bc30023, 0x00000000}},  //   _riit, _igel, _synu,
  { {0x7ae4021e, 0x64550142, 0x320d00bb, 0x00000000}},  //   _siit, _jazi, _heey_,
  { {0x6455000b, 0x7ebe0023, 0x7ae401b1, 0x00000000}},  //   _mazi, rëpr, _piit,
  { {0x645516c3, 0x6abd04a7, 0x68ed00f6, 0x00000000}},  //   _lazi, gosf, _buad,
  { {0x7ae4343a, 0x68ed0211, 0x78bc0d22, 0x00000000}},  //   _viit, _cuad, torv,
  { {0x6455005f, 0x68ed343b, 0x7ae408a6, 0x00000000}},  //   _nazi, _duad, _wiit,
  { {0x366a05f6, 0x7ae40934, 0x2aa40010, 0x00000000}},  //   баво_, _tiit, rűbb_,
  { {0x61e91d5b, 0x78bc0d95, 0xf8bf038e, 0x00000000}},  //   _ngel, sorv, quén_,
  { {0x68ed08d3, 0x18a6343c, 0x20c90051, 0x00000000}},  // [ae60] _guad, _наим, túil_,
  { {0x6ad10055, 0xf8bf00f4, 0xa84a0025, 0x00000000}},  //   _সংযো, trée_, _الدم_,
  { {0x645a0181, 0xa87b009b, 0xb5fb0428, 0x00000000}},  //   _ótim, _האיר, _znám,
  { {0x20c9002a, 0x200c17f3, 0x3d1c03d7, 0x00000000}},  //   súil_, _sedi_, _मिले_,
  { {0x200c01aa, 0x6455343d, 0x66040518, 0x00000000}},  //   _pedi_, _fazi, mbik,
  { {0x61ff005f, 0x6455014a, 0x61e9343e, 0x00000000}},  //   ıqla, _gazi, _egel,
  { {0x43430057, 0x200c0198, 0xddcb0036, 0x00000000}},  //   _перв, _vedi_, _nagł,
  { {0x200c0bc4, 0x75240285, 0x6604343f, 0x00000000}},  //   _wedi_, oriz, nbik,
  { {0x64553440, 0xc106006d, 0xfe6f0025, 0x00000000}},  //   _yazi, _رواي, ادى_,
  { {0x752400c4, 0x7c3a010f, 0x68ed0048, 0x00000000}},  //   iriz, uftr, _ruad,
  { {0x6abd00d4, 0xb5fb0051, 0x320d0022, 0x00000000}},  //   tosf, _snám, _yeey_,
  { {0x75240066, 0x00000000, 0x00000000, 0x00000000}},  //   kriz,   ,   ,
  { {0xac183441, 0x68ed3442, 0x6298009d, 0x00000000}},  //   _долу_, _quad, évoy,
  { {0x752419ee, 0xe8d90011, 0x387a005b, 0x00000000}},  //   driz, _trọ_, _copr_,
  { {0x645500d0, 0x6af30054, 0x4c3b009b, 0x00000000}},  //   _razi, _كثير, _התוב,
  { {0x64553443, 0x6ee7014a, 0x75240391, 0x00000000}},  //   _sazi, _kıbr, friz,
  { {0x6455001e, 0x95cb0893, 0xc8670849, 0x00000000}},  // [ae70] _pazi, сува_, _етни,
  { {0xddc9016c, 0x26c2068f, 0x64550350, 0x00000000}},  //   nješ, _ekko_, _qazi,
  { {0x645504a5, 0x9259007c, 0x2a690089, 0x00000000}},  //   _vazi, жает_, _knab_,
  { {0x6455000b, 0x75243444, 0xa49b000a, 0x00000000}},  //   _wazi, briz, _otòg,
  { {0xdb18021e, 0x75243445, 0x7e790045, 0x00000000}},  //   _hyvä, criz, _rowp,
  { {0x660f010f, 0x26c9008e, 0xf958009b, 0x00000000}},  //   _heck, llao_, פסות_,
  { {0xdb1800b0, 0x660f00d2, 0x00000000, 0x00000000}},  //   _jyvä, _keck,   ,
  { {0x61e920f5, 0x00000000, 0x00000000, 0x00000000}},  //   _ugel,   ,   ,
  { {0x660f010f, 0x6e3b01e5, 0x9f5c0161, 0x00000000}},  //   _meck, rfub, mavý_,
  { {0x660f010f, 0x6d5b0065, 0x13aa00a1, 0x00000000}},  //   _leck, rvua, _انہی_,
  { {0xf8bf0181, 0x26c90107, 0x661d0142, 0x00000000}},  //   guém_, klao_, _odsk,
  { {0x2f18007e, 0xedd501b7, 0x00000000, 0x00000000}},  //   _хоць_, _قياد,   ,
  { {0x3ead01e2, 0x3ebf00ca, 0xcdcb0151, 0x00000000}},  //   mnet_, mout_, _اذان_,
  { {0x3ead1902, 0x3ebf0300, 0x661d0637, 0x00000000}},  //   lnet_, lout_, _adsk,
  { {0x3ead0065, 0x66043446, 0x00000000, 0x00000000}},  //   onet_, tbik,   ,
  { {0x3ead0292, 0x3ebf0224, 0x26c9016c, 0x00000000}},  //   nnet_, nout_, glao_,
  { {0x660f15b4, 0x6604002d, 0xe5a30088, 0x00000000}},  // [ae80] _deck, rbik, вити,
  { {0x7524022b, 0x67210f3a, 0x3ebf3447, 0x00000000}},  //   rriz, šlja, hout_,
  { {0x3ebf01aa, 0x3ead0007, 0x93c3001a, 0x00000000}},  //   kout_, knet_, _ţări,
  { {0xd1ca007c, 0xf773009b, 0x61ed0e54, 0x00000000}},  //   олее_, _סקר_, žaln,
  { {0x3ead0056, 0x00000000, 0x00000000, 0x00000000}},  //   dnet_,   ,   ,
  { {0x3ead3448, 0x32e8014a, 0x74e70088, 0x00000000}},  //   enet_, _eşya_, _одяг_,
  { {0x20b9008b, 0xddc90166, 0x3ead010f, 0x00000000}},  //   чыць_, vješ, fnet_,
  { {0x3ebf0010, 0x3ead27a1, 0x26c00026, 0x00000000}},  //   gout_, gnet_, noio_,
  { {0x320601a3, 0xe3b00044, 0x00000000, 0x00000000}},  //   mboy_, _করিব,   ,
  { {0x3ead0d69, 0x32061c53, 0x21260022, 0x00000000}},  //   anet_, lboy_, mroh_,
  { {0x3ead0190, 0x3ebf009d, 0xda3500a5, 0x00000000}},  //   bnet_, bout_, нены,
  { {0xcfa90355, 0x32060543, 0x3ead0009, 0x00000000}},  //   _عالم_, nboy_, cnet_,
  { {0x6f18001c, 0xddc90243, 0x26c00197, 0x00000000}},  //   lsvc, pješ, doio_,
  { {0x660f144f, 0x00000000, 0x00000000, 0x00000000}},  //   _seck,   ,   ,
  { {0x320600e0, 0xbc6700a2, 0xdb1806ec, 0x00000000}},  //   kboy_, _زمين_, _byvå,
  { {0xe8d90082, 0x26c00026, 0x2a69004a, 0x00000000}},  //   _trỏ_, goio_, _unab_,
  { {0x660f0073, 0xf8ae007a, 0x2d8400f4, 0x00000000}},  // [ae90] _veck, شکی_, nyme_,
  { {0x26c9021d, 0xdb180039, 0x320600d9, 0x00000000}},  //   slao_, _tyvä, eboy_,
  { {0x3ead0030, 0x660f0039, 0x3ebf0339, 0x00000000}},  //   ynet_, _teck, yout_,
  { {0x661d0030, 0xe29801fb, 0x291900b0, 0x00000000}},  //   _udsk, має_, ossa_,
  { {0x2919021e, 0x61ed0091, 0x3ead05ba, 0x00000000}},  //   nssa_, žalo, vnet_,
  { {0x7ff500a2, 0x3ebf1cdc, 0x2919021e, 0x00000000}},  //   رستا, wout_, issa_,
  { {0x3ead15c8, 0xdbd6003c, 0x752d002d, 0x00000000}},  //   tnet_, _jääk, luaz,
  { {0x32060145, 0x3ead1689, 0x00000000, 0x00000000}},  //   cboy_, unet_,   ,
  { {0xc0cb01fb, 0xdbd6021e, 0x3ebf00be, 0x00000000}},  //   _дуже_, _lääk, rout_,
  { {0xeb99003b, 0x3ebf0068, 0x00000000, 0x00000000}},  //   зио_, sout_,   ,
  { {0x3ead00f8, 0x2919021e, 0x200731f8, 0x00000000}},  //   pnet_, essa_, mbni_,
  { {0x9413013f, 0x00000000, 0x00000000, 0x00000000}},  //   rixə_,   ,   ,
  { {0x96150055, 0xf2d2007b, 0x61fb0020, 0x00000000}},  //   িলাম_, טעט_, _mful,
  { {0x752d3449, 0xeb9900e2, 0x00000000, 0x00000000}},  //   duaz, _нил_,   ,
  { {0xfaa6007e, 0x26c00197, 0x2ca5000c, 0x00000000}},  //   _пако, toio_, mild_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd9de0044, 0x26c000c4, 0x22b80059, 0x00000000}},  // [aea0] _ভ্রম, roio_, nčke_,
  { {0x26c00197, 0x00000000, 0x00000000, 0x00000000}},  //   soio_,   ,   ,
  { {0x389b007b, 0x32061ae5, 0x2d8400ab, 0x00000000}},  //   _זיינ, tboy_, zyme_,
  { {0x2ca504b2, 0x21260022, 0x6aa601a2, 0x00000000}},  //   hild_, troh_, nikf,
  { {0xc1e70057, 0x2ca500d8, 0x752d0026, 0x00000000}},  //   ньше_, kild_, cuaz,
  { {0x6616015e, 0x7e6b20c0, 0x00000000, 0x00000000}},  //   layk, _angp,   ,
  { {0xb5fb002a, 0x44f6000c, 0xce94005e, 0x00000000}},  //   _snái, _hæ_, какъ,
  { {0x64800bac, 0x433b0049, 0x2d84007f, 0x00000000}},  //   _töis, _מעלב, tyme_,
  { {0x2ca5012d, 0x00000000, 0x00000000, 0x00000000}},  //   fild_,   ,   ,
  { {0x4f96012b, 0x253701ce, 0x61e400ca, 0x00000000}},  //   _преу, עניש_, žils,
  { {0x3d100316, 0xa3d6006e, 0x29000982, 0x00000000}},  //   _दौरे_, ाइट_, _atia_,
  { {0xdbd60004, 0x2d84004a, 0x00000000, 0x00000000}},  //   _rääk, pyme_,   ,
  { {0x2ca51543, 0x291900b0, 0x0dc705a5, 0x00000000}},  //   bild_, ussa_, _пуши_,
  { {0xdbd600b0, 0x3a20014a, 0x67210010, 0x00000000}},  //   _pääk, _edip_, áljo,
  { {0x92100309, 0x29191da2, 0x69c001a2, 0x00000000}},  //   ाराज_, sssa_, ümer,
  { {0x752d0207, 0x44f6344a, 0x7af7004a, 0x00000000}},  //   tuaz, _bæ_, _éxta,
  { {0x2900008e, 0xd25100a1, 0xf4870a85, 0x00000000}},  // [aeb0] _gtia_, یچر_, нужн,
  { {0x752d065d, 0x00000000, 0x00000000, 0x00000000}},  //   ruaz,   ,   ,
  { {0xe78700e2, 0x78a70023, 0x00000000, 0x00000000}},  //   _чупо, mijv,   ,
  { {0x78a700b5, 0x44f6000c, 0x00000000, 0x00000000}},  //   lijv, _fæ_,   ,
  { {0x752d0026, 0x69da0036, 0x00000000, 0x00000000}},  //   quaz, ęteg,   ,
  { {0x8fa5007e, 0x99920173, 0x394900fa, 0x00000000}},  //   кале, _deyň_, _mpas_,
  { {0xb88200b9, 0x2eb500e2, 0xa3d40b86, 0x00000000}},  //   _říka, ксис, _борч,
  { {0x2ca5040f, 0x394900b0, 0x78a700bb, 0x00000000}},  //   wild_, _opas_, hijv,
  { {0x2d8b004f, 0x00000000, 0x00000000, 0x00000000}},  //   áce_,   ,   ,
  { {0x4c850088, 0x22b80e0d, 0x4433016b, 0x00000000}},  //   тлов, rčke_, ngx_,
  { {0x2d8b0c76, 0x2900237d, 0x3a2009e4, 0x00000000}},  //   šce_, _stia_, _pdip_,
  { {0xfeb80054, 0xfaa600ed, 0x628b01d6, 0x00000000}},  //   _كانت_, тамо, nkgo,
  { {0x8276007b, 0x78a70065, 0x6ad10044, 0x00000000}},  //   דערע_, fijv, _সংশো,
  { {0x6aa61d30, 0x60c3344b, 0x7d1b006c, 0x00000000}},  //   sikf, nonm, msus,
  { {0xe7370256, 0x7d1b344c, 0x39490066, 0x00000000}},  //   кер_, lsus, _epas_,
  { {0xddd901aa, 0x60c3010f, 0x61ed10f7, 0x00000000}},  //   _pawň, honm, žalj,
  { {0x958302d3, 0x7d1b006c, 0xa806005e, 0x00000000}},  // [aec0] алте, nsus, _изпл,
  { {0x14c8007a, 0x7d1b0933, 0x212f0045, 0x00000000}},  //   رهای_, isus, dugh_,
  { {0xddc20166, 0x7d1b11f3, 0x00000000, 0x00000000}},  //   _mnoš, hsus,   ,
  { {0xd36f0054, 0x7d1b006c, 0x527500ec, 0x00000000}},  //   تهم_, ksus, лучу,
  { {0xc43400a6, 0xdbcc01e5, 0x00000000, 0x00000000}},  //   _مکات, _lóði,   ,
  { {0x7d1b211f, 0x399b00a3, 0x60c3344d, 0x00000000}},  //   dsus, וינד, gonm,
  { {0x64a301a4, 0x4438344e, 0x6aa406c2, 0x00000000}},  //   _тара, _icr_, _omif,
  { {0xc7b3009b, 0x628b0203, 0x7d780025, 0x00000000}},  //   יבו_, ckgo, فمبر_,
  { {0x645c344f, 0x7d1b27b2, 0xdd9005d4, 0x00000000}},  //   _kari, gsus, صود_,
  { {0x645e0190, 0x4438041d, 0x9f9801ca, 0x00000000}},  //   ndpi, _jcr_, lším_,
  { {0x6148000c, 0x394918a7, 0x00000000, 0x00000000}},  //   _félö, _spas_,   ,
  { {0x645c1097, 0x2fd7007a, 0xc3330104, 0x00000000}},  //   _lari, _شوند_, סור_,
  { {0x81e40055, 0x443800ea, 0x628001a3, 0x00000000}},  //   পুর_, _ocr_, _momo,
  { {0x645c1bd3, 0x60da04b7, 0x443810c5, 0x00000000}},  //   _nari, _jhtm, _ncr_,
  { {0x9cd7009b, 0x656600ea, 0x78a73450, 0x00000000}},  //   _שווה_, _arkh, rijv,
  { {0x62800390, 0x60c30173, 0xeb77009b, 0x00000000}},  //   _nomo, zonm, _יעוץ_,
  { {0x4438001a, 0x645e00bb, 0x394900e0, 0x00000000}},  // [aed0] _bcr_, fdpi, _upas_,
  { {0x645c0127, 0x4438121e, 0x7d1d3451, 0x00000000}},  //   _cari, _ccr_, ássi,
  { {0x645c0127, 0x6e2211e4, 0x7d020061, 0x00000000}},  //   _dari, _odob, _ltos,
  { {0x62800555, 0xf364025f, 0x60c301aa, 0x00000000}},  //   _como, штун, wonm,
  { {0x645c009f, 0x62800cce, 0x7aed0047, 0x00000000}},  //   _fari, _domo, _miat,
  { {0x7aed1866, 0x765d04be, 0x44380145, 0x00000000}},  //   _liat, _hasy, _gcr_,
  { {0xa3df0164, 0x60c300ab, 0x7d020006, 0x00000000}},  //   देश_, ronm, _atos,
  { {0x7d1b0004, 0x60c33452, 0x645c0027, 0x00000000}},  //   tsus, sonm, _zari,
  { {0x765d1535, 0x645c014a, 0x5c150783, 0x00000000}},  //   _masy, _yari, льну,
  { {0x645c005f, 0x765d01aa, 0x7d020051, 0x00000000}},  //   _xari, _lasy, _dtos,
  { {0x7d1b0052, 0x7d022ba6, 0x22b800ca, 0x00000000}},  //   ssus, _etos, lčka_,
  { {0x765d0263, 0x7d1b006c, 0x60da0045, 0x00000000}},  //   _nasy, psus, _zhtm,
  { {0x7aed0169, 0x8c4508fc, 0xe8f701e1, 0x00000000}},  //   _diat, _беле, лля_,
  { {0x60da2903, 0x6e220941, 0x7e7b0166, 0x00000000}},  //   _xhtm, _zdob, ljup,
  { {0x7aed0010, 0x765d188a, 0x00000000, 0x00000000}},  //   _fiat, _basy,   ,
  { {0x645c3453, 0x44231670, 0x44380061, 0x00000000}},  //   _sari, _adj_, _scr_,
  { {0x9f9801dc, 0x6280007f, 0x05660783, 0x00000000}},  // [aee0] vším_, _romo, ыван,
  { {0x62800d4e, 0x645c3454, 0x6d590020, 0x00000000}},  //   _somo, _qari, _mswa,
  { {0x442301ee, 0x9f980861, 0x443814f9, 0x00000000}},  //   _ddj_, tším_, _vcr_,
  { {0x60da0061, 0x6d4b0e78, 0x645c01a3, 0x00000000}},  //   _shtm, _opga, _wari,
  { {0x645c087e, 0x60da0061, 0xa1583455, 0x00000000}},  //   _tari, _phtm, талу_,
  { {0xd00f0025, 0xe8d90082, 0x4438004a, 0x00000000}},  //   كله_, _trễ_, _ucr_,
  { {0x7d020046, 0x6d4b0dec, 0xb4e000e8, 0x00000000}},  //   _stos, _apga, दगी_,
  { {0x44440b8d, 0x44230450, 0x1ef70025, 0x00000000}},  //   lf_, _zdj_, دعوة_,
  { {0x0caa0751, 0x7aed3456, 0x4444112b, 0x00000000}},  //   етни_, _riat, of_,
  { {0x444400c4, 0x7aed0036, 0x2018000c, 0x00000000}},  //   nf_, _siat, _þri_,
  { {0x4444001c, 0x7aed3457, 0x54770049, 0x00000000}},  //   if_, _piat, אגיע_,
  { {0x6e2200ee, 0x8c0c0044, 0x20c90051, 0x00000000}},  //   _udob, _শাওন_, búis_,
  { {0x7aed1800, 0xa802005d, 0x6da30517, 0x00000000}},  //   _viat, ğınd, _лица,
  { {0x444402ae, 0xa802047f, 0x7aed0036, 0x00000000}},  //   jf_, şınd, _wiat,
  { {0x765d130b, 0x6d400279, 0x4444281b, 0x00000000}},  //   _pasy, ltma, df_,
  { {0x7bd80363, 0x44441aaf, 0x44230173, 0x00000000}},  //   _izvu, ef_, _sdj_,
  { {0x44440090, 0x6d4001aa, 0xf1a4013d, 0x00000000}},  // [aef0] ff_, ntma, _खेलन,
  { {0x78a5009f, 0x00000000, 0x00000000, 0x00000000}},  //   _umhv,   ,   ,
  { {0x1cbb007b, 0xf367007e, 0x765d3458, 0x00000000}},  //   עמבע, ытан, _tasy,
  { {0x444403cd, 0x9f5e00f6, 0x6d4001a2, 0x00000000}},  //   af_, _letó_, ktma,
  { {0x660d04cb, 0xe1f8008b, 0x44443459, 0x00000000}},  //   mbak, угі_, bf_,
  { {0x660d0292, 0x22b800ca, 0x444400d2, 0x00000000}},  //   lbak, rčka_, cf_,
  { {0xf8bf009d, 0x1e950fd8, 0x8f67009e, 0x00000000}},  //   lués_, ирир, البے_,
  { {0x6d400061, 0x660d022b, 0x752d02cf, 0x00000000}},  //   ftma, nbak, oraz,
  { {0x212b001d, 0x6d400030, 0x7e7b006c, 0x00000000}},  //   _ích_, gtma, rjup,
  { {0x3ea60039, 0x1035007a, 0x20c90048, 0x00000000}},  //   _emot_, _خبرگ, rúis_,
  { {0xbb450088, 0x752d00b9, 0x7644006b, 0x00000000}},  //   шенк, hraz, yfiy,
  { {0x09e601be, 0xfc3f0224, 0x752d345a, 0x00000000}},  //   ионн, ří_, kraz,
  { {0x6d4000bb, 0x660d0190, 0x6d59345b, 0x00000000}},  //   ctma, dbak, _uswa,
  { {0x752d037e, 0x44440927, 0x225f0a42, 0x00000000}},  //   draz, xf_, _lauk_,
  { {0x752d022b, 0x7d092a68, 0xe61600ed, 0x00000000}},  //   eraz, lpes, ифаќ,
  { {0x752d345c, 0xcf92071c, 0xfb24007a, 0x00000000}},  //   fraz, קטן_, _اروپ,
  { {0xf8bf0a53, 0x752d28dc, 0x64a604b6, 0x00000000}},  // [af00] gués_, graz, аааа,
  { {0x4444001f, 0xd90d0123, 0x3940002b, 0x00000000}},  //   uf_, _سیف_, _iqis_,
  { {0x4444037f, 0x752d064c, 0xd4d5007e, 0x00000000}},  //   rf_, araz, сітэ,
  { {0x752d0428, 0xd7bb00b6, 0xe2460025, 0x00000000}},  //   braz, _יציר, شخصي,
  { {0x28db03d7, 0x752d0207, 0x4444010f, 0x00000000}},  //   _मीडि, craz, pf_,
  { {0xdce20119, 0x7e0e0164, 0x394d2af7, 0x00000000}},  //   _proč, सर्ग_, çesi_,
  { {0xd3720076, 0x20c90051, 0x4fc602ea, 0x00000000}},  //   _ظهر_, túir_, јсла,
  { {0x6299010f, 0xdce20059, 0x6d4005b4, 0x00000000}},  //   chwo, _vroč, ttma,
  { {0x8c3c011f, 0xddc9014a, 0x9f5e00d4, 0x00000000}},  //   liği, rdeş, _petó_,
  { {0x6721089f, 0x20c90051, 0x2ca70082, 0x00000000}},  //   šlji, súir_, _cmnd_,
  { {0x9992000a, 0x7d090472, 0xee3a142c, 0x00000000}},  //   _deyō_, apes, _ане_,
  { {0x201c345d, 0x66fc00b9, 0x2a6000f6, 0x00000000}},  //   lavi_, _ačko, _caib_,
  { {0xf8bf0010, 0x0e9b0104, 0x00000000, 0x00000000}},  //   nség_, _בשאל,   ,
  { {0x8d850167, 0xb5fb00c4, 0x201c0095, 0x00000000}},  //   _دشمن, _anáp, navi_,
  { {0x6298001e, 0x23a5013d, 0x660d0376, 0x00000000}},  //   īvoj, _गेंद, tbak,
  { {0x8c3c011f, 0x35f5007e, 0xf8bf009d, 0x00000000}},  //   diği, спар, tués_,
  { {0x95cb345e, 0x201c0bf8, 0x660d014a, 0x00000000}},  // [af10] тува_, kavi_, rbak,
  { {0x201c1f6c, 0x752d02cb, 0xf3671f25, 0x00000000}},  //   javi_, rraz, итен,
  { {0xa85600b6, 0x201c014a, 0x752d0107, 0x00000000}},  //   _היתה_, davi_, sraz,
  { {0x623528d1, 0x752d0213, 0xb4db00f6, 0x00000000}},  //   седу, praz, _apàt,
  { {0xf8bf345f, 0xddd90173, 0x00000000, 0x00000000}},  //   qués_, _pawō,   ,
  { {0x3861001f, 0x62990c0d, 0x77f5013d, 0x00000000}},  //   _jahr_, shwo, _आलोक_,
  { {0xb3e50055, 0xe3e50055, 0x33950025, 0x00000000}},  //   _প্রজ, _প্রব, _الأز,
  { {0x9454006b, 0x57b8009b, 0x9e6202dc, 0x00000000}},  //   _çərş, ילוב_, звъд,
  { {0x201c0119, 0x2a600093, 0xa1940a85, 0x00000000}},  //   bavi_, _raib_, _датч,
  { {0x0dc8012b, 0x7d0901a3, 0x201c0197, 0x00000000}},  //   јући_, rpes, cavi_,
  { {0x7d0906c0, 0x00000000, 0x00000000, 0x00000000}},  //   spes,   ,   ,
  { {0x7d09004e, 0xdb1e0f49, 0xc332009b, 0x00000000}},  //   ppes, íván, הוט_,
  { {0xddc90363, 0x290d001a, 0x3ead0485, 0x00000000}},  //   ljež, ţean_, miet_,
  { {0x3ead002b, 0xdd8e0025, 0x00000000, 0x00000000}},  //   liet_, _سوى_,   ,
  { {0xd62a003b, 0xf8bf0010, 0x386101f3, 0x00000000}},  //   лове_, zség_, _dahr_,
  { {0x3ead0ebd, 0x6298001e, 0x201c1701, 0x00000000}},  //   niet_, īvok, zavi_,
  { {0x201c000a, 0x98a6007c, 0x20ca0061, 0x00000000}},  // [af20] yavi_, _гипе, ाकमध,
  { {0xb97b00b6, 0x8c3c014a, 0x3ead00bb, 0x00000000}},  //   _עניי, tiği, hiet_,
  { {0x8c1a00b6, 0x3ead0036, 0x6fa70061, 0x00000000}},  //   רועי, kiet_, _केलं,
  { {0x3ead0f68, 0xf8bf0047, 0x8c3c014a, 0x00000000}},  //   jiet_, tség_, riği,
  { {0x3ead3460, 0x201c0340, 0x64430129, 0x00000000}},  //   diet_, tavi_, ònic,
  { {0x2eb20164, 0x04960025, 0x31660023, 0x00000000}},  //   ुक्त, _السح, rvoz_,
  { {0xf8bf0047, 0x201c0340, 0x321d0036, 0x00000000}},  //   sség_, ravi_, bawy_,
  { {0x25ad10f7, 0x93b7009b, 0x877b0049, 0x00000000}},  //   _želi_, _הללו_, טאצי,
  { {0x25a0006b, 0x2b4e00c4, 0xf8bf0068, 0x00000000}},  //   nzil_, _spfc_, lsée_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3ead3461, 0xf8bf00f4, 0xaca900a1, 0x00000000}},  //   biet_, nsée_, جھنے_,
  { {0x59aa007d, 0x3ead200a, 0xf8bf009d, 0x00000000}},  //   _चेहर, ciet_, isée_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x321d0036, 0x98ab0035, 0xf99f0026, 0x00000000}},  //   zawy_, ducă_, rzè_,
  { {0x48a80077, 0x21240068, 0x00000000, 0x00000000}},  //   стям_, _lvmh_,   ,
  { {0x386101a2, 0x7c3a01d6, 0x9f4d0068, 0x00000000}},  //   _wahr_, lgtr, înée_,
  { {0x9419026b, 0x00000000, 0x00000000, 0x00000000}},  // [af30] ижат_,   ,   ,
  { {0x7c3a0011, 0x7e623462, 0x3ead3463, 0x00000000}},  //   ngtr, _laop, ziet_,
  { {0xd3710054, 0x321d0036, 0x249800e5, 0x00000000}},  //   بها_, tawy_, _dlrm_,
  { {0x7e620161, 0xddc9016e, 0x00000000, 0x00000000}},  //   _naop, vjež,   ,
  { {0x3ead0011, 0x2bcf007d, 0x763a0049, 0x00000000}},  //   viet_, _सुना, _דערג,
  { {0xa06901f9, 0x29090020, 0xd0060478, 0x00000000}},  //   рака_, _mtaa_, оеше_,
  { {0x3ead3464, 0x6457008e, 0x00000000, 0x00000000}},  //   tiet_, mexi,   ,
  { {0x6457027b, 0xd109023c, 0x00000000, 0x00000000}},  //   lexi, _نقره_,   ,
  { {0x0c790147, 0xa28200a1, 0x8d550088, 0x00000000}},  //   асны_, _تینو, ітич,
  { {0x64570211, 0x4b25189f, 0x3ead0089, 0x00000000}},  //   nexi, омов, siet_,
  { {0xa49b000a, 0xfbd10025, 0x00000000, 0x00000000}},  //   _atòk, بتة_,   ,
  { {0x28d2013d, 0xe8d90082, 0x6aaf06ed, 0x00000000}},  //   _दीजि, _trớ_, gicf,
  { {0x6abd008e, 0x2d820056, 0x00000000, 0x00000000}},  //   érfa, øket_,   ,
  { {0x64b80164, 0xf8bf009d, 0xfc460802, 0x00000000}},  //   _आदेश, ysée_, čích_,
  { {0x7c6400a1, 0x378700ed, 0x64570133, 0x00000000}},  //   _راول, обро_, dexi,
  { {0x6e3b04cb, 0x316d3465, 0x15e50061, 0x00000000}},  //   ngub, _orez_, _कणखर_,
  { {0x2909001c, 0x34aa003b, 0xda7b009b, 0x00000000}},  // [af40] _gtaa_, авао_, _כנקר,
  { {0x61e600b9, 0x14260088, 0xe3b20137, 0x00000000}},  //   _úkli, ідем, ورا_,
  { {0x2bcf001c, 0xe1fa003b, 0xa5bb004a, 0x00000000}},  //   _सुमा, аге_, _neóf,
  { {0x316d01d9, 0x366a012b, 0xf8bf009d, 0x00000000}},  //   _brez_, _тамо_, rsée_,
  { {0xf8bf00f4, 0x60ca0168, 0x316d00e5, 0x00000000}},  //   ssée_, tofm, _crez_,
  { {0x7e6205fa, 0x2bcf0164, 0xf9930104, 0x00000000}},  //   _saop, _सुभा, ורד_,
  { {0x9f030025, 0x442a2552, 0x644e0066, 0x00000000}},  //   وووو, _idb_, _ibbi,
  { {0x442a0066, 0x66040b53, 0x00000000, 0x00000000}},  //   _hdb_, ncik,   ,
  { {0x7c3a001c, 0x7524014a, 0x442a0288, 0x00000000}},  //   tgtr, nsiz, _kdb_,
  { {0x628200b0, 0x442a3466, 0x75240197, 0x00000000}},  //   ljoo, _jdb_, isiz,
  { {0x442a006b, 0xc3fb0049, 0x0eba007e, 0x00000000}},  //   _mdb_, יליש, _куды_,
  { {0x7524014a, 0x442a1325, 0x66040305, 0x00000000}},  //   ksiz, _ldb_, jcik,
  { {0x6e20011c, 0x644e0197, 0x6ef50006, 0x00000000}},  //   mamb, _obbi, _išba,
  { {0x6e2009f3, 0x6aaf02c2, 0x75243467, 0x00000000}},  //   lamb, sicf, dsiz,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x644e3468, 0x6e20020c, 0x8f9b0104, 0x00000000}},  //   _abbi, namb, בילי,
  { {0x6457049a, 0x6e200020, 0x7a440010, 0x00000000}},  // [af50] texi, iamb, sító,
  { {0x6e200020, 0x442a0061, 0xd5b801ff, 0x00000000}},  //   hamb, _cdb_, іст_,
  { {0xd37b008b, 0x64570142, 0x6e200020, 0x00000000}},  //   шча_, rexi, kamb,
  { {0x6e200020, 0x442a2be8, 0x644e00d9, 0x00000000}},  //   jamb, _edb_, _ebbi,
  { {0x21690175, 0x661d0dec, 0x442a013e, 0x00000000}},  //   сили_, _iesk, _fdb_,
  { {0xa5bb0051, 0x80a80088, 0x442a05af, 0x00000000}},  //   _ndói, овів_, _gdb_,
  { {0x661d0368, 0x4421020c, 0x00000000, 0x00000000}},  //   _kesk, mah_,   ,
  { {0x4421020c, 0x661d00b9, 0x7c2a0009, 0x00000000}},  //   lah_, _jesk, _adfr,
  { {0x661d0169, 0x2d8b00f4, 0xf1b901a8, 0x00000000}},  //   _mesk, âce_, _beše_,
  { {0x44210281, 0x23bf001c, 0x6aad3469, 0x00000000}},  //   nah_, _एखाद, _amaf,
  { {0x6e202174, 0xfa6a0264, 0x395201d6, 0x00000000}},  //   bamb, банк_, _spys_,
  { {0x442109f3, 0x661d0027, 0x6e200207, 0x00000000}},  //   hah_, _nesk, camb,
  { {0x4421020c, 0xed580088, 0x75240045, 0x00000000}},  //   kah_, _мої_, xsiz,
  { {0x44211092, 0xf8bf0211, 0x45090044, 0x00000000}},  //   jah_, drés_, _লিংক_,
  { {0x66e60057, 0x4421020c, 0x661d059d, 0x00000000}},  //   зова, dah_, _besk,
  { {0x661d01ca, 0xe737025f, 0x442a009d, 0x00000000}},  //   _cesk, џет_, _sdb_,
  { {0xf8bf0fdb, 0x442a0093, 0x4421003f, 0x00000000}},  // [af60] grés_, _pdb_, fah_,
  { {0x7524005d, 0x6604003b, 0x442104cb, 0x00000000}},  //   rsiz, scik, gah_,
  { {0x7ae40093, 0x6e200ea6, 0x0af90044, 0x00000000}},  //   _khit, yamb, _আবুল_,
  { {0x661d0343, 0x44210058, 0x25e90061, 0x00000000}},  //   _gesk, aah_, चेही_,
  { {0x4421020c, 0x7c210190, 0x22b80059, 0x00000000}},  //   bah_, kalr, nčki_,
  { {0x4421346a, 0x10a300c0, 0x644e0afb, 0x00000000}},  //   cah_, ничн, _ubbi,
  { {0x6e20000b, 0x7ae40e33, 0xb4d8007d, 0x00000000}},  //   tamb, _ohit, ाती_,
  { {0x3da601fb, 0x2bcf007d, 0x629b04a5, 0x00000000}},  //   зроб, _सुधा, _gluo,
  { {0x81d30044, 0x22b80059, 0xa3e8013d, 0x00000000}},  //   হেব_, jčki_, मेर_,
  { {0x7ae4346b, 0xc19b0104, 0x7af6000a, 0x00000000}},  //   _ahit, _השמי, _aiyt,
  { {0x6e20000b, 0x7ae430b3, 0x69c40843, 0x00000000}},  //   pamb, _bhit, _axie,
  { {0x7ae40263, 0x201e0ae4, 0xc33300a0, 0x00000000}},  //   _chit, _heti_, עור_,
  { {0x44211c52, 0x661d01aa, 0x201e0ed5, 0x00000000}},  //   yah_, _resk, _keti_,
  { {0x7ae40004, 0x7c21060d, 0xf8bf009d, 0x00000000}},  //   _ehit, calr, vrés_,
  { {0x44210059, 0x661d0229, 0x656f0009, 0x00000000}},  //   vah_, _pesk, _srch,
  { {0x4421020c, 0xddc20428, 0x201e0059, 0x00000000}},  //   wah_, _množ, _leti_,
  { {0x44210127, 0x661d006c, 0x00000000, 0x00000000}},  // [af70] tah_, _vesk,   ,
  { {0x656f01ca, 0x661d0007, 0xf8bf0666, 0x00000000}},  //   _vrch, _wesk, rrés_,
  { {0x4421020c, 0x661d037e, 0x6abd346c, 0x00000000}},  //   rah_, _tesk, onsf,
  { {0x44211a56, 0xf8bf00d4, 0x6abd00ea, 0x00000000}},  //   sah_, prés_, nnsf,
  { {0x201e022b, 0x656f0056, 0xf1940088, 0x00000000}},  //   _beti_, _urch, ниць,
  { {0x201e0145, 0x44210085, 0x00000000, 0x00000000}},  //   _ceti_, qah_,   ,
  { {0x201e0027, 0x7c210133, 0x00000000, 0x00000000}},  //   _deti_, valr,   ,
  { {0x2d95007c, 0x00000000, 0x00000000, 0x00000000}},  //   дрос,   ,   ,
  { {0x4c35008b, 0x6298001e, 0x7ae40016, 0x00000000}},  //   мэнт, īvot, _rhit,
  { {0x7ae40065, 0x201e009f, 0x22b800ca, 0x00000000}},  //   _shit, _geti_, včki_,
  { {0x7fb90014, 0x60c40051, 0x7d190009, 0x00000000}},  //   _بهار_, éime, _wwws,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7c2900da, 0xd6c50044, 0x201e0471, 0x00000000}},  //   _долг_, ্ষায, _yeti_,
  { {0x7ae40866, 0x7e6908e0, 0x6d490035, 0x00000000}},  //   _whit, ldep, mtea,
  { {0x6d49002a, 0x7ae41d5d, 0x61fb016e, 0x00000000}},  //   ltea, _thit, _ogul,
  { {0xe8d9001d, 0x61fb0065, 0x61f60006, 0x00000000}},  //   _trở_, _ngul, žyli,
  { {0x6d490c0e, 0x17fa0025, 0x68f70045, 0x00000000}},  // [af80] ntea, _وردة_, _fixd,
  { {0xb937007b, 0xb4d8062e, 0x61fb1052, 0x00000000}},  //   _קריג_, ाते_, _agul,
  { {0xe8140365, 0xa3e803d7, 0x201e197d, 0x00000000}},  //   _त्या_, में_, _reti_,
  { {0x201e346d, 0x7e690190, 0x673c02db, 0x00000000}},  //   _seti_, jdep, murj,
  { {0xba480006, 0x7e692ca0, 0x20ca0025, 0x00000000}},  //   _grįž, ddep, يبتي_,
  { {0xd00f0379, 0x6d490051, 0xcf9a00e2, 0x00000000}},  //   لله_, dtea, жји_,
  { {0x201e346e, 0xe29a0152, 0x6d490dd1, 0x00000000}},  //   _veti_, _дав_, etea,
  { {0x61fb0009, 0x7e6900ea, 0x6d49346f, 0x00000000}},  //   _ggul, gdep, ftea,
  { {0x1ee8026c, 0x6d490051, 0x63ae0006, 0x00000000}},  //   _ہوئی_, gtea, žinė,
  { {0xe5710049, 0x2bcf007d, 0x6abd005b, 0x00000000}},  //   אַט_, _सुहा, wnsf,
  { {0x764d014a, 0xaab5007e, 0x8f75007e, 0x00000000}},  //   yfay, ейні, _пуці,
  { {0x3a200129, 0x3d19013d, 0xbb93007c, 0x00000000}},  //   _ceip_, _मौके_, тающ,
  { {0x6d4932aa, 0xdd9200a6, 0x6abd0669, 0x00000000}},  //   ctea, _جوش_, rnsf,
  { {0xfb1900a1, 0x290000d4, 0x00000000, 0x00000000}},  //   _کروں_, _duia_,   ,
  { {0xf1b90b18, 0xeaf80123, 0x64430129, 0x00000000}},  //   _meša_, ثریت_, ònim,
  { {0xdce2016c, 0xdddb04eb, 0x649b0035, 0x00000000}},  //   _broć, ljuš, _cîin,
  { {0x2900273e, 0x7d0d0065, 0x22b800ca, 0x00000000}},  // [af90] _guia_, _çast, nčku_,
  { {0x764d0190, 0x673c00ca, 0xf1b93470, 0x00000000}},  //   sfay, burj, _neša_,
  { {0x656d0934, 0x6d49002d, 0x7e6916d4, 0x00000000}},  //   svah, ztea, ydep,
  { {0x4ed00044, 0x02c90061, 0x6d490943, 0x00000000}},  //   াগুল, िकेन, ytea,
  { {0x6d490197, 0x7e690142, 0xd009003b, 0x00000000}},  //   xtea, vdep, пеле_,
  { {0xfc4e0082, 0x3f6916e8, 0x00000000, 0x00000000}},  //   _sửng_, зико_,   ,
  { {0xff51004b, 0x6d4900d9, 0xcef500e2, 0x00000000}},  //   اخت_, wtea, нчињ,
  { {0x6d49006c, 0x4d65003b, 0x00000000, 0x00000000}},  //   ttea, екив,   ,
  { {0x7e691aae, 0x6d490e46, 0x00000000, 0x00000000}},  //   rdep, utea,   ,
  { {0x6d493471, 0x317800f3, 0x7e690056, 0x00000000}},  //   rtea, _تحفظ_, sdep,
  { {0x6d493472, 0x7e6900d4, 0x7a6a0478, 0x00000000}},  //   stea, pdep, пинг_,
  { {0x9cea026c, 0x6d493473, 0x62993474, 0x00000000}},  //   _ہونے_, ptea, nkwo,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f010010, 0x3ebf0a6b, 0x2a690288, 0x00000000}},  //   _kulc, lnut_, _eaab_,
  { {0xc5f80164, 0x7bd80006, 0xac7400a6, 0x00000000}},  //   ंख्य_, _gyvu, _جانش,
  { {0x3ebf021e, 0xdce20166, 0xb4d8006e, 0x00000000}},  //   nnut_, _proć, ात्_,
  { {0x69c1011f, 0xe5a3025f, 0xcdac0049, 0x00000000}},  // [afa0] şler, гити, ֿיבֿ,
  { {0x62990112, 0x03a63475, 0x673c3476, 0x00000000}},  //   ekwo, низо, purj,
  { {0xdce901d9, 0x3ebf3477, 0xf4841125, 0x00000000}},  //   jveč, knut_, _یاسی,
  { {0xdce916d0, 0xa683007c, 0x41e6007e, 0x00000000}},  //   dveč, _блюд, ніла,
  { {0x3ebf0142, 0x26d20020, 0x26c0228c, 0x00000000}},  //   dnut_, moyo_, mnio_,
  { {0x232a0077, 0x26c00006, 0x26d20022, 0x00000000}},  //   _ноги_, lnio_, loyo_,
  { {0x645e0a13, 0x82a60088, 0x6f010035, 0x00000000}},  //   mepi, _завж, _culc,
  { {0x6f01050a, 0x645e2910, 0x26c00207, 0x00000000}},  //   _dulc, lepi, nnio_,
  { {0x8ffa00a6, 0xfd0f0167, 0x26c03478, 0x00000000}},  //   _فرار_, یجی_, inio_,
  { {0x2a690004, 0x645e3479, 0xc5f3007b, 0x00000000}},  //   _saab_, nepi, נדז_,
  { {0x34b700b3, 0x26d20022, 0xdb1c014a, 0x00000000}},  //   תפים_, koyo_, _özür,
  { {0x6ee52cf4, 0x26d20093, 0x645e0052, 0x00000000}},  //   tóbe, joyo_, hepi,
  { {0x26c01070, 0x645e0145, 0x26d20022, 0x00000000}},  //   dnio_, kepi, doyo_,
  { {0x645e016e, 0x26c0347a, 0x00000000, 0x00000000}},  //   jepi, enio_,   ,
  { {0x645e013e, 0x67d50f62, 0x65660146, 0x00000000}},  //   depi, тову, _askh,
  { {0xd6d802e9, 0x7bdb00b3, 0x7d02347b, 0x00000000}},  //   ету_, _מקוו, _kuos,
  { {0x7d020997, 0xeaf80070, 0xa8020276, 0x00000000}},  // [afb0] _juos, _ثروت_, ğırd,
  { {0x64a4012b, 0x645e00bb, 0xa8020279, 0x00000000}},  //   гађа, gepi, şırd,
  { {0x69d50061, 0x26d20022, 0x00000000, 0x00000000}},  //   _युती, boyo_,   ,
  { {0x46a5007d, 0x26d2004a, 0x26c000f6, 0x00000000}},  //   _ऐतिह, coyo_, cnio_,
  { {0x7d02010a, 0xa069007e, 0x62990112, 0x00000000}},  //   _nuos, дала_, rkwo,
  { {0x6f010089, 0x645e0197, 0x6299050c, 0x00000000}},  //   _pulc, cepi, skwo,
  { {0x6e22010f, 0xb2ab005e, 0x3c2d0010, 0x00000000}},  //   _beob, _етаж_, _jövő_,
  { {0x442304d7, 0x6f010375, 0x44310243, 0x00000000}},  //   _hej_, _vulc, _hdz_,
  { {0xc05b01fb, 0xdce907a0, 0x6e221bf1, 0x00000000}},  //   _ніж_, sveč, _deob,
  { {0xeb99012b, 0x1fa704f9, 0x44230721, 0x00000000}},  //   дио_, _прег, _jej_,
  { {0xfaa60a27, 0x44230039, 0x4431004a, 0x00000000}},  //   вано, _mej_, _mdz_,
  { {0x645e0046, 0x6e2200d9, 0x44232e10, 0x00000000}},  //   zepi, _geob, _lej_,
  { {0x64550091, 0x81d30044, 0x645e347c, 0x00000000}},  //   _obzi, হের_, yepi,
  { {0x4423347d, 0x26d20ef9, 0xe8f7347e, 0x00000000}},  //   _nej_, woyo_, кля_,
  { {0x26c00046, 0x26d20093, 0x645e347f, 0x00000000}},  //   tnio_, toyo_, vepi,
  { {0xf1b9016c, 0x645501a2, 0x7e6b01c3, 0x00000000}},  //   _nešo_, _abzi, _jagp,
  { {0x26d2011c, 0x7e6b006a, 0x44230065, 0x00000000}},  // [afc0] royo_, _magp, _bej_,
  { {0x26c012f8, 0x7e6b0058, 0x6d5900e7, 0x00000000}},  //   snio_, _lagp, _mpwa,
  { {0x645e002d, 0xc7a601fb, 0x7c230093, 0x00000000}},  //   repi, _ринк, _menr,
  { {0xe2970888, 0x7e6b006a, 0x645e010e, 0x00000000}},  //   ках_, _nagp, sepi,
  { {0x6e2200d4, 0x44310032, 0x40340b86, 0x00000000}},  //   _reob, _fdz_, гелс,
  { {0x212d0059, 0x44233480, 0x76441e00, 0x00000000}},  //   _dveh_, _gej_, lgiy,
  { {0x7d02021e, 0x44440061, 0x7e6b0190, 0x00000000}},  //   _suos, mg_, _bagp,
  { {0xa3e70183, 0x764401dd, 0x44443481, 0x00000000}},  //   _परत_, ngiy, lg_,
  { {0xade301fb, 0x7e6b3482, 0x7c23005b, 0x00000000}},  //   ицьк, _dagp, _benr,
  { {0x4444084e, 0x7d02021e, 0x7c2301c5, 0x00000000}},  //   ng_, _vuos, _cenr,
  { {0xdeef03c8, 0x4444002a, 0xeb9700ed, 0x00000000}},  //   _вы_, ig_, виќ_,
  { {0x7d0200b0, 0x65640009, 0x13b50044, 0x00000000}},  //   _tuos, kwih, _জুড়,
  { {0xf2d3007b, 0x7c2301e5, 0x7e603483, 0x00000000}},  //   שער_, _fenr, memp,
  { {0x7c2300f4, 0x444400b5, 0x6d4004cb, 0x00000000}},  //   _genr, jg_, muma,
  { {0x6d40005f, 0x87040401, 0x7c281b3c, 0x00000000}},  //   luma, ияте, madr,
  { {0x4444018e, 0x7c2802ae, 0x7e601035, 0x00000000}},  //   eg_, ladr, nemp,
  { {0x44310bd3, 0x44230b97, 0x00000000, 0x00000000}},  // [afd0] _pdz_, _pej_,   ,
  { {0x7c2800bb, 0x7e6000b0, 0x34bf007d, 0x00000000}},  //   nadr, hemp, ्वेद,
  { {0x6d400051, 0x44230018, 0x3cfc0026, 0x00000000}},  //   huma, _vej_, _mivv_,
  { {0x4444049b, 0x1de2024c, 0x6d40006c, 0x00000000}},  //   ag_, _परंत, kuma,
  { {0xdd86031d, 0x44230ad0, 0x7c280a2e, 0x00000000}},  //   _او_, _tej_, kadr,
  { {0x6d40006c, 0x44440009, 0x7c280027, 0x00000000}},  //   duma, cg_, jadr,
  { {0x7e6b006a, 0xc4d200a3, 0x752d0026, 0x00000000}},  //   _pagp, _הגם_, lsaz,
  { {0x660d0475, 0x9294007e, 0x6d400197, 0x00000000}},  //   ncak, _касц, fuma,
  { {0x6d400181, 0x752d0282, 0x7c230016, 0x00000000}},  //   guma, nsaz, _penr,
  { {0x6445020c, 0x4c8500ed, 0x7c280232, 0x00000000}},  //   nghi, улов, gadr,
  { {0x7c23027b, 0x7e6b119d, 0x644518e4, 0x00000000}},  //   _venr, _tagp, ighi,
  { {0xc86901f8, 0x6d400006, 0x38a60007, 0x00000000}},  //   _מן_, buma, _môre_,
  { {0x6d4026be, 0xf2d20097, 0x7c280292, 0x00000000}},  //   cuma, מעט_, badr,
  { {0x7c2802a4, 0x91ba00b6, 0xf74600ed, 0x00000000}},  //   cadr, תמשי, лего,
  { {0xb8dc02d2, 0xc795007e, 0x00000000, 0x00000000}},  //   _आग_, арты,   ,
  { {0x6b9c0030, 0x44440b78, 0x64450026, 0x00000000}},  //   ørge, wg_, eghi,
  { {0x6aa40020, 0x76443484, 0x00000000, 0x00000000}},  // [afe0] _ilif, rgiy,   ,
  { {0x44440006, 0x64450197, 0x7e6000b4, 0x00000000}},  //   ug_, gghi, zemp,
  { {0x6d400035, 0x7e6011b3, 0xd62a0265, 0x00000000}},  //   zuma, yemp, _поне_,
  { {0x44440016, 0x914a00ed, 0x7e600a5e, 0x00000000}},  //   sg_, ечка_, xemp,
  { {0x44440009, 0x3942006c, 0xc43400a6, 0x00000000}},  //   pg_, nuks_, _نکات,
  { {0x6aa40016, 0xc953009b, 0x6d400006, 0x00000000}},  //   _llif, צמו_, vuma,
  { {0x6aa43485, 0x39423486, 0x00000000, 0x00000000}},  //   _olif, huks_,   ,
  { {0x1d340001, 0x39420004, 0x60c30051, 0x00000000}},  //   ания, kuks_, annm,
  { {0x62800841, 0x7e6004d4, 0x22930054, 0x00000000}},  //   _inmo, remp, _القس,
  { {0x7e600292, 0x6aa4000b, 0xfc4600b9, 0x00000000}},  //   semp, _alif, _číst_,
  { {0x6d40006c, 0x7c280c46, 0xf8bf0010, 0x00000000}},  //   suma, radr, ssék_,
  { {0x7c282280, 0x6d4000b0, 0x22460127, 0x00000000}},  //   sadr, puma, ngok_,
  { {0x7c283487, 0xdebb01ce, 0x00000000, 0x00000000}},  //   padr, _אמאל,   ,
  { {0x2a6d00b9, 0x6aa400be, 0x01d10044, 0x00000000}},  //   žeb_, _elif, ়েকদ,
  { {0x6280001c, 0xa3b4013d, 0x81b80044, 0x00000000}},  //   _onmo, _जेल_, _ঘুম_,
  { {0x7d0d0051, 0x6b7b00a3, 0x752d0032, 0x00000000}},  //   _éasc, _טרונ, tsaz,
  { {0x660d1a03, 0x7aed2119, 0xf5590014, 0x00000000}},  // [aff0] rcak, _ihat, ضلاب_,
  { {0x752d0cc8, 0x660d0093, 0x6280068f, 0x00000000}},  //   rsaz, scak, _anmo,
  { {0x6445001a, 0x7aed0727, 0x752d0207, 0x00000000}},  //   rghi, _khat, ssaz,
  { {0x7d090023, 0x22460022, 0x00000000, 0x00000000}},  //   yqes, ggok_,   ,
  { {0x2169013b, 0x7aff0065, 0x7aed1f74, 0x00000000}},  //   тили_, _miqt, _mhat,
  { {0xf4870245, 0x60da0009, 0x00000000, 0x00000000}},  //   _сумн, _cktm,   ,
  { {0x7aed1e17, 0x00000000, 0x00000000, 0x00000000}},  //   _ohat,   ,   ,
  { {0x8d55007c, 0xed5900ed, 0x7aed0011, 0x00000000}},  //   аточ, вои_, _nhat,
  { {0x31580025, 0x98a20036, 0x00000000, 0x00000000}},  //   _مجلة_, lską_,   ,
  { {0x7aed0032, 0x8b07013e, 0x6aa404a5, 0x00000000}},  //   _ahat, _neří, _slif,
  { {0x6a8600e3, 0x2bcf0164, 0x7aed0048, 0x00000000}},  //   ална, _सुखा, _bhat,
  { {0x7f430198, 0x3942006c, 0x00000000, 0x00000000}},  //   munq, tuks_,   ,
  { {0x7f430207, 0x7aed3488, 0x00000000, 0x00000000}},  //   lunq, _dhat,   ,
  { {0x8c42041f, 0x8f000088, 0x7ebe0e3f, 0x00000000}},  //   _деше, цiї_, rūpe,
  { {0xd62a0a27, 0x4cba009b, 0x6aa4002b, 0x00000000}},  //   кове_, _במסג, _tlif,
  { {0x3942006c, 0x6aa40020, 0xa5bb0325, 0x00000000}},  //   puks_, _ulif, _teól,

  { {0x9426007c, 0x00000000, 0x00000000, 0x00000000}},  // [b000] имае,   ,   ,
  { {0x9989016c, 0xc4830d15, 0xd70a01ab, 0x00000000}},  //   _udaš_, олук, _иное_,
  { {0xa3d303d7, 0xe9df0211, 0x61e90968, 0x00000000}},  //   _हुआ_, ngún_, _azel,
  { {0x5b5601ce, 0x25080014, 0x00000000, 0x00000000}},  //   ישען_, _مرسی_,   ,
  { {0xe29702ea, 0x61e900b4, 0x00000000, 0x00000000}},  //   јач_, _czel,   ,
  { {0x61e90089, 0x78bc0026, 0x64a61abd, 0x00000000}},  //   _dzel, nirv, _тага,
  { {0x61e90010, 0x00000000, 0x00000000, 0x00000000}},  //   _ezel,   ,   ,
  { {0x62800f10, 0x00000000, 0x00000000, 0x00000000}},  //   _unmo,   ,   ,
  { {0x3b07008e, 0x7aed005b, 0x00000000, 0x00000000}},  //   _aunq_, _rhat,   ,
  { {0x7aed3489, 0x00000000, 0x00000000, 0x00000000}},  //   _shat,   ,   ,
  { {0xb479007b, 0x9e66041f, 0xe4790049, 0x00000000}},  //   אָרי, _введ, אָרש,
  { {0xd90f0014, 0x00000000, 0x00000000, 0x00000000}},  //   ویب_,   ,   ,
  { {0xa3d303d7, 0x1ea90076, 0x78bc000c, 0x00000000}},  //   _हुई_, _حالي_, firv,
  { {0xa8a4017f, 0x7aed00ab, 0x98b90035, 0x00000000}},  //   орск, _what, dusă_,
  { {0x7c650a90, 0xd6db00e3, 0x787c0039, 0x00000000}},  //   _دانل, вта_, _såvä,
  { {0xabfb009b, 0x00000000, 0x00000000, 0x00000000}},  //   _בהור,   ,   ,
  { {0x6abd010e, 0x38c902fd, 0x04c903ec, 0x00000000}},  // [b010] misf, _مادی_, هوري_,
  { {0x44270051, 0x6abd000c, 0x673a0059, 0x00000000}},  //   ún_, lisf, štja,
  { {0x61e90010, 0x3ea60129, 0x00000000, 0x00000000}},  //   _szel, _olot_,   ,
  { {0x42d80451, 0x6abd01e5, 0x7f430197, 0x00000000}},  //   афія_, nisf, vunq,
  { {0x290125ba, 0x00000000, 0x00000000, 0x00000000}},  //   _kiha_,   ,   ,
  { {0x4174035b, 0x2bcf006e, 0xe0d803e8, 0x00000000}},  //   غانس, _सुझा, аві_,
  { {0x3ea60030, 0x2901348a, 0xf83800a0, 0x00000000}},  //   _blot_, _miha_, בנות_,
  { {0xa3d303d7, 0x1e850098, 0x3ea600d4, 0x00000000}},  //   _हुए_, слим, _clot_,
  { {0xf2d2007b, 0xdfd100a1, 0x6abd002b, 0x00000000}},  //   _זען_, _کيا_, disf,
  { {0xf65f0030, 0xf1b9012d, 0x81f400a1, 0x00000000}},  //   _sjæl_, _neši_, _ظہور_,
  { {0x3ea60030, 0x60da0049, 0x00000000, 0x00000000}},  //   _flot_, _עקענ,   ,
  { {0x3a2925a9, 0x00000000, 0x00000000, 0x00000000}},  //   _ceap_,   ,   ,
  { {0x29010066, 0x00000000, 0x00000000, 0x00000000}},  //   _biha_,   ,   ,
  { {0x7d1b002d, 0x00000000, 0x00000000, 0x00000000}},  //   mpus,   ,   ,
  { {0x2bcf0164, 0x31ae0010, 0x2901348b, 0x00000000}},  //   _सुचा, _közé_, _diha_,
  { {0xf74300ed, 0x59860088, 0x3a2900fa, 0x00000000}},  //   џето, _глиб, _geap_,
  { {0x2901002b, 0x7d1b238e, 0x00000000, 0x00000000}},  // [b020] _fiha_, npus,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x289700b3, 0x61e00016, 0x316d00e5, 0x00000000}},  //   _הדין_, _syml, _asez_,
  { {0x20050198, 0x63ae0521, 0x98b90035, 0x00000000}},  //   _agli_, _đinđ, pusă_,
  { {0x6f080142, 0x78c70010, 0xc05a01e1, 0x00000000}},  //   _sudc, _árví, гій_,
  { {0x987a007b, 0x9407005e, 0xa87a0049, 0x00000000}},  //   ראַט, _герб_, ראַר,
  { {0x645c348c, 0x4438348d, 0x3ea6071e, 0x00000000}},  //   _ibri, _idr_, _plot_,
  { {0x442a348e, 0x44380061, 0x20050207, 0x00000000}},  //   _heb_, _hdr_, _egli_,
  { {0x3a290784, 0x7d1b0b57, 0x443826ac, 0x00000000}},  //   _reap_, gpus, _kdr_,
  { {0x442a0089, 0xdce20091, 0x2cb812fe, 0x00000000}},  //   _jeb_, _prođ, òrd_,
  { {0x44380030, 0xef1a0200, 0xf1b910f5, 0x00000000}},  //   _mdr_, _сме_, _reši_,
  { {0x442a00d4, 0xe8d90011, 0x44380022, 0x00000000}},  //   _leb_, _trừ_, _ldr_,
  { {0x645c02d5, 0x588704af, 0x81da0055, 0x00000000}},  //   _obri, быва, ডের_,
  { {0x60c4002a, 0x442a0016, 0x6da3003b, 0x00000000}},  //   éimh, _neb_, _хиља,
  { {0x4993007a, 0x6f020026, 0x29010961, 0x00000000}},  //   زیگر, _kioc, _viha_,
  { {0x4438013f, 0x442a0032, 0x59da007d, 0x00000000}},  //   _adr_, _aeb_, _युवर,
  { {0x442a0145, 0xca38009b, 0xe694007c, 0x00000000}},  // [b030] _beb_, _הנחה_, читы,
  { {0xf99f0263, 0x4438348f, 0x442a00fa, 0x00000000}},  //   myè_, _cdr_, _ceb_,
  { {0x932700a1, 0x442a0145, 0x6d40010f, 0x00000000}},  //   صران, _deb_, hrma,
  { {0x645c3490, 0x7c2a0173, 0x442a007f, 0x00000000}},  //   _ebri, _lefr, _eeb_,
  { {0xf99f01aa, 0x7c380091, 0x765d0009, 0x00000000}},  //   nyè_, _odvr, _ibsy,
  { {0x44380197, 0xb6080161, 0x7c2a014a, 0x00000000}},  //   _gdr_, _vyšš, _nefr,
  { {0x6f0200ab, 0x26c93491, 0x6d400c4c, 0x00000000}},  //   _bioc, onao_, erma,
  { {0x6f023492, 0x645c0c33, 0x44210033, 0x00000000}},  //   _cioc, _zbri, lbh_,
  { {0x4421002a, 0xa2d60309, 0x7c2a010f, 0x00000000}},  //   obh_, यकर्, _befr,
  { {0x40340216, 0x7d1b04cb, 0x44210051, 0x00000000}},  //   _неус, rpus, nbh_,
  { {0xda660bbd, 0x7d1b1b5b, 0x4421131d, 0x00000000}},  //   овни, spus, ibh_,
  { {0x6f020198, 0xc33200b3, 0x4fd60049, 0x00000000}},  //   _gioc, ווט_, _וועב_,
  { {0xdce90119, 0x3ead093b, 0x7de706b4, 0x00000000}},  //   jveć, mhet_, _اسام,
  { {0x7c2a010f, 0x7cef01e3, 0x3ead3493, 0x00000000}},  //   _gefr, føre, lhet_,
  { {0x7d0b22ad, 0x7cef0030, 0x44381651, 0x00000000}},  //   _hugs, gøre, _rdr_,
  { {0x7d031642, 0x3ead3494, 0x442a1be3, 0x00000000}},  //   _hins, nhet_, _seb_,
  { {0x7d033495, 0x6e2b0047, 0x7d040051, 0x00000000}},  // [b040] _kins, _megb, _éist,
  { {0x7d03303f, 0x25de0061, 0x6e2b1428, 0x00000000}},  //   _jins, _कुणी_, _legb,
  { {0x7d030199, 0x656f0f10, 0x442a006b, 0x00000000}},  //   _mins, _esch, _veb_,
  { {0xf99f00f4, 0x4b4c0049, 0x44210051, 0x00000000}},  //   ccès_, רגאַ, abh_,
  { {0x3ead3496, 0x64430b76, 0x6f020051, 0x00000000}},  //   dhet_, ónic, _rioc,
  { {0x7d03002b, 0x645c04c6, 0x10a30726, 0x00000000}},  //   _nins, _ubri, мичн,
  { {0x7d0b001e, 0xf99f0263, 0x3ead0007, 0x00000000}},  //   _augs, zyè_, fhet_,
  { {0x7d03028c, 0x3ead1f82, 0x7d0b0058, 0x00000000}},  //   _ains, ghet_, _bugs,
  { {0x6fda0316, 0x6d400112, 0x7d031ae9, 0x00000000}},  //   _पुरू, urma, _bins,
  { {0x7d03011f, 0x6d400210, 0xf99f01aa, 0x00000000}},  //   _cins, rrma, vyè_,
  { {0x7d0301b5, 0xdee6025f, 0xf413009b, 0x00000000}},  //   _dins, _дожи, ופת_,
  { {0x7d0326cf, 0xf99f01aa, 0x0d860b7b, 0x00000000}},  //   _eins, tyè_, _млен,
  { {0x7d0301d2, 0xeabf0026, 0x3942012d, 0x00000000}},  //   _fins, riù_, grks_,
  { {0x2498006c, 0xf7730070, 0xf99f01aa, 0x00000000}},  //   _norm_, واز_, ryè_,
  { {0xf99f01aa, 0xeabf0197, 0x00000000, 0x00000000}},  //   syè_, più_,   ,
  { {0x7d03010f, 0x7cef0637, 0x657d0ed5, 0x00000000}},  //   _zins, røre, _prsh,
  { {0x7cef0190, 0x00000000, 0x00000000, 0x00000000}},  // [b050] søre,   ,   ,
  { {0xde8f0011, 0xd37b012b, 0x92c70044, 0x00000000}},  //   _kịch_, иче_, _উঠে_,
  { {0x44210033, 0xf8bf00f4, 0xdce90091, 0x00000000}},  //   rbh_, ssés_, sveć,
  { {0x656f010f, 0x3ead0023, 0x6ee50036, 0x00000000}},  //   _tsch, xhet_, róbk,
  { {0xde8f001d, 0x24980498, 0xf1b901ed, 0x00000000}},  //   _lịch_, _form_, _nešt_,
  { {0xc5fa00b6, 0xccf800b9, 0x7d0b3497, 0x00000000}},  //   _לפרט, jmě_, _rugs,
  { {0x6f1a001c, 0x3ead1204, 0xbf680025, 0x00000000}},  //   _cttc, thet_, قصيم_,
  { {0x764d170b, 0x7d030051, 0x656d00e7, 0x00000000}},  //   ngay, _sins, owah,
  { {0x7d03011c, 0x3ebf008d, 0x3ead3498, 0x00000000}},  //   _pins, riut_, rhet_,
  { {0x2ca90081, 0x6e2b15d0, 0x3ead3499, 0x00000000}},  //   скоп_, _wegb, shet_,
  { {0x7d0305ce, 0xcb69005e, 0x00000000, 0x00000000}},  //   _vins, щане_,   ,
  { {0xde8f001d, 0x7d0300b5, 0xa96a0e75, 0x00000000}},  //   _dịch_, _wins, бима_,
  { {0x7d03002b, 0x4999007c, 0x290f009d, 0x00000000}},  //   _tins, отря_, _égal_,
  { {0x23bd02fb, 0xa3ab006e, 0x7e690d6f, 0x00000000}},  //   ्पाद, गना_, leep,
  { {0xfaa6013b, 0x17790057, 0x6d490035, 0x00000000}},  //   _нако, ость_, luea,
  { {0x764d22dc, 0x6b9c0210, 0x46f50088, 0x00000000}},  //   ggay, ärge, дчут,
  { {0x656d22dc, 0x6d490035, 0x00000000, 0x00000000}},  // [b060] gwah, nuea,   ,
  { {0x7e690112, 0x6aac0309, 0x897b00b3, 0x00000000}},  //   heep, _चतुर, _פריצ,
  { {0x389b061e, 0x249800c7, 0x35fa007a, 0x00000000}},  //   _היינ, _vorm_, _گردد_,
  { {0x5b3a0049, 0x656d0009, 0x00000000, 0x00000000}},  //   מגעק, bwah,   ,
  { {0x317f0489, 0x24980ff4, 0x055501e0, 0x00000000}},  //   _cruz_, _torm_, _отря,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa857009b, 0x00000000, 0x00000000, 0x00000000}},  //   פיקה_,   ,   ,
  { {0x877b007b, 0xbd181c31, 0x00000000, 0x00000000}},  //   מאצי, ожих_,   ,
  { {0x5046349a, 0x61430098, 0x6d49008e, 0x00000000}},  //   _неаб, _пета, guea,
  { {0x6f1a001c, 0xd00f0025, 0x2f110051, 0x00000000}},  //   _tttc, _ملك_, _fág_,
  { {0xe457007b, 0xccf800b9, 0x7e6900e0, 0x00000000}},  //   הייט_, rmě_, beep,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69da001a, 0x00000000, 0x00000000, 0x00000000}},  //   şten,   ,   ,
  { {0xddeb007b, 0xde8f0011, 0x00000000, 0x00000000}},  //   _פֿאָ, _tịch_,   ,
  { {0x7b0600b9, 0x24c40044, 0x6d950066, 0x00000000}},  //   ístě, ্তাহ, _eżaġ,
  { {0x5694003b, 0xe8d9001d, 0x27ed00b9, 0x00000000}},  //   наст, _trữ_, řeno_,
  { {0x5499007e, 0x764d349b, 0xba740014, 0x00000000}},  // [b070] оваў_, rgay, _سايت,
  { {0xe8d3026c, 0x8707007e, 0x656d01a2, 0x00000000}},  //   _سمجھ, _няме, rwah,
  { {0x656d2934, 0x98ab001a, 0x6aad04d3, 0x00000000}},  //   swah, ască_, _klaf,
  { {0x38af010f, 0xddd400b9, 0x00000000, 0x00000000}},  //   _würd_, žařs,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6aad07b5, 0x2f110b33, 0x2054005e, 0x00000000}},  //   _llaf, _pág_, етър,
  { {0xb4d9024c, 0x44330142, 0x6aad349c, 0x00000000}},  //   ावी_, max_, _olaf,
  { {0x44330142, 0x9258007c, 0x6d490035, 0x00000000}},  //   lax_, _наст_, tuea,
  { {0x7e690112, 0xa15901ee, 0x905501ee, 0x00000000}},  //   reep, _фазу_, _овац,
  { {0x4433001c, 0x6aad2aa7, 0x629b012d, 0x00000000}},  //   nax_, _alaf, _houo,
  { {0xeb9900ed, 0x6aad00bb, 0xbc690123, 0x00000000}},  //   цин_, _blaf, ممکن_,
  { {0x929d0036, 0x60c3014a, 0x443323d6, 0x00000000}},  //   _miło, linm, hax_,
  { {0x6d490489, 0x3ea20039, 0x44330066, 0x00000000}},  //   quea, ökte_, kax_,
  { {0x44330066, 0x6aad00ea, 0xfbc500a8, 0x00000000}},  //   jax_, _elaf, _обло,
  { {0x66e6013b, 0x6aad0146, 0x00000000, 0x00000000}},  //   дова, _flaf,   ,
  { {0x6aad00e5, 0xfe79013e, 0x60c30943, 0x00000000}},  //   _glaf, ndů_, hinm,
  { {0x4433001a, 0x7ae40b1f, 0x66160193, 0x00000000}},  // [b080] fax_, _ikit, rcyk,
  { {0x6dc50066, 0x6616032e, 0x7cf400f6, 0x00000000}},  //   _iċaħ, scyk, càrd,
  { {0xa0130044, 0x60c3349d, 0x00000000, 0x00000000}},  //   হরাব_, dinm,   ,
  { {0xeb960049, 0x9c7c07ac, 0x2d800089, 0x00000000}},  //   ודער_, moče, _šiem_,
  { {0x9c7c0cce, 0x60c3012d, 0x7ae4349e, 0x00000000}},  //   loče, finm, _mkit,
  { {0x60c3000c, 0x1de1013d, 0x44330026, 0x00000000}},  //   ginm, _पड़त, cax_,
  { {0xb4ea0309, 0x2d990844, 0x41de006e, 0x00000000}},  //   मती_, äsen_, _फुरस,
  { {0x3da60057, 0x7ae406f6, 0x645e0943, 0x00000000}},  //   дроб, _nkit, lfpi,
  { {0x9c7c00b9, 0x00000000, 0x00000000, 0x00000000}},  //   hoče,   ,   ,
  { {0x7ae40020, 0x9c7c089f, 0x7cef0056, 0x00000000}},  //   _akit, koče, tøra,
  { {0x9c7c00ca, 0x69da2987, 0x00000000, 0x00000000}},  //   joče, ştel,   ,
  { {0x9c7c00b9, 0x7af6349f, 0xf8bf00f4, 0x00000000}},  //   doče, _chyt, ipée_,
  { {0x7e6200c4, 0xb9e40088, 0x25de0316, 0x00000000}},  //   _ibop, віри, _कुली_,
  { {0x7ae4022b, 0x1bd41a02, 0xdb02009d, 0x00000000}},  //   _ekit, _поля, hylè,
  { {0x248d0011, 0x9c7c10b9, 0x61e4002b, 0x00000000}},  //   _đem_, goče, żilh,
  { {0xbebc001e, 0x8f9b009b, 0x6aad00e7, 0x00000000}},  //   _avīz, חילי, _ulaf,
  { {0x4433002b, 0x7afd01a2, 0x60c30276, 0x00000000}},  // [b090] tax_, mmst, yinm,
  { {0xb4d9001c, 0xa7750bbd, 0x7afd0039, 0x00000000}},  //   ावे_, _злоч, lmst,
  { {0x44330039, 0xca480014, 0x7afd00d9, 0x00000000}},  //   rax_, _علیه_, omst,
  { {0xd6270054, 0xd9f30061, 0x6595007c, 0x00000000}},  //   _تعدي, _घरात_, _заму,
  { {0x44330288, 0xf07500a1, 0xde8f0082, 0x00000000}},  //   pax_, ٹیاں_, _bịnh_,
  { {0xe1f00025, 0xe4c7007e, 0x00000000, 0x00000000}},  //   جسم_, _цёмн,   ,
  { {0xd0061592, 0xa5bb00fa, 0x00000000, 0x00000000}},  //   неше_, _geór,   ,
  { {0xee3905a5, 0xfe710076, 0x628922cd, 0x00000000}},  //   чни_, ادث_, _uneo,
  { {0xc05b0106, 0x4431011f, 0x7af603a1, 0x00000000}},  //   _між_, _kez_, _rhyt,
  { {0x7ae40039, 0xd0110054, 0x7afd0328, 0x00000000}},  //   _skit, _إلا_, emst,
  { {0x7af6062a, 0x443134a0, 0x6aa5002b, 0x00000000}},  //   _phyt, _mez_, _ċifr,
  { {0xeab20647, 0x44310032, 0xfb240014, 0x00000000}},  //   اعد_, _lez_, کریپ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afd0112, 0x6d5b0065, 0x7af60319, 0x00000000}},  //   amst, mtua, _whyt,
  { {0x46f60069, 0x6d5b045f, 0x05d801f5, 0x00000000}},  //   ечат, ltua, _भुजब,
  { {0xcf92007b, 0x7ae4117b, 0x9c7c0059, 0x00000000}},  //   נטן_, _ukit, roče,
  { {0x6d5b0659, 0x61e90047, 0xceb200b3, 0x00000000}},  // [b0a0] ntua, _nyel, אין_,
  { {0x9c7c016e, 0x44310027, 0xb9db009b, 0x00000000}},  //   poče, _cez_, _מחפש,
  { {0x7b09038c, 0x443134a1, 0x6d5b006c, 0x00000000}},  //   _üstü, _dez_, htua,
  { {0xa50a01f9, 0x6d5b34a2, 0xe8d9001d, 0x00000000}},  //   _нема_, ktua, _trợ_,
  { {0x44310181, 0x6d5b0065, 0xf8a40061, 0x00000000}},  //   _fez_, jtua, _ऐकाय,
  { {0xa5bb19a6, 0xd00f006d, 0xf8bf009d, 0x00000000}},  //   _teór, مله_, ppée_,
  { {0x232a2963, 0xde8f0011, 0x29120058, 0x00000000}},  //   _хоби_, _vịnh_, _luya_,
  { {0x6d5b0065, 0x38b40039, 0x44310ede, 0x00000000}},  //   ftua, _färg_, _zez_,
  { {0xde8f0011, 0xf65f0030, 0x00000000, 0x00000000}},  //   _tịnh_, _kjær_,   ,
  { {0xe0850025, 0x387a0027, 0x00000000, 0x00000000}},  //   _لجمي, _napr_,   ,
  { {0xd00f01b7, 0x79840ef9, 0xe7e0006e, 0x00000000}},  //   _الم_, _ariw, _खुला_,
  { {0x9e7303ec, 0x29120093, 0xd337009b, 0x00000000}},  //   _مهمت, _buya_, ערכה_,
  { {0xf2d3007b, 0x29120211, 0x6d5b34a3, 0x00000000}},  //   רער_, _cuya_, ctua,
  { {0x2d800066, 0x00000000, 0x00000000, 0x00000000}},  //   _ġieh_,   ,   ,
  { {0x64430b76, 0x44310923, 0xe7db007d, 0x00000000}},  //   ónim, _rez_, _मुखप,
  { {0x44310197, 0x63a50f6c, 0x00000000, 0x00000000}},  //   _sez_, vyhn,   ,
  { {0x25fc001c, 0x54550893, 0x99840025, 0x00000000}},  // [b0b0] लेली_, кват, _مليو,
  { {0x6fb00204, 0x26c21291, 0x00000000, 0x00000000}},  //   जनां, _emko_,   ,
  { {0x44310977, 0x9259007c, 0x6d5b002d, 0x00000000}},  //   _vez_, дает_, ztua,
  { {0x4431010f, 0x7d0a0203, 0x29121544, 0x00000000}},  //   _wez_, _lifs, _yuya_,
  { {0x443134a4, 0x6d5b0325, 0xf65f0635, 0x00000000}},  //   _tez_, xtua, _fjær_,
  { {0xfaff0065, 0xe04200e2, 0x290434a5, 0x00000000}},  //   hmë_, анши, ímax_,
  { {0xe0d00025, 0xe2d90014, 0x00000000, 0x00000000}},  //   حزن_, _قارچ_,   ,
  { {0xfaff008d, 0x6d5b0198, 0xa3e60061, 0x00000000}},  //   jmë_, ttua, _पडत_,
  { {0xc212019b, 0x6b9c21db, 0x6d5b0315, 0x00000000}},  //   _כהן_, ärgn, utua,
  { {0x5ba90b5f, 0xcfab00a1, 0x2d590026, 0x00000000}},  //   дком_, _ٹائم_, rèe_,
  { {0x6d5b1180, 0x7984023a, 0x291234a6, 0x00000000}},  //   stua, _sriw, _suya_,
  { {0x6d5b0065, 0x29120035, 0x387a0145, 0x00000000}},  //   ptua, _puya_, _sapr_,
  { {0x6e2934a7, 0xec6e030d, 0xdce2013e, 0x00000000}},  //   mbeb, _кп_, _zpoč,
  { {0xdca200d7, 0x661d34a8, 0x2eed002b, 0x00000000}},  //   _ваши, _afsk, llef_,
  { {0xc0520097, 0xe73a007c, 0x00000000, 0x00000000}},  //   יזם_, ьев_,   ,
  { {0x79840093, 0x2912008e, 0x6d49060c, 0x00000000}},  //   _triw, _tuya_, orea,
  { {0x9c7c0059, 0x6d490051, 0xf50a0478, 0x00000000}},  // [b0c0] loča, nrea, днал_,
  { {0x6d49002a, 0x2937019b, 0x14230077, 0x00000000}},  //   irea, _שאין_, идум,
  { {0x6d493276, 0x38b40039, 0xaac6013d, 0x00000000}},  //   hrea, _värd_, _लगाक,
  { {0x232734a9, 0xdcfb0107, 0xb6a60581, 0x00000000}},  //   тоци_, dvuč, _римл,
  { {0x75430425, 0xdce20161, 0xaa7b0161, 0x00000000}},  //   _княз, _spoč, plýv,
  { {0x2ee601d6, 0x00000000, 0x00000000, 0x00000000}},  //   _skof_,   ,   ,
  { {0x6f0b0019, 0xfaff0065, 0x240700e2, 0x00000000}},  //   _bigc, ymë_, _анри_,
  { {0x6d490051, 0x63a30bf4, 0x9c7c0166, 0x00000000}},  //   frea, änne, doča,
  { {0x6d490035, 0x20560256, 0x6ee50142, 0x00000000}},  //   grea, _атер, tóbr,
  { {0x8ffa04e8, 0x21260127, 0xcb980088, 0x00000000}},  //   _قرار_, mpoh_, евої_,
  { {0xda3500a5, 0x6d490190, 0x9c7c0059, 0x00000000}},  //   лены, area, goča,
  { {0x6d490add, 0x2eed01aa, 0x4ea300ec, 0x00000000}},  //   brea, clef_, _врша,
  { {0x6d490038, 0xfaff0065, 0x3ed90049, 0x00000000}},  //   crea, rmë_, _אַסא,
  { {0x929d0036, 0x9c7c1332, 0x690b002b, 0x00000000}},  //   _piłk, boča, _eżen,
  { {0x57a434aa, 0x00000000, 0x00000000, 0x00000000}},  //   ашта,   ,   ,
  { {0x2f180047, 0x49750072, 0x5a47007e, 0x00000000}},  //   _még_, _блис, _рэка,
  { {0xd6840143, 0xdcfb0466, 0x00000000, 0x00000000}},  // [b0d0] јусп, zvuč,   ,
  { {0xd3a70534, 0x00000000, 0x00000000, 0x00000000}},  //   креп,   ,   ,
  { {0x53e4008b, 0x00000000, 0x00000000, 0x00000000}},  //   ацца,   ,   ,
  { {0xe2980088, 0xfb150049, 0x3a3900fa, 0x00000000}},  //   кає_, אַסט_, nasp_,
  { {0x38b4001f, 0x7abc009b, 0x9c7c0295, 0x00000000}},  //   _wäre_, וצאו, zoča,
  { {0x6d490035, 0x26c9004a, 0x69da01a2, 0x00000000}},  //   vrea, liao_, ßtei,
  { {0x533401f9, 0x2eed0bdf, 0x2f180010, 0x00000000}},  //   _вест, tlef_, _cég_,
  { {0x6d490585, 0x26c900c4, 0x9c7c00ca, 0x00000000}},  //   trea, niao_, voča,
  { {0x6468009f, 0x6d4900e5, 0x6e2934ab, 0x00000000}},  //   _þrið, urea, rbeb,
  { {0x9c7c00ca, 0x752200c4, 0x6d490238, 0x00000000}},  //   toča, ãozi, rrea,
  { {0xfaa6041f, 0x2d860197, 0x6f0b00d9, 0x00000000}},  //   гано, _eroe_, _tigc,
  { {0x9c7c08fb, 0x38af34ac, 0x6d5c001a, 0x00000000}},  //   roča, _büro_, ărar,
  { {0x38c8007a, 0x9c7c34ad, 0xc9560783, 0x00000000}},  //   ناسی_, soča, ытны,
  { {0x3ead0cb2, 0x9c7c0027, 0x290c0bfe, 0x00000000}},  //   lket_, ločn, öda_,
  { {0xaa7b009f, 0x81a90044, 0x9cda00b3, 0x00000000}},  //   glýs, খছি_, _אקספ,
  { {0x26c90559, 0x9c7c0161, 0xa3d7006e, 0x00000000}},  //   giao_, nočn, ापन_,
  { {0x5983007e, 0x7ae634ae, 0xdb020344, 0x00000000}},  // [b0e0] _глыб, mokt, szló,
  { {0xf4c40044, 0x236a0022, 0x00000000, 0x00000000}},  //   ্ত্ব, _ppbj_,   ,
  { {0x394002cc, 0x3ead02cc, 0x00000000, 0x00000000}},  //   _hvis_, kket_,   ,
  { {0x26c90026, 0x5b560049, 0x2f180010, 0x00000000}},  //   ciao_, טשען_, _rég_,
  { {0xc1e707ca, 0x9c7c0b4a, 0xc69300a3, 0x00000000}},  //   льше_, dočn, _האר_,
  { {0x3ead0007, 0xe9f90082, 0x00000000, 0x00000000}},  //   eket_, _hoả_,   ,
  { {0x443a02ae, 0x00000000, 0x00000000, 0x00000000}},  //   map_,   ,   ,
  { {0x443a34af, 0x3ead0093, 0x2d860007, 0x00000000}},  //   lap_, gket_, _proe_,
  { {0x7ae6023a, 0xe0560014, 0x2f1801c3, 0x00000000}},  //   dokt, _مخاب, _wég_,
  { {0x443a006a, 0x5b260eec, 0x3a20004a, 0x00000000}},  //   nap_, льма, _afip_,
  { {0x3940028c, 0xdfcf0025, 0xdd920063, 0x00000000}},  //   _avis_, _فيك_, _گوش_,
  { {0x3ead0aa4, 0x443a033b, 0x00000000, 0x00000000}},  //   cket_, hap_,   ,
  { {0x2d8600ea, 0xdd9201b2, 0x00000000, 0x00000000}},  //   _uroe_, _دوش_,   ,
  { {0x6b9c0018, 0xed5700b6, 0x3a3900d4, 0x00000000}},  //   ørgs, _עבור_, sasp_,
  { {0x443a020c, 0x7c3a016e, 0x8c1b00b3, 0x00000000}},  //   dap_, matr, _אווי,
  { {0x7c3a0092, 0xaa7b000c, 0x00000000, 0x00000000}},  //   latr, rlýs,   ,
  { {0x344b00e3, 0x443a00fa, 0xf4870545, 0x00000000}},  // [b0f0] ечен_, fap_, лужн,
  { {0xaa7b009f, 0x443a2544, 0x25a934b0, 0x00000000}},  //   plýs, gap_, ryal_,
  { {0x25a934b1, 0xd371057d, 0xe787007e, 0x00000000}},  //   syal_, تها_, _супо,
  { {0xf53f0073, 0x7c3a0b96, 0x26c90066, 0x00000000}},  //   _två_, hatr, qiao_,
  { {0x763a0049, 0x7c3a2f0c, 0x210f006e, 0x00000000}},  //   _בערג, katr, ादेश_,
  { {0xa069003b, 0x8fa5005e, 0x38b40274, 0x00000000}},  //   така_, иале, _kära_,
  { {0x9c7c0027, 0xc4d200b6, 0x3ead00b0, 0x00000000}},  //   točn, _וגם_, tket_,
  { {0x29030023, 0x00000000, 0x00000000, 0x00000000}},  //   hmja_,   ,   ,
  { {0x9c7c0b41, 0x38b40039, 0x6d46173d, 0x00000000}},  //   ročn, _lära_, škan,
  { {0x3ead01e3, 0x64572240, 0xa2a1006e, 0x00000000}},  //   sket_, ngxi, कॉर्,
  { {0x38b40039, 0xc1040070, 0x24810051, 0x00000000}},  //   _nära_, _اولي, idhm_,
  { {0x1fa400aa, 0x4a430088, 0x8a060a85, 0x00000000}},  //   _уруг, онюв, изне,
  { {0xfeb800a6, 0x7c3a088c, 0x443a04be, 0x00000000}},  //   _حالت_, batr, yap_,
  { {0x6e3b34b2, 0x38b400f8, 0x00000000, 0x00000000}},  //   laub, _bära_,   ,
  { {0xac74007a, 0x443a011f, 0xe7370893, 0x00000000}},  //   _دانش, vap_, иер_,
  { {0x443a01a3, 0x7a0c0089, 0x6e3b082c, 0x00000000}},  //   wap_, _pētī, naub,
  { {0xe8fa34b3, 0x443a04d4, 0xe61701ee, 0x00000000}},  // [b100] _или_, tap_, рду_,
  { {0xe3b20379, 0x0446004c, 0x7cef05ba, 0x00000000}},  //   يرا_, режн, føri,
  { {0x443a00e0, 0x6e3b34b4, 0xe9f90082, 0x00000000}},  //   rap_, kaub, _toả_,
  { {0x443a163c, 0x63a30039, 0xe9f90011, 0x00000000}},  //   sap_, änna, _hoạ_,
  { {0x7c3a014a, 0x443a0145, 0x00000000, 0x00000000}},  //   yatr, pap_,   ,
  { {0x6ab6018e, 0xe8d90011, 0x4f6a1649, 0x00000000}},  //   _llyf, _trụ_, вшим_,
  { {0x4438027b, 0x7c3a0197, 0xdfcf0379, 0x00000000}},  //   _ier_, vatr, ويه_,
  { {0x443834b5, 0x7c3a0058, 0x6e3b007f, 0x00000000}},  //   _her_, watr, gaub,
  { {0x443801d9, 0xdd9001f7, 0x7c3a0253, 0x00000000}},  //   _ker_, سود_, tatr,
  { {0x44380119, 0x628026f9, 0x62820250, 0x00000000}},  //   _jer_, _hamo, ldoo,
  { {0x443834b6, 0x00000000, 0x00000000, 0x00000000}},  //   _mer_,   ,   ,
  { {0x44380f2c, 0x628200b5, 0x6aa400f4, 0x00000000}},  //   _ler_, ndoo, _coif,
  { {0xdd8f0054, 0x62800006, 0x7c3a05fd, 0x00000000}},  //   _يوم_, _mamo, patr,
  { {0x44380073, 0x62800b9a, 0x8cf3007e, 0x00000000}},  //   _ner_, _lamo, _дзіц,
  { {0x6ab60190, 0x6d40000c, 0x6282006c, 0x00000000}},  //   _flyf, lsma, kdoo,
  { {0x443827a9, 0x62800181, 0x0bb7009b, 0x00000000}},  //   _aer_, _namo, _כלום_,
  { {0x6d400263, 0x4438000c, 0x7aed170b, 0x00000000}},  // [b110] nsma, _ber_, _ikat,
  { {0x7c3805fa, 0x44382662, 0x6d4000b0, 0x00000000}},  //   _jevr, _cer_, isma,
  { {0x443834b7, 0xdd86026c, 0x7c380250, 0x00000000}},  //   _der_, _کو_, _mevr,
  { {0xe6950d75, 0x6d400006, 0x645c00f4, 0x00000000}},  //   _الحد, ksma, _ecri,
  { {0x44383248, 0x7aed0020, 0x62802b05, 0x00000000}},  //   _fer_, _mkat, _damo,
  { {0x443834b8, 0x6280140b, 0x3e710082, 0x00000000}},  //   _ger_, _eamo, _ạt_,
  { {0x6d400089, 0x9c7c07a0, 0xc0580088, 0x00000000}},  //   esma, ročl, річ_,
  { {0x44210b70, 0x4438022b, 0x6280011c, 0x00000000}},  //   lch_, _zer_, _gamo,
  { {0x443834b9, 0x7c3800c7, 0x9c7c01d9, 0x00000000}},  //   _yer_, _bevr, močj,
  { {0x7aed0bb2, 0x442119ba, 0x628008c5, 0x00000000}},  //   _akat, nch_, _zamo,
  { {0x7c380670, 0x442128f5, 0x628000e0, 0x00000000}},  //   _devr, ich_, _yamo,
  { {0xf8a90104, 0x6d400190, 0x7cfd009d, 0x00000000}},  //   _אש_, bsma, dère,
  { {0x7c3834ba, 0x82760049, 0x6b8a0112, 0x00000000}},  //   _fevr, זערע_, _erfg,
  { {0x7c3801b5, 0x7aed0173, 0x7cfd009d, 0x00000000}},  //   _gevr, _ekat, fère,
  { {0x7eb50428, 0x7cfd00f4, 0x4438199e, 0x00000000}},  //   _zápa, gère, _rer_,
  { {0x645c07ec, 0x64470093, 0x442134bb, 0x00000000}},  //   _scri, _adji, ech_,
  { {0x4438059a, 0x62800a0a, 0x2bb7006b, 0x00000000}},  // [b120] _per_, _ramo, dəcə_,
  { {0x99920224, 0xa99b00a0, 0x442301c3, 0x00000000}},  //   _když_, _עביר, _cfj_,
  { {0x44380c2e, 0x6280000b, 0x61fb0b33, 0x00000000}},  //   _ver_, _pamo, _azul,
  { {0x4438001f, 0xd25901fb, 0x44210122, 0x00000000}},  //   _wer_, иці_, ach_,
  { {0x443834bc, 0x62800489, 0x6282017c, 0x00000000}},  //   _ter_, _vamo, rdoo,
  { {0xdb1a0047, 0x6d401ab8, 0x645c0026, 0x00000000}},  //   szté, vsma, _ucri,
  { {0x628034bd, 0xd095007e, 0x65641841, 0x00000000}},  //   _tamo, ўшчы, ltih,
  { {0x6d400002, 0x7c38009d, 0x6d4601ed, 0x00000000}},  //   tsma, _sevr, škam,
  { {0x6d400006, 0x65640504, 0x25fc0061, 0x00000000}},  //   usma, ntih, लेची_,
  { {0x7aed001e, 0x6d400039, 0x9c7c1000, 0x00000000}},  //   _skat, rsma, močk,
  { {0x6d40027b, 0x7f8600a1, 0xc5f5013d, 0x00000000}},  //   ssma, _دلان, _आर्य_,
  { {0x38af047f, 0x6d4034be, 0x7cfd009d, 0x00000000}},  //   _türk_, psma, vère,
  { {0x442134bf, 0x78a51dbe, 0x7c3801b5, 0x00000000}},  //   ych_, _pohv, _tevr,
  { {0x7cfd00f4, 0x4c940069, 0xd90f0014, 0x00000000}},  //   tère, _фикс, ژیک_,
  { {0x7aed022e, 0x38af146f, 0x4919013d, 0x00000000}},  //   _tkat, _jüri_, _यूरो_,
  { {0x44210bc4, 0x7aed2367, 0x7cfd009d, 0x00000000}},  //   wch_, _ukat, rère,
  { {0x44210038, 0x69da12fc, 0x3ea601d6, 0x00000000}},  // [b130] tch_, şter, _moot_,
  { {0x3f8c022b, 0x3ea60436, 0x4421010f, 0x00000000}},  //   _ordu_, _loot_, uch_,
  { {0x442123b9, 0xcfad0044, 0x9c7c0087, 0x00000000}},  //   rch_, _কেনন, točj,
  { {0x442104e5, 0xe570026c, 0x3ea60116, 0x00000000}},  //   sch_, بطہ_, _noot_,
  { {0x2bb7006b, 0x6145007e, 0x9c7c00ca, 0x00000000}},  //   rəcə_, цела, ročj,
  { {0x6447016c, 0x493c00a3, 0x24180641, 0x00000000}},  //   _udji, נגוו, _горы_,
  { {0x3ea634c0, 0x29130210, 0xf3f30379, 0x00000000}},  //   _boot_, _mixa_, _رأس_,
  { {0x92b7004b, 0x3f87013e, 0x9c7c0161, 0x00000000}},  //   _احسا, rvnu_, bočk,
  { {0x2d8b00b9, 0x225f0022, 0x3f8c0288, 0x00000000}},  //   íce_, _icuk_, _erdu_,
  { {0x6cc5007e, 0x00000000, 0x00000000, 0x00000000}},  //   ійна,   ,   ,
  { {0x798d01aa, 0xf9890104, 0x3ea60549, 0x00000000}},  //   _araw, _שר_, _foot_,
  { {0xef0e0822, 0x798d1156, 0x24830065, 0x00000000}},  //   _ім_, _braw, _lajm_,
  { {0x8c4500ed, 0x7cef01e3, 0x2913000a, 0x00000000}},  //   _деле, ført, _bixa_,
  { {0x798d1959, 0x6c6700a1, 0xd94300ed, 0x00000000}},  //   _draw, _طلبہ_, ќери,
  { {0x798d0085, 0x00000000, 0x00000000, 0x00000000}},  //   _eraw,   ,   ,
  { {0x2ca701b5, 0x798d0016, 0x291300d4, 0x00000000}},  //   _hond_, _fraw, _eixa_,
  { {0x798d002b, 0x29130039, 0xcfad0044, 0x00000000}},  // [b140] _graw, _fixa_, _কেমন,
  { {0x33f6007c, 0x26cb059c, 0x7cef06ec, 0x00000000}},  //   очес, _emco_, mørs,
  { {0x2ca70263, 0x7eb5004f, 0x3e4c0006, 0x00000000}},  //   _mond_, _nápo, lėtų_,
  { {0x7ebc0047, 0x2ca734c1, 0xfbd2009b, 0x00000000}},  //   _képe, _lond_, ותב_,
  { {0x3ea600ab, 0x2ca701d6, 0x7cef068f, 0x00000000}},  //   _root_, _oond_, nørs,
  { {0x9c7c00ca, 0x113900a5, 0x38780022, 0x00000000}},  //   ročk, сяцы_, nerr_,
  { {0x3ea634c2, 0x7e6906ec, 0x225f04a5, 0x00000000}},  //   _poot_, ffep, _fcuk_,
  { {0xbe8a0e82, 0x7cf40129, 0x3e4c0006, 0x00000000}},  //   рске_, màri, kėtų_,
  { {0x9c7c01d9, 0x4127005e, 0xeeb70088, 0x00000000}},  //   loči, _мото_, ільш_,
  { {0x0caa047d, 0x2ca70c61, 0x38780065, 0x00000000}},  //   ртии_, _cond_, jerr_,
  { {0x7cf40129, 0x3ea60058, 0x38780023, 0x00000000}},  //   nàri, _toot_, derr_,
  { {0x798d34c3, 0x7cef068f, 0x00000000, 0x00000000}},  //   _praw, førs,   ,
  { {0x99920036, 0x31660288, 0x00000000, 0x00000000}},  //   _gdyż_, ntoz_,   ,
  { {0x9c7c0627, 0x7ebc00f4, 0x2ca70010, 0x00000000}},  //   koči, _dépe, _gond_,
  { {0xa81400ed, 0x9c7c0059, 0x9a87003b, 0x00000000}},  //   ддрш, joči, _дупл,
  { {0x798d010b, 0x316634c4, 0x5694007e, 0x00000000}},  //   _traw, ktoz_, маст,
  { {0x7ebc0010, 0x00000000, 0x00000000, 0x00000000}},  // [b150] _gépe,   ,   ,
  { {0x7d1d0a0a, 0x44981255, 0x752d004a, 0x00000000}},  //   íssi, овую_, rpaz,
  { {0x3959010f, 0x9c7c0059, 0xd2510025, 0x00000000}},  //   luss_, goči, فنا_,
  { {0xb77a007b, 0x6f020082, 0x877a00a3, 0x00000000}},  //   _פארש, _nhoc, _פארי,
  { {0xc692007b, 0x2483016c, 0x395930ac, 0x00000000}},  //   _נאך_, _tajm_, nuss_,
  { {0x9c7c0253, 0x63a30056, 0x00000000, 0x00000000}},  //   boči, ønns,   ,
  { {0x2ca734c5, 0x3959010f, 0x44330d3f, 0x00000000}},  //   _rond_, huss_, mbx_,
  { {0x3eb9000c, 0x6f0234c6, 0xfe4500ed, 0x00000000}},  //   óst_, _choc, чнио,
  { {0xee360642, 0x38610016, 0x6f020048, 0x00000000}},  //   чны_, _ochr_, _dhoc,
  { {0x7ebc00f4, 0xdce201d5, 0xdc990216, 0x00000000}},  //   _répe, _proġ, стиш_,
  { {0x2ca700b5, 0x6f020051, 0x00000000, 0x00000000}},  //   _vond_, _fhoc,   ,
  { {0x2ca734c7, 0x395934c8, 0x00000000, 0x00000000}},  //   _wond_, fuss_,   ,
  { {0x6f090d22, 0x2ca70066, 0xf9920025, 0x00000000}},  //   mmec, _tond_, ربح_,
  { {0x3e4c010a, 0x6f092fcd, 0xbdf800a1, 0x00000000}},  //   rėtų_, lmec, _برما_,
  { {0xc7a60265, 0x3b0a005e, 0x00000000, 0x00000000}},  //   чивк, _леко_,   ,
  { {0x3ebf0093, 0x39591263, 0x9c7c0062, 0x00000000}},  //   nhut_, buss_, voči,
  { {0xcb1300b6, 0x00000000, 0x00000000, 0x00000000}},  // [b160] _אלה_,   ,   ,
  { {0x7cf40129, 0x6f09010f, 0xf8e0013d, 0x00000000}},  //   tàri, hmec, _नदिय,
  { {0x3ebf34c9, 0x6f0934ca, 0x68ee0022, 0x00000000}},  //   khut_, kmec, mobd,
  { {0x9c7c0c06, 0x7cf40129, 0x2d8f34cb, 0x00000000}},  //   roči, ràri, _orge_,
  { {0x9c7c00b9, 0x290a0020, 0x6f0901ee, 0x00000000}},  //   soči, omba_, dmec,
  { {0x92cc0055, 0x26d20cd7, 0x9c7c047c, 0x00000000}},  //   রকে_, liyo_, poči,
  { {0xdfd00025, 0xdddb0059, 0x7eb50010, 0x00000000}},  //   ضية_, vduš, _tápl,
  { {0x6d550046, 0x39590022, 0x00000000, 0x00000000}},  //   ązan, yuss_,   ,
  { {0x38af014a, 0x5d98007e, 0x249800d9, 0x00000000}},  //   _kürt_, ікоў_, _knrm_,
  { {0x26d211b3, 0x31bb019b, 0x645e08e3, 0x00000000}},  //   hiyo_, _הזמנ, ngpi,
  { {0x2d8f1315, 0x7cef05b7, 0x6f0234cc, 0x00000000}},  //   _erge_, tørr, _thoc,
  { {0xed5a04af, 0x39590089, 0xbf9b01ce, 0x00000000}},  //   _год_, tuss_, _ליבש,
  { {0x26d202d1, 0x7e620146, 0x00000000, 0x00000000}},  //   diyo_, _icop,   ,
  { {0x395901c5, 0x26de009d, 0xb69b005b, 0x00000000}},  //   russ_, éton_, _chân,
  { {0x6c830379, 0x00000000, 0x00000000, 0x00000000}},  //   _سليم,   ,   ,
  { {0x0ccd0044, 0x26d20022, 0x39590203, 0x00000000}},  //   রকৃত, giyo_, puss_,
  { {0x3a290009, 0x7bdc000c, 0x27ed0036, 0x00000000}},  // [b170] _ifap_, úruf, łen_,
  { {0x7aef096e, 0x00000000, 0x00000000, 0x00000000}},  //   loct,   ,   ,
  { {0x23790151, 0x00000000, 0x00000000, 0x00000000}},  //   تماد_,   ,   ,
  { {0x26c00207, 0x39493191, 0x7aef00e5, 0x00000000}},  //   chio_, _kvas_, noct,
  { {0x44330009, 0x00000000, 0x00000000, 0x00000000}},  //   pbx_,   ,   ,
  { {0xf4840265, 0x7e6234cd, 0x44250792, 0x00000000}},  //   _пусн, _acop, _ül_,
  { {0xd3470014, 0x38b4010e, 0x3ebf0022, 0x00000000}},  //   _ریشه_, _särk_, thut_,
  { {0x3949004a, 0x00000000, 0x00000000, 0x00000000}},  //   _ovas_,   ,   ,
  { {0x6f090035, 0x7e620009, 0xdceb0089, 0x00000000}},  //   rmec, _dcop, _apgā,
  { {0x7e620142, 0x38b40dac, 0x26d20288, 0x00000000}},  //   _ecop, _värk_, ziyo_,
  { {0x39492813, 0x3ebf0022, 0x9c7c016c, 0x00000000}},  //   _avas_, phut_, joču,
  { {0xe3bf0044, 0x5f740d0b, 0x394900d9, 0x00000000}},  //   _আশাব, _سامر, _bvas_,
  { {0x2d8f0781, 0x7e7b0258, 0x00000000, 0x00000000}},  //   _urge_, meup,   ,
  { {0x3156007b, 0x290a1baa, 0x6d5b0022, 0x00000000}},  //   וישן_, umba_, muua,
  { {0x26c0018e, 0x7ebc009d, 0x00000000, 0x00000000}},  //   thio_, _hépa,   ,
  { {0x7e7b0203, 0x7aef0068, 0x00000000, 0x00000000}},  //   neup, coct,   ,
  { {0x34aa003b, 0x00000000, 0x00000000, 0x00000000}},  // [b180] овао_,   ,   ,
  { {0x26c00020, 0x26d234ce, 0x798400e7, 0x00000000}},  //   shio_, siyo_, _isiw,
  { {0x7e7b0203, 0x212d00fa, 0x00000000, 0x00000000}},  //   keup, _ateh_,   ,
  { {0xe1fa0175, 0x38af010f, 0xdb1a0010, 0x00000000}},  //   оге_, _fürs_, nztá,
  { {0x7644006b, 0xd043006b, 0x7ebc009d, 0x00000000}},  //   maiy, linə, _népa,
  { {0x7e6234cf, 0x798400e7, 0x00000000, 0x00000000}},  //   _scop, _msiw,   ,
  { {0x442a0982, 0x752405ff, 0x00000000, 0x00000000}},  //   _ifb_, lqiz,   ,
  { {0xf8bb02fb, 0x2f17007c, 0x442a0146, 0x00000000}},  //   _उत्प, мощь_, _hfb_,
  { {0x4444022b, 0x690b0066, 0x7ebc009d, 0x00000000}},  //   oa_, _mżer, _cépa,
  { {0x7ebc028c, 0x1fb60088, 0x00000000, 0x00000000}},  //   _dépa, _осер,   ,
  { {0x403301fb, 0x7aef0026, 0x76441ecd, 0x00000000}},  //   _реєс, toct, kaiy,
  { {0x44440224, 0x63a30039, 0x6e930025, 0x00000000}},  //   ha_, änni, _للما,
  { {0x44440be3, 0x644e2145, 0x7aef34d0, 0x00000000}},  //   ka_, _odbi, roct,
  { {0xfbcf089d, 0x79840146, 0x690b0066, 0x00000000}},  //   اتی_, _dsiw, _ażer,
  { {0xd7f80057, 0x2f010611, 0x7c2a0066, 0x00000000}},  //   дут_, lóga_, _iffr,
  { {0x4444000d, 0x442a020f, 0x561d0044, 0x00000000}},  //   ea_, _afb_, তর্ক_,
  { {0x4444000b, 0x09d90055, 0x39490b33, 0x00000000}},  // [b190] fa_, _সরকা, _uvas_,
  { {0x5996009b, 0x690b002b, 0x00000000, 0x00000000}},  //   _נכתב_, _eżer,   ,
  { {0x32550216, 0x442a01a2, 0xf3670259, 0x00000000}},  //   евер, _dfb_, ьтан,
  { {0x4444021e, 0x7d1803bd, 0x442a0190, 0x00000000}},  //   aa_, _livs, _efb_,
  { {0x7c2a34d1, 0x442a0009, 0x224d0023, 0x00000000}},  //   _offr, _ffb_, _vdek_,
  { {0x7ebc00f4, 0xd1b8002c, 0xc1040025, 0x00000000}},  //   _répa, باما_, نوني,
  { {0x7ebc00f4, 0x64452541, 0x00000000, 0x00000000}},  //   _sépa, mahi,   ,
  { {0x7c2a34d2, 0x644500ef, 0x0d850256, 0x00000000}},  //   _affr, lahi, елин,
  { {0x7d18037e, 0x615500a1, 0x629b00e0, 0x00000000}},  //   _bivs, _سنائ, _inuo,
  { {0x644534d3, 0xf0bb0123, 0xb16e00b9, 0x00000000}},  //   nahi, _بارش_, ížeč,
  { {0xeb990200, 0x7eb50285, 0x7d1801c5, 0x00000000}},  //   чин_, _lápi, _divs,
  { {0x44441110, 0x798f001c, 0x6445000b, 0x00000000}},  //   za_, fvcw, hahi,
  { {0xed4e01fb, 0xd01000a1, 0x6445011c, 0x00000000}},  //   _що_, _ملے_, kahi,
  { {0x44440118, 0xdb1a0047, 0xfc310123, 0x00000000}},  //   xa_, sztá, _صحت_,
  { {0x6d4934d4, 0x6445011c, 0x69c60010, 0x00000000}},  //   lsea, dahi, szke,
  { {0x6443000c, 0x6e2901a3, 0xf6550f62, 0x00000000}},  //   ðnin, nceb, ктую,
  { {0x6d4934d5, 0x661d0009, 0x79840020, 0x00000000}},  // [b1a0] nsea, _dgsk, _usiw,
  { {0x4444001a, 0x6d490051, 0x64450058, 0x00000000}},  //   ua_, isea, gahi,
  { {0x7c24038c, 0x929d0046, 0x442a01a2, 0x00000000}},  //   _şirk, _chło, _vfb_,
  { {0xd2520014, 0xaa7b04bb, 0xf7d70049, 0x00000000}},  //   انش_, mnýc, _טויש_,
  { {0x64450b1f, 0xaa7b0161, 0x291a34d6, 0x00000000}},  //   bahi, lnýc, _kipa_,
  { {0x444431a0, 0x6d490061, 0x00000000, 0x00000000}},  //   qa_, dsea,   ,
  { {0x7eb501ca, 0x6d4b34d7, 0x291a0093, 0x00000000}},  //   _zápi, _avga, _mipa_,
  { {0x291a016e, 0x3da6030d, 0x00000000, 0x00000000}},  //   _lipa_, ероб,   ,
  { {0x91e3005e, 0x301a0025, 0x6d49267c, 0x00000000}},  //   _боте, _فتاة_, gsea,
  { {0x7ae40969, 0x22460058, 0x2f010048, 0x00000000}},  //   _ajit, laok_, róga_,
  { {0x54570049, 0x31e20044, 0xaa7b0161, 0x00000000}},  //   עסטן_, _বরিশ, jnýc,
  { {0x6d492513, 0xaa7b06b8, 0xad260025, 0x00000000}},  //   bsea, dnýc, _كرتو,
  { {0x6445011c, 0x6d490048, 0xddea0014, 0x00000000}},  //   yahi, csea, _عرصه_,
  { {0x7eb50489, 0x26f90309, 0x6d461322, 0x00000000}},  //   _rápi, ंत्र_, škas,
  { {0x644514ac, 0x291a18fc, 0x9ee500a1, 0x00000000}},  //   vahi, _dipa_, _سہیل_,
  { {0x7ae4048a, 0x64450020, 0x7cf40129, 0x00000000}},  //   _gjit, wahi, càrr,
  { {0x6445036b, 0x383500ed, 0xf8bf009d, 0x00000000}},  // [b1b0] tahi, _инпр, upés_,
  { {0x9865026c, 0xa3bd013d, 0xaa7b06b8, 0x00000000}},  //   _جیسے_, इनल_, bnýc,
  { {0xf09f0011, 0xd6d101fa, 0x764b0010, 0x00000000}},  //   _đà_, _نقد_, ógys,
  { {0x64450ae5, 0x6d4902c2, 0x291a016c, 0x00000000}},  //   sahi, ysea, _zipa_,
  { {0x6445011c, 0xc2c40025, 0xb2240088, 0x00000000}},  //   pahi, ديني, уміл,
  { {0x6d490061, 0x7afd12f9, 0x656d00e7, 0x00000000}},  //   vsea, hlst, mtah,
  { {0x6d490d12, 0x656d34d8, 0x23e4007e, 0x00000000}},  //   wsea, ltah, _бітв,
  { {0x7ebc00f4, 0x6d4934d9, 0x7afd00d9, 0x00000000}},  //   _dépo, tsea, jlst,
  { {0x656d1577, 0x6e29153d, 0xaa7b01ca, 0x00000000}},  //   ntah, rceb, znýc,
  { {0x6d490051, 0x7af60239, 0x61fb006b, 0x00000000}},  //   rsea, _skyt, _iyul,
  { {0x6d4911be, 0x291a06f9, 0xb5fb0051, 0x00000000}},  //   ssea, _ripa_, _scál,
  { {0xe61f0011, 0x6d490035, 0xaa7b06b8, 0x00000000}},  //   _ngô_, psea, vnýc,
  { {0x6d460119, 0x291a023a, 0x656d0022, 0x00000000}},  //   škar, _pipa_, jtah,
  { {0x7afd0141, 0xaa7b06b8, 0xdca502ea, 0x00000000}},  //   alst, tnýc, _јаки,
  { {0xf74300ed, 0x656d0007, 0x98a30793, 0x00000000}},  //   иеро, etah, шире,
  { {0xcf920476, 0x321f0011, 0xaa7b04bb, 0x00000000}},  //   סטן_, _nguy_, rnýc,
  { {0xceb201f8, 0x291a0091, 0x7c240279, 0x00000000}},  // [b1c0] בין_, _tipa_, _şiri,
  { {0xfaf90089, 0x66db00b0, 0x3eaf00d9, 0x00000000}},  //   stīt_, täkä, _logt_,
  { {0x61e90039, 0x3eaf00d9, 0x00000000, 0x00000000}},  //   _axel, _oogt_,   ,
  { {0x7ebc028c, 0x60c10073, 0x39400173, 0x00000000}},  //   _répo, _allm, _kwis_,
  { {0x7ebc00f4, 0x656d0085, 0x00000000, 0x00000000}},  //   _dépl, ctah,   ,
  { {0x6909000c, 0x00000000, 0x00000000, 0x00000000}},  //   rþeg,   ,   ,
  { {0x61e9008e, 0x546702b0, 0x03a30a85, 0x00000000}},  //   _exel, _шарм_, _киро,
  { {0x2d8634da, 0xc7b30104, 0x91bf0316, 0x00000000}},  //   _psoe_, שבה_, वनशै,
  { {0x61fb0010, 0x7c2d014a, 0x00000000, 0x00000000}},  //   _gyul, _şara,   ,
  { {0x3a2004d4, 0x00000000, 0x00000000, 0x00000000}},  //   _agip_,   ,   ,
  { {0x34b700b6, 0x443a0009, 0xead90088, 0x00000000}},  //   דפים_, ibp_, емні_,
  { {0x4fd9007b, 0xed59013e, 0x3959004a, 0x00000000}},  //   _אַנד, brž_, trss_,
  { {0x394d028c, 0xdd9200a6, 0x7afd0039, 0x00000000}},  //   ées_, _خوش_, rlst,
  { {0x79961784, 0x26c20052, 0x3a200087, 0x00000000}},  //   _dryw, _alko_, _egip_,
  { {0x7ac70088, 0x972501d8, 0x6abd0023, 0x00000000}},  //   _аспе, افرو, ërfs,
  { {0x656d000c, 0x00000000, 0x00000000, 0x00000000}},  //   ttah,   ,   ,
  { {0x7ebc1055, 0x60d80056, 0xcb14009b, 0x00000000}},  // [b1d0] _répl, kivm, _דלק_,
  { {0xfaff008d, 0x656d0fef, 0xf9920104, 0x00000000}},  //   llë_, rtah, _פרי_,
  { {0x656d1499, 0xa2b4007d, 0x38b40039, 0x00000000}},  //   stah, _आवश्, _värt_,
  { {0x656d01e5, 0x2ee60023, 0x00000000, 0x00000000}},  //   ptah, _njof_,   ,
  { {0x865a009b, 0xa2b401f5, 0x00000000, 0x00000000}},  //   _אדרי, _आवर्,   ,
  { {0xdce9002b, 0xe05700a2, 0xd00934db, 0x00000000}},  //   rteċ, ئیات_, неле_,
  { {0x3d06013d, 0xa4d40088, 0x00000000, 0x00000000}},  //   _सीधे_, _торі,   ,
  { {0x7cfd0129, 0x61e905aa, 0x00000000, 0x00000000}},  //   mèri, _txel,   ,
  { {0x40351662, 0x213f0022, 0x3eaf01a2, 0x00000000}},  //   _безс, _uwuh_, _vogt_,
  { {0x60c10051, 0x2a69016c, 0xaba906e1, 0x00000000}},  //   _ullm, _acab_, евоз_,
  { {0x7c95007a, 0x3f670269, 0x7a6a09da, 0x00000000}},  //   نشگا, _штаб, нинг_,
  { {0x79960046, 0x66e50006, 0x00000000, 0x00000000}},  //   _pryw, dėko,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x79960007, 0x2eff0146, 0x7c24006b, 0x00000000}},  //   _vryw, lluf_, _şirv,
  { {0x2cb82c04, 0x79960abb, 0x00000000, 0x00000000}},  //   örde_, _wryw,   ,
  { {0x29250051, 0x6abd0210, 0x79960016, 0x00000000}},  //   úpaí_, cksf, _tryw,
  { {0xe5a31bc2, 0xceb20104, 0x68f50059, 0x00000000}},  // [b1e0] бити, זין_, bozd,
  { {0x888601be, 0xf7f61739, 0x03a60679, 0x00000000}},  //   _слож, _مسجد, лизо,
  { {0xfaf9001e, 0x9cd6009b, 0x7cfd00d4, 0x00000000}},  //   brīd_, נועה_, gèri,
  { {0x6d5b008d, 0x2bf60049, 0x316a31c9, 0x00000000}},  //   krua, אמען_, ешко_,
  { {0xc5b6008b, 0x35fa026c, 0x60d801aa, 0x00000000}},  //   _сёнь, _سرحد_, tivm,
  { {0x7ebc0010, 0x6d5b0023, 0x7cfd00f6, 0x00000000}},  //   _gépj, drua, bèri,
  { {0x7646000a, 0x00000000, 0x00000000, 0x00000000}},  //   _keky,   ,   ,
  { {0x72791123, 0x6e3b011c, 0x7d54005e, 0x00000000}},  //   _исус_, gbub, авих,
  { {0x6d5b34dc, 0x00000000, 0x00000000, 0x00000000}},  //   grua,   ,   ,
  { {0xddcb001a, 0x2a690ace, 0xbb74025f, 0x00000000}},  //   ţişt, _scab_, агој,
  { {0x7eb50b33, 0x4f5a035b, 0x68f5004a, 0x00000000}},  //   _cáps, _سجاد_, vozd,
  { {0x68f50036, 0x6efe0023, 0x00000000, 0x00000000}},  //   wozd, këbi,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe78701ab, 0x00000000, 0x00000000, 0x00000000}},  //   лубо,   ,   ,
  { {0x76460030, 0x00000000, 0x00000000, 0x00000000}},  //   _beky,   ,   ,
  { {0x96351deb, 0x79a7026b, 0x6d420173, 0x00000000}},  //   рнац, _брое, _kwoa,
  { {0x6282068f, 0xf8ae0167, 0x00000000, 0x00000000}},  // [b1f0] deoo, سکی_,   ,
  { {0x7cfd04bd, 0xddc210f7, 0xdce900b9, 0x00000000}},  //   tèri, _obož, yteč,
  { {0xc7ab0025, 0xd2510025, 0x00000000, 0x00000000}},  //   _أدخل_, قنا_,   ,
  { {0x76460007, 0x6e220fb9, 0x0ce10164, 0x00000000}},  //   _geky, _ngob, _पद्म,
  { {0xd04a005f, 0xdd860137, 0xc24405b8, 0x00000000}},  //   lifə, _بو_, снік,
  { {0x2f5501fb, 0x6e22008e, 0x26c900fa, 0x00000000}},  //   атис, _agob, lhao_,
  { {0x256f079a, 0x30c900a1, 0xd498005e, 0x00000000}},  //   lül_, _یورپ_, _сря_,
  { {0x26c900c4, 0x00000000, 0x00000000, 0x00000000}},  //   nhao_,   ,   ,
  { {0xd04a005f, 0x256f34dd, 0xdce901ca, 0x00000000}},  //   hifə, nül_, steč,
  { {0x64470224, 0x6d5b1180, 0xeb99012b, 0x00000000}},  //   _jeji, rrua, вио_,
  { {0x6447008e, 0xdb22000c, 0x00000000, 0x00000000}},  //   _meji, ærðf,   ,
  { {0x64470263, 0x6d5b0065, 0x256f34de, 0x00000000}},  //   _leji, prua, kül_,
  { {0xddc213c7, 0x3ead0065, 0xdca501e0, 0x00000000}},  //   _zbož, mjet_, _вали,
  { {0x3ead34df, 0xe8f70194, 0x256f34e0, 0x00000000}},  //   ljet_, иля_, dül_,
  { {0x29040089, 0xf74634e1, 0x00000000, 0x00000000}},  //   ēma_, ребо,   ,
  { {0x3ead0065, 0x068600ed, 0x1fe70044, 0x00000000}},  //   njet_, јган, _ফরাস,
  { {0x4ad8026c, 0x256f0148, 0x64470093, 0x00000000}},  // [b200] _لاکھ_, gül_, _beji,
  { {0x389a0049, 0x3ead2368, 0x00000000, 0x00000000}},  //   _ייִנ, hjet_,   ,
  { {0x3ead0065, 0x436a005e, 0x07a6007e, 0x00000000}},  //   kjet_, таен_, _танн,
  { {0x26c9087a, 0xa3e70061, 0xd4090025, 0x00000000}},  //   chao_, _बखर_, اتكم_,
  { {0x27f7089d, 0xf194004c, 0x3ead34e2, 0x00000000}},  //   _مفید_, силь, djet_,
  { {0x64550046, 0x60f701e1, 0x8997009b, 0x00000000}},  //   _gdzi, анія_, יכנס_,
  { {0x656400b0, 0x00000000, 0x00000000, 0x00000000}},  //   luih,   ,   ,
  { {0x7d010061, 0x3ead0065, 0x3f98009f, 0x00000000}},  //   ells, gjet_, _árum_,
  { {0xd04a005f, 0x81d40044, 0x7b330035, 0x00000000}},  //   zifə, _সুর_, _lăud,
  { {0x26c9012d, 0x27ed0a4b, 0x00000000, 0x00000000}},  //   zhao_, şeni_,   ,
  { {0x256f0010, 0x26c00197, 0xa5bb0082, 0x00000000}},  //   zül_, kkio_, _ngón,
  { {0xdce9002b, 0x00000000, 0x00000000, 0x00000000}},  //   rveġ,   ,   ,
  { {0xe8b4007d, 0x00000000, 0x00000000, 0x00000000}},  //   ुसूच,   ,   ,
  { {0x256f0010, 0xe7f2013d, 0x00000000, 0x00000000}},  //   vül_, _आँखा_,   ,
  { {0xab2701f9, 0x644734e3, 0x26c90082, 0x00000000}},  //   _која_, _reji, thao_,
  { {0x256f34e4, 0x644734e5, 0x644a01e5, 0x00000000}},  //   tül_, _seji, ðfin,
  { {0x442300fa, 0x443100f6, 0x38c80014, 0x00000000}},  // [b210] _pgj_, _pfz_, _چاپی_,
  { {0x35e4008b, 0x256f0047, 0x26c901ee, 0x00000000}},  //   іцтв, rül_, shao_,
  { {0x9f5e0065, 0x644700d0, 0x29030ecc, 0x00000000}},  //   _dytë_, _veji, mlja_,
  { {0xb69b00f4, 0x29031204, 0x64550036, 0x00000000}},  //   _chât, llja_, _wdzi,
  { {0x64470211, 0x3ead016e, 0x816b0c74, 0x00000000}},  //   _teji, vjet_, треб_,
  { {0x64550046, 0x764d00e0, 0x798d0418, 0x00000000}},  //   _udzi, laay, _msaw,
  { {0x3ead0065, 0x987c0049, 0x02a7007e, 0x00000000}},  //   tjet_, דרוק, _крам,
  { {0x764d0058, 0x212b009d, 0x00000000, 0x00000000}},  //   naay, _écho_,   ,
  { {0x3ead0065, 0x3ebf045f, 0x2d990048, 0x00000000}},  //   rjet_, rkut_, íse_,
  { {0x3ead0d00, 0x26c0002d, 0x3ebf0ed1, 0x00000000}},  //   sjet_, zkio_, skut_,
  { {0x798d006a, 0x764d107e, 0x5f9501d8, 0x00000000}},  //   _asaw, kaay, _دلائ,
  { {0xddd9002b, 0x3ead0023, 0x00000000, 0x00000000}},  //   _kawż, qjet_,   ,
  { {0xfe70031d, 0x764d0020, 0x6bd500a1, 0x00000000}},  //   _آدم_, daay, شتگر,
  { {0x6c350167, 0x2903050f, 0x7e69010e, 0x00000000}},  //   _افغا, glja_, lgep,
  { {0x5b35004b, 0xdc360049, 0x798d000a, 0x00000000}},  //   _اعتر, _פאקט_, _esaw,
  { {0x7e6900b5, 0x9f5e0065, 0x752d006b, 0x00000000}},  //   ngep, _sytë_, fqaz,
  { {0x29030f3a, 0x6aa40a34, 0xe5a3003b, 0x00000000}},  // [b220] blja_, _inif, пити,
  { {0x07fa03ec, 0x764d00e0, 0x26c0007f, 0x00000000}},  //   _مرجع_, aaay, skio_,
  { {0xa2e634e6, 0xb69b009d, 0x6aa40133, 0x00000000}},  //   божд, _châs, _knif,
  { {0x10f900a1, 0xa97a0049, 0x00000000, 0x00000000}},  //   یبوں_, ָאַכ,   ,
  { {0xf1d203d7, 0x7ebc0010, 0x00000000, 0x00000000}},  //   _देखन, _képv,   ,
  { {0xf993009b, 0x00000000, 0x00000000, 0x00000000}},  //   פרו_,   ,   ,
  { {0x3cfc00d9, 0x7e6901a2, 0x00000000, 0x00000000}},  //   _rkvv_, fgep,   ,
  { {0xa5bb0046, 0x1dd903d7, 0x7e6905a6, 0x00000000}},  //   _ogól, _बेहत, ggep,
  { {0xc693009b, 0xfbd50044, 0x6143003b, 0x00000000}},  //   לאה_, _সুলত, _нета,
  { {0x6aa40016, 0xb5b7009b, 0x00000000, 0x00000000}},  //   _anif, צליח_,   ,
  { {0x29030295, 0xb4fb0049, 0x6ab60a6b, 0x00000000}},  //   vlja_, רליר, _boyf,
  { {0x635c0035, 0x00000000, 0x00000000, 0x00000000}},  //   mănă,   ,   ,
  { {0x63be0146, 0x80bd0044, 0x00000000, 0x00000000}},  //   hypn, ্চর্,   ,
  { {0x764d0009, 0xac1801ee, 0x66e5007f, 0x00000000}},  //   waay, _колу_, mėki,
  { {0x9cdb0104, 0xb6c7005e, 0x66e50006, 0x00000000}},  //   _תקופ, бсай, lėki,
  { {0x29030e00, 0xbb3b0049, 0x6aa400d9, 0x00000000}},  //   slja_, _געהי, _gnif,
  { {0x58d500e3, 0x29030825, 0x798d0020, 0x00000000}},  // [b230] _моит, plja_, _usaw,
  { {0x764d2778, 0x00000000, 0x00000000, 0x00000000}},  //   saay,   ,   ,
  { {0x7c2d011f, 0x764d00e0, 0x00000000, 0x00000000}},  //   _şark, paay,   ,
  { {0x26d901a2, 0xddd90066, 0x66e5007f, 0x00000000}},  //   _umso_, _pawż, kėki,
  { {0x602500e2, 0x00000000, 0x00000000, 0x00000000}},  //   одла,   ,   ,
  { {0x10a20113, 0x66e50006, 0x90c5041f, 0x00000000}},  //   дишн, dėki, юбле,
  { {0x7e690112, 0xaa7b000c, 0x9ea9007c, 0x00000000}},  //   tgep, rnýj, ивка_,
  { {0x8d550242, 0x00000000, 0x00000000, 0x00000000}},  //   оточ,   ,   ,
  { {0x2d94007e, 0xed590069, 0x00000000, 0x00000000}},  //   прэс, шоп_,   ,
  { {0x7aed021e, 0xcd280379, 0x7e690d18, 0x00000000}},  //   _ajat, حسين_, sgep,
  { {0x6a8608f3, 0x00000000, 0x00000000, 0x00000000}},  //   олна,   ,   ,
  { {0x78a50082, 0x00000000, 0x00000000, 0x00000000}},  //   _anhv,   ,   ,
  { {0x7aed0065, 0x0f18023c, 0x272e000c, 0x00000000}},  //   _djat, _اغلب_, _sýn_,
  { {0x8afd0046, 0x186a01f9, 0x78b70061, 0x00000000}},  //   stęp, јави_, _coxv,
  { {0xd7f20025, 0x00000000, 0x00000000, 0x00000000}},  //   ذكر_,   ,   ,
  { {0x7aed008d, 0xb6a3017f, 0x6aa414dc, 0x00000000}},  //   _gjat, мисл, _unif,
  { {0x0b170025, 0x00000000, 0x00000000, 0x00000000}},  // [b240] _بقية_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68fc05ad, 0xb5fb0051, 0x987b0049, 0x00000000}},  //   mord, _scát, _דריק,
  { {0xe5a600d7, 0x68fc0056, 0xa2060264, 0x00000000}},  //   _дими, lord, опед,
  { {0x9c7c018b, 0x68fc00b5, 0x29180048, 0x00000000}},  //   liče, oord, omra_,
  { {0x68fc277a, 0x25740073, 0xdce9013e, 0x00000000}},  //   nord, mäl_, čněn,
  { {0x9c7c0091, 0x00000000, 0x00000000, 0x00000000}},  //   niče,   ,   ,
  { {0x1ef70025, 0x68fc34e7, 0xb5fb0051, 0x00000000}},  //   يعية_, hord, _gcás,
  { {0x68fc0004, 0x65761241, 0x0caa04f9, 0x00000000}},  //   kord, ntyh, атни_,
  { {0xf063012b, 0x7ebc00f4, 0x68fc05d5, 0x00000000}},  //   _окуп, _répu, jord,
  { {0x9c7c0e00, 0x7aed002b, 0x68fc0190, 0x00000000}},  //   jiče, _pjat, dord,
  { {0xf3ec0055, 0x8afd0036, 0x00000000, 0x00000000}},  //   _করার_, dręc,   ,
  { {0x68fc27eb, 0x25740039, 0xfd380025, 0x00000000}},  //   ford, jäl_, _اكتب_,
  { {0x2bca007d, 0x00000000, 0x00000000, 0x00000000}},  //   ानदा,   ,   ,
  { {0xd6db0113, 0xcb67003b, 0x7aed00f8, 0x00000000}},  //   ата_, _даје_, _tjat,
  { {0xa5350099, 0x3f9e0087, 0x00000000, 0x00000000}},  //   знач, _mrtu_,   ,
  { {0x68fc0056, 0x06cd0044, 0xdb170036, 0x00000000}},  // [b250] bord, রচলি, ńców,
  { {0x7afd34e8, 0x9c7c0059, 0x3f9e0093, 0x00000000}},  //   lost, biče, _ortu_,
  { {0xfbca0061, 0x00000000, 0x00000000, 0x00000000}},  //   ानिम,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3f9e0032, 0x66c3010e, 0x00000000, 0x00000000}},  //   _artu_, _lõkk,   ,
  { {0xe0d801fb, 0x55ba009b, 0x3ea60006, 0x00000000}},  //   ові_, _המשו, _anot_,
  { {0x7afd001f, 0x7ebc0010, 0x12e70088, 0x00000000}},  //   kost, _néps, _діаг,
  { {0x0ea90057, 0xee39005e, 0x7afd0091, 0x00000000}},  //   ский_, щни_, jost,
  { {0x68fc011f, 0x3f9e000c, 0xfce51662, 0x00000000}},  //   yord, _ertu_, зопо,
  { {0x2b47018e, 0x7ebc0f08, 0x3ea634e9, 0x00000000}},  //   _pwnc_, _sépt, _enot_,
  { {0x68fc00c7, 0x7afd0051, 0x224d00bb, 0x00000000}},  //   vord, fost, _keek_,
  { {0x7afd34ea, 0x9c7c0059, 0xef0e0088, 0x00000000}},  //   gost, viče, _їм_,
  { {0x9916007e, 0x6da50545, 0x00000000, 0x00000000}},  //   зьві, _хила,   ,
  { {0xa3bd0164, 0x9c7c0059, 0x2012005f, 0x00000000}},  //   ेना_, tiče, əyib_,
  { {0x07a30264, 0x2d8d00fa, 0x3ea634eb, 0x00000000}},  //   нарн, lwee_, _ynot_,
  { {0xcf9200bd, 0x9c7c016c, 0x7afd0207, 0x00000000}},  //   עטן_, riče, cost,
  { {0x056634ec, 0x68fc01b9, 0x38b4010f, 0x00000000}},  // [b260] яван, pord, _märz_,
  { {0x9c7c34ed, 0x00000000, 0x00000000, 0x00000000}},  //   piče,   ,   ,
  { {0x224d00bb, 0x7ebc009d, 0x00000000, 0x00000000}},  //   _beek_, _mépr,   ,
  { {0xc7b300a3, 0x212d004a, 0x00000000, 0x00000000}},  //   _טבת_, _bueh_,   ,
  { {0xd24f0558, 0x7644019a, 0x7bc100d2, 0x00000000}},  //   انه_, mbiy, hylu,
  { {0x7afd1551, 0x20050c0f, 0x3ea601d6, 0x00000000}},  //   zost, _byli_, _snot_,
  { {0x645c34ee, 0x44380009, 0x6d5d0051, 0x00000000}},  //   _idri, _ifr_, ásan,
  { {0x4444001f, 0x645c0e08, 0x3f9e02db, 0x00000000}},  //   lb_, _hdri, _vrtu_,
  { {0x44440ac9, 0x644e0169, 0x442a2a36, 0x00000000}},  //   ob_, _kebi, _kgb_,
  { {0x44440173, 0xdb1b0010, 0x7afd0036, 0x00000000}},  //   nb_, sztü, wost,
  { {0x7afd004f, 0x6606068f, 0x7ebc00f4, 0x00000000}},  //   tost, _lykk, _dépr,
  { {0x644e0149, 0x13df0044, 0x67260059, 0x00000000}},  //   _lebi, _বুড়, _nikj,
  { {0x7afd0428, 0x645c037e, 0xdca6003b, 0x00000000}},  //   rost, _odri, _нади,
  { {0x644e001e, 0x645c0065, 0x442a01c3, 0x00000000}},  //   _nebi, _ndri, _ngb_,
  { {0x44440059, 0x6c7b009b, 0xe7840902, 0x00000000}},  //   db_, _האופ, нуто,
  { {0x444434ef, 0x645c001a, 0x442a010f, 0x00000000}},  //   eb_, _adri, _agb_,
  { {0xdb1b115b, 0x6726002b, 0x442a01a2, 0x00000000}},  // [b270] sztó, _dikj, _bgb_,
  { {0x4438001a, 0x644e014a, 0x29070051, 0x00000000}},  //   _cfr_, _cebi, _óna_,
  { {0x644e0211, 0x645c005b, 0x443834f0, 0x00000000}},  //   _debi, _ddri, _dfr_,
  { {0x44440004, 0x3cf00061, 0x645c0145, 0x00000000}},  //   ab_, ीकडे_, _edri,
  { {0x444434f1, 0x9c7c0006, 0xc6920049, 0x00000000}},  //   bb_, anči, _סאך_,
  { {0x644e0683, 0x224d05d0, 0x444412fe, 0x00000000}},  //   _gebi, _week_, cb_,
  { {0x7ebc009d, 0x6d4001c3, 0x224d00bb, 0x00000000}},  //   _répr, epma, _teek_,
  { {0x3eb9000c, 0x644e0032, 0x2d8d01d6, 0x00000000}},  //   ðst_, _zebi, twee_,
  { {0x802700a2, 0x628b34f2, 0x3cfe34f3, 0x00000000}},  //   _فرام, mego, fotv_,
  { {0x628b002d, 0x629934f4, 0x7d1a0009, 0x00000000}},  //   lego, ldwo, gmts,
  { {0x64450051, 0x752700bb, 0x752f34f5, 0x00000000}},  //   ibhi, _mijz, _lucz,
  { {0x628b34f6, 0xbe150355, 0x98a0012d, 0x00000000}},  //   nego, _قواع, _kuić_,
  { {0xed4e27c6, 0x6f1b0026, 0x67260066, 0x00000000}},  //   _шо_, mmuc, _rikj,
  { {0x6f09030a, 0x6606068f, 0x628b004a, 0x00000000}},  //   llec, _rykk, hego,
  { {0x442a211e, 0xa3dd006e, 0xd7060088, 0x00000000}},  //   _rgb_, _तेल_, дзви,
  { {0x644e0085, 0x443800f4, 0x65640c55, 0x00000000}},  //   _sebi, _sfr_, trih,
  { {0x764f0036, 0x752700b5, 0x9c7c0ecc, 0x00000000}},  // [b280] _decy, _bijz, liča,
  { {0x6f0934f7, 0x4444010f, 0x6f1b010f, 0x00000000}},  //   hlec, ub_, hmuc,
  { {0x9c7c0091, 0xe29a007e, 0x444403a1, 0x00000000}},  //   niča, жае_, rb_,
  { {0x644e0142, 0x65640142, 0x66061934, 0x00000000}},  //   _webi, prih, _tykk,
  { {0x44380197, 0x6f0900d2, 0x644e033b, 0x00000000}},  //   _tfr_, dlec, _tebi,
  { {0x6f090951, 0x6f020036, 0x629900d9, 0x00000000}},  //   elec, _skoc, adwo,
  { {0x6f0900ab, 0xdfd00025, 0x628b16c5, 0x00000000}},  //   flec, طية_, bego,
  { {0x24980133, 0x6f090133, 0x00000000, 0x00000000}},  //   _harm_, glec,   ,
  { {0x224604cb, 0x6d400173, 0x249825f0, 0x00000000}},  //   mbok_, upma, _karm_,
  { {0xa2da03d7, 0xd24f00a1, 0x22462b6f, 0x00000000}},  //   पोर्, _منہ_, lbok_,
  { {0x6f090211, 0x7d080039, 0x2498004a, 0x00000000}},  //   blec, rlds, _marm_,
  { {0x7c2d014a, 0x03570049, 0x6d401341, 0x00000000}},  //   _şart, ויטש_, ppma,
  { {0xace9025a, 0x00000000, 0x00000000, 0x00000000}},  //   _کرنل_,   ,   ,
  { {0x9c7c0ce4, 0x7b7600a2, 0x316600c4, 0x00000000}},  //   biča, _قطعا, iroz_,
  { {0x764f0016, 0x628b015e, 0x67d50088, 0x00000000}},  //   _pecy, yego, хову,
  { {0x929d0036, 0x290a004a, 0xaa7b01e5, 0x00000000}},  //   _okła, alba_, gnýt,
  { {0x224615b3, 0x99480025, 0x628b04e7, 0x00000000}},  // [b290] dbok_, _قليل_, vego,
  { {0x24980022, 0x6f0934f8, 0x00000000, 0x00000000}},  //   _carm_, zlec,   ,
  { {0x6f0920d5, 0x64450048, 0xdce904eb, 0x00000000}},  //   ylec, rbhi, steć,
  { {0x752702ae, 0xd25b008b, 0x21750088, 0x00000000}},  //   _wijz, іце_, еукр,
  { {0x629900b5, 0x9c7c037e, 0xa158085f, 0x00000000}},  //   rdwo, ziča, дачу_,
  { {0x628b30dc, 0x4f9500ed, 0x6d5d0048, 0x00000000}},  //   sego, ериу, ásam,
  { {0x6f090009, 0x628b00f8, 0xfe710025, 0x00000000}},  //   tlec, pego, هدة_,
  { {0xf53f0c7b, 0x27350039, 0x9c7c0213, 0x00000000}},  //   _tråd_, _mån_, viča,
  { {0x99800036, 0x6f091a98, 0x27350193, 0x00000000}},  //   _dziś_, rlec, _lån_,
  { {0x9c7c12d6, 0xc4d2007b, 0x6f0900b9, 0x00000000}},  //   tiča, ָגט_, slec,
  { {0x656d008e, 0x27350039, 0x6f0900b4, 0x00000000}},  //   huah, _nån_, plec,
  { {0x5fd80061, 0x73da0049, 0x0f360049, 0x00000000}},  //   _भेटल, פֿיצ, _טרעט_,
  { {0x9c7c0746, 0x00000000, 0x00000000, 0x00000000}},  //   mičn,   ,   ,
  { {0x9c7c34f9, 0x00000000, 0x00000000, 0x00000000}},  //   ličn,   ,   ,
  { {0x9cd600b6, 0x8cac013d, 0xe9df000c, 0x00000000}},  //   _רוצה_, जारो, rbúa_,
  { {0x9c7c0027, 0x7bda00b6, 0x66ca0428, 0x00000000}},  //   ničn, _מקצו, _výko,
  { {0x27ff005d, 0x213f0022, 0x656d0058, 0x00000000}},  // [b2a0] ğuna_, _ntuh_, guah,
  { {0x7ae60a5c, 0x33f631c9, 0xca4a0014, 0x00000000}},  //   likt, нчес, _بلکه_,
  { {0x929d0046, 0x24981861, 0x69c60007, 0x00000000}},  //   _skła, _varm_, lyke,
  { {0x24980007, 0x7d0101a2, 0x9c7c133f, 0x00000000}},  //   _warm_, hols, jičn,
  { {0x9c7c01ca, 0x27f2001e, 0x7d0109fc, 0x00000000}},  //   dičn, šanā_, kols,
  { {0x7ae600b5, 0x31660032, 0x224634fa, 0x00000000}},  //   hikt, rroz_, sbok_,
  { {0x9c7c0059, 0x443a00f6, 0x929d0036, 0x00000000}},  //   fičn, mcp_, _wkła,
  { {0xdd9001af, 0xc7b30104, 0x9c7c0295, 0x00000000}},  //   لوب_, רבה_, gičn,
  { {0x929d0036, 0x25a001aa, 0xe0da0478, 0x00000000}},  //   _ukła, nvil_, _ева_,
  { {0x23670f3a, 0x2012006b, 0x2a6034fb, 0x00000000}},  //   šnje_, əyin_, _adib_,
  { {0xdeef1036, 0x394001aa, 0xa803006b, 0x00000000}},  //   _бы_, _atis_, _çıxm,
  { {0x7ec600f4, 0x7aef0009, 0x273500f8, 0x00000000}},  //   _dépê, unct, _rån_,
  { {0x27350afc, 0x7d0119d5, 0x6ce60451, 0x00000000}},  //   _sån_, bols, _піке,
  { {0x2a60005f, 0x7d010026, 0x00000000, 0x00000000}},  //   _edib_, cols,   ,
  { {0xb909001c, 0xf53f044f, 0x39400093, 0x00000000}},  //   _मग_, _stå_, _etis_,
  { {0x56940373, 0xf1c6001d, 0x39590085, 0x00000000}},  //   ласт, _đánh_, psss_,
  { {0x225f0061, 0x6aad0020, 0xdce9001a, 0x00000000}},  // [b2b0] _rduk_, _inaf, _înăl,
  { {0x9c7c00d0, 0x4735007c, 0x76560058, 0x00000000}},  //   zičn, _инос, aayy,
  { {0x2903000b, 0x656d00fa, 0x7c3a0048, 0x00000000}},  //   moja_, suah, ictr,
  { {0xd6db0822, 0x290300b0, 0x68e700bb, 0x00000000}},  //   _хто_, loja_, lijd,
  { {0x9c7c003b, 0x6aad00e7, 0x00000000, 0x00000000}},  //   vičn, _mnaf,   ,
  { {0x29030778, 0x443a1156, 0x9c7c120f, 0x00000000}},  //   noja_, ccp_, dičo,
  { {0x9c7c0bf8, 0x6aad01b5, 0x7d010010, 0x00000000}},  //   tičn, _onaf, vols,
  { {0x290300b0, 0x00000000, 0x00000000, 0x00000000}},  //   hoja_,   ,   ,
  { {0x9c7c02aa, 0x290300b0, 0x213f04be, 0x00000000}},  //   ričn, koja_, _utuh_,
  { {0x6aad0012, 0x9c7c0e3b, 0xd7d10061, 0x00000000}},  //   _anaf, sičn, सनाच,
  { {0x7ae634fc, 0x29030d90, 0x39400300, 0x00000000}},  //   tikt, doja_, _stis_,
  { {0xd01000a1, 0x00000000, 0x00000000, 0x00000000}},  //   _چلے_,   ,   ,
  { {0x7ae60039, 0x7d010046, 0x00000000, 0x00000000}},  //   rikt, pols,   ,
  { {0x29030627, 0x7ae60039, 0x69c600ea, 0x00000000}},  //   goja_, sikt, ryke,
  { {0x66e6007c, 0x6d5b34fd, 0x6457006b, 0x00000000}},  //   вова, lsua, daxi,
  { {0x24640089, 0x6e3b01a3, 0xe3b200a6, 0x00000000}},  //   zīmē_, ncub, یرا_,
  { {0x6d5b0211, 0x78be0640, 0x2903016e, 0x00000000}},  // [b2c0] nsua, _topv, boja_,
  { {0xa443026b, 0x2903008e, 0xe0bc0044, 0x00000000}},  //   инуд, coja_, _অগ্ন,
  { {0x443a34fe, 0x6d5b01a3, 0x7ae40062, 0x00000000}},  //   rcp_, hsua, _kmit,
  { {0x6146008b, 0xd041005f, 0x25ad0059, 0x00000000}},  //   веда, _illə, _šele_,
  { {0x28a7013d, 0x00000000, 0x00000000, 0x00000000}},  //   खाचि,   ,   ,
  { {0x04430057, 0x7ae40045, 0x2fc7005b, 0x00000000}},  //   _верн, _lmit, fyng_,
  { {0xc6070044, 0x66d10039, 0x7ae40f7f, 0x00000000}},  //   লেদা_, _håka, _omit,
  { {0xe81a013d, 0x417600a1, 0x9c7c2dff, 0x00000000}},  //   _धरना_, _لائس, tičo,
  { {0xaca900a1, 0x127b0049, 0xa3e60316, 0x00000000}},  //   کھنے_, _קאמע, _बेत_,
  { {0x62820007, 0x7ae400f4, 0x26170061, 0x00000000}},  //   lfoo, _amit, पेटी_,
  { {0x29031747, 0x2fd80190, 0x7c3a01c5, 0x00000000}},  //   voja_, _årg_, rctr,
  { {0x62820052, 0x68e700bb, 0x7e98023c, 0x00000000}},  //   nfoo, wijd, _سنتر_,
  { {0x2903021e, 0x7ae417ee, 0x68e700b5, 0x00000000}},  //   toja_, _dmit, tijd,
  { {0x6282107b, 0x5ba6017a, 0x2903007f, 0x00000000}},  //   hfoo, _ариз, uoja_,
  { {0x68e700b5, 0x7ae40026, 0x212c000a, 0x00000000}},  //   rijd, _fmit, _midh_,
  { {0x6aad0020, 0x29030110, 0x8f9b071c, 0x00000000}},  //   _unaf, soja_, וילי,
  { {0x9634008b, 0xa61534ff, 0x290300b0, 0x00000000}},  // [b2d0] рнуц, умач, poja_,
  { {0x6d5d0d6a, 0x03c700e2, 0xca2a0049, 0x00000000}},  //   ásai, ксем, _אופֿ,
  { {0x64573500, 0xed460167, 0x442700b0, 0x00000000}},  //   raxi, _گپ_, än_,
  { {0xe8e10011, 0x7bda2efd, 0x6d5d0089, 0x00000000}},  //   _đột_, iztu, šsai,
  { {0x212c0d12, 0x2089073b, 0x00000000, 0x00000000}},  //   _bidh_, ейли_,   ,
  { {0x92e30044, 0xaf991aca, 0x200c01c3, 0x00000000}},  //   নকে_, етих_, _bydi_,
  { {0x2f54007e, 0x6d420032, 0xd0060478, 0x00000000}},  //   атыс, _atoa, леше_,
  { {0xdd912aea, 0x6455002d, 0x6d5b002d, 0x00000000}},  //   موع_, _hezi, tsua,
  { {0x6e3b01a3, 0x6d5b004a, 0x2012006b, 0x00000000}},  //   rcub, usua, əyim_,
  { {0x6d5b01a3, 0x6e3b0211, 0x332d0066, 0x00000000}},  //   rsua, scub, _hiex_,
  { {0xd0110379, 0x645500b9, 0x6d5b0d87, 0x00000000}},  //   _الا_, _mezi, ssua,
  { {0xd9460200, 0x60c104d3, 0x64550207, 0x00000000}},  //   леми, _holm, _lezi,
  { {0x60c108b2, 0xdbc9006c, 0xc27a0049, 0x00000000}},  //   _kolm, _rõõm, ערשי,
  { {0x64550ba5, 0x8d5a009b, 0x66d10039, 0x00000000}},  //   _nezi, _טכני, _råka,
  { {0x62820009, 0x66d101e3, 0x7bc80036, 0x00000000}},  //   yfoo, _såka, cydu,
  { {0xdb040068, 0x00000000, 0x00000000, 0x00000000}},  //   _orné,   ,   ,
  { {0x645515a6, 0x25a60051, 0xdb090014, 0x00000000}},  // [b2e0] _bezi, íol_, _جزوه_,
  { {0x779402fd, 0xbf0f0061, 0x00000000, 0x00000000}},  //   _پیرا, ातुन_,   ,
  { {0x332d0f68, 0x64553501, 0x287b009b, 0x00000000}},  //   _biex_, _dezi, _אנימ,
  { {0x44311669, 0xe1fa0404, 0xf367009e, 0x00000000}},  //   _egz_, нге_, ائلی,
  { {0xa0540088, 0x7e620066, 0x628214f4, 0x00000000}},  //   авлі, _rdop, rfoo,
  { {0x645500d9, 0x60c108d3, 0xb42600f3, 0x00000000}},  //   _gezi, _colm, _معزو,
  { {0xbf0f0183, 0x26c2021e, 0x60c1014a, 0x00000000}},  //   ातून_, _koko_, _dolm,
  { {0x26c23502, 0x64553503, 0x332d01f3, 0x00000000}},  //   _joko_, _zezi, _giex_,
  { {0x504603f3, 0x7ebc0047, 0x3d260088, 0x00000000}},  //   _безб, _képz, льов,
  { {0x8597007b, 0x26c20058, 0x9c7c0142, 0x00000000}},  //   נדיג_, _loko_, mičk,
  { {0x9c7c040d, 0x9b430167, 0xee8607d0, 0x00000000}},  //   ličk, ینیو, _было,
  { {0xbda60076, 0xdfcf006d, 0x26c20292, 0x00000000}},  //   _محتو, _عين_, _noko_,
  { {0x7bda1a53, 0x9c7c0091, 0x6d420020, 0x00000000}},  //   sztu, ničk, _utoa,
  { {0xb934003b, 0x3aeb0173, 0x3952005b, 0x00000000}},  //   серј, _bòpè_, _dwys_,
  { {0x645507b9, 0xdc3c0059, 0x9c7c0166, 0x00000000}},  //   _rezi, nšči, hičk,
  { {0x64550198, 0x00000000, 0x00000000, 0x00000000}},  //   _sezi,   ,   ,
  { {0x545501f9, 0xa3dd006e, 0x64550142, 0x00000000}},  // [b2f0] иват, _तेज_, _pezi,
  { {0xf53f0901, 0x9c7c01ca, 0xdc3c010a, 0x00000000}},  //   _från_, dičk, kšči,
  { {0x92590057, 0x64551322, 0x5c370049, 0x00000000}},  //   вает_, _vezi, ארבן_,
  { {0x60c10943, 0x9c7c0166, 0x00000000, 0x00000000}},  //   _solm, fičk,   ,
  { {0x6455016c, 0x764d3504, 0x60c10724, 0x00000000}},  //   _tezi, mbay, _polm,
  { {0xe0570167, 0xd5ae00a1, 0x656d01e5, 0x00000000}},  //   ایات_, _کہے_, mrah,
  { {0x60c10007, 0xa3dd0061, 0x26c20504, 0x00000000}},  //   _volm, _तेच_, _yoko_,
  { {0x8c0a0055, 0x9c7c0387, 0x0ea9004c, 0x00000000}},  //   রধান_, bičk, ткий_,
  { {0x60c1253f, 0xc6070044, 0x656d3505, 0x00000000}},  //   _tolm, লেরা_, nrah,
  { {0x660f0073, 0x3b85005c, 0xdc3c0059, 0x00000000}},  //   _myck, алог, bšči,
  { {0x660f0073, 0x764d0058, 0x5f9500a1, 0x00000000}},  //   _lyck, kbay, _خلائ,
  { {0x2023002b, 0x3eaf01e5, 0x656d12e2, 0x00000000}},  //   ħriġ_, _ungt_, krah,
  { {0x26c23506, 0x660f0039, 0x00000000, 0x00000000}},  //   _roko_, _nyck,   ,
  { {0x6d49002a, 0x26c20020, 0x7c94005e, 0x00000000}},  //   mpea, _soko_, _гръц,
  { {0x26c201aa, 0x9c7c0091, 0x6d490d48, 0x00000000}},  //   _poko_, zičk, lpea,
  { {0x764d011c, 0xdce2002b, 0x2bde0061, 0x00000000}},  //   gbay, _ipoġ, _फेटा,
  { {0x7afd147e, 0x656d3507, 0x6d491f56, 0x00000000}},  // [b300] érte, grah, npea,
  { {0x9c7c0161, 0x20a40061, 0x6d492ff0, 0x00000000}},  //   vičk, _गोंध, ipea,
  { {0x3dbd0055, 0x26c20390, 0xb4db0129, 0x00000000}},  //   েছিল, _toko_, _itàl,
  { {0x9c7c0119, 0x656d03b0, 0xdc3c0059, 0x00000000}},  //   tičk, brah, všči,
  { {0x6724002b, 0xa3e60164, 0x752e01f3, 0x00000000}},  //   mmij, _बेर_, _tibz,
  { {0x9c7c19e2, 0x273c3508, 0x3f660098, 0x00000000}},  //   ričk, _kín_, атиб,
  { {0x6d493509, 0xdce20066, 0x00000000, 0x00000000}},  //   epea, _npoġ,   ,
  { {0x273c009f, 0x3de70044, 0x9c7c350a, 0x00000000}},  //   _mín_, _পড়ল, pičk,
  { {0x9c7c0209, 0x248a0022, 0x5096003b, 0x00000000}},  //   liči, _kbbm_, _вређ,
  { {0xdc3c0059, 0x00e3004d, 0xccb80088, 0x00000000}},  //   pšči, _джун, угої_,
  { {0x764d17e5, 0x798d0075, 0x9c7c0142, 0x00000000}},  //   ybay, _spaw, niči,
  { {0x7b22009d, 0x6724350b, 0x00000000, 0x00000000}},  //   _sœur, jmij,   ,
  { {0x2c06001c, 0x00000000, 0x00000000, 0x00000000}},  //   _सुरू_,   ,   ,
  { {0x386d010f, 0xa3d60164, 0x660f00f8, 0x00000000}},  //   ßer_, िना_, _ryck,
  { {0x386d011f, 0x9c7c0ebe, 0x57a400ed, 0x00000000}},  //   ğer_, jiči, ошта,
  { {0xd6d80088, 0x656d05da, 0x9c7c0142, 0x00000000}},  //   ату_, trah, diči,
  { {0x764d006b, 0x89da00a1, 0x672f00f6, 0x00000000}},  // [b310] rbay, _موٹر_, _vicj,
  { {0xb8950054, 0x656d014a, 0x273c350c, 0x00000000}},  //   _الدع, rrah, _fín_,
  { {0x656d03b6, 0x06cc0044, 0xb5fb013e, 0x00000000}},  //   srah, রোধি, _zdál,
  { {0x660f0073, 0x23670059, 0x56940152, 0x00000000}},  //   _tyck, šnjo_, _дают,
  { {0xe1f00380, 0x00000000, 0x00000000, 0x00000000}},  //   وسه_,   ,   ,
  { {0x66d80161, 0x9c7c016e, 0x00000000, 0x00000000}},  //   _víke, biči,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x77f800b3, 0x29f80082, 0x00000000, 0x00000000}},  //   ימוד_, ọai_,   ,
  { {0x6d49009d, 0xdcfb1246, 0x00000000, 0x00000000}},  //   upea, stuč,   ,
  { {0x2ba5001e, 0x6d490032, 0x66d10039, 0x00000000}},  //   _pēc_, rpea, _såkl,
  { {0xe21701f5, 0x1fe50044, 0xcfe50044, 0x00000000}},  //   _तरुण_, _পুরস, _পুরন,
  { {0x2d99002b, 0x6d4900ab, 0x00000000, 0x00000000}},  //   ħseb_, ppea,   ,
  { {0xdca50088, 0x273c000c, 0xfe700014, 0x00000000}},  //   _гали, _sín_, _زدن_,
  { {0x2eed00ab, 0x7b330035, 0xbbe80014, 0x00000000}},  //   lief_, _băut, اریم_,
  { {0xdc12005f, 0x7b33001a, 0xb8f0013d, 0x00000000}},  //   _işğa, _căut, _शव_,
  { {0x9c7c350d, 0x3ebf020c, 0x66e302e9, 0x00000000}},  //   viči, njut_, поса,
  { {0xe61a013b, 0x672400b5, 0x99860025, 0x00000000}},  // [b320] уда_, rmij, _الخو,
  { {0x273c001d, 0x2eed0270, 0x6724016e, 0x00000000}},  //   _tín_, hief_, smij,
  { {0x1d160049, 0x00000000, 0x00000000, 0x00000000}},  //   צקער_,   ,   ,
  { {0x9c7c04a5, 0x2d030204, 0x68ee013f, 0x00000000}},  //   riči, रकुल_, libd,
  { {0x9c7c00ca, 0x2eed040f, 0x00000000, 0x00000000}},  //   siči, dief_,   ,
  { {0x290a2698, 0x9c7c021c, 0x154300d7, 0x00000000}},  //   noba_, piči, _херм,
  { {0x645e036b, 0x7d080059, 0x2d9d0173, 0x00000000}},  //   mapi, vods, _aswe_,
  { {0x645e350e, 0x2eed0007, 0x26c004eb, 0x00000000}},  //   lapi, gief_, njio_,
  { {0x7cd80069, 0x290a0213, 0x00000000, 0x00000000}},  //   имир_, koba_,   ,
  { {0x645e1084, 0x290a0062, 0x00000000, 0x00000000}},  //   napi, joba_,   ,
  { {0x290a0036, 0xbb470752, 0x8af90e75, 0x00000000}},  //   doba_, یلین_, инос_,
  { {0x645e006c, 0x3f9e0091, 0xee3a0245, 0x00000000}},  //   hapi, _istu_, _снд_,
  { {0x645e0013, 0x1ea90f8b, 0x00000000, 0x00000000}},  //   kapi, _خالي_,   ,
  { {0x645e006c, 0x7d7b00a3, 0x290a01ed, 0x00000000}},  //   japi, _ענוו, goba_,
  { {0xccf800b9, 0x67d4350f, 0x645e05cd, 0x00000000}},  //   mně_, пору, dapi,
  { {0xccf80224, 0xe3df0044, 0x2d84016c, 0x00000000}},  //   lně_, _বুঝব, otme_,
  { {0x6345010a, 0x290a012d, 0xfaf80014, 0x00000000}},  // [b330] _mėne, boba_, _دروغ_,
  { {0x7aef029a, 0x645e011c, 0x290a0093, 0x00000000}},  //   lict, gapi, coba_,
  { {0x1635007c, 0x4394007c, 0x22490032, 0x00000000}},  //   _меня, захс, ñako_,
  { {0x7aef3510, 0xd048006b, 0xdce93191, 0x00000000}},  //   nict, _ildə, vreč,
  { {0x416b003b, 0xccf800b9, 0x3f9e20d4, 0x00000000}},  //   ујем_, kně_, _astu_,
  { {0x661d001e, 0xccf80224, 0x9fc90aed, 0x00000000}},  //   _izsk, jně_, игла_,
  { {0xccf80224, 0x2eed049b, 0x3ebf0052, 0x00000000}},  //   dně_, tief_, tjut_,
  { {0xee39017a, 0x290a0010, 0xef190545, 0x00000000}},  //   шни_, zoba_, јми_,
  { {0x7aef1ee1, 0x2eed049b, 0x0c95008b, 0x00000000}},  //   dict, rief_, ошня,
  { {0xdce90059, 0x2eed00c1, 0xe4560049, 0x00000000}},  //   preč, sief_, ֿירט_,
  { {0x39490149, 0x66d8009f, 0xf53f1d43, 0x00000000}},  //   _atas_, _líka, _bråk_,
  { {0xeb960057, 0xc9aa00ed, 0x290a0009, 0x00000000}},  //   цию_, авме_, woba_,
  { {0xdd94008b, 0x290a0020, 0xccf800b9, 0x00000000}},  //   _нацы, toba_, bně_,
  { {0x26d923b9, 0xccf800b9, 0x6efe0089, 0x00000000}},  //   _also_, cně_, mība,
  { {0x290a0161, 0x6efe001e, 0x25a90403, 0x00000000}},  //   roba_, lība, eval_,
  { {0x7e7b1330, 0x645e0020, 0x25a90328, 0x00000000}},  //   ngup, wapi, fval_,
  { {0x056601fb, 0x6efe001e, 0x645e16c3, 0x00000000}},  // [b340] юван, nība, tapi,
  { {0xdb2100b0, 0x6aa40020, 0xa3d50164, 0x00000000}},  //   ätök, _haif, ाईं_,
  { {0x39840039, 0x6aa43511, 0x00000000, 0x00000000}},  //   lös_, _kaif,   ,
  { {0x41aa00d7, 0x645e0013, 0x914a00aa, 0x00000000}},  //   ивен_, sapi, ачка_,
  { {0xccf800b9, 0x645e293d, 0x39840b90, 0x00000000}},  //   yně_, papi, nös_,
  { {0x6efe0089, 0x3f9e0ab2, 0x656400e7, 0x00000000}},  //   dība, _pstu_, msih,
  { {0xccf80224, 0xc059008b, 0x645c01c5, 0x00000000}},  //   vně_, сіі_, _ieri,
  { {0x44443278, 0xeeb80f97, 0x398401ba, 0x00000000}},  //   lc_, слиш_, kös_,
  { {0x01630b11, 0xccf80224, 0x645c04cb, 0x00000000}},  //   _окто, tně_, _keri,
  { {0x4444018e, 0x645c3512, 0x44383513, 0x00000000}},  //   nc_, _jeri, _jgr_,
  { {0x44440051, 0x44383514, 0x2018009f, 0x00000000}},  //   ic_, _mgr_, _ári_,
  { {0x6aa413b2, 0xccf80224, 0x25a90725, 0x00000000}},  //   _caif, sně_, yval_,
  { {0x6efe001e, 0x7e6004d4, 0x61e20142, 0x00000000}},  //   cība, mamp, nzol,
  { {0x645c0006, 0x444400ca, 0x61e20142, 0x00000000}},  //   _neri, jc_, izol,
  { {0x7aef0857, 0x444423bb, 0x25a90d4d, 0x00000000}},  //   pict, dc_, wval_,
  { {0x645c001a, 0x7e6004d4, 0x44440036, 0x00000000}},  //   _aeri, namp, ec_,
  { {0x7aed04bd, 0x645c3515, 0x44380c3f, 0x00000000}},  // [b350] _imat, _beri, _bgr_,
  { {0x25a9095c, 0x645c0127, 0x7e6001a3, 0x00000000}},  //   rval_, _ceri, hamp,
  { {0x6efe001e, 0x7e602f6c, 0x25a904d3, 0x00000000}},  //   zība, kamp, sval_,
  { {0x44443516, 0x44381ac4, 0x7e600006, 0x00000000}},  //   ac_, _egr_, jamp,
  { {0x645c0240, 0x27ff01f6, 0x78a5115d, 0x00000000}},  //   _feri, ğunu_, _kahv,
  { {0x645c010a, 0x850502fd, 0xb5fb002a, 0x00000000}},  //   _geri, _روزن, _ndái,
  { {0x765d0263, 0xd34302fd, 0x39840010, 0x00000000}},  //   _kesy, _آفری, zös_,
  { {0x64450016, 0x6efe0089, 0x645c19e1, 0x00000000}},  //   lchi, tība, _zeri,
  { {0x645c01f6, 0x765d3517, 0x629900ab, 0x00000000}},  //   _yeri, _mesy, mewo,
  { {0x7aed3518, 0x753d0036, 0x6efe0089, 0x00000000}},  //   _amat, _musz, rība,
  { {0x6efe001e, 0x75350066, 0x6445010f, 0x00000000}},  //   sība, _mizz, ichi,
  { {0x6efe12d1, 0x319d0173, 0x64451139, 0x00000000}},  //   lībn, _kňz_, hchi,
  { {0xec6e0088, 0x6445068d, 0x9c7c013e, 0x00000000}},  //   _пп_, kchi, tičt,
  { {0x7aed022b, 0x17fa0054, 0x7535054f, 0x00000000}},  //   _emat, مرأة_, _nizz,
  { {0x6aa43519, 0x753d18de, 0x61e20207, 0x00000000}},  //   _taif, _ausz, zzol,
  { {0x645c000b, 0x3b070265, 0x443822c7, 0x00000000}},  //   _seri, _нещо_, _sgr_,
  { {0x645c020c, 0x765d000a, 0x443800d6, 0x00000000}},  // [b360] _peri, _desy, _pgr_,
  { {0x44440089, 0x656404cb, 0x753d0036, 0x00000000}},  //   uc_, rsih, _dusz,
  { {0x7535002b, 0x44440051, 0x645c351a, 0x00000000}},  //   _dizz, rc_, _veri,
  { {0xd7bb00b6, 0x4444351b, 0x62990546, 0x00000000}},  //   _הצטר, sc_, gewo,
  { {0x60c80428, 0x75350c0d, 0x7e6000b0, 0x00000000}},  //   _podm, _fizz, vamp,
  { {0x64450198, 0x61e2001b, 0x75350912, 0x00000000}},  //   cchi, rzol, _gizz,
  { {0x7e6014e8, 0x6d4b010a, 0x61e20047, 0x00000000}},  //   tamp, _atga, szol,
  { {0x62990c0d, 0x6f0411af, 0x00000000, 0x00000000}},  //   cewo, čico,   ,
  { {0x7e600169, 0x60c8000a, 0xa06a00a8, 0x00000000}},  //   ramp, _todm, _газа_,
  { {0x7aed0119, 0x7e600fef, 0xa0c90025, 0x00000000}},  //   _smat, samp, _وذلك_,
  { {0x78a50004, 0x6d40001c, 0x7e600225, 0x00000000}},  //   _rahv, sqma, pamp,
  { {0xdee30131, 0x00000000, 0x00000000, 0x00000000}},  //   _похи,   ,   ,
  { {0x644513f7, 0xf2d3007b, 0x765d0016, 0x00000000}},  //   ychi, גער_, _resy,
  { {0x23670295, 0x3d1403d7, 0x62990036, 0x00000000}},  //   šnji_, _नीचे_, zewo,
  { {0x78a50b3e, 0x75350197, 0x6445012d, 0x00000000}},  //   _vahv, _rizz, vchi,
  { {0xabfb00b6, 0x753d115b, 0x7aed0518, 0x00000000}},  //   _להור, _pusz, _umat,
  { {0x75351d7a, 0x644500ab, 0xa5350816, 0x00000000}},  // [b370] _pizz, tchi, днач,
  { {0xda070014, 0x3ea61ecd, 0x00000000, 0x00000000}},  //   _ويژه_, _laot_,   ,
  { {0x62990e9e, 0x75350066, 0x00000000, 0x00000000}},  //   tewo, _vizz,   ,
  { {0x7afd351c, 0x64452f66, 0x386301d5, 0x00000000}},  //   nnst, schi, lajr_,
  { {0x7afd010f, 0x644527ec, 0x75350026, 0x00000000}},  //   inst, pchi, _tizz,
  { {0x66d8000c, 0x7afd2cd7, 0xb4db00f6, 0x00000000}},  //   _líkl, hnst, _atàv,
  { {0xdb240010, 0x4394007e, 0x00000000, 0x00000000}},  //   őség, _парс,   ,
  { {0xdd9105f3, 0x24bf0055, 0x7afd351d, 0x00000000}},  //   نوع_, _ইতিহ, jnst,
  { {0xfce50594, 0x00000000, 0x00000000, 0x00000000}},  //   допо,   ,   ,
  { {0xd1310a90, 0x26cb0e1d, 0x7afd351e, 0x00000000}},  //   _شما_, _loco_, enst,
  { {0x6d5900e7, 0x00000000, 0x00000000, 0x00000000}},  //   _wwwa,   ,   ,
  { {0xc86900b6, 0x673e0089, 0x7afd0fd1, 0x00000000}},  //   _כן_, _rupj, gnst,
  { {0x6d4b0292, 0xdce20059, 0xad882638, 0x00000000}},  //   _utga, _zvoč, _فضول_,
  { {0x225f02ae, 0x7afd0039, 0xe73a0fd8, 0x00000000}},  //   _leuk_, anst, жев_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x225f002d, 0x7afd012d, 0x00000000, 0x00000000}},  //   _neuk_, cnst,   ,
  { {0x3a200009, 0x2ca70239, 0x09060088, 0x00000000}},  // [b380] _uzip_, _kand_, _опин,
  { {0xa5bb0010, 0x27010006, 0x00000000, 0x00000000}},  //   _szóc, rėna_,   ,
  { {0x39400100, 0x2ca70018, 0x33d5008b, 0x00000000}},  //   _huis_, _mand_, ніцт,
  { {0x2ca7351f, 0x3940033b, 0x26cb012d, 0x00000000}},  //   _land_, _kuis_, _goco_,
  { {0xa158007c, 0x61433520, 0x39400007, 0x00000000}},  //   чалу_, веча, _juis_,
  { {0x2ca71ebf, 0x394000c7, 0x2a6003e1, 0x00000000}},  //   _nand_, _muis_, _leib_,
  { {0x39400211, 0x25a025f4, 0xc306009e, 0x00000000}},  //   _luis_, lwil_, _قبرو,
  { {0x2ca70007, 0x225f0032, 0xbd6a007c, 0x00000000}},  //   _aand_, _geuk_, орое_,
  { {0x25a03521, 0xdb1b0036, 0x64430089, 0x00000000}},  //   nwil_, zytó, žnie,
  { {0x2ca7000d, 0x225f002d, 0x7afd0133, 0x00000000}},  //   _cand_, _zeuk_, wnst,
  { {0xc47700b3, 0x2ca70035, 0x2cb8006b, 0x00000000}},  //   ותיו_, _dand_, ırd_,
  { {0x394000bb, 0xf9e70044, 0x2bac00b9, 0x00000000}},  //   _buis_, _গুগল_, _věc_,
  { {0x7afd2ac9, 0xb5fb0051, 0x2ca712dc, 0x00000000}},  //   rnst, _meác, _fand_,
  { {0x6e2201d9, 0xa803014a, 0x2ca70035, 0x00000000}},  //   _izob, _çıkm, _gand_,
  { {0x26cb156d, 0x55fb0044, 0x39400022, 0x00000000}},  //   _poco_, _আরেক_, _euis_,
  { {0x2ca700bb, 0x00000000, 0x00000000, 0x00000000}},  //   _zand_,   ,   ,
  { {0x66d8000c, 0x225f0007, 0x2b4e0009, 0x00000000}},  // [b390] _kíkj, _reuk_, _htfc_,
  { {0xdb04010f, 0x651503ab, 0xd1380036, 0x00000000}},  //   _ernä, روائ, _nią_,
  { {0x68f501f6, 0x26cb0b33, 0xd34100a1, 0x00000000}},  //   mizd, _toco_, اہری,
  { {0x29111140, 0x00000000, 0x00000000, 0x00000000}},  //   loza_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6458009f, 0x68f5047f, 0x2911206d, 0x00000000}},  //   ðvit, nizd, noza_,
  { {0x386108ba, 0x2ca70938, 0x6e2200d2, 0x00000000}},  //   _mehr_, _rand_, _azob,
  { {0xf838019b, 0xfaff048a, 0x29113522, 0x00000000}},  //   ונות_, jnë_, hoza_,
  { {0x2ca700bb, 0x213f012d, 0x6f020066, 0x00000000}},  //   _pand_, _uuuh_, _djoc,
  { {0x23670091, 0x394000bb, 0xa28100a1, 0x00000000}},  //   šnju_, _ruis_, _شیڈو,
  { {0x3940028c, 0x2ca7161c, 0x2b4e00f6, 0x00000000}},  //   _suis_, _vand_, _ctfc_,
  { {0x3940028c, 0x2ca705c6, 0xdd8e0014, 0x00000000}},  //   _puis_, _wand_, جوی_,
  { {0x394000c4, 0x2ca73523, 0x634c0095, 0x00000000}},  //   _quis_, _tand_, _iğne,
  { {0x2911231e, 0x65760007, 0x68f5016c, 0x00000000}},  //   goza_, vryh, gizd,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x39400343, 0x6f1b0197, 0x63a20036, 0x00000000}},  //   _tuis_, nluc, łonk,
  { {0xb5fb0051, 0x29113524, 0xe6e0013d, 0x00000000}},  // [b3a0] _reác, boza_, _नतीज,
  { {0x25a00093, 0x6f1b01a2, 0x29113525, 0x00000000}},  //   rwil_, hluc, coza_,
  { {0x6f1b3526, 0x657600b0, 0x00000000, 0x00000000}},  //   kluc, sryh,   ,
  { {0xc7b300b3, 0x672d00f6, 0x0166005c, 0x00000000}},  //   _עבר_, cmaj, екдо,
  { {0xc693007b, 0xd1380036, 0x00000000, 0x00000000}},  //   _גאר_, _pią_,   ,
  { {0x6aa90055, 0x7f413527, 0x00000000, 0x00000000}},  //   গাযো, _bulq,   ,
  { {0x6443167a, 0x6e220047, 0x66d8000c, 0x00000000}},  //   žnic, _szob, _ríkj,
  { {0x7d03002f, 0x2389093f, 0x8fa300ed, 0x00000000}},  //   _ajns, žují_, ѓање,
  { {0x62820168, 0xfe6f0025, 0x00000000, 0x00000000}},  //   mgoo, حدى_,   ,
  { {0x6f1b0026, 0x00000000, 0x00000000, 0x00000000}},  //   aluc,   ,   ,
  { {0x6f020039, 0x291111cc, 0xd12f0379, 0x00000000}},  //   _tjoc, voza_, _امل_,
  { {0x3861001f, 0x6f1b00e5, 0x00000000, 0x00000000}},  //   _sehr_, cluc,   ,
  { {0x4dd305f3, 0x291100e7, 0x7ae80023, 0x00000000}},  //   _متوس, toza_, ëjta,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7e621220, 0xd6db00c0, 0xed35007e, 0x00000000}},  //   _keop, пта_, _рэцэ,
  { {0xf5e701ff, 0x29110009, 0x6d4200e7, 0x00000000}},  //   нізм, soza_, _kuoa,
  { {0x672d3528, 0x95cb06e3, 0x68f5016e, 0x00000000}},  // [b3b0] rmaj, чува_, pizd,
  { {0x672d006c, 0x9964005e, 0x00000000, 0x00000000}},  //   smaj, _стъл,   ,
  { {0xd2510647, 0x00000000, 0x00000000, 0x00000000}},  //   لنا_,   ,   ,
  { {0x7e62041a, 0x6282040f, 0x00000000, 0x00000000}},  //   _neop, ggoo,   ,
  { {0x6f1b00bb, 0x00000000, 0x00000000, 0x00000000}},  //   vluc,   ,   ,
  { {0xf07500a1, 0x26c904eb, 0x7f41004a, 0x00000000}},  //   ئیاں_, ljao_, _pulq,
  { {0x2cac0142, 0xc4d2009b, 0xbea5005e, 0x00000000}},  //   dddd_, _דגם_, вайк,
  { {0x26c90091, 0x00000000, 0x00000000, 0x00000000}},  //   njao_,   ,   ,
  { {0x6f1b0145, 0x7e620035, 0x00000000, 0x00000000}},  //   rluc, _deop,   ,
  { {0x6f1b002a, 0x63b510ec, 0xdbde000c, 0x00000000}},  //   sluc, _krzn, tíða,
  { {0x3b0a00ed, 0x2d980035, 0xef740bb6, 0x00000000}},  //   дено_, ărea_, _مدنظ,
  { {0x7e6200b5, 0xf41200b6, 0x63b52270, 0x00000000}},  //   _geop, שפט_, _mrzn,
  { {0x4e780054, 0x26c90107, 0xdbde01e5, 0x00000000}},  //   _أحمد_, djao_, _bíóm,
  { {0x3ead0374, 0x7ce400f6, 0x63a200b4, 0x00000000}},  //   ldet_, _còrd, łoni,
  { {0xb90a02f4, 0x62820a89, 0x2d8d04e7, 0x00000000}},  //   _मत_, ygoo, ltee_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3ead08db, 0x4ad900a1, 0x2d8d03cf, 0x00000000}},  // [b3c0] idet_, _ساٹھ_, ntee_,
  { {0xb97b073e, 0x3ead00b0, 0x628200d9, 0x00000000}},  //   _קניי, hdet_, wgoo,
  { {0x316d028c, 0x1877009b, 0x628201d6, 0x00000000}},  //   _avez_, _בעיר_, tgoo,
  { {0x3ead0030, 0x63b5089f, 0xdb0400f6, 0x00000000}},  //   jdet_, _drzn, _arnú,
  { {0x3ead3529, 0x64430006, 0x628200b4, 0x00000000}},  //   ddet_, žnia, rgoo,
  { {0x224d10ed, 0xc953009b, 0x7e620022, 0x00000000}},  //   _efek_, סמו_, _seop,
  { {0x7e620038, 0x7416007a, 0x6282352a, 0x00000000}},  //   _peop, _شورا, pgoo,
  { {0xb5fb0051, 0x3ead0023, 0x395200d9, 0x00000000}},  //   _meán, gdet_, _otys_,
  { {0x6ce6007e, 0x80c201f5, 0xb5fb0010, 0x00000000}},  //   віне, लादे, _leán,
  { {0x9b5801f9, 0x8f760088, 0x00000000, 0x00000000}},  //   ниот_, _ауді,   ,
  { {0x753c006b, 0x7e62004a, 0x5eaa0044, 0x00000000}},  //   _mirz, _teop, কাবে,
  { {0xbe850379, 0x75da0089, 0xf413034e, 0x00000000}},  //   _مجهو, _kāzā, יפת_,
  { {0x7e7d00d6, 0xba3b00f6, 0x00000000, 0x00000000}},  //   óspe, deïc,   ,
  { {0x0d970104, 0xdce60089, 0xab62013f, 0x00000000}},  //   _סכום_, ēmēj, _şüur,
  { {0x09cb0055, 0xd7f8007c, 0xdd31006b, 0x00000000}},  //   _লেখা, вут_, ləşi,
  { {0xdce00006, 0x644e1e2e, 0x00000000, 0x00000000}},  //   tumė, _afbi,   ,
  { {0xa5f8352b, 0x753c0fec, 0x00000000, 0x00000000}},  // [b3d0] вету_, _birz,   ,
  { {0x798d01f3, 0x6aad00d9, 0x00000000, 0x00000000}},  //   _iqaw, _haaf,   ,
  { {0xdce90091, 0x753c352c, 0x3ead115d, 0x00000000}},  //   sreć, _dirz, ydet_,
  { {0xdce9016c, 0x6aad0145, 0xa6db000c, 0x00000000}},  //   preć, _jaaf, _siðf,
  { {0x6aad00f0, 0x667a009b, 0x3ead352d, 0x00000000}},  //   _maaf, _אטרק, vdet_,
  { {0x66d8009f, 0x89dc009b, 0x656d1be0, 0x00000000}},  //   _ríki, וחדי, msah,
  { {0x938800ed, 0xd3470014, 0xa6db000c, 0x00000000}},  //   _иста_, _شیشه_, _viðf,
  { {0x2d8d00ab, 0x3ead00b0, 0x63b80030, 0x00000000}},  //   ttee_, udet_, ævne,
  { {0x3ead00ea, 0x656d006a, 0x673d352e, 0x00000000}},  //   rdet_, nsah, _misj,
  { {0x29030107, 0x656d352f, 0x661d2593, 0x00000000}},  //   jnja_, isah, _mysk,
  { {0x290301ae, 0x2d8d0ace, 0x9f550216, 0x00000000}},  //   dnja_, stee_, _свеч,
  { {0xa5bb0047, 0x673d3530, 0x6aad00d9, 0x00000000}},  //   _gyóg, _nisj, _caaf,
  { {0x661d04d3, 0x6dc40151, 0xb5fb0048, 0x00000000}},  //   _nysk, _نزول, _seán,
  { {0xd943026b, 0x9409006b, 0x61eb012d, 0x00000000}},  //   сери, şkən_, izgl,
  { {0x66e600aa, 0x1cb801d8, 0x37e30152, 0x00000000}},  //   гова, _جانب_, борг,
  { {0x6b810f6a, 0x673d02d0, 0x290308f0, 0x00000000}},  //   mulg, _cisj, anja_,
  { {0x7ae422b2, 0x2903016e, 0x656d2c6b, 0x00000000}},  // [b3e0] _ilit, bnja_, gsah,
  { {0x661d0046, 0xe61702e9, 0x05770025, 0x00000000}},  //   _dysk, уду_, املة_,
  { {0x2b4f001a, 0x753c0089, 0x656d011c, 0x00000000}},  //   _încă_, _virz, asah,
  { {0x55e601fc, 0x6efe0089, 0x331a0439, 0x00000000}},  //   _бомб, lībv, رزاد_,
  { {0x6b81050d, 0x753c2234, 0x00000000, 0x00000000}},  //   hulg, _tirz,   ,
  { {0x7ae40221, 0x779100a1, 0xbfaa09da, 0x00000000}},  //   _llit, _دیہا, етие_,
  { {0xfbc70379, 0x661d0036, 0x6b81010e, 0x00000000}},  //   _ات_, _zysk, julg,
  { {0x29030107, 0xa6db000c, 0x62890048, 0x00000000}},  //   znja_, _viðg, _gceo,
  { {0xa206008b, 0x386a3531, 0x2903000c, 0x00000000}},  //   _спад, kabr_, ynja_,
  { {0x7ae4000b, 0x764d0553, 0x90d50082, 0x00000000}},  //   _alit, zcay, _hìn,
  { {0x7ae40292, 0x447b0049, 0x2903016e, 0x00000000}},  //   _blit, ענטע, vnja_,
  { {0x7ae421e3, 0xf4260044, 0xb5fb0010, 0x00000000}},  //   _clit, _বলার_, _beál,
  { {0x29030166, 0x8d5601fc, 0x90d50082, 0x00000000}},  //   tnja_, _стеч, _mìn,
  { {0x661d3532, 0x6aad0020, 0x6b813533, 0x00000000}},  //   _rysk, _waaf, bulg,
  { {0x7ae40065, 0x66d8000c, 0x661d0039, 0x00000000}},  //   _flit, _líku, _sysk,
  { {0x2903016c, 0x213e0460, 0x656d0176, 0x00000000}},  //   snja_, _lith_, tsah,
  { {0x29033534, 0x764d3535, 0x673d0056, 0x00000000}},  // [b3f0] pnja_, rcay, _visj,
  { {0x661d3536, 0x764d01a3, 0x656d003f, 0x00000000}},  //   _vysk, scay, rsah,
  { {0x5695008b, 0x7ae400b0, 0x656d0052, 0x00000000}},  //   _кант, _ylit, ssah,
  { {0x661d05fe, 0x51550088, 0x98b30035, 0x00000000}},  //   _tysk, атку, _fixă_,
  { {0x213e002a, 0x201e0173, 0xd5f90049, 0x00000000}},  //   _bith_, _ayti_, _ספֿר,
  { {0x6ae202fb, 0x7bda3537, 0x3a290288, 0x00000000}},  //   _पत्र, kytu, _mzap_,
  { {0xbf100061, 0x00000000, 0x00000000, 0x00000000}},  //   ावून_,   ,   ,
  { {0x6b811160, 0xfe4501f9, 0x201e0065, 0x00000000}},  //   vulg, шнио, _dyti_,
  { {0x386a06db, 0x5187012b, 0x60870025, 0x00000000}},  //   yabr_, _љуба, _مشاك,
  { {0x7ae403ed, 0xb5fb0d7f, 0xa2c30061, 0x00000000}},  //   _slit, _reál, ळाव्,
  { {0xa6db000c, 0x7ae40091, 0x66d8000c, 0x00000000}},  //   _miðb, _plit, _kíkt,
  { {0x4e190057, 0xf1b90107, 0xa3b6007d, 0x00000000}},  //   _июля_, _krš_, जित_,
  { {0xd9463538, 0x291a0085, 0x00000000, 0x00000000}},  //   реги, _pkpa_,   ,
  { {0xcc89007a, 0x9d520025, 0x271e0309, 0x00000000}},  //   _شنبه_, _بنوت, पत्र_,
  { {0x46f61280, 0xbebd0dec, 0x366a0088, 0x00000000}},  //   ачат, plūd, каво_,
  { {0xfd4c0011, 0x3eaf3539, 0x7ae409bd, 0x00000000}},  //   _nhiễ, _jagt_, _ulit,

  { {0xb46601e0, 0x25ab041d, 0x3eaf0030, 0x00000000}},  // [b400] икал, _cscl_, _magt_,
  { {0x3eaf030e, 0xe4570cb3, 0xdb0b01a2, 0x00000000}},  //   _lagt_, ижу_, _erfä,
  { {0x213e0051, 0xa87b009b, 0x287b0104, 0x00000000}},  //   _rith_, _באיר, _בנימ,
  { {0x29180198, 0xeb96007b, 0x969601fc, 0x00000000}},  //   lora_, ידער_, _трош,
  { {0xaa7b0802, 0x7bda00b4, 0x00000000, 0x00000000}},  //   lkýc, zytu,   ,
  { {0x29180555, 0xa87a0049, 0xa6db000c, 0x00000000}},  //   nora_, דאַר, _viðe,
  { {0x7ee60c96, 0x90d50082, 0x2d9d0173, 0x00000000}},  //   ицие, _tìn, _apwe_,
  { {0x213e0a8a, 0x29180129, 0x68fc353a, 0x00000000}},  //   _with_, hora_, hird,
  { {0x291807ef, 0x68fc005a, 0x91e302e9, 0x00000000}},  //   kora_, kird, _доте,
  { {0x29180211, 0x7bda093c, 0x00000000, 0x00000000}},  //   jora_, tytu,   ,
  { {0x291800d6, 0x26c2021e, 0x68fc0180, 0x00000000}},  //   dora_, _onko_, dird,
  { {0x3f9e353b, 0x7bda0fed, 0xdce70089, 0x00000000}},  //   _iptu_, rytu, ālāk,
  { {0x0f120061, 0x442a00d9, 0x00000000, 0x00000000}},  //   डकीस_, _lzb_,   ,
  { {0x29180aa8, 0x26c201aa, 0x68fc353c, 0x00000000}},  //   gora_, _anko_, gird,
  { {0xbb840054, 0x2d840053, 0x442a02c2, 0x00000000}},  //   _العي, lume_, _nzb_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afd0368, 0xb9950054, 0x68fc1352, 0x00000000}},  // [b410] mist, _الخب, bird,
  { {0x7afd0004, 0x29180198, 0x26c219c5, 0x00000000}},  //   list, cora_, _enko_,
  { {0x69dd05d5, 0xa6db009f, 0xaa7b0428, 0x00000000}},  //   lyse, _viðb, ckýc,
  { {0x2d84002d, 0x7b1d008e, 0x39490022, 0x00000000}},  //   kume_, céut, _kuas_,
  { {0xf1a7007c, 0x2d84251b, 0x442a0f30, 0x00000000}},  //   ррен, jume_, _ezb_,
  { {0x3eaf009f, 0x7afd1d2e, 0x2d84353d, 0x00000000}},  //   _sagt_, hist, dume_,
  { {0x7afd021e, 0x3949353e, 0x2ee60173, 0x00000000}},  //   kist, _luas_, _blof_,
  { {0x7afd353f, 0x29180091, 0x2d840022, 0x00000000}},  //   jist, zora_, fume_,
  { {0x7afd021e, 0x25a9006a, 0x2d84001a, 0x00000000}},  //   dist, nwal_, gume_,
  { {0x50db02f4, 0x7afd0877, 0x2b470d0a, 0x00000000}},  //   _भविष, eist, _punc_,
  { {0x29180119, 0x7f840025, 0x25a90022, 0x00000000}},  //   vora_, _ولكن, hwal_,
  { {0x2d840f04, 0x3949008a, 0x68fc005b, 0x00000000}},  //   bume_, _buas_, wird,
  { {0x68fc005d, 0x8c4510d6, 0x00000000, 0x00000000}},  //   tird, _леле,   ,
  { {0x394902d5, 0x7d7604e8, 0x6d5b020c, 0x00000000}},  //   _duas_, _امور_, mpua,
  { {0x7afd022b, 0x291804f8, 0x5eaa0055, 0x00000000}},  //   bist, rora_, কারে,
  { {0x2918231e, 0x68fc3540, 0x69dd3541, 0x00000000}},  //   sora_, sird, byse,
  { {0xf50a08fc, 0xaa7b01ca, 0x9fa2000c, 0x00000000}},  // [b420] гнал_, skýc, _líða_,
  { {0x77ca01e0, 0x88860aed, 0xfe7900b9, 0x00000000}},  //   _блог_, _улож, chův_,
  { {0x493b00b6, 0x2d84003b, 0x7b1d008e, 0x00000000}},  //   _תגיו, zume_, péut,
  { {0x2ca50056, 0xa2940088, 0xca7b0049, 0x00000000}},  //   held_, іалі, ָנסט,
  { {0x672407e3, 0x2ca52398, 0x673600d9, 0x00000000}},  //   mlij, keld_, mmyj,
  { {0x7afd008d, 0x836a0014, 0x9fa2000c, 0x00000000}},  //   zist, _مصرف_, _bíða_,
  { {0x7afd19db, 0x8f3400e2, 0x3ea43542, 0x00000000}},  //   yist, оекц, temt_,
  { {0x7afd049a, 0x2d84218d, 0x672402ae, 0x00000000}},  //   xist, tume_, nlij,
  { {0x6724178a, 0x2ca5010f, 0x6d5b011c, 0x00000000}},  //   ilij, feld_, gpua,
  { {0x2d84010a, 0x2ca5333c, 0x39493543, 0x00000000}},  //   rume_, geld_, _ruas_,
  { {0x3949304c, 0x2a690004, 0x6724200c, 0x00000000}},  //   _suas_, _peab_, klij,
  { {0x69dd0541, 0x612d000c, 0x3949003f, 0x00000000}},  //   tyse, rúle, _puas_,
  { {0x2ca500b5, 0x672401ed, 0xdb0401e5, 0x00000000}},  //   beld_, dlij, _arnó,
  { {0x69dd0fb6, 0x672400b5, 0x6e220009, 0x00000000}},  //   ryse, elij, _iyob,
  { {0x7afd3544, 0x64430059, 0x7d1a0479, 0x00000000}},  //   pist, žnik, mots,
  { {0xaae70070, 0x25a90a1d, 0x67240006, 0x00000000}},  //   _دستو, twal_, glij,
  { {0x8627008b, 0x555500a1, 0xf8ae00a6, 0x00000000}},  // [b430] сьве, زپار, رکی_,
  { {0xf9900025, 0xfaff01b5, 0x6e223545, 0x00000000}},  //   _أبي_, lië_, _myob,
  { {0x78b50061, 0xb5fb0051, 0x67240d7d, 0x00000000}},  //   mdzv, _meái, blij,
  { {0xfaff01b5, 0x326b0025, 0x7d1a0471, 0x00000000}},  //   nië_, احاً_, hots,
  { {0xdd860167, 0x6e223546, 0x9fa2000c, 0x00000000}},  //   _تو_, _nyob, _síða_,
  { {0x7bc5009f, 0xa3b6013d, 0x2f550793, 0x00000000}},  //   _áhug, जिश_, отис,
  { {0x2ca501b5, 0x7f4200d6, 0x1ec902dc, 0x00000000}},  //   veld_, _bioq, илки_,
  { {0x2ca53547, 0x9fa2000c, 0x7d0800fe, 0x00000000}},  //   weld_, _víða_, ends,
  { {0x2ca53548, 0xfaff054c, 0x44230023, 0x00000000}},  //   teld_, dië_, _hyj_,
  { {0x7d1a0032, 0x6d5b01a3, 0x463c0049, 0x00000000}},  //   gots, rpua, נעזע,
  { {0x2ca50100, 0xeb990264, 0x7ced00f6, 0x00000000}},  //   reld_, шин_, _lúrg,
  { {0x628b3549, 0x3f87014a, 0x20c70061, 0x00000000}},  //   nggo, munu_, लावध,
  { {0x7d1a0056, 0x3f870279, 0x6f1b00b9, 0x00000000}},  //   bots, lunu_, mouc,
  { {0x6d59002b, 0x64470065, 0x6f1b013e, 0x00000000}},  //   _itwa, _ngji, louc,
  { {0x67241fed, 0x3f87005d, 0x6d4b354a, 0x00000000}},  //   tlij, nunu_, _huga,
  { {0x6d43006a, 0x6f09028a, 0x6f1b24b0, 0x00000000}},  //   _hina, nnec, nouc,
  { {0x6d431bc6, 0x672402ae, 0x6d4b354b, 0x00000000}},  // [b440] _kina, rlij, _juga,
  { {0x67240209, 0x6d4b1e17, 0x6d430224, 0x00000000}},  //   slij, _muga, _jina,
  { {0x6d4b354c, 0x6d43354d, 0x389b01ce, 0x00000000}},  //   _luga, _mina, _דיינ,
  { {0xe29a08fd, 0xd25000b8, 0x6d43000b, 0x00000000}},  //   рад_, رنت_, _lina,
  { {0x6d43022b, 0x6f1b00b9, 0x6d4b0006, 0x00000000}},  //   _oina, douc, _nuga,
  { {0x6d43000b, 0x99bb01ce, 0xc0e3007c, 0x00000000}},  //   _nina, יזנט, мочк,
  { {0x6d4b354e, 0x7d1a039a, 0x3f87014a, 0x00000000}},  //   _auga, vots, gunu_,
  { {0x6d4b037e, 0x6447008d, 0x6d43021e, 0x00000000}},  //   _buga, _zgji, _aina,
  { {0x6d4b0129, 0x6d432ce2, 0x7d1a0288, 0x00000000}},  //   _cuga, _bina, tots,
  { {0x6d43005f, 0x332601d5, 0x7d08010f, 0x00000000}},  //   _cina, llox_, unds,
  { {0x6d59001f, 0x7c230016, 0x7d1a006c, 0x00000000}},  //   _etwa, _cynr, rots,
  { {0x2eed01bf, 0x6d4305ed, 0x6f1b00f4, 0x00000000}},  //   chef_, _eina, couc,
  { {0x5a44007e, 0x6d4b1640, 0xdd8f0025, 0x00000000}},  //   дэра, _guga, _لون_,
  { {0x6d43006a, 0xfaff0116, 0x6f0015dc, 0x00000000}},  //   _gina, sië_, limc,
  { {0x466b1281, 0x6d4b0fa5, 0xd66b00ec, 0x00000000}},  //   ирам_, _zuga, ијал_,
  { {0x6d43000b, 0x497518ea, 0xdb040190, 0x00000000}},  //   _zina, _елис, _asnæ,
  { {0x3f87005d, 0x612d0048, 0x6d4b002b, 0x00000000}},  // [b450] zunu_, húla, _xuga,
  { {0xb9a4026c, 0x6d430288, 0x3f87026d, 0x00000000}},  //   _کمیٹ, _xina, yunu_,
  { {0x14190054, 0xa5bb0010, 0x612400f6, 0x00000000}},  //   حياة_, _azót, còli,
  { {0x994801ef, 0x00000000, 0x00000000, 0x00000000}},  //   _دلیل_,   ,   ,
  { {0x6f1b013e, 0xdce9016c, 0x00000000, 0x00000000}},  //   vouc, zređ,   ,
  { {0x6d4b00e5, 0x463a00a3, 0x3f870095, 0x00000000}},  //   _ruga, _לערע, tunu_,
  { {0x6d430207, 0x33260ace, 0x6d4b354f, 0x00000000}},  //   _rina, blox_, _suga,
  { {0x6d43006a, 0x3f87014a, 0x5334007c, 0x00000000}},  //   _sina, runu_, _жест,
  { {0x6f093550, 0x6d431084, 0x26d901aa, 0x00000000}},  //   rnec, _pina, _moso_,
  { {0xa3df02d2, 0x6f0900c4, 0x6f1b0f8e, 0x00000000}},  //   _तथा_, snec, souc,
  { {0x6d433551, 0x6f000ce4, 0xf989071c, 0x00000000}},  //   _vina, bimc, _תר_,
  { {0x6d4b1b39, 0x26d9027b, 0xfeb8006d, 0x00000000}},  //   _tuga, _noso_, _وانت_,
  { {0x6d43006a, 0xdc3c0089, 0x44260082, 0x00000000}},  //   _tina, kšķi, ́o_,
  { {0xe8e10011, 0x6b880c95, 0x61240129, 0x00000000}},  //   _đợt_, budg, tòli,
  { {0x3f77001a, 0xb8e4007d, 0x5fbd006e, 0x00000000}},  //   nău_, _एफ_, ्मिल,
  { {0x3f510011, 0x9c7c01ca, 0x00000000, 0x00000000}},  //   _máu_, nkčn,   ,
  { {0xe5a331c9, 0x00000000, 0x00000000, 0x00000000}},  // [b460] нити,   ,   ,
  { {0xe5230081, 0x7d0100c4, 0x993400a1, 0x00000000}},  //   едуп, nils, _آہست,
  { {0xa5bb0010, 0x68e106d4, 0x26d9004a, 0x00000000}},  //   _szót, ölde, _foso_,
  { {0x26d900f6, 0x7d010190, 0x8b560049, 0x00000000}},  //   _goso_, hils, ליעס_,
  { {0x7d010039, 0xa6db000c, 0x399608c8, 0x00000000}},  //   kils, _miðl, næs_,
  { {0x3f510082, 0x612d1445, 0x26d900e5, 0x00000000}},  //   _báu_, túla, _zoso_,
  { {0x03a304b6, 0x3f510082, 0x6f000095, 0x00000000}},  //   _пиро, _cáu_, timc,
  { {0xc7b300b6, 0x04430088, 0x64620036, 0x00000000}},  //   תבה_, _чесн, świę,
  { {0x2167012b, 0x612d29de, 0x00000000, 0x00000000}},  //   _нити_, súla,   ,
  { {0x61e20b3d, 0xa17700a0, 0x7d012c50, 0x00000000}},  //   myol, _מעמד_, gils,
  { {0x60c80030, 0x3f77001a, 0x61e20284, 0x00000000}},  //   _indm, cău_, lyol,
  { {0x77750009, 0x60da0781, 0x9f0402fd, 0x00000000}},  //   vszx, _hotm, _کوچو,
  { {0x61e23552, 0x7d01001e, 0xa3b3007d, 0x00000000}},  //   nyol, bils, _जैन_,
  { {0x7d5700b6, 0x26d906d2, 0x00000000, 0x00000000}},  //   _ציוד_, _soso_,   ,
  { {0xb8f5013d, 0x26d93553, 0x57a40072, 0x00000000}},  //   _सच_, _poso_, ншта,
  { {0xf77000f3, 0xd6d801ee, 0x6ab60288, 0x00000000}},  //   طاف_, пту_, _gayf,
  { {0xf6500a4f, 0x7aed0058, 0x3f770035, 0x00000000}},  // [b470] ائف_, _ilat, zău_,
  { {0x60da0146, 0x61e2014a, 0x7aed01c3, 0x00000000}},  //   _notm, dyol, _hlat,
  { {0x9295007e, 0x00000000, 0x00000000, 0x00000000}},  //   даец,   ,   ,
  { {0x2903021e, 0x60c80004, 0x629e0047, 0x00000000}},  //   lija_, _andm, őpon,
  { {0x3f5114ab, 0x60da2ba6, 0x20d50088, 0x00000000}},  //   _sáu_, _botm, дійс,
  { {0x290301d9, 0x7aed1d90, 0x60da0087, 0x00000000}},  //   nija_, _llat, _cotm,
  { {0x7d0100ca, 0x7aed002d, 0x7ae6000c, 0x00000000}},  //   vils, _olat, ykkt,
  { {0x29030089, 0x443100d9, 0x00000000, 0x00000000}},  //   hija_, _izz_,   ,
  { {0x7d010030, 0x6ab602d4, 0x00000000, 0x00000000}},  //   tils, _rayf,   ,
  { {0x6ab6011f, 0x7aed3554, 0x290300ee, 0x00000000}},  //   _sayf, _alat, jija_,
  { {0x7d010279, 0xa3b6013d, 0x2d841965, 0x00000000}},  //   rils, जिए_, arme_,
  { {0x7aed0035, 0x7d012d33, 0x68fe0022, 0x00000000}},  //   _clat, sils, _smpd,
  { {0x7aed0036, 0x80b4013d, 0x82760049, 0x00000000}},  //   _dlat, _इसमे, וערע_,
  { {0x7aed3555, 0xdcfb0089, 0xfc050081, 0x00000000}},  //   _elat, bruā, _опло,
  { {0x7aed03fa, 0xd9430069, 0x6ab6005d, 0x00000000}},  //   _flat, тери, _tayf,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xcb1300b6, 0x2903012b, 0xe57a2546, 0x00000000}},  // [b480] _שלח_, bija_, юза_,
  { {0x61e200e7, 0x00000000, 0x00000000, 0x00000000}},  //   vyol,   ,   ,
  { {0xa6db000c, 0x00000000, 0x00000000, 0x00000000}},  //   _miðj,   ,   ,
  { {0x05000055, 0x60da0ac7, 0x2bb00164, 0x00000000}},  //   ্তের_, _sotm, _जनसा,
  { {0x443100d9, 0x00000000, 0x00000000, 0x00000000}},  //   _ezz_,   ,   ,
  { {0x61e2019a, 0xd259000a, 0xd130006d, 0x00000000}},  //   ryol, _efņ_, دمت_,
  { {0x61e23556, 0x00000000, 0x00000000, 0x00000000}},  //   syol,   ,   ,
  { {0x29030209, 0x3f802198, 0x877b0049, 0x00000000}},  //   zija_, čiu_, קאפי,
  { {0x64590046, 0xa3b6007d, 0x60da3557, 0x00000000}},  //   świe, जिक_, _totm,
  { {0x7aed0363, 0x290301d5, 0xe05601b2, 0x00000000}},  //   _slat, xija_, _غیبت_,
  { {0x29030213, 0xa2c30061, 0xaa7b0062, 0x00000000}},  //   vija_, ळाच्, ským,
  { {0x8c3c014a, 0x00000000, 0x00000000, 0x00000000}},  //   neği,   ,   ,
  { {0xf2d3007b, 0x7aed016e, 0x7ce400f6, 0x00000000}},  //   דער_, _vlat, _lòri,
  { {0xa6db000c, 0x3cf70025, 0x00000000, 0x00000000}},  //   _viðm, _يعود_,   ,
  { {0xd6db0242, 0x3cf90065, 0x7aed004a, 0x00000000}},  //   ота_, ësve_, _tlat,
  { {0x7aed006c, 0x2cac0016, 0x3b120023, 0x00000000}},  //   _ulat, ledd_, _gjyq_,
  { {0x2cac018e, 0xa53501ee, 0x00000000, 0x00000000}},  // [b490] oedd_, енач,   ,
  { {0x2cac018e, 0x29030023, 0x4431004a, 0x00000000}},  //   nedd_, qija_, _pzz_,
  { {0xd37b0920, 0x00000000, 0x00000000, 0x00000000}},  //   юча_,   ,   ,
  { {0x2cac018e, 0x7ce400f6, 0x00000000, 0x00000000}},  //   hedd_, _dòri,   ,
  { {0x865a00b6, 0x2169013b, 0x26cb0022, 0x00000000}},  //   _מדרי, чили_, _inco_,
  { {0x2cac0056, 0x00000000, 0x00000000, 0x00000000}},  //   jedd_,   ,   ,
  { {0x8c3c014a, 0xdfd103ec, 0x2cac0016, 0x00000000}},  //   beği, ايع_, dedd_,
  { {0x8c3c011f, 0xb4db0129, 0x680e0010, 0x00000000}},  //   ceği, _guàr, lődé,
  { {0x2cac0016, 0x3a2900d4, 0x00000000, 0x00000000}},  //   fedd_, _nyap_,   ,
  { {0xdb0b010f, 0x2cac1e3d, 0x2b4900f6, 0x00000000}},  //   _erfü, gedd_, _aiac_,
  { {0xab2a31c9, 0x7ced002a, 0xe81f01f5, 0x00000000}},  //   зона_, _cúra, _मुला_,
  { {0xf4120049, 0x7ced0048, 0xdceb0066, 0x00000000}},  //   רפט_, _dúra, _oqgħ,
  { {0xc332019b, 0x3ead04fd, 0x2cac3558, 0x00000000}},  //   טוט_, meet_, bedd_,
  { {0xdce901a8, 0x3ead0dcd, 0x26cb0375, 0x00000000}},  //   dseć, leet_, _anco_,
  { {0x6b9a001c, 0x07a31fd9, 0x68e1000c, 0x00000000}},  //   cttg, ларн, ölda,
  { {0x3ead021e, 0x29010022, 0x224d0058, 0x00000000}},  //   neet_, _emha_, _ngek_,
  { {0xd5af00a1, 0x6ea10316, 0x6aa40045, 0x00000000}},  // [b4a0] یفہ_, क्यु, _ibif,
  { {0x3ead00b0, 0x05000044, 0x69c40203, 0x00000000}},  //   heet_, ্ত্র_, _irie,
  { {0x3ead003c, 0x66e6005e, 0xdb0409af, 0x00000000}},  //   keet_, _зона, _apné,
  { {0x69c43559, 0x3ead00b0, 0x00000000, 0x00000000}},  //   _krie, jeet_,   ,
  { {0x67260c64, 0x8c3c014a, 0xf1260259, 0x00000000}},  //   _ikkj, reği, нько,
  { {0x3ead0fd5, 0xab6801f3, 0x6564355a, 0x00000000}},  //   eeet_, _heżż, mpih,
  { {0x3ead01bb, 0x645c2264, 0x656400e0, 0x00000000}},  //   feet_, _ifri, lpih,
  { {0x2cac018e, 0x81af0044, 0x539b009b, 0x00000000}},  //   wedd_, _ওপর_, _מילו,
  { {0xcd060088, 0xdce2016c, 0x10a6004d, 0x00000000}},  //   ечни, _svođ, _пиан,
  { {0x559700bd, 0x6b9a001c, 0x9b5800ed, 0x00000000}},  //   עדיע_, tttg, миот_,
  { {0x69c404cb, 0x2cac024d, 0xe1ff000c, 0x00000000}},  //   _arie, redd_, _þór_,
  { {0xa6db000c, 0x290401aa, 0x2cac2eb3, 0x00000000}},  //   _viðk, èman_, sedd_,
  { {0xfce60081, 0x2b490027, 0x7fb3006b, 0x00000000}},  //   _подо, _viac_, _rəqə,
  { {0x69c42c42, 0x6aa40009, 0x00000000, 0x00000000}},  //   _drie, _ebif,   ,
  { {0x62800091, 0x69c40032, 0xdce204eb, 0x00000000}},  //   _odmo, _erie, _uvođ,
  { {0x645c1273, 0x69c40038, 0x6d4a0020, 0x00000000}},  //   _afri, _frie, _hifa,
  { {0x6d4a1926, 0x395200ab, 0x69c4191c, 0x00000000}},  // [b4b0] _kifa, _guys_, _grie,
  { {0x3f8e0020, 0x6abd05d5, 0x29010048, 0x00000000}},  //   kufu_, ldsf, _umha_,
  { {0xa6db000c, 0x6d4a0020, 0x6f020026, 0x00000000}},  //   _liði, _mifa, _omoc,
  { {0xf679007b, 0x6abd158f, 0x6d4a000c, 0x00000000}},  //   _קאָמ, ndsf, _lifa,
  { {0x645c0016, 0xf6e4007e, 0x7c2a0016, 0x00000000}},  //   _ffri, _сцэн, _lyfr,
  { {0x3ead0007, 0x672d0211, 0x91e2007c, 0x00000000}},  //   weet_, llaj, роше,
  { {0x02a7008b, 0x3ead0103, 0x6fb20025, 0x00000000}},  //   _прам, teet_, لموا,
  { {0x6d4a0697, 0xdce00089, 0x6abd0190, 0x00000000}},  //   _aifa, ksmē, jdsf,
  { {0x260703d7, 0x3ead00ab, 0xa6db000c, 0x00000000}},  //   _सेमी_, reet_, _viðh,
  { {0x2d832794, 0x82340054, 0x3ead0056, 0x00000000}},  //   čje_, _إرفا, seet_,
  { {0x7c2a12a7, 0x6d4a01a3, 0x672d0059, 0x00000000}},  //   _cyfr, _difa, klaj,
  { {0x69c416a4, 0x29110207, 0x7c2a0016, 0x00000000}},  //   _prie, enza_, _dyfr,
  { {0x69c401f3, 0x2d8d06d2, 0x00000000, 0x00000000}},  //   _qrie, quee_,   ,
  { {0x69c4049b, 0x7bc3016c, 0x6d4a1bb7, 0x00000000}},  //   _vrie, _trnu, _gifa,
  { {0x7c2a018e, 0xf092012e, 0x81d70044, 0x00000000}},  //   _gyfr, ינם_, ানি_,
  { {0x69c40027, 0x2911355b, 0x442a2cbd, 0x00000000}},  //   _trie, anza_, _ryb_,
  { {0x69c400d4, 0x7afd0065, 0x6d4a0045, 0x00000000}},  // [b4c0] _urie, ërte, _yifa,
  { {0x81d70055, 0x25b20343, 0x7ce404bd, 0x00000000}},  //   ানা_, rwyl_, _fòru,
  { {0xe29a008b, 0x25b20016, 0x672d2aaa, 0x00000000}},  //   дае_, swyl_, blaj,
  { {0x672d008e, 0x6d4601ca, 0x14170025, 0x00000000}},  //   claj, íkaz, خيمة_,
  { {0x64590046, 0x00000000, 0x00000000, 0x00000000}},  //   świa,   ,   ,
  { {0x6f0200b4, 0x7e6900d9, 0x01e10044, 0x00000000}},  //   _smoc, ebep, _মেহদ,
  { {0xdfd00054, 0xc29a003b, 0x00000000, 0x00000000}},  //   صية_, _отац_,   ,
  { {0x3f8e0020, 0x6d4a355c, 0x7bc101d6, 0x00000000}},  //   rufu_, _sifa, dvlu,
  { {0x3f9c12ac, 0x3f8e00e7, 0x6d4a007f, 0x00000000}},  //   stvu_, sufu_, _pifa,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d4a000b, 0x00000000, 0x00000000, 0x00000000}},  //   _vifa,   ,   ,
  { {0xb69b1138, 0x6f020ad0, 0x00000000, 0x00000000}},  //   _amân, _umoc,   ,
  { {0x6d4a1b3e, 0x6abd02e7, 0x00000000, 0x00000000}},  //   _tifa, rdsf,   ,
  { {0x3878219f, 0xac180242, 0xdb0b000c, 0x00000000}},  //   garr_, _полу_, _erfð,
  { {0xa6db000c, 0x799d0544, 0x00000000, 0x00000000}},  //   _miðv, stsw,   ,
  { {0x6609009f, 0x7d0800ca, 0x3878012d, 0x00000000}},  //   _þekk, lids, aarr_,
  { {0x06c50055, 0xd49b0140, 0x953900ed, 0x00000000}},  // [b4d0] _একদি, дре_, езат_,
  { {0x672d0329, 0x04f416e8, 0x38780203, 0x00000000}},  //   slaj, азую, carr_,
  { {0xd2510b03, 0xf99f0173, 0xd498005e, 0x00000000}},  //   منا_, ltè_, ърт_,
  { {0x6ef510fa, 0x7d08355d, 0xddc00006, 0x00000000}},  //   _kábe, hids, namų,
  { {0xf99f0263, 0x656f0016, 0x00000000, 0x00000000}},  //   ntè_, _uwch,   ,
  { {0xf07500a1, 0x3ea61876, 0x6e2b0016, 0x00000000}},  //   ایاں_, _abot_, _rygb,
  { {0x3f580181, 0x4ac30061, 0x63b80030, 0x00000000}},  //   _céu_, षयाव, ævnt,
  { {0xf83800b6, 0xf99f0263, 0x3f580129, 0x00000000}},  //   כנות_, ktè_, _déu_,
  { {0x7e6901a2, 0x3dc60133, 0x00000000, 0x00000000}},  //   rbep, _crow_,   ,
  { {0xee36008b, 0x3dc60022, 0x7bc10116, 0x00000000}},  //   ыны_, _drow_, tvlu,
  { {0xfc050264, 0x67241519, 0x00000000, 0x00000000}},  //   упно, yoij,   ,
  { {0x9407005f, 0x00000000, 0x00000000, 0x00000000}},  //   ünə_,   ,   ,
  { {0x6f090036, 0x3878150e, 0x3dc600ab, 0x00000000}},  //   miec, tarr_, _grow_,
  { {0x6f09001e, 0xa6db000c, 0x3ebd041d, 0x00000000}},  //   liec, _miðu, _hawt_,
  { {0x9d1a00b3, 0xa6db000c, 0xcc2400a1, 0x00000000}},  //   _אוסט, _liðu, _پروٹ,
  { {0x6f093221, 0x3ebf355e, 0x6d4101ee, 0x00000000}},  //   niec, ndut_, lmla,
  { {0xa6db009f, 0x6d4101d6, 0x2d9f355f, 0x00000000}},  // [b4e0] _niðu, omla, ntue_,
  { {0x690900ca, 0x7cf600e5, 0x00000000, 0x00000000}},  //   lžen, _gârd,   ,
  { {0x389b007b, 0x6f090a62, 0xb89b0097, 0x00000000}},  //   _איינ, kiec, _אביש,
  { {0x290a014a, 0x7cf6001a, 0x3f5800c4, 0x00000000}},  //   liba_, _târg, _réu_,
  { {0xc05a01fb, 0x2813007a, 0x3f58009f, 0x00000000}},  //   ній_, _نویس, _séu_,
  { {0xe5a3003b, 0x290a01c5, 0x26c03560, 0x00000000}},  //   _ћири, niba_, ldio_,
  { {0x7d080030, 0x6d4110c1, 0xa857009b, 0x00000000}},  //   vids, dmla, ניקה_,
  { {0x2d821501, 0x81ac0044, 0x443800ca, 0x00000000}},  //   škem_, গিব_, _izr_,
  { {0x25a006c0, 0x7d0803bd, 0x6909016c, 0x00000000}},  //   ntil_, tids, džen,
  { {0x8f7601fb, 0xdce90027, 0x00000000, 0x00000000}},  //   _буді, ateľ,   ,
  { {0x6f093561, 0x7d0805ad, 0x290a01d6, 0x00000000}},  //   biec, rids, diba_,
  { {0x6f090036, 0x7ce400d4, 0xf99f0026, 0x00000000}},  //   ciec, _còrr, ttè_,
  { {0x7d080611, 0x26c0018e, 0x588700a5, 0x00000000}},  //   pids, ddio_, лыва,
  { {0x7faa005f, 0xac970054, 0x5d830054, 0x00000000}},  //   _təqd, _منها_, _الول,
  { {0xd7f80057, 0xf99f2965, 0x00000000, 0x00000000}},  //   гут_, stè_,   ,
  { {0x7c380295, 0xa4ff0309, 0x00000000, 0x00000000}},  //   _izvr, ोच्च_,   ,
  { {0x290a2db6, 0x00000000, 0x00000000, 0x00000000}},  // [b4f0] biba_,   ,   ,
  { {0x290a008e, 0x753c0036, 0x6f090036, 0x00000000}},  //   ciba_, _chrz, ziec,
  { {0x3255007e, 0x00000000, 0x00000000, 0x00000000}},  //   авер,   ,   ,
  { {0xd6db222e, 0x6595008b, 0xb7da0104, 0x00000000}},  //   _что_, _каму, _סקרי,
  { {0x25a00efe, 0x8c080044, 0x6f090253, 0x00000000}},  //   ctil_, _রুমন_, viec,
  { {0x6f090046, 0xa6db000c, 0xc05b0088, 0x00000000}},  //   wiec, _viðu, хід_,
  { {0x6f09001e, 0x00000000, 0x00000000, 0x00000000}},  //   tiec,   ,   ,
  { {0x0d85012b, 0x290a0020, 0x2d9f3562, 0x00000000}},  //   алин, ziba_, ttue_,
  { {0xa1590264, 0x3ebf1825, 0x6f090253, 0x00000000}},  //   _разу_, rdut_, riec,
  { {0x6f0912a7, 0x2d9f060b, 0xa5bb0325, 0x00000000}},  //   siec, rtue_, _exóg,
  { {0x6f09001e, 0x6d41145c, 0xd0110355, 0x00000000}},  //   piec, rmla, _بلا_,
  { {0x1f5a009b, 0x690900b9, 0xa6db000c, 0x00000000}},  //   _סדנא, užen, _miðs,
  { {0x290a30ed, 0x25a00161, 0x690905d2, 0x00000000}},  //   tiba_, xtil_, ržen,
  { {0x2ca70011, 0x7e7b0127, 0xa9670751, 0x00000000}},  //   _ubnd_, laup, рира_,
  { {0x290a19bb, 0x61eb000c, 0x2f1a0089, 0x00000000}},  //   riba_, hygl, līga_,
  { {0x26c00207, 0x25a000ea, 0x09e610f2, 0x00000000}},  //   udio_, ttil_, _воин,
  { {0x6d5b1e5a, 0x2f1a0089, 0x00000000, 0x00000000}},  // [b500] nqua, nīga_,   ,
  { {0x25a00030, 0x7ae417f9, 0xb97b0104, 0x00000000}},  //   rtil_, _hoit, _שניי,
  { {0x7e7b021e, 0x7ae400b0, 0xb4d60061, 0x00000000}},  //   kaup, _koit, _ाची_,
  { {0x82a6008b, 0x7ae400b0, 0x877b01ce, 0x00000000}},  //   радж, _joit, _באטי,
  { {0x44260046, 0x7ae43563, 0xe297017a, 0x00000000}},  //   ło_, _moit, рач_,
  { {0xb1140055, 0x7af60016, 0x6b5e0089, 0x00000000}},  //   িত্ব_, _llyt, _līga,
  { {0xd00f006d, 0xa50700ed, 0x4fb30025, 0x00000000}},  //   وله_, _тера_, قصير,
  { {0x7ae43564, 0x7e7b10c9, 0x3da6007e, 0x00000000}},  //   _noit, gaup, ароб,
  { {0x2d8d00ab, 0x50b60088, 0x00000000, 0x00000000}},  //   gree_, _всеу,   ,
  { {0x7af60006, 0x7cf60035, 0xc19b009b, 0x00000000}},  //   _alyt, _sârb, _בשמי,
  { {0xdeef008b, 0x7ae400f4, 0x2d8d0026, 0x00000000}},  //   _ды_, _boit, aree_,
  { {0x7ae4002a, 0x6da601fb, 0x7ce40045, 0x00000000}},  //   _coit, _вида, _eòrp,
  { {0x7ae40032, 0x4efb00a3, 0x7cf60035, 0x00000000}},  //   _doit, _בלאג, _cârc,
  { {0xa6db000c, 0x7af604a5, 0x6abf002b, 0x00000000}},  //   _niðr, _elyt, _waqf,
  { {0x9a871561, 0x7c380091, 0x7d1d0010, 0x00000000}},  //   _купл, _uzvr, ésse,
  { {0x31a001aa, 0x7ae4002d, 0x00000000, 0x00000000}},  //   kòz_, _goit,   ,
  { {0x63ae0022, 0xc6390088, 0x00000000, 0x00000000}},  // [b510] _apbn, упає_,   ,
  { {0x629b0198, 0x04670264, 0x612d16b2, 0x00000000}},  //   _scuo, ртам, núlt,
  { {0xd6d10054, 0x6136001a, 0x6ef50010, 0x00000000}},  //   _فقد_, tâln, _lába,
  { {0xa6db009f, 0x6d5b0082, 0xc6a72180, 0x00000000}},  //   _viðs, yqua, _трои,
  { {0x68e5021e, 0x80a50044, 0xf9940049, 0x00000000}},  //   _kohd, _গোষ্, ַרק_,
  { {0x61eb0016, 0x68e500b0, 0x92d70044, 0x00000000}},  //   rygl, _johd, িসে_,
  { {0x7e7b0d90, 0x92030089, 0x68e50145, 0x00000000}},  //   taup, _šādu, _mohd,
  { {0x2d8d0007, 0x2d95007c, 0x381800b3, 0x00000000}},  //   tree_, брос, יקום_,
  { {0x6b5e001e, 0x7e7b1a19, 0x4d650184, 0x00000000}},  //   _rīga, raup, љков,
  { {0x7ae4021e, 0x6d5b00f4, 0x62990007, 0x00000000}},  //   _soit, rqua, lgwo,
  { {0x6d5b0207, 0x7ae400f4, 0x6909010a, 0x00000000}},  //   squa, _poit, ržel,
  { {0x60c1154f, 0xdce00089, 0xa96a003b, 0x00000000}},  //   _halm, rpmā, лима_,
  { {0x7ae402af, 0x333f01d5, 0x60c13565, 0x00000000}},  //   _voit, _mhux_, _kalm,
  { {0xb4d60061, 0xeb990478, 0x00000000, 0x00000000}},  //   _ाचे_, _бик_,   ,
  { {0xbb850054, 0x60c10073, 0x6d59006a, 0x00000000}},  //   _البي, _malm, _huwa,
  { {0x6d59000b, 0xaa7b000c, 0xcaf600a6, 0x00000000}},  //   _kuwa, skýr, _دستب,
  { {0xe73700ed, 0x7faa005f, 0x629902c2, 0x00000000}},  // [b520] сет_, _məqa, dgwo,
  { {0x6d5900e7, 0x00000000, 0x00000000, 0x00000000}},  //   _muwa,   ,   ,
  { {0xcc7a0049, 0x6d591ecd, 0x8ca9013d, 0x00000000}},  //   רװער, _luwa, ज्यो,
  { {0x64550263, 0x91860025, 0x60c101c3, 0x00000000}},  //   _egzi, مجتم, _aalm,
  { {0x26c20091, 0x60c10982, 0x6d590697, 0x00000000}},  //   _iako_, _balm, _nuwa,
  { {0xa50a0200, 0x60c100f4, 0x8637009b, 0x00000000}},  //   _сега_, _calm, _לרכב_,
  { {0x6ef532be, 0x26c201d9, 0x60c1016e, 0x00000000}},  //   _sába, _kako_, _dalm,
  { {0x26c23566, 0x6d59006a, 0x232a00e2, 0x00000000}},  //   _jako_, _buwa, _соби_,
  { {0x2dda0025, 0xbd870379, 0xa2d50316, 0x00000000}},  //   ابعة_, منين_, णार्,
  { {0x26c20020, 0x2d8a0235, 0x6d593567, 0x00000000}},  //   _lako_, čbe_, _duwa,
  { {0x68e50240, 0x7afd0065, 0x09e60044, 0x00000000}},  //   _rohd, ërto, _পেলা,
  { {0x26c2011c, 0x2b40009d, 0x00000000, 0x00000000}},  //   _nako_, _chic_,   ,
  { {0x6d59011c, 0x13b10044, 0x68e500b0, 0x00000000}},  //   _guwa, ছিয়, _pohd,
  { {0xa2d5001c, 0x2ee60007, 0x93f80061, 0x00000000}},  //   णाऱ्, _hoof_, ंनाच_,
  { {0x6e3c0163, 0x78b50065, 0x2f1a0089, 0x00000000}},  //   ərba, rezv, nīgo_,
  { {0xceb900b9, 0xdce00089, 0x2c4e006b, 0x00000000}},  //   toři_, ksmī, məd_,
  { {0x26c20e6a, 0x26c700b9, 0x746b09da, 0x00000000}},  // [b530] _dako_, ěno_, грев_,
  { {0xdce2040d, 0xe415007e, 0x2ee601d6, 0x00000000}},  //   _otoč, одзь, _loof_,
  { {0x2c4e006b, 0xaadd01f5, 0x00000000, 0x00000000}},  //   nəd_, यापक,   ,
  { {0x26c20032, 0x69cd03e1, 0x81bd0044, 0x00000000}},  //   _gako_, _krae, ইমস_,
  { {0x99480123, 0x7faa006b, 0x00000000, 0x00000000}},  //   _خلیل_, _rəqa,   ,
  { {0x60c1005f, 0x26c20020, 0x6d590020, 0x00000000}},  //   _qalm, _zako_, _ruwa,
  { {0x60c1044e, 0x26c2000b, 0xfe57026c, 0x00000000}},  //   _valm, _yako_, میاب_,
  { {0x6d59011c, 0xb2753568, 0xa3ae01f5, 0x00000000}},  //   _puwa, _флаш, _कहत_,
  { {0x60c10051, 0x63a50300, 0x30a720d2, 0x00000000}},  //   _talm, lthn, _грев,
  { {0x3b850264, 0x5ba9003b, 0x6aad3569, 0x00000000}},  //   олог, аком_, _abaf,
  { {0x2f1a0089, 0x63a50009, 0x7faa006b, 0x00000000}},  //   cīgo_, nthn, _təqa,
  { {0x2b83005f, 0x63a5002a, 0x6d5909bd, 0x00000000}},  //   rıc_, ithn, _tuwa,
  { {0xabd7026c, 0x6f0b0d12, 0x26c2002d, 0x00000000}},  //   _گزشت, _imgc, _rako_,
  { {0x672f0036, 0x26c20006, 0x69cd0016, 0x00000000}},  //   _akcj, _sako_, _drae,
  { {0x62890023, 0x69cd1a9f, 0x00000000, 0x00000000}},  //   _odeo, _erae,   ,
  { {0x7afd001f, 0x1b180044, 0x62890048, 0x00000000}},  //   chst, _ধীরে_, _ndeo,
  { {0x69cd00d4, 0xceb200a0, 0xf50a0745, 0x00000000}},  // [b540] _grae, וין_, анал_,
  { {0x26c2000b, 0xe57700c2, 0x62890258, 0x00000000}},  //   _wako_, юзу_, _adeo,
  { {0x26c201d9, 0x66e6025f, 0x6efc356a, 0x00000000}},  //   _tako_, _дона, _hébe,
  { {0x657b0048, 0x81b30044, 0x8c1a009b, 0x00000000}},  //   úchó, টিন_, בועי,
  { {0x63a5002a, 0x2ee60aba, 0x2c4e006b, 0x00000000}},  //   athn, _roof_, zəd_,
  { {0xc5f300b6, 0x67360052, 0x00000000, 0x00000000}},  //   _חדש_, llyj,   ,
  { {0x4aca0316, 0x7cf600e5, 0xe8d90082, 0x00000000}},  //   ियाव, _bârn, _quỉ_,
  { {0x2f1a0089, 0xe29701a4, 0x7cf60035, 0x00000000}},  //   rīgo_, _мас_, _cârn,
  { {0xfd46007e, 0x00000000, 0x00000000, 0x00000000}},  //   жэнн,   ,   ,
  { {0xa3ae03d7, 0xbc4a0407, 0x6aad0026, 0x00000000}},  //   _कहा_, ичне_, _sbaf,
  { {0x6ef507fd, 0x656d0032, 0xdce211af, 0x00000000}},  //   _gábo, zpah, _utoč,
  { {0xeb0701fb, 0x69cd356b, 0x7f19007e, 0x00000000}},  //   ічно, _prae, _лічу_,
  { {0xad5a007c, 0x9e650014, 0x00000000, 0x00000000}},  //   _трех_, _رانن,   ,
  { {0x69cd0007, 0xd90f00a6, 0x63a50016, 0x00000000}},  //   _vrae, ئید_, ythn,
  { {0x6d4804f2, 0x36d502ea, 0x00000000, 0x00000000}},  //   mmda, повр,   ,
  { {0x69cd356c, 0x6d4800f8, 0x8b24003b, 0x00000000}},  //   _trae, lmda, _одје,
  { {0x61e400b0, 0x00000000, 0x00000000, 0x00000000}},  // [b550] äill,   ,   ,
  { {0x2d8400d4, 0x88830014, 0x81e00044, 0x00000000}},  //   isme_, _زیرن, দনা_,
  { {0x29110020, 0x68e1000c, 0x7d1a0032, 0x00000000}},  //   miza_, öldu, ints,
  { {0x2911356d, 0x63a5018e, 0x2d840089, 0x00000000}},  //   liza_, rthn, ksme_,
  { {0x81b30044, 0x6d48006b, 0x2d84013e, 0x00000000}},  //   টিভ_, kmda, jsme_,
  { {0xdcfb0089, 0x672d0052, 0x00000000, 0x00000000}},  //   ksuā, loaj,   ,
  { {0xdce9002b, 0x3cf00061, 0x00000000, 0x00000000}},  //   speċ, ेसने_,   ,
  { {0x2d9501be, 0x7f42356e, 0x7d1a0471, 0x00000000}},  //   прос, _choq, ents,
  { {0xfaff0065, 0x2911356f, 0x00000000, 0x00000000}},  //   dhë_, kiza_,   ,
  { {0x6ef509ee, 0xeb99012b, 0x29110020, 0x00000000}},  //   _tábo, био_, jiza_,
  { {0xca29019b, 0xc104023c, 0x2d841de2, 0x00000000}},  //   _עם_, _تولي, asme_,
  { {0xdb040030, 0x5e590025, 0x00000000, 0x00000000}},  //   _opnå, _الإس_,   ,
  { {0x29113570, 0x00000000, 0x00000000, 0x00000000}},  //   fiza_,   ,   ,
  { {0x29110020, 0x18673571, 0xccc40088, 0x00000000}},  //   giza_, зари_, _обій,
  { {0x7faa005f, 0x00000000, 0x00000000, 0x00000000}},  //   _nəql,   ,   ,
  { {0x05660057, 0x6f1b1a9a, 0x4b7a0049, 0x00000000}},  //   зван, nnuc, _פאפו,
  { {0x29110061, 0x9c7c089f, 0x8afb009b, 0x00000000}},  // [b560] biza_, ljča, _להקי,
  { {0x29111bf1, 0x00000000, 0x00000000, 0x00000000}},  //   ciza_,   ,   ,
  { {0x9c7c0e3d, 0xd336007e, 0x00000000, 0x00000000}},  //   njča, пэды,   ,
  { {0xe29a0839, 0x2d843572, 0x00000000, 0x00000000}},  //   сад_, ysme_,   ,
  { {0x5ee10055, 0x7cf60035, 0x6d4808e6, 0x00000000}},  //   বসাই, _bârl, ymda,
  { {0x7f42008d, 0x66040020, 0xfaff0023, 0x00000000}},  //   _shoq, mzik, zhë_,
  { {0xd0100054, 0x6ef51430, 0x7f420068, 0x00000000}},  //   ضلة_, _tábl, _phoq,
  { {0xe2f8026c, 0x29110066, 0x6f1b3573, 0x00000000}},  //   _بورڈ_, ziza_, gnuc,
  { {0x29110009, 0x27f10036, 0x2cae0270, 0x00000000}},  //   yiza_, zyzn_, _pbfd_,
  { {0x7d1a0288, 0x6d431218, 0x69cb00fa, 0x00000000}},  //   unts, _chna, _ágei,
  { {0xfaff008d, 0x29110232, 0x2d840087, 0x00000000}},  //   thë_, viza_, ssme_,
  { {0xf773026c, 0x23be00b9, 0x29113574, 0x00000000}},  //   ہار_, _můj_, wiza_,
  { {0x7ced002a, 0x29110020, 0xdd8f002c, 0x00000000}},  //   _cúrs, tiza_, _مون_,
  { {0xfaff008d, 0x7bdc006c, 0xc2fa0044, 0x00000000}},  //   shë_, ärus, েকটি_,
  { {0x29110311, 0x3d2b00a1, 0x672d00d4, 0x00000000}},  //   riza_, _اتنی_, toaj,
  { {0x70b9007d, 0xb8f4006e, 0x8c1b0104, 0x00000000}},  //   _इस्ल, _सो_, _לווי,
  { {0xdce90428, 0x29111b6f, 0x68e11faf, 0x00000000}},  // [b570] zpeč, piza_, ölds,
  { {0xe9450167, 0x28de0164, 0x672d00e7, 0x00000000}},  //   _تربی, माणि, soaj,
  { {0xccf3007b, 0xc7ab0025, 0xd25100a1, 0x00000000}},  //   עכע_, _ادخل_, چنا_,
  { {0xd2510a4f, 0x7afd0065, 0xa3ae006e, 0x00000000}},  //   ننا_, ërth, _कहर_,
  { {0xdd8600a1, 0x6f000051, 0x2d910036, 0x00000000}},  //   _جو_, dhmc, ązek_,
  { {0xc24401ff, 0xf770007a, 0x25a90039, 0x00000000}},  //   хнік, _جای_, mtal_,
  { {0x25a900f8, 0x7cf600e5, 0x00000000, 0x00000000}},  //   ltal_, _cârm,   ,
  { {0x26c9000b, 0x6f1b016c, 0x25a92ea9, 0x00000000}},  //   ndao_, unuc, otal_,
  { {0x2cac0009, 0xa194007c, 0x00000000, 0x00000000}},  //   ffdd_, _патч,   ,
  { {0xab650264, 0xb11401ff, 0x2a692202, 0x00000000}},  //   мвол, _змуш, _afab_,
  { {0x1c4502d3, 0x7cff0007, 0x25a93575, 0x00000000}},  //   ьном, _nêre, htal_,
  { {0xc9aa00ed, 0x25a90145, 0x00000000, 0x00000000}},  //   овме_, ktal_,   ,
  { {0xdca50098, 0x00000000, 0x00000000, 0x00000000}},  //   _жали,   ,   ,
  { {0xa3ae0061, 0x7cff01c3, 0x6b9a3576, 0x00000000}},  //   _कहल_, _bêre, butg,
  { {0x07a30088, 0x25a900bb, 0x7cff01c3, 0x00000000}},  //   карн, etal_, _vêrd,
  { {0x6604002d, 0x25a900bb, 0xdcfb002b, 0x00000000}},  //   tzik, ftal_, ftuħ,
  { {0x25a90270, 0x54c609e6, 0x00000000, 0x00000000}},  // [b580] gtal_, мбаб,   ,
  { {0x26d9059f, 0x3f873577, 0xf53f0d32, 0x00000000}},  //   _enso_, ksnu_, _spår_,
  { {0x69c40066, 0x78bc00bb, 0x316d0032, 0x00000000}},  //   _hsie, merv, _atez_,
  { {0xf7730097, 0x69c43578, 0x7cf600e5, 0x00000000}},  //   _שקר_, _ksie, _cârj,
  { {0x8c110055, 0x7afd0065, 0x914a007c, 0x00000000}},  //   _সুমন_, ërti, очка_,
  { {0x7bc300ee, 0x69c40066, 0x2f1a0089, 0x00000000}},  //   _osnu, _msie, mīgi_,
  { {0x3ead01e3, 0x645c10f7, 0x2f1a0089, 0x00000000}},  //   ffet_, _igri, līgi_,
  { {0x78bc0725, 0x78a90091, 0x69c40036, 0x00000000}},  //   herv, đevi, _osie,
  { {0x44383579, 0x5d5400e3, 0x78bc1b17, 0x00000000}},  //   _hyr_, нкит, kerv,
  { {0x62800211, 0x6efc00f4, 0x443800ea, 0x00000000}},  //   _hemo, _déba, _kyr_,
  { {0x78bc0018, 0x69c40885, 0x628001ed, 0x00000000}},  //   derv, _asie, _kemo,
  { {0x6b9a0056, 0x00000000, 0x00000000, 0x00000000}},  //   rutg,   ,   ,
  { {0x5ea3026c, 0x81ac0044, 0x0d8317a4, 0x00000000}},  //   _شمول, গিক_, _алчн,
  { {0x645c008d, 0x78bc158f, 0x25a90039, 0x00000000}},  //   _ngri, gerv, vtal_,
  { {0x69090ebc, 0x60c80253, 0xe7330025, 0x00000000}},  //   džet, _madm, نصر_,
  { {0x25a90010, 0x6d580047, 0x60c8096b, 0x00000000}},  //   ttal_, _hiva, _ladm,
  { {0x7cff0343, 0x60da06b2, 0x6d5800b0, 0x00000000}},  // [b590] _wêre, _ontm, _kiva,
  { {0x4438030c, 0x3f9c0009, 0x6d5800e5, 0x00000000}},  //   _byr_, kuvu_, _jiva,
  { {0x25a92a92, 0x62800007, 0x443800df, 0x00000000}},  //   stal_, _bemo, _cyr_,
  { {0x443805b7, 0x7aed002d, 0x25a9013e, 0x00000000}},  //   _dyr_, _joat, ptal_,
  { {0xa0690b7a, 0x7aed16cc, 0x7d080006, 0x00000000}},  //   пала_, _moat, _kūrė,
  { {0x443801e3, 0x7aed135b, 0x6d580511, 0x00000000}},  //   _fyr_, _loat, _niva,
  { {0x6ef5357a, 0xa295008b, 0x6efc009d, 0x00000000}},  //   _hábi, _паві, _séba,
  { {0x628000c7, 0x6d58021e, 0x799d0022, 0x00000000}},  //   _gemo, _aiva, kusw,
  { {0x6d580059, 0x3ead1c29, 0x6abd2297, 0x00000000}},  //   _biva, rfet_, desf,
  { {0x3ead00d4, 0x6aa40052, 0x6201005a, 0x00000000}},  //   sfet_, _scif, ızlı,
  { {0x2903008d, 0x7c95007a, 0xa3c1013d, 0x00000000}},  //   dhja_, وشگا, ्टि_,
  { {0x78bc00d9, 0x7aed00ab, 0x00000000, 0x00000000}},  //   werv, _coat,   ,
  { {0x99d6026c, 0x799d00e7, 0x6e920f8b, 0x00000000}},  //   رتحا, gusw, _صلوا,
  { {0x6ef50051, 0xa3c10309, 0x6d580479, 0x00000000}},  //   _sábh, ्टा_, _giva,
  { {0x656f005b, 0x78bc0bc7, 0xfc64005e, 0x00000000}},  //   _atch, rerv, _ръчн,
  { {0xc4c6007a, 0x645c0016, 0x6abd00f6, 0x00000000}},  //   کترو, _sgri, cesf,
  { {0x443e357b, 0xf98a0025, 0x443813f7, 0x00000000}},  // [b5a0] _št_, _عندي_, _syr_,
  { {0x4aac024c, 0x2f1a001e, 0x628004cb, 0x00000000}},  //   ट्रव, rīgi_, _semo,
  { {0x6ef5002a, 0x60c805fa, 0x628004cb, 0x00000000}},  //   _tábh, _radm, _pemo,
  { {0x869a0057, 0x2228007a, 0xe363007c, 0x00000000}},  //   _этот_, وزشی_, укци,
  { {0x75350061, 0x62800211, 0x395a06ba, 0x00000000}},  //   _fkzz, _vemo, _kips_,
  { {0x7faa005f, 0x443810c5, 0xc0e30077, 0x00000000}},  //   _həqi, _tyr_, лочк,
  { {0x62801325, 0x443e0047, 0xa5230545, 0x00000000}},  //   _temo, _át_, _смрд,
  { {0x03d7009b, 0x6d58014a, 0x69090107, 0x00000000}},  //   _אולם_, _siva, nžer,
  { {0x7aed0035, 0x7ced004a, 0x6d58016e, 0x00000000}},  //   _roat, _púrp, _piva,
  { {0x81b30055, 0x395a0606, 0x00000000, 0x00000000}},  //   টিশ_, _nips_,   ,
  { {0x6d5811aa, 0x7aed000d, 0xa2d50061, 0x00000000}},  //   _viva, _poat, णाच्,
  { {0x81b30055, 0x7e6900bb, 0x141b0049, 0x00000000}},  //   টির_, ccep, לויב,
  { {0x6d580023, 0xdc12005d, 0x29030023, 0x00000000}},  //   _tiva, rşım, thja_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7aed000d, 0xed4d00a1, 0x7a490089, 0x00000000}},  //   _toat, _بھي_, _sūtī,
  { {0x29030065, 0xdc3b00b3, 0x00000000, 0x00000000}},  //   shja_, _מעור,   ,
  { {0x7faa006b, 0x7afd0065, 0x00000000, 0x00000000}},  // [b5b0] _dəqi, ërtu,   ,
  { {0x2f1a0089, 0xd7e7007e, 0x00000000, 0x00000000}},  //   mīgu_, _зімо,   ,
  { {0x2901357c, 0x2b490082, 0xd498007e, 0x00000000}},  //   _ilha_, _khac_, эрт_,
  { {0x7e690133, 0xf7760104, 0x395a0253, 0x00000000}},  //   xcep, _שערי_, _zips_,
  { {0x10a524dd, 0x2b490051, 0xf99f0026, 0x00000000}},  //   вилн, _mhac_, nuè_,
  { {0x6e390016, 0x25b901f3, 0xdddb0089, 0x00000000}},  //   _rywb, _ipsl_, jauš,
  { {0x7faa006b, 0x26cb0085, 0x00000000, 0x00000000}},  //   _yəqi, _kaco_,   ,
  { {0x26cb0007, 0x2b490011, 0x200700ca, 0x00000000}},  //   _jaco_, _nhac_, rzni_,
  { {0x26cb0c56, 0xf2d20049, 0x29010181, 0x00000000}},  //   _maco_, _דען_, _olha_,
  { {0x6b5e001e, 0x7e6906fa, 0xfc3f00b9, 0x00000000}},  //   _līgu, scep, řím_,
  { {0x4add0061, 0xab2a017a, 0xaadd0309, 0x00000000}},  //   यांव, дона_, यांक,
  { {0x395a01c3, 0x2b491e16, 0xf1b90087, 0x00000000}},  //   _sips_, _chac_, _kpš_,
  { {0xed4e1b70, 0x7faa006b, 0x395a357d, 0x00000000}},  //   _во_, _rəqi, _pips_,
  { {0x7c8700c0, 0xd94608d6, 0xabd50098, 0x00000000}},  //   _чуде, теги, _ациј,
  { {0x395a357e, 0xe73a17a4, 0x00000000, 0x00000000}},  //   _vips_, дев_,   ,
  { {0x07a3300e, 0xcf9200a0, 0x3ebf010f, 0x00000000}},  //   јатн, יטל_, neut_,
  { {0x6ab60009, 0x69090925, 0x24830023, 0x00000000}},  // [b5c0] _ibyf, ržer, _bejm_,
  { {0x3ebf357f, 0x00000000, 0x00000000, 0x00000000}},  //   heut_,   ,   ,
  { {0x29180091, 0x94060014, 0x7faa013f, 0x00000000}},  //   mira_, خواه, _təqi,
  { {0x69d6008d, 0x2918016e, 0x26cb0146, 0x00000000}},  //   _krye, lira_, _gaco_,
  { {0x6efc009d, 0x00000000, 0x00000000, 0x00000000}},  //   _débl,   ,   ,
  { {0x81b30055, 0x3ea6001a, 0x26c00851, 0x00000000}},  //   টিং_, _scot_, leio_,
  { {0x0fe00055, 0x73e3007c, 0x26cb004a, 0x00000000}},  //   বন্ধ, _корз, _yaco_,
  { {0x2918011c, 0xa3c102d2, 0x14e00061, 0x00000000}},  //   hira_, ्टर_, नावण,
  { {0x29182092, 0xf1aa007a, 0x1d34005e, 0x00000000}},  //   kira_, _تازه_, лния,
  { {0x6443208b, 0x29180f70, 0x26c000c4, 0x00000000}},  //   żnie, jira_, heio_,
  { {0x2918002d, 0x69d60173, 0x25a03580, 0x00000000}},  //   dira_, _arye, huil_,
  { {0x29180181, 0x7cff01c3, 0x2f1a01c5, 0x00000000}},  //   eira_, _vêra, tīgu_,
  { {0xc33300b6, 0x6f0200b5, 0x26cb00d4, 0x00000000}},  //   שור_, _iloc, _raco_,
  { {0x29180569, 0x26cb0285, 0x2f1a0089, 0x00000000}},  //   gira_, _saco_, rīgu_,
  { {0x6f023581, 0x195807d0, 0x26cb0efe, 0x00000000}},  //   _kloc, тары_, _paco_,
  { {0x25a00195, 0x37043582, 0x6ef50b33, 0x00000000}},  //   fuil_, ачув, _fábu,
  { {0x29180059, 0x2f1a0089, 0x69d6000a, 0x00000000}},  // [b5d0] bira_, līgs_, _grye,
  { {0x2918016c, 0x6f021d90, 0x7afd3583, 0x00000000}},  //   cira_, _lloc, lkst,
  { {0xf2b10044, 0x7afd01d6, 0x7d1d2560, 0x00000000}},  //   _ঘোষণ, okst, éssi,
  { {0x7afd1ec2, 0x26c000c4, 0x442a0203, 0x00000000}},  //   nkst, ceio_, _dxb_,
  { {0xf1a70679, 0xf62b0088, 0x442a3584, 0x00000000}},  //   трен, _ціни_, _exb_,
  { {0xa5da0049, 0x6f02001a, 0x00000000, 0x00000000}},  //   _אַלי, _aloc,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x29180091, 0x7afd00b5, 0xfe710025, 0x00000000}},  //   zira_, jkst, حدث_,
  { {0x6d4a002a, 0x291827a5, 0xdfd100a1, 0x00000000}},  //   _bhfa, yira_, _گيا_,
  { {0x6f02058b, 0x7afd0ebd, 0x00000000, 0x00000000}},  //   _eloc, ekst,   ,
  { {0x2918231b, 0xdfd11234, 0x00000000, 0x00000000}},  //   vira_, _ديا_,   ,
  { {0x6f020abe, 0x139a0049, 0x291816c3, 0x00000000}},  //   _gloc, עברע, wira_,
  { {0x7c2a04ce, 0x6b9a00d9, 0x00000000, 0x00000000}},  //   _exfr, artg,   ,
  { {0x6f022270, 0x7c2a3585, 0x2d8d012d, 0x00000000}},  //   _zloc, _fxfr, msee_,
  { {0x29182645, 0x31560049, 0x81e90044, 0x00000000}},  //   rira_, טישן_, মনি_,
  { {0x7afd05b4, 0xef1901d5, 0x7faa006b, 0x00000000}},  //   ckst, niż_, _təqv,
  { {0xb90a0055, 0x2d8d010f, 0x29180091, 0x00000000}},  // [b5e0] _মত_, nsee_, pira_,
  { {0x81e90044, 0x25a00112, 0x26c000c4, 0x00000000}},  //   মনা_, ruil_, seio_,
  { {0x1d160049, 0xdb020190, 0x00000000, 0x00000000}},  //   נקער_, rtlæ,   ,
  { {0x5c360049, 0x7cf60035, 0x65763586, 0x00000000}},  //   ארען_, _hârt, ppyh,
  { {0x25a0008e, 0x67240091, 0x2f1a01c5, 0x00000000}},  //   quil_, mnij, zīgs_,
  { {0x6f0200f8, 0x67240091, 0xf4870bb6, 0x00000000}},  //   _sloc, lnij, _مافی,
  { {0x6d4701d5, 0x6f020161, 0xf50316b6, 0x00000000}},  //   ċjal, _ploc, _узро,
  { {0x67240f68, 0x6d4a008d, 0x64430036, 0x00000000}},  //   nnij, _shfa, żnic,
  { {0x0caa06e1, 0xb226007e, 0x1ed70025, 0x00000000}},  //   нтни_, _смал, طبيب_,
  { {0x65661084, 0x2f1a01c5, 0x00000000, 0x00000000}},  //   _mukh, tīgs_,   ,
  { {0x5ea6026c, 0xdb0200f8, 0x00000000, 0x00000000}},  //   _ممال, ktlä,   ,
  { {0xe4570049, 0x2f1a0089, 0x67243587, 0x00000000}},  //   טייט_, rīgs_, jnij,
  { {0x67243588, 0xb69b0035, 0x00000000, 0x00000000}},  //   dnij, _blân,   ,
  { {0x7afd074d, 0x7cf600e5, 0x00000000, 0x00000000}},  //   skst, _cârt,   ,
  { {0xd6db0265, 0x7d1a00b0, 0xd7e4030d, 0x00000000}},  //   нта_, mits, біто,
  { {0x7d1a0004, 0xc8780279, 0x656604d4, 0x00000000}},  //   lits, ığa_, _bukh,
  { {0xd49b0679, 0xb4c2006e, 0xdb020007, 0x00000000}},  // [b5f0] ере_, ्यू_, kulê,
  { {0x7d1a03b6, 0x3f9c016c, 0x65660058, 0x00000000}},  //   nits, krvu_, _dukh,
  { {0x67243589, 0x7faa005f, 0x7e620258, 0x00000000}},  //   bnij, _məqs, _ogop,
  { {0x6724037e, 0x2d8d0190, 0x7d1a010e, 0x00000000}},  //   cnij, ysee_, hits,
  { {0xd49b01f9, 0x91e5007c, 0xef1901d5, 0x00000000}},  //   _прв_, роле, viż_,
  { {0x7e620197, 0x4f95358a, 0x00000000, 0x00000000}},  //   _agop, ариу,   ,
  { {0x7d1a33d1, 0x660d00bb, 0xb444007e, 0x00000000}},  //   dits, lzak, _гэтк,
  { {0x2d8d0ba4, 0x0e65007c, 0x6463014a, 0x00000000}},  //   tsee_, шкин, ştiğ,
  { {0x628b1892, 0x7bd80004, 0x660d0020, 0x00000000}},  //   mago, _arvu, nzak,
  { {0x628b1431, 0x67241279, 0x5f95005e, 0x00000000}},  //   lago, znij, _вижт,
  { {0x3b0a064b, 0x60c30c10, 0x8c45041f, 0x00000000}},  //   вено_, menm, рене,
  { {0x628b149a, 0x60c3011f, 0x81d80044, 0x00000000}},  //   nago, lenm, াহর_,
  { {0xfce50373, 0x7bca0211, 0x6ef5029d, 0x00000000}},  //   _воло, _esfu, _fábr,
  { {0x660d00b5, 0x7d1a0009, 0x6f0900c4, 0x00000000}},  //   dzak, cits, lhec,
  { {0x67240091, 0xc71600ed, 0x6566008a, 0x00000000}},  //   tnij, аќањ, _sukh,
  { {0x6f0902d5, 0x67240089, 0x60c301a2, 0x00000000}},  //   nhec, unij, henm,
  { {0x67240091, 0xa56800a1, 0x60c3046a, 0x00000000}},  // [b600] rnij, اشرے_, kenm,
  { {0xb4c2001c, 0x67240119, 0x6d41018e, 0x00000000}},  //   ्ये_, snij, nlla,
  { {0x6d4100f4, 0x672400ee, 0x845a0088, 0x00000000}},  //   illa, pnij, трат_,
  { {0x7d1a022b, 0x628b23f7, 0xe29a086c, 0x00000000}},  //   zits, gago, тад_,
  { {0x867b0104, 0x7d1a23f6, 0x00000000, 0x00000000}},  //   _ברכו, yits,   ,
  { {0x3f9c0521, 0x2fc70016, 0x60c301a2, 0x00000000}},  //   trvu_, fwng_, genm,
  { {0x628b358b, 0x7d1a044e, 0x7b160006, 0x00000000}},  //   bago, vits, ršuj,
  { {0xa85700b6, 0x6d410211, 0x00000000, 0x00000000}},  //   סיקה_, ella,   ,
  { {0x10a60088, 0xa0a6003b, 0xdb0201d6, 0x00000000}},  //   _визн, _вазд, pulê,
  { {0x6208005a, 0x61460478, 0x00000000, 0x00000000}},  //   ırlı, _теза,   ,
  { {0x9b5900ed, 0x14d90049, 0xe8d90011, 0x00000000}},  //   лиот_, אַרמ, _huệ_,
  { {0x6f0909fa, 0x6d41230b, 0x7d1a006c, 0x00000000}},  //   chec, alla, sits,
  { {0x7faa006b, 0x799d01d6, 0xfaff0023, 0x00000000}},  //   _təqs, ursw, rkë_,
  { {0x2905009f, 0x7cf6001a, 0x628b0dd6, 0x00000000}},  //   óla_, _vârs, zago,
  { {0x9b940879, 0xdb0b0030, 0x628b0010, 0x00000000}},  //   _البت, _opfø, yago,
  { {0x660d022b, 0x27ed0091, 0x60c3358c, 0x00000000}},  //   tzak, ćen_, zenm,
  { {0x628b0232, 0x60c30082, 0xd6d800e2, 0x00000000}},  // [b610] vago, yenm, јтс_,
  { {0x6efc358d, 0x660d358e, 0x69cd1de0, 0x00000000}},  //   _débi, rzak, _isae,
  { {0x660d0047, 0x60c301aa, 0xfc3f013e, 0x00000000}},  //   szak, venm, řív_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x628b04f3, 0x6d41358f, 0x60c31e49, 0x00000000}},  //   rago, ylla, tenm,
  { {0x628b011c, 0x2fc7005b, 0x80a80088, 0x00000000}},  //   sago, twng_, ивів_,
  { {0x628b011c, 0x60c3014a, 0xa2d80061, 0x00000000}},  //   pago, renm, _नोव्,
  { {0x60c30cba, 0x533400aa, 0xf99f01aa, 0x00000000}},  //   senm, _дест, krè_,
  { {0x20c70057, 0xc332052f, 0x6d410129, 0x00000000}},  //   _всег, _זון_, tlla,
  { {0xa5da0049, 0xf99f0197, 0x6f09004a, 0x00000000}},  //   אַטי, drè_, shec,
  { {0x63a5003f, 0x673d006c, 0x6d410016, 0x00000000}},  //   nuhn, _oksj, rlla,
  { {0x6d410ac7, 0xc8690049, 0x9f550816, 0x00000000}},  //   slla, _טן_, _увеч,
  { {0xf99f01aa, 0xdb023590, 0x4add0061, 0x00000000}},  //   grè_, nulé, याजव,
  { {0xcd76009b, 0xed440088, 0xa9671592, 0x00000000}},  //   _העסק_, _дніп, сира_,
  { {0x69cd0032, 0x66e6007c, 0x00000000, 0x00000000}},  //   _esae, бова,   ,
  { {0x753c241b, 0x96660a78, 0x49ca007c, 0x00000000}},  //   _skrz, скае, _блин_,
  { {0x98a602d3, 0x00000000, 0x00000000, 0x00000000}},  // [b620] _липе,   ,   ,
  { {0x88ca041f, 0x7af6004a, 0x673d21db, 0x00000000}},  //   _слов_, _hoyt, _eksj,
  { {0x63a504cb, 0x25b20df1, 0x7ae4086a, 0x00000000}},  //   guhn, styl_, _knit,
  { {0x82a6013a, 0x2d9f1f6e, 0x00000000, 0x00000000}},  //   садж, krue_,   ,
  { {0x61460893, 0xdce20091, 0xdb0200d2, 0x00000000}},  //   беда, _suoč, gulé,
  { {0x63a504cb, 0x69d90061, 0x291a0145, 0x00000000}},  //   buhn, मिती, _jmpa_,
  { {0x6f1900f6, 0x7ae4149f, 0x00000000, 0x00000000}},  //   _bmwc, _onit,   ,
  { {0xe8d90011, 0x3da60b81, 0x00000000, 0x00000000}},  //   _tuệ_, броб,   ,
  { {0xa206003b, 0xfe6f0076, 0xdb02009d, 0x00000000}},  //   _упад, ردي_, culé,
  { {0x7ae4002d, 0x6aad0197, 0xf99f01aa, 0x00000000}},  //   _anit, _scaf, vrè_,
  { {0x853b0097, 0x7af63591, 0x25a0008a, 0x00000000}},  //   רגיי, _boyt, hril_,
  { {0x291a0129, 0xf99f3592, 0x25a000ca, 0x00000000}},  //   _ampa_, trè_, kril_,
  { {0x4aaa024c, 0x2d9f3593, 0xaaaa01f5, 0x00000000}},  //   _कारव, crue_, _कारक,
  { {0x7ae400b0, 0xf99f0026, 0x25a012c9, 0x00000000}},  //   _enit, rrè_, dril_,
  { {0x28de0309, 0x00000000, 0x00000000, 0x00000000}},  //   माजि,   ,   ,
  { {0xf99f01aa, 0x7af600c4, 0x7ae400e0, 0x00000000}},  //   prè_, _goyt, _gnit,
  { {0x44f5003b, 0xddc90de5, 0x7a1c0089, 0x00000000}},  // [b630] опас, zbež, gātī,
  { {0x04670888, 0x63a50093, 0x00000000, 0x00000000}},  //   стам, tuhn,   ,
  { {0x645a3594, 0x25a0010e, 0x00000000, 0x00000000}},  //   _útil, aril_,   ,
  { {0xa29401fb, 0x63a50169, 0x25a0006c, 0x00000000}},  //   заці, ruhn, bril_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xaf993595, 0x29030eb6, 0xdb020010, 0x00000000}},  //   атих_, nkja_, rulé,
  { {0x2903000c, 0x4aaa0963, 0x00000000, 0x00000000}},  //   ikja_, _कालव,   ,
  { {0x2d950242, 0x4ad90061, 0xdb020068, 0x00000000}},  //   орос, _बोलव, pulé,
  { {0x29030c32, 0xdd8e006d, 0xa0c5023c, 0x00000000}},  //   kkja_, نوي_, _ويرو,
  { {0x2d9f1176, 0x7b24012d, 0xb65c0049, 0x00000000}},  //   rrue_, nđuv, נדזש,
  { {0xddc20036, 0x00000000, 0x00000000, 0x00000000}},  //   _czoł,   ,   ,
  { {0x6b9c004a, 0x68e50082, 0xbdf801b2, 0x00000000}},  //   árga, _anhd, _گرما_,
  { {0x7ae400b9, 0x68f70fcf, 0xa96a02dc, 0x00000000}},  //   _vnit, _boxd, рига_,
  { {0x6efc028c, 0x25a00035, 0x61f600ea, 0x00000000}},  //   _débu, vril_, øyli,
  { {0x46f60088, 0x00000000, 0x00000000, 0x00000000}},  //   очат,   ,   ,
  { {0x25a00253, 0x224d0087, 0x00000000, 0x00000000}},  //   tril_, _ozek_,   ,
  { {0x3cf00061, 0x236a0019, 0x24980145, 0x00000000}},  // [b640] ेसचे_, _subj_, _pdrm_,
  { {0x25a0029a, 0x81cf0044, 0x7a1c0089, 0x00000000}},  //   rril_, ষমা_, rātī,
  { {0xba290167, 0xb3760014, 0x25a0008a, 0x00000000}},  //   _نسیم_, زداش, sril_,
  { {0x645a3360, 0x3bba0049, 0x00000000, 0x00000000}},  //   _útim, ימעד,   ,
  { {0x68f7005f, 0x00000000, 0x00000000, 0x00000000}},  //   _yoxd,   ,   ,
  { {0xdfd0023c, 0x224d012d, 0xcf9a003b, 0x00000000}},  //   فيت_, _dzek_, аји_,
  { {0x224d0047, 0x28b2013d, 0x00000000, 0x00000000}},  //   _ezek_, _जानि,   ,
  { {0x644e0087, 0x63b301ca, 0x741300a1, 0x00000000}},  //   _izbi, žení, _کوہا,
  { {0x628200b5, 0xd1320647, 0x2903000c, 0x00000000}},  //   mboo, _قمر_, ykja_,
  { {0x62820270, 0x00000000, 0x00000000, 0x00000000}},  //   lboo,   ,   ,
  { {0x443100f6, 0x00000000, 0x00000000, 0x00000000}},  //   _xxz_,   ,   ,
  { {0x628200bb, 0x539b009b, 0x00000000, 0x00000000}},  //   nboo, סיכו,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x644e01cd, 0x6282086d, 0x00000000, 0x00000000}},  //   _ozbi, hboo,   ,
  { {0x368b012d, 0x2903021a, 0x62820133, 0x00000000}},  //   исан_, rkja_, kboo,
  { {0x442d0119, 0x8f9b00a0, 0x27030044, 0x00000000}},  //   _će_, יילי, রোনো_,
  { {0x95cb00ed, 0xc4cf0044, 0x00000000, 0x00000000}},  // [b650] шува_, রাসঙ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x62820168, 0x00000000, 0x00000000, 0x00000000}},  //   fboo,   ,   ,
  { {0x62821f65, 0x224400c4, 0x2d4b0056, 0x00000000}},  //   gboo, _bymk_, jøen_,
  { {0xdb021565, 0x00000000, 0x00000000, 0x00000000}},  //   rtlø,   ,   ,
  { {0x98aa00b9, 0x93970025, 0x26c900fa, 0x00000000}},  //   době_, _وجزا, leao_,
  { {0x62820068, 0x5ed40044, 0x00000000, 0x00000000}},  //   bboo, থানে,   ,
  { {0x0d8500c0, 0x6b8d0036, 0x6296004a, 0x00000000}},  //   плин, _łago, óyot,
  { {0xb364005e, 0x00000000, 0x00000000, 0x00000000}},  //   _църк,   ,   ,
  { {0x7d09003b, 0x2a6901c3, 0x2ee600d9, 0x00000000}},  //   сног_, _agab_, _enof_,
  { {0x0ff20061, 0x6b730035, 0x25a9004a, 0x00000000}},  //   _अपयश_, _băga, hual_,
  { {0x7d0a0039, 0x6910006c, 0x00000000, 0x00000000}},  //   _elfs, _käeg,   ,
  { {0x316d0ea1, 0x25a904cb, 0x14ac0061, 0x00000000}},  //   _juez_, jual_, _चालण,
  { {0x25a9354d, 0x672f0061, 0x3ead3596, 0x00000000}},  //   dual_, _ajcj, lget_,
  { {0x66e60407, 0x8c420256, 0x7d060089, 0x00000000}},  //   пова, _пеше, īkst,
  { {0x7d06008f, 0x05d70061, 0x9bfa009b, 0x00000000}},  //   ūkst, ठिंब, _להצט,
  { {0xf651026c, 0x25a90919, 0x316d02a0, 0x00000000}},  // [b660] ہئے_, gual_, _nuez_,
  { {0xd8840014, 0x00000000, 0x00000000, 0x00000000}},  //   _تهدی,   ,   ,
  { {0xc95300b6, 0x62820011, 0xe73a02dc, 0x00000000}},  //   _רמת_, tboo, _ген_,
  { {0xcfc30044, 0x69c40066, 0xe2972e81, 0x00000000}},  //   ্মান, _kpie, зац_,
  { {0x62820168, 0x237f0091, 0xd046006b, 0x00000000}},  //   rboo, _čuje_, əmən,
  { {0x628201d6, 0x7bc30d08, 0x00000000, 0x00000000}},  //   sboo, _opnu,   ,
  { {0xdfda005e, 0x00000000, 0x00000000, 0x00000000}},  //   съл_,   ,   ,
  { {0x3ead05fe, 0x69c40832, 0x3da6041f, 0x00000000}},  //   gget_, _opie, проб,
  { {0x5d54026b, 0xdbcb004a, 0xa0a6007e, 0x00000000}},  //   мкит, dóñe, _наад,
  { {0xcb9801fb, 0xa617009b, 0x48d70044, 0x00000000}},  //   ової_, פקיד_, _সক্র,
  { {0xc0590088, 0x6efc009d, 0x69c401c5, 0x00000000}},  //   _дії_, _débr, _apie,
  { {0xbd870014, 0x77660066, 0xcb0b01ab, 0x00000000}},  //   _کنون_, _nikx, сход_,
  { {0x7646021e, 0xfe4601ab, 0x00000000, 0x00000000}},  //   _nyky, _эндо,   ,
  { {0xa3df007d, 0xd90f007a, 0x00000000, 0x00000000}},  //   तिम_, اید_,   ,
  { {0xc7c40088, 0x1cbb00b3, 0x8c41010f, 0x00000000}},  //   нсти, _המוע, ößte,
  { {0x6d4800db, 0x64430036, 0x6d5a0333, 0x00000000}},  //   llda, żnik, lmta,
  { {0xa63401fb, 0x7b160006, 0xdb0200c4, 0x00000000}},  // [b670] енті, ršut, bulâ,
  { {0x25a90022, 0x6d5a0173, 0x6abd04f2, 0x00000000}},  //   rual_, nmta, lfsf,
  { {0x316d0923, 0x3ead0039, 0x6d4801e5, 0x00000000}},  //   _suez_, yget_, ilda,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x672d00ca, 0x00000000, 0x00000000, 0x00000000}},  //   mnaj,   ,   ,
  { {0x69dd006c, 0x7b24016c, 0x656f0045, 0x00000000}},  //   ivse, nđur, _iuch,
  { {0xdfce0025, 0xdb090181, 0x656f0020, 0x00000000}},  //   ليو_, rudê, _huch,
  { {0x656f000b, 0xe3b20049, 0x6d48010e, 0x00000000}},  //   _kuch, _שױן_, elda,
  { {0x3ead001c, 0x51870265, 0x61e004eb, 0x00000000}},  //   rget_, _хуба, _grml,
  { {0x656f0219, 0x69dd01d9, 0x3ead0009, 0x00000000}},  //   _much, dvse, sget_,
  { {0x69c4001f, 0x656f3597, 0xfaa600ed, 0x00000000}},  //   _spie, _luch, мано,
  { {0x6d48049a, 0x656f1259, 0x00000000, 0x00000000}},  //   alda, _ouch,   ,
  { {0x656f00bb, 0x00000000, 0x00000000, 0x00000000}},  //   _nuch,   ,   ,
  { {0x656700d9, 0xa3c2006e, 0x6d5a0009, 0x00000000}},  //   _nijh, ्बम_, cmta,
  { {0x18670216, 0x656f009d, 0x00000000, 0x00000000}},  //   дари_, _auch,   ,
  { {0x656f001f, 0x69c0014a, 0xeab20464, 0x00000000}},  //   _buch, çmes, _شعب_,
  { {0x656f1526, 0xf74301fc, 0x05663598, 0x00000000}},  // [b680] _cuch, тето, дван,
  { {0x656f07e4, 0xe5a30517, 0x80bf00e8, 0x00000000}},  //   _duch, тифи, ल्मे,
  { {0x656f05e1, 0x77660066, 0x6d430145, 0x00000000}},  //   _euch, _tikx, _mkna,
  { {0x2bf6007b, 0x71a6007e, 0x656f01a2, 0x00000000}},  //   ומען_, дадз, _fuch,
  { {0xc69300b3, 0x6d48000c, 0x2fc50022, 0x00000000}},  //   _באר_, ylda, _aplg_,
  { {0x6d4600b9, 0x60c10045, 0x26c20288, 0x00000000}},  //   ůkaz, _cblm, _hbko_,
  { {0xd0100054, 0x656f3599, 0xa067003b, 0x00000000}},  //   طلة_, _zuch, маља_,
  { {0x6d43006c, 0x00000000, 0x00000000, 0x00000000}},  //   _akna,   ,   ,
  { {0x66041eb9, 0xd1b302fd, 0x6da3003b, 0x00000000}},  //   nyik, _لینک, виња,
  { {0x672d0119, 0x28c00204, 0x00000000, 0x00000000}},  //   znaj, श्मि,   ,
  { {0x6d4800f8, 0x672d0036, 0x6d5a007f, 0x00000000}},  //   rlda, ynaj, rmta,
  { {0xdd8f007a, 0x6abd01a2, 0xa3df006e, 0x00000000}},  //   _چون_, ufsf, तित_,
  { {0x6ef50428, 0x6abd000c, 0xdd8f03d6, 0x00000000}},  //   _náby, rfsf, _نون_,
  { {0x656f0871, 0xab94003b, 0x200101a2, 0x00000000}},  //   _ruch, _закљ, ähig_,
  { {0x656f001f, 0xb8820027, 0x672d0d0a, 0x00000000}},  //   _such, _číta, tnaj,
  { {0x656f2c37, 0x63a504bb, 0x00000000, 0x00000000}},  //   _puch, vrhn,   ,
  { {0xdb02004a, 0x672d0161, 0x656f004a, 0x00000000}},  // [b690] atló, rnaj, _quch,
  { {0x88c40036, 0x798d027f, 0xdb0213aa, 0x00000000}},  //   ęści, _iwaw, mulá,
  { {0x442b007e, 0x656f01a2, 0xdce3002b, 0x00000000}},  //   ццам_, _wuch, _sinċ,
  { {0x656f15f4, 0x9259007c, 0x798d00e7, 0x00000000}},  //   _tuch, пает_, _kwaw,
  { {0xdb020344, 0x90c5022a, 0x66160036, 0x00000000}},  //   nulá, ебле, czyk,
  { {0x26d90166, 0x798d0258, 0x00000000, 0x00000000}},  //   _haso_, _mwaw,   ,
  { {0x26d9006a, 0x6b56140e, 0x00000000, 0x00000000}},  //   _kaso_, láge,   ,
  { {0x26d9022b, 0xdb02359a, 0xd1bb0025, 0x00000000}},  //   _jaso_, kulá, _واذا_,
  { {0x2d990047, 0x2d8b00f4, 0x26d900b9, 0x00000000}},  //   ése_, èce_, _maso_,
  { {0x26d900e0, 0xdb0213a5, 0x00000000, 0x00000000}},  //   _laso_, dulá,   ,
  { {0x8b26170a, 0x6b5f0089, 0x798d00e7, 0x00000000}},  //   едне, _lūgu, _awaw,
  { {0x28b20201, 0x26d90197, 0x798d047b, 0x00000000}},  //   _जाहि, _naso_, _bwaw,
  { {0xdca501fb, 0x645a000c, 0xdb02359b, 0x00000000}},  //   _зали, _útiv, gulá,
  { {0xfe7900b9, 0x00000000, 0x00000000, 0x00000000}},  //   lců_,   ,   ,
  { {0x3b0a012b, 0x26d9359c, 0x00000000, 0x00000000}},  //   _неко_, _baso_,   ,
  { {0x6d41023a, 0x9666012b, 0xfe7900b9, 0x00000000}},  //   lola, екбе, nců_,
  { {0xe5a301f9, 0xdce30107, 0x26d918d9, 0x00000000}},  // [b6a0] лити, _linč, _daso_,
  { {0x6d4104cb, 0x387a00c4, 0x66160036, 0x00000000}},  //   nola, _ufpr_, rzyk,
  { {0x66160036, 0x26d9359d, 0xb69b009d, 0x00000000}},  //   szyk, _faso_, _plât,
  { {0xe2920025, 0x6d4100ab, 0x6b560010, 0x00000000}},  //   اذا_, hola, lágb,
  { {0x6d41020c, 0xfe7900b9, 0x68fe359e, 0x00000000}},  //   kola, dců_, _kopd,
  { {0x6d410093, 0x00000000, 0x00000000, 0x00000000}},  //   jola,   ,   ,
  { {0x6d41018e, 0x7cf6001a, 0x68fe0022, 0x00000000}},  //   dola, _târz, _mopd,
  { {0xdce3016c, 0x26c000c4, 0xb1830f6c, 0x00000000}},  //   _dinč, nfio_, šťan,
  { {0xe2a6000c, 0x6d410051, 0x68fe01c3, 0x00000000}},  //   æðum_, fola, _oopd,
  { {0x6d4113f0, 0x2175003b, 0x798d0045, 0x00000000}},  //   gola, _јутр, _rwaw,
  { {0xac18165b, 0xdee60404, 0xfe7900b9, 0x00000000}},  //   фону_, _пожи, bců_,
  { {0x60da00e7, 0xdb0207fd, 0xbebd0006, 0x00000000}},  //   _hatm, tulá, liūn,
  { {0x6d410039, 0xc333009b, 0x26d9007f, 0x00000000}},  //   bola, רור_, _raso_,
  { {0xd048006b, 0xbebd0006, 0xa3c2006e, 0x00000000}},  //   _sadə, niūn, ्बा_,
  { {0x26d90211, 0x60da007f, 0x3cf70a4f, 0x00000000}},  //   _paso_, _matm, _سعود_,
  { {0xd6d801e1, 0xf7700188, 0xddc20059, 0x00000000}},  //   нту_, صاف_, _zgoš,
  { {0x7aed000b, 0xe5730380, 0x8939359f, 0x00000000}},  // [b6b0] _inat, اطر_, _опис_,
  { {0x60da123c, 0x81d60044, 0xdb02068f, 0x00000000}},  //   _natm, িমা_, gulæ,
  { {0x9295008b, 0x7aed000c, 0x64150025, 0x00000000}},  //   ваец, _knat, خواط,
  { {0x6d412352, 0x7aff0066, 0x25760146, 0x00000000}},  //   zola, _joqt, _fæl_,
  { {0xe4a7098c, 0xdce302aa, 0x7aed0020, 0x00000000}},  //   _прво, _sinč, _mnat,
  { {0x60da2b9a, 0x4fa5005e, 0x6d410032, 0x00000000}},  //   _catm, викв, xola,
  { {0x6d410062, 0xe534007c, 0x7aed2865, 0x00000000}},  //   vola, _серь, _onat,
  { {0x645535a0, 0x6b560010, 0x25a900fa, 0x00000000}},  //   _izzi, zágb, oral_,
  { {0x6d41022b, 0x60da02ba, 0x20090089, 0x00000000}},  //   tola, _fatm, ņai_,
  { {0x7aed000b, 0x270e006e, 0x25a9011c, 0x00000000}},  //   _anat, _सत्र_, iral_,
  { {0x6d41022b, 0x21270082, 0x6d5801f3, 0x00000000}},  //   rola, minh_, _dhva,
  { {0x25a927f1, 0x21270082, 0x6d410e69, 0x00000000}},  //   kral_, linh_, sola,
  { {0x6d411a64, 0xd6b90044, 0x68fe35a1, 0x00000000}},  //   pola, ুযায, _popd,
  { {0x645535a2, 0xdca5017f, 0x7aed1382, 0x00000000}},  //   _ozzi, _раки, _enat,
  { {0xa96700e3, 0x7aed00f8, 0x2576000c, 0x00000000}},  //   тира_, _fnat, _sæl_,
  { {0x21270082, 0x7e7b0329, 0x6b560010, 0x00000000}},  //   hinh_, ncup, ságb,
  { {0x26c00016, 0x660301a4, 0xd6270cb3, 0x00000000}},  // [b6c0] rfio_, апта, воте_,
  { {0xd910026c, 0x7aed0119, 0x61e6016c, 0x00000000}},  //   _ایس_, _znat, _šklo,
  { {0x60da115e, 0x21270082, 0xa3df006e, 0x00000000}},  //   _ratm, dinh_, तिष_,
  { {0xf626007e, 0x2ba90309, 0x60da005d, 0x00000000}},  //   _адмо, _किना, _satm,
  { {0xdb0205b7, 0x41b606e3, 0x60da189a, 0x00000000}},  //   pulæ, тсет, _patm,
  { {0x2127012d, 0x00000000, 0x00000000, 0x00000000}},  //   ginh_,   ,   ,
  { {0xd00f006d, 0x2d9d0173, 0x20070010, 0x00000000}},  //   يله_, _avwe_, gyni_,
  { {0x6d580119, 0xa3df0201, 0xc059007e, 0x00000000}},  //   _shva, तिर_, хіі_,
  { {0x324601fc, 0x21270082, 0x7aed0087, 0x00000000}},  //   _реаг, binh_, _rnat,
  { {0x61e2013f, 0x00000000, 0x00000000, 0x00000000}},  //   mvol,   ,   ,
  { {0x61e20625, 0xdb0212f9, 0x3fa5221c, 0x00000000}},  //   lvol, kulä, _مصنف,
  { {0x7e7b117e, 0xbb9301ab, 0x00000000, 0x00000000}},  //   ccup, шающ,   ,
  { {0xf2d300bd, 0x61e21596, 0x316c121e, 0x00000000}},  //   בער_, nvol, _kidz_,
  { {0x6d580091, 0xa8a4003b, 0x25a9006b, 0x00000000}},  //   _uhva, ирск, vral_,
  { {0xe894007e, 0x39430089, 0xd918007c, 0x00000000}},  //   рась, rojs_, тья_,
  { {0x7aed181e, 0x61e20168, 0xdb0201a2, 0x00000000}},  //   _unat, kvol, gulä,
  { {0x27370f68, 0x25a902ed, 0x00000000, 0x00000000}},  // [b6d0] għna_, ural_,   ,
  { {0x58d50057, 0x2ba901f5, 0x21270082, 0x00000000}},  //   _соот, _किमा, xinh_,
  { {0xdd860167, 0x61e2007f, 0xb88200b9, 0x00000000}},  //   _گو_, evol, číte,
  { {0x25a901aa, 0xf6790049, 0xef1f0036, 0x00000000}},  //   pral_, _ראָמ, ężko_,
  { {0xdd860167, 0x29010715, 0x21270011, 0x00000000}},  //   _دو_, _koha_, tinh_,
  { {0xe3b302fd, 0xe1f00025, 0x958200b4, 0x00000000}},  //   _پرس_, تسم_, żące,
  { {0x6455001e, 0xb4c1006e, 0xf3671281, 0x00000000}},  //   _uzzi, ्जी_, _атан,
  { {0xa3c2062e, 0x21270082, 0x00000000, 0x00000000}},  //   ्बर_, sinh_,   ,
  { {0x7e7b0035, 0x2007000c, 0x629900d9, 0x00000000}},  //   rcup, syni_, mawo,
  { {0x6299224b, 0x63730066, 0x290113ae, 0x00000000}},  //   lawo, _aħni, _noha_,
  { {0x5edb0044, 0x00000000, 0x00000000, 0x00000000}},  //   ভাবে,   ,   ,
  { {0x62990058, 0x00000000, 0x00000000, 0x00000000}},  //   nawo,   ,   ,
  { {0xed4e053c, 0x6da5003b, 0xf99f01aa, 0x00000000}},  //   _го_, _сила, syèn_,
  { {0xdce30089, 0xf99f01aa, 0x00000000, 0x00000000}},  //   _finā, myèl_,   ,
  { {0x61e235a3, 0xab2a0057, 0x290100ea, 0x00000000}},  //   zvol, _пока_, _doha_,
  { {0x236d0036, 0xdb2401b2, 0x00000000, 0x00000000}},  //   _niej_, _خوبی,   ,
  { {0xe7370057, 0xdce3001e, 0xf99f01aa, 0x00000000}},  // [b6e0] ует_, _zinā, nyèl_,
  { {0xa3c20309, 0x61e20026, 0x00000000, 0x00000000}},  //   ्बल_, vvol,   ,
  { {0xdb0209fe, 0x6e2d0107, 0x29180048, 0x00000000}},  //   pulä, _žabl, mhra_,
  { {0x62990173, 0x248701df, 0x798401c3, 0x00000000}},  //   gawo, ınma_, _ktiw,
  { {0xf126105c, 0x26d20026, 0x00000000, 0x00000000}},  //   лько, meyo_,   ,
  { {0x61e20664, 0xbebd010a, 0xdfd00025, 0x00000000}},  //   rvol, siūl, قيت_,
  { {0x61e20125, 0x62992b98, 0x3d07006e, 0x00000000}},  //   svol, bawo, ाउने_,
  { {0x3f8301d5, 0x61e20116, 0x26d200e7, 0x00000000}},  //   _ħjut_, pvol, neyo_,
  { {0x9d14081e, 0x79840009, 0x6b8300e0, 0x00000000}},  //   идич, _ntiw, _atng,
  { {0x6aa40843, 0x00000000, 0x00000000, 0x00000000}},  //   _adif,   ,   ,
  { {0x9b5901f9, 0xef86003b, 0x88c40036, 0x00000000}},  //   киот_, _слеп, ęśli,
  { {0x29010010, 0x644e0145, 0x7de60380, 0x00000000}},  //   _soha_, _mybi, _مستم,
  { {0xf2d3007b, 0x6aa40016, 0x26d201aa, 0x00000000}},  //   זער_, _ddif, deyo_,
  { {0x6aa40118, 0x6f0201ee, 0x291835a4, 0x00000000}},  //   _edif, _hooc, ghra_,
  { {0x19580a78, 0x7bca0045, 0x644e35a5, 0x00000000}},  //   уары_, _upfu, _nybi,
  { {0x2ba900e8, 0x656e0051, 0x26d20045, 0x00000000}},  //   _किता, _aibh, geyo_,
  { {0x2918002a, 0x35f5007e, 0x6f0200c4, 0x00000000}},  // [b6f0] bhra_, шпар, _mooc,
  { {0x7afd00ee, 0x291835a6, 0x6f0235a7, 0x00000000}},  //   ljst, chra_, _looc,
  { {0x629935a8, 0xa87a009b, 0xdb0235a9, 0x00000000}},  //   tawo, _באתר, rtlö,
  { {0x7afd0295, 0xdb0235aa, 0x656e0048, 0x00000000}},  //   njst, stlö, _eibh,
  { {0x629935ab, 0xf99f01aa, 0xb60735ac, 0x00000000}},  //   rawo, nsè_, _сянк,
  { {0x7777002b, 0x00000000, 0x00000000, 0x00000000}},  //   _kuxx,   ,   ,
  { {0xfe710054, 0x23e4007e, 0x6f020785, 0x00000000}},  //   يدة_, _літв, _booc,
  { {0xf99f01aa, 0x3eb91bd5, 0x638100e5, 0x00000000}},  //   ksè_, üst_, _cânţ,
  { {0x7afd0645, 0x6b8400ca, 0x00000000, 0x00000000}},  //   djst, _čiga,   ,
  { {0xf99f01aa, 0x61e9038f, 0xdca500ec, 0x00000000}},  //   ryèl_, _irel, јани,
  { {0x5ea70055, 0xf99f01aa, 0x26d20600, 0x00000000}},  //   ক্ষে, syèl_, yeyo_,
  { {0xda660603, 0x2bb60164, 0x6f0200bb, 0x00000000}},  //   ивни, _अमरा, _gooc,
  { {0x82d6061e, 0x29181706, 0x4a43005e, 0x00000000}},  //   בורג_, thra_, жняв,
  { {0xdce300e5, 0x00000000, 0x00000000, 0x00000000}},  //   _dină,   ,   ,
  { {0xa696098c, 0x7d030051, 0x969635ad, 0x00000000}},  //   ирај, _ions, ираш,
  { {0x61e90e98, 0x656e0051, 0x5ea70044, 0x00000000}},  //   _orel, _sibh, ক্রে,
  { {0x7d03134e, 0xa526008b, 0x644e0061, 0x00000000}},  // [b700] _kons, амад, _sybi,
  { {0x7d03093b, 0x64a60679, 0x00000000, 0x00000000}},  //   _jons, ража,   ,
  { {0xe29a008b, 0x7d03032c, 0x61e9008e, 0x00000000}},  //   вае_, _mons, _arel,
  { {0xf99f0263, 0x7d030471, 0x98a30089, 0x00000000}},  //   zyèm_, _lons, mijā_,
  { {0x644e0046, 0x98a30089, 0x7bc1006c, 0x00000000}},  //   _wybi, lijā_, htlu,
  { {0x25a00279, 0x656e23a3, 0x6f020087, 0x00000000}},  //   msil_, _uibh, _sooc,
  { {0xdfd00054, 0x03a3007c, 0x98a30089, 0x00000000}},  //   سية_, _миро, nijā_,
  { {0x61e935ae, 0x3ec30783, 0x24980145, 0x00000000}},  //   _frel, осьб, _herm_,
  { {0x61e935af, 0xf99f01aa, 0x7d03032c, 0x00000000}},  //   _grel, tyèm_, _bons,
  { {0x8fa6026b, 0xdceb001a, 0x00000000, 0x00000000}},  //   _важе, _rugă,   ,
  { {0x25a002b9, 0x69cd0240, 0x6c340025, 0x00000000}},  //   hsil_, _spae, صفحا,
  { {0x4cd30044, 0x25a00058, 0x98a30089, 0x00000000}},  //   তাগু, ksil_, dijā_,
  { {0x7d03185b, 0xdd8e00a1, 0x5ebe0044, 0x00000000}},  //   _fons, _کوڈ_, ্যদে,
  { {0x7d0301d6, 0x2d8600e7, 0x00000000, 0x00000000}},  //   _gons, _itoe_,   ,
  { {0x6d481529, 0x6b56027b, 0x00000000, 0x00000000}},  //   moda, cágo,   ,
  { {0x6d4835b0, 0x7d0300bb, 0x2d86000a, 0x00000000}},  //   loda, _zons, _ktoe_,
  { {0x24980f46, 0xe6670764, 0xd49b0140, 0x00000000}},  // [b710] _berm_, ртво, вре_,
  { {0x6d480ecf, 0x00000000, 0x00000000, 0x00000000}},  //   noda,   ,   ,
  { {0x98a30089, 0x9cd700b3, 0x39460051, 0x00000000}},  //   cijā_, שובה_, _íosa_,
  { {0xfaff008d, 0x2ba903d7, 0x6d480733, 0x00000000}},  //   një_, _किसा, hoda,
  { {0x672d000b, 0x2498002b, 0x6d48006c, 0x00000000}},  //   miaj, _ferm_, koda,
  { {0xe134007e, 0x672d0020, 0x61e90466, 0x00000000}},  //   ончы, liaj, _vrel,
  { {0x6d4812db, 0x8352026c, 0x656500f6, 0x00000000}},  //   doda, _کھلا, mmhh,
  { {0x61e9027b, 0x7d03001f, 0xf838019b, 0x00000000}},  //   _trel, _sons, ינות_,
  { {0x660d2943, 0x7d03023a, 0xa3df007d, 0x00000000}},  //   nyak, _pons, तिक_,
  { {0x7d1a0857, 0x7bc1010f, 0x6d480091, 0x00000000}},  //   ghts, ttlu, goda,
  { {0x660d24a8, 0x2d9f00ab, 0x672d00e7, 0x00000000}},  //   hyak, ssue_, kiaj,
  { {0xfaff0065, 0xa3e8006e, 0x7d03000a, 0x00000000}},  //   gjë_, बित_, _wons,
  { {0xfce50373, 0x6d48018e, 0x7bc135b1, 0x00000000}},  //   _голо, boda, stlu,
  { {0x7d1a04e5, 0x6d480036, 0x2f180010, 0x00000000}},  //   chts, coda, _vége_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x98a3001e, 0x6b5d00f4, 0x25a0010e, 0x00000000}},  //   rijā_, tége, tsil_,
  { {0x24980c0d, 0x660d0390, 0x98a30089, 0x00000000}},  // [b720] _perm_, gyak, sijā_,
  { {0x2ed4006e, 0x25a003f2, 0xaa7b0161, 0x00000000}},  //   _दस्त, rsil_, ndýn,
  { {0x6b5d0047, 0x25a00ab5, 0xf746003b, 0x00000000}},  //   sége, ssil_, _гено,
  { {0x734901fb, 0x9f580190, 0x394a009d, 0x00000000}},  //   ачів_, _ærø_, lobs_,
  { {0xc297008b, 0x249800ab, 0x6d480969, 0x00000000}},  //   скіх_, _term_, yoda,
  { {0x614301e0, 0xc05a03e8, 0x394a01c3, 0x00000000}},  //   печа, лій_, nobs_,
  { {0xf487026c, 0x6d480428, 0x08770049, 0x00000000}},  //   _چاہی, voda, זעצט_,
  { {0x645c2ad6, 0x6d480036, 0xf773009b, 0x00000000}},  //   _izri, woda, הקה_,
  { {0x6ce603e8, 0xa0a6025f, 0x394a01e5, 0x00000000}},  //   біне, _газд, kobs_,
  { {0x628235b2, 0xd24f0025, 0xdb0201a2, 0x00000000}},  //   lcoo, _أنك_, hrlä,
  { {0x6d4835b3, 0xa4fb00a0, 0x00000000, 0x00000000}},  //   roda, אליט,   ,
  { {0x2ba9013d, 0x8fa3007e, 0x6d480ff8, 0x00000000}},  //   _किरा, _хаце, soda,
  { {0x6d480062, 0x63ab0036, 0x2bda0316, 0x00000000}},  //   poda, ągni, _बनवा,
  { {0x672d0036, 0x47d20044, 0x2905000c, 0x00000000}},  //   wiaj, হিনী, ðla_,
  { {0x672d010e, 0x00000000, 0x00000000, 0x00000000}},  //   tiaj,   ,   ,
  { {0xec37009b, 0x6b5d0010, 0x6e2d0b4a, 0x00000000}},  //   _לאור_, ségb, _žabi,
  { {0x645c1827, 0x672d0052, 0x4499054d, 0x00000000}},  // [b730] _azri, riaj, иваю_,
  { {0x394a01d6, 0x2fde0009, 0xe6c00166, 0x00000000}},  //   cobs_, _ostg_, čišć,
  { {0x3e6f014a, 0x73d900e2, 0x660d21e6, 0x00000000}},  //   _kötü_, рдер_, syak,
  { {0x32551023, 0x00000000, 0x00000000, 0x00000000}},  //   овер,   ,   ,
  { {0x28c0006e, 0x673d00bb, 0x00000000, 0x00000000}},  //   श्कि, _ijsj,   ,
  { {0x64400046, 0xc244007e, 0xc5f2009b, 0x00000000}},  //   _śmie, чнік, _קדם_,
  { {0xdbf100b9, 0x628200fd, 0x29380049, 0x00000000}},  //   _přít, bcoo, זאגן_,
  { {0x0d85025f, 0x38180104, 0x00000000, 0x00000000}},  //   олин, מקום_,   ,
  { {0x0cc401f5, 0xa6e2000c, 0x00000000, 0x00000000}},  //   वभूम, öðin,   ,
  { {0x929d0036, 0x00000000, 0x00000000, 0x00000000}},  //   _koło,   ,   ,
  { {0xeb99012b, 0x28c4013d, 0x6f1b0082, 0x00000000}},  //   јим_, _लॉगि, phuc,
  { {0xd250026c, 0x4421009d, 0x00000000, 0x00000000}},  //   _آنے_, izh_,   ,
  { {0x4e7801f7, 0x7de70014, 0x00000000, 0x00000000}},  //   _احمد_, _دسام,   ,
  { {0x2d8d35b4, 0x00000000, 0x00000000, 0x00000000}},  //   mpee_,   ,   ,
  { {0x394a000a, 0x869a0745, 0x2d8d004a, 0x00000000}},  //   robs_, итат_, lpee_,
  { {0x81d00044, 0x628200d2, 0x629b27d7, 0x00000000}},  //   ষিত_, xcoo, _neuo,
  { {0x7ae41419, 0xd7f8001a, 0x9b4400a1, 0x00000000}},  // [b740] _iait, ţă_, _ونڈو,
  { {0x7ae40d2a, 0x8c3c006b, 0x628200d9, 0x00000000}},  //   _hait, bağd, wcoo,
  { {0x7ae40004, 0x62820061, 0x6b5d00f4, 0x00000000}},  //   _kait, tcoo, léga,
  { {0x7ae4002d, 0x74130025, 0xfaff0065, 0x00000000}},  //   _jait, بوما, hmën_,
  { {0x7ae4002a, 0x69c60047, 0x2240006b, 0x00000000}},  //   _mait, ntke, çik_,
  { {0x7ae4021e, 0x628200b5, 0x45d90049, 0x00000000}},  //   _lait, scoo, _פֿרא,
  { {0xea010011, 0x6f190016, 0x00000000, 0x00000000}},  //   _đậu_, _blwc,   ,
  { {0x7ae4011c, 0x3da60088, 0x98a3007f, 0x00000000}},  //   _nait, ороб, miją_,
  { {0xaf070380, 0x69c401f3, 0x98a3007f, 0x00000000}},  //   تقيم_, _nqie, liją_,
  { {0x7af600ab, 0xad260025, 0x85f70049, 0x00000000}},  //   _anyt, تربو, קציע_,
  { {0x7ae4022b, 0x747b01ce, 0x98a30006, 0x00000000}},  //   _bait, יניג, niją_,
  { {0x7ae4002a, 0x291a12da, 0x74ca006e, 0x00000000}},  //   _cait, _alpa_, स्तृ,
  { {0x7ae435b5, 0x00000000, 0x00000000, 0x00000000}},  //   _dait,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa2db001c, 0x7ae40549, 0x370735b6, 0x00000000}},  //   _नसल्, _fait, очав,
  { {0x7ae419c0, 0xab2807d8, 0xba3b009d, 0x00000000}},  //   _gait, _моја_, raïb,
  { {0x690b0129, 0x69c600d9, 0x00000000, 0x00000000}},  // [b750] _qües, ctke,   ,
  { {0x929d0036, 0x7ae4002d, 0x6abd0302, 0x00000000}},  //   _poło, _zait, lgsf,
  { {0x7ae4023a, 0xb4ab03d7, 0x98a30006, 0x00000000}},  //   _yait, _गयी_, giją_,
  { {0x8cca013d, 0x9294007e, 0x6aad0044, 0x00000000}},  //   त्तो, дацц, ট্রো,
  { {0x68e5021e, 0x8234007a, 0x5eb90044, 0x00000000}},  //   _kahd, ورها, _আসলে,
  { {0x673b0091, 0x68e535b7, 0xd6d70044, 0x00000000}},  //   čuju, _jahd, হাওয,
  { {0xa2950822, 0x68e5021e, 0x657d0039, 0x00000000}},  //   _наві, _mahd, _hush,
  { {0x657d06b7, 0xdfce007a, 0x68e500b0, 0x00000000}},  //   _kush, ايي_, _lahd,
  { {0x7ae400b0, 0x2d8d0045, 0xc3320049, 0x00000000}},  //   _rait, upee_, _נומ_,
  { {0x7ae435b8, 0x68e535b9, 0x80b435ba, 0x00000000}},  //   _sait, _nahd, _обух,
  { {0x7ae400b0, 0x657d0065, 0xfaff0065, 0x00000000}},  //   _pait, _lush, rmën_,
  { {0x0eb8007e, 0xaa460256, 0xfaff0023, 0x00000000}},  //   _душы_, земл, smën_,
  { {0x7ae40006, 0x98a30006, 0x657d1264, 0x00000000}},  //   _vait, ziją_, _nush,
  { {0x29030065, 0x7ae402f1, 0x6b5d0299, 0x00000000}},  //   gjja_, _wait, réga,
  { {0x7ae435bb, 0x657d01a2, 0x69c63250, 0x00000000}},  //   _tait, _aush, stke,
  { {0x657d0065, 0x6910006c, 0x7ae40048, 0x00000000}},  //   _bush, _näev, _uait,
  { {0xf1da03d7, 0x7abb009b, 0x2b810082, 0x00000000}},  // [b760] _मैंन, _הצפו, _hóc_,
  { {0x657d0350, 0x6b5600c4, 0x98a3007f, 0x00000000}},  //   _dush, dági, tiją_,
  { {0xa87b009b, 0x387a00e5, 0x00000000, 0x00000000}},  //   _לאיר, _igpr_,   ,
  { {0x657d008d, 0x2b8135bc, 0x98a30006, 0x00000000}},  //   _fush, _móc_, riją_,
  { {0xc6930452, 0x657d2b7f, 0x673b06fc, 0x00000000}},  //   _ראש_, _gush, čujt,
  { {0x28c00309, 0x2d8200b9, 0x64550161, 0x00000000}},  //   श्चि, íkem_, _fyzi,
  { {0x044335bd, 0x2b810082, 0xb4b8013d, 0x00000000}},  //   _зерн, _nóc_, छली_,
  { {0x543b009b, 0x671c007d, 0xadf420e6, 0x00000000}},  //   _העלא, नसिक_, дпиш,
  { {0xf99f01aa, 0x00000000, 0x00000000, 0x00000000}},  //   nyèt_,   ,   ,
  { {0x2b810011, 0x00000000, 0x00000000, 0x00000000}},  //   _bóc_,   ,   ,
  { {0xdbf100b9, 0x2b810011, 0x00000000, 0x00000000}},  //   _přát, _cóc_,   ,
  { {0x7c420089, 0x60c4016e, 0xaa590152, 0x00000000}},  //   _ātrā, đimu, жиму_,
  { {0x6abd35be, 0x00000000, 0x00000000, 0x00000000}},  //   rgsf,   ,   ,
  { {0x61ed005f, 0xb4ab03d7, 0x67d50175, 0x00000000}},  //   çilə, _गये_, могу,
  { {0x2b81001d, 0xd7f8003b, 0x31570049, 0x00000000}},  //   _góc_, пут_, פילן_,
  { {0x443f0363, 0x7d0a130e, 0x68e535bf, 0x00000000}},  //   _ću_, _hofs, _wahd,
  { {0x68e535c0, 0x6aad0045, 0x7d0a35c1, 0x00000000}},  // [b770] _tahd, _idaf, _kofs,
  { {0x04670b11, 0xe61f018e, 0x798d35c2, 0x00000000}},  //   птем, _ffôn_, _itaw,
  { {0x69100004, 0x657d0361, 0x7bc8046a, 0x00000000}},  //   _päev, _wush, ntdu,
  { {0x6b560181, 0x657d0f3e, 0x63a535c3, 0x00000000}},  //   tági, _tush, rshn,
  { {0x798d0066, 0xbebd007f, 0x00000000, 0x00000000}},  //   _jtaw, kiūr,   ,
  { {0xdb1b0c4d, 0xe4e40088, 0x7d0a002b, 0x00000000}},  //   lttä, _пісн, _nofs,
  { {0x2054005e, 0xd006005e, 0x00000000, 0x00000000}},  //   нтър, деще_,   ,
  { {0xdb1b00b0, 0x41e701ff, 0x798d0173, 0x00000000}},  //   nttä, _ніза, _otaw,
  { {0x2b810a91, 0x2d99023f, 0x798d14a5, 0x00000000}},  //   _sóc_, èse_, _ntaw,
  { {0xee360642, 0x6910006c, 0x6aad0045, 0x00000000}},  //   ьны_, _jäet, _adaf,
  { {0x3c6501fb, 0x798d0020, 0xcb6a02dc, 0x00000000}},  //   ьког, _ataw, жане_,
  { {0x2b810082, 0x6b5d0010, 0x00000000, 0x00000000}},  //   _vóc_, ségn,   ,
  { {0xc6120044, 0xddcb00b4, 0xbebd007f, 0x00000000}},  //   _সেনা_, _wygł, siūs,
  { {0x2b81001d, 0x3ebf0129, 0xeb9900ed, 0x00000000}},  //   _tóc_, lgut_, _дик_,
  { {0x798d0022, 0x39410146, 0x00000000, 0x00000000}},  //   _etaw, _djhs_,   ,
  { {0x3ebf04bd, 0x00000000, 0x00000000, 0x00000000}},  //   ngut_,   ,   ,
  { {0x69c80035, 0x8c3c0095, 0xe737017a, 0x00000000}},  // [b780] ădes, mağa, фет_,
  { {0xb4b803d7, 0x3ce735c4, 0x6f0b0d12, 0x00000000}},  //   छले_, _janv_, _logc,
  { {0x6f0b00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _oogc,   ,   ,
  { {0xdb090190, 0x958602b3, 0x00000000, 0x00000000}},  //   ardæ, _олме,   ,
  { {0x316a243b, 0x00000000, 0x00000000, 0x00000000}},  //   ошко_,   ,   ,
  { {0x26c01875, 0x29180010, 0x00000000, 0x00000000}},  //   lgio_, nkra_,   ,
  { {0x6f0b0146, 0x7d0a130e, 0x2bdd006e, 0x00000000}},  //   _bogc, _rofs, _फैला,
  { {0x69100004, 0xef91007a, 0x26c00419, 0x00000000}},  //   _käes, ایند, ngio_,
  { {0x2918000c, 0x8c3c006b, 0x6d470173, 0x00000000}},  //   kkra_, dağa, čjan,
  { {0x6b5d028c, 0x7d0a0065, 0x5edb0044, 0x00000000}},  //   tégo, _qofs, ভাগে,
  { {0xdb1b0f3c, 0xccf800b9, 0x798d0036, 0x00000000}},  //   yttä, dmět_, _staw,
  { {0x7bc800c7, 0xef690025, 0x00000000, 0x00000000}},  //   rtdu, _فإنه_,   ,
  { {0xff2700d3, 0xdb1b0023, 0x00000000, 0x00000000}},  //   _تبلی, lutë,   ,
  { {0xfc2f00d3, 0x7e6204eb, 0x3ea42bf0, 0x00000000}},  //   احی_, _izop, lamt_,
  { {0x36d50242, 0xba3b35c5, 0x9be60088, 0x00000000}},  //   новр, caïn, _цілк,
  { {0x26c005d3, 0x8cca03d7, 0x6d5a0065, 0x00000000}},  //   ggio_, त्रो, llta,
  { {0x798d000b, 0x6d5a35c6, 0x6458002b, 0x00000000}},  // [b790] _utaw, olta, żvil,
  { {0x29180039, 0x6d5a0009, 0xb8f40044, 0x00000000}},  //   ckra_, nlta, _সো_,
  { {0xa77510d8, 0x6d5a14a7, 0x6910010e, 0x00000000}},  //   _плоч, ilta, _väet,
  { {0xfe0e02fb, 0x659502dc, 0x00000000, 0x00000000}},  //   िहास_, _паму,   ,
  { {0xa159003b, 0x00000000, 0x00000000, 0x00000000}},  //   паду_,   ,   ,
  { {0x25a9014a, 0xdb1b0023, 0xd5b8007e, 0x00000000}},  //   msal_, futë, _ўся_,
  { {0x25a90058, 0x442505fe, 0x92c704ac, 0x00000000}},  //   lsal_, _ål_, _ощад,
  { {0x26160061, 0x6d5a35c7, 0x00000000, 0x00000000}},  //   पैकी_, elta,   ,
  { {0x25a935c8, 0x3ebf02ba, 0x98a30006, 0x00000000}},  //   nsal_, rgut_, siję_,
  { {0x25a90133, 0xb69b0173, 0x00000000, 0x00000000}},  //   isal_, _goâv,   ,
  { {0xc4d2007b, 0x25a90180, 0xd0110025, 0x00000000}},  //   נגט_, hsal_, _حلا_,
  { {0x6d5a0129, 0x25a90095, 0x441a00b3, 0x00000000}},  //   alta, ksal_, פורס,
  { {0x88e40044, 0x776d004a, 0x00000000, 0x00000000}},  //   মাসক, dmax,   ,
  { {0x291e0092, 0x8d651523, 0x7f5b006b, 0x00000000}},  //   óta_, _явле, lluq,
  { {0x9d1a007b, 0xc0520049, 0x46f6007e, 0x00000000}},  //   _מוסט, ָזן_, нчат,
  { {0x66e302b8, 0x291835c9, 0xeab20379, 0x00000000}},  //   лоса, skra_, _صعب_,
  { {0xea0100ad, 0x26c00a15, 0x0566013b, 0x00000000}},  // [b7a0] _đầu_, rgio_, еван,
  { {0x7d7a0049, 0x691000b0, 0x2019006b, 0x00000000}},  //   פרעג, _väes, _əsir_,
  { {0x389b007b, 0x00000000, 0x00000000, 0x00000000}},  //   _מיינ,   ,   ,
  { {0xfe67004b, 0x2ca50fdc, 0xb80800a1, 0x00000000}},  //   _مد_, hald_, _ٹکڑے_,
  { {0x6d5a00f8, 0x2ca50190, 0xa3e5013d, 0x00000000}},  //   ylta, kald_, _बैठ_,
  { {0xdb1b0065, 0x2ca507a8, 0x00000000, 0x00000000}},  //   tutë, jald_,   ,
  { {0x4ac60061, 0x7e620c59, 0x2ca500d4, 0x00000000}},  //   _वाढव, _szop, dald_,
  { {0x91e601f9, 0x6d4327a9, 0x00000000, 0x00000000}},  //   _побе, _ajna,   ,
  { {0xb1462436, 0x3ea40302, 0x2ca52141, 0x00000000}},  //   _знал, ramt_, fald_,
  { {0x3ea4073d, 0x61e201a2, 0x00000000, 0x00000000}},  //   samt_, mwol,   ,
  { {0xe5710049, 0x00000000, 0x00000000, 0x00000000}},  //   יַט_,   ,   ,
  { {0xa4fd007d, 0xd00f0014, 0x6d430146, 0x00000000}},  //   _उच्च_, _دلم_, _ejna,
  { {0x2ca5010f, 0x298b35ca, 0x80d501f5, 0x00000000}},  //   bald_, ясно_, _मॉडे,
  { {0x63be0161, 0xed59016c, 0x00000000, 0x00000000}},  //   kupn, tuže_,   ,
  { {0x67d4004c, 0x9848005e, 0x776d06d3, 0x00000000}},  //   лору, еята_, tmax,
  { {0x25a9014a, 0x63be04cb, 0x7bcf0036, 0x00000000}},  //   tsal_, dupn, ńcuc,
  { {0xf6531298, 0x00000000, 0x00000000, 0x00000000}},  // [b7b0] ائز_,   ,   ,
  { {0x2edd062e, 0xf9900379, 0x7d1a006c, 0x00000000}},  //   _मस्त, _ابي_, nkts,
  { {0x25a92c71, 0x00000000, 0x00000000, 0x00000000}},  //   ssal_,   ,   ,
  { {0x672402ae, 0x25a900b9, 0x62750025, 0x00000000}},  //   chij, psal_, نهائ,
  { {0xaad30164, 0x66640265, 0xa6ca0044, 0x00000000}},  //   ध्यक, _бърз, _লোকট,
  { {0xccf800b9, 0x7bd82c09, 0x78a71d9b, 0x00000000}},  //   změr_, _opvu, najv,
  { {0x22950025, 0x2ca5104b, 0xa4d40088, 0x00000000}},  //   _للأس, vald_, _щорі,
  { {0x256600f4, 0x2ca50dcc, 0x2d8f00f6, 0x00000000}},  //   rôle_, wald_, _ptge_,
  { {0x628401a8, 0x2ca500f8, 0xd05a013f, 0x00000000}},  //   žioc, tald_, _matə,
  { {0x61e4014a, 0x2f110b33, 0x6724012d, 0x00000000}},  //   çile, _págs_, zhij,
  { {0x8c450256, 0x00000000, 0x00000000, 0x00000000}},  //   тене,   ,   ,
  { {0x2b16005e, 0x398600c4, 0xde95003b, 0x00000000}},  //   тьор, _pôs_, _радњ,
  { {0xdd94008b, 0xb5fb0010, 0x00000000, 0x00000000}},  //   _бачы, _szán,   ,
  { {0x9e6401fb, 0x6f09016e, 0x00000000, 0x00000000}},  //   _свід, ljec,   ,
  { {0xea01001d, 0x6e290173, 0x61e235cb, 0x00000000}},  //   _đấu_, lzeb, zwol,
  { {0x6604002d, 0x2eed00fa, 0x00000000, 0x00000000}},  //   txik, ndef_,   ,
  { {0x6d4131f7, 0x6b830e69, 0xcb130104, 0x00000000}},  // [b7c0] onla, _hung, _כלה_,
  { {0x6b8335cc, 0x672422cb, 0x63be01ca, 0x00000000}},  //   _kung, shij, tupn,
  { {0x6b83125e, 0x6d41010f, 0x798401d6, 0x00000000}},  //   _jung, inla, _huiw,
  { {0x6b833193, 0x61e22a9c, 0x9c7c013e, 0x00000000}},  //   _mung, twol, meče,
  { {0x9c7c004f, 0x2eed0016, 0x6b8335cd, 0x00000000}},  //   leče, ddef_, _lung,
  { {0x61e20016, 0x6aa4000c, 0x85470006, 0x00000000}},  //   rwol, _leif, _plėš,
  { {0x03a30364, 0x8f340265, 0x63630004, 0x00000000}},  //   _висо, лекц, sõna,
  { {0xdb1b00f4, 0x044300a8, 0x00000000, 0x00000000}},  //   puté, _тесн,   ,
  { {0x91e30364, 0x5d5405f6, 0x3eb935ce, 0x00000000}},  //   _коте, лкит, ósta_,
  { {0x6b83183a, 0xb0c90164, 0x6d4102d8, 0x00000000}},  //   _bung, _रायग, gnla,
  { {0x6f092cb9, 0x6b5d35cf, 0x9c7c016e, 0x00000000}},  //   bjec, légi, ječe,
  { {0x6b8301a3, 0x9c7c1282, 0x7d1a00e0, 0x00000000}},  //   _dung, deče, skts,
  { {0x645c0038, 0x7def0010, 0x6aa41f74, 0x00000000}},  //   _lyri, rősö, _deif,
  { {0x79840007, 0x00000000, 0x00000000, 0x00000000}},  //   _duiw,   ,   ,
  { {0xf77301fa, 0x6b8300f8, 0x6b560181, 0x00000000}},  //   لار_, _gung, rágr,
  { {0x6aa4005b, 0x6b560010, 0x00000000, 0x00000000}},  //   _geif, ságr,   ,
  { {0x657c0058, 0x6b832a95, 0x645c005a, 0x00000000}},  // [b7d0] _birh, _zung, _ayri,
  { {0x6b831a16, 0xe5c4025f, 0x7aed0007, 0x00000000}},  //   _yung, јсто, _haat,
  { {0x645c048d, 0x5ea80044, 0x7aed00b0, 0x00000000}},  //   _cyri, _গানে, _kaat,
  { {0x7aed35d0, 0x645c0146, 0x00000000, 0x00000000}},  //   _jaat, _dyri,   ,
  { {0x7aed0168, 0x69cf0f36, 0x6d580059, 0x00000000}},  //   _maat, ntce, _okva,
  { {0x645c0359, 0x7aed35d1, 0x1bf4013d, 0x00000000}},  //   _fyri, _laat, ेमाल_,
  { {0x6f090209, 0xed59016c, 0x645c35d2, 0x00000000}},  //   tjec, juža_, _gyri,
  { {0x6b88001c, 0x765d021e, 0x6b83236c, 0x00000000}},  //   dqdg, _kysy, _rung,
  { {0x74ca02f4, 0x6aa4010f, 0x6b830971, 0x00000000}},  //   स्कृ, _reif, _sung,
  { {0x61e90004, 0x6b8304cb, 0xeb99025f, 0x00000000}},  //   _isel, _pung, нио_,
  { {0xb5fb0047, 0xfaa60407, 0x79840007, 0x00000000}},  //   _szál, лано, _suiw,
  { {0x7aed001c, 0x69cf2635, 0x6b830082, 0x00000000}},  //   _caat, ftce, _vung,
  { {0x3f8504cb, 0x9c7c016e, 0x6b8324a8, 0x00000000}},  //   _hulu_, veče, _wung,
  { {0x6b83006a, 0x2f180010, 0x6aa40066, 0x00000000}},  //   _tung, _régi_, _weif,
  { {0xc81501fb, 0x3f850107, 0x765d01aa, 0x00000000}},  //   аєть, _julu_, _aysy,
  { {0x7bc1000d, 0x3f8535d3, 0x7aed0112, 0x00000000}},  //   mulu, _mulu_, _gaat,
  { {0x765d018e, 0x7bc13219, 0x166615c4, 0x00000000}},  // [b7e0] _cysy, lulu, увам,
  { {0x645c00b0, 0x9c7c0107, 0x3f8500b0, 0x00000000}},  //   _pyri, seče, _oulu_,
  { {0x7bc1000d, 0x657c00b0, 0x06b00044, 0x00000000}},  //   nulu, _virh, ঙ্গি,
  { {0x645c16a4, 0x6363006c, 0x7bc10035, 0x00000000}},  //   _vyri, sõnn, iulu,
  { {0x7bc117ca, 0x765d018e, 0x1a9b0049, 0x00000000}},  //   hulu, _gysy, גינע,
  { {0x7bc1022b, 0x645c010a, 0xdce3001e, 0x00000000}},  //   kulu, _tyri, _minē,
  { {0x61e90093, 0x7bc1001a, 0x395a0022, 0x00000000}},  //   _esel, julu, _mkps_,
  { {0x7bc1001a, 0x3f85027e, 0x6d58141b, 0x00000000}},  //   dulu, _dulu_, _skva,
  { {0xd335008b, 0x7aed01b1, 0xb6370049, 0x00000000}},  //   _тэры, _raat, ָריס_,
  { {0x7aed35d4, 0x2dd70025, 0x7bc1001a, 0x00000000}},  //   _saat, ابية_, fulu,
  { {0x7bc1148e, 0xeb9700ed, 0x78a5006c, 0x00000000}},  //   gulu, лиќ_, _rehv,
  { {0xb5fb0047, 0x6da601f9, 0x317e022b, 0x00000000}},  //   _szám, _бида, _hitz_,
  { {0x7aed08b2, 0xaac60061, 0x00000000, 0x00000000}},  //   _vaat, _वारक,   ,
  { {0x7bc12bd0, 0x2727006c, 0x6d580059, 0x00000000}},  //   bulu, _mõne_, _ukva,
  { {0x7bc1000d, 0x7aed001c, 0x69cf0142, 0x00000000}},  //   culu, _taat, stce,
  { {0xcb69007a, 0x765d00b0, 0x7bcf0035, 0x00000000}},  //   _جمعه_, _pysy, ăcut,
  { {0x4ca70055, 0xb8db0044, 0x3ea600d9, 0x00000000}},  // [b7f0] _খাতু, _ইউ_, _meot_,
  { {0x395a0022, 0x317e0203, 0x00000000, 0x00000000}},  //   _gkps_, _nitz_,   ,
  { {0x765d0046, 0x61e9107b, 0xb97a009b, 0x00000000}},  //   _wysy, _ssel, _שנתי,
  { {0x92eb0025, 0x14c701f5, 0x317e0288, 0x00000000}},  //   عراق_, _लावण, _aitz_,
  { {0x7bc10ac8, 0x3f8524ac, 0x69360089, 0x00000000}},  //   zulu, _sulu_, zņem,
  { {0xf77f011f, 0x1fb509ae, 0x7bc10180, 0x00000000}},  //   _hiç_, асир, yulu,
  { {0x6b5d009d, 0x7bc10035, 0x1aec0044, 0x00000000}},  //   légu, xulu, টাতে_,
  { {0xd3430123, 0xe0d300a1, 0x7bc1001a, 0x00000000}},  //   _افری, _گزر_, vulu,
  { {0xfaff0023, 0xb5fb0010, 0x835200a1, 0x00000000}},  //   hmës_, _száj, _بھلا,
  { {0x7bc1000d, 0x3f850795, 0x6ffc0035, 0x00000000}},  //   tulu, _tulu_, _băcă,
  { {0x30840054, 0x237f07b9, 0xc1040025, 0x00000000}},  //   _المف, _kiuj_, _دولي,
  { {0x7bc1228e, 0xb5fb01ca, 0x69360089, 0x00000000}},  //   rulu, _vzáj, rņem,
  { {0xfe9a00b6, 0x7bc11a04, 0x395a0022, 0x00000000}},  //   _סיסמ, sulu, _pkps_,
  { {0x8276007b, 0x7bc1001a, 0x7c8700a8, 0x00000000}},  //   יערע_, pulu, _суде,
  { {0xbd6806e3, 0x291335d5, 0x225f35d6, 0x00000000}},  //   _срце_, _doxa_, _lyuk_,
  { {0xd91000e9, 0x273f00b0, 0x6fd8007d, 0x00000000}},  //   _کیس_, vänä_, _महसू,

  { {0x2ca70023, 0xfaff0023, 0xf77f0023, 0x00000000}},  // [b800] _kend_, rmët_, _diç_,
  { {0x33f601be, 0x26cb0207, 0x2ca70c35, 0x00000000}},  //   ичес, _ecco_, _jend_,
  { {0x2ca70065, 0x3958230d, 0x225f0022, 0x00000000}},  //   _mend_, mors_, _ayuk_,
  { {0x395812a0, 0x317e010f, 0x6b5d0010, 0x00000000}},  //   lors_, _sitz_, ségv,
  { {0x317e0288, 0x273f00b0, 0xdb0200f8, 0x00000000}},  //   _pitz_, sänä_, mslä,
  { {0x39581ce2, 0xc05a01fb, 0xd12f2638, 0x00000000}},  //   nors_, кій_, ومن_,
  { {0xf8b300b6, 0x443e059f, 0x98b10035, 0x00000000}},  //   קשה_, _ät_, liză_,
  { {0x9c7c0209, 0x395800f4, 0xdb020a35, 0x00000000}},  //   ječa, hors_, nslä,
  { {0x60ea0200, 0x39580066, 0x2ca7016e, 0x00000000}},  //   _имам_, kors_, _bend_,
  { {0x39580129, 0x64430036, 0x7fd60088, 0x00000000}},  //   jors_, źnie, _віді,
  { {0x395804bd, 0x291300c4, 0x2ca70146, 0x00000000}},  //   dors_, _roxa_, _dend_,
  { {0x2ca70112, 0x6ffc0035, 0x00000000, 0x00000000}},  //   _eend_, _văcă,   ,
  { {0x8d940054, 0x6f020b33, 0x39580039, 0x00000000}},  //   _التش, _inoc, fors_,
  { {0xf77f008d, 0x395801c5, 0x00000000, 0x00000000}},  //   _siç_, gors_,   ,
  { {0x6f02192b, 0x00000000, 0x00000000, 0x00000000}},  //   _knoc,   ,   ,
  { {0x6c7b00a0, 0x2ca700bb, 0x370435d7, 0x00000000}},  //   _באופ, _zend_, очув,
  { {0x39580133, 0xfaff0023, 0x00000000, 0x00000000}},  // [b810] bors_, smës_,   ,
  { {0x2901081d, 0x39580666, 0x6b5d2496, 0x00000000}},  //   _unha_, cors_, régu,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x1fcc0055, 0x2b592387, 0x256f006c, 0x00000000}},  //   লবাস, nosc_, külg_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f0235d8, 0x00000000, 0x00000000, 0x00000000}},  //   _anoc,   ,   ,
  { {0x2ca735d9, 0x6458010e, 0x00000000, 0x00000000}},  //   _rend_, üvit,   ,
  { {0x8505013d, 0x24890006, 0x395801c5, 0x00000000}},  //   रावट_, šimą_, zors_,
  { {0x9c7c0059, 0xa1940b87, 0x2ca701a3, 0x00000000}},  //   veča, _матч, _pend_,
  { {0x0d8201e1, 0x61fb0032, 0xd13101b7, 0x00000000}},  //   яльн, _irul, _عما_,
  { {0x39582bf9, 0x2ca7008d, 0x7f850025, 0x00000000}},  //   vors_, _vend_, _الصن,
  { {0x39580007, 0x80cd0061, 0x6f020197, 0x00000000}},  //   wors_, _साडे, _gnoc,
  { {0x2ca735da, 0x3958230d, 0x3ead043e, 0x00000000}},  //   _tend_, tors_, maet_,
  { {0x9c7c35db, 0x00000000, 0x00000000, 0x00000000}},  //   seča,   ,   ,
  { {0x9c7c35dc, 0x7d0335dd, 0x7d1c35de, 0x00000000}},  //   lečn, _inns, örse,
  { {0x39580bd3, 0xdc3901d5, 0x86990088, 0x00000000}},  //   sors_, _aħħa, итут_,
  { {0xa3ca001c, 0x7ae6011f, 0x9c7c0428, 0x00000000}},  // [b820] ळून_, mekt, nečn,
  { {0x98b10035, 0x69c6017b, 0x63b80142, 0x00000000}},  //   riză_, muke, ávno,
  { {0x9418006b, 0x69c600b0, 0xe73a00d7, 0x00000000}},  //   _yerə_, luke, _бен_,
  { {0x61fb009d, 0x6b5d32e2, 0x00000000, 0x00000000}},  //   _brul, légr,   ,
  { {0x7ae6022b, 0x9c7c0209, 0x69c61e17, 0x00000000}},  //   iekt, ječn, nuke,
  { {0x9f981418, 0x776401f3, 0x9c7c01ca, 0x00000000}},  //   авку_, llix, dečn,
  { {0xdfd00025, 0x7416025a, 0x64a3003b, 0x00000000}},  //   ذية_, _اوزا, _хаса,
  { {0x69c600b0, 0x80c4006e, 0x7d0335df, 0x00000000}},  //   kuke, _राके, _anns,
  { {0xa63b0049, 0xb2261fe6, 0x64cf0061, 0x00000000}},  //   ָגיר, _умал, स्कळ,
  { {0x69c615d6, 0xdce30006, 0x26c9016c, 0x00000000}},  //   duke, _minė, zgao_,
  { {0x7ae601e2, 0x628500b9, 0x2cac0016, 0x00000000}},  //   fekt, ěhov, radd_,
  { {0x8e860025, 0x3c0e006b, 0x6f020675, 0x00000000}},  //   _الإه, nəvi_, _unoc,
  { {0xc33300b6, 0x9418006b, 0x69c635e0, 0x00000000}},  //   פוש_, _verə_, guke,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x0d3b00b6, 0xd6db0887, 0x6d5a016e, 0x00000000}},  //   _תגוב, лта_, mota,
  { {0xf7700355, 0x6d5a002d, 0x7ae6011f, 0x00000000}},  //   فاق_, lota, cekt,
  { {0xe6670256, 0xdb240010, 0x6d480325, 0x00000000}},  // [b830] ство, _írás, onda,
  { {0x6d4803e3, 0x6aaf0051, 0xdb020748, 0x00000000}},  //   nnda, lacf, rslå,
  { {0x6d48121f, 0x1aec0044, 0x68e70035, 0x00000000}},  //   inda, টারে_, mejd,
  { {0x61fb00bb, 0x68e700ca, 0x321d0036, 0x00000000}},  //   _prul, lejd, tywy_,
  { {0x6d5a21d4, 0x7e6208e0, 0x00000000, 0x00000000}},  //   kota, _nyop,   ,
  { {0x9c7c0db7, 0x68e70091, 0x855700a1, 0x00000000}},  //   večn, nejd, _ایئر_,
  { {0x6d5a0dec, 0x7ae635e1, 0x3d0c013d, 0x00000000}},  //   dota, yekt, ़ाने_,
  { {0xef190364, 0x6d4835e2, 0x9c7c0224, 0x00000000}},  //   рми_, enda, tečn,
  { {0x6b8a001f, 0x6d48009f, 0x6d5a04be, 0x00000000}},  //   _aufg, fnda, fota,
  { {0x6d5a0059, 0x9c7c07ac, 0x1c450088, 0x00000000}},  //   gota, rečn, жном,
  { {0x5fdd02fb, 0x9c7c0087, 0x63710039, 0x00000000}},  //   _महिल, sečn, gång,
  { {0x6d480020, 0x69c603b6, 0x2fc701a2, 0x00000000}},  //   anda, tuke, mung_,
  { {0x2fc735e3, 0x1d0901f9, 0x6b5d00f4, 0x00000000}},  //   lung_, _вели_, tégr,
  { {0x69c60056, 0x7f5b00c4, 0x7d030bdc, 0x00000000}},  //   ruke, louq, _unns,
  { {0x2fc7001f, 0x3cee001c, 0x2727006c, 0x00000000}},  //   nung_, _असते_, _sõna_,
  { {0x7f49009d, 0x291e006c, 0x6b5d0010, 0x00000000}},  //   nneq, ötab_, ségr,
  { {0xf09f001d, 0x68e70018, 0x2fc735e4, 0x00000000}},  // [b840] _đàn_, bejd, hung_,
  { {0x2fc70390, 0x61e40279, 0xf53f0039, 0x00000000}},  //   kung_, çilm, _svår_,
  { {0x2bb50089, 0x2fc701a3, 0x753e0032, 0x00000000}},  //   nāc_, jung_, ripz,
  { {0x2fc7033b, 0xe1fa0aed, 0x672d0142, 0x00000000}},  //   dung_, иге_, chaj,
  { {0x6d48009f, 0x6d5a0020, 0x00000000, 0x00000000}},  //   ynda, yota,   ,
  { {0x6b840004, 0x2fc7010f, 0x6d5a002d, 0x00000000}},  //   _liig, fung_, xota,
  { {0x2fc735e5, 0x6d5a00b0, 0x4fc605b8, 0x00000000}},  //   gung_, vota, іска,
  { {0x67240006, 0x68e70036, 0x3f82000c, 0x00000000}},  //   nkij, zejd, öku_,
  { {0x6d5a1759, 0xf77300b6, 0x1ee80014, 0x00000000}},  //   tota, וקה_, لوژی_,
  { {0x2fc735e6, 0x236635e7, 0x6d4820c2, 0x00000000}},  //   bung_, lloj_, unda,
  { {0x6d480028, 0x6d5a35e8, 0x6724317c, 0x00000000}},  //   rnda, rota, kkij,
  { {0x6d5a002d, 0x67241a8f, 0x8ae70088, 0x00000000}},  //   sota, jkij, ціол,
  { {0x6d5a01aa, 0x9f4c0051, 0x5a34165b, 0x00000000}},  //   pota, _ordú_, днят,
  { {0x3f8c2887, 0x00000000, 0x00000000, 0x00000000}},  //   _kudu_,   ,   ,
  { {0xfe6d00a1, 0x76ab26d0, 0x29050276, 0x00000000}},  //   _لگی_, итав_, ıla_,
  { {0x9f4c0051, 0x7bc801a3, 0xa3e5013d, 0x00000000}},  //   _ardú_, mudu, _बैग_,
  { {0x7bc81ece, 0x2fc7010f, 0x7d1835e9, 0x00000000}},  // [b850] ludu, zung_, _kovs,
  { {0x672d000b, 0xf09f001d, 0x850500e8, 0x00000000}},  //   shaj, _đào_, राइट_,
  { {0x3eb9010a, 0x80c4007d, 0x7bc8083a, 0x00000000}},  //   ųsti_, _राजे, nudu,
  { {0x80cd01f5, 0x7d1800ca, 0x00000000, 0x00000000}},  //   _साहे, _lovs,   ,
  { {0x2fc70170, 0x7bc80020, 0xa2cc007d, 0x00000000}},  //   wung_, hudu, _हार्,
  { {0x2fc735ea, 0x3f8c01ca, 0x7bc8002d, 0x00000000}},  //   tung_, _budu_, kudu,
  { {0xe8d90011, 0x2fc7010f, 0x63710039, 0x00000000}},  //   _quỹ_, uung_, tånd,
  { {0x2fc735eb, 0xc6120055, 0x7bc801a3, 0x00000000}},  //   rung_, _সেটা_, dudu,
  { {0x6b840004, 0x2fc735ec, 0x2d990065, 0x00000000}},  //   _riig, sung_, ëse_,
  { {0x2fc704cb, 0xee3600a5, 0x00000000, 0x00000000}},  //   pung_, яны_,   ,
  { {0x3c65109f, 0x798d00e7, 0x7bc8006c, 0x00000000}},  //   яког, _auaw, gudu,
  { {0x09e60121, 0x1bec006e, 0x612f01e3, 0x00000000}},  //   помн, _जनरल_, _bølg,
  { {0xb0d203d7, 0x7ed402fd, 0x6aad04d2, 0x00000000}},  //   _सामग, _آزما, _deaf,
  { {0xfe70007a, 0x14c70061, 0x6f190719, 0x00000000}},  //   _شدن_, _लागण, _howc,
  { {0xab99039d, 0x672400b0, 0x7bc8014a, 0x00000000}},  //   _اختر_, tkij, cudu,
  { {0x612f02cc, 0xfaff0065, 0x3bba00a0, 0x00000000}},  //   _følg, llën_, _המקד,
  { {0x672435ed, 0x6443000c, 0xb9930025, 0x00000000}},  // [b860] rkij, únin, _كليب,
  { {0x6d4118a8, 0x9a3b009b, 0xe8ca01ab, 0x00000000}},  //   nila, _לתפק, _угол_,
  { {0x64a300c0, 0x7af635ee, 0x00000000, 0x00000000}},  //   хаха, _kayt,   ,
  { {0xeb96007b, 0x6d4120c0, 0x6f190026, 0x00000000}},  //   לדער_, hila, _nowc,
  { {0x6d4118a8, 0x7af60082, 0x3f8c10c6, 0x00000000}},  //   kila, _mayt, _sudu_,
  { {0x25a00169, 0x291a00b0, 0x7af600ea, 0x00000000}},  //   mpil_, _jopa_, _layt,
  { {0xc448089d, 0x6d410169, 0x80cd0316, 0x00000000}},  //   _بیان_, dila, _सारे,
  { {0x57fb009b, 0x7d1802e7, 0x7bc8013f, 0x00000000}},  //   מלצו, _sovs, vudu,
  { {0x6aad0285, 0x7d180e3c, 0x4ac60061, 0x00000000}},  //   _reaf, _povs, _वाजव,
  { {0x6d410760, 0x7bc801a3, 0x00000000, 0x00000000}},  //   gila, tudu,   ,
  { {0xd12f031d, 0x6db501f6, 0x9dd300a1, 0x00000000}},  //   _حمل_, _aşağ, وزیش,
  { {0x7bc8023a, 0x9c7c0802, 0x00000000, 0x00000000}},  //   rudu, lečk,   ,
  { {0x6d41006a, 0xc333009b, 0xc882006b, 0x00000000}},  //   bila, תור_, əşə_,
  { {0x291a02d5, 0x9c7c35ef, 0x256f006c, 0x00000000}},  //   _copa_, nečk, küla_,
  { {0xd148001d, 0xf99f01aa, 0xaac601f5, 0x00000000}},  //   yễn_, spè_, _वाचक,
  { {0xf09f0011, 0x8f9b00a3, 0x64910059, 0x00000000}},  //   _đàm_, מילי, zžič,
  { {0x9f5e0023, 0x291a0087, 0xdb0200ea, 0x00000000}},  // [b870] _artë_, _fopa_, vslø,
  { {0xf994012f, 0x612f0030, 0x9c7c32e0, 0x00000000}},  //   _ארץ_, _køle, ječk,
  { {0x442735f0, 0x9c7c0861, 0x00000000, 0x00000000}},  //   án_, dečk,   ,
  { {0x3943001e, 0x99990036, 0xf8ae00a1, 0x00000000}},  //   lijs_, mysł_, _مکہ_,
  { {0x6f190b69, 0x291a1b5e, 0x6d410cca, 0x00000000}},  //   _rowc, _yopa_, yila,
  { {0x39430089, 0x9c7c35f1, 0xe4c50167, 0x00000000}},  //   nijs_, rečj, _تصحی,
  { {0x213e0065, 0x9c7c0e0d, 0x6d41016e, 0x00000000}},  //   _dmth_, sečj, vila,
  { {0x6fcf0061, 0x394300bb, 0x850300a1, 0x00000000}},  //   संबं, hijs_, _توڑن,
  { {0x6d41021e, 0x7af6013f, 0x3f86000a, 0x00000000}},  //   tila, _rayt, _diou_,
  { {0x7af6005f, 0xfe420088, 0x00000000, 0x00000000}},  //   _sayt, тньо,   ,
  { {0x291a0211, 0x7af6006b, 0x68ec006b, 0x00000000}},  //   _ropa_, _payt, _öndə,
  { {0x2d8b008e, 0x7af6006b, 0xf1d1006e, 0x00000000}},  //   íces_, _qayt, _समान,
  { {0x6d41322f, 0xdb1b021e, 0x291a00e5, 0x00000000}},  //   pila, yttö, _popa_,
  { {0x61e40180, 0x612f068f, 0x6d41006b, 0x00000000}},  //   çili, _føle, qila,
  { {0xb8f60183, 0x2d8f00ab, 0x257401a2, 0x00000000}},  //   _हा_, _huge_, näle_,
  { {0x2d8700e0, 0x00000000, 0x00000000, 0x00000000}},  //   _hine_,   ,   ,
  { {0xb5fb0047, 0x2d8f1fd2, 0x6db5006b, 0x00000000}},  // [b880] _szár, _juge_, _uşağ,
  { {0xc8ca007a, 0x3eaf35f2, 0x25a02461, 0x00000000}},  //   _بودن_, _legt_, rpil_,
  { {0x2d87113d, 0x25a00030, 0x2d8f0023, 0x00000000}},  //   _mine_, spil_, _luge_,
  { {0x2d8735f3, 0x2bc50164, 0x660935f4, 0x00000000}},  //   _line_, _विना, _šeke,
  { {0x3cee0061, 0xd00f0014, 0x9c7c0062, 0x00000000}},  //   _असले_, یله_, tečk,
  { {0xcf9a012b, 0x2d8700ab, 0xd24f0025, 0x00000000}},  //   оји_, _nine_, جنه_,
  { {0x39940073, 0x2d8f0109, 0x3d1101f5, 0x00000000}},  //   _läs_, _auge_, ताने_,
  { {0x9c7c35f5, 0x2d8705e0, 0xadf435f6, 0x00000000}},  //   sečk, _aine_, епиш,
  { {0x2d87000d, 0xc6200044, 0x9c7c35f7, 0x00000000}},  //   _bine_, _নেতা_, meči,
  { {0x2d8735f8, 0x2b4004bd, 0x9c7c0059, 0x00000000}},  //   _cine_, _amic_, leči,
  { {0x2d8705ba, 0x69c00387, 0xdb0213f6, 0x00000000}},  //   _dine_, ámen, mplê,
  { {0x2d8708ba, 0x394300b5, 0x7e26007c, 0x00000000}},  //   _eine_, wijs_, _одеж,
  { {0x2d870198, 0x69c00c47, 0x13e70044, 0x00000000}},  //   _fine_, šmen, ফিয়,
  { {0x3eaf00b5, 0x2d870c42, 0x2b4000f6, 0x00000000}},  //   _zegt_, _gine_, _emic_,
  { {0x394329dc, 0x67d4072b, 0x69c60056, 0x00000000}},  //   rijs_, кору, arke,
  { {0x9c7c10ec, 0x2d87002d, 0x00000000, 0x00000000}},  //   ječi, _zine_,   ,
  { {0x2d87011f, 0x7bda021e, 0xe784004c, 0x00000000}},  // [b890] _yine_, lttu, туро,
  { {0x88c60055, 0x2bc50309, 0xe46b007c, 0x00000000}},  //   শ্বক, _विमा, ошел_,
  { {0x7bda0052, 0x00000000, 0x00000000, 0x00000000}},  //   nttu,   ,   ,
  { {0x25c401df, 0x9c7c0391, 0x7bda0fc8, 0x00000000}},  //   ürlü_, geči, ittu,
  { {0x2bc50201, 0xa1eb0025, 0x332d0285, 0x00000000}},  //   _विभा, تراك_, _vlex_,
  { {0x70c90204, 0x7d1c0039, 0xf6520104, 0x00000000}},  //   रलेल, örsl, _עצם_,
  { {0x2d8f0c0e, 0x9c7c00d0, 0x13f4004d, 0x00000000}},  //   _suge_, beči, _изря,
  { {0x2d8702cc, 0x69c605fe, 0x2d8f00f6, 0x00000000}},  //   _sine_, yrke, _puge_,
  { {0x6ff3006b, 0x2d87112b, 0xf1a70245, 0x00000000}},  //   _məcə, _pine_, _іран,
  { {0x28df006e, 0xfd110025, 0x3ea2014a, 0x00000000}},  //   _पॉलि, اجة_, ıkta_,
  { {0x2d87001a, 0x6ed70061, 0xcb6a01c0, 0x00000000}},  //   _vine_, _यापु, зане_,
  { {0x2d8700ab, 0x2d8f35f9, 0x81e20044, 0x00000000}},  //   _wine_, _tuge_, ধির_,
  { {0xed4e0822, 0x2d87000d, 0xee2e02dc, 0x00000000}},  //   _бо_, _tine_, _сн_,
  { {0x2eed07a5, 0x2a6901aa, 0x00000000, 0x00000000}},  //   leef_, _dyab_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x637802a0, 0x2a69000a, 0x2eed00d9, 0x00000000}},  //   míng, _fyab_, neef_,
  { {0x7ae40061, 0x9c7c00ca, 0x69da0035, 0x00000000}},  // [b8a0] _ibit, veči, ătes,
  { {0x63710039, 0x00000000, 0x00000000, 0x00000000}},  //   våna,   ,   ,
  { {0x20c9007d, 0xb0c90316, 0x9c7c16d0, 0x00000000}},  //   _राजध, _राजग, teči,
  { {0xeb9200bd, 0x00000000, 0x00000000, 0x00000000}},  //   אָס_,   ,   ,
  { {0x9c7c0006, 0x00000000, 0x00000000, 0x00000000}},  //   reči,   ,   ,
  { {0xdfd00076, 0x2eed0009, 0x7bda000c, 0x00000000}},  //   ليت_, eeef_, yttu,
  { {0x50b70054, 0x7ae41d7a, 0xfbc70389, 0x00000000}},  //   ردود_, _obit, _حت_,
  { {0x26d200e0, 0x20d2007d, 0x68ee0249, 0x00000000}},  //   ngyo_, _सावध, hebd,
  { {0x020601fb, 0xdb0200f4, 0x657e009d, 0x00000000}},  //   _язан, mplè, omph,
  { {0x7ae435fa, 0xe7b1013d, 0x00000000, 0x00000000}},  //   _abit, _जबलप,   ,
  { {0x2eed05a6, 0x6c5435fb, 0x6f0b00e5, 0x00000000}},  //   beef_, ткну, _fngc,
  { {0xf09f001d, 0xbacf0044, 0x7bda00b0, 0x00000000}},  //   _đài_, িজ্ঞ, rttu,
  { {0x6ff3006b, 0xfaff0023, 0x00000000, 0x00000000}},  //   _rəcə, llëk_,   ,
  { {0x7ae411a8, 0x63780919, 0x00000000, 0x00000000}},  //   _ebit, línd,   ,
  { {0xc6a7025f, 0x78b5089f, 0x6ed70061, 0x00000000}},  //   ерзи, razv, _यामु,
  { {0x64430036, 0x00000000, 0x00000000, 0x00000000}},  //   źnik,   ,   ,
  { {0x27350039, 0x6126000c, 0xe8d90082, 0x00000000}},  // [b8b0] _lång_, _eðli, _quỳ_,
  { {0x7afd0030, 0x48ab007c, 0x2727006c, 0x00000000}},  //   ldst, _этим_, _mõni_,
  { {0x98c40057, 0x320400ab, 0xd404007c, 0x00000000}},  //   _ссыл, _army_, ляци,
  { {0x7aef0219, 0xe8d90011, 0xa3b4013d, 0x00000000}},  //   nect, _tuỳ_, _फ़िर_,
  { {0x69dd35fc, 0x6378027b, 0x7aef000d, 0x00000000}},  //   ntse, dínd, iect,
  { {0xe61f001d, 0xa06902be, 0x69dd006c, 0x00000000}},  //   _ngôi_, мала_, itse,
  { {0x2bc502fb, 0x6296011f, 0xb4cd0061, 0x00000000}},  //   _विधा, ıyor, ळली_,
  { {0x7aef01cb, 0x7afd2c1a, 0x69dd006c, 0x00000000}},  //   ject, jdst, ktse,
  { {0x2eed0007, 0x69cf055a, 0xa195005e, 0x00000000}},  //   reef_, juce, _разч,
  { {0xdb0235fd, 0x7afd1cc8, 0x273501e3, 0x00000000}},  //   mplé, edst, _hånd_,
  { {0x7aef030a, 0x27350073, 0xfaa6003b, 0x00000000}},  //   fect, _gång_, кано,
  { {0x69dd0109, 0x637811c3, 0x2005010e, 0x00000000}},  //   ftse, ríng, _irli_,
  { {0x69cf0521, 0x2f180010, 0x7ae401f3, 0x00000000}},  //   guce, _négy_, _vbit,
  { {0x7afd0168, 0xa021006c, 0x6378013e, 0x00000000}},  //   adst, _ööse, míne,
  { {0x1867012d, 0x69dd02ae, 0x63780051, 0x00000000}},  //   вари_, atse, líne,
  { {0xc6c30680, 0xcf920049, 0xed590091, 0x00000000}},  //   ийск, שטן_, drži_,
  { {0xceb20452, 0x69dd0009, 0x69cf0035, 0x00000000}},  // [b8c0] יין_, ctse, cuce,
  { {0x61ed01d5, 0x5ea80044, 0x613400f6, 0x00000000}},  //   ħall, _গাছে, _xàld,
  { {0xf651026c, 0x6b5d0010, 0x27350190, 0x00000000}},  //   لئے_, végz, _bånd_,
  { {0x8c1a0049, 0x3329007e, 0x00000000, 0x00000000}},  //   וועי, нцін_,   ,
  { {0x80da0044, 0x273500f8, 0x067523ee, 0x00000000}},  //   _যোগ্, _sång_, _буря,
  { {0x64a3132e, 0x00000000, 0x00000000, 0x00000000}},  //   _вара,   ,   ,
  { {0x154301fb, 0x7aef0219, 0x63bc0107, 0x00000000}},  //   _терм, yect, _uvrn,
  { {0x7aef049a, 0xd007012b, 0x6d4300e5, 0x00000000}},  //   xect, ђење_, _amna,
  { {0xe0da01f9, 0x629e00b9, 0x28d3007d, 0x00000000}},  //   _ова_, ěpod, _तालि,
  { {0x69cf0107, 0x00000000, 0x00000000, 0x00000000}},  //   vuce,   ,   ,
  { {0x776d0f10, 0x637800fa, 0xeb9700e2, 0x00000000}},  //   ylax, pínd, киќ_,
  { {0x69cf00f4, 0x69dd0635, 0x7afd0190, 0x00000000}},  //   tuce, ttse, udst,
  { {0x7afd0239, 0x9c7c00ca, 0x69dd00ea, 0x00000000}},  //   rdst, veču, utse,
  { {0x69dd0da6, 0xdc5500a1, 0x69cf0253, 0x00000000}},  //   rtse, ئریک, ruce,
  { {0x6d48029d, 0x660600b0, 0x27350190, 0x00000000}},  //   mida, _arkk, _låne_,
  { {0x6d480682, 0x69dd01a2, 0x9f5e00f6, 0x00000000}},  //   lida, ptse, _ortí_,
  { {0xb0d2001c, 0x65940242, 0x7c28005b, 0x00000000}},  // [b8d0] _सांग, иату, lydr,
  { {0x6d480977, 0xb4cd0061, 0xdb0b00ea, 0x00000000}},  //   nida, ळले_, _avfø,
  { {0x61e92419, 0xe3b00025, 0x6606003c, 0x00000000}},  //   _spel, قرن_, _erkk,
  { {0x6d480518, 0xfaff0065, 0xe3b00025, 0x00000000}},  //   hida, ndë_, ترك_,
  { {0x6d48286b, 0x6b8d0058, 0xe9df07da, 0x00000000}},  //   kida, _miag, ntú_,
  { {0x3075007c, 0xe4f90049, 0x6d482378, 0x00000000}},  //   луйс, _אפֿש, jida,
  { {0x6d482b05, 0xe9df0048, 0x9982013e, 0x00000000}},  //   dida, htú_, zyků_,
  { {0xdb0200f4, 0x6b8d04cb, 0xe1f30014, 0x00000000}},  //   pplé, _niag, _پسر_,
  { {0x6d4835fe, 0x61e935ff, 0x65650058, 0x00000000}},  //   fida, _upel, oohh,
  { {0x5ba9012c, 0x672d3600, 0xacf50143, 0x00000000}},  //   нком_, hkaj, учиј,
  { {0x6b8d0197, 0xe8d90082, 0x20050026, 0x00000000}},  //   _biag, _huỷ_, _urli_,
  { {0x6b8d00b4, 0x6d48055f, 0x63783601, 0x00000000}},  //   _ciag, aida, píne,
  { {0x2bc502fb, 0xfce5013b, 0x3cfc00d9, 0x00000000}},  //   _विवा, _боло, _favv_,
  { {0x6d483602, 0x6f1b12d6, 0x82760049, 0x00000000}},  //   cida, ljuc, טערע_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x25a20022, 0x6b8d3603, 0x6f1d01a2, 0x00000000}},  //   _ptkl_, _giag, ösch,
  { {0x6e293604, 0xe57a003b, 0x635c0235, 0x00000000}},  // [b8e0] nyeb, еза_, nčne,
  { {0xdff30164, 0xd910025a, 0x2a3b00b3, 0x00000000}},  //   _आनंद_, _بیس_, _נעימ,
  { {0x6ab60279, 0xceb900b9, 0xe4d70014, 0x00000000}},  //   _keyf, kař_, اومت_,
  { {0xe73a0057, 0x6d480263, 0x672d0107, 0x00000000}},  //   _чем_, zida, ckaj,
  { {0x6d48013f, 0x00000000, 0x00000000, 0x00000000}},  //   yida,   ,   ,
  { {0x6d48027b, 0x6ab6009f, 0x66043605, 0x00000000}},  //   xida, _leyf, mvik,
  { {0x6d481596, 0x6604000c, 0x9fe60076, 0x00000000}},  //   vida, lvik, استه,
  { {0xcfe70025, 0x6d480066, 0x6e3b01a2, 0x00000000}},  //   افيه_, wida, fzub,
  { {0x10a60256, 0x6d48049a, 0x66040173, 0x00000000}},  //   _бизн, tida, nvik,
  { {0x6b8d1164, 0x2bc5007d, 0xb5f70049, 0x00000000}},  //   _siag, _विशा, נציג_,
  { {0x205606b6, 0x409306ea, 0x6d480325, 0x00000000}},  //   _стар, _المر, rida,
  { {0x8aa7007e, 0x2bc50309, 0xde960025, 0x00000000}},  //   ырод, _विरा, _إجاب,
  { {0x6b8d3606, 0x7c3a0047, 0xfe7200a1, 0x00000000}},  //   _viag, sztr, _ادا_,
  { {0x66040193, 0x68fe0129, 0xe9df0051, 0x00000000}},  //   dvik, _capd, rtú_,
  { {0xf77306dd, 0xb8fd006e, 0x6b8d0181, 0x00000000}},  //   مار_, _डा_, _tiag,
  { {0x96f800e3, 0x672d00e7, 0xd6d816b6, 0x00000000}},  //   лест_, ukaj, лту_,
  { {0x6d5d009d, 0x672d055a, 0x2d8e0173, 0x00000000}},  // [b8f0] ésag, rkaj, _kife_,
  { {0x672d12db, 0x6fea006b, 0x45d40088, 0x00000000}},  //   skaj, _məcb, софс,
  { {0xa926001e, 0x53a40025, 0x672d016e, 0x00000000}},  //   _dažā, مملك, pkaj,
  { {0x2d8e0038, 0x63780a06, 0x929d0036, 0x00000000}},  //   _life_, vínc, _małg,
  { {0xd5af026c, 0xe8d90011, 0x8627007e, 0x00000000}},  //   _رہا_, _quỷ_, _сьне,
  { {0x2cf3001c, 0x25a904d4, 0xc0c8012b, 0x00000000}},  //   _असेल_, mpal_, гуће_,
  { {0x60de0263, 0x25a900e0, 0x98b10089, 0x00000000}},  //   òpma, lpal_, lizē_,
  { {0x6d580107, 0x29040089, 0xcf250025, 0x00000000}},  //   _ajva, ēmai_, شرعي,
  { {0xed590113, 0xef160783, 0xa28301b2, 0x00000000}},  //   кои_, рмы_, _ایشو,
  { {0xd1670265, 0xed450088, 0x61fb011c, 0x00000000}},  //   _съби, рноп, _isul,
  { {0x2d8e0263, 0x610b001e, 0x6e3b06f2, 0x00000000}},  //   _dife_, _vēlē, szub,
  { {0x6a860745, 0xdb1b00fa, 0x8f9a034e, 0x00000000}},  //   илна, dutó, _סיני,
  { {0x3da7044b, 0x3ead0065, 0x68fe0173, 0x00000000}},  //   _среб, mbet_, _papd,
  { {0xdca50764, 0x3ead1ed6, 0x8b95005c, 0x00000000}},  //   _таки, lbet_, _крич,
  { {0x290400b9, 0xdb1b0010, 0x25a91163, 0x00000000}},  //   ěma_, gutó, epal_,
  { {0xb6a601be, 0x66040056, 0x7d1c18f7, 0x00000000}},  //   риал, tvik, örsv,
  { {0x68fe006b, 0x5976007c, 0x3f8f0087, 0x00000000}},  // [b900] _tapd, _выну, _migu_,
  { {0x66040368, 0x3ead014a, 0x499100a1, 0x00000000}},  //   rvik, hbet_, _ریفر,
  { {0x66e6003b, 0x66040039, 0x3cdd013d, 0x00000000}},  //   _кона, svik, _खाने_,
  { {0x78bc006c, 0xf3c9023c, 0x74130439, 0x00000000}},  //   larv, ابله_, توما,
  { {0x637803fd, 0x27f80016, 0x09e40044, 0x00000000}},  //   gína, lwrn_, মিকা,
  { {0x78bc3607, 0xfaff0065, 0x3f8f1a0f, 0x00000000}},  //   narv, llët_, _aigu_,
  { {0x61fb3608, 0x613400f6, 0x00000000, 0x00000000}},  //   _esul, _càla,   ,
  { {0x78bc01b1, 0x2327017f, 0x2d8e0ac8, 0x00000000}},  //   harv, _коси_, _sife_,
  { {0xb5fb0047, 0xad260025, 0x3f8f002d, 0x00000000}},  //   _száz, لردو, _digu_,
  { {0xdce10e0d, 0x3f8f000c, 0x61e23609, 0x00000000}},  //   bolč, _eigu_, mtol,
  { {0x3ead30e7, 0x25740039, 0x80db0061, 0x00000000}},  //   bbet_, väll_, _नाते,
  { {0x25a9001c, 0x27f80016, 0x2d8e2f94, 0x00000000}},  //   ypal_, dwrn_, _wife_,
  { {0x61e2021e, 0x9da7005e, 0x2d960072, 0x00000000}},  //   ntol, _къща_, _трес,
  { {0x27030011, 0x78bc20db, 0xdce30066, 0x00000000}},  //   _ổn_, garv, _tinġ,
  { {0xd6db0242, 0xb5fb0010, 0xed57003b, 0x00000000}},  //   кта_, _nyár, _њој_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb020039, 0x78bc11b9, 0x58d5003b, 0x00000000}},  // [b910] tslö, barv, _лопт,
  { {0x25a90145, 0x78bc0026, 0x929d0036, 0x00000000}},  //   rpal_, carv, _małe,
  { {0x75880077, 0x25a902c1, 0xdb0200f8, 0x00000000}},  //   рств_, spal_, rslö,
  { {0x2901011c, 0x25a90010, 0x52152485, 0x00000000}},  //   _haha_, ppal_, йдет,
  { {0x877a00b6, 0x10a50751, 0xfaff0065, 0x00000000}},  //   _תארי, билн, llës_,
  { {0xb34701d5, 0x69cf05d7, 0xe0d80088, 0x00000000}},  //   _saħħ, irce, иві_,
  { {0x290117f6, 0xb5fb0047, 0xdb09000c, 0x00000000}},  //   _maha_, _gyár, nsdó,
  { {0x81e60055, 0x63780161, 0x00000000, 0x00000000}},  //   _বছর_, pína,   ,
  { {0xf2d200bd, 0x61fb08a9, 0x3ead02ba, 0x00000000}},  //   _מען_, _usul, rbet_,
  { {0x68f5360a, 0x3ead0066, 0xdce301d5, 0x00000000}},  //   jezd, sbet_, _minħ,
  { {0x68f5360b, 0x00000000, 0x00000000, 0x00000000}},  //   dezd,   ,   ,
  { {0x5e950025, 0xdce70095, 0x00000000, 0x00000000}},  //   _الإط, ımıy,   ,
  { {0x8e850054, 0x78bc250b, 0x290107b1, 0x00000000}},  //   _الشه, tarv, _baha_,
  { {0x7d1c0073, 0x2b490943, 0x18a302dc, 0x00000000}},  //   örst, _emac_, зарм,
  { {0x290101f6, 0x236d0039, 0x6d4f009d, 0x00000000}},  //   _daha_, _okej_, écau,
  { {0x6abd0066, 0x78bc1603, 0xdceb0066, 0x00000000}},  //   casf, sarv, _bugħ,
  { {0x3bc3005f, 0x7bc10030, 0x78bc0daa, 0x00000000}},  // [b920] lıq_, lslu, parv,
  { {0xfaff0023, 0xba49013e, 0x00000000, 0x00000000}},  //   blës_, ulůž,   ,
  { {0x7bc100b5, 0x69c40027, 0x4abe0061, 0x00000000}},  //   nslu, _hvie, _्याव,
  { {0x61e2360c, 0x69c40006, 0x59af013d, 0x00000000}},  //   ttol, _kvie, जीकर,
  { {0x21250087, 0x7ce1000a, 0x00000000, 0x00000000}},  //   _bolh_, _kňrč,   ,
  { {0x61e2360d, 0x7bc1360e, 0x67260376, 0x00000000}},  //   rtol, kslu, _hokj,
  { {0x443e1f82, 0x7bc100bb, 0x09e40044, 0x00000000}},  //   _åt_, jslu, মিটা,
  { {0x69c4008e, 0x2903012d, 0x3bc3006b, 0x00000000}},  //   _ovie, zdja_, dıq_,
  { {0x171b0049, 0x6b4f0173, 0x8e140088, 0x00000000}},  //   רופע, _lògè, ідоц,
  { {0xccfa012b, 0x69cf016c, 0x2b490026, 0x00000000}},  //   ући_, vrce, _smac_,
  { {0x29010004, 0x351b007b, 0x69c41228, 0x00000000}},  //   _raha_, אוינ, _avie,
  { {0x290129c8, 0x447701ce, 0x00000000, 0x00000000}},  //   _saha_, מעיל_,   ,
  { {0x69cf360f, 0x4f650025, 0xf2d30049, 0x00000000}},  //   urce, _بالف, הער_,
  { {0x69c430e2, 0x63711565, 0xdd90009e, 0x00000000}},  //   _dvie, råni, _غوث_,
  { {0x2903002b, 0x6d4a3610, 0x3cdd0309, 0x00000000}},  //   rdja_, _imfa, _खाते_,
  { {0x69c40009, 0xdb09000c, 0x00000000, 0x00000000}},  //   _fvie, rsdó,   ,
  { {0x2901006c, 0x7aed3611, 0x69c0008e, 0x00000000}},  // [b930] _taha_, _ibat, ámet,
  { {0xdb1b0051, 0x6f020051, 0x200c009d, 0x00000000}},  //   istí, _laoc, _ordi_,
  { {0x69c43612, 0x69c00089, 0x00000000, 0x00000000}},  //   _zvie, šmet,   ,
  { {0x6f020107, 0x60c81042, 0xd25101af, 0x00000000}},  //   _naoc, _addm, ونا_,
  { {0x6d4a044f, 0x4cd00044, 0x200c002d, 0x00000000}},  //   _omfa, ত্যু, _ardi_,
  { {0xdb1b0f6e, 0x7bc112de, 0x3bc3006b, 0x00000000}},  //   nstâ, yslu, yıq_,
  { {0x69a002fb, 0x7aed023a, 0x200c0471, 0x00000000}},  //   _गंभी, _obat, _crdi_,
  { {0xf838019b, 0x3eb9009f, 0x200701ae, 0x00000000}},  //   מנות_, úst_, rvni_,
  { {0x200c0a3f, 0x00000000, 0x00000000, 0x00000000}},  //   _erdi_,   ,   ,
  { {0x7aed001c, 0x3bc3005f, 0x7bc10250, 0x00000000}},  //   _abat, tıq_, tslu,
  { {0x81bb0044, 0x69c431b3, 0xc4d2009b, 0x00000000}},  //   _অমি_, _svie, וגי_,
  { {0xf8a900b6, 0x7bc1009f, 0xcb6a00ed, 0x00000000}},  //   _יש_, rslu, раме_,
  { {0x2bc502fb, 0xfe700025, 0x91620082, 0x00000000}},  //   _विका, _كده_, _sử_,
  { {0x7aed006c, 0x3ebf293e, 0x2d9f00f6, 0x00000000}},  //   _ebat, laut_, mque_,
  { {0x273c002a, 0x2d9f00f4, 0x67260093, 0x00000000}},  //   _líne_, lque_, _pokj,
  { {0x7d0302bd, 0x3ebf22d7, 0x00000000, 0x00000000}},  //   _hans, naut_,   ,
  { {0x7d031382, 0x2d9f3613, 0xa52601fb, 0x00000000}},  // [b940] _kans, nque_, омад,
  { {0x2904001e, 0x7aed0065, 0x2bed03d7, 0x00000000}},  //   ēmas_, _zbat, _जहां_,
  { {0x3ebf0036, 0x0d3a0049, 0x00000000, 0x00000000}},  //   kaut_, סגעב,   ,
  { {0x7d031502, 0x4c6c0049, 0x386d01a2, 0x00000000}},  //   _lans, נדאַ, ßere_,
  { {0x26c00032, 0x3ebf00e0, 0xdb210010, 0x00000000}},  //   maio_, daut_, áték,
  { {0x752710c1, 0x26c00207, 0x257400b0, 0x00000000}},  //   _gojz, laio_, käli_,
  { {0xdfd00054, 0x256f0047, 0x3ebf00f4, 0x00000000}},  //   رية_, rült_, faut_,
  { {0x7d03049b, 0x26c00197, 0x03670242, 0x00000000}},  //   _aans, naio_, _диск_,
  { {0x7d030480, 0x320d0339, 0x2600006e, 0x00000000}},  //   _bans, _grey_, रिटी_,
  { {0x7aed0cc8, 0x6440006b, 0x200c0059, 0x00000000}},  //   _sbat, _əmin, _trdi_,
  { {0x7d030018, 0x3ebf010f, 0x2d9f263c, 0x00000000}},  //   _dans, baut_, aque_,
  { {0x3ebf3614, 0x6d4f009d, 0x00000000, 0x00000000}},  //   caut_, écar,   ,
  { {0xde03012b, 0x7d030056, 0x2d9f117e, 0x00000000}},  //   _опци, _fans, cque_,
  { {0x7d030cb2, 0x6d4a05e9, 0x00000000, 0x00000000}},  //   _gans, _umfa,   ,
  { {0x28dc013d, 0xdb1b010e, 0x7aed002b, 0x00000000}},  //   _बारि, dutö, _tbat,
  { {0x4c3b00b6, 0x7d0301aa, 0x7aed3615, 0x00000000}},  //   _כתוב, _zans, _ubat,
  { {0xd49b003b, 0x6d5a3616, 0x7d03014a, 0x00000000}},  // [b950] аре_, onta, _yans,
  { {0x25a60051, 0x00000000, 0x00000000, 0x00000000}},  //   íola_,   ,   ,
  { {0xa2f501fb, 0x6d5a0cc9, 0x273c0051, 0x00000000}},  //   зпеч, inta, _síne_,
  { {0x2cbc00ea, 0x320d0133, 0x659501ee, 0x00000000}},  //   _levd_, _prey_, _наму,
  { {0x86350049, 0xf1d50061, 0x10a500e2, 0x00000000}},  //   _זאָג_, डूंन, пилн,
  { {0x9f6501e5, 0x00000000, 0x00000000, 0x00000000}},  //   _útúr_,   ,   ,
  { {0x7d0300b0, 0xc9540097, 0x91a900a1, 0x00000000}},  //   _rans, ומס_, جنڈے_,
  { {0x7d033617, 0x660f0ebe, 0x257405e0, 0x00000000}},  //   _sans, _krck, väli_,
  { {0x7d033618, 0x3ebf00db, 0x30a70242, 0x00000000}},  //   _pans, raut_, _древ,
  { {0x2d9f0325, 0x1c4502d3, 0x3ebf009d, 0x00000000}},  //   rque_, зном, saut_,
  { {0xc4d2007b, 0x7d030056, 0x2d9f032c, 0x00000000}},  //   עגט_, _vans, sque_,
  { {0x6d5a19dd, 0x2d990489, 0x6fea005f, 0x00000000}},  //   anta, íses_, _məcl,
  { {0x7d0300b0, 0x26c00026, 0x81e90044, 0x00000000}},  //   _tans, vaio_, যিক_,
  { {0x7d0301e3, 0x00000000, 0x00000000, 0x00000000}},  //   _uans,   ,   ,
  { {0x26c00197, 0x25ab00e7, 0xdb1b1e71, 0x00000000}},  //   taio_, _atcl_, ustã,
  { {0x2d9d00e7, 0xac16003b, 0x06d40044, 0x00000000}},  //   _kuwe_, _хоћу_, হ্নি,
  { {0x26c00198, 0x3ebd002b, 0x6b840058, 0x00000000}},  // [b960] raio_, _mewt_, _ihig,
  { {0x649a2472, 0x26c00181, 0x69c63619, 0x00000000}},  //   стар_, saio_, mske,
  { {0x389b007b, 0x69c60235, 0x26c0004a, 0x00000000}},  //   _ליינ, lske, paio_,
  { {0x637800b9, 0x929d0036, 0x2d9d00bb, 0x00000000}},  //   mínk, _pała, _ouwe_,
  { {0x2d9d0343, 0x69c60c30, 0x660f0107, 0x00000000}},  //   _nuwe_, nske, _grck,
  { {0x6724089f, 0x98a40006, 0x867b009b, 0x00000000}},  //   ljij, ėmė_, _לרכו,
  { {0xb4ca0164, 0x653b0049, 0x00000000, 0x00000000}},  //   ोली_, _פעלד,   ,
  { {0x6724002b, 0x69c6109a, 0xe80d007d, 0x00000000}},  //   njij, kske, हिता_,
  { {0x4444010f, 0x69c61a2d, 0x76440180, 0x00000000}},  //   lz_, jske, nziy,
  { {0x44440061, 0x613d03eb, 0x6fea006b, 0x00000000}},  //   oz_, _pèle, _həcm,
  { {0x4444001f, 0x6d5a0c7a, 0x4c9400e2, 0x00000000}},  //   nz_, rnta, ќинс,
  { {0x44440668, 0xdee60069, 0x6b841063, 0x00000000}},  //   iz_, _ходи, _chig,
  { {0x6e930054, 0x3e8500f4, 0x6724361a, 0x00000000}},  //   _كلما, rêté_, djij,
  { {0x2bc50201, 0xfbcf00a2, 0x3f9e361b, 0x00000000}},  //   _विचा, ختی_, _kutu_,
  { {0x4444361c, 0xa4270044, 0x63a9012d, 0x00000000}},  //   jz_, _মধ্য_, _čeno,
  { {0x4444361d, 0x7bda1577, 0x3f9e0169, 0x00000000}},  //   dz_, mutu, _mutu_,
  { {0x444406d2, 0x7bda08b2, 0x69c60010, 0x00000000}},  // [b970] ez_, lutu, cske,
  { {0x272e000c, 0x2a58009b, 0xe4a40143, 0x00000000}},  //   _sýnt_, _מבחן_, ерцо,
  { {0x25f903d7, 0xe5700076, 0x9f5e0211, 0x00000000}},  //   _उनकी_, اطق_, _esté_,
  { {0x660f041a, 0x25ab361e, 0x00000000, 0x00000000}},  //   _trck, _ttcl_,   ,
  { {0x7bda17b8, 0x4444002d, 0x62341e6a, 0x00000000}},  //   hutu, az_, нецу,
  { {0x7bda02b1, 0x3f9e0964, 0x4444361f, 0x00000000}},  //   kutu, _butu_, bz_,
  { {0x44440046, 0x64e20061, 0x660d0039, 0x00000000}},  //   cz_, _पातळ, lvak,
  { {0xee3900aa, 0x273c05ee, 0x3f9e1378, 0x00000000}},  //   жни_, _kína_, _dutu_,
  { {0x4433098e, 0x660d3620, 0x6b84005b, 0x00000000}},  //   lyx_, nvak, _rhig,
  { {0x273c000c, 0x6b840f87, 0x7bda2174, 0x00000000}},  //   _mína_, _shig, futu,
  { {0x7bda023e, 0x60c31198, 0x88e30044, 0x00000000}},  //   gutu, manm, য়াক,
  { {0x60c3049d, 0x09e20044, 0x929d0036, 0x00000000}},  //   lanm, যবসা, _mało,
  { {0xba230088, 0x612f05b7, 0x6f0900d9, 0x00000000}},  //   вдяк, _følt, mdec,
  { {0x69c6068f, 0x7bda0390, 0x6f0906b9, 0x00000000}},  //   rske, butu, ldec,
  { {0x6d41002a, 0x69c62228, 0x66e601e1, 0x00000000}},  //   mhla, sske, мова,
  { {0x6f09001a, 0x629b0011, 0x2574010f, 0x00000000}},  //   ndec, _nguo, hält_,
  { {0x09e20055, 0xdb1b009f, 0xa5f700ed, 0x00000000}},  // [b980] যবহা, fstæ, меѓу_,
  { {0x44440577, 0x63780181, 0x25740039, 0x00000000}},  //   tz_, míni, jält_,
  { {0xd91b052f, 0x68fc0169, 0x60c30190, 0x00000000}},  //   _וויל, merd, danm,
  { {0x44440661, 0x68fc23c7, 0x273c01e5, 0x00000000}},  //   rz_, lerd, _fína_,
  { {0x4444268a, 0x7d080039, 0x6f090016, 0x00000000}},  //   sz_, ydds, ddec,
  { {0x44440061, 0x68fc0207, 0x60c31ba1, 0x00000000}},  //   pz_, nerd, ganm,
  { {0xd01003ec, 0x2b0e03d7, 0x7ae4040d, 0x00000000}},  //   الب_, ियाँ_, _ocit,
  { {0x68fc0016, 0x7bda03b6, 0x00000000, 0x00000000}},  //   herd, vutu,   ,
  { {0x10a6007c, 0x929d0036, 0x62800550, 0x00000000}},  //   _жизн, _zało, _uzmo,
  { {0x6d41002a, 0x7bda006a, 0x3f9e0007, 0x00000000}},  //   ghla, tutu, _tutu_,
  { {0x68fc11fe, 0x660d01c5, 0x6f092297, 0x00000000}},  //   derd, zvak, bdec,
  { {0x2cb1005d, 0x7bda01a3, 0x7ae400ea, 0x00000000}},  //   ızda_, rutu, _ccit,
  { {0x7bda0004, 0x68fc122f, 0x6d413621, 0x00000000}},  //   sutu, ferd, bhla,
  { {0x6d41001f, 0x7bda033b, 0x68fc0ee6, 0x00000000}},  //   chla, putu, gerd,
  { {0x273c009f, 0x44330061, 0xf7730647, 0x00000000}},  //   _sína_, xyx_, نار_,
  { {0x60c33622, 0xb8e6013d, 0x212c0023, 0x00000000}},  //   zanm, _उड़_, _lodh_,
  { {0x7afd0027, 0x68fc3623, 0xa3dc0061, 0x00000000}},  // [b990] mest, berd, णूस_,
  { {0x69dd0004, 0x660901ee, 0x660d29f9, 0x00000000}},  //   muse, _šeks, rvak,
  { {0x69dd0004, 0xdb1b158f, 0xfe080011, 0x00000000}},  //   luse, rstæ, _lữ_,
  { {0x44330912, 0x6d4101ca, 0x7bc80009, 0x00000000}},  //   ryx_, zhla, isdu,
  { {0xfe08001d, 0x69dd0004, 0x9294008b, 0x00000000}},  //   _nữ_, nuse, вацц,
  { {0xdb1b09b0, 0x613d0173, 0xc0e20184, 0x00000000}},  //   lstä, _bèla, гошк,
  { {0x69dd0193, 0x60c3006b, 0x6f09010f, 0x00000000}},  //   huse, ranm, tdec,
  { {0xdb1b0002, 0x7afd3624, 0x2d8c00c7, 0x00000000}},  //   nstä, jest, emde_,
  { {0x7afd021e, 0x6f0907f2, 0x6d410048, 0x00000000}},  //   dest, rdec, thla,
  { {0x69dd3625, 0xfe08001d, 0x0c25004c, 0x00000000}},  //   duse, _dữ_, емон,
  { {0x68fc0c46, 0x116a01ef, 0x69dd009d, 0x00000000}},  //   verd, _علمی_, euse,
  { {0x7afd0168, 0x60c10329, 0xf412007b, 0x00000000}},  //   gest, _helm, אפט_,
  { {0x68fc0168, 0x69dd0004, 0x60c13626, 0x00000000}},  //   terd, guse, _kelm,
  { {0xf1b2019b, 0xfc31039d, 0xfce50545, 0x00000000}},  //   רסם_, _محب_, _чоко,
  { {0x60c1059a, 0xdb1b01a2, 0x00000000, 0x00000000}},  //   _melm, fstä,   ,
  { {0x69dd2f30, 0x14e20061, 0x68fc006c, 0x00000000}},  //   buse, _पाहण, serd,
  { {0xcf92061e, 0x6996041f, 0xceb20104, 0x00000000}},  // [b9a0] רטן_, _прох, טין_,
  { {0xec09001d, 0xe5773627, 0x60c101c3, 0x00000000}},  //   _kế_, езу_, _nelm,
  { {0x2b4000ca, 0xccf2009b, 0x59d80061, 0x00000000}},  //   _klic_, רכב_, भंकर,
  { {0x44260166, 0xdcea0066, 0x661b01ed, 0x00000000}},  //   ćo_, _tifħ, _šuke,
  { {0x2d87001f, 0x200504cb, 0x635c0059, 0x00000000}},  //   _ohne_, _asli_, nčni,
  { {0x7afd0046, 0x59d30061, 0xdb1b0945, 0x00000000}},  //   zest, _तिसर, mstå,
  { {0x333f00f4, 0x60c10056, 0x7afd0056, 0x00000000}},  //   _flux_, _delm, yest,
  { {0x7afd049a, 0x60c10004, 0x8003007c, 0x00000000}},  //   xest, _eelm, учше,
  { {0xdb1b0c88, 0x60c109e9, 0x91620011, 0x00000000}},  //   nstå, _felm, _từ_,
  { {0x7afd0036, 0x60c1011f, 0x69dd0004, 0x00000000}},  //   west, _gelm, vuse,
  { {0x2b40003b, 0x69dd0061, 0x7afd0585, 0x00000000}},  //   _blic_, wuse, test,
  { {0x69dd0004, 0x26c23628, 0xec090011, 0x00000000}},  //   tuse, _neko_, _dế_,
  { {0x7afd0585, 0xdb1b0039, 0x60c1004a, 0x00000000}},  //   rest, vstä, _yelm,
  { {0x7afd0f3c, 0x69dd006c, 0xe80d0061, 0x00000000}},  //   sest, ruse, हिला_,
  { {0x69dd2153, 0xdb1b0002, 0xd7f81c4a, 0x00000000}},  //   suse, tstä, нут_,
  { {0x69dd1f37, 0x26c21e36, 0x7d0a000c, 0x00000000}},  //   puse, _ceko_, _hafs,
  { {0xdb1b03a9, 0x7d0a0065, 0xa5f80088, 0x00000000}},  // [b9b0] rstä, _kafs, нету_,
  { {0xdb1b0a5d, 0xfaff0007, 0x6fea006b, 0x00000000}},  //   sstä, leë_, _təch,
  { {0xec090011, 0x9f4706b8, 0x660600e0, 0x00000000}},  //   _xế_, stné_, _eskk,
  { {0xd6db222e, 0x60c101aa, 0xd3240077, 0x00000000}},  //   _это_, _selm, льчи,
  { {0x39840039, 0xa2cd0164, 0x52740143, 0x00000000}},  //   lösa_, दृष्, лушу,
  { {0x7d0a16da, 0xd18401e1, 0x200a002b, 0x00000000}},  //   _nafs, глій, _ġbir_,
  { {0xe81402d2, 0x60c1004f, 0x3cfe00c4, 0x00000000}},  //   डिया_, _velm, detv_,
  { {0x27e70073, 0x4394007c, 0x60c12ba6, 0x00000000}},  //   _ännu_, _басс, _welm,
  { {0x60c101aa, 0x5f760025, 0x1ea80014, 0x00000000}},  //   _telm, خميس_, رايي_,
  { {0x29cd0027, 0x635c0059, 0x6aad0258, 0x00000000}},  //   dľa_, včni, _afaf,
  { {0xcb6a005e, 0xbb4600ed, 0x2b403629, 0x00000000}},  //   дане_, венк, _plic_,
  { {0xec090082, 0x00000000, 0x00000000, 0x00000000}},  //   _vế_,   ,   ,
  { {0x26c200ca, 0xee2e00d7, 0x613400f6, 0x00000000}},  //   _reko_, _тн_, _vàlv,
  { {0x49990057, 0xec09001d, 0x23d102fb, 0x00000000}},  //   ется_, _tế_, _हिंद,
  { {0x929d0036, 0x69ce0061, 0x8c420242, 0x00000000}},  //   _całk, _तिकी, _веще,
  { {0xdb1b342b, 0x752e0521, 0x41d2013d, 0x00000000}},  //   tstå, _sobz, _सिलस,
  { {0x9676008b, 0x6f0b00d2, 0x00000000, 0x00000000}},  // [b9c0] тыві, _magc,   ,
  { {0xdb1b03bd, 0x1dd4001c, 0xb4cc0061, 0x00000000}},  //   rstå, _दिसत, ळणे_,
  { {0xd7ca007a, 0xd4f5007e, 0x26c20997, 0x00000000}},  //   _توجه_, ыяты, _teko_,
  { {0xdb1b17db, 0xdceb0089, 0x6f0b0087, 0x00000000}},  //   pstå, _augļ, _nagc,
  { {0xe297012b, 0xcb130097, 0x7af60065, 0x00000000}},  //   вац_, ילא_, _mbyt,
  { {0x6604049a, 0x395800f4, 0xdfd005f3, 0x00000000}},  //   mwik, nirs_, ميت_,
  { {0xa87a0049, 0x3cfe0203, 0x7d0a01e5, 0x00000000}},  //   ואַר, vetv_, _rafs,
  { {0x3ce7000a, 0x6f0b10f0, 0x00000000, 0x00000000}},  //   _acnv_, _cagc,   ,
  { {0x613400d4, 0xf4e40044, 0x6f0b362a, 0x00000000}},  //   _bàlt, নজীব, _dagc,
  { {0x27fa00ca, 0x00000000, 0x00000000, 0x00000000}},  //   _oppn_,   ,   ,
  { {0x3cfe000a, 0xa3b60061, 0x6aad01a2, 0x00000000}},  //   retv_, चीच_, _pfaf,
  { {0xee3a012b, 0x005700b3, 0x613400f6, 0x00000000}},  //   _оне_, _בשבת_, _vàlu,
  { {0x7d0a362b, 0x6d86000c, 0x6f0000e7, 0x00000000}},  //   _tafs, rðab, memc,
  { {0xf99f01aa, 0x27fa0093, 0x672f2db7, 0x00000000}},  //   twèb_, _bppn_, _socj,
  { {0x63780b32, 0x57a4362c, 0x3cfb009b, 0x00000000}},  //   níns, ишта, _חלונ,
  { {0x2d9c0606, 0xd6d80099, 0x48e30055, 0x00000000}},  //   _hive_, кту_, য়ের,
  { {0x69c000c4, 0xf794007e, 0x66040058, 0x00000000}},  // [b9d0] âmet, ратэ, gwik,
  { {0xf8b702fb, 0x7af6197c, 0x2d9c14f9, 0x00000000}},  //   _अभिय, _zbyt, _jive_,
  { {0x82d900d7, 0xc7ab0025, 0x7afa0010, 0x00000000}},  //   едес_, _تدخل_, őtte,
  { {0x6f000387, 0x6604000a, 0x00000000, 0x00000000}},  //   jemc, bwik,   ,
  { {0xd179007e, 0x66040146, 0x66f600a3, 0x00000000}},  //   нскі_, cwik, _גמרא_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ff50380, 0x5ebe0044, 0xdb020056, 0x00000000}},  //   استا, োলনে, pplø,
  { {0xaf0516e0, 0x64580036, 0x00000000, 0x00000000}},  //   упил, ócił,   ,
  { {0x2018000c, 0x6f0b0190, 0x9f5e00f6, 0x00000000}},  //   _árin_, _vagc, _artó_,
  { {0x9f5e04bd, 0x63780051, 0x7f42301e, 0x00000000}},  //   _està_, sínt, _eloq,
  { {0x6f0b0e89, 0x7f42362d, 0xccf800b9, 0x00000000}},  //   _tagc, _floq, mněl_,
  { {0x660400e0, 0x273500f8, 0xa09a0049, 0x00000000}},  //   ywik, _måns_, _װינט,
  { {0x2d9c00ab, 0x9f4701dc, 0xdd8e0123, 0x00000000}},  //   _five_, ntní_, توی_,
  { {0x2d9c1ef2, 0x61fb01c3, 0x9876003b, 0x00000000}},  //   _give_, _mpul, губљ,
  { {0x7d01101e, 0x1867026b, 0x39580026, 0x00000000}},  //   mels, гари_, rirs_,
  { {0x290c0119, 0x6604049b, 0x3958028c, 0x00000000}},  //   žda_, twik, sirs_,
  { {0x395800f6, 0x93cb00a1, 0x056635ac, 0x00000000}},  // [b9e0] pirs_, ہانہ_, гван,
  { {0x7d010190, 0x66040116, 0x27350039, 0x00000000}},  //   nels, rwik, _sånt_,
  { {0x48e9001c, 0x0d3a0049, 0x6604055f, 0x00000000}},  //   _जातो_, עגעב, swik,
  { {0xb7db0097, 0x71a6007e, 0xf26a0745, 0x00000000}},  //   _אקטי, гадз, ниел_,
  { {0x7d010239, 0x00000000, 0x00000000, 0x00000000}},  //   kels,   ,   ,
  { {0x64a3008b, 0x7d010030, 0x00000000, 0x00000000}},  //   _гара, jels,   ,
  { {0x2d9c0263, 0x7d0127a1, 0x6f00362e, 0x00000000}},  //   _rive_, dels, temc,
  { {0x2d9c00ca, 0x6d430203, 0x2dd4007c, 0x00000000}},  //   _sive_, _alna, ажир,
  { {0x7d0102fa, 0x443a175b, 0xd266004d, 0x00000000}},  //   fels, lyp_, _скай,
  { {0x7d01068f, 0x61e20006, 0xdb1b08e0, 0x00000000}},  //   gels, muol, lstø,
  { {0x9f5e362f, 0x7ee60025, 0x0577009b, 0x00000000}},  //   _está_, _مكان, רגים_,
  { {0xe9f90082, 0x6d43013f, 0x543b0049, 0x00000000}},  //   _ngả_, _elna, געטא,
  { {0x7d0123dc, 0x2d9c0181, 0x2b593630, 0x00000000}},  //   bels, _tive_, risc_,
  { {0xdd8f0d0b, 0x7d010089, 0xdd9004b1, 0x00000000}},  //   _فون_, cels, _بوت_,
  { {0x273c001d, 0x3f9d1163, 0x6d480051, 0x00000000}},  //   _kính_, _yiwu_, mhda,
  { {0x6d5a0d8a, 0x8c1b00b3, 0x61e23631, 0x00000000}},  //   lita, _טווי, kuol,
  { {0x613d0263, 0x6b8d22dc, 0x7c3a00ea, 0x00000000}},  // [b9f0] _sèlm, _ihag, lytr,
  { {0x6d5a2c49, 0x273c0011, 0x6d480082, 0x00000000}},  //   nita, _lính_, nhda,
  { {0x2903023a, 0x61fb00b5, 0x02d00061, 0x00000000}},  //   meja_, _spul, हणून,
  { {0x6d5a000b, 0x5215022a, 0x7d0100bb, 0x00000000}},  //   hita, идет, zels,
  { {0x6d5a0149, 0x90c5008b, 0x7d01032e, 0x00000000}},  //   kita, абле, yels,
  { {0x6d5a1102, 0xdb04008d, 0x672d0209, 0x00000000}},  //   jita, _punë, ljaj,
  { {0x7d0111b6, 0x9f4713c7, 0x4ab50061, 0x00000000}},  //   vels, stní_, ंडाव,
  { {0x613d01aa, 0x7d010fb6, 0xcb140061, 0x00000000}},  //   _kèlk, wels, _तोंड_,
  { {0x6d5a3632, 0x7d010224, 0x3f83001e, 0x00000000}},  //   fita, tels, ēju_,
  { {0x6d5a3633, 0xa3dc0061, 0x6d480051, 0x00000000}},  //   gita, णूक_, ghda,
  { {0x7d0100eb, 0x69dd0112, 0x6b8d0051, 0x00000000}},  //   rels, erse, _bhag,
  { {0x7d01004e, 0x6b8d0020, 0x672d008e, 0x00000000}},  //   sels, _chag, jjaj,
  { {0x9f04026c, 0x672d003b, 0x6d5a01cb, 0x00000000}},  //   _دونو, djaj, bita,
  { {0x6d5a04bd, 0x6d4823bb, 0x2903006c, 0x00000000}},  //   cita, chda, geja_,
  { {0x6c790049, 0x63a70059, 0x5c790049, 0x00000000}},  //   _באַפ, _nujn, _באַה,
  { {0x6b8d01f3, 0x00000000, 0x00000000, 0x00000000}},  //   _ghag,   ,   ,
  { {0x4b7b052f, 0x6aa43634, 0x7b080089, 0x00000000}},  // [ba00] _באקו, _igif, āstī,
  { {0xf53f05cb, 0x443a0f86, 0x14c80014, 0x00000000}},  //   _står_, typ_, اهای_,
  { {0x69c40066, 0x00000000, 0x00000000, 0x00000000}},  //   _hwie,   ,   ,
  { {0x6d5a28f8, 0x1bf6007b, 0x2bf600a3, 0x00000000}},  //   zita, יצער_, ימען_,
  { {0x65770061, 0x6d5a08cb, 0xdb1b01e3, 0x00000000}},  //   boxh, yita, rstø,
  { {0x6d5a049a, 0x61e20419, 0x41530088, 0x00000000}},  //   xita, ruol, овіс,
  { {0x4034008b, 0x6d5a3635, 0x61e23636, 0x00000000}},  //   сейс, vita, suol,
  { {0x61e22bb3, 0x29032e3f, 0xd1160061, 0x00000000}},  //   puol, zeja_, _धोरण_,
  { {0x6d5a04bd, 0x6b8d018e, 0xe2970088, 0x00000000}},  //   tita, _rhag, _ват_,
  { {0x69dd037e, 0x6b8d3637, 0x23660091, 0x00000000}},  //   vrse, _shag, lnoj_,
  { {0x273c00ad, 0xa3c90309, 0x6b8d066d, 0x00000000}},  //   _tính_, लीप_, _phag,
  { {0x69cf0190, 0x60c803b1, 0x7f490691, 0x00000000}},  //   tsce, _hedm, cheq,
  { {0x29030308, 0x69dd3638, 0x6e3b0009, 0x00000000}},  //   teja_, urse, cyub,
  { {0x69c41f27, 0x69cf0a75, 0x6440006b, 0x00000000}},  //   _dwie, rsce, _əmir,
  { {0x2903029d, 0x6b8d0051, 0x6d580009, 0x00000000}},  //   reja_, _thag, _imva,
  { {0x29031329, 0x63a7016e, 0x6b8d11a8, 0x00000000}},  //   seja_, _rujn, _uhag,
  { {0xa3c90316, 0x23660119, 0x672d0059, 0x00000000}},  // [ba10] लीन_, dnoj_, rjaj,
  { {0x64410004, 0x4a7c009b, 0xe9df1445, 0x00000000}},  //   _ülik, _ברחב, mrú_,
  { {0x69c40046, 0x628000fa, 0x93f502be, 0x00000000}},  //   _zwie, _aymo, спец,
  { {0x63a026e4, 0xc7b2009b, 0x9295007e, 0x00000000}},  //   _cimn, _מבט_, баец,
  { {0x6280018e, 0x63a002aa, 0x6d5807a2, 0x00000000}},  //   _cymo, _dimn, _omva,
  { {0x2bac0224, 0xb4b8025a, 0x62801e11, 0x00000000}},  //   _něco_, _نافذ_, _dymo,
  { {0xe9df002a, 0x7aed00f6, 0x7f49009d, 0x00000000}},  //   hrú_, _ocat, theq,
  { {0x75351bc0, 0x23660107, 0x929d0036, 0x00000000}},  //   _hozz, cnoj_, _bałt,
  { {0x6d86009f, 0x7f490065, 0x62800016, 0x00000000}},  //   rðan, rheq, _gymo,
  { {0x63a00387, 0x41540ae0, 0x61e60039, 0x00000000}},  //   _zimn, _двус, _åkla,
  { {0x69c43639, 0x7aed0061, 0x753517f4, 0x00000000}},  //   _swie, _bcat, _mozz,
  { {0x6fea006b, 0x75350026, 0xa3c90164, 0x00000000}},  //   _təcr, _lozz, लीय_,
  { {0x3da701f9, 0x3ebf0149, 0x5f740025, 0x00000000}},  //   _треб, mbut_, _بالر,
  { {0x4e7a007b, 0x75352525, 0x7aed058b, 0x00000000}},  //   _גאנצ, _nozz, _ecat,
  { {0xa7860379, 0x7aed0009, 0x6d410190, 0x00000000}},  //   مشرو, _fcat, mkla,
  { {0x6d410039, 0x7aed0051, 0x6b6b0036, 0x00000000}},  //   lkla, _gcat, lęgn,
  { {0xd62711a6, 0x23660091, 0xe9df0051, 0x00000000}},  // [ba20] боте_, vnoj_, crú_,
  { {0x4cd90055, 0x6d41010a, 0x75350197, 0x00000000}},  //   ব্রু, nkla, _cozz,
  { {0x23660091, 0x75350197, 0x395a0277, 0x00000000}},  //   tnoj_, _dozz, _imps_,
  { {0xd3790088, 0x00000000, 0x00000000, 0x00000000}},  //   ачі_,   ,   ,
  { {0x26c0156d, 0x23660091, 0x6d41000c, 0x00000000}},  //   mbio_, rnoj_, kkla,
  { {0x75350cff, 0x23660091, 0x6d4100bb, 0x00000000}},  //   _gozz, snoj_, jkla,
  { {0x63a0363a, 0x6d4107e4, 0x62800036, 0x00000000}},  //   _timn, dkla, _wymo,
  { {0x543b0049, 0x62800016, 0x6d410772, 0x00000000}},  //   _געלא, _tymo, ekla,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf1bf00b9, 0x7aed051b, 0xd6c00044, 0x00000000}},  //   ášen_, _scat, েলিয,
  { {0xdefa0057, 0x30860054, 0x9f4704bb, 0x00000000}},  //   _был_, _الاف, stná_,
  { {0x395a0133, 0x00000000, 0x00000000, 0x00000000}},  //   _amps_,   ,   ,
  { {0x6e960025, 0x395a0022, 0x09e4007e, 0x00000000}},  //   _الشا, _bmps_, поўн,
  { {0x6d410039, 0x273c000c, 0x3f8401d5, 0x00000000}},  //   ckla, _mínu_, llmu_,
  { {0x753531a6, 0xa8990245, 0x273c01e5, 0x00000000}},  //   _rozz, ркву_, _línu_,
  { {0x6b460051, 0x75350638, 0xdb1b01a2, 0x00000000}},  //   _tóga, _sozz, nstü,
  { {0xa53500ed, 0x7535363b, 0x54a70025, 0x00000000}},  // [ba30] онач, _pozz, محاف,
  { {0x98c70242, 0x00000000, 0x00000000, 0x00000000}},  //   _усил,   ,   ,
  { {0x26c00207, 0x293801ce, 0x63550088, 0x00000000}},  //   bbio_, _לאזן_, овжу,
  { {0xdb1b000c, 0xd8b80014, 0x00000000, 0x00000000}},  //   mstó, _پدیا_,   ,
  { {0x75350197, 0x6d41074d, 0x65950545, 0x00000000}},  //   _tozz, ykla, _маму,
  { {0xa5bb009f, 0x2b491e13, 0x3ea600e0, 0x00000000}},  //   _próf, _llac_, _agot_,
  { {0x6d410039, 0x6d86000c, 0xa5bb0051, 0x00000000}},  //   vkla, rðal, _bróg,
  { {0xfe4500ed, 0x26cb01ee, 0x291300f6, 0x00000000}},  //   жнио, _jeco_, _laxa_,
  { {0xee36045a, 0x6d410af1, 0x3ebf0995, 0x00000000}},  //   жны_, tkla, rbut_,
  { {0xbc19007e, 0x2b4900e5, 0xdb1b0036, 0x00000000}},  //   аімі_, _alac_, kstó,
  { {0x2b490544, 0x25a300bb, 0x6e240066, 0x00000000}},  //   _blac_, _mijl_, _ġibe,
  { {0xa3e102d2, 0x6e24016e, 0x395a112d, 0x00000000}},  //   _दिन_, _šibe, _smps_,
  { {0xa3c90061, 0x6d410bc7, 0x21250022, 0x00000000}},  //   लीत_, pkla, _knlh_,
  { {0x07a6363c, 0x26d90056, 0x25a300d9, 0x00000000}},  //   жавн, _adso_, _nijl_,
  { {0xe73a16c4, 0x98a30545, 0x26cb363d, 0x00000000}},  //   аев_, дире, _beco_,
  { {0x661d0059, 0x236d0059, 0x26cb04c6, 0x00000000}},  //   _brsk, _njej_, _ceco_,
  { {0x26c0027b, 0x80ca0055, 0x26cb2701, 0x00000000}},  // [ba40] rbio_, _রাস্, _deco_,
  { {0x661d04eb, 0x00000000, 0x00000000, 0x00000000}},  //   _drsk,   ,   ,
  { {0x273c000c, 0x661d01d6, 0x2d85363e, 0x00000000}},  //   _sínu_, _ersk, ille_,
  { {0x03260242, 0xa5bb0d28, 0x25b90022, 0x00000000}},  //   юден, _bród, _ftsl_,
  { {0x6726002b, 0xb77b0049, 0x2d090164, 0x00000000}},  //   _inkj, _כאטש, _वसूल_,
  { {0x6143007c, 0x00000000, 0x00000000, 0x00000000}},  //   меча,   ,   ,
  { {0x273c000c, 0xb4e6006e, 0x00000000, 0x00000000}},  //   _fínt_, फली_,   ,
  { {0x236d008d, 0x6d86000c, 0xf1b90087, 0x00000000}},  //   _gjej_, rðam, _ftš_,
  { {0xdb1b010f, 0xcd06005c, 0x00000000, 0x00000000}},  //   rstü, очни,   ,
  { {0xdd9006dd, 0xdb1b068d, 0x00000000, 0x00000000}},  //   عود_, mpté,   ,
  { {0x2b491507, 0x46aa0204, 0x61e20109, 0x00000000}},  //   _plac_, कशाह, lrol,
  { {0x2d8500b0, 0x201e00b0, 0x9f5e16ff, 0x00000000}},  //   alle_, _irti_, _opté_,
  { {0xf2d3012f, 0xfd0f00d3, 0x26cb00f8, 0x00000000}},  //   וער_, رجی_, _reco_,
  { {0x26cb0285, 0x201e012d, 0x67260146, 0x00000000}},  //   _seco_, _krti_, _ankj,
  { {0x7d081c1a, 0x6d4a0026, 0x661d012d, 0x00000000}},  //   meds, _ilfa, _srsk,
  { {0x661d016e, 0x7d08363f, 0x25b90145, 0x00000000}},  //   _prsk, leds, _ptsl_,
  { {0x29131c37, 0x25a300bb, 0x26cb0089, 0x00000000}},  // [ba50] _taxa_, _pijl_, _veco_,
  { {0x61e20adc, 0x7d08004e, 0x201e1d1d, 0x00000000}},  //   drol, neds, _orti_,
  { {0x61e200d4, 0xf3f9005e, 0xfa3400a6, 0x00000000}},  //   erol, снеш_, _فرید,
  { {0x7d080018, 0x80ca0055, 0x4bfb0049, 0x00000000}},  //   heds, _রাষ্, שלאס,
  { {0x61e2002d, 0x201e3640, 0x2d8525b9, 0x00000000}},  //   grol, _arti_, ylle_,
  { {0x2b920027, 0x201e0022, 0x660d047b, 0x00000000}},  //   máce_, _brti_, mwak,
  { {0x236d0039, 0x660d0022, 0x7d080009, 0x00000000}},  //   _tjej_, lwak, deds,
  { {0x6d4a049a, 0x81aa0055, 0x61e2007f, 0x00000000}},  //   _alfa, _খবর_, brol,
  { {0x61e20129, 0x2d8500d4, 0x802700a1, 0x00000000}},  //   crol, tlle_, _ڈرام,
  { {0xc5f200b3, 0x613d00f6, 0x7d080d22, 0x00000000}},  //   עדי_, _cèlt, geds,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x660d0093, 0x6d4a2a22, 0xdb0400fa, 0x00000000}},  //   kwak, _elfa, _tuní,
  { {0x7d083641, 0x4a43005e, 0x00000000, 0x00000000}},  //   beds, еняв,   ,
  { {0xfbd10054, 0xdce10089, 0x00000000, 0x00000000}},  //   _كتب_, rolē,   ,
  { {0xeb9a20d2, 0x99190088, 0x613d00f6, 0x00000000}},  //   _лик_, ціях_, _hèls,
  { {0xcc3a007b, 0x38650a87, 0x61e20133, 0x00000000}},  //   _לעצט, úlra_, yrol,
  { {0xa3c9024c, 0xe737007c, 0x273c000c, 0x00000000}},  // [ba60] लीस_, чет_, _síns_,
  { {0x458300ed, 0x2bc2007d, 0x3dbd0044, 0x00000000}},  //   егув, वीका, _ইটাল,
  { {0x491502fb, 0x493b009b, 0x29183642, 0x00000000}},  //   _फोटो_, _הגיו, mdra_,
  { {0x7d080046, 0x2918021a, 0x290a0142, 0x00000000}},  //   zeds, ldra_, leba_,
  { {0x26d2011c, 0xe5a60954, 0x613d000a, 0x00000000}},  //   mayo_, _хиги, _nèls,
  { {0x29180073, 0xe4da06c6, 0x61e20219, 0x00000000}},  //   ndra_, _دوست_, rrol,
  { {0x9f98080d, 0x7d0801e3, 0x657e06fa, 0x00000000}},  //   овку_, veds, moph,
  { {0x64a3008b, 0x26d20e1a, 0x290a0173, 0x00000000}},  //   _часа, nayo_, heba_,
  { {0x7d0804b3, 0x63ae00b9, 0x60da0009, 0x00000000}},  //   teds, _hubn, _tdtm,
  { {0x657e0ace, 0x63ae016c, 0x26d200e7, 0x00000000}},  //   noph, _kubn, hayo_,
  { {0x7d080030, 0x290a0173, 0x201e1a48, 0x00000000}},  //   reds, deba_, _urti_,
  { {0x26d200e7, 0xbebd0089, 0x657e0133, 0x00000000}},  //   jayo_, sjūr, hoph,
  { {0x26d2107e, 0x63ae0504, 0x657e0146, 0x00000000}},  //   dayo_, _lubn, koph,
  { {0xada300ed, 0x290a0006, 0x6d4a0022, 0x00000000}},  //   _зачл, geba_, _ulfa,
  { {0xd6db3643, 0x657e06fa, 0x6cfb009b, 0x00000000}},  //   йта_, doph, _הפוס,
  { {0x29183644, 0x26d20058, 0x7bd80066, 0x00000000}},  //   adra_, gayo_, _ivvu,
  { {0xaac302f4, 0x4ac302fb, 0x290a0020, 0x00000000}},  // [ba70] _व्यक, _व्यव, beba_,
  { {0xa5bb0e17, 0xd49b0265, 0x290a0181, 0x00000000}},  //   _prób, бре_, ceba_,
  { {0x26d20e19, 0x7afd01d6, 0xa5bb00d6, 0x00000000}},  //   bayo_, ofst, _bróc,
  { {0x1ddd013d, 0x63ae01ca, 0x26d2004a, 0x00000000}},  //   _मिलत, _dubn, cayo_,
  { {0xdb0200f8, 0x63bc000a, 0x00000000, 0x00000000}},  //   pplö, _etrn,   ,
  { {0xf8bf0201, 0x2bac00b9, 0xdca60025, 0x00000000}},  //   ्रिय, _těch_, _لى_,
  { {0xe0d003ec, 0x7bdc0010, 0xaf950184, 0x00000000}},  //   ازه_, árul, мшиј,
  { {0x39840002, 0x290a0046, 0x321f001d, 0x00000000}},  //   löst_, zeba_, _truy_,
  { {0x1ddd0061, 0x63ae0161, 0xdb08000c, 0x00000000}},  //   _मिळत, _zubn, ílík,
  { {0x61e415a1, 0x1c452e44, 0x853a0049, 0x00000000}},  //   áile, дном, ַגרי,
  { {0x6f0901f3, 0x776d0009, 0x7afd09b0, 0x00000000}},  //   peec, knax, ffst,
  { {0x657e287f, 0x290a0058, 0x00000000, 0x00000000}},  //   zoph, weba_,   ,
  { {0x290a033f, 0x26d20045, 0x00000000, 0x00000000}},  //   teba_, vayo_,   ,
  { {0x7aef001c, 0x26d200e7, 0x2005008a, 0x00000000}},  //   agct, wayo_, _kpli_,
  { {0x26d211b3, 0x290a1786, 0x29182280, 0x00000000}},  //   tayo_, reba_, rdra_,
  { {0x7aef001c, 0x7bc123b4, 0x290a002d, 0x00000000}},  //   cgct, mplu, seba_,
  { {0x63ae2ac7, 0x6b843645, 0x26d20922, 0x00000000}},  // [ba80] _subn, _ikig, rayo_,
  { {0x26d23646, 0x00000000, 0x00000000, 0x00000000}},  //   sayo_,   ,   ,
  { {0xe73a0200, 0x7bc10032, 0xa3c90067, 0x00000000}},  //   _ден_, nplu, लील_,
  { {0x27e50027, 0x657e287f, 0xd62a0783, 0x00000000}},  //   álne_, soph, _доме_,
  { {0x75490047, 0x2bac00b9, 0x20053647, 0x00000000}},  //   ászó, _věci_, _apli_,
  { {0xa5bb0036, 0x7bc100bb, 0x5183004d, 0x00000000}},  //   _wróc, kplu, куща,
  { {0x6b640010, 0xdb1b2d3c, 0xa5bb0048, 0x00000000}},  //   zőga, mstö, _tróc,
  { {0x8e14025f, 0x444405a9, 0x61eb0026, 0x00000000}},  //   едиц, my_, bugl,
  { {0x44440387, 0x753c1551, 0x3ea20039, 0x00000000}},  //   ly_, _korz, äkt_,
  { {0x444401d6, 0xdb1b3648, 0xe2a6000c, 0x00000000}},  //   oy_, nstö, áðum_,
  { {0x44440df0, 0x8c4300ed, 0x753c0036, 0x00000000}},  //   ny_, веќе, _morz,
  { {0x7afd01a2, 0x44440258, 0x00000000, 0x00000000}},  //   ufst, iy_,   ,
  { {0x4444004f, 0xc333019b, 0x527b0049, 0x00000000}},  //   hy_, דור_, ַנלא,
  { {0x44440428, 0x6b840b99, 0x6e22013e, 0x00000000}},  //   ky_, _ekig, _irob,
  { {0x80d30055, 0x7afd01a2, 0x00000000, 0x00000000}},  //   _সাম্, pfst,   ,
  { {0xf7700137, 0x7d18192d, 0x7d1a00eb, 0x00000000}},  //   لاق_, _havs, ldts,
  { {0x753c3649, 0xddc90036, 0xa5f8003b, 0x00000000}},  // [ba90] _borz, czeń, мету_,
  { {0x7d1a0302, 0x444400ab, 0x6d480006, 0x00000000}},  //   ndts, fy_, nkda,
  { {0x444413ae, 0x36d5007c, 0x7985008a, 0x00000000}},  //   gy_, _понр, _ikhw,
  { {0x1635005e, 0x6e220032, 0x661b364a, 0x00000000}},  //   _земя, _orob, _šuku,
  { {0x753c0207, 0x44441dc0, 0xb6ba00a0, 0x00000000}},  //   _forz, ay_, _מצרי,
  { {0x44441712, 0x6f0200d4, 0x7d180142, 0x00000000}},  //   by_, _aboc, _navs,
  { {0x62860378, 0x44440652, 0x6e2200e7, 0x00000000}},  //   _økon, cy_, _arob,
  { {0xee390069, 0x6e22364b, 0x61eb0026, 0x00000000}},  //   зни_, _brob, pugl,
  { {0xe1f004e8, 0x7bc10288, 0x00000000, 0x00000000}},  //   _نسل_, wplu,   ,
  { {0x31590b03, 0x29cd1a47, 0x6aad0129, 0x00000000}},  //   _علاج_, dža_, _agaf,
  { {0x63a901d5, 0x6e220c7a, 0x6b660893, 0x00000000}},  //   _kien, _erob, екна,
  { {0xf98900a0, 0x63a9002b, 0x09e60088, 0x00000000}},  //   _הר_, _jien, номн,
  { {0x44440046, 0x63a90219, 0xdc3b0746, 0x00000000}},  //   zy_, _mien, _išče,
  { {0x63a9028c, 0x6f1b1f38, 0x7f8500c4, 0x00000000}},  //   _lien, lduc, róqu,
  { {0x6e220046, 0x6b460489, 0xe7eb0061, 0x00000000}},  //   _zrob, _lógi, जूला_,
  { {0x44440428, 0xe73701f9, 0x63a9364c, 0x00000000}},  //   vy_, нес_, _nien,
  { {0x44440046, 0xb8f60055, 0x673d364d, 0x00000000}},  // [baa0] wy_, _হা_, _dosj,
  { {0x63a9009d, 0xdce10006, 0x649a00e2, 0x00000000}},  //   _aien, rolė, птер_,
  { {0x63a9364e, 0xdb1b364f, 0x44440a5f, 0x00000000}},  //   _bien, rstö, uy_,
  { {0x44440a8a, 0x291a000b, 0x63a90219, 0x00000000}},  //   ry_, _hapa_, _cien,
  { {0x44440395, 0x63a92e3a, 0x291a0058, 0x00000000}},  //   sy_, _dien, _kapa_,
  { {0x63a93650, 0xdb040181, 0xa5bb3651, 0x00000000}},  //   _eien, _funç, _krón,
  { {0x291a049a, 0x63a901c9, 0xa2c70061, 0x00000000}},  //   _mapa_, _fien, ारख्,
  { {0x291a001e, 0x7d180089, 0xdb0b0292, 0x00000000}},  //   _lapa_, _savs, _utfø,
  { {0x628900e0, 0x00000000, 0x00000000, 0x00000000}},  //   _gyeo,   ,   ,
  { {0x291a0487, 0x63a9022b, 0xd24f0025, 0x00000000}},  //   _napa_, _zien, _انك_,
  { {0x6d4800b5, 0x6f190a2e, 0x6f1b00f6, 0x00000000}},  //   rkda, _fawc, bduc,
  { {0x6e2204bd, 0x59dc013d, 0x00000000, 0x00000000}},  //   _trob, _बिखर,   ,
  { {0x7d18011f, 0x22460010, 0x673d0036, 0x00000000}},  //   _tavs, nyok_, _rosj,
  { {0xa3e103d7, 0x291a0181, 0x29cd0d90, 0x00000000}},  //   _दिल_, _capa_, rža_,
  { {0x44330846, 0x673d0182, 0xf7730076, 0x00000000}},  //   xxx_, _posj, هار_,
  { {0x7bda1c23, 0x2d8c0039, 0x478801fc, 0x00000000}},  //   mstu, llde_, есум_,
  { {0x7bda0a74, 0x63a9133c, 0x44230521, 0x00000000}},  // [bab0] lstu, _rien, _srj_,
  { {0x63a90219, 0x44232224, 0xd49b0072, 0x00000000}},  //   _sien, _prj_, пре_,
  { {0x63a9021e, 0x9cd700b6, 0x2d9e0250, 0x00000000}},  //   _pien, גובה_, imte_,
  { {0x7bda3652, 0x2d9e01a2, 0xdb19013e, 0x00000000}},  //   istu, hmte_, _otví,
  { {0x63a90ebc, 0x213e0038, 0x22460047, 0x00000000}},  //   _vien, _both_, gyok_,
  { {0x7bda3653, 0x26c92a9f, 0xdb04010f, 0x00000000}},  //   kstu, lbao_, _zunä,
  { {0x63a90219, 0x7f490065, 0x00000000, 0x00000000}},  //   _tien, tkeq,   ,
  { {0x2d8c00c7, 0x61e43654, 0x212c0022, 0x00000000}},  //   elde_, šila, _endh_,
  { {0xb115026b, 0xc11507d8, 0x6f1b0197, 0x00000000}},  //   _имаш, _имај, rduc,
  { {0x7bda0007, 0x2d8c00ea, 0xdca502ea, 0x00000000}},  //   fstu, glde_, капи,
  { {0x7bda3583, 0x291a01c5, 0x2ef5007c, 0x00000000}},  //   gstu, _rapa_, _азер,
  { {0x2d8c3655, 0x291a01a3, 0x2d9e0bed, 0x00000000}},  //   alde_, _sapa_, amte_,
  { {0x291a0263, 0x3b1b0066, 0x7bda304b, 0x00000000}},  //   _papa_, _daqq_, astu,
  { {0xfce5072b, 0x3f8d3656, 0xf99f0173, 0x00000000}},  //   _роко, lleu_, dwès_,
  { {0x5d7a0049, 0x291a25b9, 0xbc190088, 0x00000000}},  //   _קאצק, _vapa_, _цілі_,
  { {0x1fe30044, 0x27e50027, 0xcfe30044, 0x00000000}},  //   _মহাস, álna_, _মহান,
  { {0x291a0ba2, 0x07a301be, 0xdcfa0089, 0x00000000}},  // [bac0] _tapa_, ратн, lotā,
  { {0x44210045, 0x3b1b01f3, 0x00000000, 0x00000000}},  //   fvh_, _zaqq_,   ,
  { {0x213e3657, 0x66e6003b, 0xdcfa0089, 0x00000000}},  //   _roth_, _иона, notā,
  { {0xf7460364, 0xa5bb0036, 0x798e005b, 0x00000000}},  //   _ремо, _król, llbw,
  { {0x333f00f4, 0xe28300e2, 0x8af0006b, 0x00000000}},  //   _doux_, алци, _iləd,
  { {0x9103005e, 0x7bda2d22, 0x3f8601d6, 0x00000000}},  //   ипче, ystu, _skou_,
  { {0xb5020201, 0xcf9a01f9, 0xdfd00025, 0x00000000}},  //   र्णय_, мји_, حيب_,
  { {0x2d870263, 0x3f1400ed, 0xdcfa0089, 0x00000000}},  //   _akne_, удис, dotā,
  { {0x7bda3658, 0x213e1db2, 0x00000000, 0x00000000}},  //   wstu, _toth_,   ,
  { {0xfe6f06ea, 0x7bda006c, 0xdce1050f, 0x00000000}},  //   تدى_, tstu, bilč,
  { {0x6fb6026c, 0xc0a90025, 0xa0a6005e, 0x00000000}},  //   _شمشا, _كامل_, _ражд,
  { {0x7bda02ae, 0x6d86000c, 0xe502006e, 0x00000000}},  //   rstu, gðar, र्ति_,
  { {0x290411af, 0xeb9f0374, 0x00000000, 0x00000000}},  //   đman_, rmø_,   ,
  { {0x6d86000c, 0x7bda01d6, 0x3dc80044, 0x00000000}},  //   rðas, pstu, _শিপল,
  { {0x1b080055, 0xed57012b, 0x26c90011, 0x00000000}},  //   ষয়ে_, _јој_, tbao_,
  { {0x3f843659, 0x5ba4007e, 0x34cb0316, 0x00000000}},  //   nomu_, _крыз, िर्द,
  { {0x333f1b30, 0x80d80044, 0x387a0716, 0x00000000}},  // [bad0] _roux_, _ঠান্, _expr_,
  { {0xeaaa007b, 0x69dd004e, 0x8af0006b, 0x00000000}},  //   _אױפֿ, msse, _eləd,
  { {0x2911365a, 0x3f840161, 0x69dd00ea, 0x00000000}},  //   meza_, komu_, lsse,
  { {0x291100e4, 0xd498019d, 0xdce100ca, 0x00000000}},  //   leza_, тру_, vilč,
  { {0x80ca0055, 0x672f0061, 0x3f840089, 0x00000000}},  //   _রাজ্, _incj, domu_,
  { {0xd5fa00b6, 0x69dd00f4, 0x29110020, 0x00000000}},  //   _אפשר, isse, neza_,
  { {0x614201e0, 0xd3a701fc, 0x6d86000c, 0x00000000}},  //   сеща, _арап, yðar,
  { {0x291100e7, 0x00000000, 0x00000000, 0x00000000}},  //   heza_,   ,   ,
  { {0x2911000b, 0x69dd00bb, 0x00000000, 0x00000000}},  //   keza_, jsse,   ,
  { {0x80ca0164, 0xdcfa001e, 0x69dd0146, 0x00000000}},  //   _स्पे, totā, dsse,
  { {0x63b5003b, 0x2911097c, 0x69dd010f, 0x00000000}},  //   _juzn, deza_, esse,
  { {0xa5bb365b, 0xdcfa0089, 0x00000000, 0x00000000}},  //   _pról, rotā,   ,
  { {0x6d86009f, 0xee2e0407, 0x69c600e7, 0x00000000}},  //   rðar, _ун_, upke,
  { {0x291114a5, 0x28a50963, 0x00000000, 0x00000000}},  //   geza_, _गृहि,   ,
  { {0x66e612ab, 0x31b90173, 0x00000000, 0x00000000}},  //   лова, _lèz_,   ,
  { {0x69dd365c, 0xfaff040f, 0x80ca0309, 0x00000000}},  //   bsse, niël_, _स्ने,
  { {0x29110211, 0x7ae40107, 0xceb2019b, 0x00000000}},  // [bae0] beza_, _idit, מין_,
  { {0x2d85001a, 0xd7640014, 0x6e2400ca, 0x00000000}},  //   nole_, _چندی, _šibk,
  { {0x68fb0104, 0x61eb08ed, 0x69c40066, 0x00000000}},  //   _אליה, ergl, _htie,
  { {0x63b50107, 0x2d8504d2, 0x69c4002b, 0x00000000}},  //   _duzn, hole_, _ktie,
  { {0x614601f9, 0xdb040051, 0x5ea90044, 0x00000000}},  //   леда, _bunú, ছুতে,
  { {0xca7b0049, 0x61e41282, 0x00000000, 0x00000000}},  //   ענסט, šilo,   ,
  { {0xa3e103d7, 0x2d85231e, 0x61eb0026, 0x00000000}},  //   _दिए_, dole_, argl,
  { {0x69dd0039, 0x20d8010a, 0x2911365d, 0x00000000}},  //   ysse, džių_, zeza_,
  { {0x70f6035b, 0x80d30055, 0x63a21685, 0x00000000}},  //   _مسائ, _সার্, mmon,
  { {0x2d850207, 0x7ae4002d, 0x00000000, 0x00000000}},  //   gole_, _adit,   ,
  { {0x4c9401f9, 0x69c412b9, 0x29110091, 0x00000000}},  //   ринс, _atie, veza_,
  { {0x29110be3, 0x69dd00ea, 0x5e2601fa, 0x00000000}},  //   weza_, tsse, _معتق,
  { {0x6abd001c, 0x2911365e, 0x2d8532df, 0x00000000}},  //   rcsf, teza_, bole_,
  { {0x2d85000d, 0x6e93057d, 0x69dd00b0, 0x00000000}},  //   cole_, _الها, rsse,
  { {0x2911365f, 0x69c41c83, 0x69dd0c3f, 0x00000000}},  //   reza_, _etie, ssse,
  { {0x63b51127, 0xa6db000c, 0x9f470062, 0x00000000}},  //   _ruzn, _boða, trné_,
  { {0x61e40051, 0x00000000, 0x00000000, 0x00000000}},  // [baf0] áill,   ,   ,
  { {0x63a2010a, 0x3a290fd9, 0x61eb0618, 0x00000000}},  //   emon, _irap_, vrgl,
  { {0x442716b8, 0x63a2046a, 0x6b460051, 0x00000000}},  //   ín_, fmon, _tógt,
  { {0xd2510054, 0x3a2901bb, 0x2bf70049, 0x00000000}},  //   ينا_, _krap_, רמאן_,
  { {0xe7040167, 0xa3c9007d, 0x2d853660, 0x00000000}},  //   _اسپی, लीज_, yole_,
  { {0x63b53661, 0x98ba001e, 0x63a20253, 0x00000000}},  //   _tuzn, _kopā_, amon,
  { {0x2d850207, 0x2f550a27, 0xe9df0051, 0x00000000}},  //   vole_, итис, hsú_,
  { {0x2d8501aa, 0xddc90036, 0x63a20ede, 0x00000000}},  //   wole_, cześ, cmon,
  { {0x00e50014, 0x00000000, 0x00000000, 0x00000000}},  //   _نتای,   ,   ,
  { {0xa5bb008e, 0x1d09003b, 0x00000000, 0x00000000}},  //   _prój, њени_,   ,
  { {0x2d8506f9, 0x69c40fd6, 0x66160036, 0x00000000}},  //   role_, _stie, zwyk,
  { {0x2d8506f9, 0x34b2006e, 0xcd350752, 0x00000000}},  //   sole_, _जल्द, ارکب,
  { {0x2d853662, 0xde4600a1, 0x6d5d01aa, 0x00000000}},  //   pole_, _نیٹو_, èsas,
  { {0xa5bb0036, 0x9ce700a1, 0x3a290056, 0x00000000}},  //   _trój, _صوبے_, _drap_,
  { {0x6d43002a, 0xccf20104, 0x3a293663, 0x00000000}},  //   _iona, _וכו_, _erap_,
  { {0x6d43022b, 0x7ae40cc8, 0x3a290173, 0x00000000}},  //   _hona, _udit, _frap_,
  { {0x05661c19, 0x6b46002a, 0x3a291896, 0x00000000}},  // [bb00] аван, _fógr, _grap_,
  { {0x6d430981, 0xa6db000c, 0x63a20537, 0x00000000}},  //   _jona, _voða, wmon,
  { {0xaaba03d7, 0x63a213f4, 0x6d4303a1, 0x00000000}},  //   _इलाक, tmon, _mona,
  { {0xa3e7007c, 0x63a2028a, 0x6d4304eb, 0x00000000}},  //   рдца_, umon, _lona,
  { {0xddc90036, 0x70d10316, 0x00000000, 0x00000000}},  //   rześ, हरूल,   ,
  { {0x63a21439, 0x26c00207, 0x200c0022, 0x00000000}},  //   smon, lcio_, _ppdi_,
  { {0xd0100025, 0x63a201d6, 0x201a0026, 0x00000000}},  //   سلة_, pmon, ìpi_,
  { {0x26c0156d, 0x6d43002a, 0x6e2d0107, 0x00000000}},  //   ncio_, _aona, _šaba,
  { {0x6db20036, 0x26c0157e, 0x2cab006b, 0x00000000}},  //   _słab, icio_, əkdə_,
  { {0x6d43002a, 0x20b9008b, 0x5d540113, 0x00000000}},  //   _cona, _быць_, скот,
  { {0x34b700b6, 0x6d4301cb, 0xaee80044, 0x00000000}},  //   יפים_, _dona, ক্ষণ_,
  { {0x2b923664, 0x3a290065, 0x00000000, 0x00000000}},  //   nách_, _prap_,   ,
  { {0x6d430129, 0x4cd50044, 0xee9400a1, 0x00000000}},  //   _fona, _দারু, _اداک,
  { {0x6d4301aa, 0x442a0089, 0xc987026b, 0x00000000}},  //   _gona, _orb_, руми,
  { {0x2b9201ca, 0x3d2b00a1, 0x3a290339, 0x00000000}},  //   kách_, _جتنی_, _wrap_,
  { {0x442d17fd, 0x6d430211, 0xf77300f3, 0x00000000}},  //   _če_, _zona, زاز_,
  { {0x61e40746, 0x6d430022, 0x6b8d3665, 0x00000000}},  // [bb10] šilj, _yona, _ikag,
  { {0x443a008e, 0x6d5a0082, 0x170500a1, 0x00000000}},  //   fxp_, nhta, _گہری_,
  { {0xdcf800b9, 0x442a005b, 0xd83b0a7c, 0x00000000}},  //   _skvě, _crb_, _рэп_,
  { {0x26c00198, 0x9259007c, 0x7c2a0258, 0x00000000}},  //   ccio_, лает_, _mrfr,
  { {0x6d5a0145, 0x3ebf014a, 0x826900a1, 0x00000000}},  //   khta, vcut_, دشاہ_,
  { {0x442a0146, 0x661d007f, 0x00000000, 0x00000000}},  //   _frb_, _issk,   ,
  { {0x3f693666, 0x44252fbf, 0x442a0107, 0x00000000}},  //   лико_, _él_, _grb_,
  { {0x6d43003b, 0x7c25009f, 0xef1900ed, 0x00000000}},  //   _sona, _áhri, уми_,
  { {0x764d3667, 0x26d90213, 0xa5bb0051, 0x00000000}},  //   nyay, _meso_, _brói,
  { {0x3ebf1efc, 0x6d43005f, 0x6b8d0cd1, 0x00000000}},  //   scut_, _qona, _akag,
  { {0x40950025, 0x6d433668, 0x6db20036, 0x00000000}},  //   _الار, _vona, _płac,
  { {0x26d9016c, 0x6d4301a2, 0x2c57013f, 0x00000000}},  //   _neso_, _wona, nədə_,
  { {0x5ea50044, 0xc332009b, 0x42790049, 0x00000000}},  //   _গ্রে, פוך_, ראָג,
  { {0x6d5a0195, 0x2c57006b, 0xd99a0014, 0x00000000}},  //   chta, hədə_, انست_,
  { {0x2c57005f, 0x26d90211, 0x25b90026, 0x00000000}},  //   kədə_, _beso_, _ausl_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf74301f9, 0x64433669, 0x442a0107, 0x00000000}},  // [bb20] чето, änin, _srb_,
  { {0x26c00207, 0xd91000a1, 0x442a0145, 0x00000000}},  //   scio_, _تیس_, _prb_,
  { {0xe3b200a1, 0x232a00e3, 0xe2ca04f9, 0x00000000}},  //   سرا_, ложи_, глед_,
  { {0xd048006b, 0xe73a007e, 0x764d0009, 0x00000000}},  //   _gedə, _сем_, byay,
  { {0x2b920161, 0x93c800a1, 0x00000000, 0x00000000}},  //   rách_, _چارہ_,   ,
  { {0xfd070318, 0xdb0b010f, 0xf1b90087, 0x00000000}},  //   _عج_, _zufä, _duš_,
  { {0x80d90164, 0x6604006c, 0x442a008e, 0x00000000}},  //   _नजरे, ltik, _urb_,
  { {0xc7b3009b, 0x2c57006b, 0x66041583, 0x00000000}},  //   הבה_, cədə_, otik,
  { {0x6604020c, 0xa5bb002a, 0x50d60014, 0x00000000}},  //   ntik, _prói, _هزار,
  { {0x50cf02f4, 0x6b8d0dba, 0x660406aa, 0x00000000}},  //   _स्पष, _skag, itik,
  { {0x660400b0, 0x61e201b8, 0x69b2013d, 0x00000000}},  //   htik, lsol, _इंजी,
  { {0x6604022b, 0x6d5a1ea5, 0x201e2d33, 0x00000000}},  //   ktik, shta, _isti_,
  { {0x4e960070, 0x26d90207, 0x539b071c, 0x00000000}},  //   _اشار, _reso_, טיטו,
  { {0x60da0023, 0x2c57006b, 0x6ab60010, 0x00000000}},  //   _jetm, zədə_, _egyf,
  { {0x26d90325, 0x2c57006b, 0x6604006c, 0x00000000}},  //   _peso_, yədə_, etik,
  { {0xd6d835bd, 0x6b8d09df, 0xdce10035, 0x00000000}},  //   йту_, _ukag, pilă,
  { {0xf7700d3a, 0x26d90173, 0x35b4007e, 0x00000000}},  // [bb30] راف_, _veso_, збур,
  { {0x60da05d2, 0x61e200f8, 0x201e0052, 0x00000000}},  //   _netm, dsol, _osti_,
  { {0xd49b0113, 0x6724366a, 0xf99400b3, 0x00000000}},  //   ура_, bdij, _מרץ_,
  { {0xdb190039, 0x00000000, 0x00000000, 0x00000000}},  //   _utvä,   ,   ,
  { {0x4cde0055, 0x2c57005f, 0x6d580047, 0x00000000}},  //   _মানু, rədə_, _olva,
  { {0x2c57006b, 0x00000000, 0x00000000, 0x00000000}},  //   sədə_,   ,   ,
  { {0x5edd0044, 0x7f9e0023, 0x60da366b, 0x00000000}},  //   _যাবে, zëqe, _detm,
  { {0x6d581652, 0x61e20035, 0xf1b90059, 0x00000000}},  //   _alva, bsol, _tuš_,
  { {0x201e000d, 0x9f5c0224, 0xbd390088, 0x00000000}},  //   _esti_, ctví_, аїні_,
  { {0x60da005f, 0x80d30055, 0x67241a72, 0x00000000}},  //   _getm, _সাক্, zdij,
  { {0xca29019b, 0x66042f69, 0x8c4502dc, 0x00000000}},  //   _שם_, ztik, цене,
  { {0x60da00d9, 0x7f9e0023, 0x66040d8f, 0x00000000}},  //   _zetm, tëqe, ytik,
  { {0x8d740063, 0xfce50131, 0x60da005a, 0x00000000}},  //   _کانا, _доло, _yetm,
  { {0xa3ea02d2, 0x66040059, 0x61e40051, 0x00000000}},  //   _मिल_, vtik, áili,
  { {0x1b0f0055, 0xdb190173, 0x6e29068f, 0x00000000}},  //   িয়ে_, _ouvè, lveb,
  { {0x6604366c, 0x61e4366d, 0x236f0065, 0x00000000}},  //   ttik, šili, jigj_,
  { {0x68fe0022, 0x88d90044, 0x00000000, 0x00000000}},  // [bb40] _tcpd, _তারক,   ,
  { {0x3a20006a, 0xd6cf00a1, 0x240a0143, 0x00000000}},  //   _isip_, فقہ_, инзи_,
  { {0x03260741, 0xf74601f9, 0x2937034e, 0x00000000}},  //   жден, _дено, _ואין_,
  { {0x2918022b, 0x60da04bd, 0x61e204d3, 0x00000000}},  //   lera_, _setm, tsol,
  { {0x61e2366e, 0x26d20922, 0x9c7c0340, 0x00000000}},  //   usol, mbyo_, mače,
  { {0x29180ed6, 0xdb0b0039, 0x9c7c1470, 0x00000000}},  //   nera_, _utfö, lače,
  { {0x6f090016, 0x60da008d, 0x29182352, 0x00000000}},  //   ffec, _vetm, iera_,
  { {0x9c7c190a, 0x2918002d, 0x61e20190, 0x00000000}},  //   nače, hera_, psol,
  { {0x2918022b, 0x63bc0058, 0x3f980089, 0x00000000}},  //   kera_, _hurn, ēru_,
  { {0xa06a005e, 0x29180091, 0x0caa00e3, 0x00000000}},  //   _каза_, jera_, итни_,
  { {0x63bc005f, 0x9c7c04eb, 0x201e1504, 0x00000000}},  //   _jurn, kače, _usti_,
  { {0x9c7c050f, 0xa5bb0036, 0x63bc04cb, 0x00000000}},  //   jače, _krót, _murn,
  { {0x2918001a, 0x9c7c0c76, 0xfd7900a1, 0x00000000}},  //   fera_, dače, ششیں_,
  { {0x09bd0044, 0x00000000, 0x00000000, 0x00000000}},  //   _অবদা,   ,   ,
  { {0xa8990eec, 0x36d50cee, 0xa2aa0061, 0x00000000}},  //   скву_, зобр, जेत्,
  { {0x27ed01d9, 0x9c7c089f, 0x2d8c01c5, 0x00000000}},  //   čen_, gače, lode_,
  { {0x2918022b, 0xe4cb0084, 0x63bc0288, 0x00000000}},  // [bb50] bera_, لبان_, _aurn,
  { {0x29180039, 0x2d8c0007, 0x63bc00ab, 0x00000000}},  //   cera_, node_, _burn,
  { {0xf77000a1, 0x69cf00bb, 0x29010022, 0x00000000}},  //   راہ_, lpce, _icha_,
  { {0x63bc0006, 0x2d8c0142, 0x29010288, 0x00000000}},  //   _durn, hode_, _hcha_,
  { {0x2d8c15c8, 0x7afd0171, 0xdb19009d, 0x00000000}},  //   kode_, igst, _cuvé,
  { {0x63bc0e5f, 0x88d90044, 0xe8b9013d, 0x00000000}},  //   _furn, _তাঁক, _आलोच,
  { {0x63bc0d6b, 0xb4d70316, 0xa5bb366f, 0x00000000}},  //   _gurn, सरी_, _erót,
  { {0x63680256, 0xd00e0379, 0x2918119a, 0x00000000}},  //   _друг_, الي_, zera_,
  { {0x5edd0044, 0x29180065, 0x63bc0042, 0x00000000}},  //   _যাদে, yera_, _zurn,
  { {0x6f0900dc, 0x291823ca, 0x7afd144a, 0x00000000}},  //   sfec, xera_, egst,
  { {0x317a0049, 0x395a0022, 0x31560049, 0x00000000}},  //   _פרעמ, _rlps_, _ציען_,
  { {0x29180066, 0x29010181, 0xe456007b, 0x00000000}},  //   wera_, _acha_, פירט_,
  { {0x2918022b, 0x2d8c0091, 0x9c7c05c5, 0x00000000}},  //   tera_, bode_, vače,
  { {0x2d8c00b5, 0x27f80866, 0x7afd00c7, 0x00000000}},  //   code_, turn_, agst,
  { {0x29180073, 0x200701aa, 0x9c7c0b46, 0x00000000}},  //   rera_, ntni_, tače,
  { {0x29180039, 0x63ba0d7b, 0x2901008e, 0x00000000}},  //   sera_, _étni, _echa_,
  { {0x63bc006c, 0xe4d60025, 0x4cde0044, 0x00000000}},  // [bb60] _surn, كتاب, _মাতু,
  { {0x20070059, 0x63bc023a, 0x27f8000c, 0x00000000}},  //   ktni_, _purn, purn_,
  { {0x9c7c00ee, 0xf993009b, 0xd2520014, 0x00000000}},  //   pače, _ארז_, کنش_,
  { {0xa5bb0a58, 0xf99f01aa, 0x09230044, 0x00000000}},  //   _prót, ntèn_, মাণু_,
  { {0x61ed089f, 0x20073670, 0x00000000, 0x00000000}},  //   šaln, etni_,   ,
  { {0x20070618, 0x4a9b0097, 0xb0c60061, 0x00000000}},  //   ftni_, זינג, रुंग,
  { {0x35a3008b, 0x2d8c0466, 0x8af0006b, 0x00000000}},  //   _чарг, vode_, _aləm,
  { {0xf8b30104, 0x6449005d, 0x547b009b, 0x00000000}},  //   עשה_, çmiş, _הטלו,
  { {0x2d8c023a, 0x798e0061, 0x67260145, 0x00000000}},  //   tode_, kobw, _makj,
  { {0x7c860269, 0xdb190035, 0x2cb800ea, 0x00000000}},  //   зуме, _cuvî, ørd_,
  { {0x2d8c0091, 0xbae10044, 0x8af0006b, 0x00000000}},  //   rode_, _ভাবছ, _eləm,
  { {0x2d8c028a, 0x7afd3671, 0x09b50061, 0x00000000}},  //   sode_, ugst, ंद्य,
  { {0x7afd0002, 0xdb040011, 0x60cb0010, 0x00000000}},  //   rgst, _khiê, _élmé,
  { {0x6db200b4, 0x67260146, 0x00000000, 0x00000000}},  //   _kłam, _aakj,   ,
  { {0xd90f007a, 0x7d1a017b, 0xd1380036, 0x00000000}},  //   نیک_, mets, _mną_,
  { {0x7d1a0016, 0x95d9005e, 0x3cfe00e7, 0x00000000}},  //   lets, ждат_, lgtv_,
  { {0x7aed022b, 0xf1d70055, 0x59b702d2, 0x00000000}},  // [bb70] _idat, _সম্ভ, _इंटर,
  { {0xb4d70164, 0xdb04001d, 0xb4c90061, 0x00000000}},  //   सरे_, _nhiê, ैरे_,
  { {0xa5bb000c, 0x9cd7009b, 0xbb1b009d, 0x00000000}},  //   _prós, פואה_, boît,
  { {0x7d1a3672, 0xfaff0065, 0x6d4a000c, 0x00000000}},  //   hets, ngë_, _lofa,
  { {0x7d1a0b79, 0x00000000, 0x00000000, 0x00000000}},  //   kets,   ,   ,
  { {0x7d1a0209, 0xdb040011, 0x672600bb, 0x00000000}},  //   jets, _chiê, _zakj,
  { {0x7aed3673, 0x6e2212fe, 0x7d1a073a, 0x00000000}},  //   _odat, _asob, dets,
  { {0x20070059, 0x2d830c0a, 0xa6db000c, 0x00000000}},  //   rtni_, čjem_, _boði,
  { {0x6adc0055, 0x61e4002a, 0x200701d9, 0x00000000}},  //   _ভালো, áilt, stni_,
  { {0x7aed0047, 0x7d1a27a5, 0x6d4a07ad, 0x00000000}},  //   _adat, gets, _cofa,
  { {0x69cd11f3, 0x00000000, 0x00000000, 0x00000000}},  //   _atae,   ,   ,
  { {0x7aed0009, 0x61e90635, 0x2b9207fd, 0x00000000}},  //   _cdat, _kvel, vács_,
  { {0x7d1a0073, 0x7aed018e, 0x6d4a00fa, 0x00000000}},  //   bets, _ddat, _fofa,
  { {0x752709fc, 0x6d4a018e, 0x7aed0ec8, 0x00000000}},  //   _najz, _gofa, _edat,
  { {0x7aed0066, 0x672600bb, 0x00000000, 0x00000000}},  //   _fdat, _pakj,   ,
  { {0xd70a007e, 0x61e90ac1, 0x798e0045, 0x00000000}},  //   ўнае_, _ovel, sobw,
  { {0xe96a0545, 0x672600bb, 0x44310095, 0x00000000}},  // [bb80] _маил_, _vakj, _arz_,
  { {0x9c7c00ca, 0xa5bb004a, 0xf99f0173, 0x00000000}},  //   lača, _prór, ntèl_,
  { {0x61e907c5, 0x6f1b0c7d, 0x4423004a, 0x00000000}},  //   _avel, keuc, _csj_,
  { {0x9c7c0091, 0x65c60fd7, 0x7d1a1833, 0x00000000}},  //   nača, _обма, zets,
  { {0xdb04001d, 0xa3de013d, 0x61e90e00, 0x00000000}},  //   _phiê, _दौर_, _cvel,
  { {0x6f020197, 0x61e93674, 0x7d030087, 0x00000000}},  //   _scoc, _dvel, _ncns,
  { {0xd5ad00a1, 0x44310197, 0x7d1a0010, 0x00000000}},  //   _اہل_, _grz_, vets,
  { {0x6d4a0030, 0x9c7c10ec, 0x00000000, 0x00000000}},  //   _sofa, jača,   ,
  { {0xdb04001d, 0x7d1a05d5, 0xb0cf0061, 0x00000000}},  //   _thiê, tets, _स्वग,
  { {0x657e0051, 0xab640036, 0x00000000, 0x00000000}},  //   nnph, óżni,   ,
  { {0x7d1a011f, 0xcf8f01fc, 0xdb1601aa, 0x00000000}},  //   rets, _ај_, _kiyè,
  { {0xee3a03c8, 0x7d1a01d6, 0x61e9009d, 0x00000000}},  //   _мне_, sets, _yvel,
  { {0xf2d3007b, 0x6d4a000b, 0x5eac0044, 0x00000000}},  //   כער_, _tofa, _ট্রে,
  { {0x9f4e0051, 0xf1b801f3, 0x3a320146, 0x00000000}},  //   irfí_, _jiġ_, _dryp_,
  { {0x7aed00ea, 0x75270010, 0x9c7c11af, 0x00000000}},  //   _tdat, _rajz, bača,
  { {0xb4d70061, 0x44230022, 0x7aed04eb, 0x00000000}},  //   सर्_, _rsj_, _udat,
  { {0x3a320007, 0x69cd00e7, 0x75270232, 0x00000000}},  // [bb90] _gryp_, _utae, _pajz,
  { {0xd49b0175, 0x15f30061, 0x44230c5d, 0x00000000}},  //   оре_, ेंबर_, _psj_,
  { {0xf48500e9, 0x7527008d, 0x61e90197, 0x00000000}},  //   رائی, _vajz, _svel,
  { {0x3d0e013d, 0xe94500a1, 0x25b8004a, 0x00000000}},  //   त्ते_, _آرکی, _eirl_,
  { {0xeb920049, 0x44310036, 0xe5c4007c, 0x00000000}},  //   אָג_, _wrz_, _ассо,
  { {0x25b8190f, 0xe8e00011, 0xa0a50893, 0x00000000}},  //   _girl_, _kiều_, налд,
  { {0x1fb500e3, 0xd00e023c, 0xdb16000a, 0x00000000}},  //   нсир, ملو_, _fiyè,
  { {0xa29505b8, 0x26c900c4, 0x61e900ea, 0x00000000}},  //   _забі, ncao_, _tvel,
  { {0x61e90bf8, 0xfce5004c, 0xe8e00011, 0x00000000}},  //   _uvel, нопо, _liều_,
  { {0x653a007b, 0x1c450088, 0x7d09003b, 0x00000000}},  //   ִערד, еном, чног_,
  { {0xeb9a01e0, 0xab2a0e75, 0x15f3013d, 0x00000000}},  //   зин_, пона_, ेंडर_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9c7c0e3b, 0x00000000, 0x00000000, 0x00000000}},  //   rača,   ,   ,
  { {0xdb19001a, 0x9c7c0161, 0x00000000, 0x00000000}},  //   _cuvâ, mačn,   ,
  { {0x8b96012b, 0x9c7c07ac, 0x2bc60164, 0x00000000}},  //   _прич, lačn, _रूपा,
  { {0xa5bb02d5, 0x28d0007d, 0x3958016c, 0x00000000}},  //   _próp, _त्रि, skrs_,
  { {0x61ed021d, 0x9c7c0363, 0x7ae63675, 0x00000000}},  // [bba0] šalj, načn, makt,
  { {0x26c900fa, 0x394616e8, 0x00000000, 0x00000000}},  //   acao_, _чног,   ,
  { {0x66e602e9, 0xa3db0061, 0xed560049, 0x00000000}},  //   _пона, ढील_, עבער_,
  { {0x9c7c0161, 0x26c93676, 0xa5bb3677, 0x00000000}},  //   kačn, ccao_, _tróp,
  { {0x9c7c1531, 0x3ce502e1, 0x799c005b, 0x00000000}},  //   jačn, kalv_, olrw,
  { {0x6fc7014a, 0x6143091b, 0x216700d7, 0x00000000}},  //   _sıca, леча, ничи_,
  { {0x64a319ec, 0x7ae63678, 0x3ddd0319, 0x00000000}},  //   _бара, kakt, _awww_,
  { {0x4444002b, 0x7ae60255, 0x8c250044, 0x00000000}},  //   mx_, jakt, যমান_,
  { {0x44443679, 0x9c7c1b4e, 0x00000000, 0x00000000}},  //   lx_, gačn,   ,
  { {0xc0aa05d4, 0x44441b4d, 0x5d54367a, 0x00000000}},  //   _فاضل_, ox_, ткот,
  { {0x7ae601aa, 0x4444049e, 0x20b9007e, 0x00000000}},  //   fakt, nx_, _жыць_,
  { {0x444403d5, 0x3ddd158d, 0xdd2f00b9, 0x00000000}},  //   ix_, _fwww_, _měři,
  { {0xf99f0263, 0xc333019b, 0x44440066, 0x00000000}},  //   stèm_, אור_, hx_,
  { {0x2b840676, 0x4444002b, 0xd90f0167, 0x00000000}},  //   rıca_, kx_, حید_,
  { {0x97a70545, 0x7b0600b0, 0xe89501ab, 0x00000000}},  //   ерал, ättö, тавь,
  { {0x7ae6011f, 0x4444002b, 0x6d5a064a, 0x00000000}},  //   cakt, dx_, lkta,
  { {0x4444002b, 0x69c00325, 0x80e10044, 0x00000000}},  // [bbb0] ex_, ímet, _নাস্,
  { {0x44440066, 0x6d5a0006, 0x61ed0059, 0x00000000}},  //   fx_, nkta, šalk,
  { {0x44440066, 0xf48700ed, 0x9c7c0161, 0x00000000}},  //   gx_, хуан, začn,
  { {0x68e7367b, 0x29030635, 0x9c7c220f, 0x00000000}},  //   lajd, lgja_, hačo,
  { {0x2258007c, 0x7c210009, 0x673d00f8, 0x00000000}},  //   ницы_, zwlr, _insj,
  { {0x660d19bd, 0x865a01f8, 0x2903009f, 0x00000000}},  //   mtak, _חדשי, ngja_,
  { {0x7d01001c, 0xe8e0001d, 0x660d1603, 0x00000000}},  //   vgls, _hiểu_, ltak,
  { {0x672d367c, 0xee39017f, 0xe8e0001d, 0x00000000}},  //   ndaj, дни_, _kiểu_,
  { {0x7ae6074d, 0x65650058, 0x25640010, 0x00000000}},  //   vakt, ohhh, _föld_,
  { {0x41b500d3, 0x9c7c367d, 0x6b9602d8, 0x00000000}},  //   _شمار, račn, _skyg,
  { {0x80ca02fb, 0x63bb0020, 0x660d0b48, 0x00000000}},  //   _स्टे, _kiun, htak,
  { {0x65651d50, 0x9c7c0627, 0x628c0036, 0x00000000}},  //   hhhh, pačn, żnoś,
  { {0x63bb0020, 0x1d09003b, 0x63a90016, 0x00000000}},  //   _miun, _жели_, _mhen,
  { {0x7ae6011c, 0x29030635, 0x660d00ea, 0x00000000}},  //   sakt, ggja_, dtak,
  { {0x660d022b, 0x7ae60058, 0x00000000, 0x00000000}},  //   etak, pakt,   ,
  { {0x660d002b, 0xe8e0001d, 0x69df00f6, 0x00000000}},  //   ftak, _biểu_, _fwqe,
  { {0x660d367e, 0x7e69010f, 0x7ae40016, 0x00000000}},  // [bbc0] gtak, nzep, _ieit,
  { {0x7ae4367f, 0x4444158a, 0x7bc30020, 0x00000000}},  //   _heit, tx_, _kunu,
  { {0x4444028c, 0x9980085c, 0x7bc3033b, 0x00000000}},  //   ux_, _križ_, _junu,
  { {0x4444002b, 0x63a90020, 0x69c432c8, 0x00000000}},  //   rx_, _chen, _kuie,
  { {0x7ae43680, 0x63a90065, 0x44440066, 0x00000000}},  //   _meit, _dhen, sx_,
  { {0x7ae40a58, 0x44440026, 0x23a7010e, 0x00000000}},  //   _leit, px_, võje_,
  { {0x7bc304d4, 0x69c424b6, 0x256401e5, 0x00000000}},  //   _nunu, _luie, _völd_,
  { {0x63bb0207, 0x63a9001a, 0x03a6005e, 0x00000000}},  //   _giun, _ghen, _рибо,
  { {0xf77300b6, 0x3da60264, 0x9c7c0161, 0x00000000}},  //   יקה_, кроб, tačo,
  { {0x63a90066, 0x7bc301f6, 0x00000000, 0x00000000}},  //   _zhen, _bunu,   ,
  { {0x7ae408ba, 0xaf060d68, 0x6d5a0218, 0x00000000}},  //   _beit, _апел, rkta,
  { {0x3f80010a, 0xbf13026c, 0x16dc0061, 0x00000000}},  //   čius_, _نومب, बरोब,
  { {0x3ea0002a, 0x7ae43681, 0x7bc31901, 0x00000000}},  //   _áit_, _deit, _eunu,
  { {0xbea3003b, 0x7bc30016, 0x69c400d4, 0x00000000}},  //   _тачк, _funu, _duie,
  { {0x7ae402d5, 0x212c008d, 0x7bc30169, 0x00000000}},  //   _feit, _madh_, _gunu,
  { {0x2d9e001f, 0x61ed3682, 0x660d1603, 0x00000000}},  //   llte_, šali, ttak,
  { {0x63bb0207, 0x69c40129, 0x63a90016, 0x00000000}},  // [bbd0] _riun, _guie, _rhen,
  { {0x660d1b5c, 0x7ae4001f, 0x63a9008d, 0x00000000}},  //   rtak, _zeit, _shen,
  { {0x2d9e3683, 0x63a93684, 0xd49b0216, 0x00000000}},  //   ilte_, _phen, фра_,
  { {0xe8e0001d, 0x660d0169, 0x2d9e010f, 0x00000000}},  //   _tiểu_, ptak, hlte_,
  { {0x63bb000b, 0x64450ede, 0x00000000, 0x00000000}},  //   _viun, sxhi,   ,
  { {0x349500ed, 0x3f860173, 0x63a91012, 0x00000000}},  //   _багр, _ajou_, _when,
  { {0xd4980887, 0x68e5006b, 0xf07500a1, 0x00000000}},  //   _арт_, _mehd, دیاں_,
  { {0x68e500b0, 0x7bc300e7, 0x2d5b00c4, 0x00000000}},  //   _lehd, _runu, _vêem_,
  { {0xa3e703d7, 0x7bc33685, 0x79950009, 0x00000000}},  //   _मौत_, _sunu, kozw,
  { {0x7ae4001f, 0x7bc33686, 0x7bc4007f, 0x00000000}},  //   _seit, _punu, _čiur,
  { {0x7ae4044e, 0x3a2904cb, 0x3b0a0920, 0x00000000}},  //   _peit, _asap_, нено_,
  { {0xa2aa007d, 0x69c42c2c, 0x00000000, 0x00000000}},  //   जेक्, _puie,   ,
  { {0x7ae4009f, 0x69c40781, 0xe8e00011, 0x00000000}},  //   _veit, _quie, _liễu_,
  { {0x7ae43687, 0xdb190030, 0xa3e40316, 0x00000000}},  //   _weit, _nuvæ, पीड_,
  { {0x7ae4018e, 0x00000000, 0x00000000, 0x00000000}},  //   _teit,   ,   ,
  { {0xfbd200b3, 0x00000000, 0x00000000, 0x00000000}},  //   _פתח_,   ,   ,
  { {0x3667107f, 0x00000000, 0x00000000, 0x00000000}},  // [bbe0] гато_,   ,   ,
  { {0x04460069, 0x00000000, 0x00000000, 0x00000000}},  //   лезн,   ,   ,
  { {0x98a8007d, 0x212c2927, 0x00000000, 0x00000000}},  //   _गरिए, _radh_,   ,
  { {0xb827004c, 0xe8e00082, 0x22460032, 0x00000000}},  //   _союз_, _diễu_, txok_,
  { {0x5b7b0049, 0x2d9e00ea, 0x00000000, 0x00000000}},  //   ערנא, ylte_,   ,
  { {0x29360049, 0x23660065, 0x31341737, 0x00000000}},  //   ראַן_, shoj_, рекр,
  { {0xfaff0065, 0x00000000, 0x00000000, 0x00000000}},  //   dhën_,   ,   ,
  { {0x44380022, 0xbdf40143, 0x9f540a85, 0x00000000}},  //   _irr_, апиј, рвич,
  { {0x442a00f8, 0x00000000, 0x00000000, 0x00000000}},  //   _hsb_,   ,   ,
  { {0x44380093, 0x98ba000a, 0x621b0049, 0x00000000}},  //   _krr_, _anpč_, _אומק,
  { {0x9c7c0119, 0x2cb80039, 0x55970049, 0x00000000}},  //   mačk, ärd_, רדיע_,
  { {0xda351001, 0x4fa3005e, 0x3a290022, 0x00000000}},  //   аемы, _лихв, _psap_,
  { {0xed5a34b3, 0x629e0036, 0x799500e7, 0x00000000}},  //   _под_, ępow, tozw,
  { {0xceb301ce, 0x442a3688, 0x44383689, 0x00000000}},  //   _פיס_, _osb_, _orr_,
  { {0x442a1372, 0x37ab0f93, 0x58d40131, 0x00000000}},  //   _nsb_, етан_, сост,
  { {0xf40a0044, 0xcb9900a2, 0x9c7c040d, 0x00000000}},  //   রবার_, _جنبش_, hačk,
  { {0x68e5368a, 0x9c7c18a2, 0x442a0007, 0x00000000}},  // [bbf0] _tehd, kačk, _asb_,
  { {0x9c7c1d9b, 0x442a00c4, 0x4438368b, 0x00000000}},  //   jačk, _bsb_, _brr_,
  { {0x9c7c0387, 0x824b025a, 0xa2d50439, 0x00000000}},  //   dačk, کشاف_, ليات,
  { {0x442a0169, 0x3dda0044, 0x91d5007e, 0x00000000}},  //   _dsb_, _দিনল, ацкі,
  { {0x81c7001e, 0x442a000c, 0x443803f2, 0x00000000}},  //   klēš, _esb_, _err_,
  { {0xb42500a1, 0x9c7c0091, 0x2fc5004a, 0x00000000}},  //   _پٹرو, gačk, _pulg_,
  { {0x44381346, 0xa156012b, 0x00000000, 0x00000000}},  //   _grr_, рају_,   ,
  { {0xbe390088, 0x00000000, 0x00000000, 0x00000000}},  //   вчої_,   ,   ,
  { {0x9c7c016e, 0x3eb90039, 0x6234368c, 0x00000000}},  //   bačk, äst_, _лету,
  { {0x8d55026b, 0x00000000, 0x00000000, 0x00000000}},  //   ртич,   ,   ,
  { {0xdca50001, 0xcb6a0265, 0xe8e0001d, 0x00000000}},  //   рани, ване_, _hiệu_,
  { {0x661d368d, 0xfaff0065, 0x61ed14f8, 0x00000000}},  //   _opsk, shën_, šalu,
  { {0x6db20036, 0x7c2a368e, 0xe7e8013d, 0x00000000}},  //   _płat, _esfr, टीना_,
  { {0x3941000a, 0x00000000, 0x00000000, 0x00000000}},  //   _cnhs_,   ,   ,
  { {0xb8ce03d7, 0xe8e0001d, 0x661d0a5c, 0x00000000}},  //   _और_, _liệu_, _apsk,
  { {0x2b40001a, 0x92e70044, 0x9c7c049c, 0x00000000}},  //   _unic_, পলু_, začk,

  { {0x442a0093, 0xc4e6007c, 0x4438368f, 0x00000000}},  // [bc00] _ssb_, ижай, _srr_,
  { {0x845a003b, 0x442a24b9, 0x6e2b278b, 0x00000000}},  //   крет_, _psb_, _msgb,
  { {0xb4d603d7, 0x9c7c0466, 0xc7a60140, 0x00000000}},  //   _सभी_, vačk, _винк,
  { {0x442a06ed, 0x2d853690, 0x00000000, 0x00000000}},  //   _vsb_, hnle_,   ,
  { {0x2d820047, 0x9c7c0142, 0xdb1b009d, 0x00000000}},  //   ékek_, tačk, mptô,
  { {0x442a023a, 0xe8e00011, 0x44380059, 0x00000000}},  //   _tsb_, _diệu_, _trr_,
  { {0x442a067b, 0x6b5f0065, 0x9c7c0091, 0x00000000}},  //   _usb_, _dëgj, račk,
  { {0xd1380046, 0x03d700b6, 0x9c7c0eae, 0x00000000}},  //   _skąd_, _כולם_, sačk,
  { {0x9c7c3691, 0x70f60025, 0xf11a13d9, 0x00000000}},  //   mači, _نسائ, _لغات_,
  { {0x63a20219, 0x9c7c0627, 0x4096003b, 0x00000000}},  //   llon, lači, _крет,
  { {0x63a2095f, 0x4c94012d, 0x61ed007f, 0x00000000}},  //   olon, синс, šalt,
  { {0x9c7c3692, 0x63a21e16, 0x6db20036, 0x00000000}},  //   nači, nlon, _płas,
  { {0x672f0036, 0x63a20026, 0xa2aa0061, 0x00000000}},  //   _racj, ilon, जेच्,
  { {0x7af60046, 0x63a2005b, 0x661d012d, 0x00000000}},  //   _edyt, hlon, _rpsk,
  { {0x6db20046, 0xd7c9007a, 0x63a20091, 0x00000000}},  //   _włas, اوره_, klon,
  { {0xd6d803c0, 0x501b00b3, 0xdb1f0065, 0x00000000}},  //   иту_, כולו, _miqë,
  { {0x63a23693, 0xd84300b9, 0x9c7c09fc, 0x00000000}},  // [bc10] dlon, dičů_, dači,
  { {0x63a20036, 0xdce800b9, 0x00000000, 0x00000000}},  //   elon, vidě,   ,
  { {0xd5b802ea, 0xf9900025, 0x317c01a2, 0x00000000}},  //   рст_, _تبي_, divz_,
  { {0x9c7c0091, 0x3384005e, 0x660400d9, 0x00000000}},  //   gači, оучв, buik,
  { {0x569401fb, 0xa1593694, 0x9647007e, 0x00000000}},  //   _мают, ладу_, _тэнд,
  { {0x63a201d6, 0x00000000, 0x00000000, 0x00000000}},  //   alon,   ,   ,
  { {0x63a200b9, 0x2564010f, 0xdc3b01d5, 0x00000000}},  //   blon, _köln_, _oġġe,
  { {0x43850054, 0x9f4e01aa, 0x645800b0, 0x00000000}},  //   _الرق, nsfè_, ävie,
  { {0xf99f0197, 0x00000000, 0x00000000, 0x00000000}},  //   ntès_,   ,   ,
  { {0x4d6501e0, 0xdc3b002b, 0x201e0022, 0x00000000}},  //   сков, _aġġe, _fpti_,
  { {0x3f5800c4, 0x00000000, 0x00000000, 0x00000000}},  //   _céus_,   ,   ,
  { {0x8e390439, 0x3f5800d4, 0xcc08009e, 0x00000000}},  //   _مستر_, _déus_, گزین_,
  { {0xed4e02dc, 0x00000000, 0x00000000, 0x00000000}},  //   _ео_,   ,   ,
  { {0x2bcf02f4, 0xe503007d, 0x63a20a4b, 0x00000000}},  //   _संपा, _लागि_, zlon,
  { {0x6d433695, 0x6e2927f4, 0x1867017a, 0x00000000}},  //   _inna, lweb, бари_,
  { {0x6f0904cb, 0x290c0036, 0x7c3c0190, 0x00000000}},  //   ngec, żda_, ærre,
  { {0x9c7c12a8, 0x6e290462, 0x00000000, 0x00000000}},  // [bc20] vači, nweb,   ,
  { {0x660400c7, 0x00000000, 0x00000000, 0x00000000}},  //   ruik,   ,   ,
  { {0x63a2006a, 0xdd7a0049, 0x6e2901a2, 0x00000000}},  //   tlon, נטעל, hweb,
  { {0xf77200f3, 0xd24f0014, 0x68ee079c, 0x00000000}},  //   _راج_, کنه_, labd,
  { {0x9c7c0b4d, 0x63a21e5a, 0x6d430010, 0x00000000}},  //   rači, rlon, _onna,
  { {0x63a202db, 0x6e2900ea, 0x29180810, 0x00000000}},  //   slon, dweb, nfra_,
  { {0x6e2901c3, 0x00000000, 0x00000000, 0x00000000}},  //   eweb,   ,   ,
  { {0x6d433696, 0x9df80081, 0x984c0089, 0x00000000}},  //   _anna, анит_, dēļa_,
  { {0xa5bb362f, 0x2cea0e09, 0x645e18ef, 0x00000000}},  //   _próx, льно_, lypi,
  { {0x2c4e013f, 0x00000000, 0x00000000, 0x00000000}},  //   lədi_,   ,   ,
  { {0xaf0a0123, 0xfaff008d, 0x459b007b, 0x00000000}},  //   _مقام_, shëm_, רסיע,
  { {0x6d4303b6, 0x7b6700ed, 0x657e063f, 0x00000000}},  //   _enna, стое, hiph,
  { {0x29183697, 0xbc670167, 0x5e5a083e, 0x00000000}},  //   ffra_, لمین_, _حجاج_,
  { {0xdd900439, 0x29180190, 0xfbcf02fd, 0x00000000}},  //   _توت_, gfra_, بتی_,
  { {0x115b0049, 0x9848007c, 0x00000000, 0x00000000}},  //   נדלע, бята_,   ,
  { {0x28d902fb, 0xc6220044, 0x443f016e, 0x00000000}},  //   _ब्रि, নিনা_, _ču_,
  { {0x7aef1de2, 0x657e0009, 0x29050009, 0x00000000}},  // [bc30] mact, fiph, òlas_,
  { {0x7bca000b, 0x657e0009, 0x7aef0531, 0x00000000}},  //   _kufu, giph, lact,
  { {0x59d4025a, 0x7aef02d0, 0xf99f1c88, 0x00000000}},  //   _وغیر, oact, stès_,
  { {0x7aef00bb, 0x2564072d, 0x7bca0ea6, 0x00000000}},  //   nact, _höll_, _mufu,
  { {0x2bcf02fb, 0xe29900ec, 0x944500a1, 0x00000000}},  //   _संभा, јал_, _ڈھان,
  { {0x7aef0927, 0x6142003b, 0xc1e8007e, 0x00000000}},  //   hact, деша, сьце_,
  { {0x7aef00b5, 0x00000000, 0x00000000, 0x00000000}},  //   kact,   ,   ,
  { {0x9c7c01ca, 0x27e50027, 0x6b8d05bd, 0x00000000}},  //   naču, álny_, _njag,
  { {0x7aef0382, 0x7c24012d, 0x6f09020d, 0x00000000}},  //   dact, _ćira, rgec,
  { {0x6e2900e7, 0x6b8d006c, 0x7bca0045, 0x00000000}},  //   rweb, _ajag, _bufu,
  { {0x3a2003eb, 0x7aef00ab, 0x8b26003b, 0x00000000}},  //   _spip_, fact, одне,
  { {0x920d0164, 0xeb9a04b6, 0x200701bc, 0x00000000}},  //   _समाज_, рим_, muni_,
  { {0x20070b37, 0xc9aa00ed, 0x6b8d000a, 0x00000000}},  //   luni_, ивме_, _djag,
  { {0x7aef001c, 0x7bca142e, 0x6d4315c1, 0x00000000}},  //   aact, _fufu, _unna,
  { {0x20071926, 0x5b36007e, 0x7bca2a98, 0x00000000}},  //   nuni_, _дэпу, _gufu,
  { {0x7aef001c, 0x00000000, 0x00000000, 0x00000000}},  //   cact,   ,   ,
  { {0x200707d7, 0xe57a0242, 0x25640039, 0x00000000}},  // [bc40] huni_, аза_, _föll_,
  { {0x645e0065, 0x7bc4006c, 0x00000000, 0x00000000}},  //   typi, _hiiu,   ,
  { {0x20070d5d, 0x657e3698, 0x93cb00a1, 0x00000000}},  //   juni_, riph, لانہ_,
  { {0xe73a0057, 0x20070020, 0x9f5c00b9, 0x00000000}},  //   _тем_, duni_, prvé_,
  { {0x914a0072, 0x27ed0091, 0x645e00b4, 0x00000000}},  //   ичка_, ćene_, sypi,
  { {0xd5b200a1, 0x799c3699, 0x200700e7, 0x00000000}},  //   _آفس_, norw, funi_,
  { {0x200712e8, 0xdb0f0161, 0xa067003b, 0x00000000}},  //   guni_, ždéh, жаја_,
  { {0x799c0016, 0x7aef009d, 0x2c4e006b, 0x00000000}},  //   horw, xact, qədi_,
  { {0xc7b3019b, 0x799c369a, 0xed8a369b, 0x00000000}},  //   ובה_, korw, исок_,
  { {0x2007000b, 0x6616010a, 0xdb0d00f4, 0x00000000}},  //   buni_, ityk, _chaî,
  { {0x7aef001c, 0x20070198, 0x6aad0036, 0x00000000}},  //   tact, cuni_, _szaf,
  { {0x6616369c, 0x6aa40045, 0x00000000, 0x00000000}},  //   ktyk, _byif,   ,
  { {0x799c0675, 0xdcfa369d, 0x7bc40022, 0x00000000}},  //   forw, litč, _diiu,
  { {0x7aef2318, 0x69dd00ea, 0x7bca00e7, 0x00000000}},  //   sact, rpse, _tufu,
  { {0x7e600253, 0x6d58093e, 0x2fcc000a, 0x00000000}},  //   lymp, _iova, _judg_,
  { {0x2bcf0164, 0x69dd04d3, 0x6d580471, 0x00000000}},  //   _संता, ppse, _hova,
  { {0x6d580e88, 0x9c7c1034, 0x20070509, 0x00000000}},  // [bc50] _kova, raču, zuni_,
  { {0x6d58012b, 0x7aed167c, 0x20071475, 0x00000000}},  //   _jova, _heat, yuni_,
  { {0x49b8007a, 0x7aed003f, 0x6d580403, 0x00000000}},  //   _بايد_, _keat, _mova,
  { {0x6d580010, 0x200700e7, 0x69c50010, 0x00000000}},  //   _lova, vuni_, _hihe,
  { {0x69c5225a, 0x7aed369e, 0x6145007e, 0x00000000}},  //   _kihe, _meat, зела,
  { {0x6d5819fa, 0x412900e3, 0x7aed0122, 0x00000000}},  //   _nova, соко_, _leat,
  { {0x69c52460, 0x2bc601f5, 0xe0420131, 0x00000000}},  //   _mihe, _रंगा, енщи,
  { {0xd34300a6, 0x6e220051, 0x200700a9, 0x00000000}},  //   _تفری, _bpob, runi_,
  { {0xc332007b, 0x75350066, 0x6d581c35, 0x00000000}},  //   _און_, _kazz, _bova,
  { {0x6d58001a, 0x200720b9, 0xceb900b9, 0x00000000}},  //   _cova, puni_, neři_,
  { {0x6d58369f, 0x75350207, 0x7aed038f, 0x00000000}},  //   _dova, _mazz, _beat,
  { {0x61e936a0, 0x69c5021e, 0x66160639, 0x00000000}},  //   _kwel, _aihe, ytyk,
  { {0x7aed00ab, 0xf1c3002b, 0x69c50032, 0x00000000}},  //   _deat, poġġ_, _bihe,
  { {0x753501d5, 0x61e90020, 0x2d820010, 0x00000000}},  //   _nazz, _mwel, éket_,
  { {0x7aed0038, 0x69c50065, 0x25640039, 0x00000000}},  //   _feat, _dihe, _följ_,
  { {0x7aed36a1, 0x66160052, 0x799c0045, 0x00000000}},  //   _geat, ttyk, sorw,
  { {0x442336a2, 0x75350197, 0x799c00e7, 0x00000000}},  // [bc60] _apj_, _bazz, porw,
  { {0x75350207, 0xaa3b009b, 0x661636a3, 0x00000000}},  //   _cazz, _פתיח, rtyk,
  { {0x66161d20, 0x44310009, 0x395a0190, 0x00000000}},  //   styk, _csz_, _iops_,
  { {0x69c500d0, 0x644801d5, 0x61e91163, 0x00000000}},  //   _zihe, _ġdid, _bwel,
  { {0x75350197, 0x69c500e0, 0x443a0087, 0x00000000}},  //   _fazz, _yihe, svp_,
  { {0x7535054f, 0x61e9112b, 0x00000000, 0x00000000}},  //   _gazz, _dwel,   ,
  { {0x442c0263, 0x6d5836a4, 0xa3c50061, 0x00000000}},  //   _èd_, _rova, _उंच_,
  { {0x6d5815d8, 0x09e20044, 0x00000000, 0x00000000}},  //   _sova, _বিনা,   ,
  { {0x61e9018e, 0x6d5829e4, 0x7aed1acc, 0x00000000}},  //   _gwel, _pova, _reat,
  { {0x7aed00ab, 0x63ae0006, 0x7bcd016c, 0x00000000}},  //   _seat, šinė, _čaur,
  { {0x7aed0004, 0x6d580061, 0x7e600052, 0x00000000}},  //   _peat, _vova, symp,
  { {0x66040007, 0xa3e4006e, 0x395a0045, 0x00000000}},  //   krik, पीए_, _aops_,
  { {0x09e4008b, 0x6d580027, 0x65ab010f, 0x00000000}},  //   ноўн, _tova, fühl,
  { {0x395a0129, 0x7aed00ab, 0xdb0d009d, 0x00000000}},  //   _cops_, _weat, _thaï,
  { {0x7aed0004, 0x36d501f9, 0x753501bc, 0x00000000}},  //   _teat, добр, _razz,
  { {0x27ff0746, 0x2d9e36a5, 0x660436a6, 0x00000000}},  //   čun_, lote_, frik,
  { {0x75350207, 0x2d8c36a7, 0x69c501c2, 0x00000000}},  // [bc70] _pazz, onde_, _tihe,
  { {0x2d9e0263, 0x2d8c36a8, 0x2fc60058, 0x00000000}},  //   note_, nnde_, _liog_,
  { {0x6604006c, 0xf9900025, 0x61e92c41, 0x00000000}},  //   arik, _حبي_, _swel,
  { {0x2bcf007d, 0xe1f10014, 0x2d9e0142, 0x00000000}},  //   _संसा, نست_, hote_,
  { {0xb90a001d, 0x7535002b, 0x45d4109f, 0x00000000}},  //   _nghệ_, _tazz, _пояс,
  { {0x2d9e36a9, 0x09e20044, 0x1a9c0049, 0x00000000}},  //   jote_, _বিমা, זידע,
  { {0xd12e0439, 0x442336aa, 0x2fc601c3, 0x00000000}},  //   شمي_, _upj_, _biog_,
  { {0x2d8c1296, 0x2366037e, 0xfe4500ed, 0x00000000}},  //   ende_, ckoj_, днио,
  { {0x09e20055, 0x88c50055, 0xee360642, 0x00000000}},  //   _বিভা, ্রিক, дны_,
  { {0xe81e03d7, 0x2d9e1ebf, 0x2b4900c4, 0x00000000}},  //   _पहला_, gote_, _anac_,
  { {0x61fc0089, 0x395a0943, 0x26d900d9, 0x00000000}},  //   _ārli, _rops_, _ofso_,
  { {0x2d8c2a27, 0x09e20044, 0x395a0943, 0x00000000}},  //   ande_, _বিবা, _sops_,
  { {0x2d9e001f, 0x2bcf02d2, 0xfe4503e8, 0x00000000}},  //   bote_, _संवा, _інко,
  { {0x2d9e0181, 0x2b490026, 0x26cb17f1, 0x00000000}},  //   cote_, _enac_, _agco_,
  { {0x2b4900f4, 0x07a6005c, 0x236d0ce2, 0x00000000}},  //   _fnac_, давн, _olej_,
  { {0x6604022b, 0x2904047f, 0x8b95008b, 0x00000000}},  //   trik, şma_, _прыч,
  { {0xdcfa001e, 0x07a30783, 0x27ed0091, 0x00000000}},  // [bc80] litā, татн, ćena_,
  { {0x6604022b, 0x59830eec, 0xfaff0023, 0x00000000}},  //   rrik, _альб, nkën_,
  { {0x66040004, 0xdcfa0089, 0x236d0023, 0x00000000}},  //   srik, nitā, _blej_,
  { {0x2ca7069c, 0x491a006e, 0x2d9e0020, 0x00000000}},  //   _mynd_, म्रो_, zote_,
  { {0x23660065, 0x2d9e03ef, 0x2d8c36ab, 0x00000000}},  //   rkoj_, yote_, ynde_,
  { {0x23660091, 0x2d9e28f0, 0xdb040048, 0x00000000}},  //   skoj_, xote_, _chiú,
  { {0x2d9e0142, 0x656318ee, 0xdb040051, 0x00000000}},  //   vote_, önhe, _dhiú,
  { {0x2d9e0020, 0x236d0059, 0xdcfa0089, 0x00000000}},  //   wote_, _glej_, ditā,
  { {0x2d9e0006, 0x00000000, 0x00000000, 0x00000000}},  //   tote_,   ,   ,
  { {0x2d8c36ac, 0xdb040048, 0x61e2046e, 0x00000000}},  //   unde_, _ghiú, mpol,
  { {0x61e2006c, 0xcfa900a1, 0xdcfa0089, 0x00000000}},  //   lpol, _کالم_, gitā,
  { {0x61e236ad, 0xdb0d00c4, 0xa5bb00fa, 0x00000000}},  //   opol, _thaí, _apól,
  { {0x320601d6, 0x61e21469, 0xfaff0065, 0x00000000}},  //   nroy_, npol, dhët_,
  { {0x3f84000b, 0x2ca70909, 0x61e20026, 0x00000000}},  //   limu_, _fynd_, ipol,
  { {0xb8d70183, 0x58d40088, 0xdcfa0089, 0x00000000}},  //   _जर_, тост, citā,
  { {0x3f8436ae, 0x65ab0bea, 0x61e204d3, 0x00000000}},  //   nimu_, rühm, kpol,
  { {0x35b501f9, 0x60da01a2, 0x00000000, 0x00000000}},  // [bc90] ебар, _oftm,   ,
  { {0x3f84000b, 0x61e20142, 0x236d00ca, 0x00000000}},  //   himu_, dpol, _slej_,
  { {0x3f840a64, 0x68f50279, 0x61e20be1, 0x00000000}},  //   kimu_, mazd, epol,
  { {0x14df02fb, 0xdb040051, 0x3f840006, 0x00000000}},  //   _प्रण, _shiú, jimu_,
  { {0xdb1600f4, 0x69d80059, 0x3f840006, 0x00000000}},  //   écéd, _čvek, dimu_,
  { {0x6d5c0039, 0x672d0217, 0x00000000, 0x00000000}},  //   öral, leaj,   ,
  { {0x6033006b, 0x10a219a5, 0x25a101dc, 0x00000000}},  //   _kəmə, лишн, mohl_,
  { {0x6d4a010f, 0xdcfa0089, 0x3f840bc3, 0x00000000}},  //   _anfa, vitā, gimu_,
  { {0x2ca736af, 0x3f8d36b0, 0x656e0022, 0x00000000}},  //   _synd_, rneu_, _ylbh,
  { {0x68f50620, 0x128a0167, 0x98a30089, 0x00000000}},  //   jazd, _عملی_, zejā_,
  { {0x1ae70044, 0x09e20044, 0x660d0022, 0x00000000}},  //   _কাজে_, _বিধা, huak,
  { {0x6d4a028c, 0xdcfa0089, 0xfaff0065, 0x00000000}},  //   _enfa, ritā, dhës_,
  { {0x672d0035, 0x00000000, 0x00000000, 0x00000000}},  //   deaj,   ,   ,
  { {0x09e20044, 0x20070197, 0xdcfa0089, 0x00000000}},  //   _বিদা, orni_, pitā,
  { {0x61e20059, 0xd7be0061, 0x00000000, 0x00000000}},  //   zpol, ्दलच,   ,
  { {0x2d85048f, 0xc7a300ed, 0x07a30478, 0x00000000}},  //   lile_, гиск, гасн,
  { {0x61e20288, 0x660d0032, 0x00000000, 0x00000000}},  // [bca0] xpol, guak,   ,
  { {0x2d850938, 0xba9b034e, 0x3f840020, 0x00000000}},  //   nile_, _מספי, zimu_,
  { {0xdcfa001a, 0x130600ed, 0x61fb00b0, 0x00000000}},  //   lită, езем, _avul,
  { {0x2d850912, 0x00000000, 0x00000000, 0x00000000}},  //   hile_,   ,   ,
  { {0x2d8536b1, 0xdcfa001a, 0x3f840006, 0x00000000}},  //   kile_, nită, vimu_,
  { {0x1ae70055, 0x61e236b2, 0x61e4000d, 0x00000000}},  //   _কাছে_, rpol, ţilo,
  { {0x2d8520b9, 0x61e20091, 0x3f8416c3, 0x00000000}},  //   dile_, spol, timu_,
  { {0x61e20197, 0x7c3e0010, 0x2d85006c, 0x00000000}},  //   ppol, _ápri, eile_,
  { {0x2d8521f3, 0x63a20160, 0xfaff0023, 0x00000000}},  //   file_, moon, zhës_,
  { {0x2d85023e, 0x3f840020, 0x00000000, 0x00000000}},  //   gile_, simu_,   ,
  { {0x4c94005e, 0x61e00009, 0xfaff2f53, 0x00000000}},  //   тинс, _html, xhës_,
  { {0x63a2011c, 0xe0df0011, 0x00000000, 0x00000000}},  //   noon, _đòi_,   ,
  { {0x2d85051b, 0x00000000, 0x00000000, 0x00000000}},  //   bile_,   ,   ,
  { {0x2d851e5a, 0x63a217c6, 0x6d4a2cd7, 0x00000000}},  //   cile_, hoon, _unfa,
  { {0x63a2003c, 0x27ed0091, 0x2bac0316, 0x00000000}},  //   koon, ćeno_, _टीका,
  { {0x25a1010f, 0x63a2006c, 0x660d2092, 0x00000000}},  //   wohl_, joon, tuak,
  { {0xfaff0065, 0xf48500a1, 0xb999003b, 0x00000000}},  // [bcb0] shës_, ھائی, _ових_,
  { {0xd2510167, 0x660d0032, 0x6d9c014a, 0x00000000}},  //   ینا_, ruak, _uçağ,
  { {0x63a202ae, 0x44270115, 0x79870009, 0x00000000}},  //   foon, ïn_, mijw,
  { {0x63a20be4, 0xdb16000a, 0x00000000, 0x00000000}},  //   goon, _chyè,   ,
  { {0xdb0400bb, 0x00000000, 0x00000000, 0x00000000}},  //   _skië,   ,   ,
  { {0x79870009, 0x2d85010e, 0x3a29000a, 0x00000000}},  //   nijw, xile_, _mpap_,
  { {0x63a201d6, 0x200e0009, 0xdcfa0035, 0x00000000}},  //   boon, gufi_, zită,
  { {0xc01c0011, 0x20070065, 0x63a2062a, 0x00000000}},  //   _hước_, rrni_, coon,
  { {0xe3b00188, 0x2d85001a, 0x32190076, 0x00000000}},  //   _طرف_, tile_, _زياد_,
  { {0x4d6501fb, 0x1c450aef, 0xdcfa001a, 0x00000000}},  //   тков, вном, vită,
  { {0x2d851305, 0xeb9a1662, 0x3b0a1123, 0x00000000}},  //   rile_, дин_, мено_,
  { {0x2d85001a, 0x29011799, 0x00560097, 0x00000000}},  //   sile_, _adha_, _בשעת_,
  { {0x3f7a0049, 0x3a290436, 0x3b000065, 0x00000000}},  //   _קאנס, _cpap_, _vdiq_,
  { {0xc01c00ad, 0xdcfa001a, 0xdce80006, 0x00000000}},  //   _nước_, rită, didė,
  { {0x98a61666, 0x63a20020, 0x00000000, 0x00000000}},  //   тиве, yoon,   ,
  { {0x9a6a0025, 0x00000000, 0x00000000, 0x00000000}},  //   _يمثل_,   ,   ,
  { {0x6b8436b3, 0xc01c001d, 0x7c240107, 0x00000000}},  // [bcc0] _imig, _bước_, _ćiri,
  { {0x63a201bb, 0xc01c0011, 0x09f700a0, 0x00000000}},  //   woon, _cước_, _שמים_,
  { {0x63a20fd5, 0x80c70055, 0x9f4e0065, 0x00000000}},  //   toon, রুত্, ënës_,
  { {0x91e60849, 0x9343073b, 0x00000000, 0x00000000}},  //   воде, инхе,   ,
  { {0x2564000c, 0x63a2006c, 0x82330025, 0x00000000}},  //   _sölu_, roon, لروا,
  { {0x63a2006c, 0x42d20044, 0xe0cf0025, 0x00000000}},  //   soon, ারেশ, يزى_,
  { {0x63a20020, 0xf993009b, 0x00000000, 0x00000000}},  //   poon, ברג_,   ,
  { {0x442a023a, 0x65b0010f, 0x44381352, 0x00000000}},  //   _ipb_, zähl, _isr_,
  { {0x442a1ce1, 0x753c00b4, 0x201c050f, 0x00000000}},  //   _hpb_, _karz, stvi_,
  { {0x6b840977, 0x44380022, 0xc01c0082, 0x00000000}},  //   _amig, _ksr_, _xước_,
  { {0x217501c0, 0x09e20044, 0x442a0085, 0x00000000}},  //   _сутр, _বিষা, _jpb_,
  { {0xf41300b6, 0x65b0010f, 0xdce10089, 0x00000000}},  //   ספר_, wähl, rklā,
  { {0xc33301f8, 0x80c70055, 0xed5a005e, 0x00000000}},  //   בור_, রুদ্, _оод_,
  { {0x6b8436b4, 0x753c0046, 0x09e20044, 0x00000000}},  //   _emig, _narz, _বিশা,
  { {0x97a7007c, 0x798722b1, 0x443836b5, 0x00000000}},  //   врал, rijw, _nsr_,
  { {0x25fe013d, 0x09e20044, 0x24b80044, 0x00000000}},  //   _लिखी_, _বিরা, জশাহ,
  { {0xc7c8007c, 0x443836b6, 0x45d40072, 0x00000000}},  // [bcd0] тыре_, _asr_, иотс,
  { {0x753c0026, 0x44380aa0, 0x6b840087, 0x00000000}},  //   _carz, _bsr_, _zmig,
  { {0x6f020061, 0x443805ae, 0xdce80006, 0x00000000}},  //   _odoc, _csr_, sidė,
  { {0x44380179, 0x386c068f, 0x6f0203e7, 0x00000000}},  //   _dsr_, ødre_, _ndoc,
  { {0x4438104a, 0xc01c0082, 0x753c0095, 0x00000000}},  //   _esr_, _tước_, _farz,
  { {0x753c1ee4, 0x7c380091, 0x7bcd0006, 0x00000000}},  //   _garz, _osvr, _liau,
  { {0xc9540097, 0x44380145, 0x673d21ca, 0x00000000}},  //   ימס_, _gsr_, _kasj,
  { {0xee390113, 0x753c0046, 0x9324026c, 0x00000000}},  //   ени_, _zarz, _پرِن,
  { {0x673d36b7, 0x63bb1721, 0x5cf5105c, 0x00000000}},  //   _masj, _ihun, ляну,
  { {0x257618f9, 0x6b840066, 0x27fe0059, 0x00000000}},  //   _vælg_, _smig, štni_,
  { {0x9f0506b4, 0x63bb0011, 0x6f020009, 0x00000000}},  //   _موضو, _khun, _fdoc,
  { {0x673d36b8, 0x2bba0025, 0x7bcd2b0f, 0x00000000}},  //   _nasj, عادة_, _ciau,
  { {0x7c2a107b, 0x7bcd0093, 0x63a900e7, 0x00000000}},  //   _epfr, _diau, _mken,
  { {0x6447014a, 0xfce20aa2, 0x6aad000a, 0x00000000}},  //   _orji, _лошо, _dyaf,
  { {0x63a90263, 0xbd9a0049, 0x673d0168, 0x00000000}},  //   _oken, _אױסט, _basj,
  { {0xe73700ed, 0x63bb0011, 0x753c2820, 0x00000000}},  //   лес_, _nhun, _sarz,
  { {0x64430698, 0x753c0207, 0x4438013f, 0x00000000}},  // [bce0] ænin, _parz, _ssr_,
  { {0x20180193, 0x44380b7d, 0x63a9010e, 0x00000000}},  //   _årig_, _psr_, _aken,
  { {0x63bb002a, 0x7af601c3, 0x753c2005, 0x00000000}},  //   _bhun, _keyt, _varz,
  { {0xe29a36b9, 0x63bb001d, 0x753c0036, 0x00000000}},  //   нае_, _chun, _warz,
  { {0xa683132a, 0x63bb0065, 0x753c1c17, 0x00000000}},  //   _гляд, _dhun, _tarz,
  { {0x64a60106, 0x7af61ea9, 0x63bb002d, 0x00000000}},  //   _бага, _leyt, _ehun,
  { {0x629c0046, 0x442a00ca, 0x80260014, 0x00000000}},  //   _środ, _upb_, ارتم,
  { {0x7af6000c, 0x444400e5, 0x63bb0177, 0x00000000}},  //   _neyt, mv_, _ghun,
  { {0xa5bb0051, 0x44442d0f, 0x7bcd007f, 0x00000000}},  //   _spói, lv_, _riau,
  { {0xa3d303d7, 0x71d7009b, 0x7bcd0006, 0x00000000}},  //   _हूँ_, _עובד_, _siau,
  { {0x7bcd0181, 0xdb55007c, 0x444436ba, 0x00000000}},  //   _piau, авны, nv_,
  { {0x444436bb, 0x69d600ab, 0x63bb0023, 0x00000000}},  //   iv_, _buye, _xhun,
  { {0xc33300b6, 0x673d0056, 0x4444006c, 0x00000000}},  //   זור_, _rasj, hv_,
  { {0x4444012d, 0xef19002b, 0x69d60082, 0x00000000}},  //   kv_, viżi_, _duye,
  { {0xa3d303d7, 0x672436bc, 0x673d05c9, 0x00000000}},  //   _हूं_, ffij, _pasj,
  { {0x44440232, 0x673d0065, 0x213e0544, 0x00000000}},  //   dv_, _qasj, _lath_,
  { {0x44440253, 0x673d00ca, 0xc987013b, 0x00000000}},  // [bcf0] ev_, _vasj, _буни,
  { {0x63a91105, 0x63bb1706, 0x64470061, 0x00000000}},  //   _sken, _shun, _prji,
  { {0xd6d10054, 0x63bb2088, 0x3d1c007d, 0x00000000}},  //   _وقد_, _phun, _माने_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4444164f, 0x213e00ab, 0x90d50082, 0x00000000}},  //   av_, _bath_, _dàn,
  { {0x3ce90107, 0xa5930167, 0x3f8636bd, 0x00000000}},  //   _đavo_, _اگرچ, _amou_,
  { {0x213e0051, 0x70520025, 0x63bb0122, 0x00000000}},  //   _dath_, قنوا, _thun,
  { {0x63a90637, 0x6f65005e, 0x660d0032, 0x00000000}},  //   _uken, рвиз, orak,
  { {0x44210038, 0x660d005d, 0x213e018e, 0x00000000}},  //   lth_, nrak, _fath_,
  { {0x213e005b, 0x660d36be, 0x65b0010e, 0x00000000}},  //   _gath_, irak, vähk,
  { {0x44210038, 0xdcfa0089, 0x69d60022, 0x00000000}},  //   nth_, entē, _suye,
  { {0x4421016d, 0x660d0089, 0x1ee700a2, 0x00000000}},  //   ith_, krak, _صوتی_,
  { {0xeb9701e0, 0x386a0016, 0x7ae904de, 0x00000000}},  //   рия_, wybr_, ñeta,
  { {0xfce5012b, 0x44210023, 0x7af600e0, 0x00000000}},  //   _токо, kth_, _weyt,
  { {0x46f6013b, 0x660d006c, 0x02b2006e, 0x00000000}},  //   ичат, erak, _जर्न,
  { {0x44210365, 0x69d60011, 0x44441768, 0x00000000}},  //   dth_, _tuye, vv_,
  { {0x44210bc4, 0x672400b5, 0xe737007c, 0x00000000}},  // [bd00] eth_, rfij, шет_,
  { {0x6d4107dc, 0x44440035, 0xe5770057, 0x00000000}},  //   ndla, tv_, азу_,
  { {0x68fc003b, 0x442108cb, 0x213e1d6c, 0x00000000}},  //   mard, gth_, _rath_,
  { {0x779401ef, 0x68fc01f6, 0x44440030, 0x00000000}},  //   _ایرا, lard, rv_,
  { {0x80ad0055, 0x213e0339, 0x44210122, 0x00000000}},  //   টেম্, _path_, ath_,
  { {0x2918000c, 0x333f00f4, 0x444400f6, 0x00000000}},  //   ngra_, _eaux_, pv_,
  { {0x333f00f4, 0x6d4136bf, 0x2167003b, 0x00000000}},  //   _faux_, ddla, рији_,
  { {0x68fc0c54, 0x931602fd, 0x3eaf00ea, 0x00000000}},  //   hard, _خورش, _bygt_,
  { {0x68fc014a, 0x27ed0091, 0x602a006b, 0x00000000}},  //   kard, ćeni_, _qəmb,
  { {0x5d66012b, 0x65b0010f, 0xe2a6000c, 0x00000000}},  //   ртиз, fähi, íðum_,
  { {0x2cb80d32, 0x10a60088, 0x6441000c, 0x00000000}},  //   ård_, _тижн, _álit,
  { {0x2d872cba, 0xbb94007c, 0x80ad0044, 0x00000000}},  //   _emne_, жающ, _চলচ্,
  { {0x68fc0056, 0x00000000, 0x00000000, 0x00000000}},  //   fard,   ,   ,
  { {0xac180245, 0x44210016, 0x68fc36c0, 0x00000000}},  //   _боку_, yth_, gard,
  { {0x2d8c006c, 0xb868098c, 0x2bd002fb, 0x00000000}},  //   mide_, ајте_, _संचा,
  { {0x2d8c11be, 0x291836c1, 0x8b67035b, 0x00000000}},  //   lide_, agra_, _خاتم,
  { {0x7afd36c2, 0x68fc027b, 0x7bd80073, 0x00000000}},  // [bd10] mast, bard, _huvu,
  { {0x7afd1c0b, 0x68fc0181, 0x660d22d1, 0x00000000}},  //   last, card, rrak,
  { {0x65ab001f, 0x442103a1, 0x660d0052, 0x00000000}},  //   führ, uth_, srak,
  { {0x7afd0073, 0x44213339, 0x660d36c3, 0x00000000}},  //   nast, rth_, prak,
  { {0x2bd0001c, 0x075600b6, 0x2d8c066f, 0x00000000}},  //   _संघा, _הסרט_, kide_,
  { {0x463a007b, 0x7afd0ac2, 0x4421275b, 0x00000000}},  //   _געשע, hast, pth_,
  { {0x7afd021e, 0x333f00f4, 0x65ab010f, 0x00000000}},  //   kast, _taux_, bühr,
  { {0x7afd044e, 0x2d8c0328, 0x67070309, 0x00000000}},  //   jast, eide_, षणिक_,
  { {0x7afd02d5, 0x68fc005d, 0x52850025, 0x00000000}},  //   dast, yard, _الذك,
  { {0x7bd80006, 0x30a701fc, 0x2d8c1683, 0x00000000}},  //   _buvu, _крев, gide_,
  { {0x68fc143d, 0x7afd141a, 0x6d4128e0, 0x00000000}},  //   vard, fast, rdla,
  { {0xe4560049, 0x68fc00ab, 0x3165010f, 0x00000000}},  //   צירט_, ward, _holz_,
  { {0x2d8c022b, 0x139a0049, 0x2b401690, 0x00000000}},  //   bide_, רברע, _vaic_,
  { {0x3f8d05f2, 0x7afd006c, 0x6d5c006c, 0x00000000}},  //   lieu_, aast, örat,
  { {0x2b400061, 0x2918000c, 0x00000000, 0x00000000}},  //   _taic_, rgra_,   ,
  { {0xea5a0080, 0x68fc0089, 0x5fa70061, 0x00000000}},  //   _број_, sard, खविल,
  { {0x09e20055, 0x7ae431d8, 0xe4d60025, 0x00000000}},  // [bd20] _বিকা, _ifit, متاب,
  { {0xceb200a0, 0x3f8d2afd, 0x7bc600ea, 0x00000000}},  //   לין_, hieu_, lmku,
  { {0xd8d7007b, 0xa5bb0d4e, 0x07a617fa, 0x00000000}},  //   _לויט_, _após, _ганн,
  { {0x798e0117, 0xdce300b9, 0x2d8c014a, 0x00000000}},  //   libw, _plně, zide_,
  { {0x7ae436c4, 0x65ab010f, 0x3f8d0082, 0x00000000}},  //   _mfit, rühr, dieu_,
  { {0x7afd26b5, 0x645800b0, 0x2d8c0133, 0x00000000}},  //   zast, ävis, xide_,
  { {0x2d8c00ab, 0x7ae40035, 0x55770049, 0x00000000}},  //   vide_, _ofit, _פעלן_,
  { {0x7bd80648, 0x7ae40066, 0x38c3009d, 0x00000000}},  //   _ruvu, _nfit, léré_,
  { {0x7afd0368, 0x2d8c006c, 0x798e0009, 0x00000000}},  //   vast, tide_, kibw,
  { {0x867b00b6, 0x71650054, 0x7ae436c5, 0x00000000}},  //   טרפו, _والك, _afit,
  { {0x2d8c10ea, 0xb09a0088, 0xad660014, 0x00000000}},  //   ride_, _стає_, لاگه,
  { {0x005700b3, 0x3f8d00d4, 0x00000000, 0x00000000}},  //   _לשבת_, cieu_,   ,
  { {0x2d8c00f4, 0x256f014a, 0x6d5c010e, 0x00000000}},  //   pide_, _yılı_, öras,
  { {0x7bd80089, 0x7afd36c6, 0x3eb9035a, 0x00000000}},  //   _tuvu, sast, üste_,
  { {0x38c300f4, 0x7ae40016, 0x3cfe00e5, 0x00000000}},  //   déré_, _ffit, matv_,
  { {0xe894007e, 0x3cfe004a, 0x89d90014, 0x00000000}},  //   чась, latv_, _پودر_,
  { {0xfa280044, 0x798e0009, 0x38c3009d, 0x00000000}},  // [bd30] মিউল_, bibw, féré_,
  { {0x67d50006, 0x7d1a0039, 0x3cfe0089, 0x00000000}},  //   _sąju, ngts, natv_,
  { {0xe4350014, 0x3b090009, 0x00000000, 0x00000000}},  //   تفاد, _kdaq_,   ,
  { {0xdfc60025, 0x316500ca, 0x00000000, 0x00000000}},  //   _زي_, _solz_,   ,
  { {0x3f8d00d4, 0x38c3009d, 0x31650066, 0x00000000}},  //   vieu_, béré_, _polz_,
  { {0xa069004d, 0x00000000, 0x00000000, 0x00000000}},  //   иала_,   ,   ,
  { {0xfaff0023, 0x80240025, 0x31e60044, 0x00000000}},  //   nkës_, كريم, _নিঃশ,
  { {0x798e0dfc, 0x65670087, 0x00000000, 0x00000000}},  //   zibw, _hojh,   ,
  { {0x63ab037e, 0x332d008e, 0x3f8d0666, 0x00000000}},  //   mogn, _ibex_, rieu_,
  { {0x63ab27b9, 0x98ba0089, 0x61e92f60, 0x00000000}},  //   logn, _lapā_, _itel,
  { {0x61e905fa, 0x602a006b, 0x00000000, 0x00000000}},  //   _htel, _təma,   ,
  { {0xcaca09ae, 0x65b00103, 0x6d5c00f8, 0x00000000}},  //   игне_, läht, örar,
  { {0x798e0a5f, 0x433a0049, 0x61e90066, 0x00000000}},  //   tibw, בערב, _jtel,
  { {0x2eff010f, 0x65b036c7, 0x3cfe0197, 0x00000000}},  //   lauf_, näht, catv_,
  { {0x7ae401d5, 0x798e002b, 0x6d43034a, 0x00000000}},  //   _tfit, ribw, _iana,
  { {0x6d43006a, 0x61e9014a, 0x7ae40061, 0x00000000}},  //   _hana, _otel, _ufit,
  { {0x056607ca, 0x6d430127, 0x63ab0026, 0x00000000}},  // [bd40] ован, _kana, dogn,
  { {0x6d4320eb, 0xa5bb1a43, 0xa50a0088, 0x00000000}},  //   _jana, _spór, режа_,
  { {0x61e900f4, 0x2eff01a2, 0x00000000, 0x00000000}},  //   _atel, kauf_,   ,
  { {0x6d43022b, 0xfe670379, 0x232a0088, 0x00000000}},  //   _lana, _قد_, роди_,
  { {0x38c3009d, 0x20050087, 0x224d0e98, 0x00000000}},  //   péré_, _avli_, _crek_,
  { {0x6d43006a, 0x66040020, 0x2d992656, 0x00000000}},  //   _nana, msik, ésel_,
  { {0x657e002a, 0x61e900b0, 0x66040f20, 0x00000000}},  //   mhph, _etel, lsik,
  { {0x69c70243, 0x63ab00ab, 0x6d430058, 0x00000000}},  //   zmje, cogn, _aana,
  { {0x224d0065, 0x660420d9, 0x6d430238, 0x00000000}},  //   _grek_, nsik, _bana,
  { {0x105600a1, 0x660436c8, 0x657e0011, 0x00000000}},  //   _وضاح, isik, nhph,
  { {0x6d430119, 0xdd97007e, 0x00000000, 0x00000000}},  //   _dana, ўшы_,   ,
  { {0x9e660188, 0x61e90056, 0x6d430048, 0x00000000}},  //   _واشن, _ytel, _eana,
  { {0x6d4336c9, 0x62820270, 0x09e4007e, 0x00000000}},  //   _fana, nzoo, моўн,
  { {0x6d4336ca, 0x2735001d, 0x6f000284, 0x00000000}},  //   _gana, _ấn_, lamc,
  { {0xf77305d4, 0x69c70065, 0x9848005e, 0x00000000}},  //   وار_, rmje, оята_,
  { {0x6d432097, 0x69c701ed, 0x6f0000e7, 0x00000000}},  //   _zana, smje, namc,
  { {0x6b8d0365, 0x6d4336cb, 0x63ab0737, 0x00000000}},  // [bd50] _imag, _yana, vogn,
  { {0x6d43001c, 0x09e20055, 0x344b1666, 0x00000000}},  //   _xana, _বিচা, ичен_,
  { {0x61e9001f, 0x917b0082, 0x6f0000e7, 0x00000000}},  //   _stel, hệ_, kamc,
  { {0x224d3019, 0x883a009b, 0x6f00016c, 0x00000000}},  //   _prek_, _פתרו, jamc,
  { {0x644e00b5, 0x63ab00f8, 0x6b8d00f6, 0x00000000}},  //   _erbi, rogn, _mmag,
  { {0xc244008b, 0x63ab0198, 0xd24e031d, 0x00000000}},  //   ьнік, sogn, انو_,
  { {0xddc90036, 0x6b8d0207, 0xf9940104, 0x00000000}},  //   rzeż, _omag, ורס_,
  { {0x6d43011f, 0x224d0aba, 0x7d0a0045, 0x00000000}},  //   _sana, _trek_, _adfs,
  { {0x6d43006a, 0x2eff010f, 0x61e90056, 0x00000000}},  //   _pana, rauf_, _utel,
  { {0x0d820194, 0x6b8d25f2, 0x4177004b, 0x00000000}},  //   ельн, _amag, _بارس,
  { {0x6d430277, 0x3d1c006e, 0xa3b800a1, 0x00000000}},  //   _vana, _मारे_, _طاہر_,
  { {0x6d430be3, 0x65b0010f, 0xeb9a017f, 0x00000000}},  //   _wana, nähr, сим_,
  { {0x6d43020c, 0xee2e007e, 0x80d00044, 0x00000000}},  //   _tana, _ян_, _স্প্,
  { {0xdce336cc, 0x6b8d00c4, 0x6d430020, 0x00000000}},  //   _konč, _emag, _uana,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66041e17, 0xab660088, 0x65b0010f, 0x00000000}},  //   tsik, _хвил, jähr,
  { {0x644e01a8, 0xfbd300b6, 0xf99f0e16, 0x00000000}},  // [bd60] _srbi, _אתה_, grès_,
  { {0x6b8d0059, 0x644e0087, 0x00000000, 0x00000000}},  //   _zmag, _prbi,   ,
  { {0x6604006c, 0x65b0010f, 0xf8db009b, 0x00000000}},  //   ssik, fähr, _לחימ,
  { {0x7d010052, 0x628200bb, 0x93cb00a1, 0x00000000}},  //   hals, tzoo, مانہ_,
  { {0x7d0105d5, 0x4b4d0049, 0x7bd602d4, 0x00000000}},  //   kals, יגאַ, _miyu,
  { {0x4034004c, 0x7d010059, 0x7bd600e7, 0x00000000}},  //   декс, jals, _liyu,
  { {0x50d600a1, 0x644e117a, 0x645a00d0, 0x00000000}},  //   _ہزار, _urbi, _štif,
  { {0x5ea50055, 0x232700e3, 0x7bd600e0, 0x00000000}},  //   খেছে, _носи_, _niyu,
  { {0x80a60123, 0x7d01094f, 0x00000000, 0x00000000}},  //   _کمان, fals,   ,
  { {0x6b8d36cd, 0xc2430500, 0x6f000107, 0x00000000}},  //   _smag, _янук, samc,
  { {0x6f00016c, 0x7bd60045, 0x00000000, 0x00000000}},  //   pamc, _biyu,   ,
  { {0x7bc40198, 0x7d01006c, 0xdce801df, 0x00000000}},  //   _chiu, aals, ğlıy,
  { {0x7d01001e, 0x602a005f, 0x2aab0242, 0x00000000}},  //   bals, _məmm, стно_,
  { {0x5e5700b6, 0xd90f01ef, 0x7c37049a, 0x00000000}},  //   _מידע_, دید_, ñarí,
  { {0x68fe023a, 0x6d580585, 0x6b8d00e0, 0x00000000}},  //   _depd, _inva, _tmag,
  { {0x5ba4008b, 0x6b8d011c, 0xf99f10cf, 0x00000000}},  //   _прыз, _umag, très_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [bd70]   ,   ,   ,
  { {0x6d4836ce, 0x65b0010f, 0xdb1f06c0, 0x00000000}},  //   ndda, währ, _liqü,
  { {0x290304d4, 0x6b9d07eb, 0x7c280146, 0x00000000}},  //   maja_, onsg, ntdr,
  { {0xf99f36cf, 0x69df0023, 0x9295007e, 0x00000000}},  //   près_, _kuqe, маец,
  { {0x21690175, 0x2d990047, 0x614500da, 0x00000000}},  //   жили_, ések_, дела,
  { {0x290301a3, 0xdce30c76, 0xe1f003e6, 0x00000000}},  //   naja_, _ponč, اسن_,
  { {0x7d01066e, 0x69d700ab, 0x7ae60039, 0x00000000}},  //   vals, _mixe, yckt,
  { {0x6d580263, 0x290336d0, 0x0858009b, 0x00000000}},  //   _anva, haja_, לבום_,
  { {0x2903006c, 0x7c2800d9, 0x00000000, 0x00000000}},  //   kaja_, etdr,   ,
  { {0x29030211, 0x7bc436d1, 0x7bd60058, 0x00000000}},  //   jaja_, _shiu, _siyu,
  { {0x290301d9, 0xd7bf001c, 0x7bd600e0, 0x00000000}},  //   daja_, ्षाच, _piyu,
  { {0x7d010058, 0x69d70129, 0x6d48005b, 0x00000000}},  //   sals, _aixe, adda,
  { {0x7d0100b0, 0x1d0901fc, 0x69d70032, 0x00000000}},  //   pals, _дели_, _bixe,
  { {0x29030059, 0x7bd60022, 0x00000000, 0x00000000}},  //   gaja_, _wiyu,   ,
  { {0xcb6a00ed, 0x66e60d68, 0xb906013d, 0x00000000}},  //   _маке_, доба, _फल_,
  { {0x69c50010, 0x69df0066, 0x5bc60025, 0x00000000}},  //   _ehhe, _fuqe, _تقبل,
  { {0x29030211, 0x7546003b, 0x69d70549, 0x00000000}},  // [bd80] baja_, мназ, _fixe,
  { {0x20070b2e, 0x29030091, 0xf1e1013d, 0x00000000}},  //   ksni_, caja_, _पढ़न,
  { {0x53e501fb, 0x395a0197, 0x2007016c, 0x00000000}},  //   еціа, _inps_, jsni_,
  { {0xb347002b, 0x320600e0, 0x00000000, 0x00000000}},  //   _neħħ, tsoy_,   ,
  { {0x6d4836d2, 0x6e29012d, 0x91e3007c, 0x00000000}},  //   ydda, jteb, воче,
  { {0xc693007b, 0xc1a80061, 0x25760030, 0x00000000}},  //   _יאר_, गवेग, _mælk_,
  { {0x443e0173, 0x6e2900c4, 0xd24e009e, 0x00000000}},  //   _èt_, eteb, انڈ_,
  { {0x2903016c, 0x602a006b, 0x3366007e, 0x00000000}},  //   zaja_, _həmk, _ўваг,
  { {0x6e291810, 0x6d580032, 0x00000000, 0x00000000}},  //   gteb, _pnva,   ,
  { {0x3eb80089, 0x98b10035, 0x236604eb, 0x00000000}},  //   ārt_, neză_, ljoj_,
  { {0x290300ee, 0x6d480016, 0x61e0032e, 0x00000000}},  //   vaja_, rdda, _huml,
  { {0x69d736d3, 0x7c2801d6, 0x61e036d4, 0x00000000}},  //   _sixe, rtdr, _kuml,
  { {0x29030cfc, 0x69d736d5, 0x61e0252e, 0x00000000}},  //   taja_, _pixe, _juml,
  { {0x66160142, 0x6d58019a, 0x00000000, 0x00000000}},  //   dryk, _unva,   ,
  { {0x29030518, 0x80d00044, 0x61e000e0, 0x00000000}},  //   raja_, _স্ত্, _luml,
  { {0x29032222, 0x316c0d28, 0x36d502b8, 0x00000000}},  //   saja_, _lodz_, еобр,
  { {0x98bf006b, 0x2366016c, 0x2d9e0026, 0x00000000}},  // [bd90] ırıb_, djoj_, onte_,
  { {0x2d9e23b7, 0x201c36d6, 0xd5bb0451, 0x00000000}},  //   nnte_, kuvi_, іса_,
  { {0x2d9e000d, 0x79950020, 0x6e290f30, 0x00000000}},  //   inte_, mizw, zteb,
  { {0x7995000b, 0x23660065, 0x2d9e010f, 0x00000000}},  //   lizw, gjoj_, hnte_,
  { {0x2901006c, 0x6fc5008e, 0xc6a701fc, 0x00000000}},  //   _keha_, nóce, _црни,
  { {0x27e12c1f, 0xc105067a, 0xb3470066, 0x00000000}},  //   _kuhn_, روبي, _seħħ,
  { {0xe05700a2, 0xdce30089, 0x2fc623a3, 0x00000000}},  //   بیات_, _nonā, _bhog_,
  { {0x2d9e0219, 0xfe4500ed, 0x6e2918ee, 0x00000000}},  //   ente_, енио, tteb,
  { {0xee3603c8, 0x6e290009, 0x79950020, 0x00000000}},  //   ены_, uteb, kizw,
  { {0x316c0036, 0x290136d7, 0xed4502dc, 0x00000000}},  //   _godz_, _neha_, хноп,
  { {0x6e29010a, 0x00000000, 0x00000000, 0x00000000}},  //   steb,   ,   ,
  { {0x2d9e0576, 0x6e2936d8, 0x00000000, 0x00000000}},  //   ante_, pteb,   ,
  { {0x395a0022, 0x29010032, 0x00000000, 0x00000000}},  //   _pnps_, _beha_,   ,
  { {0xdca5019d, 0x7995047b, 0x00000000, 0x00000000}},  //   _пали, gizw,   ,
  { {0x0d16009b, 0x00000000, 0x00000000, 0x00000000}},  //   _טקסט_,   ,   ,
  { {0x6616043e, 0x613301df, 0xf743007c, 0x00000000}},  //   tryk, lılı, лесо,
  { {0xe61a005e, 0x7dec0049, 0x98b10035, 0x00000000}},  // [bda0] яда_, ַקאַ, teză_,
  { {0x6133005d, 0x661604fd, 0xfaff0065, 0x00000000}},  //   nılı, rryk, njën_,
  { {0x61e00bf8, 0x69ce01a2, 0x00000000, 0x00000000}},  //   _suml, mmbe,   ,
  { {0x237f000d, 0x69ce17f2, 0x2576000c, 0x00000000}},  //   _cluj_, lmbe, _mæli_,
  { {0x6133005d, 0x2d9e36d9, 0x290100e0, 0x00000000}},  //   kılı, ynte_, _yeha_,
  { {0x602a005f, 0x7646007f, 0x00000000, 0x00000000}},  //   _həmi, _isky,   ,
  { {0x613300c3, 0xc0e701b7, 0x69ce0b57, 0x00000000}},  //   dılı, رفين_, imbe,
  { {0x44380146, 0x61e036da, 0x7bde009d, 0x00000000}},  //   _ipr_, _tuml, _épui,
  { {0x79950009, 0x44380bd3, 0x929d0036, 0x00000000}},  //   yizw, _hpr_, _pełe,
  { {0x44380093, 0x2d9e0026, 0xfaff0023, 0x00000000}},  //   _kpr_, unte_, gjën_,
  { {0x443829f0, 0x799501aa, 0x2cb805b7, 0x00000000}},  //   _jpr_, vizw, ærd_,
  { {0x4438023a, 0x69ce36db, 0xab950088, 0x00000000}},  //   _mpr_, embe, тимі,
  { {0xdb0f2656, 0x799500e7, 0x29010145, 0x00000000}},  //   nocé, tizw, _peha_,
  { {0x6133005d, 0x443800ca, 0x6f022139, 0x00000000}},  //   cılı, _opr_, _heoc,
  { {0x44380059, 0x79950009, 0x67260022, 0x00000000}},  //   _npr_, rizw, _bckj,
  { {0x6d4a018e, 0x602a005f, 0xba550545, 0x00000000}},  //   _hafa, _cəmi, _авиј,
  { {0x29010004, 0xc8f50265, 0x6d4a0dad, 0x00000000}},  // [bdb0] _teha_, _изпъ, _kafa,
  { {0x6d4a0697, 0x443804be, 0x656e0051, 0x00000000}},  //   _jafa, _bpr_, _cobh,
  { {0x44380030, 0x6d4a000b, 0x656e07da, 0x00000000}},  //   _cpr_, _mafa, _dobh,
  { {0x6d4a00be, 0x4438023a, 0x613301f6, 0x00000000}},  //   _lafa, _dpr_, zılı,
  { {0x6133005d, 0x00000000, 0x00000000, 0x00000000}},  //   yılı,   ,   ,
  { {0x6d4a36dc, 0x6133005f, 0x3d1c001c, 0x00000000}},  //   _nafa, xılı, _मागे_,
  { {0x8ffa00a1, 0xa156003b, 0xa3b5007e, 0x00000000}},  //   ورٹر_, тају_, _абві,
  { {0x64550066, 0x00000000, 0x00000000, 0x00000000}},  //   _irzi,   ,   ,
  { {0x0ea901fb, 0x6d4a130a, 0x6133047f, 0x00000000}},  //   ький_, _bafa, tılı,
  { {0x7aed0065, 0x673f0065, 0x320d0606, 0x00000000}},  //   _afat, heqj, _ivey_,
  { {0x6133038c, 0xdca50057, 0x6d4a0016, 0x00000000}},  //   rılı, тани, _dafa,
  { {0x1eea04e1, 0x6f020253, 0x64550091, 0x00000000}},  //   _قومی_, _geoc, _mrzi,
  { {0x6133005a, 0x6d4a36dd, 0x4a43005e, 0x00000000}},  //   pılı, _fafa, аняв,
  { {0x6d4a04bf, 0x602a006b, 0x64550026, 0x00000000}},  //   _gafa, _səmi, _orzi,
  { {0xbbe80025, 0x7aed0016, 0x69ce0c4c, 0x00000000}},  //   _كريم_, _ffat, rmbe,
  { {0x7d032bb0, 0xd910025a, 0x6d4a0253, 0x00000000}},  //   _hens, _گیس_, _zafa,
  { {0xc9aa01f9, 0x443836de, 0x6d4a14a5, 0x00000000}},  // [bdc0] _овие_, _spr_, _yafa,
  { {0x7d030030, 0x44380061, 0x64550091, 0x00000000}},  //   _jens, _ppr_, _brzi,
  { {0x602a005f, 0x00000000, 0x00000000, 0x00000000}},  //   _təmi,   ,   ,
  { {0xe29a007e, 0x64551238, 0x29cf01f3, 0x00000000}},  //   мае_, _drzi, _wżat_,
  { {0x6d2103d7, 0x645536df, 0x6f02041d, 0x00000000}},  //   _मांग_, _erzi, _reoc,
  { {0x7d030065, 0x09df0044, 0x4438033b, 0x00000000}},  //   _nens, বীকা, _tpr_,
  { {0x5f9408d6, 0xccf800b9, 0x00000000, 0x00000000}},  //   ликт, vbě_,   ,
  { {0x6724006c, 0x6d4a03ef, 0xfaff0023, 0x00000000}},  //   ngij, _safa, gjël_,
  { {0x6d4a0065, 0x44440016, 0x4ea6005e, 0x00000000}},  //   _pafa, lw_, ърка,
  { {0x7aed001a, 0x6d4a31ad, 0x44441651, 0x00000000}},  //   _sfat, _qafa, ow_,
  { {0x351b0476, 0xfe6f01ef, 0x7c2a0061, 0x00000000}},  //   ווינ, مدی_, _qqfr,
  { {0x6d4a000b, 0x76440061, 0x7d030007, 0x00000000}},  //   _wafa, kwiy, _eens,
  { {0x6d4a000b, 0x7d03010f, 0x6e2b0061, 0x00000000}},  //   _tafa, _fens, _gqgb,
  { {0xf2d30476, 0x7d0336e0, 0x2d8501ca, 0x00000000}},  //   יער_, _gens, chle_,
  { {0x6d3b012f, 0x63a20058, 0x29cf0066, 0x00000000}},  //   _חתונ, knon, _bżar_,
  { {0x7d03037e, 0x7d080030, 0x7aed0190, 0x00000000}},  //   _zens, lads, _ufat,
  { {0x6e20006c, 0x444400ab, 0x63a2138b, 0x00000000}},  // [bdd0] numb, ew_, dnon,
  { {0x7d080203, 0x2713001d, 0x04f40131, 0x00000000}},  //   nads, ện_, изую,
  { {0x6e200020, 0x98ba00b9, 0x83190084, 0x00000000}},  //   humb, _mapě_, فقار_,
  { {0x6e20000b, 0x3d1c001c, 0x63a236e1, 0x00000000}},  //   kumb, _माझे_, gnon,
  { {0x6e200020, 0x602a006b, 0x471a009b, 0x00000000}},  //   jumb, _məmu, _אורג,
  { {0x645536e2, 0x6e20008e, 0xdca60025, 0x00000000}},  //   _trzi, dumb, _هى_,
  { {0x7d0300f4, 0x6455001a, 0x660d0755, 0x00000000}},  //   _rens, _urzi, lsak,
  { {0x2f540057, 0x7d0301cb, 0x6e2036e3, 0x00000000}},  //   атьс, _sens, fumb,
  { {0x660d3277, 0x442104cb, 0x644500d2, 0x00000000}},  //   nsak, luh_, lwhi,
  { {0x4d6501fb, 0x00000000, 0x00000000, 0x00000000}},  //   уков,   ,   ,
  { {0x4421020c, 0x7d0301e3, 0xa3c7007d, 0x00000000}},  //   nuh_, _vens, _उठा_,
  { {0x4fa401fb, 0x7d030250, 0x6e200d59, 0x00000000}},  //   _києв, _wens, bumb,
  { {0x2d8b028c, 0x7d080010, 0x442114c3, 0x00000000}},  //   èces_, bads, huh_,
  { {0xfe9a0049, 0x660d0056, 0x09e3003b, 0x00000000}},  //   _אינמ, dsak, сорн,
  { {0xa6db009f, 0xe73a17be, 0x442104cb, 0x00000000}},  //   _maðu, нев_, juh_,
  { {0x6d4136e4, 0x8a96007a, 0x6f09020f, 0x00000000}},  //   lela, _مشخص, naec,
  { {0x67240655, 0x6b84011c, 0xa7a701e0, 0x00000000}},  // [bde0] rgij, _ilig, укта_,
  { {0x6d410cf8, 0x850600a2, 0x76440022, 0x00000000}},  //   nela, اوان, rwiy,
  { {0x444402ae, 0x290a2345, 0x442104cb, 0x00000000}},  //   uw_, maba_, guh_,
  { {0x6d41175f, 0x290a2378, 0x6e2014a5, 0x00000000}},  //   hela, laba_, yumb,
  { {0x63a2011c, 0x69de33be, 0x44440026, 0x00000000}},  //   rnon, _kipe, sw_,
  { {0x4421020c, 0x6b840129, 0x290a0dfb, 0x00000000}},  //   buh_, _llig, naba_,
  { {0x6d4101d9, 0x6b842b35, 0x7f400009, 0x00000000}},  //   dela, _olig, temq,
  { {0x6e20036b, 0x290a036b, 0xa85700b6, 0x00000000}},  //   tumb, haba_, ריקה_,
  { {0x290a36e5, 0x6d410016, 0x7d080239, 0x00000000}},  //   kaba_, fela, tads,
  { {0x6b840365, 0x01d70644, 0x6e2013df, 0x00000000}},  //   _alig, _موقع_, rumb,
  { {0x290a0211, 0x6b84011a, 0x6e200d92, 0x00000000}},  //   daba_, _blig, sumb,
  { {0x7d0836e6, 0x6e202984, 0x2b820051, 0x00000000}},  //   sads, pumb, _póca_,
  { {0x6d410127, 0x7d0836e7, 0x6b841270, 0x00000000}},  //   bela, pads, _dlig,
  { {0x2905002a, 0x6b84058a, 0x6d410169, 0x00000000}},  //   úla_, _elig, cela,
  { {0x69de25ff, 0x4cd20044, 0x6b8400ab, 0x00000000}},  //   _dipe, _দ্রু, _flig,
  { {0x660d143d, 0x602a006b, 0x69de0048, 0x00000000}},  //   tsak, _həms, _eipe,
  { {0x290a006a, 0x98a5005d, 0xdb0f008e, 0x00000000}},  // [bdf0] baba_, ılı_, nocí,
  { {0x7afd010f, 0x290a029d, 0x442104cb, 0x00000000}},  //   lbst, caba_, tuh_,
  { {0x660d00b0, 0xe5c4007c, 0x7bcd05cd, 0x00000000}},  //   ssak, ссто, _khau,
  { {0x44210149, 0x6d41002d, 0x660d010e, 0x00000000}},  //   ruh_, zela, psak,
  { {0x7bdf0129, 0x4421003f, 0x201c0026, 0x00000000}},  //   _miqu, suh_, ervi_,
  { {0x6edb001e, 0x657e2fe9, 0x442104cb, 0x00000000}},  //   _jābū, ckph, puh_,
  { {0xddcb010a, 0x98b8001a, 0x6f09005b, 0x00000000}},  //   žiūr, meră_, taec,
  { {0xee3909bb, 0x290a008e, 0x7bdf009d, 0x00000000}},  //   вни_, zaba_, _niqu,
  { {0x6d410149, 0x63bb01d5, 0x52380123, 0x00000000}},  //   tela, _ikun, _مسلح_,
  { {0x6b8400ab, 0x6b9636e8, 0x290a00c4, 0x00000000}},  //   _slig, _smyg, xaba_,
  { {0x6b840286, 0x69de0207, 0x30a70242, 0x00000000}},  //   _plig, _ripe, _срав,
  { {0xeb9a012b, 0x7bcd028c, 0x6d410127, 0x00000000}},  //   тим_, _chau, sela,
  { {0x290a36e9, 0x63a936ea, 0x7bdf004a, 0x00000000}},  //   taba_, _mjen, _diqu,
  { {0x7aef001c, 0x63a901ed, 0xb6070066, 0x00000000}},  //   acct, _ljen, _miġġ,
  { {0x290a300f, 0x63bb011f, 0x7bdf0181, 0x00000000}},  //   raba_, _okun, _fiqu,
  { {0x7aef001c, 0x63a90295, 0x63bb36eb, 0x00000000}},  //   ccct, _njen, _nkun,
  { {0xaa46004c, 0x7ae40061, 0x69de36ec, 0x00000000}},  // [be00] _тепл, _igit, _tipe,
  { {0x63a90c8f, 0x929d0046, 0x63bb023a, 0x00000000}},  //   _ajen, _pełn, _akun,
  { {0x9986025a, 0x799c0009, 0x00000000, 0x00000000}},  //   _ملکو, mirw,   ,
  { {0x7bdf0129, 0x799c0009, 0x63a9016e, 0x00000000}},  //   _xiqu, lirw, _cjen,
  { {0x63a901ee, 0x42540025, 0x98b8001a, 0x00000000}},  //   _djen, إنتر, beră_,
  { {0x63a90030, 0x799c0009, 0xf1aa0025, 0x00000000}},  //   _ejen, nirw, خاصه_,
  { {0x64a3007e, 0x63a90030, 0x7ae40032, 0x00000000}},  //   _дара, _fjen, _ogit,
  { {0x63a936ed, 0x799c0009, 0x7ae4011c, 0x00000000}},  //   _gjen, hirw, _ngit,
  { {0x799c0009, 0xddc200e5, 0x00000000, 0x00000000}},  //   kirw, _croş,   ,
  { {0x7bdf0489, 0x7bcd00f0, 0x63a901ed, 0x00000000}},  //   _siqu, _shau, _zjen,
  { {0xdeef04af, 0x7aef001c, 0xfe1802f4, 0x00000000}},  //   _мы_, tcct, _दिवस_,
  { {0x63a9002b, 0x81cb0044, 0x2fc00048, 0x00000000}},  //   _xjen, _রূপ_, _óig_,
  { {0xc33300b6, 0x7bdf04bd, 0x602a006b, 0x00000000}},  //   חור_, _viqu, _təms,
  { {0x7ae40756, 0x799c0009, 0x7bdf00f6, 0x00000000}},  //   _egit, girw, _wiqu,
  { {0x7bdf0f57, 0x7bcd0066, 0x3707005e, 0x00000000}},  //   _tiqu, _thau, ичав,
  { {0x386d0166, 0x7bcd00fa, 0xc9270044, 0x00000000}},  //   ćer_, _uhau, য়েত_,
  { {0x6b8701ef, 0xfaff0065, 0x799c0009, 0x00000000}},  // [be10] _مشکل, mbë_, birw,
  { {0x63a90166, 0x799c0045, 0xe5c40194, 0x00000000}},  //   _sjen, cirw, осхо,
  { {0xaab8007a, 0x63a9016e, 0x04670b81, 0x00000000}},  //   _مدیر_, _pjen, штам,
  { {0x6cd90049, 0x6b9d0016, 0x98b8001a, 0x00000000}},  //   אַנצ, nisg, seră_,
  { {0x4ec10055, 0x63a9016e, 0x926b005e, 0x00000000}},  //   _উল্ল, _vjen, ържа_,
  { {0x61450081, 0x6b9d00e0, 0x00000000, 0x00000000}},  //   сека, hisg,   ,
  { {0x3f860007, 0x63a92229, 0x63bb002b, 0x00000000}},  //   _blou_, _tjen, _tkun,
  { {0x63a90020, 0x63bb0dfc, 0x1f65007c, 0x00000000}},  //   _ujen, _ukun, ским,
  { {0x799c0009, 0x6b9d0271, 0x98b80a62, 0x00000000}},  //   yirw, disg, merą_,
  { {0x51740054, 0x417401b7, 0xbd890014, 0x00000000}},  //   _والأ, _والس, اندن_,
  { {0x3b0a0264, 0x61e90211, 0x443336ee, 0x00000000}},  //   лено_, _huel, ntx_,
  { {0x61e9000b, 0x63b936ef, 0x3fc9007a, 0x00000000}},  //   _kuel, nown, _صدای_,
  { {0xeb97046c, 0x61e101a6, 0x61e90190, 0x00000000}},  //   сия_, _kill, _juel,
  { {0x61e1002b, 0x61e9008e, 0x60c100b0, 0x00000000}},  //   _jill, _muel, _kylm,
  { {0x63b90046, 0xdca20517, 0x7dc6009f, 0x00000000}},  //   kown, _наши, iðsl,
  { {0x61e10018, 0x61e90068, 0x63b900b4, 0x00000000}},  //   _lill, _ouel, jown,
  { {0x63b90036, 0x9f4500f6, 0x61e9002d, 0x00000000}},  // [be20] down, _culé_, _nuel,
  { {0xd91001ef, 0x61e10239, 0xb8ce0044, 0x00000000}},  //   _زیر_, _nill, _ঔর_,
  { {0x74130025, 0x44331291, 0xdb0f004a, 0x00000000}},  //   كولا, gtx_, locá,
  { {0x61e100f4, 0x61e9002d, 0x9a55009e, 0x00000000}},  //   _aill, _buel, _اٹیچ,
  { {0x61e10905, 0x61e90211, 0x200501f3, 0x00000000}},  //   _bill, _cuel, _awli_,
  { {0x61e9022b, 0x61e136f0, 0xa15801ee, 0x00000000}},  //   _duel, _cill, раку_,
  { {0x61e104bd, 0x01330054, 0xdfd0023c, 0x00000000}},  //   _dill, سعود, ويت_,
  { {0x63b90046, 0x645c086a, 0xadf400e2, 0x00000000}},  //   cown, _irri, опиш,
  { {0x61e136f1, 0xbdf7009e, 0x00000000, 0x00000000}},  //   _fill, یریا_,   ,
  { {0x61e10073, 0x61ef00f4, 0xf99f01aa, 0x00000000}},  //   _gill, _écla, nsèt_,
  { {0xb5fb0489, 0x61e9002d, 0xe0850025, 0x00000000}},  //   _gráf, _zuel, _وجمي,
  { {0x60db0049, 0x255f0089, 0x00000000, 0x00000000}},  //   _עקאנ, _zālē_,   ,
  { {0xfaff0065, 0x26c20146, 0x6b9d0fd1, 0x00000000}},  //   rbë_, _nyko_, risg,
  { {0x645c022b, 0x6b9d00bb, 0x00000000, 0x00000000}},  //   _orri, sisg,   ,
  { {0x2d9e36f2, 0x65750428, 0x2d8c0048, 0x00000000}},  //   mite_, _rozh, mhde_,
  { {0x2d9e09d8, 0x4735007e, 0x7d0a000c, 0x00000000}},  //   lite_, ўнас, _hefs,
  { {0x557500ed, 0x2d9e0051, 0x644e174d, 0x00000000}},  // [be30] огат, oite_, _asbi,
  { {0x2d9e1d7a, 0x645c0284, 0x0907243b, 0x00000000}},  //   nite_, _brri, _учим,
  { {0x61e90211, 0x61e101d6, 0x63b90036, 0x00000000}},  //   _suel, _rill, town,
  { {0x61e1021e, 0x2d9e36f3, 0x44330066, 0x00000000}},  //   _sill, hite_, rtx_,
  { {0x2d9e010a, 0x61e911c5, 0x645c09ce, 0x00000000}},  //   kite_, _quel, _erri,
  { {0x61e90219, 0x2d9e0209, 0x1a9c0049, 0x00000000}},  //   _vuel, jite_, ניגע,
  { {0x61e1028c, 0x2d9e0209, 0x94750014, 0x00000000}},  //   _vill, dite_, _بگذا,
  { {0x5334012b, 0x7d180061, 0x61e907a4, 0x00000000}},  //   _нест, _advs, _tuel,
  { {0x2d9e0600, 0x61e102e1, 0xb5fb0010, 0x00000000}},  //   fite_, _till, _drág,
  { {0xb5fb029d, 0x2d9e0181, 0x2d8c0051, 0x00000000}},  //   _tráf, gite_, ghde_,
  { {0x5baa2672, 0xb5fb36f4, 0x7f190014, 0x00000000}},  //   иком_, _frág, _نياز_,
  { {0xf4120104, 0xdb960088, 0x2c57001a, 0x00000000}},  //   ופט_, ішнь, _văd_,
  { {0x2d9e0059, 0xab5b01df, 0x00000000, 0x00000000}},  //   bite_, mlül,   ,
  { {0x2d9e0209, 0x80d00044, 0x3f8d00c4, 0x00000000}},  //   cite_, _স্ট্, lheu_,
  { {0x765d008d, 0xa4140044, 0x00000000, 0x00000000}},  //   _arsy, _সহ্য_,   ,
  { {0xfbc3005e, 0xfaa620e6, 0x00000000, 0x00000000}},  //   _общо, _майо,   ,
  { {0xf50a012b, 0xb6a601be, 0x6f0b0010, 0x00000000}},  // [be40] инал_, циал, _megc,
  { {0x7bc60023, 0x26c20006, 0x644e012d, 0x00000000}},  //   llku, _vyko_, _psbi,
  { {0x66e6013b, 0x2db6007b, 0xf65100a1, 0x00000000}},  //   _мона, קלען_, وئے_,
  { {0x2d9e0209, 0x8936026c, 0xd62a012b, 0x00000000}},  //   zite_, _اٹھا, _коме_,
  { {0x2d9e01aa, 0xdce300b9, 0xbb3b0049, 0x00000000}},  //   yite_, _poně, שעני,
  { {0x753c0091, 0x201a00c4, 0x2d9e0082, 0x00000000}},  //   _ubrz, ápio_, xite_,
  { {0xcc240055, 0x645c022b, 0x7d0a000c, 0x00000000}},  //   _বন্ধ_, _urri, _refs,
  { {0x93fb0104, 0xfc460802, 0xfaff0023, 0x00000000}},  //   _כללי, šíku_, njët_,
  { {0x2d9e36f5, 0xe29a01f9, 0x4fb300a1, 0x00000000}},  //   tite_, _таа_, بصور,
  { {0x6609014a, 0x7bc6046a, 0x00000000, 0x00000000}},  //   _çeke, elku,   ,
  { {0x2d9e36f6, 0x7d0a009f, 0xb5fb2ff2, 0x00000000}},  //   rite_, _vefs, _trág,
  { {0x2d9e09d8, 0x3f8d00c4, 0x00000000, 0x00000000}},  //   site_, cheu_,   ,
  { {0x7fd700bd, 0x2d9e0209, 0x7ae9016c, 0x00000000}},  //   _וואס_, pite_, žeto,
  { {0x27fa0281, 0x2d9e0023, 0x00000000, 0x00000000}},  //   _btpn_, qite_,   ,
  { {0x6d48006c, 0x67d502d3, 0x00000000, 0x00000000}},  //   meda, зову,   ,
  { {0x6d4801d9, 0x442101ca, 0x7c2836f7, 0x00000000}},  //   leda, vrh_, mudr,
  { {0xd6db0131, 0x1634073b, 0x00000000, 0x00000000}},  // [be50] ртв_, метя,   ,
  { {0x6d48018e, 0x4421013e, 0x00000000, 0x00000000}},  //   neda, trh_,   ,
  { {0x69c70f3a, 0x290332fc, 0x29110da4, 0x00000000}},  //   mlje, mbja_, maza_,
  { {0x6d48006c, 0x69c70af9, 0xb5fb01ca, 0x00000000}},  //   heda, llje, _prád,
  { {0x0204008b, 0x6d48023a, 0xd179007e, 0x00000000}},  //   дзін, keda, йскі_,
  { {0x88df0055, 0x764d01aa, 0x6d480091, 0x00000000}},  //   _ব্যক, mway, jeda,
  { {0x6d48148f, 0xfaff0065, 0x601007da, 0x00000000}},  //   deda, njës_, _rómá,
  { {0x672d21c4, 0xb5fb002a, 0x291129df, 0x00000000}},  //   ngaj, _trád, haza_,
  { {0x60b500a1, 0x29110091, 0x6d4800f6, 0x00000000}},  //   _کمائ, kaza_, feda,
  { {0x61fb1535, 0x6d48095c, 0x69c70243, 0x00000000}},  //   _itul, geda, jlje,
  { {0x63ab0082, 0x7c280089, 0x00000000, 0x00000000}},  //   ongn, gudr,   ,
  { {0x61fb001c, 0x764d0173, 0x2911001a, 0x00000000}},  //   _ktul, kway, eaza_,
  { {0x6d4836f8, 0xed59091b, 0x63ab0048, 0x00000000}},  //   beda, _гол_, ingn,
  { {0x290c027b, 0x6e290211, 0x6d48001a, 0x00000000}},  //   úda_, mueb, ceda,
  { {0xfaff0065, 0x6e290045, 0x7c28004a, 0x00000000}},  //   gjës_, lueb, cudr,
  { {0xc0520049, 0x00000000, 0x00000000, 0x00000000}},  //   עזן_,   ,   ,
  { {0x69c7092f, 0x6fc502d5, 0x29110061, 0x00000000}},  // [be60] blje, góci, baza_,
  { {0x2d8536f9, 0xe61701e1, 0x2911004a, 0x00000000}},  //   nkle_, яду_, caza_,
  { {0x98160355, 0x225f0022, 0x61fb25d0, 0x00000000}},  //   _عبدا, _aruk_, _atul,
  { {0x394a0050, 0x225f36fa, 0x764d0019, 0x00000000}},  //   lebs_, _bruk_, bway,
  { {0x11540259, 0x6d480020, 0x6fc516b5, 0x00000000}},  //   дклю, yeda, cóci,
  { {0x225f0100, 0xb5fb009f, 0xc6930049, 0x00000000}},  //   _druk_, _fráb, _טאר_,
  { {0x6d4836fb, 0x0443005e, 0x39580089, 0x00000000}},  //   veda, _перн, idrs_,
  { {0x7c280479, 0x645b0036, 0x6d481e11, 0x00000000}},  //   vudr, śció, weda,
  { {0x6d48006b, 0x6e2936fc, 0x225f0146, 0x00000000}},  //   teda, gueb, _gruk_,
  { {0x63a236fd, 0x71a3003b, 0x667b0049, 0x00000000}},  //   lion, _зауз, צטיק,
  { {0x69c701ae, 0xfe6f0167, 0x29110107, 0x00000000}},  //   vlje, ندی_, vaza_,
  { {0x63a22820, 0x29110020, 0x799e000a, 0x00000000}},  //   nion, waza_, _ampw,
  { {0x6d480207, 0x69c710f7, 0x291100e7, 0x00000000}},  //   peda, tlje, taza_,
  { {0x63a20197, 0xed57007e, 0x2d8500ab, 0x00000000}},  //   hion, _ноч_, ckle_,
  { {0x2911000b, 0x63a236fe, 0xb5fb00d6, 0x00000000}},  //   raza_, kion, _orác,
  { {0x69c70363, 0x764d0ed7, 0xf77301fa, 0x00000000}},  //   slje, tway, راز_,
  { {0x63a2096f, 0x69c710f7, 0xab5b005f, 0x00000000}},  // [be70] dion, plje, hlük,
  { {0x6fc50036, 0x26c70089, 0x764d0133, 0x00000000}},  //   róci, āno_, rway,
  { {0x6b8d0030, 0x80c20055, 0x61fb0ba5, 0x00000000}},  //   _klag, ষেত্, _stul,
  { {0x63a20198, 0xf65f0030, 0xf8b200b3, 0x00000000}},  //   gion, _træ_, _ישי_,
  { {0x2d850036, 0xb5fb004a, 0x00000000, 0x00000000}},  //   ykle_, _drác,   ,
  { {0x6b8d36ff, 0x98140014, 0x00000000, 0x00000000}},  //   _llag, _تبیا,   ,
  { {0x63a20046, 0x6b8d0039, 0x6b8600ea, 0x00000000}},  //   bion, _olag, ykkg,
  { {0x63a20919, 0x225f023a, 0x0e650131, 0x00000000}},  //   cion, _truk_, дкин,
  { {0xe3b0025a, 0x61fb0020, 0x00000000, 0x00000000}},  //   _صرف_, _utul,   ,
  { {0x6b8d3700, 0x6e290211, 0x00000000, 0x00000000}},  //   _alag, rueb,   ,
  { {0x6b8d073a, 0x1b4a00e3, 0x00000000, 0x00000000}},  //   _blag, озни_,   ,
  { {0x394a3701, 0xf9890104, 0x6e29004a, 0x00000000}},  //   webs_, _דר_, pueb,
  { {0x2a60002b, 0x6e290666, 0x00000000, 0x00000000}},  //   _qrib_, queb,   ,
  { {0x63a205d3, 0x57b60061, 0x6b8d010e, 0x00000000}},  //   zion, ंव्ह, _elag,
  { {0x394a01a2, 0x00000000, 0x00000000, 0x00000000}},  //   rebs_,   ,   ,
  { {0x63a20919, 0x2905000c, 0x2a60237d, 0x00000000}},  //   xion, ðlar_, _trib_,
  { {0xab5b014a, 0x9f4500f6, 0x7bc43702, 0x00000000}},  // [be80] zlük, _mulà_, _ikiu,
  { {0x63a20046, 0x62820020, 0x6b8d00ca, 0x00000000}},  //   wion, vyoo, _zlag,
  { {0xb5fb3703, 0x69dc0210, 0x661606d5, 0x00000000}},  //   _prác, mmre, ssyk,
  { {0x69dc03f1, 0x66163704, 0x27f70161, 0x00000000}},  //   lmre, psyk, žené_,
  { {0x63a23322, 0xd041006b, 0xb5fb01dc, 0x00000000}},  //   rion, _izlə, _vrác,
  { {0x14b70061, 0x00000000, 0x00000000, 0x00000000}},  //   _अडचण,   ,   ,
  { {0x03a6017a, 0xb5fb10b3, 0x63a20036, 0x00000000}},  //   _живо, _trác, pion,
  { {0xab5b014a, 0x04430545, 0x2269013e, 0x00000000}},  //   rlük, _шесн, átký_,
  { {0x657c3705, 0x113a007e, 0x03a310f3, 0x00000000}},  //   _korh, _мяжы_, _рито,
  { {0xe1660380, 0x7bc400e7, 0xe12301ee, 0x00000000}},  //   _تدري, _akiu, _амфи,
  { {0x6b8d3706, 0xe0460088, 0x657c0145, 0x00000000}},  //   _plag, _інди, _morh,
  { {0x0a6b005e, 0x61e8005b, 0x4ea6173a, 0x00000000}},  //   орги_, _hidl, _орла,
  { {0xfe720426, 0x6b8d0059, 0x61e80058, 0x00000000}},  //   _جدا_, _vlag, _kidl,
  { {0x7dcf0637, 0x657c3707, 0x00000000, 0x00000000}},  //   løsn, _norh,   ,
  { {0x61e8122f, 0x6b8d011c, 0x6d580026, 0x00000000}},  //   _midl, _tlag, _iava,
  { {0x7e620073, 0x6d58011f, 0x6d5a004e, 0x00000000}},  //   _krop, _hava, ldta,
  { {0x6d580004, 0x7aed006c, 0x657c01a3, 0x00000000}},  // [be90] _kava, _igat, _borh,
  { {0x6d580365, 0x6d5a0333, 0xca48007a, 0x00000000}},  //   _java, ndta, _کلیه_,
  { {0x6d5824fc, 0x3c380010, 0x200c0022, 0x00000000}},  //   _mava, név_, _nwdi_,
  { {0x6d580263, 0x7e62097c, 0xc79700a1, 0x00000000}},  //   _lava, _orop, _کھڑا_,
  { {0x657c02cc, 0x61e8002b, 0x2169003b, 0x00000000}},  //   _forh, _bidl, зили_,
  { {0x6d583708, 0x205500c0, 0xdb1d03a2, 0x00000000}},  //   _nava, етир, llsä,
  { {0x7aed012d, 0x7e620022, 0x61e83709, 0x00000000}},  //   _ogat, _arop, _didl,
  { {0xa4d401fb, 0x7aed0065, 0x7e620190, 0x00000000}},  //   _росі, _ngat, _brop,
  { {0x7c3a2b6e, 0x7e620133, 0x78b700e5, 0x00000000}},  //   ettr, _crop, _lxxv,
  { {0x6d58005f, 0x7c3a04d3, 0xb06b09b9, 0x00000000}},  //   _cava, fttr, _وصال_,
  { {0x6d58005f, 0x7e620169, 0x7aed012d, 0x00000000}},  //   _dava, _erop, _bgat,
  { {0x69c500e7, 0xa11300a1, 0x7e620022, 0x00000000}},  //   _akhe, _سوچت, _frop,
  { {0xbe8701f7, 0x7e6211c9, 0x6d580197, 0x00000000}},  //   _تجاو, _grop, _fava,
  { {0x6d580416, 0x6e3b00d9, 0x602a006b, 0x00000000}},  //   _gava, mtub, _rəmz,
  { {0x186701f9, 0xf7460131, 0x6e3b0032, 0x00000000}},  //   нари_, нево, ltub,
  { {0x6d5801d9, 0x9f460207, 0x7bc40020, 0x00000000}},  //   _zava, _cioè_, _ukiu,
  { {0xcf92007b, 0x6d58005a, 0x3ea0000c, 0x00000000}},  // [bea0] אטן_, _yava, _þitt_,
  { {0x443a0061, 0x09060069, 0x6d581052, 0x00000000}},  //   ttp_, _япон, _xava,
  { {0x03260373, 0x657c001f, 0x399b0049, 0x00000000}},  //   еден, _vorh, _זייד,
  { {0xb5fb1f2c, 0x6e3b370a, 0x443a000a, 0x00000000}},  //   _irán, ktub, rtp_,
  { {0x6d430087, 0x443a0146, 0x71a600a5, 0x00000000}},  //   _obna, stp_, надз,
  { {0x64a60099, 0x6604370b, 0xa3dc0061, 0x00000000}},  //   _зага, mpik, _ठळक_,
  { {0x61e8016e, 0x395a06d7, 0x78b70288, 0x00000000}},  //   _vidl, _maps_, _xxxv,
  { {0xdb1d00f4, 0x395a006c, 0x6d58370c, 0x00000000}},  //   posé, _laps_, _sava,
  { {0x6d582154, 0x61e802cc, 0x64550009, 0x00000000}},  //   _pava, _tidl, _zszi,
  { {0x409600e1, 0x721b00b3, 0x5096003b, 0x00000000}},  //   _прет, _מומח, _пређ,
  { {0x6fc500dc, 0x6e3b00c4, 0x6d580052, 0x00000000}},  //   tóct, atub, _vava,
  { {0x7e620198, 0x6d430009, 0x317e0032, 0x00000000}},  //   _trop, _ebna, _hotz_,
  { {0x6d5808b2, 0x7c3a00f8, 0xb5fb370d, 0x00000000}},  //   _tava, sttr, _arán,
  { {0xf2d3007b, 0x395a0129, 0x09e4008b, 0x00000000}},  //   טער_, _caps_, лоўн,
  { {0x7aed001c, 0x8d5b00b6, 0x9848005e, 0x00000000}},  //   _tgat, _זכוי, нята_,
  { {0x0aeb0379, 0x317e01c3, 0x36d502dc, 0x00000000}},  //   _عربي_, _lotz_, вобр,
  { {0x9f460026, 0x66040058, 0x00000000, 0x00000000}},  // [beb0] _cioé_, gpik,   ,
  { {0x57f501e0, 0x64550010, 0x61ef009d, 0x00000000}},  //   _ипот, _pszi, _écli,
  { {0x26e20055, 0xdcf80182, 0x645a0059, 0x00000000}},  //   গুলো_, _novč, _štir,
  { {0x291300c4, 0xae21006e, 0x00000000, 0x00000000}},  //   _hexa_, _मिलन_,   ,
  { {0x2bb60089, 0x29130032, 0x00000000, 0x00000000}},  //   nāca_, _kexa_,   ,
  { {0x25a5009f, 0xdcf80087, 0x00000000, 0x00000000}},  //   _öll_, _bovč,   ,
  { {0x94d4025f, 0xf33300a1, 0x1fb50069, 0x00000000}},  //   _борц, _مہاج, ксир,
  { {0xfe4501f9, 0x883c009b, 0x291305d2, 0x00000000}},  //   внио, פתחו, _lexa_,
  { {0xdb0f0023, 0x6e3b05f0, 0x00000000, 0x00000000}},  //   ancë, utub,   ,
  { {0x6e3b04cb, 0x399401a2, 0x00000000, 0x00000000}},  //   rtub, _käse_,   ,
  { {0x6e3b006c, 0x6604002d, 0x317a0049, 0x00000000}},  //   stub, zpik, _קרעמ,
  { {0x395a0129, 0x6ff10089, 0xdb060023, 0x00000000}},  //   _saps_, _nāci, mikë,
  { {0xed4e012b, 0xeb9701be, 0x395a0058, 0x00000000}},  //   _ко_, тия_, _paps_,
  { {0x2fcd000c, 0x00000000, 0x00000000, 0x00000000}},  //   lleg_,   ,   ,
  { {0x6f092dd6, 0x661d093b, 0xdb060023, 0x00000000}},  //   obec, _avsk, nikë,
  { {0x2fcd0e58, 0x6d410b36, 0xeafa0123, 0x00000000}},  //   nleg_, lfla, _غربت_,
  { {0x395a0006, 0x3cee0009, 0xa922000c, 0x00000000}},  // [bec0] _taps_, _ygfv_, _óþol,
  { {0x6d4121ba, 0xb5fb370e, 0x6604023a, 0x00000000}},  //   nfla, _trán, rpik,
  { {0x291800d6, 0x660423d6, 0x382a0ae0, 0x00000000}},  //   mara_, spik, _южно_,
  { {0x291801f6, 0x69ce0039, 0xb5fb01c8, 0x00000000}},  //   lara_, llbe, _král,
  { {0x27e0021e, 0x2fcd0c31, 0x29181b90, 0x00000000}},  //   mmin_, dleg_, oara_,
  { {0x2918037e, 0xf503007c, 0x4a9b01ce, 0x00000000}},  //   nara_, _взро, וינג,
  { {0x656e0033, 0xf04400a1, 0x6e290197, 0x00000000}},  //   _inbh, اعتی, ereb,
  { {0x29180127, 0x27e0370f, 0x2fcd3710, 0x00000000}},  //   hara_, nmin_, gleg_,
  { {0x2918011f, 0x6e290209, 0x6d4100f8, 0x00000000}},  //   kara_, greb, ffla,
  { {0x29180211, 0x27e0014a, 0x6d413711, 0x00000000}},  //   jara_, hmin_, gfla,
  { {0x291804cb, 0x6fc5027b, 0x27e0008a, 0x00000000}},  //   dara_, rócr, kmin_,
  { {0x2913027b, 0xdb0601aa, 0x69ce01a2, 0x00000000}},  //   _sexa_, nikè, elbe,
  { {0x27e0002b, 0x291806ab, 0x6fc50325, 0x00000000}},  //   dmin_, fara_, pócr,
  { {0x2918020c, 0x7dc6000c, 0x6d410146, 0x00000000}},  //   gara_, rðss, cfla,
  { {0x28f80077, 0xc3130044, 0x62993712, 0x00000000}},  //   тесь_, _হাসি_, zzwo,
  { {0xe4e3013d, 0x00000000, 0x00000000, 0x00000000}},  //   _कृषि_,   ,   ,
  { {0x2918000b, 0x6ff1001e, 0xdb1d0010, 0x00000000}},  // [bed0] bara_, _vāci, nosí,
  { {0x29183713, 0x27e00058, 0x6609014a, 0x00000000}},  //   cara_, amin_, _çekm,
  { {0x80a2001c, 0x27e000f6, 0x2fcd005b, 0x00000000}},  //   _केले, bmin_, yleg_,
  { {0x9f81000c, 0x27eb00f6, 0x92390131, 0x00000000}},  //   jóð_, _uicn_, ечку_,
  { {0x6d410016, 0x13080088, 0x2fcd3714, 0x00000000}},  //   yfla, тній_, vleg_,
  { {0x6e290207, 0xdb060065, 0x237f01aa, 0x00000000}},  //   vreb, tikë, _wouj_,
  { {0x2fcd2c77, 0x3495003b, 0x14c70014, 0x00000000}},  //   tleg_, _савр, _شهری_,
  { {0x291828d3, 0xdb060065, 0x236d0022, 0x00000000}},  //   zara_, rikë, _unej_,
  { {0x2fcd1dc6, 0x6d41152f, 0xab5b010f, 0x00000000}},  //   rleg_, tfla, hlüs,
  { {0x27e03715, 0x6e2926d8, 0xdb0d000c, 0x00000000}},  //   zmin_, rreb, _skað,
  { {0x291807ea, 0x6d4101e3, 0x27e01544, 0x00000000}},  //   vara_, rfla, ymin_,
  { {0x29180518, 0x6e290c06, 0x60c40095, 0x00000000}},  //   wara_, preb, şimc,
  { {0x2918020c, 0x2905005d, 0x6d4101a2, 0x00000000}},  //   tara_, ılan_, pfla,
  { {0xab5b01a2, 0xed5600d7, 0x00000000, 0x00000000}},  //   flüs, _бош_,   ,
  { {0x29183716, 0xf99f0263, 0xb5fb3717, 0x00000000}},  //   rara_, nsèy_, _drám,
  { {0x291801a3, 0x7c3c0129, 0x3f8d0093, 0x00000000}},  //   sara_, àrre, nkeu_,
  { {0xb5fb0051, 0x00000000, 0x00000000, 0x00000000}},  // [bee0] _frám,   ,   ,
  { {0x7bc600b0, 0x1a9b007b, 0x7e640c76, 0x00000000}},  //   loku, _נייע, _šipk,
  { {0xef190046, 0x0d160049, 0x07a60077, 0x00000000}},  //   każ_, רקעט_, _банн,
  { {0x44260b8e, 0x4ad80061, 0xef190036, 0x00000000}},  //   čo_, _ठराव, jaż_,
  { {0xef190036, 0x69650123, 0xdb060173, 0x00000000}},  //   daż_, _صدیق, rikè,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7bc61c86, 0x853b00b3, 0xdcf80089, 0x00000000}},  //   koku, _רגלי, _novā,
  { {0x083b0049, 0x2d8300b0, 0x7bc601ed, 0x00000000}},  //   געקל, öjen_, joku,
  { {0x7bc6006c, 0x0136023c, 0xdb160173, 0x00000000}},  //   doku, _معاد, _ijyè,
  { {0xdd900025, 0xc8850279, 0x5c061cf4, 0x00000000}},  //   زوج_, _yaşı_, ляма,
  { {0x7bc60007, 0x00000000, 0x00000000, 0x00000000}},  //   foku,   ,   ,
  { {0x7bc63718, 0x3f8d00f6, 0x00000000, 0x00000000}},  //   goku, ckeu_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afd0f02, 0x00000000, 0x00000000, 0x00000000}},  //   scst,   ,   ,
  { {0x7bc6006b, 0x3a200087, 0x3cfb009b, 0x00000000}},  //   boku, _evip_, _אלונ,
  { {0x7d1a225c, 0x291e000c, 0x00000000, 0x00000000}},  //   lats, ótar_,   ,
  { {0xb5fb049a, 0x00000000, 0x00000000, 0x00000000}},  // [bef0] _trám,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c70052, 0xd5b802ea, 0x545502dc, 0x00000000}},  //   moje, уст_, рвет,
  { {0x69c71011, 0xfaff008d, 0x7d1a014a, 0x00000000}},  //   loje, ncë_, hats,
  { {0x7d1a03b6, 0x00000000, 0x00000000, 0x00000000}},  //   kats,   ,   ,
  { {0x69c700b0, 0xef190036, 0x7bc60020, 0x00000000}},  //   noje, waż_, zoku,
  { {0x7bc60020, 0x2b490129, 0x7d1a0232, 0x00000000}},  //   yoku, _obac_, dats,
  { {0x82f80054, 0x44330066, 0xd3460014, 0x00000000}},  //   _مركز_, mux_, _نیمه_,
  { {0x69c73719, 0x44330142, 0x39940039, 0x00000000}},  //   koje, lux_, _läsa_,
  { {0x63ab218c, 0x1c4502f0, 0x2007000c, 0x00000000}},  //   lign, аном, ppni_,
  { {0x2a690169, 0x5f74007a, 0xeb9a0088, 0x00000000}},  //   _arab_, _گالر, вин_,
  { {0x63ab03d2, 0x00000000, 0x00000000, 0x00000000}},  //   nign,   ,   ,
  { {0x61ee014a, 0x7bc60213, 0x6f1b06ed, 0x00000000}},  //   _ünlü, roku, mauc,
  { {0x69c70087, 0x2a690190, 0xf1b20049, 0x00000000}},  //   goje, _drab_, ַסן_,
  { {0xdca20069, 0x7bc6000b, 0xa3d5007d, 0x00000000}},  //   _маши, poku, हता_,
  { {0x4433002b, 0xcc3a007b, 0x00000000, 0x00000000}},  //   dux_, _סעפט,   ,
  { {0x443300f4, 0x69c700ca, 0x63ab18a7, 0x00000000}},  // [bf00] eux_, boje, dign,
  { {0x75d30076, 0x4433002b, 0x69c7004a, 0x00000000}},  //   قيقا, fux_, coje,
  { {0x7afb24f2, 0x224d0145, 0xdb040010, 0x00000000}},  //   žute, _apek_, _amié,
  { {0x232a371a, 0x05160044, 0x626600ed, 0x00000000}},  //   тоди_, ালের_, ивеа,
  { {0x4433028c, 0x3f82000c, 0x2005000c, 0x00000000}},  //   aux_, ökum_, _atli_,
  { {0xa507003b, 0x44330066, 0x6b96018e, 0x00000000}},  //   _вера_, bux_, _llyg,
  { {0x7d1a0209, 0x6b960016, 0x63ab009d, 0x00000000}},  //   vats, _olyg, bign,
  { {0x628b0016, 0x63ab3608, 0x6f1b0dfc, 0x00000000}},  //   bygo, cign, gauc,
  { {0xb355026c, 0x644e0009, 0x7d1a006c, 0x00000000}},  //   _دینا_, _hpbi, tats,
  { {0xddc20046, 0x71ea035b, 0xeb880049, 0x00000000}},  //   _społ, _شفاف_, _אָ_,
  { {0x7d1a168e, 0x1b19007c, 0x69c70091, 0x00000000}},  //   rats, лжны_, voje,
  { {0x7d1a225c, 0x6f1b0efe, 0x6b840051, 0x00000000}},  //   sats, cauc, _coig,
  { {0x69c700b0, 0x6b8400f4, 0x37cc0044, 0x00000000}},  //   toje, _doig, লগার,
  { {0x6609014a, 0xdb0f00c4, 0x644e00d9, 0x00000000}},  //   _çeki, tocó, _opbi,
  { {0x628b0046, 0x6b9605cc, 0xf7730076, 0x00000000}},  //   zygo, _flyg, يار_,
  { {0x2a69002b, 0x69c72001, 0x8aa7007c, 0x00000000}},  //   _trab_, soje, _врод,
  { {0xa935371b, 0x69c70161, 0x7bcd371c, 0x00000000}},  // [bf10] _лепш, poje, _ikau,
  { {0x44330066, 0x5574371d, 0x7d180087, 0x00000000}},  //   tux_, огут, _jevs,
  { {0x63ab2d54, 0x6b84008e, 0xf48700ed, 0x00000000}},  //   tign, _yoig, јузн,
  { {0x44330066, 0x00000000, 0x00000000, 0x00000000}},  //   rux_,   ,   ,
  { {0xd6db317a, 0x63ab117e, 0x44330066, 0x00000000}},  //   _што_, rign, sux_,
  { {0x63ab0038, 0x628b0036, 0x798500ea, 0x00000000}},  //   sign, rygo, _johw,
  { {0x04950054, 0x63ab0026, 0xa2b30204, 0x00000000}},  //   _الأح, pign, _अशक्,
  { {0x53340256, 0x28b800b6, 0x636800da, 0x00000000}},  //   _мест, יפוש_, _круг_,
  { {0x63a900ee, 0x6f1b125c, 0x22940088, 0x00000000}},  //   _imen, rauc, _дитя,
  { {0x7bcd0518, 0x6f1b0089, 0x6b8400f4, 0x00000000}},  //   _akau, sauc, _soig,
  { {0x30a701fb, 0x6b840c81, 0x44210089, 0x00000000}},  //   _трав, _poig, nsh_,
  { {0x69de008d, 0x63a900b9, 0xf98900a3, 0x00000000}},  //   _shpe, _jmen, _אר_,
  { {0xeab2026c, 0x6b840302, 0xdef8008b, 0x00000000}},  //   سٹس_, _voig, _тых_,
  { {0x63a9088f, 0x63bb0039, 0x44210ede, 0x00000000}},  //   _lmen, _ljun, ksh_,
  { {0xb9000183, 0x63a90144, 0x765d00f8, 0x00000000}},  //   _तर_, _omen, _assy,
  { {0x07a3022a, 0x63bb00ca, 0xc7a308d6, 0x00000000}},  //   пасн, _njun, писк,
  { {0x44212154, 0x75d60076, 0x00000000, 0x00000000}},  // [bf20] esh_, ميرا,   ,
  { {0x63bb0d8a, 0x63a9371e, 0x44210065, 0x00000000}},  //   _ajun, _amen, fsh_,
  { {0x63a904e6, 0x291a371f, 0x00000000, 0x00000000}},  //   _bmen, _iepa_,   ,
  { {0x63a92b3c, 0xe29a03f6, 0x291a0253, 0x00000000}},  //   _cmen, лае_, _hepa_,
  { {0x232700e3, 0x291a0032, 0x63bb00f8, 0x00000000}},  //   сочи_, _kepa_, _djun,
  { {0x63a93720, 0x55e3007c, 0xf5960025, 0x00000000}},  //   _emen, _нояб, _السج,
  { {0x6e222086, 0xe04a0014, 0x7d180190, 0x00000000}},  //   _svob, اشته_, _revs,
  { {0xb5fb0051, 0x291a0059, 0x6f190016, 0x00000000}},  //   _srái, _lepa_, _cewc,
  { {0x7644163c, 0xa3d5013d, 0x877b00a3, 0x00000000}},  //   ntiy, हतर_, ראפי,
  { {0x7bcd0006, 0x63a90027, 0x444429e7, 0x00000000}},  //   _skau, _zmen, ot_,
  { {0xe6d5007d, 0x6cd40439, 0x6aa60044, 0x00000000}},  //   _दर्ज, تقدا, _গুলো,
  { {0x44443721, 0x6f190016, 0x63a90288, 0x00000000}},  //   it_, _gewc, _xmen,
  { {0x44443722, 0x2aab003b, 0xb5fb16b8, 0x00000000}},  //   ht_, утно_, _trái,
  { {0x398f006c, 0x44210023, 0x00000000, 0x00000000}},  //   _küsi_, ysh_,   ,
  { {0x444432fc, 0x6f0d001a, 0xbc670014, 0x00000000}},  //   jt_, _încâ, _همون_,
  { {0x44441440, 0x6d4801d6, 0x06150077, 0x00000000}},  //   dt_, lfda, ждаю,
  { {0x44440e23, 0xaa5902d3, 0x76440058, 0x00000000}},  // [bf30] et_, _типу_, gtiy,
  { {0x44440f12, 0x63a9003b, 0x63bb0039, 0x00000000}},  //   ft_, _smen, _sjun,
  { {0x44440cb2, 0x490f013d, 0x4421060f, 0x00000000}},  //   gt_, _त्यो_, ush_,
  { {0x69d5010f, 0x7dcf068f, 0x291a00f6, 0x00000000}},  //   llze, løst, _zepa_,
  { {0x60c401df, 0x44210023, 0x442301c3, 0x00000000}},  //   şiml, ssh_, _wvj_,
  { {0x660d01a3, 0x29030036, 0x444403a1, 0x00000000}},  //   mpak, ncja_, bt_,
  { {0x44440f44, 0x93e90025, 0x63bb016c, 0x00000000}},  //   ct_, _نفسك_, _tjun,
  { {0xdfd10025, 0x63a90027, 0x63bb0169, 0x00000000}},  //   بيع_, _umen, _ujun,
  { {0x29030046, 0x660d00bb, 0x6d480c3f, 0x00000000}},  //   kcja_, npak, ffda,
  { {0xb5fb01e5, 0xb65c0049, 0x00000000, 0x00000000}},  //   _fráv, רדזש,   ,
  { {0x64450181, 0x7e640e00, 0xb5fb00c4, 0x00000000}},  //   nthi, _šipt, _gráv,
  { {0x61fb3723, 0x64451b88, 0x291a008e, 0x00000000}},  //   _kuul, ithi, _sepa_,
  { {0x61fb0004, 0x44440010, 0xb69b001a, 0x00000000}},  //   _juul, zt_, _sfân,
  { {0x61fb044e, 0x44443724, 0x64450065, 0x00000000}},  //   _muul, yt_, kthi,
  { {0x61fb003c, 0x44440866, 0x6fea0036, 0x00000000}},  //   _luul, xt_, _ręcz,
  { {0x444405fe, 0x29030036, 0xd70a007e, 0x00000000}},  //   vt_, acja_, рнае_,
  { {0x44443725, 0x2d873726, 0x660d011c, 0x00000000}},  // [bf40] wt_, _kone_, gpak,
  { {0x44443727, 0x764402b9, 0x2d870065, 0x00000000}},  //   tt_, rtiy, _jone_,
  { {0x44440a8a, 0x76440b78, 0x644500ea, 0x00000000}},  //   ut_, stiy, gthi,
  { {0x39580018, 0x2a600066, 0x76441c39, 0x00000000}},  //   lers_, _ksib_, ptiy,
  { {0x4444061f, 0x644527a4, 0x2a60002b, 0x00000000}},  //   st_, athi, _jsib_,
  { {0x44443728, 0xb5fb0428, 0x2d870866, 0x00000000}},  //   pt_, _práv, _none_,
  { {0xcf9a012b, 0x444401d5, 0x39583729, 0x00000000}},  //   ији_, qt_, iers_,
  { {0x39580038, 0x2d87327e, 0x00000000, 0x00000000}},  //   hers_, _aone_,   ,
  { {0x395813e2, 0x6609014a, 0x2d8700ab, 0x00000000}},  //   kers_, _çekt, _bone_,
  { {0x2d980036, 0x395801d5, 0x2b4006c0, 0x00000000}},  //   óre_, jers_, _acic_,
  { {0x39580f12, 0x2d8700ab, 0xe4fb0049, 0x00000000}},  //   ders_, _done_, יפיש,
  { {0x2366008d, 0xddc2001e, 0xb5fb0161, 0x00000000}},  //   ndoj_, _droš, _krát,
  { {0x395800ab, 0x2d870181, 0x6fc70061, 0x00000000}},  //   fers_, _fone_, ावरू,
  { {0x644500ab, 0x2d872f94, 0x60cd0c4f, 0x00000000}},  //   ythi, _gone_, şame,
  { {0xd7fb007c, 0xddc200ca, 0x6ca3005e, 0x00000000}},  //   руг_, _groš, _оръж,
  { {0x2246011c, 0x660d00bb, 0x7ddd01aa, 0x00000000}},  //   ktok_, tpak, mèsa,
  { {0x2b59000d, 0x3958192b, 0x29030036, 0x00000000}},  // [bf50] mesc_, bers_, pcja_,
  { {0x660d0281, 0x6445010f, 0x2b59001a, 0x00000000}},  //   rpak, tthi, lesc_,
  { {0x43750a94, 0x64450082, 0xe9df008e, 0x00000000}},  //   зулт, uthi, ctúa_,
  { {0x6445018e, 0x2b59001a, 0x660d00b0, 0x00000000}},  //   rthi, nesc_, ppak,
  { {0x27e9171a, 0xd25b0887, 0xdb06372a, 0x00000000}},  //   mman_, рце_, niká,
  { {0x27e9372b, 0x6b9d0065, 0xb5fb372c, 0x00000000}},  //   lman_, ërgj, _drát,
  { {0x76590477, 0x2d9e372d, 0x27e9337a, 0x00000000}},  //   şayı, dhte_, oman_,
  { {0x27e92900, 0x395800b5, 0x61fb003c, 0x00000000}},  //   nman_, zers_, _tuul,
  { {0x28d202d2, 0xb5fb02d5, 0x2d87372e, 0x00000000}},  //   _दुनि, _grát, _pone_,
  { {0xddc206a6, 0x27e901a3, 0x2d9e0051, 0x00000000}},  //   _proš, hman_, ghte_,
  { {0x1b200055, 0x3958032c, 0x27e9134e, 0x00000000}},  //   _ভাবে_, vers_, kman_,
  { {0x27e90263, 0x39580b8d, 0xdb0629c5, 0x00000000}},  //   jman_, wers_, fiká,
  { {0x27e90b3d, 0x2d9e0051, 0x00000000, 0x00000000}},  //   dman_, bhte_,   ,
  { {0x2d9e1626, 0xdca50242, 0xddc20466, 0x00000000}},  //   chte_, _нали, _troš,
  { {0x22460a50, 0x2b59001a, 0x7d7a009b, 0x00000000}},  //   ztok_, besc_, _לנסו,
  { {0x39582a7d, 0x2fcd0100, 0xab9a007a, 0x00000000}},  //   sers_, noeg_, _دختر_,
  { {0x395800ab, 0x41cb0309, 0x00000000, 0x00000000}},  // [bf60] pers_, िवास,   ,
  { {0xfaff0065, 0x27e90358, 0x00000000, 0x00000000}},  //   ndën_, aman_,   ,
  { {0x27e9005b, 0xdb0f00f6, 0x67ce007f, 0x00000000}},  //   bman_, ficè, tėję,
  { {0xb5fb0181, 0x27e901ee, 0x22462d0f, 0x00000000}},  //   _prát, cman_, ttok_,
  { {0xb5fb372f, 0x00000000, 0x00000000, 0x00000000}},  //   _drás,   ,   ,
  { {0x4736007a, 0x69ce0039, 0xb5fb06b8, 0x00000000}},  //   _برگز, nobe, _vrát,
  { {0x34a7358a, 0x224605fd, 0xb5fb3730, 0x00000000}},  //   _евро_, stok_, _frás,
  { {0x443a0061, 0xb5fb3731, 0x69ce010f, 0x00000000}},  //   mup_, _trát, hobe,
  { {0x443a3732, 0xed580027, 0x2b59001a, 0x00000000}},  //   lup_, teľ_, vesc_,
  { {0x27e901aa, 0x291e000c, 0x4c940a85, 0x00000000}},  //   zman_, ðtal_, диос,
  { {0x27e90f99, 0x2b59001a, 0x443a0095, 0x00000000}},  //   yman_, tesc_, nup_,
  { {0x2d9e008d, 0xdb060a50, 0xbe4a0014, 0x00000000}},  //   shte_, tiká, _هشتم_,
  { {0x27e90263, 0x2b59000d, 0x69ce00bb, 0x00000000}},  //   vman_, resc_, fobe,
  { {0x2b59001a, 0x23de013d, 0x69ce29d8, 0x00000000}},  //   sesc_, _फीसद, gobe,
  { {0x6d5a20b9, 0xa3be006e, 0x27e9060b, 0x00000000}},  //   meta, ीका_, tman_,
  { {0x1cbb00b6, 0x443a020c, 0x27e901a3, 0x00000000}},  //   _למוע, dup_, uman_,
  { {0xd6db0373, 0xddc200b9, 0x9f4c0027, 0x00000000}},  // [bf70] ств_, _spoř, _budú_,
  { {0x6d5a0756, 0x27e90263, 0x7bcf001a, 0x00000000}},  //   neta, sman_, locu,
  { {0x44270219, 0x27e90263, 0x443a01a3, 0x00000000}},  //   én_, pman_, gup_,
  { {0x6d5a006c, 0x245e00b9, 0x316501a2, 0x00000000}},  //   heta, _dům_, _salz_,
  { {0x6d5a022b, 0x2fcd0343, 0xa29403e8, 0x00000000}},  //   keta, voeg_, наці,
  { {0x2d8a050d, 0x443a0093, 0x7c3a059f, 0x00000000}},  //   öbel_, bup_, kutr,
  { {0x6d5a006c, 0x950800a1, 0x00000000, 0x00000000}},  //   deta, _رہنے_,   ,
  { {0x389c00a3, 0x69ce2061, 0x7c3a141a, 0x00000000}},  //   מיונ, zobe, dutr,
  { {0x200c005f, 0x7bcf00bb, 0x7e620047, 0x00000000}},  //   _etdi_, docu, _csop,
  { {0x6d5a0585, 0xa3a90164, 0x200c0544, 0x00000000}},  //   geta, गोर_, _ftdi_,
  { {0x7bcf15e0, 0x65670059, 0x69ce01ee, 0x00000000}},  //   focu, _majh, vobe,
  { {0x2d9c3733, 0xeb9701ab, 0x00000000, 0x00000000}},  //   _elve_, дию_,   ,
  { {0x6d5a05ad, 0x65a0010f, 0xdce3002b, 0x00000000}},  //   beta, _höhe, _kanċ,
  { {0x9f5e0f3c, 0x6d5a0211, 0x64553734, 0x00000000}},  //   _että_, ceta, _opzi,
  { {0x69ce3735, 0x65a00010, 0x18671867, 0x00000000}},  //   robe, _jöhe, мари_,
  { {0xe61a1ef9, 0x69ce01ca, 0x7bcf3736, 0x00000000}},  //   жда_, sobe, cocu,
  { {0x60c4011f, 0x645508ad, 0x69ce144f, 0x00000000}},  // [bf80] ğimi, _apzi, pobe,
  { {0x60c4005a, 0x65670087, 0xca37009b, 0x00000000}},  //   şimi, _cajh, _קניה_,
  { {0x6d4302f1, 0x00000000, 0x00000000, 0x00000000}},  //   _mcna,   ,   ,
  { {0x443a0018, 0x6d5a2828, 0x7dd400f6, 0x00000000}},  //   rup_, zeta, làst,
  { {0x6d5a23d3, 0x925a031d, 0xd2501095, 0x00000000}},  //   yeta, تشار_, انت_,
  { {0x443a0061, 0x6d5a002d, 0xdce301f3, 0x00000000}},  //   pup_, xeta, _canċ,
  { {0x6d5a04bd, 0xa3d9007d, 0x61ea04f2, 0x00000000}},  //   veta, _ठीक_, rmfl,
  { {0x6d5a002b, 0x88c00044, 0x6629000c, 0x00000000}},  //   weta, _ইরাক, _óskö,
  { {0xb1460264, 0x3df400ed, 0x63a22c4f, 0x00000000}},  //   _онал, нзис, mhon,
  { {0x60cd005d, 0xf99f01aa, 0xaad2013d, 0x00000000}},  //   şama, npèt_, _सड़क,
  { {0x6d5a02e1, 0x7bcf009d, 0x67243287, 0x00000000}},  //   reta, tocu, kaij,
  { {0x69c0028c, 0x6d5a0091, 0x442a3737, 0x00000000}},  //   émen, seta, _mvb_,
  { {0x6d5a0004, 0x7bcf0035, 0x7e620146, 0x00000000}},  //   peta, rocu, _usop,
  { {0x7bcf06c0, 0x7c3a04be, 0x6d430048, 0x00000000}},  //   socu, putr, _gcna,
  { {0x4bdb0025, 0x656701ee, 0x9848005e, 0x00000000}},  //   _وبعد_, _rajh, мята_,
  { {0x1b190055, 0xab5b014a, 0x7c2800f8, 0x00000000}},  //   _থাকে_, ylüy, msdr,
  { {0x1515007e, 0x7c281b0d, 0x63a20023, 0x00000000}},  // [bf90] едзя, lsdr, dhon,
  { {0x442a0de1, 0xab5b006b, 0x9f5e0023, 0x00000000}},  //   _bvb_, vlüy, _butë_,
  { {0x7c2801c5, 0x7bc8009d, 0x63a201c3, 0x00000000}},  //   nsdr, éjug, fhon,
  { {0xa3a903d7, 0xd6d0026c, 0xa5f93738, 0x00000000}},  //   गों_, اقے_, _нему_,
  { {0xdcf800b9, 0x7d0a00ab, 0x442a0296, 0x00000000}},  //   _pově, _offs, _evb_,
  { {0xe0450174, 0x00000000, 0x00000000, 0x00000000}},  //   енки,   ,   ,
  { {0x442a00bb, 0x00000000, 0x00000000, 0x00000000}},  //   _gvb_,   ,   ,
  { {0x63a23739, 0x0e6501fc, 0xdbd70103, 0x00000000}},  //   chon, екин, _jääh,
  { {0xa3cc007d, 0xa3be01f5, 0x7c2801c3, 0x00000000}},  //   रकर_, ीकर_, esdr,
  { {0x4c85013b, 0xac850959, 0x3f82000c, 0x00000000}},  //   елов, егол, ökur_,
  { {0xe572007b, 0x3f150057, 0x8014008b, 0x00000000}},  //   אַר_, _здес, _афіц,
  { {0xfe7106c6, 0x27f9023a, 0x4c820088, 0x00000000}},  //   _مدت_, _nisn_, улюв,
  { {0xc3320104, 0x998400b9, 0xdd95007e, 0x00000000}},  //   נוך_, émů_, _пады,
  { {0xc212012f, 0x63a225c3, 0x00000000, 0x00000000}},  //   רהם_, zhon,   ,
  { {0xeb9a007c, 0x6e2902e7, 0x9f5e0173, 0x00000000}},  //   _ник_, lseb, _butè_,
  { {0x6d41006c, 0x6f0901a3, 0x1ae6007c, 0x00000000}},  //   lgla, ncec, _пойм,
  { {0x290501f6, 0xdce301ee, 0x6e291a3d, 0x00000000}},  // [bfa0] ılar_, _manč, nseb,
  { {0xdce30209, 0x65a0005f, 0x442a00d9, 0x00000000}},  //   _lanč, _söhb, _pvb_,
  { {0x63a20e69, 0x6fcf0061, 0x6d4117b4, 0x00000000}},  //   thon, हकां, igla,
  { {0x69dc0061, 0x24860091, 0x8c1a009b, 0x00000000}},  //   llre, ćom_, פוני,
  { {0xe297003b, 0x45240044, 0x63a200b0, 0x00000000}},  //   нац_, _পাঠক_, rhon,
  { {0x63a2373a, 0x442a0082, 0x6e290059, 0x00000000}},  //   shon, _tvb_, dseb,
  { {0x63a2028c, 0xdce30059, 0xb88200b9, 0x00000000}},  //   phon, _banč, _říjn,
  { {0x69dc010f, 0xdd250006, 0xa857009b, 0x00000000}},  //   hlre, _rūši, תיקה_,
  { {0x7ae40020, 0x67c50006, 0xd3450014, 0x00000000}},  //   _nzit, nėja, _شیوه_,
  { {0x7bc40020, 0x7c28373b, 0x6d4100f8, 0x00000000}},  //   _ajiu, tsdr, ggla,
  { {0xdcba005e, 0xaf1f0044, 0x0ee20061, 0x00000000}},  //   ящи_, _ধারণ_, _परवड,
  { {0x67c50006, 0x2918008e, 0xdce30087, 0x00000000}},  //   kėja, ebra_, _ganč,
  { {0xdfcf0014, 0x4e930084, 0x61fa014a, 0x00000000}},  //   _اين_, _مشور, _kitl,
  { {0x67c50006, 0xdb0f0181, 0x61fa002b, 0x00000000}},  //   dėja, micí, _jitl,
  { {0x61fa0bdf, 0xdb0f0211, 0x7ae41cff, 0x00000000}},  //   _mitl, licí, _ezit,
  { {0x61fa0635, 0x657c0016, 0x69dc0009, 0x00000000}},  //   _litl, _anrh, alre,
  { {0xdb0f2d7d, 0x2918373c, 0x391501fc, 0x00000000}},  // [bfb0] nicí, bbra_, _импр,
  { {0x27f90022, 0x7bdd01a2, 0x69dc0009, 0x00000000}},  //   _wisn_, llsu, clre,
  { {0xe3be005d, 0xc952009b, 0xdce3002b, 0x00000000}},  //   ğına_, _דמי_, _konġ,
  { {0x04c80054, 0xe3be01f6, 0x6d4100ee, 0x00000000}},  //   روني_, şına_, zgla,
  { {0x2169013b, 0x6d410016, 0x61fa373d, 0x00000000}},  //   дили_, ygla, _bitl,
  { {0x23690e00, 0xd83801d9, 0x657c0022, 0x00000000}},  //   žaj_, šče_, _gnrh,
  { {0xa0660265, 0xdce30b30, 0x6e290009, 0x00000000}},  //   ваща_, _panč, wseb,
  { {0x39940039, 0x61fa0051, 0x6e291db4, 0x00000000}},  //   _häst_, _eitl, tseb,
  { {0x764d0176, 0x6f090093, 0x6d4100f8, 0x00000000}},  //   ntay, rcec, tgla,
  { {0x30a7012b, 0x6e290149, 0xfe420088, 0x00000000}},  //   _прев, rseb, шньо,
  { {0x6e290010, 0xdce3013e, 0x21272e7e, 0x00000000}},  //   sseb, _tanč, manh_,
  { {0x09da001c, 0x39940039, 0x6d41005b, 0x00000000}},  //   णत्य, _läst_, sgla,
  { {0x68e5016c, 0xdb0f0adb, 0x8d651ac0, 0x00000000}},  //   _azhd, ficâ, _авле,
  { {0x21270082, 0x67c50006, 0x7bdd006c, 0x00000000}},  //   nanh_, vėja, alsu,
  { {0x3f8f0004, 0x2918277c, 0x69dc01e5, 0x00000000}},  //   _kogu_, rbra_, rlre,
  { {0x21270011, 0x7ae4012d, 0x67c50006, 0x00000000}},  //   hanh_, _tzit, tėja,
  { {0x3f8f0091, 0x39940039, 0x7ae40020, 0x00000000}},  // [bfc0] _mogu_, _bäst_, _uzit,
  { {0x67c50006, 0x3f8f0089, 0x00000000, 0x00000000}},  //   rėja, _logu_,   ,
  { {0x499b0104, 0x03260088, 0x764d0020, 0x00000000}},  //   _חשיב, вден, atay,
  { {0x78a302b9, 0x3f8f0091, 0x61ca006e, 0x00000000}},  //   _ünva, _nogu_, ाक्ष,
  { {0x4254006d, 0x15ba007e, 0x60cd01df, 0x00000000}},  //   انتر, _жывы_, şaml,
  { {0x657c018e, 0x7f95029d, 0x39940039, 0x00000000}},  //   _unrh, _máqu, _gäst_,
  { {0x93460517, 0x61fa000c, 0x3f8f0091, 0x00000000}},  //   _инве, _vitl, _bogu_,
  { {0x61fa046a, 0x2d8e1ce1, 0xdb0f373e, 0x00000000}},  //   _witl, _sofe_, ticí,
  { {0x61fa0365, 0xc7b301f8, 0x3f8f002d, 0x00000000}},  //   _titl, יבה_, _dogu_,
  { {0x61fa01b5, 0x2ca900b9, 0x21270082, 0x00000000}},  //   _uitl, _řada_, canh_,
  { {0x853b0104, 0x00000000, 0x00000000, 0x00000000}},  //   וגיי,   ,   ,
  { {0x3f8f0035, 0x443a0048, 0xc4d3009b, 0x00000000}},  //   _gogu_, irp_, יגת_,
  { {0xa5bb000c, 0xee940014, 0x00000000, 0x00000000}},  //   _kvót, _حداک,   ,
  { {0xdd93007e, 0x3f8f0065, 0xdee30364, 0x00000000}},  //   _вашы, _zogu_, _точи,
  { {0x316c0007, 0x60e6013e, 0x3a390045, 0x00000000}},  //   _madz_, _úsmě, srsp_,
  { {0x764d0048, 0xddd9000a, 0xe894007e, 0x00000000}},  //   ttay, _apwň, шась,
  { {0x8bb4004b, 0xeb1f006e, 0x00000000, 0x00000000}},  // [bfd0] _خصوص, परीत_,   ,
  { {0x6b9d0546, 0x21270082, 0x9f9a006c, 0x00000000}},  //   lksg, xanh_, _hääl_,
  { {0xf99200b3, 0xdce30089, 0x69d50142, 0x00000000}},  //   _הרי_, _kanā, moze,
  { {0x69d5041a, 0x317e0032, 0x6b9d0133, 0x00000000}},  //   loze, _antz_, nksg,
  { {0xdb1d373f, 0xf9900123, 0x6b9d0328, 0x00000000}},  //   losó, _طبی_, iksg,
  { {0x644a0129, 0xa5bb0036, 0x69d50692, 0x00000000}},  //   àfic, _dwóc, noze,
  { {0x65a0006b, 0xf3670081, 0x27eb0082, 0x00000000}},  //   _köhn, _итан, _khcn_,
  { {0x69d50062, 0x4394007c, 0x6d5c006c, 0x00000000}},  //   hoze, _касс, õran,
  { {0x69d500b5, 0x00000000, 0x00000000, 0x00000000}},  //   koze,   ,   ,
  { {0x9f4c00f6, 0x6b9d00bb, 0xc69200a0, 0x00000000}},  //   _budó_, eksg, צאי_,
  { {0x75eb005a, 0x62990462, 0x301501ab, 0x00000000}},  //   müzd, lywo, _сдер,
  { {0x29cd0027, 0x9f4c004a, 0xe4560049, 0x00000000}},  //   hľad_, _dudó_, נירט_,
  { {0x539a007b, 0x6f1b0181, 0xff04005e, 0x00000000}},  //   גירו, mbuc, _тяхн,
  { {0x6f1b027b, 0x186a0265, 0x2fdf01d5, 0x00000000}},  //   lbuc, наги_, llug_,
  { {0xc4be0044, 0x237f012d, 0x58950088, 0x00000000}},  //   _অর্জ, _onuj_, ашту,
  { {0x2005006a, 0x6f1b010f, 0x2be00061, 0x00000000}},  //   _muli_, nbuc, नतळा,
  { {0x6e3b00d9, 0xe57a004d, 0x69d50861, 0x00000000}},  // [bfe0] nrub, нза_, boze,
  { {0xc9663740, 0x629904d2, 0xab5b0010, 0x00000000}},  //   _свой, dywo, nnün,
  { {0x62990009, 0xdb0f00c4, 0xe3be005a, 0x00000000}},  //   eywo, licá, şıma_,
  { {0xa22a0ae0, 0x42ca00e2, 0x7c2e004a, 0x00000000}},  //   ежда_, нген_, ábri,
  { {0x27e03741, 0x75840014, 0xdb0f004a, 0x00000000}},  //   mlin_, _پیام, nicá,
  { {0x27e03327, 0xb42606b4, 0x20052c13, 0x00000000}},  //   llin_, _معرو, _buli_,
  { {0x660601c2, 0x27e00052, 0x20053742, 0x00000000}},  //   _hukk, olin_, _culi_,
  { {0x660603b6, 0x5f94026b, 0x63b90036, 0x00000000}},  //   _kukk, риит, ciwn,
  { {0x660600b0, 0xdd900025, 0x244e0161, 0x00000000}},  //   _jukk, قوة_, lým_,
  { {0x27e00039, 0xdce30089, 0x6606054f, 0x00000000}},  //   hlin_, _sanā, _mukk,
  { {0x244e004f, 0x6606068f, 0x69d5013e, 0x00000000}},  //   ným_, _lukk, voze,
  { {0x656e002a, 0x67260059, 0x6e3b1d56, 0x00000000}},  //   _labh, _nekj, brub,
  { {0x6b9d01d6, 0x69d5002d, 0x660600b0, 0x00000000}},  //   rksg, toze, _nukk,
  { {0xf2d3007b, 0x645c1de0, 0x244e0428, 0x00000000}},  //   מער_, _opri, kým_,
  { {0x69d507e4, 0xddc20059, 0x67260056, 0x00000000}},  //   roze, _krož, _bekj,
  { {0x66060d22, 0x7ddd01aa, 0x27e03743, 0x00000000}},  //   _bukk, vèsi, glin_,
  { {0xa9c70084, 0x656e0051, 0x2a69011c, 0x00000000}},  // [bff0] _مزدو, _babh, _usab_,
  { {0x656e002a, 0x2d9e03a9, 0xd83801d9, 0x00000000}},  //   _cabh, nkte_, šča_,
  { {0x27e00036, 0x6d4a01c3, 0x2d9e00c1, 0x00000000}},  //   blin_, _mcfa, ikte_,
  { {0xb7670ae0, 0xae04006e, 0x656e0051, 0x00000000}},  //   _стой, रदान_, _eabh,
  { {0x92070089, 0x2fdf01d6, 0xc4cf00a1, 0x00000000}},  //   klāš, vlug_, _کےا_,
  { {0x6f02049a, 0x656e0051, 0xe29604cf, 0x00000000}},  //   _agoc, _gabh, раш_,
  { {0x10a504ef, 0xddc20062, 0x349516e8, 0x00000000}},  //   рийн, _brož, _тавр,
  { {0xe3b0002c, 0xa29501ff, 0xe3b300a6, 0x00000000}},  //   _فرق_, _кабі, _طرز_,
  { {0xdb06008d, 0x6f1b0c3f, 0xddc80064, 0x00000000}},  //   shkë, rbuc, _šošk,
  { {0x20050368, 0xdcf8001e, 0x6e3b00c4, 0x00000000}},  //   _tuli_, _novē, rrub,
  { {0xb17a0049, 0xa17a0049, 0x27e00052, 0x00000000}},  //   _שטער, _שטעט, ylin_,
  { {0xddc2010a, 0x765d224b, 0x2d9e00c7, 0x00000000}},  //   _grož, _opsy, akte_,
  { {0x7ff40151, 0x27e000ca, 0x6e220016, 0x00000000}},  //   _اسلا, vlin_, _gwob,
  { {0x2d9e0002, 0x66060007, 0x5e560049, 0x00000000}},  //   ckte_, _rukk, _כינע_,
  { {0xd706026b, 0x6606018d, 0x27e0010e, 0x00000000}},  //   изви, _sukk, tlin_,
  { {0x656e2423, 0x244e0428, 0x27e001f3, 0x00000000}},  //   _sabh, vým_, ulin_,

  { {0x27f232b3, 0x27e003a1, 0xb69b001a, 0x00000000}},  // [c000] rmyn_, rlin_, _sfâr,
  { {0x1a9b00a3, 0x645c1087, 0x27e0016e, 0x00000000}},  //   _סייע, _ppri, slin_,
  { {0x27e004cb, 0x6726000c, 0xf8ca0061, 0x00000000}},  //   plin_, _tekj, _रशिय,
  { {0xe29a008b, 0xa3b003d7, 0x244e01ca, 0x00000000}},  //   кае_, टों_, rým_,
  { {0x656e002a, 0x395a0161, 0x4431001a, 0x00000000}},  //   _tabh, _kbps_, _evz_,
  { {0xfe08001d, 0x76440020, 0x77640129, 0x00000000}},  //   _nữa_, muiy, leix,
  { {0x395a0082, 0xddc232e0, 0xdb0400b5, 0x00000000}},  //   _mbps_, _prož, _clië,
  { {0x44440be3, 0x6e220263, 0x776404bd, 0x00000000}},  //   mu_, _pwob, neix,
  { {0x4444021e, 0xfe080011, 0x6146003b, 0x00000000}},  //   lu_, _bữa_, _веза,
  { {0x3d160061, 0x00000000, 0x00000000, 0x00000000}},  //   पुढे_,   ,   ,
  { {0x2d9e046a, 0x8fa61023, 0xb5fb0161, 0x00000000}},  //   rkte_, _каже, _práz,
  { {0x9ffa0025, 0xa3cc006e, 0xddc90340, 0x00000000}},  //   _شراء_, रकट_, rveš,
  { {0x44440387, 0x77640129, 0x7e790016, 0x00000000}},  //   hu_, deix, _grwp,
  { {0x1cba0025, 0x6b5c0030, 0x65a001a2, 0x00000000}},  //   _لاعب_, _pågæ, _böhm,
  { {0x444404a9, 0x776400d4, 0x752717d8, 0x00000000}},  //   ju_, feix, _rejz,
  { {0xf7700025, 0x77640129, 0x3cfb009b, 0x00000000}},  //   واق_, geix, _בלונ,
  { {0x444402ad, 0x44230022, 0xe66701fc, 0x00000000}},  // [c010] eu_, _swj_, штво,
  { {0x4444000b, 0x44310006, 0x00000000, 0x00000000}},  //   fu_, _pvz_,   ,
  { {0x54551deb, 0x7ddd25b8, 0x776400d4, 0x00000000}},  //   свет, mèst, beix,
  { {0xdfc60379, 0x69c70059, 0x7ddd00d4, 0x00000000}},  //   _ري_, lnje, lèst,
  { {0x44440bc4, 0x672d01c5, 0xc244007e, 0x00000000}},  //   au_, maaj, жнік,
  { {0xdca60054, 0x672d021e, 0x00000000, 0x00000000}},  //   _فى_, laaj,   ,
  { {0x44440119, 0x3f9f00b0, 0xddc20036, 0x00000000}},  //   cu_, tkuu_, _droż,
  { {0xfe080011, 0x64450058, 0x69c7050f, 0x00000000}},  //   _sữa_, muhi, hnje,
  { {0x3ead0107, 0x64453744, 0xe7f801f5, 0x00000000}},  //   uzet_, luhi, ंगता_,
  { {0xcda9023c, 0x4c6900ed, 0x3ead0f5d, 0x00000000}},  //   اهده_, гион_, rzet_,
  { {0x69c7092f, 0x6445006a, 0xeb9a007c, 0x00000000}},  //   dnje, nuhi, гин_,
  { {0xe0d00151, 0x672d3745, 0x65651084, 0x00000000}},  //   _غزل_, jaaj, hehh,
  { {0x7bc63746, 0x00000000, 0x00000000, 0x00000000}},  //   rnku,   ,   ,
  { {0x69c70a0f, 0x6445191a, 0x44440357, 0x00000000}},  //   gnje, kuhi, yu_,
  { {0x776404bd, 0x68e90224, 0xe73a009a, 0x00000000}},  //   teix, ředn, лев_,
  { {0x81cd0055, 0x81bf0055, 0x6445011c, 0x00000000}},  //   রতি_, ীতি_, duhi,
  { {0x776404bd, 0x4444047a, 0xe4d0006b, 0x00000000}},  // [c020] reix, wu_, _küçə,
  { {0x44440756, 0x7644000a, 0x6b9604f3, 0x00000000}},  //   tu_, ruiy, _hoyg,
  { {0x6445011c, 0x7ae90089, 0xdb04009d, 0x00000000}},  //   guhi, ļete, _alié,
  { {0x7e690020, 0x672d012d, 0x78a1068f, 0x00000000}},  //   kwep, caaj, ølve,
  { {0x91e60794, 0x425631c9, 0x62340a85, 0x00000000}},  //   боде, стет, целу,
  { {0x44440209, 0xa97a0049, 0x65a0006b, 0x00000000}},  //   pu_, ראַכ, _möhk,
  { {0xfaff008d, 0x44440d82, 0x443e001d, 0x00000000}},  //   ndër_, qu_, _ít_,
  { {0x69c7016c, 0x987b0097, 0x00000000, 0x00000000}},  //   znje, ראקט,   ,
  { {0x62860059, 0xf773009b, 0x63a2006c, 0x00000000}},  //   _škof, לקה_, mkon,
  { {0x6b840068, 0x00000000, 0x00000000, 0x00000000}},  //   _anig,   ,   ,
  { {0x4c940256, 0xcb0403d7, 0xcf8f025f, 0x00000000}},  //   цинс, रखंड_, _еј_,
  { {0x63a23747, 0xd90f02fd, 0x69de0022, 0x00000000}},  //   nkon, کید_, _akpe,
  { {0xddc20089, 0x672d00b0, 0x6d340745, 0x00000000}},  //   _esoš, vaaj, _делф,
  { {0x6b843748, 0xfe370049, 0x67c50006, 0x00000000}},  //   _enig, _פרוי_, mėji,
  { {0x63a201d5, 0x97a70121, 0x29110036, 0x00000000}},  //   kkon, брал, rcza_,
  { {0x69c7016c, 0x8aa7008b, 0x68e900b9, 0x00000000}},  //   snje, _грод, ředo,
  { {0xdb0d014a, 0x67c50006, 0x69c73749, 0x00000000}},  // [c030] _amaç, nėji, pnje,
  { {0x7aed022b, 0x6445011c, 0xec090011, 0x00000000}},  //   _izat, tuhi, _mến_,
  { {0x93190025, 0x63a20190, 0x75eb006b, 0x00000000}},  //   لقاء_, fkon, güza,
  { {0x64451a91, 0x67c50006, 0x756500a1, 0x00000000}},  //   ruhi, kėji, _ڈیرہ_,
  { {0xe1f10014, 0x64450058, 0x7bcd016c, 0x00000000}},  //   وست_, suhi, _mjau,
  { {0x67c50006, 0x80150d51, 0x63a2010e, 0x00000000}},  //   dėji, офиц, akon,
  { {0x63a2003b, 0x299c009b, 0x00000000, 0x00000000}},  //   bkon, רסומ,   ,
  { {0xee39017a, 0x2d98374a, 0xec090011, 0x00000000}},  //   ани_, ören_, _bến_,
  { {0xa3e20061, 0x63a905fc, 0xe2930445, 0x00000000}},  //   _नीट_, _ilen, _عذر_,
  { {0x61e3001c, 0x313402e9, 0x00000000, 0x00000000}},  //   qlnl, _неур,   ,
  { {0x63a90161, 0x7e6901c3, 0xdce3012d, 0x00000000}},  //   _klen, swep, _manć,
  { {0xf98901f8, 0x22400521, 0x5e590ae0, 0x00000000}},  //   _בר_, šike_, _видя_,
  { {0x63bb1607, 0x7bcd0022, 0x63a900e7, 0x00000000}},  //   _mmun, _djau, _mlen,
  { {0x63a9374b, 0xdca50216, 0x63a20387, 0x00000000}},  //   _llen, _мали, zkon,
  { {0x929d0046, 0x63a9003c, 0x63bb374c, 0x00000000}},  //   _ogło, _olen, _omun,
  { {0x6b84018e, 0x9f460011, 0xec090011, 0x00000000}},  //   _unig, _khoá_, _yến_,
  { {0xe6170001, 0x79970ace, 0xf1a90316, 0x00000000}},  // [c040] жду_, _foxw, कसान,
  { {0x63a9068f, 0x63bb0129, 0xba9b009b, 0x00000000}},  //   _alen, _amun, _כספי,
  { {0x63a2006c, 0x546a328b, 0x23c501f5, 0x00000000}},  //   tkon, раем_, लचंद,
  { {0x69dc374d, 0x63a90253, 0x9f4c00c4, 0x00000000}},  //   lore, _clen, _judô_,
  { {0x63a2374e, 0x7f9c00d4, 0x63bb0146, 0x00000000}},  //   rkon, _xéqu, _dmun,
  { {0x63a20004, 0x63bb0288, 0x316701a2, 0x00000000}},  //   skon, _emun, genz_,
  { {0xe571007b, 0xbfaa1e4d, 0x62860387, 0x00000000}},  //   _אַן_, итие_, _škod,
  { {0xe29a008b, 0xdfd00054, 0x69dc1c71, 0x00000000}},  //   _каб_, عية_, hore,
  { {0x69dc002d, 0x7ae40010, 0x80da0061, 0x00000000}},  //   kore, _nyit, _पुरे,
  { {0x929d0046, 0x69dc0219, 0x81f6026c, 0x00000000}},  //   _zgło, jore, _بہتر_,
  { {0x69dc00d6, 0x7ae40263, 0xdb1d028c, 0x00000000}},  //   dore, _ayit, lisé,
  { {0x67c50006, 0x212c0065, 0x7ae40009, 0x00000000}},  //   pėji, _hedh_, _byit,
  { {0xdb1d374f, 0x7ae40009, 0xdce30006, 0x00000000}},  //   nisé, _cyit, _manę,
  { {0x7e623750, 0x00000000, 0x00000000, 0x00000000}},  //   _ipop,   ,   ,
  { {0xa3bc001c, 0x200c3751, 0x98a30036, 0x00000000}},  //   ेचा_, _judi_, kają_,
  { {0x3167010f, 0x7aed3752, 0x6d5a000c, 0x00000000}},  //   zenz_, _tzat, lfta,
  { {0x1ab40057, 0x69dc21c5, 0x200c0b54, 0x00000000}},  // [c050] _объя, bore, _ludi_,
  { {0x69dc001a, 0x8b3500a1, 0x443321b3, 0x00000000}},  //   core, _بڑھت, tsx_,
  { {0x200c0340, 0x331901e1, 0x00000000, 0x00000000}},  //   _nudi_, біля_,   ,
  { {0x98a30036, 0xb51b0316, 0x3a290145, 0x00000000}},  //   gają_, _प्रय_, _kwap_,
  { {0x44330066, 0x3167010f, 0xdb7c0049, 0x00000000}},  //   ssx_, tenz_, ינאכ,
  { {0x200c016e, 0x7bdd070d, 0x3f860173, 0x00000000}},  //   _budi_, hosu, _anou_,
  { {0x200c002f, 0x7bdd00b0, 0x3167010f, 0x00000000}},  //   _cudi_, kosu, renz_,
  { {0x63bb1bf2, 0x69dc0091, 0x200c0bde, 0x00000000}},  //   _umun, zore, _dudi_,
  { {0xdd91035b, 0x69dc0211, 0x657501ee, 0x00000000}},  //   فوظ_, yore, _kazh,
  { {0xc05b01fb, 0x41b501d8, 0x7ae40009, 0x00000000}},  //   _від_, _عمار, _ryit,
  { {0x69dc049c, 0x7e620062, 0x65750065, 0x00000000}},  //   vore, _epop, _mazh,
  { {0x7bdd1002, 0x6575012d, 0x3f86000a, 0x00000000}},  //   gosu, _lazh, _gnou_,
  { {0xde58007e, 0xfaff01d6, 0x3a99007c, 0x00000000}},  //   _маці_, seën_, отрю_,
  { {0xceb2007b, 0xa2cc0061, 0x200c0093, 0x00000000}},  //   _איד_, तपत्, _yudi_,
  { {0x2d873753, 0x2adc02d2, 0x69dc04f3, 0x00000000}},  //   _inne_, _गुरु_, rore,
  { {0x69dc0211, 0x7bdd0adb, 0xdb1d0010, 0x00000000}},  //   sore, cosu, yisé,
  { {0x69dc073a, 0x7e620009, 0x32050133, 0x00000000}},  // [c060] pore, _xpop, _oily_,
  { {0x7abb009b, 0x98a30036, 0x67c50006, 0x00000000}},  //   _לצפו, wają_, dėju,
  { {0x999b009b, 0x399b00a3, 0x765600b0, 0x00000000}},  //   _הביט, _הייד, styy,
  { {0x200c14d2, 0xdb1d3754, 0x320d004a, 0x00000000}},  //   _rudi_, tisé, _buey_,
  { {0x98a30036, 0x200c01a3, 0x52130088, 0x00000000}},  //   rają_, _sudi_, едіт,
  { {0xdb1d0353, 0x67243755, 0x00000000, 0x00000000}},  //   risé, lbij,   ,
  { {0x7e620465, 0x7bdd014a, 0x00000000, 0x00000000}},  //   _spop, yosu,   ,
  { {0x2d87014a, 0x44383756, 0x44440145, 0x00000000}},  //   _anne_, _ivr_, mr_,
  { {0x44442c04, 0x442a0016, 0x7bdd0091, 0x00000000}},  //   lr_, _hwb_, vosu,
  { {0x200c17fd, 0x444413e2, 0x64430089, 0x00000000}},  //   _tudi_, or_, šnie,
  { {0x7bdd045f, 0x3a2908d0, 0x443801c3, 0x00000000}},  //   tosu, _swap_, _jvr_,
  { {0x4444038f, 0x2d870004, 0x68e900b9, 0x00000000}},  //   ir_, _enne_, ředk,
  { {0x44440109, 0x753c3757, 0x7bdd0994, 0x00000000}},  //   hr_, _odrz, rosu,
  { {0x62800521, 0x7644061d, 0x44380541, 0x00000000}},  //   _mrmo, driy, _ovr_,
  { {0x44443758, 0x7bdd2cb7, 0xec090082, 0x00000000}},  //   jr_, posu, _yếm_,
  { {0x44440016, 0x628030dc, 0x6724129d, 0x00000000}},  //   dr_, _ormo, gbij,
  { {0x444400cc, 0x443800f4, 0x442a0116, 0x00000000}},  // [c070] er_, _avr_, _awb_,
  { {0x645701d5, 0x443801d6, 0x444403d0, 0x00000000}},  //   ttxi, _bvr_, fr_,
  { {0x6575008d, 0xf992009b, 0x44380030, 0x00000000}},  //   _vazh, _סרט_, _cvr_,
  { {0x61e10065, 0x64570032, 0x00000000, 0x00000000}},  //   _skll, rtxi,   ,
  { {0xd25b3430, 0x44380087, 0x27e90085, 0x00000000}},  //   сце_, _evr_, mlan_,
  { {0x27e90073, 0x4444252f, 0xfa78009b, 0x00000000}},  //   llan_, br_, פעות_,
  { {0x660f04d2, 0x27e90032, 0x628001a2, 0x00000000}},  //   _huck, olan_, _ermo,
  { {0x660f041a, 0x27e90058, 0x2240041a, 0x00000000}},  //   _kuck, nlan_, šika_,
  { {0x660702ae, 0xc2c40025, 0x27e922f6, 0x00000000}},  //   _kijk, _كيفي, ilan_,
  { {0x660f3759, 0xd8380059, 0x27e90022, 0x00000000}},  //   _muck, šči_, hlan_,
  { {0xbb4601e1, 0x673d0166, 0x1b1f0044, 0x00000000}},  //   менк, _odsj, _ভয়ে_,
  { {0x660702ae, 0x547a00b6, 0xfc3f0428, 0x00000000}},  //   _lijk, קטרו, čí_,
  { {0xeb972aa3, 0x8db50088, 0x660f01c3, 0x00000000}},  //   фия_, _оскі, _nuck,
  { {0x7644375a, 0x4444375b, 0xdd94008b, 0x00000000}},  //   vriy, yr_, _пачы,
  { {0x661d375c, 0x672400b5, 0x65a0006b, 0x00000000}},  //   _atsk, tbij, _möht,
  { {0x76440263, 0x27e9000c, 0x444401ee, 0x00000000}},  //   triy, glan_, vr_,
  { {0x67240004, 0x4444018e, 0x660700b5, 0x00000000}},  // [c080] rbij, wr_, _bijk,
  { {0x44440667, 0x272c001d, 0x27e90149, 0x00000000}},  //   tr_, ến_, alan_,
  { {0x444400cc, 0x27e9008e, 0x660700bb, 0x00000000}},  //   ur_, blan_, _dijk,
  { {0x660f001c, 0x444405d7, 0x76440263, 0x00000000}},  //   _fuck, rr_, priy,
  { {0x27e00c7e, 0x12170380, 0x644508b5, 0x00000000}},  //   moin_, وتوث_, arhi,
  { {0x4438001a, 0x6443008e, 0xd01a0242, 0x00000000}},  //   _tvr_, ánic, офи_,
  { {0x660f010f, 0x00000000, 0x00000000, 0x00000000}},  //   _zuck,   ,   ,
  { {0x64430627, 0x27e000b0, 0x660700bb, 0x00000000}},  //   šnic, noin_, _zijk,
  { {0x8d6a01fc, 0x33261d33, 0x6ac8013d, 0x00000000}},  //   ојна_, mbox_, रपोर,
  { {0x68e900b9, 0xf1aa0014, 0x33260fe8, 0x00000000}},  //   ředi, _باره_, lbox_,
  { {0x27e9014a, 0x27e00052, 0x00000000, 0x00000000}},  //   ylan_, koin_,   ,
  { {0x61ea1642, 0xf0b70049, 0x27e0375d, 0x00000000}},  //   llfl, _קלאר_, join_,
  { {0x27e900f8, 0x672f01ee, 0xdb060010, 0x00000000}},  //   vlan_, _recj, zikö,
  { {0x33260009, 0x0cd4004c, 0x660f010f, 0x00000000}},  //   hbox_, _полю, _ruck,
  { {0x27e90047, 0x660700b5, 0x332600bb, 0x00000000}},  //   tlan_, _rijk, kbox_,
  { {0x2fc4375e, 0x2d9c0190, 0x69ce046a, 0x00000000}},  //   nimg_, _hove_, anbe,
  { {0x33260009, 0x35f5005c, 0x2d9c231b, 0x00000000}},  // [c090] dbox_, епар, _kove_,
  { {0x27e91402, 0x2d9c0129, 0x660f11cd, 0x00000000}},  //   slan_, _jove_, _vuck,
  { {0x2d9c19ba, 0x3326009d, 0x672f00f6, 0x00000000}},  //   _move_, fbox_, _tecj,
  { {0x2d9c0038, 0x64453438, 0x660700b5, 0x00000000}},  //   _love_, rrhi, _wijk,
  { {0x201e0282, 0x661d093b, 0x2fc40009, 0x00000000}},  //   _atti_, _utsk, dimg_,
  { {0x2d9c086e, 0x018b007c, 0xdb1d00d6, 0x00000000}},  //   _nove_, ющей_, disí,
  { {0xc0e201fc, 0x213e0011, 0x6474007c, 0x00000000}},  //   лошк, _ddth_, _игру,
  { {0x80be0061, 0x2fc40009, 0xe0d0023c, 0x00000000}},  //   _वेळे, gimg_, جزه_,
  { {0x201e014a, 0x69ce01d6, 0x63a400b0, 0x00000000}},  //   _etti_, ynbe, öine,
  { {0x2fcd018e, 0x27e0375f, 0x2d9c01cb, 0x00000000}},  //   sneg_, zoin_, _cove_,
  { {0xdca50069, 0xfbc6007c, 0x2d9c051b, 0x00000000}},  //   хани, ебно, _dove_,
  { {0x7f840054, 0xdb040181, 0xcc2400a1, 0x00000000}},  //   _للمن, _aliá, کریٹ,
  { {0x1a66025a, 0x27e000b0, 0x65a001a2, 0x00000000}},  //   ریدی_, voin_, _möhr,
  { {0xe9df000c, 0x2018009d, 0x06e60044, 0x00000000}},  //   trúa_, _éric_, পেডি,
  { {0x69ce010f, 0x27e01622, 0x33260253, 0x00000000}},  //   rnbe, toin_, ybox_,
  { {0x2d9c0091, 0x33261588, 0xc3250044, 0x00000000}},  //   _zove_, xbox_, মৃতি_,
  { {0x7bc625b4, 0x764d0211, 0x3667026b, 0x00000000}},  // [c0a0] miku, guay, нато_,
  { {0x7bc61448, 0x27e000f4, 0x291a00c4, 0x00000000}},  //   liku, soin_, _ufpa_,
  { {0xe899026c, 0x2fc40009, 0x65a0006b, 0x00000000}},  //   _ہمیں_, yimg_, _böhr,
  { {0x7bc63554, 0x799e005b, 0x22460085, 0x00000000}},  //   niku, _hopw, trok_,
  { {0x41e60ee0, 0xdb1d00c4, 0x799e29f0, 0x00000000}},  //   ніка, lisã, _kopw,
  { {0xd8380059, 0xdb1d00c4, 0x7bc6023e, 0x00000000}},  //   šču_, visí, hiku,
  { {0x232a064b, 0x2fc410e0, 0x7bc60034, 0x00000000}},  //   _нови_, timg_, kiku,
  { {0x2d9c3760, 0x7bc60020, 0x443a088a, 0x00000000}},  //   _sove_, jiku, msp_,
  { {0x7bc60d49, 0x443a097e, 0x2d9c0059, 0x00000000}},  //   diku, lsp_, _pove_,
  { {0x2b4000e5, 0x2fc40045, 0x00000000, 0x00000000}},  //   _adic_, simg_,   ,
  { {0x7bc63761, 0x443a107b, 0x2fc40009, 0x00000000}},  //   fiku, nsp_, pimg_,
  { {0xe9df000c, 0x68150036, 0x7bc60010, 0x00000000}},  //   grún_, _sądo, giku,
  { {0xada6007e, 0x69da00b9, 0x2d9c02e7, 0x00000000}},  //   _падл, čten, _tove_,
  { {0x7c940025, 0xddd9000a, 0x2b402dc8, 0x00000000}},  //   _للتص, _apwņ, _edic_,
  { {0x7bc6006c, 0xbd17009b, 0x00000000, 0x00000000}},  //   biku, _אחוז_,   ,
  { {0x7c3a0030, 0x17f80025, 0x443a01c5, 0x00000000}},  //   mstr, فرقة_, dsp_,
  { {0x7c3a01e3, 0xe6130025, 0x75eb006b, 0x00000000}},  // [c0b0] lstr, اشر_, lüzi,
  { {0x7c3a21de, 0xddc90645, 0x2a690026, 0x00000000}},  //   ostr, zvež, _ipab_,
  { {0x69c73762, 0xdb1d0181, 0x6b8d3763, 0x00000000}},  //   mije, cisã, _knag,
  { {0x69c70209, 0x7c3a0016, 0x6b9f002b, 0x00000000}},  //   lije, istr, _joqg,
  { {0xfe08001d, 0xa56500a1, 0xdb0f0b33, 0x00000000}},  //   _hữu_, _لگان, licó,
  { {0x7bc61a92, 0x69c70363, 0x7c3a000c, 0x00000000}},  //   ziku, nije, kstr,
  { {0x7c3a0142, 0x7bc60009, 0x443a00fa, 0x00000000}},  //   jstr, yiku, csp_,
  { {0x7c3a01b5, 0xa5bb0010, 0xc6240044, 0x00000000}},  //   dstr, _utób, _পিতা_,
  { {0x7bc60004, 0xddc90006, 0x69c704eb, 0x00000000}},  //   viku, rvež, kije,
  { {0x0d8209c0, 0x6b8d1cae, 0x69c73764, 0x00000000}},  //   альн, _anag, jije,
  { {0x7c3a0af1, 0x69c7016e, 0x3a203765, 0x00000000}},  //   gstr, dije, _stip_,
  { {0xdb1d02d5, 0x61e30c2b, 0x799e0022, 0x00000000}},  //   visã, lonl, _sopw,
  { {0x7bc6020c, 0x7c3a001a, 0x799e3766, 0x00000000}},  //   riku, astr, _popw,
  { {0x7c3a04d2, 0x7bc6006c, 0x0ea80088, 0x00000000}},  //   bstr, siku, _якій_,
  { {0x6e3b01e5, 0x00000000, 0x00000000, 0x00000000}},  //   lsub,   ,   ,
  { {0x6f1b04cb, 0x6b8d0479, 0x61e30052, 0x00000000}},  //   ncuc, _gnag, honl,
  { {0x69c70119, 0x6443009f, 0x6e3b0276, 0x00000000}},  // [c0c0] bije, ánin, nsub,
  { {0x75d30025, 0xca37009b, 0x69c70091, 0x00000000}},  //   ليقا, _שניה_, cije,
  { {0x61e30052, 0x6e3b057e, 0x00000000, 0x00000000}},  //   donl, hsub,   ,
  { {0x07a600ed, 0x6e3b002b, 0x61e30026, 0x00000000}},  //   _рамн, ksub, eonl,
  { {0x7c3a09a4, 0x63a901d5, 0x61e3005d, 0x00000000}},  //   zstr, _ċent, fonl,
  { {0x41530088, 0x201a0181, 0x7c3a0016, 0x00000000}},  //   ивіс, ípio_, ystr,
  { {0xddc90036, 0xd34200a1, 0x7c3a06d3, 0x00000000}},  //   steś, _نہای, xstr,
  { {0x7c3a0190, 0x7ddd01aa, 0x245c01ca, 0x00000000}},  //   vstr, mèsy, mím_,
  { {0x6e3b011c, 0x245c01ca, 0x03a3003b, 0x00000000}},  //   gsub, lím_, _тито,
  { {0x6b8d0363, 0x7c3a00b5, 0x657e0169, 0x00000000}},  //   _snag, tstr, ndph,
  { {0x69c70209, 0x245c0428, 0x7c3a3767, 0x00000000}},  //   vije, ním_, ustr,
  { {0xfe4600ed, 0xa3d5007d, 0x6e3b0009, 0x00000000}},  //   _андо, िचय_, bsub,
  { {0xfe7206c6, 0xec0a001d, 0x7af60046, 0x00000000}},  //   _خدا_, _nếu_, _czyt,
  { {0x7c3a2353, 0x6e2d1e00, 0x63a00142, 0x00000000}},  //   pstr, _çaba, _lomn,
  { {0x62861581, 0x69c70209, 0x245c0161, 0x00000000}},  //   _škol, rije, jím_,
  { {0x657c0637, 0x245c0161, 0xdb0f16b5, 0x00000000}},  //   _aarh, dím_, ricó,
  { {0x628202ae, 0x61e3005d, 0x69c719e2, 0x00000000}},  // [c0d0] jvoo, yonl, pije,
  { {0xdc4200b9, 0x61e30068, 0x8895004d, 0x00000000}},  //   _léče, xonl, _биох,
  { {0x657c1b6f, 0x61e300b0, 0x260d012d, 0x00000000}},  //   _darh, vonl, _džoa_,
  { {0x63a00035, 0x6e22014a, 0x6d580009, 0x00000000}},  //   _comn, _otob, _lcva,
  { {0x63a00704, 0x657c01a3, 0x00000000, 0x00000000}},  //   _domn, _farh,   ,
  { {0xec0a001d, 0x6e3b0009, 0x7f42004a, 0x00000000}},  //   _hết_, vsub, _adoq,
  { {0xec0a001d, 0x245c0802, 0x61e30095, 0x00000000}},  //   _kết_, cím_, ronl,
  { {0x61e30047, 0xec0a001d, 0xdff5007e, 0x00000000}},  //   sonl, _yếu_, ыяль,
  { {0x7aed04cb, 0x8d7503ec, 0x69c50116, 0x00000000}},  //   _nyat, هادا, _omhe,
  { {0x6e3b04be, 0xb5fb0051, 0xdb0d009d, 0x00000000}},  //   rsub, _bpái, _plaî,
  { {0x75350409, 0xc1040025, 0x7aed0727, 0x00000000}},  //   _mezz, _نوكي, _ayat,
  { {0x69c50016, 0x7aed0061, 0x6e3b22f4, 0x00000000}},  //   _amhe, _byat, psub,
  { {0x7aed0009, 0x245c01dc, 0x00000000, 0x00000000}},  //   _cyat, zím_,   ,
  { {0x9d5502fd, 0x99d60025, 0x2d98150e, 0x00000000}},  //   _صنعت, اتحا, öret_,
  { {0x186701f9, 0xa3e3006e, 0xf746007c, 0x00000000}},  //   лари_, नका_, лево,
  { {0x245c01c8, 0x657c3768, 0x00000000, 0x00000000}},  //   vím_, _sarh,   ,
  { {0x657c0fbd, 0x63a00058, 0x0566005e, 0x00000000}},  // [c0e0] _parh, _romn, лван,
  { {0x245c004f, 0x63a00f4a, 0x3ea00009, 0x00000000}},  //   tím_, _somn, _àite_,
  { {0x80a80055, 0x63a03769, 0x657c098a, 0x00000000}},  //   _কেন্, _pomn, _varh,
  { {0x645e09b3, 0x644a0129, 0x99990006, 0x00000000}},  //   rtpi, àfiq, busų_,
  { {0x4423008d, 0x71a6008b, 0x245c004f, 0x00000000}},  //   _etj_, ладз, sím_,
  { {0x6282376a, 0x91e3007c, 0x245c01dc, 0x00000000}},  //   rvoo, боче, pím_,
  { {0x6282376b, 0xf1a9007a, 0xc953009b, 0x00000000}},  //   svoo, خانه_, צמה_,
  { {0x6d4302ef, 0x61fa0009, 0x78a100ea, 0x00000000}},  //   _adna, _whtl, ølvi,
  { {0xb5fb376c, 0xae430014, 0x8e1400e2, 0x00000000}},  //   _spái, مپيو, јдоц,
  { {0x3f8f000c, 0x7aed0009, 0x660e0066, 0x00000000}},  //   _engu_, _ryat, _jibk,
  { {0xd0120025, 0x7aed05cd, 0x00000000, 0x00000000}},  //   _الص_, _syat,   ,
  { {0xce350752, 0x660e376d, 0x6d4300fa, 0x00000000}},  //   _چونک, _libk, _edna,
  { {0x395a000a, 0x317e03a1, 0x00000000, 0x00000000}},  //   _bcps_, _katz_,   ,
  { {0x2d8e012d, 0x7aed0729, 0x660e01f3, 0x00000000}},  //   _unfe_, _vyat, _nibk,
  { {0x75350026, 0x9848005e, 0x317e2309, 0x00000000}},  //   _rezz, лята_, _matz_,
  { {0x7535002b, 0x644303fd, 0x317e209b, 0x00000000}},  //   _sezz, ánim, _latz_,
  { {0x75350207, 0xec0a0011, 0x44230181, 0x00000000}},  // [c0f0] _pezz, _vết_, _stj_,
  { {0x64430c0a, 0xe97300a1, 0x69c504f2, 0x00000000}},  //   šnim, _اندھ, _umhe,
  { {0xec0a0011, 0x75350197, 0xab5b006c, 0x00000000}},  //   _tết_, _vezz, tiüh,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x672d0020, 0x753502e5, 0xab5b006c, 0x00000000}},  //   mbaj, _tezz, riüh,
  { {0x21690373, 0x644a0977, 0x6025142f, 0x00000000}},  //   тики_, áfic, адка,
  { {0xdb1d009f, 0xf77f014a, 0x11280088, 0x00000000}},  //   nnsó, _kaç_, уючи_,
  { {0xfe4500ec, 0xf77f00f6, 0xe3b30257, 0x00000000}},  //   анио, _jaç_, _ارس_,
  { {0xee3604af, 0xdcf80059, 0x9f5e0010, 0x00000000}},  //   аны_, _davč, _autó_,
  { {0xbc19007e, 0xdb1d000c, 0x317e0032, 0x00000000}},  //   кімі_, rnsý, _gatz_,
  { {0xab2a005e, 0x720401d8, 0x764d2408, 0x00000000}},  //   кона_, _اولم, hray,
  { {0xe4560049, 0x2d9803a2, 0x3f8f376e, 0x00000000}},  //   סירט_, örer_, _ungu_,
  { {0x764d0146, 0x00000000, 0x00000000, 0x00000000}},  //   jray,   ,   ,
  { {0x764d376f, 0x6e2924fd, 0x00000000, 0x00000000}},  //   dray, mpeb,   ,
  { {0xac16012b, 0x77640066, 0x475a005e, 0x00000000}},  //   _коју_, tfix, края_,
  { {0x6289012d, 0x764d3770, 0x200f002b, 0x00000000}},  //   _oreo, fray, _jigi_,
  { {0x764d0009, 0x25a3012d, 0x14c80014, 0x00000000}},  // [c100] gray, _bojl_, گهای_,
  { {0x200f1158, 0x00000000, 0x00000000, 0x00000000}},  //   _ligi_,   ,   ,
  { {0x14c8007a, 0xddcb0089, 0x25a3012d, 0x00000000}},  //   دهای_, _apgū, _dojl_,
  { {0x764d3771, 0x317e010f, 0x62890051, 0x00000000}},  //   bray, _satz_, _breo,
  { {0x62890263, 0x0206007c, 0xdb1d006b, 0x00000000}},  //   _creo, аздн, sisç,
  { {0x27f21703, 0x2fc60142, 0x62893772, 0x00000000}},  //   llyn_, _smog_, _dreo,
  { {0x64a6008b, 0x9f44008e, 0x0396007e, 0x00000000}},  //   _тава, lomé_, _края,
  { {0x27f21ffe, 0x22490091, 0x317e00e7, 0x00000000}},  //   nlyn_, šaka_, _watz_,
  { {0x623301f9, 0xa3e3006e, 0xd054006b, 0x00000000}},  //   _меѓу, नकर_, _əbəd,
  { {0xcd0601fb, 0x200f009f, 0x504601fc, 0x00000000}},  //   ични, _eigi_, _вежб,
  { {0xdd97008b, 0x200f1f69, 0x9df7007e, 0x00000000}},  //   ршы_, _figi_, рнэт_,
  { {0x200f033b, 0xee8607d0, 0xdb24000c, 0x00000000}},  //   _gigi_, _выко, örðu,
  { {0xddc20087, 0x27f201c3, 0x00000000, 0x00000000}},  //   _epoš, dlyn_,   ,
  { {0xf77f014a, 0x394d010f, 0x27f227f5, 0x00000000}},  //   _saç_, ßes_, elyn_,
  { {0x69d501a2, 0x27f201c3, 0x00000000, 0x00000000}},  //   rnze, flyn_,   ,
  { {0x644300ee, 0x27f21c26, 0x57b4022a, 0x00000000}},  //   šnik, glyn_, обст,
  { {0x2cac018e, 0x60150006, 0x00000000, 0x00000000}},  // [c110] lydd_, _išme,   ,
  { {0xeb9f0637, 0x2d9e0065, 0x00000000, 0x00000000}},  //   ljø_, njte_,   ,
  { {0x2cac018e, 0x764d0093, 0x00000000, 0x00000000}},  //   nydd_, sray,   ,
  { {0x77b80b32, 0x764d0460, 0x27f2254e, 0x00000000}},  //   _píxe, pray, clyn_,
  { {0x27e90032, 0x59bb007d, 0x2cac005b, 0x00000000}},  //   moan_, _उतार, hydd_,
  { {0xc692007b, 0x27e9002d, 0x6289001a, 0x00000000}},  //   _זאך_, loan_, _vreo,
  { {0xa4d40088, 0x200f0b53, 0xbebd0e07, 0x00000000}},  //   _дорі, _pigi_, nbūv,
  { {0x6289002a, 0x2cac018e, 0x63ad006c, 0x00000000}},  //   _treo, dydd_, öand,
  { {0xddc20059, 0xe3b00025, 0xa2b516b6, 0x00000000}},  //   _spoš, _غرف_, _убач,
  { {0x2cac018e, 0x27e93773, 0x200f00d9, 0x00000000}},  //   fydd_, hoan_, _wigi_,
  { {0x27e9022b, 0x200f3774, 0xec0a0011, 0x00000000}},  //   koan_, _tigi_, _bếp_,
  { {0x5f77023c, 0xb5fb00b9, 0x6e293775, 0x00000000}},  //   _خاطر, _zpát, ppeb,
  { {0x27e9002d, 0xa5bb3776, 0x00000000, 0x00000000}},  //   doan_, _atóm,   ,
  { {0xbea2025f, 0x2fcd0007, 0x6fde0089, 0x00000000}},  //   _хашк, lieg_, rīce,
  { {0x3ead0010, 0xddc20059, 0x27f23777, 0x00000000}},  //   lyet_, _upoš, tlyn_,
  { {0x27e9002d, 0x2795017a, 0x00000000, 0x00000000}},  //   goan_, ошур,   ,
  { {0x27f20abb, 0x3ead008a, 0x07a3051f, 0x00000000}},  // [c120] rlyn_, nyet_, чатн,
  { {0x8b080036, 0x27f23778, 0x29cd00ca, 0x00000000}},  //   _cięż, slyn_, lžan_,
  { {0xb4b2013d, 0x3d3a0049, 0x27e9002d, 0x00000000}},  //   टने_, רגעס, boan_,
  { {0xec0a001d, 0xd36f0025, 0x00000000, 0x00000000}},  //   _xếp_, فهم_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x91e3003b, 0xe9df000c, 0x644300c4, 0x00000000}},  //   поче, trúi_, ânic,
  { {0xe4da02fd, 0x7c2400d2, 0x26c00851, 0x00000000}},  //   _صورت_, _čiro, lzio_,
  { {0x69ce00d4, 0xdbf100b9, 0x00000000, 0x00000000}},  //   hibe, _příb,   ,
  { {0x2cac0bc4, 0x26c00fa9, 0xe7f90061, 0x00000000}},  //   wydd_, nzio_, ंतता_,
  { {0x27e93779, 0xec0a0011, 0x26c000fa, 0x00000000}},  //   zoan_, _sếp_, izio_,
  { {0x69ce0032, 0x2fcd0036, 0x27e90058, 0x00000000}},  //   dibe, bieg_, yoan_,
  { {0x2cac018e, 0x26c0002d, 0x22400107, 0x00000000}},  //   rydd_, kzio_, šiku_,
  { {0x69ce0190, 0x2cac0016, 0x9b58005e, 0x00000000}},  //   fibe, sydd_, щият_,
  { {0x8b0800b9, 0x26c00a67, 0x260d0087, 0x00000000}},  //   _stří, dzio_, _ežoj_,
  { {0x27e92ccd, 0xfdf7009b, 0x7883013e, 0x00000000}},  //   toan_, _הצגת_, dívá,
  { {0xba1902fd, 0x9f5d000a, 0x58d40088, 0x00000000}},  //   _پيدا_, _chwè_, чост,
  { {0x27e91640, 0x7bcf0035, 0x69ce1793, 0x00000000}},  // [c130] roan_, micu, bibe,
  { {0x6d5a0006, 0x7bcf0211, 0x69ce008e, 0x00000000}},  //   ngta, licu, cibe,
  { {0x442700b5, 0x26c0002d, 0xb5fb377a, 0x00000000}},  //   ën_, azio_, _spás,
  { {0x7bcf001a, 0x00000000, 0x00000000, 0x00000000}},  //   nicu,   ,   ,
  { {0xe2990517, 0x6b7c0049, 0x326700a8, 0x00000000}},  //   рал_, טראנ, стев,
  { {0xa2cd001c, 0x7bcf377b, 0x61ea0146, 0x00000000}},  //   _देण्, hicu, gofl,
  { {0xe1f0023c, 0x2fcd010f, 0xf07500a1, 0x00000000}},  //   رسه_, tieg_, تیاں_,
  { {0xce4901e0, 0x69ce07ef, 0x6d5a377c, 0x00000000}},  //   азие_, zibe, egta,
  { {0x69ce0010, 0x7bcf0585, 0x61ea1238, 0x00000000}},  //   yibe, dicu, bofl,
  { {0x1c45029b, 0x69ce0270, 0xdcf80089, 0x00000000}},  //   оном, xibe, _savā,
  { {0x3a2909e4, 0x26c0377d, 0x3ead0065, 0x00000000}},  //   _atap_, zzio_, syet_,
  { {0x7bcf0056, 0x3b0a00e2, 0x00000000, 0x00000000}},  //   gicu, иено_,   ,
  { {0x29cd0091, 0x00000000, 0x00000000, 0x00000000}},  //   ržan_,   ,   ,
  { {0x63b80089, 0x3a2926e4, 0x1d09114a, 0x00000000}},  //   īvni, _dtap_, _кели_,
  { {0x3a29377e, 0x69ce00ab, 0xa7aa014c, 0x00000000}},  //   _etap_, ribe, аква_,
  { {0xa6db000c, 0x7bcf00e5, 0xdb0f0068, 0x00000000}},  //   _meðf, cicu, ticô,
  { {0x69ce068f, 0xd5b20379, 0x6fde0089, 0x00000000}},  // [c140] pibe, وفر_, nīca,
  { {0x6b840004, 0x26c00207, 0x2ca900b9, 0x00000000}},  //   _haig, rzio_, _řady_,
  { {0x07a601be, 0x6b96010a, 0xc7a601ee, 0x00000000}},  //   _данн, _knyg, _динк,
  { {0x26c0002d, 0x7afb0036, 0x61fd0089, 0x00000000}},  //   pzio_, żute, _īsla,
  { {0x6724021c, 0x420a0517, 0x00000000, 0x00000000}},  //   mcij, андо_,   ,
  { {0x6b840051, 0x7bcf0035, 0x672401ed, 0x00000000}},  //   _laig, zicu, lcij,
  { {0x2d850339, 0xdb060c4d, 0x29cd012d, 0x00000000}},  //   ddle_, lkkä, džal_,
  { {0x4444377f, 0x4fc6008b, 0x753c010f, 0x00000000}},  //   ms_, ўска, _herz,
  { {0x7644163c, 0xdb0d0189, 0x753c01a2, 0x00000000}},  //   nsiy, _ilaç, _kerz,
  { {0x444400d6, 0x63a229f9, 0x78a10039, 0x00000000}},  //   os_, ljon, älvk,
  { {0x4444062a, 0x7bcf0211, 0x6b84010a, 0x00000000}},  //   ns_, ticu, _baig,
  { {0x63a2002b, 0x76443780, 0x6b843781, 0x00000000}},  //   njon, ksiy, _caig,
  { {0x7bcf0bc0, 0x444428a9, 0x6b84011c, 0x00000000}},  //   ricu, hs_, _daig,
  { {0x4444061f, 0x7bcf0207, 0xdb0d1e5c, 0x00000000}},  //   ks_, sicu, _llaç,
  { {0x44440a72, 0x7bcf3782, 0x6b840051, 0x00000000}},  //   js_, picu, _faig,
  { {0x5bc40025, 0x628004eb, 0x6b840048, 0x00000000}},  //   _يقول, _osmo, _gaig,
  { {0x4438018e, 0x753c003b, 0xa6db000c, 0x00000000}},  // [c150] _awr_, _berz, _meðg,
  { {0x4444028c, 0x672400d0, 0x6b840bbb, 0x00000000}},  //   fs_, acij, _zaig,
  { {0x6280022b, 0x753c010f, 0x442a00fa, 0x00000000}},  //   _asmo, _derz, _ctb_,
  { {0x987a007b, 0x44380016, 0x63a23783, 0x00000000}},  //   _פארט, _dwr_, gjon,
  { {0xe66400aa, 0x442a002d, 0x798501a3, 0x00000000}},  //   _отро, _etb_, _kahw,
  { {0x44443784, 0x79850007, 0x673d00d9, 0x00000000}},  //   bs_, _jahw, _hesj,
  { {0x444404bd, 0x661d068f, 0x62800129, 0x00000000}},  //   cs_, _husk, _esmo,
  { {0x6615022b, 0x63a20046, 0xee390aa2, 0x00000000}},  //   _hizk, cjon, бни_,
  { {0xd14b01ef, 0x661d17cf, 0x63bb002d, 0x00000000}},  //   _نشان_, _jusk, _ilun,
  { {0xd1310054, 0x6b960039, 0x63a90007, 0x00000000}},  //   _أما_, _snyg, _hoen,
  { {0x6b84006c, 0x644500ab, 0x7525010f, 0x00000000}},  //   _paig, nshi, ichz,
  { {0x2d831034, 0xf1b90091, 0x64453785, 0x00000000}},  //   žje_, _duše_, ishi,
  { {0x79850d7e, 0x63a90007, 0x4279007b, 0x00000000}},  //   _bahw, _moen, זאָג,
  { {0x63bb3786, 0x63a201d5, 0x44440f7f, 0x00000000}},  //   _llun, zjon, ys_,
  { {0x63bb02b9, 0x6b8436f9, 0x661d125e, 0x00000000}},  //   _olun, _taig, _ausk,
  { {0x6d41006a, 0x4444138f, 0x661d05ad, 0x00000000}},  //   lala, vs_, _busk,
  { {0x44440038, 0x67240ade, 0x6615022b, 0x00000000}},  // [c160] ws_, rcij, _bizk,
  { {0x444402d0, 0x63bb02d5, 0x76440890, 0x00000000}},  //   ts_, _alun, rsiy,
  { {0x44440736, 0x661d0756, 0x7644005f, 0x00000000}},  //   us_, _eusk, ssiy,
  { {0x6d411084, 0x63a901d6, 0x7644005f, 0x00000000}},  //   hala, _coen, psiy,
  { {0x44440541, 0x753c0207, 0x63a90181, 0x00000000}},  //   ss_, _terz, _doen,
  { {0x44440038, 0x6d410149, 0x63a20c64, 0x00000000}},  //   ps_, jala, sjon,
  { {0x6d413787, 0x44440003, 0x3c21000c, 0x00000000}},  //   dala, qs_, _nóv_,
  { {0x6615002d, 0x63a90032, 0x4fc60b52, 0x00000000}},  //   _zizk, _goen, ясла,
  { {0x6d410adc, 0x7ae40065, 0xa5bb0048, 0x00000000}},  //   fala, _nxit, _stói,
  { {0x6d410127, 0xfe6f0380, 0x6ce6007e, 0x00000000}},  //   gala, ادي_, зіме,
  { {0x79850022, 0x00000000, 0x00000000, 0x00000000}},  //   _rahw,   ,   ,
  { {0xb4fb00a0, 0x69dc3788, 0xb09b00b3, 0x00000000}},  //   מפיי, enre, _ליבר,
  { {0xe61f0011, 0xf0b000a1, 0x98b80089, 0x00000000}},  //   _trôi_, _سیکھ, varā_,
  { {0x6d41001a, 0x661d0161, 0x644508e9, 0x00000000}},  //   cala, _rusk, yshi,
  { {0x7ae40211, 0x661d0006, 0xd7f5007e, 0x00000000}},  //   _exit, _susk, дзвы,
  { {0x213e0190, 0x201e01c5, 0x644505d5, 0x00000000}},  //   _leth_, _muti_, vshi,
  { {0x25aa018e, 0x3f860022, 0x63a904d2, 0x00000000}},  // [c170] _bobl_, _maou_, _roen,
  { {0x63bb00b9, 0x644501a2, 0x98b80089, 0x00000000}},  //   _slun, tshi, sarā_,
  { {0x63bb0006, 0x63a93789, 0x7bdd018d, 0x00000000}},  //   _plun, _poen, onsu,
  { {0x6d411fe0, 0x64450038, 0x661d00b0, 0x00000000}},  //   zala, rshi, _tusk,
  { {0x213e018e, 0x6d41005f, 0x7bdd01e5, 0x00000000}},  //   _beth_, yala, insu,
  { {0x201e2301, 0x63a901b5, 0x6d41378a, 0x00000000}},  //   _buti_, _woen, xala,
  { {0x6d41099e, 0x63a900c7, 0x201e01a3, 0x00000000}},  //   vala, _toen, _cuti_,
  { {0x6d4109f3, 0x98b8001a, 0x63bb0145, 0x00000000}},  //   wala, lară_, _ulun,
  { {0x6d4104bd, 0x3f86000a, 0x22460010, 0x00000000}},  //   tala, _daou_, csok_,
  { {0xe29005f3, 0x98b8001a, 0x201e23eb, 0x00000000}},  //   _حذف_, nară_, _futi_,
  { {0x6d41011f, 0x201e014a, 0x7af600b0, 0x00000000}},  //   rala, _guti_, _syyt,
  { {0x333f028c, 0x6d41020c, 0x60150006, 0x00000000}},  //   _jeux_, sala, _išmo,
  { {0x6d41006a, 0x201e0107, 0x333f00d9, 0x00000000}},  //   pala, _zuti_, _meux_,
  { {0xceb20104, 0xe61f0142, 0x201800d4, 0x00000000}},  //   _ביד_, _osôb_, _èric_,
  { {0x69dc0210, 0x7e69378b, 0xfbc6213f, 0x00000000}},  //   rnre, ltep, _обко,
  { {0x2d870ce3, 0x9b460014, 0x7af600b0, 0x00000000}},  //   _hane_, _کنکو, _tyyt,
  { {0x2d87008d, 0x25aa018e, 0x05aa007e, 0x00000000}},  // [c180] _kane_, _pobl_, овай_,
  { {0x2d87071e, 0x6e2d014a, 0x00000000, 0x00000000}},  //   _jane_, _çabu,   ,
  { {0x2d87378c, 0x48060088, 0xba2900a1, 0x00000000}},  //   _mane_, _опов, _وسیم_,
  { {0x333f028c, 0x213e0784, 0x201e231b, 0x00000000}},  //   _ceux_, _seth_, _ruti_,
  { {0x333f028c, 0x213e0016, 0x201e34d6, 0x00000000}},  //   _deux_, _peth_, _suti_,
  { {0x27ed0059, 0x2d870020, 0x201e011c, 0x00000000}},  //   čene_, _nane_, _puti_,
  { {0x232a0088, 0x333f00f4, 0x2246002b, 0x00000000}},  //   _мови_, _feux_, ssok_,
  { {0x61f801ee, 0x00000000, 0x00000000, 0x00000000}},  //   slvl,   ,   ,
  { {0x2d87378d, 0x7e6900c7, 0x7c2d0166, 0x00000000}},  //   _bane_, gtep, _čara,
  { {0x2d870207, 0x201e0010, 0x00000000, 0x00000000}},  //   _cane_, _tuti_,   ,
  { {0x333f00f4, 0x2cb8378e, 0x61430331, 0x00000000}},  //   _yeux_, árd_, _реха,
  { {0xbb94007c, 0x2b4000d4, 0x7e6900e0, 0x00000000}},  //   вающ, _ceic_, btep,
  { {0xc33300b3, 0xbda60025, 0x98ba0173, 0x00000000}},  //   כור_, _يحتو, _depč_,
  { {0x2d87008e, 0x00000000, 0x00000000, 0x00000000}},  //   _gane_,   ,   ,
  { {0x9cf40088, 0x20061328, 0x98b80035, 0x00000000}},  //   _язкі, _khoi_, vară_,
  { {0x2d870089, 0x644300c4, 0xdb1d010e, 0x00000000}},  //   _zane_, ânim, nisü,
  { {0x98b8001a, 0x27e20022, 0x00000000, 0x00000000}},  // [c190] tară_, _djkn_,   ,
  { {0x05770439, 0xde880082, 0x2d8700f6, 0x00000000}},  //   بارد, _mị_, _xane_,
  { {0x333f00f4, 0x81e40055, 0x60050e7c, 0x00000000}},  //   _peux_, নতা_, lóme,
  { {0x98b8001a, 0x2b4000f6, 0x20060082, 0x00000000}},  //   sară_, _xeic_, _nhoi_,
  { {0x333f00f4, 0x60052bc9, 0x7e69004a, 0x00000000}},  //   _veux_, nóme, xtep,
  { {0x69d5378f, 0x663a0049, 0x00000000, 0x00000000}},  //   nize, _מעשׂ,   ,
  { {0x2d870091, 0xdb0d00fa, 0x00000000, 0x00000000}},  //   _rane_, _claú,   ,
  { {0xde8800ad, 0xc918019b, 0x20060011, 0x00000000}},  //   _bị_, וחות_, _choi_,
  { {0x2d873790, 0x3eb90047, 0xc175005e, 0x00000000}},  //   _pane_, ást_, _плащ,
  { {0x69d505fa, 0xde880011, 0x7e69008a, 0x00000000}},  //   jize, _dị_, rtep,
  { {0x69d52388, 0xc5f200b3, 0x2d870253, 0x00000000}},  //   dize, רדי_, _vane_,
  { {0x2d873791, 0x00000000, 0x00000000, 0x00000000}},  //   _wane_,   ,   ,
  { {0x2d8720a7, 0x69d50010, 0xeb970ae0, 0x00000000}},  //   _tane_, fize, хия_,
  { {0xbed6007b, 0x69d50e69, 0x00000000, 0x00000000}},  //   _אונז_, gize,   ,
  { {0x98b80006, 0x00000000, 0x00000000, 0x00000000}},  //   karą_,   ,   ,
  { {0x8c1a0097, 0x200d02d4, 0x2cb800ea, 0x00000000}},  //   _צופי, nmei_, ørde_,
  { {0xaffa0049, 0x6005004a, 0x00000000, 0x00000000}},  // [c1a0] פּלי, cóme,   ,
  { {0x69d512fc, 0x386a00ea, 0x273e0082, 0x00000000}},  //   cize, ptbr_, ắn_,
  { {0x19b700a3, 0x7dc400f6, 0x2db60049, 0x00000000}},  //   _נפטר_, _fòsf, עלען_,
  { {0xd8d70049, 0x00000000, 0x00000000, 0x00000000}},  //   _טויט_,   ,   ,
  { {0x2006018e, 0x857400a1, 0x27e01e8d, 0x00000000}},  //   _rhoi_, _لگائ, mnin_,
  { {0x27e00023, 0xf1b90087, 0x00000000, 0x00000000}},  //   lnin_, _puša_,   ,
  { {0xc5ec024c, 0x27e0045f, 0x6f020010, 0x00000000}},  //   जकीय_, onin_, _szoc,
  { {0x27e03792, 0x657e028a, 0xc3150044, 0x00000000}},  //   nnin_, leph, াড়ি_,
  { {0x69d50009, 0x27e00fc8, 0x00000000, 0x00000000}},  //   yize, inin_,   ,
  { {0xde88001d, 0x62820640, 0x27e00065, 0x00000000}},  //   _vị_, mwoo, hnin_,
  { {0xa5bb0df0, 0xa6db009f, 0x62820112, 0x00000000}},  //   _któr, _meða, lwoo,
  { {0xdb1d0181, 0x20550888, 0x27e03793, 0x00000000}},  //   visó, _штур, jnin_,
  { {0x628201b5, 0x27e0002b, 0x69d51688, 0x00000000}},  //   nwoo, dnin_, tize,
  { {0x645e0209, 0xa6db000c, 0x6005004a, 0x00000000}},  //   kupi, _neða, róme,
  { {0xf8072239, 0x69d53794, 0x645e0089, 0x00000000}},  //   ечан, rize, jupi,
  { {0x27e03795, 0x62820250, 0x3cfb009b, 0x00000000}},  //   gnin_, kwoo, _מלונ,
  { {0x69d500e5, 0x00000000, 0x00000000, 0x00000000}},  // [c1b0] pize,   ,   ,
  { {0xdb1d0036, 0x78a10039, 0x27e00f82, 0x00000000}},  //   pisó, älvs, anin_,
  { {0xddc20c76, 0x645e14f7, 0x2d8c3796, 0x00000000}},  //   _opož, gupi, idde_,
  { {0x62350423, 0x628200b5, 0x7f4200fa, 0x00000000}},  //   веду, fwoo, _neoq,
  { {0x62820343, 0x44330009, 0x6e220006, 0x00000000}},  //   gwoo, spx_, _nuob,
  { {0xe2960954, 0x98b80006, 0x657e0133, 0x00000000}},  //   таш_, sarą_, ceph,
  { {0x7c2d016e, 0x4425001a, 0xdcf80006, 0x00000000}},  //   _čaro, _îl_, _tavę,
  { {0x889c007b, 0x44310032, 0x389c009b, 0x00000000}},  //   לבוי, _itz_, ליונ,
  { {0x200d001a, 0x26c90020, 0x52740014, 0x00000000}},  //   rmei_, nzao_, _مالز,
  { {0x2d9501e0, 0x64580964, 0x6e22007f, 0x00000000}},  //   трис, švie, _duob,
  { {0x27e00180, 0x442302c1, 0x00000000, 0x00000000}},  //   ynin_, _juj_,   ,
  { {0x442300d2, 0x443117c9, 0x2d9c000a, 0x00000000}},  //   _muj_, _mtz_, _enve_,
  { {0xf412007b, 0x4423016c, 0x27e01b84, 0x00000000}},  //   יפט_, _luj_, vnin_,
  { {0xaf0401fb, 0x44313797, 0xddc2013e, 0x00000000}},  //   _спіл, _otz_, _zpož,
  { {0xd94300ed, 0x18670f93, 0x27e00023, 0x00000000}},  //   реси, кари_, tnin_,
  { {0x3f8d0181, 0x6d433798, 0x27e00fd1, 0x00000000}},  //   ndeu_, _hena, unin_,
  { {0x6d43020c, 0x27e0000c, 0x0566005e, 0x00000000}},  // [c1c0] _kena, rnin_, кван,
  { {0x27ed091e, 0xa5bb1324, 0x645e006c, 0x00000000}},  //   čena_, _stór, tupi,
  { {0x6d43020c, 0x224d0263, 0x44230107, 0x00000000}},  //   _mena, _avek_, _cuj_,
  { {0x6282049b, 0x6d4300ca, 0x7c2d0107, 0x00000000}},  //   twoo, _lena, _čarl,
  { {0x0ed00164, 0x2d8c15c5, 0x657e004a, 0x00000000}},  //   _तेंड, ydde_, peph,
  { {0x62820ace, 0x6d430428, 0xf1b9073a, 0x00000000}},  //   rwoo, _nena, _dušo_,
  { {0x044301f9, 0x628200bb, 0x442300fa, 0x00000000}},  //   _весн, swoo, _guj_,
  { {0x6282005b, 0xa857009b, 0x6d430288, 0x00000000}},  //   pwoo, דיקה_, _aena,
  { {0x6d430149, 0x661c307d, 0x6fde0089, 0x00000000}},  //   _bena, _kirk, nīci,
  { {0x6d43001e, 0x68e9000d, 0x661c3799, 0x00000000}},  //   _cena, şedi, _jirk,
  { {0x6d43379a, 0x443100fa, 0x224d012d, 0x00000000}},  //   _dena, _xtz_, _zvek_,
  { {0x2d8a01d9, 0x799e0173, 0x6d4300d9, 0x00000000}},  //   žbe_, _anpw, _eena,
  { {0xdfcf006d, 0x6d43065a, 0x00000000, 0x00000000}},  //   _بين_, _fena,   ,
  { {0x6d4303a8, 0x6fde0089, 0x661c0093, 0x00000000}},  //   _gena, dīci, _nirk,
  { {0x6d48011f, 0x7e60011c, 0x290502e1, 0x00000000}},  //   mada, lump, åla_,
  { {0x6d430032, 0x661c0022, 0x7bc601a2, 0x00000000}},  //   _zena, _airk, chku,
  { {0x661c014a, 0x7e601451, 0x443100d2, 0x00000000}},  // [c1d0] _birk, nump, _stz_,
  { {0x6d482378, 0x661c1d33, 0x6d430066, 0x00000000}},  //   nada, _cirk, _xena,
  { {0x661c0059, 0x6b8d011c, 0x67d50121, 0x00000000}},  //   _dirk, _kaag, _бону,
  { {0x6d48020c, 0xdfc6023c, 0xa3cd013d, 0x00000000}},  //   hada, _طي_, षों_,
  { {0x6d48011f, 0x6b8d011c, 0x661c0d22, 0x00000000}},  //   kada, _maag, _firk,
  { {0x6d48231e, 0x6b8d379b, 0x7e600c46, 0x00000000}},  //   jada, _laag, dump,
  { {0x6d480489, 0x44310032, 0xc5f2009b, 0x00000000}},  //   dada, _utz_, _הדם_,
  { {0x6d43379c, 0x661c09ce, 0x6b8d0058, 0x00000000}},  //   _sena, _zirk, _naag,
  { {0x6d430149, 0x224d3002, 0x31350920, 0x00000000}},  //   _pena, _uvek_, _безр,
  { {0x6d482346, 0x25b10087, 0x661c0066, 0x00000000}},  //   gada, _jozl_, _xirk,
  { {0x69c7008d, 0x6d4300f4, 0x6b8d379d, 0x00000000}},  //   dhje, _vena, _baag,
  { {0x4e9506b4, 0xf9890104, 0x7e6000e0, 0x00000000}},  //   _مشتر, _מר_, bump,
  { {0x6d43020c, 0x6b8d01bb, 0x7e60008e, 0x00000000}},  //   _tena, _daag, cump,
  { {0x6d4800d6, 0x7bc6008d, 0x6d430022, 0x00000000}},  //   cada, shku, _uena,
  { {0x201d01d6, 0xc8b507d0, 0xbca80025, 0x00000000}},  //   _kiwi_, асты, _لديك_,
  { {0xd24500a1, 0xab66137c, 0x00000000, 0x00000000}},  //   _وچ_, _свил,   ,
  { {0x661c379e, 0x7bc407d3, 0x7bd60009, 0x00000000}},  // [c1e0] _pirk, _iliu, _imyu,
  { {0x598602a8, 0x65650487, 0x64a6003b, 0x00000000}},  //   _слоб, gghh, лаза,
  { {0x661c068f, 0x5a17009b, 0x6289004a, 0x00000000}},  //   _virk, _תקין_, _aseo,
  { {0x661c001f, 0x6d48029d, 0x929d0046, 0x00000000}},  //   _wirk, zada, _czło,
  { {0x6d48006b, 0xe29731cd, 0xbb3b01ce, 0x00000000}},  //   yada, лац_, געני,
  { {0x7bc404bd, 0xa6db000c, 0x6d4809b1, 0x00000000}},  //   _lliu, _meðl, xada,
  { {0x65c30cee, 0x7bc400f6, 0x00000000, 0x00000000}},  //   _убра, _oliu,   ,
  { {0x6d480016, 0xdfd001af, 0x60051ae2, 0x00000000}},  //   wada, تيب_, tóma,
  { {0x6d4804bd, 0xda040061, 0x394a0306, 0x00000000}},  //   tada, ळतात_, kabs_,
  { {0x7bc40020, 0x6b8d006c, 0xc27b00a3, 0x00000000}},  //   _aliu, _saag, _ארמי,
  { {0x7e60379f, 0x6b8d0be4, 0x61fa0288, 0x00000000}},  //   sump, _paag, _iktl,
  { {0x764d006a, 0x321e0c8c, 0x00000000, 0x00000000}},  //   ysay, _hity_,   ,
  { {0x6b8d018d, 0x69c70065, 0x8f9b01ce, 0x00000000}},  //   _vaag, thje, _רידי,
  { {0x38350140, 0x00000000, 0x00000000, 0x00000000}},  //   ингр,   ,   ,
  { {0x4dfb012e, 0x69c70030, 0x7bc40048, 0x00000000}},  //   _רפוא, rhje, _fliu,
  { {0x69c7008d, 0x8aa70072, 0xdc9b009b, 0x00000000}},  //   shje, _брод, _טיול,
  { {0x2d8e01aa, 0xdb1d002a, 0x2b4b0026, 0x00000000}},  // [c1f0] _kafe_, bhsá, macc_,
  { {0x9967041f, 0xb8db0044, 0x764d0357, 0x00000000}},  //   _стил, _আই_, rsay,
  { {0x7c2d016c, 0x764d0923, 0xb604041f, 0x00000000}},  //   _čark, ssay, сятк,
  { {0x61fa37a0, 0x321e17cf, 0xdc3b0049, 0x00000000}},  //   _aktl, _aity_, געאר,
  { {0x2169003b, 0xe1f10380, 0x00000000, 0x00000000}},  //   вили_, يست_,   ,
  { {0x321e0038, 0x20550256, 0xdce80089, 0x00000000}},  //   _city_, атир, nedē,
  { {0xdb1d006c, 0xd6c70044, 0x2ba801f5, 0x00000000}},  //   misõ, _এশিয, गामा,
  { {0xa24600a1, 0xdb1d010e, 0x62890048, 0x00000000}},  //   _چینل_, lisõ, _tseo,
  { {0x20030089, 0x69c500c4, 0x2b4b009d, 0x00000000}},  //   ēji_, _olhe, dacc_,
  { {0x7bc80089, 0x2d8e0a60, 0x00000000, 0x00000000}},  //   ījum, _cafe_,   ,
  { {0x7bc40006, 0xa6db000c, 0x201d1a37, 0x00000000}},  //   _pliu, _seðl, _tiwi_,
  { {0x69c537a1, 0x68fe01c3, 0x00000000, 0x00000000}},  //   _alhe, _rypd,   ,
  { {0x394a1651, 0x9e9600a1, 0x8a060069, 0x00000000}},  //   tabs_, _پانچ, изме,
  { {0x8cb50017, 0xed590517, 0x2d8e00e5, 0x00000000}},  //   _всич, _рок_, _gafe_,
  { {0x7aed0181, 0x3f8f010e, 0x00000000, 0x00000000}},  //   _exat, _kagu_,   ,
  { {0x2d8e01aa, 0x69c50010, 0x3f8f006c, 0x00000000}},  //   _zafe_, _elhe, _jagu_,
  { {0xf1c50061, 0x3f8f0016, 0x394a0009, 0x00000000}},  // [c200] वसान, _magu_, pabs_,
  { {0x399a00bd, 0x8af0005f, 0x3f8f027e, 0x00000000}},  //   _ייִד, _edəc, _lagu_,
  { {0x69dc001a, 0x032600d7, 0x98a600ed, 0x00000000}},  //   mire, аден, _тине,
  { {0x3f8f0004, 0x69dc001a, 0x78a8010e, 0x00000000}},  //   _nagu_, lire, ädvu,
  { {0x69dc0051, 0x23660023, 0xdb1d010e, 0x00000000}},  //   oire, rgoj_, bisõ,
  { {0x69dc001a, 0xdb1d0181, 0x51f701e1, 0x00000000}},  //   nire, cisõ, анію_,
  { {0x25f5006e, 0x3f8f0022, 0x74160014, 0x00000000}},  //   ्तरी_, _bagu_, _نوسا,
  { {0x443a023a, 0x2d8e00ab, 0xf1b8002b, 0x00000000}},  //   mpp_, _safe_, _diġa_,
  { {0x443a0061, 0x317a00a6, 0x69dc16c5, 0x00000000}},  //   lpp_, _لحاظ_, kire,
  { {0x69dc001a, 0x2d8e0023, 0x00000000, 0x00000000}},  //   jire, _qafe_,   ,
  { {0x69dc0b25, 0x308605d4, 0x60050f08, 0x00000000}},  //   dire, _خلاف, cómo,
  { {0x69dc03b3, 0x61f80091, 0x98a30036, 0x00000000}},  //   eire, lovl, ncją_,
  { {0x9b58005e, 0x3f840036, 0x2fc6011c, 0x00000000}},  //   шият_, memu_, _ilog_,
  { {0x61f800ee, 0x69dc203c, 0x3f8437a2, 0x00000000}},  //   novl, gire, lemu_,
  { {0xed5701f9, 0x2ee80044, 0xdb1d00c4, 0x00000000}},  //   _тој_, _পরিষ, visõ,
  { {0x3f840d0a, 0x6aa22a6c, 0x36d5003b, 0x00000000}},  //   nemu_, _šofe, бобр,
  { {0x69dc001a, 0x7bdd1f37, 0x3b09006b, 0x00000000}},  // [c210] bire, misu, _uzaq_,
  { {0x3f84000b, 0x7bdd03b6, 0x2707006e, 0x00000000}},  //   hemu_, lisu, _शरीर_,
  { {0xe47501f9, 0x4427001d, 0x61f800ca, 0x00000000}},  //   слењ, ên_, dovl,
  { {0x889a0104, 0x2458008b, 0x7bdd11eb, 0x00000000}},  //   _עברי, раць_, nisu,
  { {0xddc9001a, 0x3f8f04cb, 0x443a0009, 0x00000000}},  //   nteţ, _ragu_, app_,
  { {0xe1f8007e, 0x3f8f008a, 0x2b492264, 0x00000000}},  //   агі_, _sagu_, _leac_,
  { {0xd3a701e1, 0x7bdd07a4, 0x00000000, 0x00000000}},  //   _крап, kisu,   ,
  { {0xdce1001e, 0x69dc002d, 0x2fc60051, 0x00000000}},  //   selī, zire, _clog_,
  { {0xef190057, 0x61f80087, 0x5fa9013d, 0x00000000}},  //   ыми_, bovl, काबल,
  { {0x236d0085, 0x7dc40173, 0x00000000, 0x00000000}},  //   _hcej_, _pòsa,   ,
  { {0x2fc60142, 0x69dc26ee, 0x3f8f0142, 0x00000000}},  //   _flog_, vire, _tagu_,
  { {0x3f8437a3, 0x2fc6016c, 0x3015007c, 0x00000000}},  //   cemu_, _glog_, _удер,
  { {0xef0e013b, 0x69dc114e, 0x37cd0044, 0x00000000}},  //   _хм_, tire, রচার,
  { {0x6e3b2818, 0xfe700014, 0x00000000, 0x00000000}},  //   mpub, _زده_,   ,
  { {0x2d85000d, 0xa3e7001c, 0x69dc001a, 0x00000000}},  //   mele_, यचा_, rire,
  { {0x2d8537a4, 0x2cb80039, 0x69dc046e, 0x00000000}},  //   lele_, ärde_, sire,
  { {0xb8ff02fb, 0xbb3b007b, 0x6e3b1c1a, 0x00000000}},  // [c220] _दे_, _געפי, npub,
  { {0x99860054, 0x2d85000d, 0xa6db01e5, 0x00000000}},  //   _الدو, nele_, _meðh,
  { {0xe45a003b, 0xdb0d000c, 0x2d850035, 0x00000000}},  //   уже_, _hlað, iele_,
  { {0x2d85017b, 0xddc200b9, 0x6cfa0049, 0x00000000}},  //   hele_, _dvoř, אפעס,
  { {0x2d8502ae, 0x61f80059, 0x3f840c8a, 0x00000000}},  //   kele_, tovl, vemu_,
  { {0x2d8537a5, 0x2fc637a6, 0x64a6003b, 0x00000000}},  //   jele_, _slog_, _лага,
  { {0x2d850004, 0xd01001f7, 0x3f8404be, 0x00000000}},  //   dele_, ولت_, temu_,
  { {0x289b0097, 0x9a290082, 0x00000000, 0x00000000}},  //   ריקא, _lươn_,   ,
  { {0x7bdd0a53, 0x442a023a, 0x25ef02d2, 0x00000000}},  //   visu, _hub_, _आदमी_,
  { {0x7bdd0022, 0x44380022, 0x442a3134, 0x00000000}},  //   wisu, _ktr_, _kub_,
  { {0xfe6f06c6, 0xb5fb0049, 0x3a2937a7, 0x00000000}},  //   ودی_, רליכ, _suap_,
  { {0xdb0d009f, 0x3a290022, 0xf1b90ecc, 0x00000000}},  //   _blað, _puap_, _ruši_,
  { {0x442a0046, 0x2d85001a, 0x15fa03d7, 0x00000000}},  //   _lub_, bele_, ्तार_,
  { {0xf2d3007b, 0x0e5701f8, 0x2d85001a, 0x00000000}},  //   לער_, _פשוט_, cele_,
  { {0x44380035, 0xeb9f0030, 0xe9190088, 0x00000000}},  //   _ntr_, rløb_, рові_,
  { {0xf77000a1, 0x60310089, 0x628001c3, 0x00000000}},  //   ٹاف_, _jāma, _opmo,
  { {0x95d9026b, 0x442a00bb, 0x6d4a01a3, 0x00000000}},  // [c230] адат_, _aub_, _kefa,
  { {0x442a0191, 0x6d4a008e, 0x6f020133, 0x00000000}},  //   _bub_, _jefa, _myoc,
  { {0x442a0145, 0x4438120e, 0x62800006, 0x00000000}},  //   _cub_, _ctr_, _apmo,
  { {0x442a00b9, 0x2d85001a, 0x923906f3, 0x00000000}},  //   _dub_, zele_, ачку_,
  { {0x6d58091e, 0x27e9011c, 0x44381baa, 0x00000000}},  //   _odva, mnan_, _etr_,
  { {0xddc200b9, 0x6d4a0142, 0x443837a8, 0x00000000}},  //   _tvoř, _nefa, _ftr_,
  { {0x2d85001a, 0x27e90b4c, 0x3dce0044, 0x00000000}},  //   vele_, onan_, িচাল,
  { {0x27e937a9, 0xdbf2101c, 0x6d580038, 0x00000000}},  //   nnan_, _přís, _adva,
  { {0x2d8537aa, 0x7c2a010f, 0x27e904cb, 0x00000000}},  //   tele_, _aufr, inan_,
  { {0x6d4a1f5a, 0x6e3b0089, 0x7c2a00ea, 0x00000000}},  //   _cefa, rpub, _bufr,
  { {0x6d4a0263, 0x6e3b37ab, 0x2d852786, 0x00000000}},  //   _defa, spub, rele_,
  { {0x2d8537ac, 0x2c710010, 0x6e3b0066, 0x00000000}},  //   sele_, rád_, ppub,
  { {0xeb970242, 0xff5002fd, 0x8af0006b, 0x00000000}},  //   ция_, _سخن_, _edən,
  { {0x8c4500e3, 0x6d4a010f, 0x7b3e0036, 0x00000000}},  //   _деке, _gefa, dłuż,
  { {0x6d410fdb, 0xab5b0279, 0x9a290011, 0x00000000}},  //   mbla, mkün, _vươn_,
  { {0x442a0089, 0x27e937ad, 0x2904001e, 0x00000000}},  //   _rub_, gnan_, āma_,
  { {0x442a000d, 0x7c2a010f, 0x6e2336a8, 0x00000000}},  // [c240] _sub_, _zufr, _kinb,
  { {0x6d4103ed, 0x442a28fe, 0x4438001a, 0x00000000}},  //   nbla, _pub_, _ptr_,
  { {0x7c24042b, 0x6e23002b, 0x98a30036, 0x00000000}},  //   _kiir, _minb, kcję_,
  { {0x13060088, 0x99860014, 0x4438004a, 0x00000000}},  //   озем, _الگو, _vtr_,
  { {0xc7b3019b, 0x27e000b0, 0x7d030190, 0x00000000}},  //   _חבר_, miin_, _lyns,
  { {0x1a9b007b, 0x4a9b007b, 0x27e0272e, 0x00000000}},  //   יינע, יינג, liin_,
  { {0x61ed07cd, 0x6d4a10ff, 0x2167012b, 0x00000000}},  //   éala, _refa, цији_,
  { {0x6d4a2609, 0x6d41008e, 0x6e2b0058, 0x00000000}},  //   _sefa, ebla, _bugb,
  { {0x7c2a0211, 0x6d4101d6, 0x3f9800b9, 0x00000000}},  //   _sufr, fbla, ěru_,
  { {0x27ed00ee, 0x44240038, 0x6d410030, 0x00000000}},  //   čeni_, _him_, gbla,
  { {0x44243206, 0x27e000b0, 0x6e23022c, 0x00000000}},  //   _kim_, kiin_, _dinb,
  { {0x442437ae, 0x6d4a018e, 0x6e2305e9, 0x00000000}},  //   _jim_, _wefa, _einb,
  { {0x44240181, 0x6d413220, 0x27e037af, 0x00000000}},  //   _mim_, bbla, diin_,
  { {0x6d5837b0, 0x442401a3, 0x7d030030, 0x00000000}},  //   _udva, _lim_, _fyns,
  { {0x61fd009f, 0x7c380091, 0x61ea010f, 0x00000000}},  //   _ísle, _utvr, infl,
  { {0x44240046, 0x27e937b1, 0x61ea01a2, 0x00000000}},  //   _nim_, unan_, hnfl,
  { {0x27e903ed, 0x9f440d62, 0x2ba80204, 0x00000000}},  // [c250] rnan_, lomó_, गारा,
  { {0x69ce010f, 0xd49b0175, 0x27e90058, 0x00000000}},  //   chbe, ире_, snan_,
  { {0xd76600a1, 0x7aeb0089, 0x7b3e0036, 0x00000000}},  //   _کاپٹ, ņotā, służ,
  { {0x78fa009b, 0x6d4137b2, 0x442437b3, 0x00000000}},  //   _לפתו, zbla, _cim_,
  { {0x4424018e, 0xe299022a, 0x80d3013d, 0x00000000}},  //   _dim_, сал_, _भेजे,
  { {0x6e2b0007, 0x76ba00b6, 0xdb0400f6, 0x00000000}},  //   _rugb, _המשפ, _dniè,
  { {0x44240181, 0x7dc400f6, 0x6d4137b4, 0x00000000}},  //   _fim_, _còsm, vbla,
  { {0xffd5007e, 0x6e23002d, 0x6d4100d2, 0x00000000}},  //   яўля, _sinb, wbla,
  { {0x600537b5, 0x720500f3, 0x7d0311b6, 0x00000000}},  //   nómi, _فورم, _syns,
  { {0xd1b801d8, 0x7c2437b6, 0x442401d6, 0x00000000}},  //   _والا_, _siir, _zim_,
  { {0x7c240cfc, 0x6d410007, 0xeb9a003b, 0x00000000}},  //   _piir, rbla, бин_,
  { {0x6d410343, 0x6e230066, 0x442400f6, 0x00000000}},  //   sbla, _winb, _xim_,
  { {0x74c30055, 0x6e23002b, 0x27e000b0, 0x00000000}},  //   ্পিউ, _tinb, viin_,
  { {0x8e080088, 0xab5b0010, 0x2caa0051, 0x00000000}},  //   _днів_, lkül, óidí_,
  { {0x27e0021e, 0x7c2437b7, 0x7e690943, 0x00000000}},  //   tiin_, _tiir, luep,
  { {0x69ce013f, 0x00000000, 0x00000000, 0x00000000}},  //   shbe,   ,   ,
  { {0x44240aa5, 0x27e037b8, 0xc0760082, 0x00000000}},  // [c260] _rim_, riin_, _bướm_,
  { {0x442437b9, 0x27e0021e, 0x1a9b0049, 0x00000000}},  //   _sim_, siin_, _פייע,
  { {0xc32a0025, 0xa3e70061, 0x442437ba, 0x00000000}},  //   مكان_, यचं_, _pim_,
  { {0x7c2e0181, 0x7bc600b0, 0x442401f3, 0x00000000}},  //   íbri, nkku, _qim_,
  { {0xd056006b, 0x442437bb, 0x6d5c0010, 0x00000000}},  //   əcək, _vim_, órak,
  { {0x442400c7, 0x3ea005a0, 0x00000000, 0x00000000}},  //   _wim_, _šito_,   ,
  { {0x61ea01a3, 0x69de0085, 0x00000000, 0x00000000}},  //   rnfl, _mmpe,   ,
  { {0x44240093, 0x67360036, 0x67220089, 0x00000000}},  //   _uim_, ncyj, žoju,
  { {0x9f5f00d6, 0x69de0052, 0x00000000, 0x00000000}},  //   cluí_, _ompe,   ,
  { {0x60e7000c, 0x3eb9225c, 0xddaa37bc, 0x00000000}},  //   ármá, ästa_, стил_,
  { {0x67360036, 0x31570049, 0x057700a0, 0x00000000}},  //   kcyj, _זיבן_, הגים_,
  { {0x69de0007, 0x6fd600f3, 0xdb0d00fa, 0x00000000}},  //   _ampe, _عزائ, _joaç,
  { {0x5fa901f5, 0xada601fc, 0x00000000, 0x00000000}},  //   कारल, _надл,   ,
  { {0x7bcf0022, 0x64b500b9, 0x00000000, 0x00000000}},  //   shcu, _hřiš,   ,
  { {0x2905000c, 0x7dc4000a, 0x64b5013e, 0x00000000}},  //   æla_, _lòsk, _křiš,
  { {0x69de0211, 0x24830022, 0x7bc60203, 0x00000000}},  //   _empe, _rpjm_, ckku,
  { {0xe6640080, 0x0587007c, 0x66f4030d, 0x00000000}},  // [c270] етхо, зуем, епту,
  { {0x7bcd000c, 0x673600b4, 0x00000000, 0x00000000}},  //   _hlau, acyj,   ,
  { {0x7bcd010a, 0x6fe800b9, 0x6b96014a, 0x00000000}},  //   _klau, pěch, _yayg,
  { {0xdfc60054, 0x69c70056, 0x00000000, 0x00000000}},  //   _شي_, lkje,   ,
  { {0xdb0d0181, 0xa81b00a1, 0x00000000, 0x00000000}},  //   _doaç, _پتھر_,   ,
  { {0x7dcd0b33, 0x69c737bd, 0x7bcd00d4, 0x00000000}},  //   _músc, nkje, _llau,
  { {0xa6db000c, 0x8464005e, 0x7bcd02e1, 0x00000000}},  //   _veðu, _пъте, _olau,
  { {0xee3901bd, 0xa24700a1, 0x4394007c, 0x00000000}},  //   они_, _فیصل_, _пасс,
  { {0x63a9046a, 0xab5b014a, 0x69c70056, 0x00000000}},  //   _inen, rkül, kkje,
  { {0xf1a403d7, 0x6b96014a, 0x7bcd0006, 0x00000000}},  //   _गोपन, _sayg, _alau,
  { {0x7bcd07eb, 0x63bb0263, 0x9d0b0055, 0x00000000}},  //   _blau, _koun, রশ্ন_,
  { {0x63bb0263, 0x3b0a0407, 0x61e3014a, 0x00000000}},  //   _joun, жемо_, linl,
  { {0x63a901d9, 0x63bb2172, 0x7bc600b0, 0x00000000}},  //   _mnen, _moun, rkku,
  { {0x63bb37be, 0x63a40089, 0x61e3005d, 0x00000000}},  //   _loun, ķini, ninl,
  { {0x7bcd021a, 0x63a9002d, 0xabf6004c, 0x00000000}},  //   _flau, _onen, _очищ,
  { {0x7bcd010f, 0x63bb0bf2, 0x7bc80089, 0x00000000}},  //   _glau, _noun, ījus,
  { {0x61e337bf, 0xfe7900b9, 0xe7df0164, 0x00000000}},  // [c280] kinl, ntů_, _नगरप,
  { {0x0446007c, 0x69de37c0, 0x00000000, 0x00000000}},  //   дежн, _umpe,   ,
  { {0x6d5c0051, 0x63bb00ab, 0x929d0036, 0x00000000}},  //   órai, _boun, _było,
  { {0x63bb0038, 0xfe7900b9, 0x8383007c, 0x00000000}},  //   _coun, ktů_, выше,
  { {0x63bb0068, 0x61e337c1, 0x6e2d0048, 0x00000000}},  //   _doun, finl, _éabh,
  { {0x61e3009f, 0xc0aa0151, 0x63a90883, 0x00000000}},  //   ginl, قابل_, _enen,
  { {0x63bb0038, 0xf1b801d5, 0x64b500b9, 0x00000000}},  //   _foun, _jiġi_, _přiš,
  { {0x63bb0b8b, 0xdb0400f6, 0xa6db01e5, 0x00000000}},  //   _goun, _joió, _geðs,
  { {0xf1b801d5, 0x00000000, 0x00000000, 0x00000000}},  //   _liġi_,   ,   ,
  { {0x7bcd0006, 0x6005000c, 0x61e3064a, 0x00000000}},  //   _slau, dómu, cinl,
  { {0x61fd009f, 0x7bcd010a, 0xd12f031d, 0x00000000}},  //   _ísla, _plau, _ضمن_,
  { {0xaec61020, 0x20140036, 0x00000000, 0x00000000}},  //   _обел, ócić_,   ,
  { {0x501b007b, 0x7bd60065, 0x7bcd0082, 0x00000000}},  //   _וואו, ëzua, _vlau,
  { {0x7c660070, 0xc9840517, 0x00000000, 0x00000000}},  //   _قابل, куси,   ,
  { {0x2d8c1045, 0x69c70056, 0xd7f5007c, 0x00000000}},  //   mede_, rkje, езвы,
  { {0x2d8c018d, 0x69c70292, 0x61e3005d, 0x00000000}},  //   lede_, skje, zinl,
  { {0x63bb00ab, 0x7dcd000c, 0x61e3005a, 0x00000000}},  // [c290] _roun, _húsa, yinl,
  { {0x63bb0038, 0xaa88007a, 0x2d8c1ead, 0x00000000}},  //   _soun, _کنیم_, nede_,
  { {0x63bb00ab, 0xa4390088, 0x61e3013f, 0x00000000}},  //   _poun, їзду_, vinl,
  { {0xe6670265, 0x2d8c1296, 0x7dcd2396, 0x00000000}},  //   _отго, hede_, _músa,
  { {0xa2af001c, 0x2d8c064a, 0x61e30180, 0x00000000}},  //   ंमध्, kede_, tinl,
  { {0x40950517, 0x2d8c016e, 0x63bb0133, 0x00000000}},  //   ерит, jede_, _woun,
  { {0x63bb0263, 0x2d8c1f11, 0x61e3005d, 0x00000000}},  //   _toun, dede_, rinl,
  { {0x61e3005a, 0x63a937c2, 0x00000000, 0x00000000}},  //   sinl, _unen,   ,
  { {0x2ec9007d, 0x2d8c0095, 0x61e3349d, 0x00000000}},  //   िनेत, fede_, pinl,
  { {0x2d8c26e0, 0xc692012e, 0x1c45041f, 0x00000000}},  //   gede_, נאי_, нном,
  { {0x44310036, 0xfe7900b9, 0x3b09013f, 0x00000000}},  //   _juz_, stů_, _ayaq_,
  { {0xeb9a0407, 0x224d0058, 0x7dcd0048, 0x00000000}},  //   чим_, _kwek_, _dúsa,
  { {0x44310489, 0x2d8c37c3, 0x5ac7007c, 0x00000000}},  //   _luz_, bede_, елям_,
  { {0xf2d2341b, 0x2d8c0682, 0x3e790263, 0x00000000}},  //   נעם_, cede_, mèt_,
  { {0x3e7901aa, 0x997d0089, 0xadd608cd, 0x00000000}},  //   lèt_, kāņu_, _רוצח_,
  { {0x224d0045, 0x00000000, 0x00000000, 0x00000000}},  //   _owek_,   ,   ,
  { {0x3e790263, 0x6b8437c4, 0x7e7b00c4, 0x00000000}},  // [c2a0] nèt_, _ibig, ntup,
  { {0xf1b801d5, 0xe4d700a1, 0x4431005a, 0x00000000}},  //   _tiġi_, کومت_, _buz_,
  { {0x290e0010, 0x6aa4000c, 0x224d01a3, 0x00000000}},  //   _áfa_, _hrif, _awek_,
  { {0xe9f9001d, 0x3e790263, 0x7e7b145c, 0x00000000}},  //   _trả_, kèt_, ktup,
  { {0xa2940245, 0xf206005e, 0x2d8c014a, 0x00000000}},  //   талі, няко, yede_,
  { {0xcb13007b, 0x7644005d, 0x3e790173, 0x00000000}},  //   אלד_, mpiy, dèt_,
  { {0x2d8c1c72, 0x6005000c, 0x4fc600ec, 0x00000000}},  //   vede_, jóms, еспа,
  { {0xdfd00054, 0x3e790263, 0x4444065f, 0x00000000}},  //   شيخ_, fèt_, mp_,
  { {0x44440292, 0x2d8c30c7, 0x3ea2000c, 0x00000000}},  //   lp_, tede_, íkt_,
  { {0x6b84010e, 0x44441936, 0xddc00010, 0x00000000}},  //   _abig, op_, ttmű,
  { {0x2d8c068f, 0x44440173, 0x6aa43194, 0x00000000}},  //   rede_, np_, _arif,
  { {0x4444232d, 0x2d8c0059, 0x6aa40016, 0x00000000}},  //   ip_, sede_, _brif,
  { {0x44440061, 0x2d8c001a, 0x5a34022a, 0x00000000}},  //   hp_, pede_, лнят,
  { {0x6aa405d5, 0x7dcd000c, 0x6b8437c5, 0x00000000}},  //   _drif, _húsn, _ebig,
  { {0x444400b5, 0x6d481382, 0x4cde0044, 0x00000000}},  //   jp_, mbda, _নুরু,
  { {0x6aa40190, 0x00000000, 0x00000000, 0x00000000}},  //   _frif,   ,   ,
  { {0xb90802fb, 0x645c0c60, 0x6aa42a9d, 0x00000000}},  // [c2b0] _मे_, _avri, _grif,
  { {0xd056006b, 0x6b840036, 0x6b9d1f7d, 0x00000000}},  //   şbəx, _zbig, ldsg,
  { {0xb4bd0204, 0xf1b801d5, 0x9964007e, 0x00000000}},  //   ेने_, _jiġu_, _стыл,
  { {0x6b9d0c95, 0xf8b60104, 0x3e7901aa, 0x00000000}},  //   ndsg, _ספרי_, yèt_,
  { {0x444437c6, 0x443100bb, 0x6b9d295a, 0x00000000}},  //   ap_, _wuz_, idsg,
  { {0xc0e50113, 0x3e7901aa, 0xe4530445, 0x00000000}},  //   колк, vèt_, _مضر_,
  { {0x44440edc, 0xe1f00647, 0x3e790173, 0x00000000}},  //   cp_, حسن_, wèt_,
  { {0x5ee20055, 0x3e790263, 0x6b9d14c1, 0x00000000}},  //   _পড়ে, tèt_, jdsg,
  { {0x644500ab, 0x3f8d0007, 0x60310089, 0x00000000}},  //   lphi, reeu_, _māmi,
  { {0x3e790263, 0x7e7b0089, 0xe530006b, 0x00000000}},  //   rèt_, rtup, _müğə,
  { {0x7e7b04c8, 0x3e7901aa, 0xcb6a0256, 0x00000000}},  //   stup, sèt_, мане_,
  { {0x6aa421ae, 0xa3d703d7, 0x798e37c7, 0x00000000}},  //   _prif, ाफट_, webw,
  { {0x6ec406b4, 0x444428e5, 0x798e005b, 0x00000000}},  //   _متوق, zp_, tebw,
  { {0x27e20093, 0x200d16e5, 0xdce10036, 0x00000000}},  //   _smkn_, llei_, zglę,
  { {0x44440066, 0x7e6900f8, 0xe9a3025f, 0x00000000}},  //   xp_, lrep, јасп,
  { {0xa2b2001c, 0x6aa437c8, 0x6fde0089, 0x00000000}},  //   _आपल्, _trif, tūci,
  { {0x78a50018, 0x7e690210, 0x645c1a8f, 0x00000000}},  // [c2c0] _erhv, nrep, _svri,
  { {0x08c602dd, 0x69d505c6, 0x44440082, 0x00000000}},  //   _абон, chze, tp_,
  { {0x4444028a, 0x200d37c9, 0x764437ca, 0x00000000}},  //   up_, klei_, spiy,
  { {0x395804bd, 0x444413e2, 0x7e692b84, 0x00000000}},  //   lars_, rp_, krep,
  { {0x4444281b, 0x98b80006, 0x7dc4000a, 0x00000000}},  //   sp_, tarė_, _kòst,
  { {0x39581fb4, 0x444437cb, 0x7e69001a, 0x00000000}},  //   nars_, pp_, drep,
  { {0x645c0243, 0x00000000, 0x00000000, 0x00000000}},  //   _uvri,   ,   ,
  { {0xb4250355, 0x27f21703, 0x00000000, 0x00000000}},  //   _معقو, nnyn_,   ,
  { {0x7e6904d3, 0xb226008b, 0x8fa300ec, 0x00000000}},  //   grep, _амал, рање,
  { {0x20e3001c, 0x22462819, 0x27010082, 0x00000000}},  //   _केवळ_, mpok_, ỗng_,
  { {0x1da6001c, 0x3958009d, 0x6d480006, 0x00000000}},  //   _कोणत, dars_, rbda,
  { {0x7e69008e, 0x200d37cc, 0x7d0a01c3, 0x00000000}},  //   brep, clei_, _vyfs,
  { {0x7e6903fd, 0x6b9d0cf5, 0x248a0145, 0x00000000}},  //   crep, rdsg, _lpbm_,
  { {0x39580089, 0xf1b80066, 0x00000000, 0x00000000}},  //   gars_, _tiġu_,   ,
  { {0xf8071b49, 0xd90f0014, 0x98c4007c, 0x00000000}},  //   вчан, تید_, астл,
  { {0x2d9c37cd, 0x20040149, 0x2d9e37ce, 0x00000000}},  //   _have_, nomi_, ldte_,
  { {0x39580061, 0x2d9c0bd9, 0x97152466, 0x00000000}},  // [c2d0] bars_, _kave_, умац,
  { {0x2d9e0374, 0x68ee002a, 0x7c2d161f, 0x00000000}},  //   ndte_, ándá, _hiar,
  { {0x659401fb, 0x7c2d0020, 0x200437cf, 0x00000000}},  //   раху, _kiar, komi_,
  { {0x2d9c37d0, 0xdb040181, 0x200437d1, 0x00000000}},  //   _lave_, _uniã, jomi_,
  { {0x27e91ff9, 0x20040089, 0x7c2d37d2, 0x00000000}},  //   mian_, domi_, _miar,
  { {0x2d9c027b, 0x27e90971, 0x3f86009d, 0x00000000}},  //   _nave_, lian_, _abou_,
  { {0x7c2d002d, 0x7e690d12, 0x316901df, 0x00000000}},  //   _oiar, wrep, ğaz_,
  { {0x7e69028c, 0x27e9020c, 0x3ea61642, 0x00000000}},  //   trep, nian_, _brot_,
  { {0x2d9c037e, 0x200d0270, 0x51f90077, 0x00000000}},  //   _bave_, rlei_, _знаю_,
  { {0x442d01d6, 0x27e9002d, 0x7cd3006b, 0x00000000}},  //   _hie_, hian_, lərə,
  { {0x1bea0751, 0x27e9033b, 0x39580089, 0x00000000}},  //   едни_, kian_, vars_,
  { {0x442d010a, 0x27e9027e, 0x7c2d0051, 0x00000000}},  //   _jie_, jian_, _ciar,
  { {0x7c2d16ca, 0x27e9020c, 0x442d0412, 0x00000000}},  //   _diar, dian_, _mie_,
  { {0x2d9c2f16, 0x442d046e, 0xddc90087, 0x00000000}},  //   _gave_, _lie_, ltež,
  { {0x39580203, 0x27e90127, 0x7c2d0035, 0x00000000}},  //   rars_, fian_, _fiar,
  { {0x442d37d3, 0xb8dc03d7, 0x27e90169, 0x00000000}},  //   _nie_, _आप_, gian_,
  { {0xe61a0216, 0x39582a1a, 0x26c900e0, 0x00000000}},  // [c2e0] еда_, pars_, gyao_,
  { {0x7c2d1111, 0x27ff2794, 0xdce3014a, 0x00000000}},  //   _ziar, čuna_, _hanı,
  { {0x27e937d4, 0xdd560049, 0x442d0065, 0x00000000}},  //   bian_, רבעט_, _bie_,
  { {0x2ca70020, 0x7c3e00f4, 0x442d0036, 0x00000000}},  //   _mrnd_, _épre, _cie_,
  { {0x442d15d0, 0x41e60ee0, 0xa3b6062e, 0x00000000}},  //   _die_, ліка, जाब_,
  { {0x442d0343, 0x69ce0010, 0x00000000, 0x00000000}},  //   _eie_, nkbe,   ,
  { {0x442d000d, 0x20040b4d, 0x2246012d, 0x00000000}},  //   _fie_, tomi_, spok_,
  { {0x09d102d2, 0x645e0240, 0x2d9c37d5, 0x00000000}},  //   _हत्य, mspi, _save_,
  { {0x7c2d002a, 0x2d9c0056, 0x64410065, 0x00000000}},  //   _riar, _pave_, _çlir,
  { {0x442d02ae, 0x7c2d0544, 0xc693009b, 0x00000000}},  //   _zie_, _siar, צאת_,
  { {0x7c2d0035, 0x225f047c, 0x645e03a1, 0x00000000}},  //   _piar, _zvuk_, nspi,
  { {0x442d0c0d, 0xdce3005a, 0x61ea006b, 0x00000000}},  //   _xie_, _canı, lifl,
  { {0xdce3027d, 0x7c2d1f38, 0x2d9c0006, 0x00000000}},  //   _danı, _viar, _tave_,
  { {0x645e003b, 0x27e913a7, 0x7c2d0036, 0x00000000}},  //   kspi, wian_, _wiar,
  { {0x27e90149, 0x248d0119, 0x7c2d0051, 0x00000000}},  //   tian_, _ćemo_, _tiar,
  { {0x645e0190, 0x69ce00bb, 0x69c000fa, 0x00000000}},  //   dspi, akbe, êmer,
  { {0x27e9020c, 0x645e05b7, 0x00000000, 0x00000000}},  // [c2f0] rian_, espi,   ,
  { {0x442d0a80, 0x6d5a2bd0, 0x27e9020c, 0x00000000}},  //   _sie_, nata, sian_,
  { {0xdce3047f, 0x27e90f7c, 0x442d191c, 0x00000000}},  //   _yanı, pian_, _pie_,
  { {0x6d5a020c, 0xdce3005f, 0xa3df013d, 0x00000000}},  //   hata, _xanı, धों_,
  { {0x442d028c, 0x49b806c6, 0xe29908d6, 0x00000000}},  //   _vie_, _شاید_, тал_,
  { {0x442d0e42, 0x6a6c000c, 0x6b9f002b, 0x00000000}},  //   _wie_, _höfð, _laqg,
  { {0x442d082e, 0x7d1c000c, 0x31580025, 0x00000000}},  //   _tie_, ýrsl, اجهة_,
  { {0x442d01d6, 0x41b500a1, 0x6b9f0066, 0x00000000}},  //   _uie_, _ھمار, _naqg,
  { {0x6d5a29d0, 0x8db501ff, 0x00000000, 0x00000000}},  //   fata, асні,   ,
  { {0x0d820eec, 0x6d5a001e, 0xdce3014a, 0x00000000}},  //   ольн, gata, _sanı,
  { {0x320700ab, 0x6b9f002b, 0x5f950478, 0x00000000}},  //   mony_, _baqg, _виет,
  { {0x8b2605b5, 0x32070652, 0x6d5a0058, 0x00000000}},  //   идне, lony_, aata,
  { {0x6d5a04be, 0x7bdd0065, 0xa3b6007d, 0x00000000}},  //   bata, ërua, जात_,
  { {0x6d5a001a, 0xef18007e, 0x32360049, 0x00000000}},  //   cata, _смі_, יטשן_,
  { {0xdce301f6, 0x9836008b, 0x69ce00bb, 0x00000000}},  //   _tanı, рэгі, rkbe,
  { {0x320737d6, 0x645e0240, 0x69ce00f8, 0x00000000}},  //   hony_, vspi, skbe,
  { {0x1b0d0055, 0x2b4d049a, 0x8af0005f, 0x00000000}},  // [c300] সেবে_, ñece_, _edər,
  { {0x2d851e83, 0x645e01a2, 0xd946003b, 0x00000000}},  //   nfle_, tspi, _њени,
  { {0x645e37d7, 0x3ea9012d, 0x7bc40288, 0x00000000}},  //   uspi, _šatl_, _koiu,
  { {0x6d5a1a92, 0xf77200a6, 0x645e010f, 0x00000000}},  //   zata, _باد_, rspi,
  { {0x6d5a0169, 0x32073510, 0x645e01e7, 0x00000000}},  //   yata, fony_, sspi,
  { {0x64430576, 0x6abb01a2, 0xf8ba0309, 0x00000000}},  //   ínic, äufi, _उपाय,
  { {0x61ea049d, 0x00000000, 0x00000000, 0x00000000}},  //   rifl,   ,   ,
  { {0x6d5a37d8, 0xbfa7007c, 0x201d0016, 0x00000000}},  //   wata, атье_, _chwi_,
  { {0x6d5a1d2e, 0x44380073, 0x2d8506fa, 0x00000000}},  //   tata, _hur_, ffle_,
  { {0x44380710, 0x63a037d9, 0x61ed0051, 0x00000000}},  //   _kur_, _hamn, éalt,
  { {0x6d5a287e, 0xa3ab0316, 0x62820168, 0x00000000}},  //   rata, _कोड_, ltoo,
  { {0x63a20198, 0x443801d5, 0x00000000, 0x00000000}},  //   ndon, _mur_,   ,
  { {0x6d5a170b, 0x62820dd7, 0x4438002d, 0x00000000}},  //   pata, ntoo, _lur_,
  { {0x44380038, 0xa2a70309, 0x6d5a24e5, 0x00000000}},  //   _our_, चित्, qata,
  { {0x4438001f, 0x6d580089, 0x63a201ee, 0x00000000}},  //   _nur_, _ieva, kdon,
  { {0x63a037da, 0x63a20047, 0x3207108d, 0x00000000}},  //   _namn, jdon, zony_,
  { {0x443837db, 0x6d58006c, 0x63a20016, 0x00000000}},  // [c310] _aur_, _keva, ddon,
  { {0x63a20207, 0x6d5837dc, 0x44380056, 0x00000000}},  //   edon, _jeva, _bur_,
  { {0x4438002a, 0xd49b0265, 0x799537dd, 0x00000000}},  //   _cur_, ъра_, mezw,
  { {0x6d5802d5, 0x69c5010f, 0x79950020, 0x00000000}},  //   _leva, _hohe, lezw,
  { {0x7cca005f, 0x69c5008d, 0xa3ab0183, 0x00000000}},  //   lərd, _kohe, _कोण_,
  { {0x7c380c69, 0x79951475, 0x6d58191c, 0x00000000}},  //   _ouvr, nezw, _neva,
  { {0x4438002a, 0x32070046, 0x69c50667, 0x00000000}},  //   _gur_, rony_, _mohe,
  { {0x63a20875, 0xe3b301d8, 0x628201f3, 0x00000000}},  //   cdon, _برس_, btoo,
  { {0x4438001f, 0x6d5800b5, 0x7dcd000c, 0x00000000}},  //   _zur_, _beva, _húsi,
  { {0x6d58011f, 0x7e6202aa, 0x7bc40035, 0x00000000}},  //   _ceva, _dvop, _soiu,
  { {0x6d5837de, 0x7e620320, 0x6bd60025, 0x00000000}},  //   _deva, _evop, متحر,
  { {0x7dcd0df5, 0xe9f9001d, 0x7c380026, 0x00000000}},  //   _músi, _trẻ_, _duvr,
  { {0xed4e0069, 0x69c500b9, 0x00000000, 0x00000000}},  //   _но_, _bohe,   ,
  { {0x69c5041d, 0x6d58049b, 0xceb20104, 0x00000000}},  //   _cohe, _geva, _מיד_,
  { {0x69c5010e, 0xab5b035a, 0x6d4104a5, 0x00000000}},  //   _dohe, rkür, mcla,
  { {0x228001aa, 0x6d580e8c, 0xdc3a0049, 0x00000000}},  //   yòk_, _zeva, _געקר,
  { {0x44380a8d, 0x63a00035, 0x6ff30035, 0x00000000}},  // [c320] _sur_, _ramn, găci,
  { {0x63a0009f, 0x443804b4, 0x63a20066, 0x00000000}},  //   _samn, _pur_, wdon,
  { {0xb8ed08b7, 0x4438013f, 0x69dc0051, 0x00000000}},  //   _শে_, _qur_, mhre,
  { {0x63a207f2, 0x53e50088, 0x8c360049, 0x00000000}},  //   udon, оціа, צטנס_,
  { {0x44380270, 0x69c50009, 0x6d430016, 0x00000000}},  //   _wur_, _yohe, _ofna,
  { {0x4438001e, 0x628237df, 0x9f440048, 0x00000000}},  //   _tur_, rtoo, rimí_,
  { {0x6d5803eb, 0x63a037e0, 0x4438015c, 0x00000000}},  //   _reva, _tamn, _uur_,
  { {0x6d4337e1, 0x232a0745, 0x6d411fce, 0x00000000}},  //   _afna, _боби_, ecla,
  { {0x6d58037e, 0x44260207, 0x7cca005f, 0x00000000}},  //   _peva, mmo_, zərd,
  { {0x44261325, 0xdd9a0216, 0x6d410009, 0x00000000}},  //   lmo_, уши_, gcla,
  { {0x69c5006c, 0x69dc03df, 0x5bb9005e, 0x00000000}},  //   _rohe, dhre, алня_,
  { {0x44261391, 0x6d43000c, 0xddc90035, 0x00000000}},  //   nmo_, _efna, pseş,
  { {0x6d58007f, 0x79950648, 0x69dc0051, 0x00000000}},  //   _teva, tezw, fhre,
  { {0x69dc0b73, 0x2fc601b5, 0x6abb0055, 0x00000000}},  //   ghre, _hoog_, উনলো,
  { {0x58d4004c, 0x79950927, 0x442611d2, 0x00000000}},  //   порт, rezw, kmo_,
  { {0x4426016c, 0x36d50242, 0x69c501a2, 0x00000000}},  //   jmo_, ообр, _wohe,
  { {0x6b8d1ebf, 0x69dc0051, 0x163b0025, 0x00000000}},  // [c330] _ibag, bhre, اسرة_,
  { {0x69dc2a9d, 0x98a301df, 0x6ff30035, 0x00000000}},  //   chre, sajı_, răci,
  { {0x6d9e01d5, 0x6aad000c, 0x07350401, 0x00000000}},  //   _għaż, _hraf, _меню,
  { {0xedb503d7, 0x6d410211, 0x2458007e, 0x00000000}},  //   _अच्छ, zcla, саць_,
  { {0x6b8d0526, 0x601e0065, 0x7cca013f, 0x00000000}},  //   _mbag, këmb, nərb,
  { {0x442616ba, 0x764d0487, 0x7f59002b, 0x00000000}},  //   amo_, mpay, _sewq,
  { {0x6025007e, 0x86fb0044, 0x6b8d1b43, 0x00000000}},  //   одка, _আরিফ_, _obag,
  { {0x7a200039, 0x6aad0026, 0xfe4500e2, 0x00000000}},  //   möte, _oraf, онио,
  { {0xa3b602fb, 0xee3603c8, 0x764d0263, 0x00000000}},  //   जार_, оны_, npay,
  { {0x2708001d, 0x6b8d36c5, 0xb8010044, 0x00000000}},  //   ởng_, _abag, ্ষিত_,
  { {0x6d4137e2, 0x6aad37e3, 0x6b8d0087, 0x00000000}},  //   rcla, _araf, _bbag,
  { {0x6d412ea8, 0xab2a013b, 0xdb040051, 0x00000000}},  //   scla, иона_, _iniú,
  { {0x69dc016d, 0x2b4d008e, 0x6aad0787, 0x00000000}},  //   thre, ñeca_, _craf,
  { {0x6aad018e, 0x442637e4, 0x7a200c49, 0x00000000}},  //   _draf, zmo_, köte,
  { {0x44260e44, 0x75e9005f, 0xe73a358a, 0x00000000}},  //   ymo_, _gözə, иев_,
  { {0xe7370057, 0x69dc01e5, 0x6aad08c8, 0x00000000}},  //   жет_, shre, _fraf,
  { {0x6aad0b25, 0x764d0058, 0x69dc0133, 0x00000000}},  // [c340] _graf, gpay, phre,
  { {0x056605b8, 0x9f4d01c3, 0x00000000, 0x00000000}},  //   івен, fieë_,   ,
  { {0x9f4d01d6, 0x24560014, 0x00000000, 0x00000000}},  //   gieë_, زنشس,   ,
  { {0xccf2009b, 0x442628bc, 0x00000000, 0x00000000}},  //   וכב_, umo_,   ,
  { {0x44260027, 0x25a3002b, 0x764d0009, 0x00000000}},  //   rmo_, _fajl_, cpay,
  { {0x442637e5, 0x7d060046, 0x2fc601c3, 0x00000000}},  //   smo_, ększ, _soog_,
  { {0xfd07026c, 0xd467007c, 0x2fc601d6, 0x00000000}},  //   _آج_, _мире_, _poog_,
  { {0xef190046, 0xb4d60309, 0xe45300a1, 0x00000000}},  //   leży_, िनी_, _آہنگ,
  { {0x6fdc00f4, 0xa3d7007d, 0x248d012d, 0x00000000}},  //   _néce, िसर_, _ćemi_,
  { {0x6b8d0207, 0x06cd0044, 0x6aad0065, 0x00000000}},  //   _sbag, _রেডি, _rraf,
  { {0x6aad012d, 0x601e0023, 0x2fc600d9, 0x00000000}},  //   _sraf, rëmb, _toog_,
  { {0x6aad0035, 0x764d00e0, 0x6ff30035, 0x00000000}},  //   _praf, ypay, făcu,
  { {0x6fe80046, 0x6448009d, 0x6aad006b, 0x00000000}},  //   jści, _édif, _qraf,
  { {0x6fdc028c, 0x1e33007e, 0x7c3e009d, 0x00000000}},  //   _déce, _жніў, _épro,
  { {0x6fe80036, 0x6b8d0066, 0x00000000, 0x00000000}},  //   eści, _tbag,   ,
  { {0x6aad018e, 0x386d0209, 0x764d02d1, 0x00000000}},  //   _traf, čer_, tpay,
  { {0x6aad37e6, 0xf402001a, 0x00000000, 0x00000000}},  // [c350] _uraf, inţă_,   ,
  { {0x764d013f, 0xdcea014a, 0x7a2001a2, 0x00000000}},  //   rpay, _hafı, töte,
  { {0xd3710379, 0x764d0022, 0x00000000, 0x00000000}},  //   فها_, spay,   ,
  { {0x3cfb0049, 0xf3670088, 0x9f4d0007, 0x00000000}},  //   סלאנ, ітен, rieë_,
  { {0x645a002b, 0xd3460014, 0x9f4d01d6, 0x00000000}},  //   _ħtie, سیله_, sieë_,
  { {0x6145371d, 0x1a9c0049, 0xe57004e8, 0x00000000}},  //   чека, יידע, _لطف_,
  { {0xe0d1009e, 0x00000000, 0x00000000, 0x00000000}},  //   عزت_,   ,   ,
  { {0xa3b20061, 0x78fc0049, 0x00000000, 0x00000000}},  //   _झोप_, יפוו,   ,
  { {0xfe710025, 0x00000000, 0x00000000, 0x00000000}},  //   ردة_,   ,   ,
  { {0x6fdc028c, 0xee360f62, 0x00000000, 0x00000000}},  //   _réce, янь_,   ,
  { {0xcb0900b6, 0x1d09017a, 0xfbdf0007, 0x00000000}},  //   _על_, сени_, fhê_,
  { {0x2904014a, 0x6fe80036, 0x00000000, 0x00000000}},  //   şmak_, yści,   ,
  { {0x7dcd1441, 0xeb970242, 0x200d3143, 0x00000000}},  //   _búst, чия_, moei_,
  { {0xa3b20204, 0x200d37e7, 0xaec4007e, 0x00000000}},  //   _झोन_, loei_, _юбіл,
  { {0x291e0039, 0x00000000, 0x00000000, 0x00000000}},  //   åta_,   ,   ,
  { {0xfbdf00c4, 0x75e00010, 0x2d820010, 0x00000000}},  //   chê_, _közg, őket_,
  { {0x7cca006b, 0x00000000, 0x00000000, 0x00000000}},  // [c360] məra,   ,   ,
  { {0x499400a1, 0x7cca006b, 0x6fe80036, 0x00000000}},  //   _تیسر, ləra, rści,
  { {0xc953012f, 0xb4d60164, 0xd9100167, 0x00000000}},  //   _אמת_, िने_, _شیر_,
  { {0xa3e60754, 0x3eaf0129, 0x73fc0044, 0x00000000}},  //   यों_, _orgt_, েষ্ট_,
  { {0x27e037e8, 0x6fd50802, 0x74130014, 0x00000000}},  //   mhin_, _václ, روها,
  { {0x27e0011c, 0xc297007e, 0x7c240058, 0x00000000}},  //   lhin_, якіх_, _lhir,
  { {0x0219007e, 0x7c240016, 0x76490095, 0x00000000}},  //   ціць_, _ohir, _çeyr,
  { {0xdfd00054, 0x27e00dc7, 0xb4fb009b, 0x00000000}},  //   ئية_, nhin_, _הפלי,
  { {0x4424010f, 0x27e0021e, 0xa1360025, 0x00000000}},  //   _ihm_, ihin_, _فراش,
  { {0x27ff089f, 0x657e0082, 0x7c240095, 0x00000000}},  //   čuni_, ngph, _ahir,
  { {0x7dcd1ad4, 0x2b4d008e, 0x442404eb, 0x00000000}},  //   _rúst, ñeco_, _khm_,
  { {0xdddb00ca, 0xddc9001a, 0xafe31764, 0x00000000}},  //   rtuš, treţ, _похл,
  { {0x27e00065, 0x9b2400ed, 0xdddb1288, 0x00000000}},  //   dhin_, ефрл, stuš,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69d5010f, 0x27e0010f, 0xa8490439, 0x00000000}},  //   rkze, fhin_, تلزم_,
  { {0x2d8c049b, 0x1d1700a0, 0x27e02264, 0x00000000}},  //   lfde_, _מקור_, ghin_,
  { {0xba6b0025, 0x2d8c040f, 0x00000000, 0x00000000}},  // [c370] _احبك_, ofde_,   ,
  { {0x06140057, 0x44240b9a, 0x200d0032, 0x00000000}},  //   едую, _ahm_, zoei_,
  { {0xd9180b87, 0xf8d1013d, 0xdb160173, 0x00000000}},  //   _нью_, _हथिय, _anyè,
  { {0x27e02b12, 0x7c240065, 0xd8280245, 0x00000000}},  //   chin_, _xhir, _ніяк_,
  { {0x46a4007e, 0x442400d4, 0x59d1007d, 0x00000000}},  //   _заўв, _dhm_, _सकार,
  { {0x644a1195, 0xe7d50180, 0x76ba009b, 0x00000000}},  //   ífic, _yığı, _ומשפ,
  { {0x44240145, 0x69be0061, 0x200d0032, 0x00000000}},  //   _fhm_, शाती, toei_,
  { {0x2d8c00c7, 0x00000000, 0x00000000, 0x00000000}},  //   efde_,   ,   ,
  { {0xc91a02fb, 0x200d3143, 0x236d0059, 0x00000000}},  //   _धर्म_, roei_, _idej_,
  { {0x7c2403ef, 0x7dcd37e9, 0x27e00065, 0x00000000}},  //   _shir, _rúss, zhin_,
  { {0xa3b8026c, 0xddc90c1e, 0x601e0065, 0x00000000}},  //   _ظاہر_, greš, sëma,
  { {0x307801b7, 0x2d8c01d6, 0x00000000, 0x00000000}},  //   _رحمة_, afde_,   ,
  { {0xbdf8026c, 0xbea5007e, 0x3ce900b9, 0x00000000}},  //   _کرنا_, _цалк, _živě_,
  { {0x7c240142, 0x75e00047, 0xdb060010, 0x00000000}},  //   _whir, _köze, ndké,
  { {0x27e00038, 0x7c24166d, 0xd7f20025, 0x00000000}},  //   thin_, _thir, نكس_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x27e0191f, 0x00000000, 0x00000000, 0x00000000}},  // [c380] rhin_,   ,   ,
  { {0x27e0008d, 0x6fdc00f4, 0x44240022, 0x00000000}},  //   shin_, _méca, _shm_,
  { {0xe73a0265, 0x799c0016, 0x27e006fa, 0x00000000}},  //   _мен_, merw, phin_,
  { {0xd36f0054, 0x799c010f, 0x68f90010, 0x00000000}},  //   لهم_, lerw, őadó,
  { {0x91e60069, 0xddc90db7, 0x224d2a53, 0x00000000}},  //   моде, zreš, _ctek_,
  { {0x799c1091, 0x77642daf, 0xb0a90164, 0x00000000}},  //   nerw, laix, किंग,
  { {0x6b8401a8, 0xe366003b, 0x442437ea, 0x00000000}},  //   _ocig, _окви, _thm_,
  { {0x799c00ab, 0x44240082, 0x77640129, 0x00000000}},  //   herw, _uhm_, naix,
  { {0xcebb006b, 0xe2460558, 0x799c0b28, 0x00000000}},  //   _şərh_, _آخري, kerw,
  { {0x7dcd0219, 0x6fdc2d7f, 0xddc90c8a, 0x00000000}},  //   _búsq, _déca, treš,
  { {0x057700b6, 0x4444006b, 0x75e037eb, 0x00000000}},  //   וגים_, nq_, _közb,
  { {0x69de00f4, 0x6fd50062, 0x6fdc0068, 0x00000000}},  //   _alpe, _nách, _féca,
  { {0x3ead01ee, 0x753c0036, 0x00000000, 0x00000000}},  //   cvet_, _ogrz,   ,
  { {0xa3ab03d7, 0x20140046, 0x2baf0061, 0x00000000}},  //   _कोई_, ścią_, _जोरा,
  { {0x6d4a0066, 0x2905014a, 0x00000000, 0x00000000}},  //   _iffa, çla_,   ,
  { {0xdc2b007a, 0x290501d5, 0xf7730076, 0x00000000}},  //   _بسته_, ħla_, ضار_,
  { {0x644e0580, 0x444401d5, 0x6b9d0089, 0x00000000}},  // [c390] _atbi, eq_, mesg,
  { {0x645c018e, 0x7dc401aa, 0x6b9d005b, 0x00000000}},  //   _bwri, _pòsy, lesg,
  { {0x776409f7, 0x79850093, 0x645c0016, 0x00000000}},  //   baix, _ichw, _cwri,
  { {0x644100f4, 0x77641396, 0x6b9d3380, 0x00000000}},  //   _élim, caix, nesg,
  { {0x224d0066, 0x6d4a0bdc, 0x44440146, 0x00000000}},  //   _qtek_, _offa, aq_,
  { {0x7ff5026c, 0x27ff10b9, 0x645c0016, 0x00000000}},  //   کستا, čunu_, _fwri,
  { {0x44441339, 0x6b9d02e1, 0x798500e7, 0x00000000}},  //   cq_, kesg, _mchw,
  { {0x799c0036, 0x6d4a37ec, 0x7bcd238e, 0x00000000}},  //   zerw, _affa, _noau,
  { {0x63bb001a, 0xcdf50a78, 0x799c004a, 0x00000000}},  //   _inun, ечны, yerw,
  { {0x7bdf0211, 0x3ead0030, 0x63a90678, 0x00000000}},  //   _alqu, rvet_, _haen,
  { {0x3ead0059, 0x63a90217, 0x799c1e7c, 0x00000000}},  //   svet_, _kaen, verw,
  { {0xff5301f7, 0x6d4a0b73, 0x7bcd00d4, 0x00000000}},  //   _شخص_, _effa, _coau,
  { {0x63a937ed, 0x799c010f, 0x7cca006b, 0x00000000}},  //   _maen, terw, lərl,
  { {0x63a9006c, 0x69c1006c, 0x7bdf004a, 0x00000000}},  //   _laen, ölep, _elqu,
  { {0x799c37ee, 0x63bb0279, 0x98aa005d, 0x00000000}},  //   rerw, _onun, tabı_,
  { {0x07a301fb, 0x63a937ef, 0x799c0036, 0x00000000}},  //   ласн, _naen, serw,
  { {0xd7070175, 0x7cca006b, 0x6aa400e7, 0x00000000}},  // [c3a0] енте_, hərl, _usif,
  { {0xe617261d, 0x2a570097, 0xf0a50011, 0x00000000}},  //   еду_, _רבין_, _đàng_,
  { {0x6fd5008e, 0x63a9005b, 0x628b01c3, 0x00000000}},  //   _tách, _baen, etgo,
  { {0x6fd50489, 0x65650487, 0x63a90544, 0x00000000}},  //   _fáci, aahh, _caen,
  { {0xa3e602d2, 0x7985018e, 0xdbc737f0, 0x00000000}},  //   योग_, _ychw, _tööl,
  { {0x63bb0035, 0x645c0016, 0x7cca006b, 0x00000000}},  //   _enun, _twri, fərl,
  { {0x66030822, 0x644e0073, 0x63a903c5, 0x00000000}},  //   _спра, _utbi, _faen,
  { {0xb4be001c, 0x291a11eb, 0x3a3a37f1, 0x00000000}},  //   ेही_, _mypa_, _lipp_,
  { {0x25aa016c, 0x628b02c2, 0x43750098, 0x00000000}},  //   _kabl_, ctgo, _јуст,
  { {0x7cca005f, 0x63a90059, 0x00000000, 0x00000000}},  //   bərl, _zaen,   ,
  { {0x67fb00b0, 0x63a930c3, 0x7fd60088, 0x00000000}},  //   näjä, _yaen, _піді,
  { {0x7985001f, 0x6805007f, 0x00000000, 0x00000000}},  //   _schw, kėda,   ,
  { {0x6b9d022b, 0xd00f0025, 0xdd92023c, 0x00000000}},  //   resg, _الن_, _موش_,
  { {0x3ea60052, 0x6805007f, 0xa2c10061, 0x00000000}},  //   _isot_, dėda, लमत्,
  { {0x2d9e006c, 0x4e17009b, 0x3a3a2442, 0x00000000}},  //   mete_, _רחוב_, _dipp_,
  { {0x6fdc009d, 0x7c8302dc, 0x7bdf06d2, 0x00000000}},  //   _méco, _суше, _ulqu,
  { {0x4735007e, 0xb8c8013d, 0x65650c2c, 0x00000000}},  // [c3b0] тнас, _खै_, tahh,
  { {0x7cca006b, 0x395401dc, 0x79850036, 0x00000000}},  //   yərl, časí_, _uchw,
  { {0xf1bf001d, 0xe1f10014, 0x63a937f2, 0x00000000}},  //   _đá_, یست_, _paen,
  { {0xe8d600b6, 0x2d9e006c, 0xa85600b3, 0x00000000}},  //   _יותר_, hete_, _שירה_,
  { {0x2d9e1067, 0x63a9006c, 0xa2c10061, 0x00000000}},  //   kete_, _vaen, लमध्,
  { {0x2d9e045e, 0x4b38007b, 0xf9940049, 0x00000000}},  //   jete_, ׂראל_, ָרק_,
  { {0x628b00b5, 0x91e2004c, 0x3ea600e0, 0x00000000}},  //   stgo, роще, _asot_,
  { {0x6fdc028c, 0x7e69006c, 0x63bb0b48, 0x00000000}},  //   _déco, tsep, _unun,
  { {0x6fdc0df9, 0x2d9e0b24, 0x7f49009d, 0x00000000}},  //   _técn, fete_, rceq,
  { {0x7e6904cb, 0x6fdc009d, 0x3f860035, 0x00000000}},  //   rsep, _féco, _ecou_,
  { {0x7e6914ac, 0x3ea60089, 0x2b4b0022, 0x00000000}},  //   ssep, _esot_, fccc_,
  { {0xe73f0011, 0x3a3a0022, 0x316701a2, 0x00000000}},  //   _ngõ_, _sipp_, lanz_,
  { {0x2d9e277a, 0x442f11c7, 0x3a3a0145, 0x00000000}},  //   bete_, img_, _pipp_,
  { {0x2d9e0428, 0x316701a2, 0x00000000, 0x00000000}},  //   cete_, nanz_,   ,
  { {0xfce50256, 0x98b80089, 0x00000000, 0x00000000}},  //   _шоко, mbrī_,   ,
  { {0x2b4b0061, 0x61e1010e, 0x00000000, 0x00000000}},  //   cccc_, _llll,   ,
  { {0x36670265, 0x3a3a37f3, 0x3a260794, 0x00000000}},  // [c3c0] като_, _tipp_, _имиг,
  { {0x67fb021e, 0x7a7b0097, 0x68050006, 0x00000000}},  //   täjä, _קריס, rėda,
  { {0x80a1013d, 0x00000000, 0x00000000, 0x00000000}},  //   _कैले,   ,   ,
  { {0xdb04076a, 0x69dc0190, 0x6fdc12a3, 0x00000000}},  //   _unió, lkre, _réco,
  { {0x6fdc00f4, 0x2d9e09e5, 0x25aa0016, 0x00000000}},  //   _décl, yete_, _tabl_,
  { {0xa13c0089, 0x6fd500fa, 0x442f06c0, 0x00000000}},  //   _kaķi, _mácu, amg_,
  { {0x75e0014a, 0x2ca70082, 0x00000000, 0x00000000}},  //   _göza, _nsnd_,   ,
  { {0x2d870051, 0x2d9e0007, 0x08770049, 0x00000000}},  //   _acne_, wete_, דעקט_,
  { {0x2d9e008d, 0x7d1d005f, 0x69dc17a9, 0x00000000}},  //   tete_, əssi, kkre,
  { {0xf77f014a, 0x00000000, 0x00000000, 0x00000000}},  //   _ilçe_,   ,   ,
  { {0x2d9e0eb5, 0xdfd200a2, 0x69dc0036, 0x00000000}},  //   rete_, _پيش_, dkre,
  { {0x40ab04e1, 0x8fa600ed, 0x10690025, 0x00000000}},  //   _زخمی_, _јаде, _أحلى_,
  { {0x2d9e1733, 0x6ab60016, 0x69dc0146, 0x00000000}},  //   pete_, _cryf, fkre,
  { {0x442f0061, 0xc333034e, 0x6ab601d6, 0x00000000}},  //   zmg_, יור_, _dryf,
  { {0xd83b007e, 0x6d5a0023, 0x7c86007c, 0x00000000}},  //   дэа_, mbta, _руле,
  { {0x5fc50061, 0x6d5a0006, 0x3f84008a, 0x00000000}},  //   वायल, lbta, ngmu_,
  { {0x6ab637f4, 0x6fdc00f4, 0x66e400e2, 0x00000000}},  // [c3d0] _gryf, _récl, аоѓа,
  { {0x69dc0210, 0x00000000, 0x00000000, 0x00000000}},  //   ckre,   ,   ,
  { {0xdb1d0004, 0x601e0065, 0x316701de, 0x00000000}},  //   rksõ, rëmj, vanz_,
  { {0x2458008b, 0x7bdd05e0, 0x00000000, 0x00000000}},  //   таць_, nksu,   ,
  { {0xe3b0007a, 0x81ac0044, 0x316701a2, 0x00000000}},  //   ترل_, গান_, tanz_,
  { {0x6fd500dc, 0xbbd00204, 0x2fcf0026, 0x00000000}},  //   _láct, _हक्क, _sogg_,
  { {0x26100061, 0x51840088, 0x316701a2, 0x00000000}},  //   तकरी_, руча, ranz_,
  { {0xfe7900b9, 0xa3ab013d, 0x7bdd00d9, 0x00000000}},  //   trů_, _कोच_, jksu,
  { {0xee390265, 0x327900a1, 0x00000000, 0x00000000}},  //   нни_, _سماج_,   ,
  { {0x2b9e0082, 0x00000000, 0x00000000, 0x00000000}},  //   _ắc_,   ,   ,
  { {0x90551606, 0xd084007c, 0x00000000, 0x00000000}},  //   _свец, _вычи,   ,
  { {0x50da0049, 0x00000000, 0x00000000, 0x00000000}},  //   _אקעא,   ,   ,
  { {0xf4120049, 0x00000000, 0x00000000, 0x00000000}},  //   מפט_,   ,   ,
  { {0x6fd500c4, 0x7bdd109a, 0x00000000, 0x00000000}},  //   _vácu, aksu,   ,
  { {0xdd8e03ec, 0xdb0400c4, 0x6fd5004a, 0x00000000}},  //   _روي_, _baiã, _fáct,
  { {0x69dc0056, 0x61f8037e, 0xad1a0097, 0x00000000}},  //   skre, zivl, _אוצר,
  { {0x2d8537f5, 0x857a003b, 0x25a101a2, 0x00000000}},  // [c3e0] ogle_, есет_, fehl_,
  { {0x2d850038, 0x2904006b, 0xe9a6003b, 0x00000000}},  //   ngle_, şmaq_, _саоп,
  { {0xdcea0521, 0x61f8032e, 0x4ad8009e, 0x00000000}},  //   ćiće, vivl, _ساکھ_,
  { {0xb5fb00b9, 0xa4f40061, 0x130a0a78, 0x00000000}},  //   _svát, _आधीच_, нней_,
  { {0x9f440065, 0x61f8006b, 0x00000000, 0x00000000}},  //   shmë_, tivl,   ,
  { {0x15430517, 0xf1260088, 0xfaff01c3, 0x00000000}},  //   _герм, льйо, daël_,
  { {0x7cca013f, 0x61f804eb, 0x64430048, 0x00000000}},  //   rərk, rivl, ínit,
  { {0x4fd4007c, 0x3eca003b, 0x00000000, 0x00000000}},  //   ржит, ећом_,   ,
  { {0x7e7b0292, 0x63a205a8, 0x7306005e, 0x00000000}},  //   grup, meon, _спаз,
  { {0x7cca0163, 0x211a0054, 0x27130011, 0x00000000}},  //   ləri, _كتاب_, ệng_,
  { {0x4c94007c, 0x7c6601b7, 0xdb04000c, 0x00000000}},  //   шинс, داخل, _snið,
  { {0x63a20061, 0x201f0181, 0x7e7b06c2, 0x00000000}},  //   neon, clui_, brup,
  { {0x7e7b10c9, 0x7dd600e5, 0x00000000, 0x00000000}},  //   crup, _bâst,   ,
  { {0x7cca005f, 0x63a20048, 0xcee900a1, 0x00000000}},  //   həri, heon, _جرمن_,
  { {0x6fd5008e, 0xe9190088, 0x63a201d6, 0x00000000}},  //   _táct, тові_, keon,
  { {0xb88600c4, 0x0ea8013d, 0x69c800f8, 0x00000000}},  //   _suíç, _कनाड, öder,
  { {0x63a209f4, 0x7c2d002d, 0x6fc50204, 0x00000000}},  // [c3f0] deon, _ihar, वातं,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7c2d09f5, 0x7cca006b, 0x06d60044, 0x00000000}},  //   _khar, fəri, _সেদি,
  { {0x43950816, 0x7c2d0003, 0x63a2009d, 0x00000000}},  //   радс, _jhar, geon,
  { {0x7c2d37f6, 0x27e90051, 0x75e00010, 0x00000000}},  //   _mhar, mhan_, _közl,
  { {0x27e9006a, 0x867a009b, 0xf67a00a3, 0x00000000}},  //   lhan_, _ברשו, _באשמ,
  { {0x7c2d37f7, 0xc0e50242, 0x7cca006b, 0x00000000}},  //   _ohar, ройк, bəri,
  { {0x7e7b0190, 0x27e900b0, 0x201f001a, 0x00000000}},  //   trup, nhan_, ului_,
  { {0x6fdc009d, 0x64470020, 0xdce10089, 0x00000000}},  //   _méch, _huji, dalā,
  { {0x7e7b070e, 0x6447000b, 0x4d65003b, 0x00000000}},  //   rrup, _kuji, шков,
  { {0x7c2d37f8, 0x1d090751, 0x442d0011, 0x00000000}},  //   _bhar, тени_, _khe_,
  { {0x6447000b, 0x443f001a, 0xca29009b, 0x00000000}},  //   _muji, _jiu_, _חם_,
  { {0xaa4601fb, 0x7c2d1ff1, 0xfc490011, 0x00000000}},  //   регл, _dhar, _bậc_,
  { {0x442d0181, 0x7cca006b, 0x2fcd0091, 0x00000000}},  //   _lhe_, zəri, ljeg_,
  { {0x6d430006, 0x7a20010f, 0xa967013b, 0x00000000}},  //   _igna, nöti, риса_,
  { {0x27e90319, 0x7c2d37f9, 0x290c01d5, 0x00000000}},  //   ghan_, _ghar, ħda_,

  { {0x6fdc00f4, 0x645537fa, 0xe61a0ab6, 0x00000000}},  // [c400] _déch, _atzi, вда_,
  { {0x75e0038c, 0x056700b9, 0x6e210082, 0x00000000}},  //   _gözl, říně_, nllb,
  { {0xb97b00b6, 0x8506004b, 0x766300b9, 0x00000000}},  //   _בניי, جوان, _čtyř,
  { {0x442d05d3, 0x27e92b15, 0x443f0129, 0x00000000}},  //   _che_, chan_, _ciu_,
  { {0x442d048a, 0x443f04bd, 0x31c6005e, 0x00000000}},  //   _dhe_, _diu_, искв,
  { {0xc569025a, 0x63a201ee, 0x442d01a2, 0x00000000}},  //   _محفل_, seon, _ehe_,
  { {0x443f001a, 0x7e620022, 0x92d60044, 0x00000000}},  //   _fiu_, _swop, াছে_,
  { {0x27e0021e, 0x06cd0055, 0x7e620263, 0x00000000}},  //   nkin_, _রেটি, _pwop,
  { {0x41aa358a, 0x27e037fb, 0xf4020035, 0x00000000}},  //   _иван_, ikin_, riţă_,
  { {0x7c2d0038, 0x2d8a014a, 0x644020bb, 0x00000000}},  //   _shar, übe_, _himi,
  { {0xa5b70049, 0x644137fc, 0x2702013d, 0x00000000}},  //   בליק_, _élit, लपुर_,
  { {0x75e001f6, 0xcfd00044, 0x7e6237fd, 0x00000000}},  //   _sözl, ়োজন, _twop,
  { {0x644001ca, 0x6fdc04ad, 0x6d5c014a, 0x00000000}},  //   _mimi, _réch, ırab,
  { {0x27e0022b, 0x6fdc009d, 0x27e90058, 0x00000000}},  //   ekin_, _séch, whan_,
  { {0x6c840025, 0x27e90051, 0x98480265, 0x00000000}},  //   _العم, than_, ията_,
  { {0x644037fe, 0x7c2d2367, 0xf7730025, 0x00000000}},  //   _nimi, _uhar, غاز_,
  { {0x443f0129, 0x27e915df, 0x06cd0044, 0x00000000}},  // [c410] _riu_, rhan_, _রেজি,
  { {0x442d0038, 0x6fdc37ff, 0x27e93800, 0x00000000}},  //   _she_, _déci, shan_,
  { {0xf8b1007a, 0x27e9063c, 0x443f0198, 0x00000000}},  //   _عکس_, phan_, _piu_,
  { {0x27e01241, 0x98a1001d, 0x644721f9, 0x00000000}},  //   ckin_, _nghĩ_, _vuji,
  { {0x443f3801, 0x479a009b, 0x442d2d4d, 0x00000000}},  //   _viu_, _גירס, _vhe_,
  { {0x64472a0a, 0x764d006b, 0x442d00e0, 0x00000000}},  //   _tuji, mqay, _whe_,
  { {0x442d2735, 0x6455002d, 0xd178007e, 0x00000000}},  //   _the_, _utzi, рсіі_,
  { {0x64400006, 0x91780011, 0x00000000, 0x00000000}},  //   _gimi, _với_,   ,
  { {0xfe710025, 0x6d4300e0, 0xa1590900, 0x00000000}},  //   أدب_, _pgna, _базу_,
  { {0x27e0022b, 0x3f770011, 0x61ea01a2, 0x00000000}},  //   zkin_, ểu_, chfl,
  { {0x27e00052, 0xd4790049, 0xcb6a0269, 0x00000000}},  //   ykin_, װאָל, лане_,
  { {0x6b8d00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _ccag,   ,   ,
  { {0xdfb80137, 0x6d4300e0, 0x00000000, 0x00000000}},  //   _خالص_, _tgna,   ,
  { {0x6fdc00f4, 0x6d43006a, 0xed5610d8, 0x00000000}},  //   _réci, _ugna, _лош_,
  { {0x27e0021e, 0xc8b50783, 0x6aad0026, 0x00000000}},  //   tkin_, осты, _esaf,
  { {0x27e01241, 0x30da0049, 0xf77f00f6, 0x00000000}},  //   ukin_, אַמע, _plça_,
  { {0x27e000b0, 0x64400207, 0x7bc4011c, 0x00000000}},  // [c420] rkin_, _rimi, _iniu,
  { {0xc9aa0bba, 0xdce30c8a, 0x00000000, 0x00000000}},  //   _свое_, _lenč,   ,
  { {0xc7a6017a, 0x64403802, 0x7bd6014a, 0x00000000}},  //   _линк, _pimi, _koyu,
  { {0xdb0400c4, 0x320700b4, 0x00000000, 0x00000000}},  //   _caiç, enny_,   ,
  { {0x6440027b, 0x9f91000c, 0xe29600ed, 0x00000000}},  //   _vimi, _ráð_, среќ,
  { {0xd46a06b4, 0x00000000, 0x00000000, 0x00000000}},  //   _محرم_,   ,   ,
  { {0x64400585, 0x00000000, 0x00000000, 0x00000000}},  //   _timi,   ,   ,
  { {0xa85700b6, 0x64400cc7, 0x61ea0253, 0x00000000}},  //   זיקה_, _uimi, shfl,
  { {0xdce3012d, 0x437500e2, 0x00000000, 0x00000000}},  //   _denč, _фуст,   ,
  { {0x6b8d3803, 0x2d990010, 0x9f44004a, 0x00000000}},  //   _scag, ősen_, timó_,
  { {0x7bd6047f, 0x25f0013d, 0x459b0049, 0x00000000}},  //   _boyu, _इतनी_, נסטע,
  { {0x7bd6008e, 0xac1916c1, 0x0ed800a1, 0x00000000}},  //   _coyu, рому_, _پاؤں_,
  { {0xa3d0007d, 0x7bd6019a, 0x00000000, 0x00000000}},  //   _वचन_, _doyu,   ,
  { {0x2d570057, 0x00000000, 0x00000000, 0x00000000}},  //   _лишь_,   ,   ,
  { {0xfc490011, 0x06d60044, 0x6805007f, 0x00000000}},  //   _hận_, _সেলি, lėdi,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6aad0020, 0x9f4600d9, 0x00000000, 0x00000000}},  // [c430] _usaf, _aloë_,   ,
  { {0x9967041f, 0xfc490082, 0x00000000, 0x00000000}},  //   _утил, _mận_,   ,
  { {0xfc490082, 0x69c5112b, 0x00000000, 0x00000000}},  //   _lận_, _inhe,   ,
  { {0x7cca006b, 0x321e1c10, 0x61fa01a2, 0x00000000}},  //   lərs, _akty_, _amtl,
  { {0x3abc0049, 0xdce33804, 0x00000000, 0x00000000}},  //   ָמונ, _renč,   ,
  { {0xd4e70d99, 0x51870057, 0x95cb07e1, 0x00000000}},  //   _люби, суда, _сума_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x403200ed, 0xb0680025, 0xfc490011, 0x00000000}},  //   мејс, حصول_, _bận_,
  { {0xdce311e4, 0x6006008b, 0xfc490011, 0x00000000}},  //   _venč, ўным_, _cận_,
  { {0x7bd60279, 0x00000000, 0x00000000, 0x00000000}},  //   _soyu,   ,   ,
  { {0x2d8e0009, 0xddc92dff, 0x2cae0062, 0x00000000}},  //   _dcfe_, prež, _csfd_,
  { {0x7bd6005f, 0x69c50016, 0xeaba004d, 0x00000000}},  //   _qoyu, _anhe, айм_,
  { {0x81ac0044, 0x201800fa, 0x00000000, 0x00000000}},  //   গার_, _íria_,   ,
  { {0xfce50373, 0xed5904b6, 0xa9670478, 0x00000000}},  //   _моло, _ток_, жира_,
  { {0xd94301fc, 0x186a02dc, 0x7bd63805, 0x00000000}},  //   дери, раби_, _toyu,
  { {0x69c5063b, 0x7bc4001a, 0x13b10044, 0x00000000}},  //   _enhe, _uniu, ছাড়,
  { {0x2fc00051, 0x00000000, 0x00000000, 0x00000000}},  // [c440] _óige_,   ,   ,
  { {0x6fdc008e, 0x7c263806, 0x75e00010, 0x00000000}},  //   _héct, llkr, _közi,
  { {0xdd7a007b, 0xfecf0044, 0xb8ff0044, 0x00000000}},  //   שטעל, িনিধ, _দে_,
  { {0x03260517, 0xdc8c0049, 0x00000000, 0x00000000}},  //   оден, רװאָ,   ,
  { {0xdc370049, 0x7791025a, 0x81b30044, 0x00000000}},  //   קאנט_, _سیلا, টান_,
  { {0x845a0545, 0x91e301ab, 0x7c2601a2, 0x00000000}},  //   _врат_, моче, hlkr,
  { {0x7cca006b, 0x00000000, 0x00000000, 0x00000000}},  //   hərr,   ,   ,
  { {0x645e00b0, 0x30170025, 0x6fdc0325, 0x00000000}},  //   mppi, يتية_, _néct,
  { {0x44260016, 0x3eaf0082, 0x00000000, 0x00000000}},  //   mlo_, _csgt_,   ,
  { {0x4426051b, 0xfc49001d, 0x6fdc00f4, 0x00000000}},  //   llo_, _vận_, _récu,
  { {0x6fdc0be0, 0xa3ae01f5, 0x44260207, 0x00000000}},  //   _sécu, _कसा_, olo_,
  { {0x44261062, 0xfc490011, 0x7a200010, 0x00000000}},  //   nlo_, _tận_, zött,
  { {0x44262346, 0x7cca006b, 0x00000000, 0x00000000}},  //   ilo_, tərs,   ,
  { {0x9e65007a, 0x44263807, 0x6fdc009d, 0x00000000}},  //   _راهن, hlo_, _vécu,
  { {0x628200bb, 0x7cca006b, 0xdcf80095, 0x00000000}},  //   hroo, rərs, _tavı,
  { {0x62823808, 0x44260107, 0x7df901dc, 0x00000000}},  //   kroo, jlo_, yňsk,
  { {0x44260428, 0xdce3001e, 0x7a200010, 0x00000000}},  // [c450] dlo_, _ienā, tött,
  { {0x44260211, 0x2d8c0374, 0x628200ab, 0x00000000}},  //   elo_, ngde_, droo,
  { {0x2fc60091, 0x321c0161, 0x2d8c2a27, 0x00000000}},  //   _onog_, dovy_, igde_,
  { {0x44260119, 0x00000000, 0x00000000, 0x00000000}},  //   glo_,   ,   ,
  { {0xa75600b6, 0x62820112, 0x59df0316, 0x00000000}},  //   _משרד_, groo, _नकार,
  { {0x2166005e, 0xe1f8007e, 0x00000000, 0x00000000}},  //   пиши_, огі_,   ,
  { {0x44260219, 0x00000000, 0x00000000, 0x00000000}},  //   blo_,   ,   ,
  { {0x628201d6, 0xefc905b5, 0xa295013a, 0x00000000}},  //   broo, слил_, _набі,
  { {0x6282008e, 0x2fc6012d, 0x6d5c0276, 0x00000000}},  //   croo, _dnog_, ıran,
  { {0x271a0011, 0x4c85004c, 0x236d0190, 0x00000000}},  //   ỏng_, плов, _heej_,
  { {0x2904019a, 0x7c950025, 0x00000000, 0x00000000}},  //   şmaz_, أشخا,   ,
  { {0xfaa6008b, 0xeb9a0194, 0xade90014, 0x00000000}},  //   памо, щим_, _گفتم_,
  { {0x67ea000c, 0x00000000, 0x00000000, 0x00000000}},  //   _nýja,   ,   ,
  { {0xceb2061e, 0x44262bd5, 0x98560088, 0x00000000}},  //   _ניו_, zlo_, зташ,
  { {0xdca201be, 0x44260016, 0x75e00010, 0x00000000}},  //   _защи, ylo_, _közv,
  { {0x6282006a, 0x68430264, 0xdb0400c4, 0x00000000}},  //   yroo, енса, _maiú,
  { {0x44260173, 0x2c0b025a, 0xe73701ab, 0x00000000}},  // [c460] vlo_, _دعوی_, зет_,
  { {0x8afb009b, 0x00000000, 0x00000000, 0x00000000}},  //   _להפי,   ,   ,
  { {0x44261144, 0x89db019b, 0x62823809, 0x00000000}},  //   tlo_, _החיי, wroo,
  { {0x628201b5, 0xd4690025, 0xc3150044, 0x00000000}},  //   troo, تحكم_, ়েছি_,
  { {0x44260817, 0xf1c70061, 0x224d0093, 0x00000000}},  //   rlo_, लांन, _cuek_,
  { {0x98b801f6, 0x442607e4, 0x6282010e, 0x00000000}},  //   ları_, slo_, rroo,
  { {0x64a3008b, 0x628201d6, 0xd12f0439, 0x00000000}},  //   _пара, sroo, همه_,
  { {0x644e000d, 0x6282006c, 0x661e00ca, 0x00000000}},  //   _iubi, proo, lopk,
  { {0x644e0211, 0x656e0022, 0xdce30089, 0x00000000}},  //   _hubi, _kebh, _renā,
  { {0x644e0dc6, 0x2d8c01bb, 0x67260292, 0x00000000}},  //   _kubi, ugde_, _mykj,
  { {0x6fdc00f4, 0x98b801df, 0x515b00b3, 0x00000000}},  //   _décr, karı_, _הכבו,
  { {0x644e380a, 0x2d82014a, 0x7f4a0025, 0x00000000}},  //   _mubi, şke_, _الإق_,
  { {0x644e0036, 0xdfcf0379, 0x98b80279, 0x00000000}},  //   _lubi, _حين_, darı_,
  { {0x644e0173, 0x00000000, 0x00000000, 0x00000000}},  //   _oubi,   ,   ,
  { {0x6aa4380b, 0x645c01f3, 0x59f8005e, 0x00000000}},  //   _epif, _ntri, черя_,
  { {0xfc15007e, 0x27eb0026, 0xcce50439, 0x00000000}},  //   _імпэ, _qlcn_, _تسهي,
  { {0x35b5003b, 0x644e009d, 0x95d9003b, 0x00000000}},  // [c470] мбар, _aubi, одат_,
  { {0x7aef01df, 0x644e380c, 0x3f83007f, 0x00000000}},  //   ıntı, _bubi, ėjui_,
  { {0x644e0211, 0x98b80276, 0xdcf301ee, 0x00000000}},  //   _cubi, barı_, ćaće,
  { {0x644e0091, 0x645c0048, 0x22450133, 0x00000000}},  //   _dubi, _dtri, _silk_,
  { {0x92390077, 0xfc490082, 0x2245010e, 0x00000000}},  //   очку_, _rậm_, _pilk_,
  { {0xed460014, 0x644e160b, 0x765d225f, 0x00000000}},  //   _لپ_, _fubi, _itsy,
  { {0x644e0091, 0xf484003b, 0x6fdc009d, 0x00000000}},  //   _gubi, _путн, _récr,
  { {0x6d5801b5, 0x7ff503ec, 0x6b9d00bb, 0x00000000}},  //   _afva, بستا, jfsg,
  { {0x644e380d, 0x76470009, 0xddc20087, 0x00000000}},  //   _zubi, _kijy, _dvož,
  { {0x63ab0030, 0x644e006b, 0x628b0058, 0x00000000}},  //   legn, _yubi, mugo,
  { {0x6448028c, 0x628b03dd, 0x6aa40085, 0x00000000}},  //   _édit, lugo, _spif,
  { {0x6b8f001c, 0x2734009f, 0xddc20107, 0x00000000}},  //   ggcg, _júní_, _gvož,
  { {0x0f5600b6, 0xce3500a1, 0x75e00010, 0x00000000}},  //   _חינם_, _ہوچک, _közt,
  { {0xbea2003b, 0x997d0089, 0x00000000, 0x00000000}},  //   _рашк, tāšu_,   ,
  { {0x656e11f0, 0x200d00fa, 0x628b0058, 0x00000000}},  //   _rebh, onei_, hugo,
  { {0x6b8f001c, 0x644e0e1d, 0x5d440049, 0x00000000}},  //   cgcg, _rubi, _אָפּ_,
  { {0x644e0375, 0xcf92007b, 0x7c241786, 0x00000000}},  // [c480] _subi, כטן_, _ikir,
  { {0x628b1431, 0xf98a0014, 0xe57a007e, 0x00000000}},  //   dugo, _بندي_, ізе_,
  { {0x76470173, 0xe3ba003b, 0xb4e8007d, 0x00000000}},  //   _dijy, жбе_, यने_,
  { {0x62990719, 0x63ab09fa, 0xd90d026c, 0x00000000}},  //   ftwo, gegn, _ایف_,
  { {0xf773009b, 0x66840123, 0x764f0009, 0x00000000}},  //   _בקר_, _سیال, _gucy,
  { {0x644e006a, 0x200d02eb, 0x00000000, 0x00000000}},  //   _tubi, enei_,   ,
  { {0x645c201a, 0x63ab0229, 0x92ce0044, 0x00000000}},  //   _utri, begn, শনে_,
  { {0xdfd00054, 0xd7d10061, 0x76470009, 0x00000000}},  //   اية_, हायच, _zijy,
  { {0x8d8602dc, 0x8fa3025f, 0x4424008a, 0x00000000}},  //   мунд, тање, _ikm_,
  { {0x7c243551, 0x25b81bea, 0x200d001a, 0x00000000}},  //   _akir, _jarl_, anei_,
  { {0x6b8f001c, 0x44240145, 0x6e281575, 0x00000000}},  //   tgcg, _kkm_, rldb,
  { {0x7c360016, 0x26c20501, 0x75e00010, 0x00000000}},  //   _chyr, _orko_, _közs,
  { {0x20040890, 0x6b9d09cb, 0x6e930025, 0x00000000}},  //   mimi_, rfsg, _للنا,
  { {0x200402ba, 0x7c241489, 0x44240022, 0x00000000}},  //   limi_, _ekir, _lkm_,
  { {0xa3ae001c, 0x26c20058, 0x6da30098, 0x00000000}},  //   _कसं_, _arko_, _рија,
  { {0x2004253f, 0x2d9e380e, 0x00000000, 0x00000000}},  //   nimi_, lfte_,   ,
  { {0x98af047f, 0x63ab380f, 0xc6f9005e, 0x00000000}},  // [c490] ınız_, vegn, чнах_,
  { {0x25b805ad, 0x20040065, 0x44240145, 0x00000000}},  //   _carl_, himi_, _akm_,
  { {0x20041e8d, 0x3914007e, 0xe7590088, 0x00000000}},  //   kimi_, _амэр, _нині_,
  { {0x6299010f, 0xb5fb0051, 0x628b1fe8, 0x00000000}},  //   ttwo, _stád, tugo,
  { {0x63ab05b7, 0x27e9020c, 0xe94500d3, 0x00000000}},  //   regn, mkan_, _ترکی,
  { {0x63ab0198, 0x27e9020c, 0x9f98000c, 0x00000000}},  //   segn, lkan_, _séð_,
  { {0x545400ed, 0x63ab0207, 0x44240022, 0x00000000}},  //   _авст, pegn, _fkm_,
  { {0x27e9020c, 0x2004166f, 0x44241856, 0x00000000}},  //   nkan_, gimi_, _gkm_,
  { {0x27e93810, 0x200d237d, 0x521503e8, 0x00000000}},  //   ikan_, rnei_, _здат,
  { {0x27e9020c, 0xee36045a, 0xef16007e, 0x00000000}},  //   hkan_, нны_, эмы_,
  { {0x27e93811, 0x20040065, 0xdb0a00b9, 0x00000000}},  //   kkan_, bimi_, čním,
  { {0xca2900b6, 0x3015004c, 0x645a009d, 0x00000000}},  //   _הם_, _ядер, _étie,
  { {0x27e904cb, 0x00000000, 0x00000000, 0x00000000}},  //   dkan_,   ,   ,
  { {0x67e30004, 0xdddb013e, 0x64490544, 0x00000000}},  //   _mõju, bruš, _liei,
  { {0x27e904cb, 0x27f20016, 0x7c360133, 0x00000000}},  //   fkan_, thyn_, _thyr,
  { {0x25b800f4, 0x7c241b81, 0x27e92544, 0x00000000}},  //   _sarl_, _ukir, gkan_,
  { {0x25b80068, 0x225f033b, 0x00000000, 0x00000000}},  // [c4a0] _parl_, _ntuk_,   ,
  { {0x2004008d, 0x6e21018e, 0x44240145, 0x00000000}},  //   zimi_, nolb, _skm_,
  { {0x27e9027e, 0x20040279, 0x442405cd, 0x00000000}},  //   bkan_, yimi_, _pkm_,
  { {0xe29a0057, 0x27e90073, 0xd36f0025, 0x00000000}},  //   зад_, ckan_, مهم_,
  { {0xd3230e09, 0x2004024f, 0x2ca70093, 0x00000000}},  //   льши, vimi_, _lpnd_,
  { {0x69de002b, 0xf48402fd, 0x6e2100f6, 0x00000000}},  //   _jope, _لاری, jolb,
  { {0x2004153a, 0x69de201a, 0x6722001e, 0x00000000}},  //   timi_, _mope, ļoju,
  { {0x69de0dd7, 0x44240169, 0x04430216, 0x00000000}},  //   _lope, _ukm_, _бесн,
  { {0x2004152b, 0x26c00197, 0x69de010e, 0x00000000}},  //   rimi_, nvio_, _oope,
  { {0xdd900151, 0x20043812, 0x69de3813, 0x00000000}},  //   جود_, simi_, _nope,
  { {0x6f663814, 0x2d9e0c0c, 0xc5f3009b, 0x00000000}},  //   _звез, rfte_, רדת_,
  { {0x69de1fdb, 0x78550006, 0x00000000, 0x00000000}},  //   _aope, _sąvo,   ,
  { {0x81b30055, 0x69de0016, 0x6e2108d1, 0x00000000}},  //   টার_, _bope, bolb,
  { {0x69de0207, 0xc33300a0, 0x3c32004f, 0x00000000}},  //   _cope, טור_, ráva_,
  { {0x27e9020c, 0x2a6000d9, 0x00000000, 0x00000000}},  //   tkan_, _etib_,   ,
  { {0xf77301af, 0x00000000, 0x00000000, 0x00000000}},  //   طار_,   ,   ,
  { {0x27e9020c, 0xf6530a4f, 0x7d2100a1, 0x00000000}},  // [c4b0] rkan_, ائر_, _مہین,
  { {0x984b2b26, 0x27e9020c, 0x7bdf0129, 0x00000000}},  //   _няма_, skan_, _hoqu,
  { {0x27e90149, 0x225f01b5, 0x00000000, 0x00000000}},  //   pkan_, _stuk_,   ,
  { {0x69de0059, 0xe454007e, 0x987a01ce, 0x00000000}},  //   _zope, укцы, _קארט,
  { {0x64491994, 0x3267003b, 0x7bdf009d, 0x00000000}},  //   _viei, хтев, _moqu,
  { {0x7bdf029a, 0x814500a1, 0x69de00f6, 0x00000000}},  //   _loqu, نچان, _xope,
  { {0xd3a7008b, 0x70bd006e, 0x81b30044, 0x00000000}},  //   _прап, ्मेल, টাল_,
  { {0x442b0011, 0x6d5a00e5, 0x7bdf004a, 0x00000000}},  //   _óc_, ecta, _noqu,
  { {0xee3900e3, 0x2284105c, 0x75e00010, 0x00000000}},  //   мни_, _бухг, _közp,
  { {0x63bb3815, 0x6d5a001c, 0x645a029d, 0x00000000}},  //   _haun, gcta, _étic,
  { {0x63bb010a, 0xa806005d, 0x69de0c78, 0x00000000}},  //   _kaun, lmış, _rope,
  { {0x63bb0580, 0x7bdf00f4, 0x69de3816, 0x00000000}},  //   _jaun, _coqu, _sope,
  { {0x63bb011c, 0xa806005d, 0x7bdf004a, 0x00000000}},  //   _maun, nmış, _doqu,
  { {0x63bb2d8a, 0x32072dd6, 0x26c00197, 0x00000000}},  //   _laun, niny_, vvio_,
  { {0x7bdf06c0, 0x44c10006, 0x64c50091, 0x00000000}},  //   _foqu, _nė_, nčić,
  { {0xb8da02fb, 0x63bb011c, 0xa806014a, 0x00000000}},  //   _आई_, _naun, kmış,
  { {0x69de00b9, 0x7e7b3817, 0x00000000, 0x00000000}},  // [c4c0] _tope, nsup,   ,
  { {0x26c01389, 0x64c5016c, 0x320704bb, 0x00000000}},  //   rvio_, kčić, jiny_,
  { {0x32070428, 0x64c50107, 0x63bb3818, 0x00000000}},  //   diny_, jčić, _baun,
  { {0x63bb01c5, 0x7e7b01b1, 0x7bdf00f6, 0x00000000}},  //   _caun, ksup, _xoqu,
  { {0x63bb001a, 0x7e7b016c, 0x6f0d012d, 0x00000000}},  //   _daun, jsup, _žacn,
  { {0x7e7b00f8, 0x00000000, 0x00000000, 0x00000000}},  //   dsup,   ,   ,
  { {0x63bb0006, 0xc95300b6, 0xfc4a001d, 0x00000000}},  //   _faun, סמה_, _hậu_,
  { {0x63bb0006, 0x00000000, 0x00000000, 0x00000000}},  //   _gaun,   ,   ,
  { {0x6d5a001c, 0x7bdf0129, 0x32073819, 0x00000000}},  //   tcta, _roqu, biny_,
  { {0x63a20007, 0xfc4a0082, 0xa28200a1, 0x00000000}},  //   lfon, _mậu_, _میچو,
  { {0x7bdf029a, 0x0cd00044, 0xfc4a0011, 0x00000000}},  //   _poqu, ান্ত, _lậu_,
  { {0x4ea6007c, 0x9f4600fa, 0x00000000, 0x00000000}},  //   _арка, _eloá_,   ,
  { {0x7e7b00f6, 0xfc3f00f6, 0xdd9201b2, 0x00000000}},  //   csup, rmí_, _نوش_,
  { {0x7a320030, 0xfc3f00b9, 0x63a20b3a, 0x00000000}},  //   sætn, smí_, hfon,
  { {0x7bdf029d, 0xa8060279, 0x00000000, 0x00000000}},  //   _toqu, zmış,   ,
  { {0x7bcd381a, 0x81d80044, 0x00000000, 0x00000000}},  //   _unau, াসি_,   ,
  { {0x63bb000c, 0xfc4a0011, 0x8aa4007e, 0x00000000}},  // [c4d0] _raun, _cậu_, _крэд,
  { {0x63bb00b0, 0x63a201d6, 0xfc4a0082, 0x00000000}},  //   _saun, efon, _dậu_,
  { {0xb9080055, 0x63bb011c, 0x63a20207, 0x00000000}},  //   _মে_, _paun, ffon,
  { {0x64c50209, 0xa8060279, 0x63a20010, 0x00000000}},  //   včić, tmış, gfon,
  { {0x32070161, 0x2ba501f5, 0x63bb00b0, 0x00000000}},  //   tiny_, ग्या, _vaun,
  { {0x40950545, 0xa8060279, 0x63bb11c2, 0x00000000}},  //   грит, rmış, _waun,
  { {0x7e62049a, 0x63bb14f7, 0xa4d40088, 0x00000000}},  //   _atop, _taun, _корі,
  { {0x81b30055, 0x7e7b00f8, 0xa806005d, 0x00000000}},  //   টাই_, tsup, pmış,
  { {0xfc4a001d, 0x32070161, 0xe315003b, 0x00000000}},  //   _mật_, piny_, _смањ,
  { {0x6455000b, 0x7e7b1864, 0xfc4a0011, 0x00000000}},  //   _kuzi, rsup, _lật_,
  { {0xd131023c, 0xeb9a013b, 0x7e7b0129, 0x00000000}},  //   _اما_, нин_, ssup,
  { {0x65750065, 0x7e620009, 0x7ff40167, 0x00000000}},  //   _lezh, _ftop, _پسما,
  { {0x61e10f68, 0x6da50081, 0x64552e4d, 0x00000000}},  //   _koll, _била, _luzi,
  { {0x09050055, 0x61e1021e, 0xceb200a0, 0x00000000}},  //   _শুধু_, _joll, _ליד_,
  { {0xfc4a001d, 0x64550026, 0x63a20009, 0x00000000}},  //   _bật_, _nuzi, yfon,
  { {0x61e10114, 0xcb7602ea, 0x00000000, 0x00000000}},  //   _loll, _сукњ,   ,
  { {0x645526c4, 0x6b840032, 0xfc4a0082, 0x00000000}},  // [c4e0] _auzi, _idig, _dật_,
  { {0x61e1381b, 0x645500b4, 0x7c26381c, 0x00000000}},  //   _noll, _buzi, lokr,
  { {0x399b0476, 0x64550f6e, 0x65750066, 0x00000000}},  //   _אייד, _cuzi, _dezh,
  { {0x64550107, 0x2486013c, 0x25f00061, 0x00000000}},  //   _duzi, čom_, _इतकी_,
  { {0x0cb00164, 0xc694007b, 0x63a202ab, 0x00000000}},  //   _जन्म, _דאָ_, rfon,
  { {0x61e106da, 0x64550035, 0x80c00061, 0x00000000}},  //   _coll, _fuzi, विले,
  { {0xee090055, 0x61e12a24, 0x6b840091, 0x00000000}},  //   রকাশ_, _doll, _odig,
  { {0xd252007a, 0x80d90044, 0x6b840023, 0x00000000}},  //   _هنر_, _ভেঙ্, _ndig,
  { {0x61e10038, 0x3df4022a, 0x644200b0, 0x00000000}},  //   _foll, изис, mmoi,
  { {0x57e1001c, 0x61e10f89, 0x6b840207, 0x00000000}},  //   _नव्ह, _goll, _adig,
  { {0xc223007a, 0xb5fb0049, 0x44260213, 0x00000000}},  //   _اکنو, גליכ, ooo_,
  { {0x4426381d, 0x764e06d0, 0x6442191b, 0x00000000}},  //   noo_, _liby, nmoi,
  { {0x61e101f6, 0x6b84018e, 0x80370049, 0x00000000}},  //   _yoll, _ddig, _ענדע_,
  { {0x44262117, 0x764e04c4, 0x5a340088, 0x00000000}},  //   hoo_, _niby, йнят,
  { {0x442600b0, 0x7c8600e2, 0xdcea00e5, 0x00000000}},  //   koo_, _суле, _defă,
  { {0xb8dd03d7, 0xf65f0190, 0x00000000, 0x00000000}},  //   _इन_, _dræn_,   ,
  { {0x55750797, 0xfc4a001d, 0x64550006, 0x00000000}},  // [c4f0] игат, _vật_, _suzi,
  { {0x60c806ec, 0xdb040032, 0x00000000, 0x00000000}},  //   _ordm, _gaiñ,   ,
  { {0x38c90167, 0xfc4a0011, 0x764e0016, 0x00000000}},  //   _شادی_, _tật_, _diby,
  { {0x61e1001f, 0x4426381e, 0x628b021c, 0x00000000}},  //   _soll, goo_, trgo,
  { {0x877a00a3, 0x60c8381f, 0x645a3820, 0x00000000}},  //   _בארי, _ardm, _étin,
  { {0x645501ee, 0x20060145, 0x61e1013f, 0x00000000}},  //   _tuzi, _amoi_, _qoll,
  { {0x44260253, 0x61e13431, 0x69c60061, 0x00000000}},  //   boo_, _voll, ायती,
  { {0x3fe50175, 0x61e103a1, 0xd7d80061, 0x00000000}},  //   ржив, _woll, डायच,
  { {0x61e10eaa, 0x63a9011c, 0xa02401a2, 0x00000000}},  //   _toll, _iben, _stöß,
  { {0x67ea00b9, 0xdb06014a, 0x00000000, 0x00000000}},  //   _výji, lekç,   ,
  { {0x7c260010, 0xa28100a1, 0xcb6a0726, 0x00000000}},  //   tokr, _ایڈو, кане_,
  { {0x92d70055, 0xf047007e, 0x00000000, 0x00000000}},  //   ানী_, _сэзо,   ,
  { {0x63a900e7, 0x6e67019d, 0x00000000, 0x00000000}},  //   _mben, _стеж,   ,
  { {0x4426001a, 0xfe7003ec, 0x7c260010, 0x00000000}},  //   zoo_, _رده_, sokr,
  { {0x63a90e43, 0x44260145, 0xd946019d, 0x00000000}},  //   _oben, yoo_, реви,
  { {0x6442009d, 0x63a93821, 0x44260249, 0x00000000}},  //   xmoi, _nben, xoo_,
  { {0x44260052, 0xa6650379, 0x00000000, 0x00000000}},  // [c500] voo_, مطلو,   ,
  { {0x63a908a0, 0x44260011, 0xb8dc0044, 0x00000000}},  //   _aben, woo_, _আপ_,
  { {0xb5fb1c85, 0x63a90066, 0x4426066d, 0x00000000}},  //   _itál, _bben, too_,
  { {0xb5fb0047, 0xa87b0049, 0x8755005e, 0x00000000}},  //   _után, _באטר, _гърц,
  { {0x4426095a, 0xdce300b9, 0x2327003b, 0x00000000}},  //   roo_, _peně, аоци_,
  { {0x80aa0055, 0x63a9010f, 0x44260ac2, 0x00000000}},  //   কিস্, _eben, soo_,
  { {0x442600b0, 0x40a800a6, 0x7e690c23, 0x00000000}},  //   poo_, اختی_, epep,
  { {0x4fc61deb, 0x67f8004a, 0x00000000, 0x00000000}},  //   рска, _fíje,   ,
  { {0x7e6900e0, 0x7e6d0276, 0x00000000, 0x00000000}},  //   gpep, _çapl,   ,
  { {0x7f8600a1, 0x00000000, 0x00000000, 0x00000000}},  //   _چلان,   ,   ,
  { {0xf9fc0044, 0x00000000, 0x00000000, 0x00000000}},  //   ঁচাল_,   ,   ,
  { {0x7afd010f, 0x00000000, 0x00000000, 0x00000000}},  //   tzst,   ,   ,
  { {0x9ce60044, 0xbea3094b, 0x00000000, 0x00000000}},  //   খছেন_, _мацк,   ,
  { {0x7afd02fa, 0x00000000, 0x00000000, 0x00000000}},  //   rzst,   ,   ,
  { {0xfc64089d, 0xf8070245, 0x20180def, 0x00000000}},  //   _اختی, ачан, _íris_,
  { {0x69da1a17, 0x3f860861, 0x87550088, 0x00000000}},  //   öter, _jdou_, скає,
  { {0x67ea009f, 0x7c2d0d58, 0xf1c60061, 0x00000000}},  // [c510] _nýju, _ikar, लयान,
  { {0x63a90145, 0x00000000, 0x00000000, 0x00000000}},  //   _sben,   ,   ,
  { {0x09050055, 0x7c2d0066, 0x2d9c0045, 0x00000000}},  //   _শুরু_, _kkar, _mcve_,
  { {0x97a70900, 0x59d50164, 0xdb16004a, 0x00000000}},  //   _трол, दावर, _hayá,
  { {0x623500ed, 0xfc4a0082, 0xdb06014a, 0x00000000}},  //   беду, _mập_, rekç,
  { {0xfc4a001d, 0xa4d501ff, 0x5ab80049, 0x00000000}},  //   _lập_, _логі, ילדע_,
  { {0x92d70055, 0x7c2d016c, 0x601e0089, 0x00000000}},  //   ানে_, _okar, zīme,
  { {0xc9180104, 0x4394007c, 0x7c2d00e0, 0x00000000}},  //   יחות_, _масс, _nkar,
  { {0x442d1802, 0xa3bc0061, 0xfaff0065, 0x00000000}},  //   _ike_, _असत_, jzë_,
  { {0x7c2d0047, 0x6e2801d9, 0x0792013e, 0x00000000}},  //   _akar, godb, _čímž_,
  { {0x443f001d, 0x7e69001c, 0x442d122f, 0x00000000}},  //   _khu_, spep, _kke_,
  { {0xfc4a001d, 0xb5fb3822, 0x81b30044, 0x00000000}},  //   _cập_, _stál, টাও_,
  { {0x442d0020, 0xeb97005e, 0x200d0de3, 0x00000000}},  //   _mke_, щия_, miei_,
  { {0x7c2d022b, 0x200d0de3, 0x433a0049, 0x00000000}},  //   _ekar, liei_, טערב,
  { {0x26cb0555, 0x7c950025, 0x291e01df, 0x00000000}},  //   _arco_, _العص, çta_,
  { {0x200d000d, 0x443f001d, 0x2fdf01ee, 0x00000000}},  //   niei_, _nhu_, njug_,
  { {0xed16009c, 0xe61a0057, 0x00000000, 0x00000000}},  // [c520] _نہیں_, гда_,   ,
  { {0x0556007e, 0x442d0142, 0xd6cf0379, 0x00000000}},  //   стая, _ake_, عقل_,
  { {0x92d70044, 0x3957009b, 0x75e00010, 0x00000000}},  //   ানো_, _לשים_, _közz,
  { {0x443f0011, 0x037a0426, 0x442d3823, 0x00000000}},  //   _chu_, احات_, _cke_,
  { {0x200d1b90, 0x21780a78, 0x00000000, 0x00000000}},  //   diei_, айлы_,   ,
  { {0x27e00d6b, 0x442d3733, 0x443f002d, 0x00000000}},  //   ljin_, _eke_, _ehu_,
  { {0xdb1f0065, 0x200d0035, 0x00000000, 0x00000000}},  //   _paqë, fiei_,   ,
  { {0x74160188, 0x5f94026b, 0x200d22cd, 0x00000000}},  //   _اورا, циит, giei_,
  { {0x6440021e, 0xfc4a0082, 0x2d8700e5, 0x00000000}},  //   _ihmi, _rập_, _bdne_,
  { {0x22f700b6, 0xf1a9007a, 0x7c2d0036, 0x00000000}},  //   _הזמן_, _نامه_, _skar,
  { {0xa3bc0183, 0x70561847, 0x11d70025, 0x00000000}},  //   _असा_, _انصا, _دولة_,
  { {0x27e001d5, 0x442d1278, 0x200d289d, 0x00000000}},  //   jjin_, _xke_, ciei_,
  { {0x6282006c, 0x6e280059, 0x27e03824, 0x00000000}},  //   nsoo, podb, djin_,
  { {0x998300b9, 0x23640022, 0x00000000, 0x00000000}},  //   rojů_, _lfmj_,   ,
  { {0xfc4a001d, 0x16d1013d, 0x64400052, 0x00000000}},  //   _tập_, सम्ब, _ohmi,
  { {0x27e00065, 0x7c2d0e15, 0xbc670380, 0x00000000}},  //   gjin_, _ukar, _امين_,
  { {0x36d401fc, 0x44c80279, 0x2bd60204, 0x00000000}},  // [c530] потр, _ağ_, धारा,
  { {0x9b95007a, 0x442d0193, 0x2ba5007d, 0x00000000}},  //   _الکت, _ske_, ग्रा,
  { {0x2bdd02fb, 0xe7c40309, 0x443f0011, 0x00000000}},  //   यापा, _लोकप, _phu_,
  { {0x62823825, 0x437401fc, 0xdb0f00c4, 0x00000000}},  //   fsoo, пушт, mecâ,
  { {0x200d1290, 0x00000000, 0x00000000, 0x00000000}},  //   viei_,   ,   ,
  { {0x657e0146, 0x00000000, 0x00000000, 0x00000000}},  //   caph,   ,   ,
  { {0x443f0ca9, 0x200d000d, 0xdb0f004a, 0x00000000}},  //   _thu_, tiei_, decí,
  { {0x442d0056, 0xa295007e, 0x4fe908d6, 0x00000000}},  //   _uke_, _мабі, рмин_,
  { {0x200d04f8, 0xdb0f008e, 0xf1a7034b, 0x00000000}},  //   riei_, fecí, _грен,
  { {0x4c850175, 0xac85004c, 0x200d0de3, 0x00000000}},  //   олов, огол, siei_,
  { {0x8c460264, 0xab5b3826, 0x1ddb0061, 0x00000000}},  //   жене, rdün, बाबत,
  { {0xeb9a02b8, 0x657e0258, 0x00000000, 0x00000000}},  //   шим_, zaph,   ,
  { {0xce6b08f3, 0x201d0009, 0xdee5005e, 0x00000000}},  //   _сред_, _ijwi_, _фоли,
  { {0x0dcb012b, 0xd7f10082, 0xf77f00c4, 0x00000000}},  //   _људи_, ễn_, _roça_,
  { {0x2a69002d, 0x9c650014, 0x75e01e00, 0x00000000}},  //   _etab_, _بهبو, _gözy,
  { {0xab5b0010, 0xf77f00fa, 0x00000000, 0x00000000}},  //   ndül, _poça_,   ,
  { {0xe57a00e3, 0x7bd60061, 0x060a2260, 0x00000000}},  // [c540] иза_, _inyu, анак_,
  { {0x644001ee, 0x67f80010, 0x27f2055f, 0x00000000}},  //   _shmi, _díja, skyn_,
  { {0x2eb6006e, 0x78ad00b9, 0xd94602b0, 0x00000000}},  //   _अन्त, čová, _фени,
  { {0x2bdd02f4, 0xd36f0025, 0x67f8008e, 0x00000000}},  //   याया, نهم_, _fíja,
  { {0xdddb01d9, 0x2bac0061, 0x7bc4225f, 0x00000000}},  //   druž, ट्या, _maiu,
  { {0x6282049b, 0x7bc4006c, 0x057a0025, 0x00000000}},  //   rsoo, _laiu, _خمسة_,
  { {0x320e2179, 0x2bdd0204, 0x6282010e, 0x00000000}},  //   rify_, यामा, ssoo,
  { {0x657c011f, 0xeeaa0081, 0xc95300b3, 0x00000000}},  //   _herh, аток_, ומו_,
  { {0xdefa0eb1, 0xdde3001a, 0x645c315e, 0x00000000}},  //   рый_, ârşi, _huri,
  { {0x645c0736, 0x50d606b4, 0x7bd60010, 0x00000000}},  //   _kuri, _وزار, _anyu,
  { {0xdb0f2bc9, 0x2a6900ea, 0x657c014a, 0x00000000}},  //   recí, _stab_, _merh,
  { {0x645c0127, 0x5c07007e, 0x7bc411c8, 0x00000000}},  //   _muri, іяна, _caiu,
  { {0xdb0f045b, 0x61e801df, 0x2bdd0309, 0x00000000}},  //   pecí, _kodl, याबा,
  { {0x645c00c4, 0x61e800d0, 0xba3b0016, 0x00000000}},  //   _ouri, _jodl, rtïo,
  { {0x61e81712, 0x645c1ece, 0xf65f0030, 0x00000000}},  //   _modl, _nuri, _træk_,
  { {0xcb0b0001, 0x3e6001aa, 0x9f5f01e5, 0x00000000}},  //   _вход_, _kòt_, nnuð_,
  { {0x645c00b0, 0x657c020c, 0xba770025, 0x00000000}},  // [c550] _auri, _berh, _باعت,
  { {0x2bac03d7, 0xdce10006, 0x645c071e, 0x00000000}},  //   ट्ठा, galė, _buri,
  { {0x3e600607, 0x645c0335, 0x00000000, 0x00000000}},  //   _lòt_, _curi,   ,
  { {0x645c0038, 0x6b9d0304, 0x61fa0808, 0x00000000}},  //   _duri, ngsg, _altl,
  { {0x69c50004, 0x61e80016, 0x3e600263, 0x00000000}},  //   _kahe, _bodl, _nòt_,
  { {0x69c73827, 0x645c0c99, 0x657c3828, 0x00000000}},  //   ndje, _furi, _gerh,
  { {0x29031f27, 0x75820cd9, 0x69c506ad, 0x00000000}},  //   nzja_, _سینم, _mahe,
  { {0x69c50004, 0xb5fb00b9, 0xe3b302fd, 0x00000000}},  //   _lahe, _stáh, _ترس_,
  { {0x645c002d, 0x61e80016, 0xb5fb0048, 0x00000000}},  //   _zuri, _fodl, _atái,
  { {0x61e80719, 0x645c0093, 0x765d04be, 0x00000000}},  //   _godl, _yuri, _musy,
  { {0xa3df0164, 0x7bc400e5, 0x645c1ea8, 0x00000000}},  //   ताप_, _paiu, _xuri,
  { {0xe672005d, 0xb5fb0051, 0x3e6001aa, 0x00000000}},  //   _ölçü, _dtái, _fòt_,
  { {0x75f3014a, 0x69c51b1c, 0x7bc60abf, 0x00000000}},  //   _kızı, _bahe, rdku,
  { {0xa9670b11, 0xcefd0279, 0xee380245, 0x00000000}},  //   зира_, ığın_, _дні_,
  { {0x69c5010f, 0x31af005d, 0xf77201b7, 0x00000000}},  //   _dahe, mızı_, فاء_,
  { {0xb8e4006e, 0x8c4301e0, 0x645c3829, 0x00000000}},  //   _एन_, _пеще, _ruri,
  { {0xa3df02d2, 0x645c1b6a, 0xdb9b00b3, 0x00000000}},  // [c560] तान_, _suri, _הספר,
  { {0x31af047f, 0x2c610d7f, 0x3c3201ca, 0x00000000}},  //   nızı_, _kód_, rávu_,
  { {0x657c0168, 0x6fbd001c, 0x5fbd02f4, 0x00000000}},  //   _verh, ्यां, ्याल,
  { {0x69c511e4, 0xe363007c, 0x2c611a43, 0x00000000}},  //   _zahe, екци, _mód_,
  { {0x61e8004f, 0x657c020c, 0x7655382a, 0x00000000}},  //   _podl, _terh, _fizy,
  { {0x645c010a, 0xd25901e1, 0x22bd000a, 0x00000000}},  //   _turi, іці_, _dňk_,
  { {0x645c0004, 0x3e6001aa, 0x61e8050f, 0x00000000}},  //   _uuri, _sòt_, _vodl,
  { {0x3e6001aa, 0x22bd01aa, 0xa4f80061, 0x00000000}},  //   _pòt_, _fňk_, ंनीच_,
  { {0xb5fb002a, 0x2903002b, 0x00000000, 0x00000000}},  //   _stái, zzja_,   ,
  { {0x7206035b, 0xf1aa007a, 0x3e6001aa, 0x00000000}},  //   _عوام, _داره_, _vòt_,
  { {0x2c6104ed, 0xdc3f00b9, 0x9f9e01d6, 0x00000000}},  //   _cód_, síčn, _lééf_,
  { {0x395a1ef5, 0x69c5382b, 0x317e0190, 0x00000000}},  //   _agps_, _sahe, _hetz_,
  { {0x69c500b0, 0xfe4617e9, 0x6b9d0cf5, 0x00000000}},  //   _pahe, _ендо, rgsg,
  { {0x22590263, 0x765d014a, 0xf77f00c4, 0x00000000}},  //   _èske_, _rusy, _poço_,
  { {0x69c50004, 0xa3bc001c, 0x28f80057, 0x00000000}},  //   _vahe, _असं_, перь_,
  { {0x2d9e21c9, 0x69c500f0, 0x765501aa, 0x00000000}},  //   lgte_, _wahe, _sizy,
  { {0x6b8d006a, 0x81e70044, 0x69c5006c, 0x00000000}},  // [c570] _idag, মোট_, _tahe,
  { {0x2d9e00b5, 0x317e010f, 0x7c2f00fa, 0x00000000}},  //   ngte_, _netz_, locr,
  { {0x7a320f4b, 0x656501a2, 0x765509e5, 0x00000000}},  //   rætt, rchh, _vizy,
  { {0x7a320018, 0xe3b30025, 0x76550036, 0x00000000}},  //   sætt, عرض_, _wizy,
  { {0xa3df006e, 0x317e382c, 0x38c700b9, 0x00000000}},  //   ताब_, _betz_, bírá_,
  { {0xf77f005f, 0x75f3006b, 0x785c01aa, 0x00000000}},  //   _heç_, _qızı, _sčvi,
  { {0x63b90046, 0xf77f006b, 0xdb060190, 0x00000000}},  //   pewn, _keç_, sekø,
  { {0xa0090b03, 0x6b8d382d, 0xdcf80925, 0x00000000}},  //   تقبل_, _ndag, _cevč,
  { {0x442f0213, 0xa3da013d, 0x7c2f0133, 0x00000000}},  //   mog_, ़ार_, docr,
  { {0x6b8d0010, 0xee3607d0, 0x317e0082, 0x00000000}},  //   _adag, мны_, _getz_,
  { {0x7c2f1aa3, 0x6284007f, 0x00000000, 0x00000000}},  //   focr, šiot,   ,
  { {0x442f0119, 0xe7d80055, 0x2ef5041f, 0x00000000}},  //   nog_, _সত্য, _озер,
  { {0xef0e00ed, 0x00000000, 0x00000000, 0x00000000}},  //   _рм_,   ,   ,
  { {0x442f0016, 0x7d280010, 0x6b8d0026, 0x00000000}},  //   hog_, épsé, _edag,
  { {0x442f0119, 0xc8b5007e, 0x225f1aff, 0x00000000}},  //   kog_, нсты, _luuk_,
  { {0xdb16008e, 0x3f9f00e7, 0x442f1c43, 0x00000000}},  //   _mayú, nguu_, jog_,
  { {0x442f018e, 0xe7370057, 0xf4130055, 0x00000000}},  // [c580] dog_, дет_, িকার_,
  { {0x7a320030, 0x3dc70173, 0x00000000, 0x00000000}},  //   ræts, _janw_,   ,
  { {0xdce1001e, 0xfaff0065, 0x442f0016, 0x00000000}},  //   dalī, ncën_, fog_,
  { {0x442f0119, 0xf77f014a, 0xb4ae006e, 0x00000000}},  //   gog_, _geç_, _कही_,
  { {0x26c200b0, 0xc17a0088, 0x2d9e0190, 0x00000000}},  //   _usko_, оїй_, ygte_,
  { {0xeb9f0637, 0xb5fb0161, 0x2fc601c3, 0x00000000}},  //   niør_, _stáv, _saog_,
  { {0x442f382e, 0xdcf80087, 0x00000000, 0x00000000}},  //   bog_, _pevč,   ,
  { {0x232a0457, 0xab5b005d, 0x8fa3003b, 0x00000000}},  //   _доби_, rdük, ваће,
  { {0x2bdd001c, 0xfbdd0061, 0x00000000, 0x00000000}},  //   यासा, यासम,   ,
  { {0xdd900d3a, 0xdb0f0181, 0x20180010, 0x00000000}},  //   دود_, lecç, őri_,
  { {0x2d9e2764, 0x55970097, 0x91e30216, 0x00000000}},  //   rgte_, ודיע_, _шофе,
  { {0x225f0022, 0x00000000, 0x00000000, 0x00000000}},  //   _yuuk_,   ,   ,
  { {0xa3df001c, 0x7c2f027b, 0xb4bb0164, 0x00000000}},  //   तात_, rocr, _अन्_,
  { {0x3f84000b, 0xfd0f00e9, 0xf77f382f, 0x00000000}},  //   lamu_, اجی_, _seç_,
  { {0xa934165b, 0xcec8001d, 0x442f011c, 0x00000000}},  //   верш, _hộ_, yog_,
  { {0x3f840020, 0xeb9f0190, 0x6b8d15db, 0x00000000}},  //   namu_, riøs_, _udag,
  { {0x442f0119, 0xf77f0065, 0xba3b00d4, 0x00000000}},  // [c590] vog_, _veç_, juïg,
  { {0x3f84000b, 0xcec80011, 0x442f0016, 0x00000000}},  //   hamu_, _mộ_, wog_,
  { {0x6289037e, 0x442f0119, 0xcec8001d, 0x00000000}},  //   _sveo, tog_, _lộ_,
  { {0x3f840ba5, 0xfc4a0082, 0xf65f0146, 0x00000000}},  //   jamu_, _bậy_, _bræt_,
  { {0x3f84000b, 0xfc4a0011, 0xf07500a1, 0x00000000}},  //   damu_, _cậy_, ڑیاں_,
  { {0x442f3830, 0xfc4a0011, 0x21690077, 0x00000000}},  //   sog_, _dậy_, чики_,
  { {0x205500d7, 0x09c90044, 0x442f0091, 0x00000000}},  //   нтир, শাপা, pog_,
  { {0xcec800ad, 0x44393831, 0xa2ba0309, 0x00000000}},  //   _bộ_, _ós_, _शैक्,
  { {0xef19004c, 0x15f30316, 0x28d10061, 0x00000000}},  //   ями_, _आकार_, हिडि,
  { {0x645a00d4, 0x00000000, 0x00000000, 0x00000000}},  //   _ètic,   ,   ,
  { {0x3f840020, 0xc1e600a1, 0xfc4a0082, 0x00000000}},  //   bamu_, _سکول_, _zậy_,
  { {0xc4d2007b, 0x26c00016, 0xfaff0023, 0x00000000}},  //   אגט_, ywio_, rcën_,
  { {0x539a009b, 0x501a0049, 0x00000000, 0x00000000}},  //   הירו, _צונו,   ,
  { {0x1d090893, 0x00000000, 0x00000000, 0x00000000}},  //   _нели_,   ,   ,
  { {0xd82600aa, 0x2d850114, 0xb4ae007d, 0x00000000}},  //   едви, male_, _कहे_,
  { {0x6d430091, 0x2d85006c, 0x3cf8023c, 0x00000000}},  //   _izna, lale_, _تعهد_,
  { {0xd70a007e, 0x3855005e, 0xdb062939, 0x00000000}},  // [c5a0] чнае_, търс, nekü,
  { {0x2d850198, 0xfbac006e, 0x3f8410d9, 0x00000000}},  //   nale_, ट्रम, zamu_,
  { {0xdb060004, 0xdb0f00c4, 0x3f840022, 0x00000000}},  //   hekü, tecç, yamu_,
  { {0xb5fb0224, 0x2d85017b, 0x03c5007e, 0x00000000}},  //   _stát, hale_, ксім,
  { {0x2d8501e3, 0xdb0f0181, 0xc7b300b3, 0x00000000}},  //   kale_, recç, _גבר_,
  { {0x2d850004, 0xfc4a001d, 0x64a6008b, 0x00000000}},  //   jale_, _vậy_, _пага,
  { {0x2d853832, 0xa3ea0ae0, 0x3f840127, 0x00000000}},  //   dale_, _едва_, tamu_,
  { {0xf65f18f9, 0x6e230087, 0x6b860022, 0x00000000}},  //   _træt_, _ajnb, jakg,
  { {0xe29701f9, 0x2d850030, 0x24170476, 0x00000000}},  //   _пат_, fale_, _נחמן_,
  { {0x2d85060c, 0x7c240020, 0x63a20207, 0x00000000}},  //   gale_, _ajir, lgon,
  { {0x2bdd01f5, 0x00000000, 0x00000000, 0x00000000}},  //   याला,   ,   ,
  { {0x63a2334f, 0x68f50006, 0x386101a2, 0x00000000}},  //   ngon, vyzd, _ruhr_,
  { {0x38610240, 0xdcf80089, 0x6d430288, 0x00000000}},  //   _suhr_, _devā, _ezna,
  { {0x2d85060c, 0x7d0600f4, 0xc3330104, 0x00000000}},  //   cale_, _céré, רוש_,
  { {0xddc90035, 0xb5fb00fa, 0x6da30098, 0x00000000}},  //   speţ, _otár, _сија,
  { {0x7c240065, 0x7e6200b0, 0xdb1d0023, 0x00000000}},  //   _gjir, _kuop, nesë,
  { {0xa3da006e, 0x63a200ca, 0xa3df01f5, 0x00000000}},  // [c5b0] ़ाई_, dgon, तास_,
  { {0x7c3d3833, 0x7d06009d, 0x63a201c3, 0x00000000}},  //   llsr, _géré, egon,
  { {0xb7d9026c, 0xd3712aea, 0x44240283, 0x00000000}},  //   _ہوگا_, لها_, _bjm_,
  { {0x2d85002d, 0x63a22191, 0x30af0044, 0x00000000}},  //   zale_, ggon, কিৎস,
  { {0x27e900d0, 0xc4cf009e, 0x44243834, 0x00000000}},  //   mjan_, _گےا_, _djm_,
  { {0x27e92e6e, 0xb5fb00c4, 0xdb0401c3, 0x00000000}},  //   ljan_, _etár, _scië,
  { {0x2d850004, 0x00000000, 0x00000000, 0x00000000}},  //   vale_,   ,   ,
  { {0x27e90ba0, 0x2d853835, 0x442413fd, 0x00000000}},  //   njan_, wale_, _gjm_,
  { {0x27e9006b, 0x64490009, 0x79870045, 0x00000000}},  //   ijan_, _ihei, kajw,
  { {0x7c36010a, 0x4c690745, 0x27e93836, 0x00000000}},  //   _skyr, мион_, hjan_,
  { {0x2d85060c, 0xfbdd0164, 0xeb9a0242, 0x00000000}},  //   rale_, यांम, мин_,
  { {0x0f15007c, 0x7d06009d, 0x88c00044, 0x00000000}},  //   _имею, _séré, _উপলক,
  { {0xa3b30164, 0x2d850207, 0x27e9087a, 0x00000000}},  //   ज्य_, pale_, djan_,
  { {0xaa46005e, 0x79870009, 0x7c3d01d6, 0x00000000}},  //   тегл, gajw, alsr,
  { {0x3ead0c7a, 0x6d430871, 0x7c242332, 0x00000000}},  //   ltet_, _uzna, _tjir,
  { {0x73ec0044, 0x27e93837, 0x7c2400e7, 0x00000000}},  //   _কষ্ট_, gjan_, _ujir,
  { {0x3ead11a9, 0x9f4f0129, 0x63a60039, 0x00000000}},  // [c5c0] ntet_, _algú_, _ökni,
  { {0x6b840472, 0x3ead010f, 0x44243838, 0x00000000}},  //   _heig, itet_, _sjm_,
  { {0x64490195, 0x26cf0073, 0x6b8406f6, 0x00000000}},  //   _bhei, ågor_, _keig,
  { {0x64490a47, 0x3ead0292, 0x6b84010a, 0x00000000}},  //   _chei, ktet_, _jeig,
  { {0x63a20ce3, 0x6449002a, 0x23600059, 0x00000000}},  //   rgon, _dhei, žijo_,
  { {0x6b84056f, 0x69ce18ee, 0x63a212c5, 0x00000000}},  //   _leig, ndbe, sgon,
  { {0x6449002a, 0xf9930104, 0xdb1d0065, 0x00000000}},  //   _fhei, ברו_, tesë,
  { {0x3ead0374, 0xb4de0061, 0x6b84377f, 0x00000000}},  //   ftet_, तमी_, _neig,
  { {0x3f98047f, 0xa3df007d, 0x765c3839, 0x00000000}},  //   ğru_, तार_, _kiry,
  { {0x20040065, 0xa8060180, 0x27e9002b, 0x00000000}},  //   shmi_, llığ, zjan_,
  { {0x6b84001e, 0xf1a90014, 0xd59b009b, 0x00000000}},  //   _beig, _ساله_, וביל,
  { {0xa80601f6, 0x69de01aa, 0x69ce0270, 0x00000000}},  //   nlığ, _anpe, edbe,
  { {0x6f090036, 0x6b841646, 0x79870020, 0x00000000}},  //   czec, _deig, tajw,
  { {0x5a341ba3, 0x69ce00d9, 0x765c0045, 0x00000000}},  //   инят, gdbe, _niry,
  { {0x27e91edb, 0xa806014a, 0xaa5804b5, 0x00000000}},  //   tjan_, klığ, тиру_,
  { {0xb5fb0211, 0xf77305f3, 0x69de2e51, 0x00000000}},  //   _cuán, شار_, _enpe,
  { {0x64490abe, 0x27e90bf4, 0xa806006b, 0x00000000}},  // [c5d0] _rhei, rjan_, dlığ,
  { {0x6449383a, 0x6b84001f, 0x27e9383b, 0x00000000}},  //   _shei, _zeig, sjan_,
  { {0x2baa0183, 0xa3df03d7, 0x290a0036, 0x00000000}},  //   _कामा, ताल_, czba_,
  { {0x7b08005d, 0x3ead383c, 0x628b0a74, 0x00000000}},  //   _örtü, ytet_, tsgo,
  { {0x3ead00f6, 0x877a00b3, 0xe2990783, 0x00000000}},  //   xtet_, _ראשי, хал_,
  { {0xb6da0049, 0x7d150142, 0x785c10ec, 0x00000000}},  //   _אַלט, úzsk, _učvr,
  { {0x64490038, 0x645b00ea, 0x00000000, 0x00000000}},  //   _thei, _tiui,   ,
  { {0x3ead02cc, 0xb4c102fb, 0x44d3016e, 0x00000000}},  //   ttet_, ्टी_, _ić_,
  { {0xdbdd000c, 0xf1a7007c, 0xfc3f23aa, 0x00000000}},  //   _ráðs, _арен, dlí_,
  { {0x6b841fcd, 0x6f090036, 0x7bdf004a, 0x00000000}},  //   _seig, rzec, _anqu,
  { {0x25a5009f, 0xed580027, 0x6f09115b, 0x00000000}},  //   _öllu_, teľa_, szec,
  { {0x6aaf001c, 0x3ead01c9, 0x7d1c0051, 0x00000000}},  //   ftcf, ptet_, úrsa,
  { {0xa3ab0316, 0x6b840def, 0xa806005a, 0x00000000}},  //   _खान_, _veig, nlış,
  { {0x6e920025, 0x5e920054, 0x6b840498, 0x00000000}},  //   _الوا, _الوط, _weig,
  { {0x63a9383d, 0xfc3f002a, 0x6b84010a, 0x00000000}},  //   _ocen, blí_, _teig,
  { {0xfc3f0051, 0x765c0435, 0xb5fb0082, 0x00000000}},  //   clí_, _siry, _quán,
  { {0x66e32180, 0x00000000, 0x00000000, 0x00000000}},  // [c5e0] бота,   ,   ,
  { {0x8a7b009b, 0xfdfc013d, 0x3e690082, 0x00000000}},  //   _ראית, एसएस_, _mút_,
  { {0xa8060279, 0x5dfa0049, 0x53160014, 0x00000000}},  //   tlığ, עפענ, گذار,
  { {0x289b0049, 0x765c0022, 0x00000000, 0x00000000}},  //   _איטא, _wiry,   ,
  { {0xa8060279, 0x3e690011, 0x8c1b009b, 0x00000000}},  //   rlığ, _nút_, עוני,
  { {0x63a90022, 0x00000000, 0x00000000, 0x00000000}},  //   _ecen,   ,   ,
  { {0xdb1d0047, 0xc653026c, 0xab5b0279, 0x00000000}},  //   resé, _اہلک, ndür,
  { {0xb4d001f5, 0x3e690011, 0x3a3a0093, 0x00000000}},  //   वटी_, _bút_, _lkpp_,
  { {0x3e690082, 0xc326013a, 0x9f5f0048, 0x00000000}},  //   _cút_, _смак, chuí_,
  { {0x32070224, 0xb5fb0051, 0x6f1d0051, 0x00000000}},  //   chny_, _nuál, úsca,
  { {0x0ce20044, 0x7bcd0dec, 0x459b0049, 0x00000000}},  //   মন্ত, _paau, עסטע,
  { {0xac190e09, 0xdb55007c, 0x79850ace, 0x00000000}},  //   тому_, ивны, _sehw,
  { {0x3a3a0022, 0xdd920014, 0xc2f80044, 0x00000000}},  //   _bkpp_, _هوش_, _আইডি_,
  { {0xc333012e, 0xb5fb008e, 0xfc3f0161, 0x00000000}},  //   מור_, _cuál, slí_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc86400d7, 0x3207000a, 0x8ae70088, 0x00000000}},  //   стри, zhny_, _біол,
  { {0xa7fb008e, 0x061509b5, 0xa3e8006e, 0x00000000}},  // [c5f0] _niñe, адаю, बान_,
  { {0x2bdd0204, 0x225e0087, 0x00000000, 0x00000000}},  //   याका, _nitk_,   ,
  { {0xb4c103d7, 0x00000000, 0x00000000, 0x00000000}},  //   ्टे_,   ,   ,
  { {0xa7fb0288, 0x00000000, 0x00000000, 0x00000000}},  //   _biñe,   ,   ,
  { {0xc7d8005e, 0x3a3a0022, 0x00000000, 0x00000000}},  //   _смях_, _ykpp_,   ,
  { {0x40950200, 0x3e690011, 0x213e0016, 0x00000000}},  //   арит, _rút_, _byth_,
  { {0x3e690011, 0x00000000, 0x00000000, 0x00000000}},  //   _sút_,   ,   ,
  { {0x63a9037e, 0xb275019d, 0xdb16000a, 0x00000000}},  //   _ucen, _влаш, _mayò,
  { {0x9e650098, 0xd00e0379, 0xa7fb0288, 0x00000000}},  //   јвод, بلي_, _giñe,
  { {0xed590072, 0xfe420088, 0x5f9500a1, 0x00000000}},  //   коп_, жньо, _چلائ,
  { {0x9d4500ed, 0x0c2601ee, 0x00000000, 0x00000000}},  //   ренд, имон,   ,
  { {0x3f89009f, 0x26d90197, 0x2a790045, 0x00000000}},  //   _þau_, _orso_, fpsb_,
  { {0xeb97005e, 0xb4e201f5, 0xaa460a85, 0x00000000}},  //   шия_, _गप्प_, иемл,
  { {0x60210089, 0x6da20ab6, 0x00000000, 0x00000000}},  //   dēmi, _диша,   ,
  { {0x26cb008e, 0xf77201b7, 0x1d06022a, 0x00000000}},  //   _asco_, قاء_, _вещи_,
  { {0xab5b014a, 0x2fcf0802, 0x2d870023, 0x00000000}},  //   rdür, _jagg_, _hene_,
  { {0x2d87383e, 0x46a60930, 0xa3df0164, 0x00000000}},  // [c600] _kene_, разв, ताई_,
  { {0x2d872578, 0xe5770088, 0xe8fa0ab6, 0x00000000}},  //   _jene_, изу_, _ало_,
  { {0x2d870119, 0x399b007b, 0xdce80089, 0x00000000}},  //   _mene_, _בייד, vadī,
  { {0x2d871e06, 0x32050020, 0xa7fb008e, 0x00000000}},  //   _lene_, _ally_, _piñe,
  { {0x213e0016, 0x7c26383f, 0xe7fb013d, 0x00000000}},  //   _syth_, inkr, _एकता_,
  { {0x2d870065, 0xa7fb008e, 0xdb1d068f, 0x00000000}},  //   _nene_, _viñe, rdsø,
  { {0xf99300b6, 0xdce80089, 0x91f50082, 0x00000000}},  //   קרה_, radī, _tín,
  { {0x44c801f6, 0x61e104bd, 0x32051d2a, 0x00000000}},  //   _iş_, _enll, _elly_,
  { {0x442600ee, 0x539b00b6, 0x2d870198, 0x00000000}},  //   mno_, _שימו, _bene_,
  { {0x442600ee, 0x6442021e, 0x2d87086e, 0x00000000}},  //   lno_, lloi, _cene_,
  { {0xd5d9007b, 0x44260207, 0x3a3800c7, 0x00000000}},  //   אַרש, ono_, dorp_,
  { {0x44260198, 0xef1a064b, 0x92d80044, 0x00000000}},  //   nno_, _име_, াহী_,
  { {0x2d873840, 0x78be0061, 0x545701ce, 0x00000000}},  //   _fene_, _appv, יסטן_,
  { {0x4426167a, 0x2d8714f9, 0xedd30380, 0x00000000}},  //   hno_, _gene_, _ويند,
  { {0x2d8c006c, 0xe7fb001c, 0xb7fb0164, 0x00000000}},  //   made_, _एकदा_, _एकदम_,
  { {0x442600ee, 0x2d8c3841, 0x2d870010, 0x00000000}},  //   jno_, lade_, _zene_,
  { {0x44263842, 0x44c83843, 0xac070167, 0x00000000}},  // [c610] dno_, _aş_, _مذکو,
  { {0x2d8c0a74, 0x4426024f, 0x7afd00b0, 0x00000000}},  //   nade_, eno_, myst,
  { {0x7afd042c, 0x3ea40374, 0x00000000, 0x00000000}},  //   lyst, humt_,   ,
  { {0x44260198, 0x2d8c00b5, 0x2d980036, 0x00000000}},  //   gno_, hade_, órej_,
  { {0xf2c70265, 0x2d8c0039, 0x60da3844, 0x00000000}},  //   рсен, kade_, _artm,
  { {0x44260198, 0x2d8c006c, 0x13080088, 0x00000000}},  //   ano_, jade_, шній_,
  { {0x2d8c0917, 0x442601d9, 0x64421c2b, 0x00000000}},  //   dade_, bno_, bloi,
  { {0x442601cd, 0xe2ab00a1, 0x2d87014a, 0x00000000}},  //   cno_, _لائن_, _sene_,
  { {0xee390751, 0x2d8c3845, 0x63bb3846, 0x00000000}},  //   лни_, fade_, _ibun,
  { {0x2d8c049a, 0x2d87008d, 0x41e4007e, 0x00000000}},  //   gade_, _qene_, _міха,
  { {0x2d870004, 0x2fcf0203, 0x00000000, 0x00000000}},  //   _vene_, _tagg_,   ,
  { {0xc0b20011, 0x26c900e7, 0x7afd3847, 0x00000000}},  //   _lưới_, kwao_, fyst,
  { {0x63bb02bf, 0x7c263848, 0x3a380039, 0x00000000}},  //   _mbun, rnkr, torp_,
  { {0x7f3a007b, 0x49990057, 0x5d850054, 0x00000000}},  //   _גענו, ится_, _الثل,
  { {0x442604a2, 0x63bb03cc, 0x79970009, 0x00000000}},  //   yno_, _obun, _ddxw,
  { {0x7afd0142, 0x6c360070, 0x2ca53849, 0x00000000}},  //   byst, _دفعا, muld_,
  { {0x44260213, 0x7bc6000b, 0x7afd0036, 0x00000000}},  // [c620] vno_, meku, cyst,
  { {0x63bb006b, 0x44260046, 0x7bc6023e, 0x00000000}},  //   _abun, wno_, leku,
  { {0x44260e3b, 0xc0b2001d, 0x69ad0164, 0x00000000}},  //   tno_, _dưới_, _जाती,
  { {0x7bc6006c, 0x2d8c0181, 0x4426384a, 0x00000000}},  //   neku, zade_, uno_,
  { {0x2ca507eb, 0x64420048, 0x321c01dc, 0x00000000}},  //   huld_, rloi, tivy_,
  { {0x44260213, 0x3c320428, 0x798e384b, 0x00000000}},  //   sno_, rávy_, nabw,
  { {0x7afd0df0, 0x64a30269, 0x644200f4, 0x00000000}},  //   zyst, _нара, ploi,
  { {0x4fc6007c, 0x2ca50b72, 0x7bc6384c, 0x00000000}},  //   сска, duld_, jeku,
  { {0x2d8c0073, 0xdb1d0010, 0x7afd00ea, 0x00000000}},  //   tade_, tesí, xyst,
  { {0x2737001d, 0xea010011, 0x63bb384d, 0x00000000}},  //   ủng_, _đắt_, _zbun,
  { {0x2d8c0aa4, 0x7afd0696, 0xdb1d0142, 0x00000000}},  //   rade_, wyst, resí,
  { {0x7afd384e, 0x2d8c1493, 0x7bc60020, 0x00000000}},  //   tyst, sade_, geku,
  { {0xa3ab007d, 0xa7fb0211, 0x6ee50025, 0x00000000}},  //   _खास_, _niña, _وسهل,
  { {0x7afd0046, 0x00000000, 0x00000000, 0x00000000}},  //   ryst,   ,   ,
  { {0x1959007e, 0x7bc6002d, 0x59f8005e, 0x00000000}},  //   равы_, beku, щеря_,
  { {0x26c900e7, 0x00000000, 0x00000000, 0x00000000}},  //   twao_,   ,   ,
  { {0x798e0009, 0x7c2d0145, 0x68e800f8, 0x00000000}},  // [c630] babw, _ijar, äddr,
  { {0xd56719ec, 0x7c2d0d3e, 0xa7fb0288, 0x00000000}},  //   стап, _hjar, _diña,
  { {0x7c2d009f, 0x69c737ef, 0xddc20087, 0x00000000}},  //   _kjar, meje, _otož,
  { {0x69c70030, 0x69d5384f, 0x690b013f, 0x00000000}},  //   leje, ldze, ıqdı,
  { {0xc0b20082, 0xa189003b, 0xa7fb0032, 0x00000000}},  //   _tưới_, абла_, _giña,
  { {0x7bc60c01, 0x69d5245c, 0xdb040036, 0x00000000}},  //   zeku, ndze, _zbió,
  { {0x92e90055, 0x7bc6000b, 0x349501fc, 0x00000000}},  //   মনে_, yeku, _фабр,
  { {0x63bb0dfc, 0xfaff0065, 0x2bd90204, 0x00000000}},  //   _ubun, ncës_, _बोला,
  { {0x69c70023, 0x443f0023, 0x6e3a3850, 0x00000000}},  //   keje, _iku_, fotb,
  { {0x69c7008e, 0x69d50107, 0x7c2d04cb, 0x00000000}},  //   jeje, jdze, _ajar,
  { {0x1ee7007a, 0x7c2d0492, 0xfbc60242, 0x00000000}},  //   _گوشی_, _bjar, обно,
  { {0x2baa001c, 0x7e7b00b0, 0x63ab0022, 0x00000000}},  //   _काळा, ppup, nggn,
  { {0x69c70047, 0x7c2d0c08, 0x7bc6002d, 0x00000000}},  //   feje, _djar, reku,
  { {0x7bc604d4, 0x69c70030, 0x201f0006, 0x00000000}},  //   seku, geje, liui_,
  { {0x7c2d000c, 0x443f3851, 0x7bc60032, 0x00000000}},  //   _fjar, _oku_, peku,
  { {0x442d0a9e, 0xfc3205d4, 0x6b8f001c, 0x00000000}},  //   _nje_, _تحت_, cacg,
  { {0xc6050055, 0xe7fb0061, 0x29110026, 0x00000000}},  // [c640] োচনা_, _एकरा_, azza_,
  { {0x443f117c, 0x7c2d0065, 0xbb1b00f4, 0x00000000}},  //   _aku_, _zjar, raît,
  { {0x7e630cc0, 0x201f0006, 0xec130014, 0x00000000}},  //   _minp, kiui_, _روید,
  { {0x6d43005b, 0x442d016c, 0xfe670379, 0x00000000}},  //   _myna, _cje_, _يد_,
  { {0x442d0065, 0xf7730014, 0x6d4304a5, 0x00000000}},  //   _dje_, _تاپ_, _lyna,
  { {0xddc20627, 0x6d4301f6, 0x442d18c8, 0x00000000}},  //   _stož, _oyna, _eje_,
  { {0x6d430146, 0xdcf8013e, 0x00000000, 0x00000000}},  //   _nyna, _devě,   ,
  { {0x442d212f, 0x78fb0049, 0xdfda005e, 0x00000000}},  //   _gje_, יפצו, рък_,
  { {0x6d43005a, 0x69c700e7, 0x00000000, 0x00000000}},  //   _ayna, yeje,   ,
  { {0x6d430fb6, 0x3cfe004a, 0x387a0521, 0x00000000}},  //   _byna, tytv_, _otpr_,
  { {0x69c70030, 0xa3df0061, 0x6d430016, 0x00000000}},  //   veje, ताच_, _cyna,
  { {0x69ad001c, 0x7ee60025, 0x200d0bc0, 0x00000000}},  //   _जाही, _وكان, chei_,
  { {0x69c7001a, 0x6e3a0010, 0x7e630146, 0x00000000}},  //   teje, potb, _finp,
  { {0x1fbc0044, 0x69d50089, 0xb5fb0048, 0x00000000}},  //   _অফিস, udze, _tuái,
  { {0x69c73852, 0x29050399, 0x69d509a4, 0x00000000}},  //   reje, ála_, rdze,
  { {0x7c2d0169, 0x9983010a, 0x69c70030, 0x00000000}},  //   _ujar, tojų_, seje,
  { {0x29050209, 0x356b00ed, 0x69c73853, 0x00000000}},  // [c650] šla_, арен_, peje,
  { {0x443f0030, 0x2bb10061, 0x6b8d2ff0, 0x00000000}},  //   _sku_, _झाडा, _heag,
  { {0x443f0022, 0x6b8d04cb, 0xfa340025, 0x00000000}},  //   _pku_, _keag, _تريد,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6b8d0e9e, 0x442d31b5, 0x23690059, 0x00000000}},  //   _meag, _vje_, žajo_,
  { {0x6b8d0122, 0xbb3c0049, 0x7e6b0006, 0x00000000}},  //   _leag, בעדי, _rugp,
  { {0xc5f2019b, 0x442d00bb, 0x7e6b00e0, 0x00000000}},  //   _אדם_, _tje_, _sugp,
  { {0xd3e300e9, 0x6b8d001a, 0x442d0065, 0x00000000}},  //   _تقری, _neag, _uje_,
  { {0x6d4305ad, 0xa3e802d2, 0x201f0006, 0x00000000}},  //   _syna, बार_, riui_,
  { {0x443d0038, 0xee360057, 0x201f007f, 0x00000000}},  //   low_, знь_, siui_,
  { {0xa7fb0219, 0x7e63227a, 0x443d0146, 0x00000000}},  //   _niño, _vinp, oow_,
  { {0x443d00b4, 0x7e630141, 0x7c3d012d, 0x00000000}},  //   now_, _winp, gosr,
  { {0x6d430036, 0xdee500d7, 0x7e630176, 0x00000000}},  //   _wyna, _холи, _tinp,
  { {0xddc30089, 0x443d00ab, 0x6d4300d9, 0x00000000}},  //   _minū, how_, _tyna,
  { {0x443d120c, 0xdb1d0161, 0x6b8d0c79, 0x00000000}},  //   kow_, resá, _feag,
  { {0x661c10d4, 0x4c9a009b, 0x27e604de, 0x00000000}},  //   _smrk, _השקע, ñon_,
  { {0x443d077a, 0x00000000, 0x00000000, 0x00000000}},  // [c660] dow_,   ,   ,
  { {0x6569014a, 0x7bd63854, 0x6e210058, 0x00000000}},  //   _şehr, _hayu, nilb,
  { {0x7bd60058, 0x14c80014, 0x7d010203, 0x00000000}},  //   _kayu, تهای_, nyls,
  { {0x68e10030, 0x27f90521, 0x7bd60085, 0x00000000}},  //   ælde, _gosn_, _jayu,
  { {0x7bd61d42, 0x7d0123b5, 0x91fc01c5, 0x00000000}},  //   _mayu, hyls, _diān,
  { {0x7bd6011c, 0x645900d9, 0x6e210022, 0x00000000}},  //   _layu, amwi, jilb,
  { {0xddc20006, 0xbfa30082, 0x443d038f, 0x00000000}},  //   _nuoš, _tiề, bow_,
  { {0x22be0089, 0x7bd600e0, 0x443d00b4, 0x00000000}},  //   tākā_, _nayu, cow_,
  { {0x6b8d3855, 0x6e2106d3, 0x00000000, 0x00000000}},  //   _reag, filb,   ,
  { {0xddcb011f, 0x6b8d1d57, 0x7bd60058, 0x00000000}},  //   ğişt, _seag, _aayu,
  { {0x61e80018, 0x7bd63856, 0x6b8d006c, 0x00000000}},  //   _indl, _bayu, _peag,
  { {0x61fa0011, 0x101605d4, 0x7bd600f6, 0x00000000}},  //   _hotl, _عباد, _cayu,
  { {0x61fa0161, 0x7bd621fb, 0x81b30044, 0x00000000}},  //   _kotl, _dayu, _জোট_,
  { {0xaa6403f3, 0xa7fb008e, 0xcf2505f3, 0x00000000}},  //   етск, _piño, _ترمي,
  { {0x6b8d002a, 0x61fa00d4, 0x7c3d0059, 0x00000000}},  //   _teag, _motl, posr,
  { {0xb8e504da, 0x7bd629ea, 0x999800b9, 0x00000000}},  //   _एह_, _gayu, borů_,
  { {0x473401fb, 0x00000000, 0x00000000, 0x00000000}},  // [c670] ентс,   ,   ,
  { {0x2d8e0211, 0x61fa014a, 0xf8ae02fd, 0x00000000}},  //   _jefe_, _notl, دکی_,
  { {0xf9fc009b, 0x443d0036, 0x7bd60022, 0x00000000}},  //   _להזמ, tow_, _yayu,
  { {0x61e8000c, 0x320c0022, 0x4ab10316, 0x00000000}},  //   _andl, _aldy_, _जमाव,
  { {0xe3b003ec, 0x443d0498, 0x645901d6, 0x00000000}},  //   ارم_, row_, rmwi,
  { {0x61fa00e5, 0xa9250142, 0x443d00b4, 0x00000000}},  //   _cotl, poľč, sow_,
  { {0x9998013e, 0xdfd100a1, 0xa3ab0061, 0x00000000}},  //   zorů_, ہيں_, _खाऊ_,
  { {0xddc20006, 0x61e803a1, 0x69d73857, 0x00000000}},  //   _ruoš, _endl, _laxe,
  { {0x3e72001a, 0x6e2102d8, 0x7bd601a3, 0x00000000}},  //   _cât_, tilb, _rayu,
  { {0x61fa0039, 0x7bd604cb, 0x6fa90061, 0x00000000}},  //   _gotl, _sayu, _टाकू,
  { {0x7bd60169, 0x23720006, 0x3f840022, 0x00000000}},  //   _payu, žyje_, bbmu_,
  { {0xea01001d, 0x6e21011c, 0x999800b9, 0x00000000}},  //   _đạt_, silb, torů_,
  { {0x81d00055, 0x61e80030, 0x3e722d2f, 0x00000000}},  //   ষার_, _yndl, _gât_,
  { {0x186a00ed, 0x2baa0204, 0xab5b006b, 0x00000000}},  //   жави_, _काका, ndüy,
  { {0xd94301e0, 0x2d85032c, 0x7bd6011c, 0x00000000}},  //   вери, mble_, _tayu,
  { {0x7b070010, 0x00000000, 0x00000000, 0x00000000}},  //   örté,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [c680]   ,   ,   ,
  { {0x2d850263, 0x2ca50009, 0x00000000, 0x00000000}},  //   nble_, orld_,   ,
  { {0x61fa0a16, 0x2d85008e, 0xf241007e, 0x00000000}},  //   _rotl, ible_, _якiя_,
  { {0x3f8f3858, 0x61fa3859, 0x00000000, 0x00000000}},  //   _negu_, _sotl,   ,
  { {0xab5b001f, 0x61fa0142, 0x00000000, 0x00000000}},  //   rfüg, _potl,   ,
  { {0xc5d5008b, 0xd2500439, 0x3f8f010e, 0x00000000}},  //   _пісь, دنت_, _aegu_,
  { {0x2d8e0173, 0x61fa385a, 0x6d47010e, 0x00000000}},  //   _refe_, _votl, üjal,
  { {0xf8b3009b, 0x2d85004a, 0x00000000, 0x00000000}},  //   דשה_, eble_,   ,
  { {0xf65f0030, 0x3f8f0032, 0x934301ab, 0x00000000}},  //   _især_, _degu_, _анте,
  { {0x62821683, 0x61e80190, 0xdce30066, 0x00000000}},  //   mpoo, _undl, _senġ,
  { {0xb4bc0061, 0x6282006c, 0xe0d2006d, 0x00000000}},  //   _अहो_, lpoo, _جزء_,
  { {0xb5fb008e, 0x69d70203, 0x2d85028a, 0x00000000}},  //   _juár, _saxe, able_,
  { {0xfc3f0051, 0x2d850388, 0xdddb006b, 0x00000000}},  //   roí_, bble_, qquş,
  { {0x7e7d13a1, 0x00000000, 0x00000000, 0x00000000}},  //   íspe,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x23dd001c, 0x7b67005e, 0xa3b30309, 0x00000000}},  //   _नोंद, _отпе, ज्ञ_,
  { {0x69d733c8, 0xa3e8007d, 0x00000000, 0x00000000}},  // [c690] _taxe, बाई_,   ,
  { {0x62820ace, 0x00000000, 0x00000000, 0x00000000}},  //   dpoo,   ,   ,
  { {0xd49b0131, 0xdb1d385b, 0x00000000, 0x00000000}},  //   юра_, sesä,   ,
  { {0x6284001e, 0x79950020, 0xdcf8012d, 0x00000000}},  //   ģion, lazw, _jevđ,
  { {0x6284000d, 0xc2cb007a, 0x3f8f0093, 0x00000000}},  //   ţion, تبال_, _regu_,
  { {0x3f8f010e, 0x2cac00ea, 0xa06902dc, 0x00000000}},  //   _segu_, kudd_, пака_,
  { {0xab5b006b, 0x614200e2, 0x00000000, 0x00000000}},  //   rdüy, леша,   ,
  { {0xb5fb008e, 0x00000000, 0x00000000, 0x00000000}},  //   _guár,   ,   ,
  { {0xe235003b, 0x442f0eb0, 0x79950258, 0x00000000}},  //   _знањ, mng_, kazw,
  { {0x273e00ad, 0x272c001d, 0x442f011c, 0x00000000}},  //   ững_, ếng_, lng_,
  { {0x442f385c, 0x3f8f04fe, 0x2d850133, 0x00000000}},  //   ong_, _tegu_, rble_,
  { {0x442f0a1d, 0x2d850146, 0xf3f900e5, 0x00000000}},  //   nng_, sble_, _biţi_,
  { {0xef0e0242, 0x62990112, 0x200f385d, 0x00000000}},  //   _см_, nswo, _ilgi_,
  { {0x2fcd0250, 0x79950dfc, 0x6f1d16b5, 0x00000000}},  //   leeg_, gazw, úscu,
  { {0x3ead0022, 0x442f0085, 0xa8562337, 0x00000000}},  //   luet_, kng_, етај,
  { {0xad1a00b6, 0x80a70164, 0x6282098e, 0x00000000}},  //   _מוצר, _घटने, ypoo,
  { {0xe7370057, 0xd6cf00a1, 0xab6602d3, 0x00000000}},  // [c6a0] еет_, یقہ_, _явил,
  { {0x7ae4022b, 0x62990ace, 0x442f0093, 0x00000000}},  //   _irit, dswo, eng_,
  { {0xe475007e, 0x69dc0544, 0x546a0a78, 0x00000000}},  //   вучэ, mdre, чаем_,
  { {0x69dc1ef2, 0x69ce010f, 0x442f0058, 0x00000000}},  //   ldre, lebe, gng_,
  { {0x629901c3, 0x3ead00ea, 0x2fcd01c3, 0x00000000}},  //   gswo, juet_, deeg_,
  { {0x6282000c, 0x442f09f3, 0x69ce0304, 0x00000000}},  //   rpoo, ang_, nebe,
  { {0x6282095c, 0x2bb101f5, 0x69dc385e, 0x00000000}},  //   spoo, _झाला, idre,
  { {0x69ce010f, 0x69dc079d, 0x62820943, 0x00000000}},  //   hebe, hdre, ppoo,
  { {0xcf260054, 0x6b9f001c, 0x61eb0047, 0x00000000}},  //   عربي, _rdqg, állí,
  { {0x44261203, 0xba3b385f, 0x7bc40026, 0x00000000}},  //   lio_, nuït, _abiu,
  { {0x69ce0030, 0x7ae4022b, 0x69dc1d03, 0x00000000}},  //   debe, _arit, ddre,
  { {0x4426010a, 0x1beb013d, 0x69dc063f, 0x00000000}},  //   nio_, टाइल_, edre,
  { {0x69ce032e, 0x69dc095d, 0xdcfa0089, 0x00000000}},  //   febe, fdre, tatē,
  { {0x7ae425c3, 0x44263860, 0x69ce001f, 0x00000000}},  //   _drit, hio_, gebe,
  { {0x44262fea, 0x7ae40368, 0x442f0271, 0x00000000}},  //   kio_, _erit, yng_,
  { {0x23690e00, 0x67d402d3, 0x44260091, 0x00000000}},  //   žaji_, лосу, jio_,
  { {0x44263861, 0x69ce027b, 0x7bcf3862, 0x00000000}},  // [c6b0] dio_, bebe, mecu,
  { {0x69ce02d5, 0x442f018e, 0x7bcf00ab, 0x00000000}},  //   cebe, wng_, lecu,
  { {0x44263863, 0xdcf8001e, 0x442f00e0, 0x00000000}},  //   fio_, _ievē, tng_,
  { {0xf1d902fb, 0x7ae4021e, 0x442f0f5e, 0x00000000}},  //   _योजन, _yrit, ung_,
  { {0x6abd08e0, 0xed4600a6, 0x442f0145, 0x00000000}},  //   ntsf, _چپ_, rng_,
  { {0xc692007b, 0x7c2601aa, 0x2fcd07a5, 0x00000000}},  //   _דאך_, zikr, weeg_,
  { {0x44260119, 0x8c3d005a, 0x442f00e0, 0x00000000}},  //   bio_, luğu, png_,
  { {0x44260819, 0x69ce0032, 0x387c0010, 0x00000000}},  //   cio_, zebe, _évre_,
  { {0x69dc0190, 0x7bcf1965, 0x386b0085, 0x00000000}},  //   ydre, decu, _micr_,
  { {0x7ae4008d, 0x7d09012b, 0x69ce002d, 0x00000000}},  //   _rrit, дног_, xebe,
  { {0x6d4a018e, 0x7ae4283b, 0x7c26010a, 0x00000000}},  //   _cyfa, _srit, tikr,
  { {0x6abd3864, 0xab2a0451, 0x69ce0b78, 0x00000000}},  //   ftsf, дома_, webe,
  { {0x69ce002d, 0x69dc0240, 0x68e10190, 0x00000000}},  //   tebe, tdre, ældn,
  { {0x4426062b, 0x8c3d01f6, 0x7c263865, 0x00000000}},  //   zio_, duğu, sikr,
  { {0x7ae40038, 0x69dc0374, 0x6d4a018e, 0x00000000}},  //   _writ, rdre, _gyfa,
  { {0xea01001d, 0x69ce0059, 0x7ae4010f, 0x00000000}},  //   _đất_, sebe, _trit,
  { {0x442601cd, 0xcf92007b, 0x7c240051, 0x00000000}},  // [c6c0] vio_, יטן_, _imir,
  { {0x44260016, 0x68e50009, 0x26d2005b, 0x00000000}},  //   wio_, _frhd, rwyo_,
  { {0x777d0009, 0x00000000, 0x00000000, 0x00000000}},  //   _ffsx,   ,   ,
  { {0x64a3007e, 0x62800045, 0x00000000, 0x00000000}},  //   раца, _ptmo,   ,
  { {0xc7b3019b, 0x38603866, 0x8c3d014a, 0x00000000}},  //   _דבר_, mmir_, cuğu,
  { {0x44263867, 0x3860006b, 0xa1580839, 0x00000000}},  //   sio_, lmir_, налу_,
  { {0x7c24016c, 0x00000000, 0x00000000, 0x00000000}},  //   _omir,   ,   ,
  { {0x4fd4005e, 0x4fc60081, 0x7bcf00e5, 0x00000000}},  //   ужит, тска, xecu,
  { {0x09aa0055, 0x44240035, 0x7bcf01ee, 0x00000000}},  //   খ্যা, _imm_, vecu,
  { {0x7c241670, 0x60270263, 0x5fae0061, 0x00000000}},  //   _amir, _pèmè, _टाकल,
  { {0x6f1d0048, 0x00000000, 0x00000000, 0x00000000}},  //   úscr,   ,   ,
  { {0x6abd0039, 0xc00600ed, 0x386000ca, 0x00000000}},  //   ttsf, _шпек, jmir_,
  { {0x7bcf001a, 0x7a290006, 0x7bdd010e, 0x00000000}},  //   recu, ežta, rdsu,
  { {0x7c24002b, 0x7bcf238d, 0x6abd02e7, 0x00000000}},  //   _emir, secu, rtsf,
  { {0x7bcf253d, 0xef190036, 0x4424002b, 0x00000000}},  //   pecu, daży_, _omm_,
  { {0x38602a23, 0xdb1d00ea, 0x2ee60087, 0x00000000}},  //   gmir_, kesø, _krof_,
  { {0x291e1801, 0x00000000, 0x00000000, 0x00000000}},  // [c6d0] útar_,   ,   ,
  { {0x80b80055, 0xa5670167, 0xdb1d06ec, 0x00000000}},  //   _আনন্, ندان, desø,
  { {0xd371057d, 0xdb0d04f3, 0xd5b802dc, 0x00000000}},  //   مها_, _ibañ, ъст_,
  { {0x7640000c, 0xfbdf00c4, 0x6015013e, 0x00000000}},  //   _ímyn, ndê_, _káme,
  { {0x44240009, 0x59c00164, 0xeabf0197, 0x00000000}},  //   _dmm_, श्वर, ntù_,
  { {0x26d902d5, 0x44240145, 0x20021361, 0x00000000}},  //   _isso_, _emm_, ökin_,
  { {0x74f700a1, 0x44240145, 0xfbab0044, 0x00000000}},  //   _جہاز_, _fmm_, গ্যত,
  { {0x44240146, 0xdb1d08c8, 0x00000000, 0x00000000}},  //   _gmm_, besø,   ,
  { {0x2f5407ca, 0xfe4501f9, 0x60150142, 0x00000000}},  //   итьс, лнио, _náme,
  { {0xaded013d, 0x7c240091, 0x8ca4006e, 0x00000000}},  //   जाइन_, _smir, _किशो,
  { {0x38603868, 0xd00e01b2, 0x00000000, 0x00000000}},  //   ymir_, زلی_,   ,
  { {0x26d91862, 0x23690295, 0x26cb0009, 0x00000000}},  //   _osso_, žaju_, _opco_,
  { {0x8f9a009b, 0x645b0051, 0x00000000, 0x00000000}},  //   _ניסי, _mhui,   ,
  { {0x2fc60119, 0xad240123, 0xddc30035, 0x00000000}},  //   _zbog_, اریو, _dinţ,
  { {0x07a6003b, 0x38602f17, 0xc7a604dd, 0x00000000}},  //   лавн, tmir_, ливк,
  { {0x7c240213, 0x200d007f, 0x00000000, 0x00000000}},  //   _umir, nkei_,   ,
  { {0x3860027b, 0x3ebf3869, 0xdc3b0049, 0x00000000}},  // [c6e0] rmir_, ntut_, _רעפר,
  { {0x44243540, 0x386008f4, 0x00000000, 0x00000000}},  //   _smm_, smir_,   ,
  { {0x26d90207, 0x200d0b90, 0x601501ca, 0x00000000}},  //   _esso_, kkei_, _záme,
  { {0x645b0195, 0x69de0065, 0x290a0006, 0x00000000}},  //   _chui, _hape, myba_,
  { {0x244e01ca, 0x645b0051, 0x14170025, 0x00000000}},  //   nými_, _dhui, دينة_,
  { {0x27e013e4, 0x69de0023, 0x8ca4007d, 0x00000000}},  //   ldin_, _jape, _किलो,
  { {0x69de000b, 0x645b0051, 0x26c0386a, 0x00000000}},  //   _mape, _fhui, ltio_,
  { {0x27e02b84, 0x69de386b, 0x44240093, 0x00000000}},  //   ndin_, _lape, _umm_,
  { {0x26c00016, 0x60e00006, 0x27e00048, 0x00000000}},  //   ntio_, _žymė, idin_,
  { {0x290a0006, 0x27e000b0, 0x7d080007, 0x00000000}},  //   kyba_, hdin_, tyds,
  { {0x85f7007b, 0x6b960c87, 0x6e2800ea, 0x00000000}},  //   אציע_, _beyg, ridb,
  { {0x290a0006, 0x31570049, 0x60da010e, 0x00000000}},  //   dyba_, _גיבן_, _istm,
  { {0x27e01419, 0x69de04be, 0x6f1b0036, 0x00000000}},  //   ddin_, _bape, czuc,
  { {0x69de0207, 0xeabf0197, 0x27e000f2, 0x00000000}},  //   _cape, rtù_, edin_,
  { {0x69de10ed, 0x7d7b0049, 0x4d7b009b, 0x00000000}},  //   _dape, _אנוו, _ארוע,
  { {0x6d5811e6, 0x6c830025, 0x80d70061, 0x00000000}},  //   _izva, _اليم, _मनसे,
  { {0x69de00c4, 0x7bdf0026, 0x0a6b0242, 0x00000000}},  // [c6f0] _fape, _iaqu, _прои_,
  { {0x645b002a, 0x6449375b, 0x60da006c, 0x00000000}},  //   _shui, _skei, _ostm,
  { {0x6f1b0026, 0x26c00052, 0x76450253, 0x00000000}},  //   zzuc, atio_, rohy,
  { {0x69de0036, 0x1e010183, 0x7bdf00c4, 0x00000000}},  //   _zape, _लक्ष_, _jaqu,
  { {0x7bdf0211, 0x26c0005b, 0x04f50044, 0x00000000}},  //   _maqu, ctio_, চনের_,
  { {0x7bdf00f4, 0x69de00f6, 0xa7fb004a, 0x00000000}},  //   _laqu, _xape, _viñu,
  { {0x645b386c, 0x801509da, 0x3d0e013d, 0x00000000}},  //   _thui, ифиц, ानों_,
  { {0x7bdf0181, 0x645b00e7, 0x3ebf0288, 0x00000000}},  //   _naqu, _uhui, ttut_,
  { {0xddcb001e, 0xcdf50147, 0xf1a7007c, 0x00000000}},  //   _augš, ачны, _брен,
  { {0x6f1b0036, 0x244e0161, 0x3ebf386d, 0x00000000}},  //   rzuc, vými_, rtut_,
  { {0xd1310025, 0x22470066, 0x6b96014a, 0x00000000}},  //   _بما_, monk_, _peyg,
  { {0x69de0198, 0x8c4602b8, 0x6b6605f6, 0x00000000}},  //   _sape, реме, икна,
  { {0x7bdf0181, 0x63a40051, 0x8c3d0095, 0x00000000}},  //   _daqu, óini, tuğr,
  { {0xc33200b6, 0x290a0006, 0x3ead386e, 0x00000000}},  //   קום_, tyba_, mret_,
  { {0x69de31ec, 0x98a3072b, 0x779601fc, 0x00000000}},  //   _vape, жисе, ијац,
  { {0x69de0b28, 0x6ca404e8, 0x290a0006, 0x00000000}},  //   _wape, _اصول, ryba_,
  { {0xdce1038c, 0x18670407, 0x7c3d386f, 0x00000000}},  // [c700] malı, рати_, érre,
  { {0xe6170269, 0x63bb0022, 0x26c01703, 0x00000000}},  //   аду_, _acun, rtio_,
  { {0x26c03870, 0x224701aa, 0x3ead1bac, 0x00000000}},  //   stio_, donk_, hret_,
  { {0xdce10279, 0x799c1e28, 0x26c000b0, 0x00000000}},  //   nalı, larw, ptio_,
  { {0x3ead0030, 0x6266189f, 0xdc370049, 0x00000000}},  //   jret_, авда, סאנט_,
  { {0x5bd303d7, 0x2cac018e, 0x3ead0374, 0x00000000}},  //   _तस्व, yrdd_, dret_,
  { {0x64a3132e, 0xdce1005a, 0x3ead3871, 0x00000000}},  //   _мара, kalı, eret_,
  { {0x0443003b, 0x601501ca, 0x63bb0051, 0x00000000}},  //   _десн, _rámc, _gcun,
  { {0x3ead0056, 0xdefa007c, 0x2cac0016, 0x00000000}},  //   gret_, тый_, wrdd_,
  { {0x59b203d7, 0x7bdf1261, 0xb6070066, 0x00000000}},  //   _जागर, _saqu, _gaġġ,
  { {0x7bdf0211, 0xfc400802, 0x799c0022, 0x00000000}},  //   _paqu, čín_, darw,
  { {0x3ead3872, 0xdcfa0089, 0x1b1f0044, 0x00000000}},  //   bret_, latī, _যুগে_,
  { {0x7bdf06c2, 0x799c018e, 0x00000000, 0x00000000}},  //   _vaqu, farw,   ,
  { {0x5d840025, 0x799c0016, 0xdcea0066, 0x00000000}},  //   _الغل, garw, _nefħ,
  { {0x6d5818c5, 0x7bdf00d6, 0x6e3d0010, 0x00000000}},  //   _uzva, _taqu, ésbe,
  { {0x20d80011, 0xdce10276, 0x00000000, 0x00000000}},  //   _mũi_, calı,   ,
  { {0x799c10ba, 0x6b9d004a, 0xdcfa0089, 0x00000000}},  // [c710] barw, masg, katī,
  { {0xb8dd0055, 0x63bb0035, 0x79a720d2, 0x00000000}},  //   _ইন_, _scun, _трие,
  { {0x69d52b09, 0x245c01dc, 0x92d60044, 0x00000000}},  //   meze, zíme_, িমো_,
  { {0x6b9d0089, 0x3ead1eb5, 0x69c73873, 0x00000000}},  //   nasg, yret_, lfje,
  { {0x1708026c, 0x00000000, 0x00000000, 0x00000000}},  //   _پہلی_,   ,   ,
  { {0x4095005e, 0x245c01ca, 0x3ead009d, 0x00000000}},  //   брит, víme_, vret_,
  { {0xdce1005d, 0x6b9d182b, 0x224701d6, 0x00000000}},  //   yalı, kasg, ronk_,
  { {0x69d50010, 0x8938009b, 0x2938009b, 0x00000000}},  //   heze, ירוע_, יאון_,
  { {0x60150845, 0x69d50047, 0xe1f30d3a, 0x00000000}},  //   _cáma, keze, _وسط_,
  { {0x69d50010, 0x3ead3874, 0xab5b01a2, 0x00000000}},  //   jeze, rret_, rfül,
  { {0xeb9a005e, 0x69d50010, 0x3ead016e, 0x00000000}},  //   лин_, deze, sret_,
  { {0x6b9d0435, 0x320500ab, 0x3ead0023, 0x00000000}},  //   gasg, _holy_, pret_,
  { {0x8e853875, 0x1ee7025a, 0xdce1005a, 0x00000000}},  //   _угле, _خوشی_, ralı,
  { {0x69d51440, 0x61e106a9, 0x32050068, 0x00000000}},  //   geze, _jall, _joly_,
  { {0x61e13876, 0xfbdf0181, 0x78b5016c, 0x00000000}},  //   _mall, glês_, guzv,
  { {0x600e0045, 0x7b070023, 0x3205004a, 0x00000000}},  //   _cùmh, ërtë, _loly_,
  { {0x69d50e43, 0x3f7a0049, 0x6b8411c8, 0x00000000}},  // [c720] beze, אָבע, _ifig,
  { {0x61e120d6, 0x499619ea, 0x00000000, 0x00000000}},  //   _nall, _ушит,   ,
  { {0xd910089d, 0xd05a006b, 0x182802fd, 0x00000000}},  //   _غیر_, _ertə, _نقدی_,
  { {0xad360049, 0xdb1d0010, 0xdb0d006c, 0x00000000}},  //   זנעס_, yesü, _ebaõ,
  { {0x61e13877, 0x6a60010f, 0xdcfa0089, 0x00000000}},  //   _ball, röff, tatī,
  { {0x61e109d9, 0x00000000, 0x00000000, 0x00000000}},  //   _call,   ,   ,
  { {0x61e1051b, 0x859b009b, 0xdcfa0089, 0x00000000}},  //   _dall, _תשלו, ratī,
  { {0x68e10f4b, 0xdb1d2939, 0x9ee80025, 0x00000000}},  //   ældi, tesü, لفعل_,
  { {0x61e11642, 0x69d50010, 0xdcfa0089, 0x00000000}},  //   _fall, yeze, patī,
  { {0x61e102f1, 0xc27b034e, 0x6ce3006e, 0x00000000}},  //   _gall, _ערבי, गिंग_,
  { {0x69d50047, 0xab5b2084, 0x00000000, 0x00000000}},  //   veze, rfüm,   ,
  { {0x69d5114d, 0xc6050061, 0x60150010, 0x00000000}},  //   weze, _शक्य_, _táma,
  { {0x69d507ef, 0x6b9d0032, 0x940c006b, 0x00000000}},  //   teze, rasg, ülər_,
  { {0x7f3b0049, 0x6b8400c4, 0x20060112, 0x00000000}},  //   _געדו, _efig, _hooi_,
  { {0x5d9b00b6, 0x69d5002d, 0x6b840016, 0x00000000}},  //   _גבוה, reze, _ffig,
  { {0x69d53878, 0xb901007d, 0x08550245, 0x00000000}},  //   seze, _धन_, іваю,
  { {0x20060100, 0x7c2f01d0, 0x69d515ea, 0x00000000}},  // [c730] _mooi_, micr, peze,
  { {0xdb04010f, 0x7aed0e49, 0x60330035, 0x00000000}},  //   _heiß, _irat, rămi,
  { {0x4d7b0049, 0xe4d50774, 0x9379026b, 0x00000000}},  //   ארבע, تقاد, абет_,
  { {0x61e11815, 0x7aed0340, 0x4cbb007b, 0x00000000}},  //   _sall, _krat, רמאג,
  { {0x2d9e023e, 0x81e20055, 0x32050133, 0x00000000}},  //   kate_, ধান_, _poly_,
  { {0x2d9e0004, 0x20893879, 0x20c10010, 0x00000000}},  //   jate_, айки_, tói_,
  { {0x61e1387a, 0x6019003b, 0x00000000, 0x00000000}},  //   _vall, ицир_,   ,
  { {0x7aed0af0, 0x20c103f0, 0x60090407, 0x00000000}},  //   _orat, rói_, рним_,
  { {0x61e10004, 0x442f011c, 0xd5c6007d, 0x00000000}},  //   _tall, mig_, र्वज,
  { {0x2d9e121e, 0x442f02cc, 0x6b840197, 0x00000000}},  //   gate_, lig_, _sfig,
  { {0x63a4009f, 0x7aed000d, 0x6d46011f, 0x00000000}},  //   ðing, _arat, şkan,
  { {0x7aed13a1, 0x200601bb, 0xae1d0164, 0x00000000}},  //   _brat, _gooi_, योजन_,
  { {0x2d9e1d7a, 0xab5b010f, 0x63a90066, 0x00000000}},  //   bate_, nfüh, _mden,
  { {0x2d9e000d, 0x2d810004, 0xe81c007d, 0x00000000}},  //   cate_, _ühe_, नसभा_,
  { {0x63a90030, 0x7aed3098, 0x5fdd006e, 0x00000000}},  //   _oden, _erat, _मसाल,
  { {0x7aed04b4, 0x442f0059, 0x63a90023, 0x00000000}},  //   _frat, jig_, _nden,
  { {0x644b0016, 0x562a387b, 0x00000000, 0x00000000}},  // [c740] dogi, ажам_,   ,
  { {0x63a9148a, 0x442f00d4, 0x00000000, 0x00000000}},  //   _aden, eig_,   ,
  { {0x442f0a48, 0x2bc10164, 0x6289004a, 0x00000000}},  //   fig_, ष्का, _ateo,
  { {0x442f138a, 0x2d9e387c, 0xab5b01a2, 0x00000000}},  //   gig_, zate_, ffüh,
  { {0x20060007, 0x63a90016, 0x2d9e0082, 0x00000000}},  //   _rooi_, _dden, yate_,
  { {0x66070107, 0xfe6704e8, 0x63a908a7, 0x00000000}},  //   _gojk, _زد_, _eden,
  { {0x442f006a, 0x2d9e167c, 0x644b1edb, 0x00000000}},  //   big_, vate_, bogi,
  { {0x644b0211, 0x63a4000c, 0xa2d5013d, 0x00000000}},  //   cogi, ðind, _मैक्,
  { {0x2d9e0585, 0x81cf0055, 0x601c0047, 0x00000000}},  //   tate_, ষয়_, _néme,
  { {0x63a918a2, 0x70f60644, 0x27370082, 0x00000000}},  //   _zden, _وسائ, ầng_,
  { {0xdca300ed, 0x1fac0044, 0x5d54387d, 0x00000000}},  //   маќи, ক্ষস, якот,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d9e1575, 0x10690025, 0xaf36023c, 0x00000000}},  //   pate_, _احلى_, _برات,
  { {0x7aed0119, 0x442f02ae, 0xdb04010f, 0x00000000}},  //   _vrat, zig_, _weiß,
  { {0x69c3011f, 0xf8070816, 0x644b1856, 0x00000000}},  //   _önem, очан, yogi,
  { {0x2d9c00ea, 0x9f4f00f6, 0x442f00f8, 0x00000000}},  //   _heve_, _gogó_, xig_,
  { {0x442f00b5, 0x66070039, 0x7c2d0020, 0x00000000}},  // [c750] vig_, _pojk, _imar,
  { {0x442f26c3, 0x644b0016, 0x2d9c0087, 0x00000000}},  //   wig_, wogi, _jeve_,
  { {0x442f04e5, 0x7c2d0093, 0x644b0006, 0x00000000}},  //   tig_, _kmar, togi,
  { {0x2d9c0263, 0x245c000c, 0xab5b01a2, 0x00000000}},  //   _leve_, tíma_, tfüh,
  { {0x386902e1, 0x442f21ef, 0x7c2d13e1, 0x00000000}},  //   mmar_, rig_, _mmar,
  { {0x442f0343, 0x2d9c1a92, 0x386902e1, 0x00000000}},  //   sig_, _neve_, lmar_,
  { {0xab5b010f, 0x7c2d0059, 0xb88206b8, 0x00000000}},  //   sfüh, _omar, žíva,
  { {0x63a90030, 0x201911ea, 0x3eab004a, 0x00000000}},  //   _uden, ósi_, ácto_,
  { {0x442d387e, 0x443f387f, 0x2d9c0197, 0x00000000}},  //   _ime_, _iju_, _beve_,
  { {0x8c080055, 0x60150047, 0x443f012d, 0x00000000}},  //   _লগইন_, _támo, _hju_,
  { {0x2d9c220a, 0x3869003b, 0x442d0058, 0x00000000}},  //   _deve_, kmar_, _kme_,
  { {0xca293880, 0x442d3881, 0x00000000, 0x00000000}},  //   _גם_, _jme_,   ,
  { {0x442d00f4, 0x386900ca, 0x2d9c3882, 0x00000000}},  //   _mme_, dmar_, _feve_,
  { {0x7c2d0032, 0x442d3883, 0x443f0087, 0x00000000}},  //   _emar, _lme_, _lju_,
  { {0xfe700a90, 0x34ba001c, 0x25a10030, 0x00000000}},  //   _شده_, _उमेद, dahl_,
  { {0xbb46008b, 0x443f0091, 0x201f0066, 0x00000000}},  //   _нейк, _nju_, nhui_,
  { {0x248a0022, 0x09d10044, 0x00000000, 0x00000000}},  // [c760] _stbm_, ায়া,   ,
  { {0x442d01aa, 0x2d8500d4, 0x7c2d0832, 0x00000000}},  //   _ame_, ncle_, _zmar,
  { {0x7c2d018e, 0x443f0093, 0x442d1658, 0x00000000}},  //   _ymar, _bju_, _bme_,
  { {0x7c2d0126, 0x442d09b8, 0xe4520774, 0x00000000}},  //   _xmar, _cme_, رضا_,
  { {0xcfc30055, 0x201f0020, 0x2bc10164, 0x00000000}},  //   ্যান, dhui_, ष्टा,
  { {0x64a60245, 0x442d00f4, 0x6724016c, 0x00000000}},  //   _нага, _eme_, mzij,
  { {0x67242962, 0x2d9c0e6d, 0x442d0fd1, 0x00000000}},  //   lzij, _reve_, _fme_,
  { {0xd0100054, 0x93a901f7, 0x853b009b, 0x00000000}},  //   ئلة_, _واقف_, _הגלי,
  { {0x67242480, 0x0443012b, 0x644300f4, 0x00000000}},  //   nzij, _четн, énie,
  { {0xab5b0129, 0x63a21ae9, 0x00000000, 0x00000000}},  //   ngüe, laon,   ,
  { {0x38693884, 0x442d0022, 0x7c2d00d9, 0x00000000}},  //   ymar_, _yme_, _pmar,
  { {0x63a20020, 0x25a1010f, 0xbb94007c, 0x00000000}},  //   naon, zahl_, нающ,
  { {0x2d9c0181, 0x7b6402ea, 0x67242570, 0x00000000}},  //   _teve_, етре, jzij,
  { {0x672401a1, 0x6b860009, 0x58d50088, 0x00000000}},  //   dzij, ackg, могт,
  { {0x63a20a6e, 0x2600013d, 0xee290025, 0x00000000}},  //   kaon, रानी_, _بأنه_,
  { {0x7c2d014a, 0x25a1010f, 0x63a200e7, 0x00000000}},  //   _umar, wahl_, jaon,
  { {0x386900d6, 0xdce8047f, 0xf77f0ddb, 0x00000000}},  // [c770] rmar_, madı, _caça_,
  { {0x3869027b, 0x442d0027, 0xdce8005d, 0x00000000}},  //   smar_, _sme_, ladı,
  { {0xf6500a4f, 0x67240107, 0x7c3d0b05, 0x00000000}},  //   ائق_, azij, onsr,
  { {0xd3712aea, 0xf77f02d5, 0xdce8005d, 0x00000000}},  //   نها_, _faça_, nadı,
  { {0x27e9005d, 0x6440003b, 0x2d850133, 0x00000000}},  //   mdan_, _djmi, ycle_,
  { {0xdb1d00f8, 0x3f9d0022, 0x00000000, 0x00000000}},  //   besö, _sewu_,   ,
  { {0xa4d40088, 0x94d4004d, 0x63a20058, 0x00000000}},  //   _порі, _порц, baon,
  { {0x27e92408, 0x442d002d, 0x00000000, 0x00000000}},  //   ndan_, _ume_,   ,
  { {0x26c90058, 0xdce80279, 0x27e9002d, 0x00000000}},  //   ntao_, dadı, idan_,
  { {0x27e93885, 0x645901a2, 0x7c3d00d9, 0x00000000}},  //   hdan_, llwi, ensr,
  { {0x6724002b, 0x4d6501fb, 0x799e01aa, 0x00000000}},  //   zzij, ьков, _repw,
  { {0x3f15004c, 0x443d0016, 0x2d8500ab, 0x00000000}},  //   _одес, nnw_, scle_,
  { {0x27e93886, 0x64590009, 0x00000000, 0x00000000}},  //   ddan_, ilwi,   ,
  { {0xf77f153d, 0x9e640088, 0xce6b064b, 0x00000000}},  //   _raça_, _звід, _уред_,
  { {0x63a22fff, 0x69cd01f5, 0x601c009d, 0x00000000}},  //   yaon, द्धी, _héma,
  { {0x6f160046, 0x27e9093e, 0x998d0091, 0x00000000}},  //   _życi, gdan_, đeš_,
  { {0x63a2016e, 0x060a007e, 0x00000000, 0x00000000}},  // [c780] vaon, онак_,   ,
  { {0x67240209, 0x63a20020, 0x7ae43702, 0x00000000}},  //   rzij, waon, _isit,
  { {0x63a23887, 0xd94600d7, 0x9f420142, 0x00000000}},  //   taon, _цени, ľké_,
  { {0x69dc05d5, 0x69ce01bb, 0xf77f0181, 0x00000000}},  //   lere, lfbe, _taça_,
  { {0x63a201ed, 0x366a0364, 0x00000000, 0x00000000}},  //   raon, _мамо_,   ,
  { {0x69dc004e, 0x201d04be, 0x7ae40020, 0x00000000}},  //   nere, _alwi_, _msit,
  { {0x69dc001a, 0x63a20166, 0x644319d5, 0x00000000}},  //   iere, paon, énic,
  { {0x7ae400b0, 0x00000000, 0x00000000, 0x00000000}},  //   _osit,   ,   ,
  { {0x69dc0eb6, 0x601504bb, 0xa1c6005e, 0x00000000}},  //   kere, _zámk, _обад,
  { {0x69dc19da, 0x601c00f4, 0x27e9005d, 0x00000000}},  //   jere, _déma, zdan_,
  { {0x45b700b6, 0x27e93888, 0x7ae40622, 0x00000000}},  //   ופיל_, ydan_, _asit,
  { {0x6280011c, 0x61e8011c, 0x63a00161, 0x00000000}},  //   _kumo, _hadl, _jemn,
  { {0xdce802b9, 0x63a0014a, 0x27e93889, 0x00000000}},  //   radı, _memn, vdan_,
  { {0x69dc1932, 0x81b00044, 0x63a0001a, 0x00000000}},  //   gere, ট্র_, _lemn,
  { {0x7ae4388a, 0x61e80058, 0x27e9006b, 0x00000000}},  //   _esit, _madl, tdan_,
  { {0xb90703d7, 0x63a00056, 0x7ae40009, 0x00000000}},  //   _मई_, _nemn, _fsit,
  { {0xfc3f0802, 0x61fa00c7, 0x60150051, 0x00000000}},  // [c790] mní_, _ontl, _dámh,
  { {0x69dc388b, 0xfc3f32ad, 0x61e8016c, 0x00000000}},  //   cere, lní_, _nadl,
  { {0x26c90119, 0xfa340025, 0x47ab0044, 0x00000000}},  //   stao_, _جريد, ঙ্গী,
  { {0xfc3f388c, 0x27e9005f, 0x61fa0095, 0x00000000}},  //   nní_, qdan_, _antl,
  { {0x320c3101, 0x64590719, 0xe299007c, 0x00000000}},  //   _body_, rlwi, чал_,
  { {0xaab203d7, 0x628015a3, 0x11d90025, 0x00000000}},  //   _जिसक, _dumo, سوعة_,
  { {0x69c5000b, 0xe0d1026c, 0x03c7025f, 0x00000000}},  //   _mche, ازت_, _осам,
  { {0x69dc143a, 0xfc3f01ca, 0x61fa010f, 0x00000000}},  //   zere, jní_, _entl,
  { {0xfc3f13c7, 0x7a22028c, 0x69dc014a, 0x00000000}},  //   dní_, _hôte, yere,
  { {0x6cea02d2, 0x63a01093, 0x69dc2230, 0x00000000}},  //   टिंग_, _zemn, xere,
  { {0x26000164, 0x82340025, 0x6015008e, 0x00000000}},  //   राती_, _شركا, _lámi,
  { {0x69c5028c, 0xeb970057, 0x601c388d, 0x00000000}},  //   _ache, нию_, _téma,
  { {0x81e20044, 0x60152c52, 0x6d58388e, 0x00000000}},  //   ধার_, _námi, _eyva,
  { {0x69dc01a2, 0xdca50900, 0x00000000, 0x00000000}},  //   uere, _заки,   ,
  { {0xfc3f13c7, 0xc212009b, 0x6d580006, 0x00000000}},  //   bní_, נהל_, _gyva,
  { {0x69dc388f, 0x7bdd001a, 0x7ae40004, 0x00000000}},  //   sere, cesu, _tsit,
  { {0x69dc0ed6, 0xb907013d, 0x7ae41080, 0x00000000}},  // [c7a0] pere, _मै_, _usit,
  { {0x63a0000d, 0xf77f0181, 0x62802817, 0x00000000}},  //   _semn, _faço_, _rumo,
  { {0x62800006, 0x399b0097, 0x7a22009d, 0x00000000}},  //   _sumo, _מייד, _côte,
  { {0x62800e20, 0x00000000, 0x00000000, 0x00000000}},  //   _pumo,   ,   ,
  { {0x81e90055, 0x61e82b70, 0x08770049, 0x00000000}},  //   যান_, _padl, _רעכט_,
  { {0x7bdd114c, 0xfc3f01dc, 0x60e61123, 0x00000000}},  //   zesu, zní_, ециз,
  { {0xe6430088, 0x63a025c2, 0x320c0161, 0x00000000}},  //   _серп, _temn, _vody_,
  { {0x320c0036, 0xefb2007a, 0xfc3f093f, 0x00000000}},  //   _wody_, ایشگ, xní_,
  { {0xfc3f13c7, 0xc24601fe, 0x7bdd01a2, 0x00000000}},  //   vní_, _знак, vesu,
  { {0x660e0190, 0x7ed30025, 0x00000000, 0x00000000}},  //   _jobk, ازيا,   ,
  { {0xfc3f13c7, 0xd622007e, 0x660e0022, 0x00000000}},  //   tní_, нiка, _mobk,
  { {0x637601f6, 0x6abd006c, 0x00000000, 0x00000000}},  //   _günü, tusf,   ,
  { {0x7bdd0292, 0xfc3f0802, 0x601c009d, 0x00000000}},  //   resu, rní_, _hémo,
  { {0xfc3f01c8, 0x7bdd014a, 0x673b016c, 0x00000000}},  //   sní_, sesu, _žujo,
  { {0xfc3f0802, 0xdf00002b, 0x6abd1617, 0x00000000}},  //   pní_, _wiċċ_, susf,
  { {0x601c00f4, 0x36d50581, 0x7bdd0065, 0x00000000}},  //   _mémo, кобр, qesu,
  { {0x2bc60164, 0x69c501aa, 0x89d900a1, 0x00000000}},  // [c7b0] _वाता, _tche, _ہوکر_,
  { {0x69c5018e, 0x63a4009f, 0x163b0025, 0x00000000}},  //   _uche, ðinn, أسرة_,
  { {0xe1ff00ad, 0x2cbe19cb, 0x81e90044, 0x00000000}},  //   _đó_, nutd_, যাম_,
  { {0x9f5f009f, 0x69cd006e, 0x00000000, 0x00000000}},  //   kkuð_, द्री,   ,
  { {0xfbd30201, 0x2bd301f5, 0x8627007e, 0x00000000}},  //   ध्यम, ध्या, _зьве,
  { {0x1a9c0049, 0x601c2a41, 0xc88200e5, 0x00000000}},  //   לידע, _bémo, _fişă_,
  { {0x91640054, 0x2ee60007, 0x8af0006b, 0x00000000}},  //   هههه, _asof_, _ayəl,
  { {0x601c00f4, 0x8f7501ff, 0x7f750088, 0x00000000}},  //   _démo, купі, купц,
  { {0x25a3002b, 0x81d60044, 0xa3e60061, 0x00000000}},  //   _kejl_, িয়_, _बघत_,
  { {0x273e001d, 0x6b8d3890, 0x2c7b007f, 0x00000000}},  //   ắng_, _afag, _rūda_,
  { {0x2bc60061, 0x25a300f8, 0x2ee600f6, 0x00000000}},  //   _वादा, _mejl_, _esof_,
  { {0x25a3002b, 0x3de10044, 0x00000000, 0x00000000}},  //   _lejl_, বাইল,   ,
  { {0x8af00163, 0xdb060023, 0xef0e0131, 0x00000000}},  //   _azər, makë, _тм_,
  { {0xe3d50044, 0x200f01ee, 0xddc3002b, 0x00000000}},  //   _সোমব, _hogi_, _jinż,
  { {0x3ebf01b5, 0x5e5600f3, 0xe9a30147, 0x00000000}},  //   luut_, _جلوس_, расп,
  { {0xf77216bb, 0x200f0010, 0x684300ed, 0x00000000}},  //   لاء_, _jogi_, анса,
  { {0xe7370057, 0x3ebf00c7, 0x200f0181, 0x00000000}},  // [c7c0] вет_, nuut_, _mogi_,
  { {0x200f0004, 0xdb0400c4, 0x64430d7f, 0x00000000}},  //   _logi_, _adiç, énin,
  { {0x27eb000a, 0xab5b035a, 0x00000000, 0x00000000}},  //   _facn_, ngün,   ,
  { {0x7af613c2, 0xb4d2013d, 0x200f3891, 0x00000000}},  //   _kryt, _वही_, _nogi_,
  { {0x27e0010f, 0x25a30030, 0x245c00b9, 0x00000000}},  //   mein_, _fejl_, ními_,
  { {0x80db0055, 0xdb0402d5, 0x27e0010f, 0x00000000}},  //   ভিন্, _ediç, lein_,
  { {0x40340088, 0x29180af9, 0x7af60006, 0x00000000}},  //   лекс, nyra_, _lryt,
  { {0xaab20061, 0x27e004ec, 0x6823006c, 0x00000000}},  //   _जिंक, nein_, _tõde,
  { {0x2e4a005e, 0x29183892, 0x00000000, 0x00000000}},  //   дяно_, hyra_,   ,
  { {0x44260fb3, 0x7c8601fb, 0x601c048d, 0x00000000}},  //   lho_, куме, _témo,
  { {0x27e0021e, 0xa3e60061, 0x29180065, 0x00000000}},  //   kein_, _बघा_, jyra_,
  { {0x44260fb3, 0x644200b0, 0x7af63893, 0x00000000}},  //   nho_, nnoi, _bryt,
  { {0x3fcb0123, 0x44260032, 0x00000000, 0x00000000}},  //   _آدمی_, iho_,   ,
  { {0x3eb90027, 0x00000000, 0x00000000, 0x00000000}},  //   áste_,   ,   ,
  { {0x7af637d6, 0x19580783, 0x44260082, 0x00000000}},  //   _eryt, вары_, kho_,
  { {0x63a4000c, 0x44260027, 0x7c26010f, 0x00000000}},  //   ðinl, jho_, chkr,
  { {0x26c00058, 0x245c01ca, 0x81e90044, 0x00000000}},  // [c7d0] guio_, cími_, যাত_,
  { {0xcfeb0055, 0x2fdf010f, 0x85b800ec, 0x00000000}},  //   কায়_, zeug_, клус_,
  { {0xf96b0a1e, 0x25a30190, 0x9f4f00f8, 0x00000000}},  //   _юрий_, _vejl_, _ingå_,
  { {0x44260487, 0x6442009d, 0x00000000, 0x00000000}},  //   gho_, gnoi,   ,
  { {0x1dc20309, 0x200f0208, 0xc2c803ec, 0x00000000}},  //   _शांत, _rogi_, نبول_,
  { {0x2169013b, 0x78ba0091, 0x00000000, 0x00000000}},  //   нили_, štve,   ,
  { {0x200f0058, 0x2055092b, 0x1634007c, 0x00000000}},  //   _pogi_, лтир, _теря,
  { {0x44260219, 0x3ebf3894, 0xe3b0031d, 0x00000000}},  //   cho_, tuut_, _ورق_,
  { {0x69d7049a, 0xdb060023, 0xddc30066, 0x00000000}},  //   _obxe, rakë, _tinż,
  { {0x27e0022b, 0x7d09012b, 0xdb1d01e5, 0x00000000}},  //   zein_, еног_, ggsí,
  { {0x6cc5008b, 0x91aa00a1, 0x611300b9, 0x00000000}},  //   ыйна, _سننے_, _dělá,
  { {0x2d8e3895, 0x9ef50025, 0xab5b1e49, 0x00000000}},  //   _effe_, _مستش, rgün,
  { {0x765e0c6a, 0x00000000, 0x00000000, 0x00000000}},  //   ylpy,   ,   ,
  { {0x29180065, 0x7c260065, 0x3ead010e, 0x00000000}},  //   tyra_, shkr, mset_,
  { {0x27e0192b, 0x291e3896, 0x3ead269f, 0x00000000}},  //   tein_, áta_, lset_,
  { {0x7a34006b, 0x3f8d00c4, 0x66e60aed, 0x00000000}},  //   _mütə, nceu_, лоба,
  { {0x291e0119, 0x7c240065, 0x27e0192b, 0x00000000}},  // [c7e0] šta_, _ilir, rein_,
  { {0x44260b32, 0x3ead021e, 0xdb060d7f, 0x00000000}},  //   who_, iset_, jaké,
  { {0x44263059, 0x37b00044, 0xe3ba003b, 0x00000000}},  //   tho_, ঙ্গর, ебе_,
  { {0x3ead021e, 0x7bc60fef, 0x69c3011f, 0x00000000}},  //   kset_, ngku, _öner,
  { {0xf77202fd, 0x26c008eb, 0x6442009d, 0x00000000}},  //   _داد_, quio_, rnoi,
  { {0x4426000b, 0x3ead0030, 0x38603897, 0x00000000}},  //   sho_, dset_, llir_,
  { {0x6015009f, 0x44260082, 0x3860005b, 0x00000000}},  //   _náms, pho_, olir_,
  { {0xb4fb0104, 0x3ead0133, 0xdfd00025, 0x00000000}},  //   _אפלי, fset_, آية_,
  { {0x74130151, 0x4424006c, 0x3ead010e, 0x00000000}},  //   _اوقا, _ilm_, gset_,
  { {0x7c2404cb, 0x7c36000a, 0x3cd4007e, 0x00000000}},  //   _alir, _amyr, ажос,
  { {0x442400bb, 0x38600fa2, 0xd657009b, 0x00000000}},  //   _klm_, klir_, ריית_,
  { {0x7c24278c, 0x60150161, 0x3ead08d0, 0x00000000}},  //   _clir, _dáms, bset_,
  { {0x4424003f, 0x2bc6006e, 0x00000000, 0x00000000}},  //   _mlm_, _वारा,   ,
  { {0x4424033b, 0x2d8e032e, 0xa2cc007d, 0x00000000}},  //   _llm_, _uffe_, _समन्,
  { {0x7c242db6, 0xbd55007a, 0x195907d0, 0x00000000}},  //   _flir, _پروژ, тавы_,
  { {0x6e3a0030, 0x6d46014a, 0x7c24005b, 0x00000000}},  //   litb, şkas, _glir,
  { {0xd5bb00ed, 0x9635132e, 0x245c01dc, 0x00000000}},  // [c7f0] есе_, анац, nímu_,
  { {0x44240030, 0x6e3a05d2, 0x00000000, 0x00000000}},  //   _alm_, nitb,   ,
  { {0x38600fdb, 0x442404be, 0xb86700a1, 0x00000000}},  //   blir_, _blm_, _ماحو,
  { {0x69c70292, 0x3ead06d5, 0x44241911, 0x00000000}},  //   lgje, yset_, _clm_,
  { {0x81e90044, 0x3ead0050, 0x44241444, 0x00000000}},  //   যাস_, xset_, _dlm_,
  { {0xd05a005f, 0x4424006b, 0x69c70de8, 0x00000000}},  //   _istə, _elm_, ngje,
  { {0x44240065, 0x6e3a06d3, 0x00000000, 0x00000000}},  //   _flm_, ditb,   ,
  { {0xe3b30318, 0x3ead03b6, 0x44393898, 0x00000000}},  //   _درس_, tset_, _ös_,
  { {0x63ab1017, 0x60060147, 0x3f8d3899, 0x00000000}},  //   magn, рным_, rceu_,
  { {0x3ead389a, 0x3f8d0181, 0x63ab141a, 0x00000000}},  //   rset_, sceu_, lagn,
  { {0x61e31016, 0x3ead05d5, 0xcb0900b3, 0x00000000}},  //   menl, sset_, _קל_,
  { {0x61e31038, 0x63ab0058, 0x8f7501e1, 0x00000000}},  //   lenl, nagn, _кулі,
  { {0x20d1001d, 0x60c3011f, 0xde0501fb, 0x00000000}},  //   _hơi_, lunm, _впли,
  { {0x7a2b0676, 0x672d0620, 0x8d8701ff, 0x00000000}},  //   _lütf, dzaj, _судд,
  { {0x63ab00e0, 0x00000000, 0x00000000, 0x00000000}},  //   kagn,   ,   ,
  { {0x6b8f001c, 0x7c24027f, 0x61e3010f, 0x00000000}},  //   cccg, _ulir, henl,

  { {0x63ab0207, 0x61e3389b, 0x81b00044, 0x00000000}},  // [c800] dagn, kenl, ট্ট_,
  { {0x645b0093, 0x4424014a, 0x63ab324d, 0x00000000}},  //   _akui, _slm_, eagn,
  { {0x20d1001d, 0x61e3014a, 0x3860389c, 0x00000000}},  //   _nơi_, denl, plir_,
  { {0x63ab0039, 0x6aa40009, 0xe29a0269, 0x00000000}},  //   gagn, _kwif, вад_,
  { {0x9983010a, 0xf194007c, 0x672d0036, 0x00000000}},  //   cijų_, биль, czaj,
  { {0x61e302ae, 0x20d10011, 0x425600ec, 0x00000000}},  //   genl, _bơi_, штет,
  { {0x03a601fb, 0x154301e0, 0xa4910014, 0x00000000}},  //   _вибо, _дерм, _فیلت,
  { {0x7e61001c, 0xdfda0265, 0xdb0b014a, 0x00000000}},  //   ellp, тък_, _çiçe,
  { {0xe61f0011, 0x26d20022, 0x7e2a05b8, 0x00000000}},  //   _muôn_, ntyo_, віна_,
  { {0xe61f001d, 0x20d601fb, 0x3eb80059, 0x00000000}},  //   _luôn_, _відс, črt_,
  { {0x6b8f001c, 0x6e3a032e, 0x64930066, 0x00000000}},  //   tccg, ritb, _għid,
  { {0x6e3a00d9, 0x691e0066, 0x00000000, 0x00000000}},  //   sitb, _mħeġ,   ,
  { {0x6e940054, 0x7b670264, 0x27f2018e, 0x00000000}},  //   _التا, ртне, ddyn_,
  { {0xdd9100a1, 0x6aa40022, 0x6b840032, 0x00000000}},  //   _ٹوٹ_, _dwif, _egig,
  { {0x69c7008d, 0x97a70216, 0xe61f0011, 0x00000000}},  //   rgje, ирал, _buôn_,
  { {0x61e3011f, 0x765c0387, 0x69c736d9, 0x00000000}},  //   zenl, _akry, sgje,
  { {0xf77300a2, 0x63ab0039, 0x61e318cf, 0x00000000}},  // [c810] زار_, vagn, yenl,
  { {0x6015147e, 0x645b0007, 0x7aed11a8, 0x00000000}},  //   _lámp, _skui, _isat,
  { {0x63ab389d, 0x99830006, 0x672d1072, 0x00000000}},  //   tagn, sijų_, szaj,
  { {0x20d10011, 0x601c00f4, 0x7aed223a, 0x00000000}},  //   _rơi_, _fémi, _ksat,
  { {0xadf8024c, 0x61e300b5, 0x63ab1562, 0x00000000}},  //   ्ञान_, tenl, ragn,
  { {0x63ab000c, 0x2ff800a1, 0x00000000, 0x00000000}},  //   sagn, یڈنگ_,   ,
  { {0x26090365, 0x63ab00f4, 0x61e3014a, 0x00000000}},  //   साठी_, pagn, renl,
  { {0x7aed389e, 0x13aa00a6, 0x16050061, 0x00000000}},  //   _osat, _منفی_, रावर_,
  { {0x64590036, 0x61e30168, 0x7fe80025, 0x00000000}},  //   mowi, penl, شريف_,
  { {0x6459389f, 0x6f09049a, 0x443d38a0, 0x00000000}},  //   lowi, rxec, liw_,
  { {0x909938a1, 0x30850054, 0x63a901a3, 0x00000000}},  //   _свет_, _الصف, _keen,
  { {0x64590046, 0x7c3d012b, 0x628104de, 0x00000000}},  //   nowi, gisr, _hilo,
  { {0x7aed0047, 0x63a9224a, 0x9f0b0025, 0x00000000}},  //   _csat, _meen, _جزاك_,
  { {0x63a900b0, 0x7aed0066, 0x7c3d0048, 0x00000000}},  //   _leen, _dsat, aisr,
  { {0x628101cd, 0x7aed38a2, 0x64590036, 0x00000000}},  //   _milo, _esat, kowi,
  { {0x765c38a3, 0x9ac501d5, 0x63a900ca, 0x00000000}},  //   _skry, fiċċ, _neen,
  { {0x64590036, 0x661538a4, 0x27f20016, 0x00000000}},  // [c820] dowi, _bozk, rdyn_,
  { {0x6281011c, 0x81e90044, 0x00000000, 0x00000000}},  //   _nilo, যাঁ_,   ,
  { {0x2e3a0049, 0x78a90107, 0x63a9010f, 0x00000000}},  //   נגענ, ćevc, _been,
  { {0x3ebf04be, 0xdc190036, 0xf7460131, 0x00000000}},  //   krut_, _błęd, _гемо,
  { {0x63a900bb, 0x628138a5, 0x63ad000c, 0x00000000}},  //   _deen, _bilo, ðana,
  { {0x765c0036, 0x30a602e9, 0x78a50045, 0x00000000}},  //   _ukry, брив, _ywhv,
  { {0x92e80055, 0x628104be, 0x63a9054e, 0x00000000}},  //   যমে_, _dilo, _feen,
  { {0xf2e80014, 0x63a9095c, 0x24b7009b, 0x00000000}},  //   _نکته_, _geen, _להלן_,
  { {0x26c000c4, 0x7bcd0026, 0x00000000, 0x00000000}},  //   nrio_, _rcau,   ,
  { {0x7bcd001a, 0x81c800a1, 0x63a900d9, 0x00000000}},  //   _scau, _خطرہ_, _zeen,
  { {0xa3bc03d7, 0xa3cf013d, 0x9f4f01aa, 0x00000000}},  //   _आया_, _शाम_, _lagè_,
  { {0x7f860054, 0x26c00091, 0x628101c5, 0x00000000}},  //   _الإن, krio_, _zilo,
  { {0x643b0049, 0xe043007c, 0x6a6001e5, 0x00000000}},  //   רעכנ, _энци, höfu,
  { {0x64590036, 0x26c0008e, 0xab5b1052, 0x00000000}},  //   zowi, drio_, ngüi,
  { {0x661508d2, 0xde880011, 0x26c004a5, 0x00000000}},  //   _rozk, _xịn_, erio_,
  { {0x2c7b001e, 0x26c02996, 0x3e6b00ea, 0x00000000}},  //   _līdz_, frio_, møta_,
  { {0x63a9027b, 0x7aed0198, 0xdce30089, 0x00000000}},  // [c830] _reen, _usat, _iznā,
  { {0x63a9006c, 0x09b30044, 0x644a38a6, 0x00000000}},  //   _seen, ঞ্জা, éfin,
  { {0x26c00819, 0x64590036, 0x628138a7, 0x00000000}},  //   ario_, towi, _rilo,
  { {0x26c00555, 0x8cc00164, 0x62810466, 0x00000000}},  //   brio_, _विनो, _silo,
  { {0x64590046, 0x63a9224a, 0x248d18e1, 0x00000000}},  //   rowi, _veen, _čemu_,
  { {0x40950517, 0x63a90007, 0x56940517, 0x00000000}},  //   орит, _ween, _харт,
  { {0x64590046, 0x628100d4, 0x63a938a8, 0x00000000}},  //   powi, _vilo, _teen,
  { {0x682a00b9, 0x2eb5034b, 0xe0d6007e, 0x00000000}},  //   _týde, осос, івы_,
  { {0xdb1d0210, 0x62811603, 0xfc3f01ca, 0x00000000}},  //   ngsä, _tilo, dií_,
  { {0xfe420088, 0x7fb9007a, 0x3f860173, 0x00000000}},  //   дньо, _چهار_, _egou_,
  { {0x5f9509de, 0xfc3f0161, 0x16c6013d, 0x00000000}},  //   _диет, fií_, _लम्ब,
  { {0x5f740167, 0xfc3f0161, 0x00000000, 0x00000000}},  //   _کامر, gií_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa2cc02fb, 0x5ebe0055, 0xb0dd0061, 0x00000000}},  //   _समस्, ্বশে, _महाग,
  { {0xfc320025, 0x81ae0044, 0x8af0013f, 0x00000000}},  //   _يحب_, _কাম_, _ayət,
  { {0xfc3f120f, 0x78ba0f3a, 0x57ea00e2, 0x00000000}},  //   cií_, štvo, јдам_,
  { {0x32050038, 0x78a90107, 0xba760025, 0x00000000}},  // [c840] _only_, ćeva, _واخت,
  { {0xa3dc0183, 0x26c00211, 0x55e300ed, 0x00000000}},  //   त्न_, rrio_, моуб,
  { {0xae560049, 0xdb0f00fa, 0x00000000, 0x00000000}},  //   קסעס_, jacê,   ,
  { {0xf8b300b6, 0x26c00198, 0x9cda0049, 0x00000000}},  //   _קשר_, prio_, יקעפ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x64a60001, 0x236d016c, 0x00000000, 0x00000000}},  //   _мага, _dzej_,   ,
  { {0x628f028c, 0x3ea60035, 0x3f86004a, 0x00000000}},  //   _écon, _swot_, _pgou_,
  { {0xdfd0006d, 0x2d87007f, 0x442201c3, 0x00000000}},  //   ريخ_, _agne_, _ôk_,
  { {0xe29700ed, 0x63a4000c, 0x11d6013a, 0x00000000}},  //   _мат_, ðinu, _міжр,
  { {0xddd80825, 0xdb1d0d32, 0x63a20010, 0x00000000}},  //   _bivš, ngså, lbon,
  { {0x8146026c, 0xc27b009b, 0xeb9f00ea, 0x00000000}},  //   _بنان, _כרמי, kjøt_,
  { {0x63a21de2, 0x2d8701e3, 0xccf8013e, 0x00000000}},  //   nbon, _egne_, rvě_,
  { {0xa3dc02f4, 0x447b0049, 0xfc3f0161, 0x00000000}},  //   त्य_, ינטע, rií_,
  { {0xda1b0061, 0x00000000, 0x00000000, 0x00000000}},  //   _नकळत_,   ,   ,
  { {0x63a238a9, 0x37ab00e2, 0x00000000, 0x00000000}},  //   kbon, итан_,   ,
  { {0x248401a2, 0x00000000, 0x00000000, 0x00000000}},  //   _nimm_,   ,   ,
  { {0x36d40057, 0x4735007e, 0xc987075f, 0x00000000}},  // [c850] мотр, чнас, _муни,
  { {0x63a200d9, 0xcfc20044, 0x00000000, 0x00000000}},  //   ebon, ্জিন,   ,
  { {0x89da026c, 0x26000164, 0x00000000, 0x00000000}},  //   _اوپر_, राजी_,   ,
  { {0x58fa0049, 0x2484088a, 0x764e0146, 0x00000000}},  //   _פּינ, _cimm_, _ejby,
  { {0x1b1d0044, 0x27e90f45, 0x2338007e, 0x00000000}},  //   _পেতে_, mean_, опцы_,
  { {0x27e9022b, 0xa2cc02fb, 0xf6790049, 0x00000000}},  //   lean_, _समर्, _לאָמ,
  { {0x2484000c, 0xd49800ed, 0x7d1c043e, 0x00000000}},  //   _fimm_, _мрт_, ørsl,
  { {0x27e90756, 0x60090407, 0xd6220451, 0x00000000}},  //   nean_, сним_, нiза,
  { {0xe293007a, 0xee391662, 0x260001f5, 0x00000000}},  //   _آذر_, йни_, राची_,
  { {0x27e9002d, 0x629b00e0, 0xddd80087, 0x00000000}},  //   hean_, _ituo, _pivš,
  { {0x80a40054, 0x27e921be, 0xed5900a8, 0x00000000}},  //   _يمكن, kean_, сон_,
  { {0x27e907b9, 0xf0f9013d, 0x30f900a1, 0x00000000}},  //   jean_, ्मीद_, _پوچھ_,
  { {0xf1d20164, 0x27e9022b, 0x644b0020, 0x00000000}},  //   _सामन, dean_, ingi,
  { {0x81e90044, 0x63a238aa, 0x00000000, 0x00000000}},  //   যাক_, zbon,   ,
  { {0x25ff013d, 0x27e91760, 0xc90a0044, 0x00000000}},  //   _रफ़ी_, fean_, রন্ত_,
  { {0x27e90add, 0x63bb0066, 0x2bc60061, 0x00000000}},  //   gean_, _ndun, _वाटा,
  { {0x6f160036, 0x995500b9, 0xe81d0204, 0x00000000}},  // [c860] _życz, _výši_, _नवरा_,
  { {0x63bb001a, 0x2484059e, 0x7ae413cb, 0x00000000}},  //   _adun, _simm_, _ipit,
  { {0x27e9002d, 0x629b17df, 0x69dc2829, 0x00000000}},  //   bean_, _atuo, mfre,
  { {0x69dc01e7, 0x63a200bb, 0x59aa0061, 0x00000000}},  //   lfre, ubon, करवर,
  { {0x628f028c, 0x57fb0097, 0x249f012d, 0x00000000}},  //   _écol, _הלכו, _čume_,
  { {0x69dc010f, 0x30a6003b, 0x644b0b38, 0x00000000}},  //   nfre, прив, angi,
  { {0x03a61123, 0x64a6060e, 0x7a22009d, 0x00000000}},  //   _ниво, _хаба, _côti,
  { {0xb60301d5, 0x81e90044, 0x92c1014a, 0x00000000}},  //   ġġet, যাগ_, üğün,
  { {0x442616d8, 0x64421622, 0x69dc0270, 0x00000000}},  //   mko_, mioi, kfre,
  { {0x44260046, 0x27e9022b, 0x69dc2ddb, 0x00000000}},  //   lko_, zean_, jfre,
  { {0x69dc04c0, 0x4426002d, 0x61ea0606, 0x00000000}},  //   dfre, oko_, mefl,
  { {0x61ea0146, 0x27e9002d, 0xdb0f009d, 0x00000000}},  //   lefl, xean_, lacé,
  { {0x69dc38ab, 0x4426002d, 0x27e90035, 0x00000000}},  //   ffre, iko_, vean_,
  { {0x44260c06, 0xa3dc02f4, 0x61ea0190, 0x00000000}},  //   hko_, त्त_, nefl,
  { {0x7ae401aa, 0x27e90756, 0x4426021e, 0x00000000}},  //   _epit, tean_, kko_,
  { {0xdc2b007a, 0x44260091, 0x69dc00f6, 0x00000000}},  //   _دسته_, jko_, afre,
  { {0x7c2d002d, 0x64420052, 0x442605e1, 0x00000000}},  // [c870] _ilar, dioi, dko_,
  { {0x27e9203c, 0xa3cf006e, 0x7bdd0007, 0x00000000}},  //   sean_, _शाह_, lfsu,
  { {0x27e91624, 0x7c2d0239, 0xb8350057, 0x00000000}},  //   pean_, _klar, _женщ,
  { {0xc95200b3, 0x644b38ac, 0x644238ad, 0x00000000}},  //   _ימי_, ungi, gioi,
  { {0x3869047f, 0x2458008b, 0x64930066, 0x00000000}},  //   mlar_, чаць_, _għin,
  { {0x4426022b, 0xdd860647, 0x7c2d04bd, 0x00000000}},  //   ako_, _لو_, _llar,
  { {0x7c2d047f, 0xe61f001d, 0xfbbf007d, 0x00000000}},  //   _olar, _nuôi_, ्लाम,
  { {0x386901f6, 0x4426004f, 0xb69b00f4, 0x00000000}},  //   nlar_, cko_, _grâc,
  { {0x442d1355, 0x3869008e, 0x69dc0016, 0x00000000}},  //   _ile_, ilar_, yfre,
  { {0x7a300103, 0x3869005d, 0x41b50014, 0x00000000}},  //   _käte, hlar_, _آمار,
  { {0x7ae40de1, 0x386938ae, 0x1bea1281, 0x00000000}},  //   _spit, klar_, одни_,
  { {0x7c2d0977, 0x3869011f, 0xca2900b3, 0x00000000}},  //   _clar, jlar_, _דם_,
  { {0x38692865, 0x69dc01a2, 0x765e0f99, 0x00000000}},  //   dlar_, tfre, yopy,
  { {0x68fc091e, 0x44260756, 0x442d38af, 0x00000000}},  //   tvrd, zko_, _lle_,
  { {0x442d0368, 0x443f14c7, 0x7a300039, 0x00000000}},  //   _ole_, _omu_, _näte,
  { {0x69dc0056, 0x3b0001d5, 0x81e90044, 0x00000000}},  //   sfre, _triq_, যাট_,
  { {0x4426037e, 0xf74338b0, 0x2c56001e, 0x00000000}},  // [c880] vko_, вето, gāde_,
  { {0xb0dd03d7, 0xf1d20164, 0x44260036, 0x00000000}},  //   _महंग, _साधन, wko_,
  { {0x4426154d, 0x386938b1, 0x442d0292, 0x00000000}},  //   tko_, blar_, _ble_,
  { {0x3869005f, 0x68310634, 0x44260d96, 0x00000000}},  //   clar_, _rådg, uko_,
  { {0x4426022b, 0x442d0224, 0x61ea01e5, 0x00000000}},  //   rko_, _dle_, tefl,
  { {0x44260027, 0x442d02d5, 0x20ee0224, 0x00000000}},  //   sko_, _ele_, _při_,
  { {0x44260d0a, 0xc0e301fc, 0x644200b0, 0x00000000}},  //   pko_, војк, pioi,
  { {0xd0100054, 0x68e3001f, 0x661c01ca, 0x00000000}},  //   الة_, _ände, _hork,
  { {0x661c1be4, 0x67240061, 0xdcea38b2, 0x00000000}},  //   _kork, nyij, čiče,
  { {0x3869005d, 0x442d0142, 0x20ee00b9, 0x00000000}},  //   zlar_, _zle_, _tři_,
  { {0x44fe010a, 0x442d021e, 0x386938b3, 0x00000000}},  //   _jį_, _yle_, ylar_,
  { {0x661c0107, 0x386938b4, 0x62880085, 0x00000000}},  //   _lork, xlar_, _hido,
  { {0x628838b5, 0x6440003b, 0x38693142, 0x00000000}},  //   _kido, _mmmi, vlar_,
  { {0x68310030, 0x7afd05d5, 0x661c007f, 0x00000000}},  //   _måde, rvst, _nork,
  { {0x38691ed0, 0x64400066, 0x62880020, 0x00000000}},  //   tlar_, _ommi, _mido,
  { {0x6ce301fb, 0x3869027b, 0x628838b6, 0x00000000}},  //   _ріше, ular_, _lido,
  { {0x386901f6, 0x78a23002, 0x1995008b, 0x00000000}},  // [c890] rlar_, _čove, _папя,
  { {0x644038b7, 0x09c60055, 0xdcfa01f6, 0x00000000}},  //   _ammi, শ্বা, latı,
  { {0x3869011f, 0x442d0129, 0x661c0232, 0x00000000}},  //   plar_, _ple_, _dork,
  { {0x3869005f, 0xdcfa0279, 0x6aad16e1, 0x00000000}},  //   qlar_, natı, _kwaf,
  { {0x661c0378, 0x442d0263, 0xdb06006b, 0x00000000}},  //   _fork, _vle_, rakç,
  { {0x8635007b, 0x6aad0020, 0x661c167f, 0x00000000}},  //   _טאָג_, _mwaf, _gork,
  { {0x62880169, 0xdcfa0279, 0x6f02004a, 0x00000000}},  //   _dido, katı, _aroc,
  { {0x442d0020, 0x661c016c, 0x6b8d1820, 0x00000000}},  //   _ule_, _zork, _ngag,
  { {0x3eb938b8, 0x81ae0044, 0x32550451, 0x00000000}},  //   ést_, _কার_, _звар,
  { {0xee360b21, 0x6f020051, 0x6288002d, 0x00000000}},  //   ень_, _droc, _gido,
  { {0xa3dc02fb, 0x1d0900aa, 0x13e30044, 0x00000000}},  //   त्व_, чени_, _নোয়,
  { {0x8cc002f4, 0xce950265, 0x62880091, 0x00000000}},  //   _विरो, _задъ, _zido,
  { {0x3860028c, 0x6f0238b9, 0x3f820006, 0x00000000}},  //   voir_, _groc, žkur_,
  { {0xc33200b3, 0x00000000, 0x00000000, 0x00000000}},  //   רוך_,   ,   ,
  { {0xdcfa0477, 0x3860009d, 0x6aad000a, 0x00000000}},  //   batı, toir_, _ewaf,
  { {0x661c002d, 0x9f440802, 0x00000000, 0x00000000}},  //   _sork, zemí_,   ,
  { {0x661c2e23, 0x7a2b0180, 0x7bd60009, 0x00000000}},  // [c8a0] _pork, _kütl, _icyu,
  { {0x683103bd, 0x9916007e, 0x3860009d, 0x00000000}},  //   _råde, _зьмі, soir_,
  { {0xf1c902d2, 0x41c902d2, 0x62880207, 0x00000000}},  //   _राजन, _राजस, _rido,
  { {0x661c0038, 0xe3b20d0b, 0x628838ba, 0x00000000}},  //   _work, ارا_, _sido,
  { {0x661c0039, 0xe80d013d, 0x4803007e, 0x00000000}},  //   _tork, हारा_, _спяв,
  { {0x27e00052, 0x25b10087, 0x00000000, 0x00000000}},  //   lfin_, _gezl_,   ,
  { {0xdcfa01f6, 0x62880a6e, 0xd5ad00a1, 0x00000000}},  //   yatı, _vido, _ذہن_,
  { {0x6f020917, 0x644038bb, 0x9f4f00d4, 0x00000000}},  //   _proc, _ummi, _bagà_,
  { {0x9cec0044, 0x62880145, 0x7d032a1e, 0x00000000}},  //   _ওপেন_, _tido, _arns,
  { {0xa3dc02f4, 0xd010026c, 0x7e61008e, 0x00000000}},  //   त्र_, الک_, golp,
  { {0x6f020046, 0x6aad0258, 0x5c750478, 0x00000000}},  //   _wroc, _swaf, клот,
  { {0x61fa014a, 0x27e00023, 0x00000000, 0x00000000}},  //   _hatl, jfin_,   ,
  { {0x7d03037f, 0xdcfa005d, 0x61fa38bc, 0x00000000}},  //   _erns, ratı, _katl,
  { {0x27e001f3, 0x7e610197, 0x2c720062, 0x00000000}},  //   efin_, colp, ráda_,
  { {0x6b8d001c, 0xe80d001c, 0x61fa01a3, 0x00000000}},  //   _tgag, हाला_, _matl,
  { {0xb9090754, 0xdb0f0861, 0x6aad00e7, 0x00000000}},  //   _यह_, lací, _twaf,
  { {0x0c7401fa, 0x3a750143, 0x00000000, 0x00000000}},  // [c8b0] _حدود, _илир,   ,
  { {0x27f900ab, 0x61fa0253, 0x81e50044, 0x00000000}},  //   _wasn_, _natl, _বোন_,
  { {0xbc6806c6, 0x6823006c, 0x92ad0044, 0x00000000}},  //   _زمین_, _sõdu, _কমে_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x61fa0129, 0x321e0c05, 0x972200a1, 0x00000000}},  //   _batl, _boty_, _پہلو,
  { {0x61fa12fe, 0x659500ed, 0x9f4400d4, 0x00000000}},  //   _catl, _јаву, demà_,
  { {0x205501be, 0x7a30006c, 0x61fa1fae, 0x00000000}},  //   ктир, _jäta, _datl,
  { {0x26050201, 0x320c1163, 0x7a30150e, 0x00000000}},  //   _होती_, _endy_, _mäta,
  { {0xf1a7022a, 0x61fa38bd, 0xa2950088, 0x00000000}},  //   _зрен, _fatl, _разі,
  { {0x61fa010e, 0xdb0f004a, 0x00000000, 0x00000000}},  //   _gatl, gací,   ,
  { {0x7e610d44, 0x22470006, 0x7a3000f8, 0x00000000}},  //   rolp, mink_, _näta,
  { {0x224703cf, 0x61fa38be, 0x7e610c10, 0x00000000}},  //   link_, _zatl, solp,
  { {0x12bf0044, 0x6d58004a, 0x00000000, 0x00000000}},  //   _ইহুদ, _exva,   ,
  { {0xf2d20049, 0x26c900fa, 0xdb0f004a, 0x00000000}},  //   בעך_, drao_, cací,
  { {0x64d000e8, 0xa96700aa, 0xa92701c5, 0x00000000}},  //   _हमेश, вира_, _nožē,
  { {0xde880011, 0x2c08013d, 0x00000000, 0x00000000}},  //   _dịu_, षाओं_,   ,
  { {0x18670264, 0x27e001e5, 0x26c90091, 0x00000000}},  // [c8c0] тати_, rfin_, grao_,
  { {0xb69b0181, 0x66e30072, 0x8ab7009b, 0x00000000}},  //   _trân, рофа, _שהיו_,
  { {0x22470007, 0xd49901fb, 0x61fa2273, 0x00000000}},  //   dink_, ері_, _ratl,
  { {0xad1a007b, 0xfbdf001d, 0x61fa0563, 0x00000000}},  //   ווער, hiên_, _satl,
  { {0xe36300da, 0xe2970072, 0x61fa014a, 0x00000000}},  //   акци, вач_, _patl,
  { {0xbb3b00a0, 0x00000000, 0x00000000, 0x00000000}},  //   ועני,   ,   ,
  { {0xd12f006d, 0xdb0f3664, 0xe643041f, 0x00000000}},  //   يمه_, vací, _терп,
  { {0x1ee600a6, 0xc953009b, 0x752301a2, 0x00000000}},  //   نوعی_, ימו_, änze,
  { {0x09b80055, 0x61fa034f, 0x78a9037e, 0x00000000}},  //   _জানা, _tatl, ćevi,
  { {0xde880082, 0x00000000, 0x00000000, 0x00000000}},  //   _nịt_,   ,   ,
  { {0x683100f8, 0x00000000, 0x00000000, 0x00000000}},  //   _låda,   ,   ,
  { {0x8fa6142c, 0x00000000, 0x00000000, 0x00000000}},  //   _раде,   ,   ,
  { {0x6fd70061, 0xde880082, 0x290c00f8, 0x00000000}},  //   _यातू, _bịt_, ådan_,
  { {0x2c560089, 0x00000000, 0x00000000, 0x00000000}},  //   rāda_,   ,   ,
  { {0x290501e5, 0x6d450062, 0x00000000, 0x00000000}},  //   íla_, _žhav,   ,
  { {0xdb2300a1, 0x26c90091, 0x00000000, 0x00000000}},  //   _نوعی, trao_,   ,
  { {0x41d2007d, 0x7a2200f4, 0xdb1d01a2, 0x00000000}},  // [c8d0] _सांस, _vôtr, ngsü,
  { {0x26c900fa, 0x9634007e, 0xdb0f00f6, 0x00000000}},  //   rrao_, ануц, macà,
  { {0x22470f46, 0x00000000, 0x00000000, 0x00000000}},  //   vink_,   ,   ,
  { {0xa2c4013d, 0x224701c3, 0x7a30010e, 0x00000000}},  //   _रिश्, wink_, _jätn,
  { {0x3e7900f4, 0x7a3000f8, 0x69c10036, 0x00000000}},  //   lète_, _mätn, ólew,
  { {0xde880082, 0x69d501a2, 0x722b007c, 0x00000000}},  //   _xịt_, ngze, ьцев_,
  { {0x09b80055, 0x3e7900f4, 0xa069003b, 0x00000000}},  //   _জামা, nète_, нака_,
  { {0x2247046a, 0x00000000, 0x00000000, 0x00000000}},  //   sink_,   ,   ,
  { {0x63b90009, 0x3e79009d, 0x22470a0e, 0x00000000}},  //   mawn, hète_, pink_,
  { {0x7c3f0006, 0x63b938bf, 0x248d0082, 0x00000000}},  //   _įpra, lawn, _hiem_,
  { {0x248d0011, 0xd7c30061, 0xac86004d, 0x00000000}},  //   _kiem_, षणाच, лгол,
  { {0x22990263, 0x41df0164, 0x248d38c0, 0x00000000}},  //   _kèk_, प्रस, _jiem_,
  { {0xef0e003b, 0x270d0061, 0xe4560049, 0x00000000}},  //   _ум_, समोर_, רירט_,
  { {0xed5901e0, 0x628f00f4, 0x683102e1, 0x00000000}},  //   _пол_, _écou, _råda,
  { {0x683104d7, 0x7d1c02cc, 0x68fb0036, 0x00000000}},  //   _såda, ørst, łudn,
  { {0xc2f90055, 0xf7720a4f, 0x248d38c1, 0x00000000}},  //   _আপনি_, ماء_, _niem_,
  { {0x63b90036, 0xdb0f00c4, 0x229905e6, 0x00000000}},  // [c8e0] dawn, racã, _nèk_,
  { {0x3e791e83, 0x6aa400e7, 0x00000000, 0x00000000}},  //   bète_, _itif,   ,
  { {0x200f023e, 0x248d0023, 0x63a4004a, 0x00000000}},  //   _ongi_, _biem_, ñino,
  { {0x4420009f, 0x98160025, 0x22990173, 0x00000000}},  //   ði_, _إبدا, _bèk_,
  { {0x248d0011, 0xe2f80088, 0x81e50044, 0x00000000}},  //   _diem_, телі_, _বোধ_,
  { {0x366a007e, 0x200f0292, 0x27f20943, 0x00000000}},  //   _чаго_, _angi_, leyn_,
  { {0xc31c0055, 0x26d20c2c, 0x90e60439, 0x00000000}},  //   _দেখি_, luyo_, استن,
  { {0x229901aa, 0xa067003b, 0x00000000, 0x00000000}},  //   _fèk_, лаја_,   ,
  { {0x26d21d8b, 0x26090204, 0x00000000, 0x00000000}},  //   nuyo_, साची_,   ,
  { {0xf297009b, 0x6fa40309, 0x9f5f000c, 0x00000000}},  //   _עכבר_, _ग्रं, rjuð_,
  { {0x519301b7, 0x6aa438c2, 0x10a63370, 0x00000000}},  //   _المذ, _atif, _сиен,
  { {0xc0a9035b, 0xf0b1026c, 0xfbdf01c3, 0x00000000}},  //   _شامل_, _بیٹھ, enêr_,
  { {0x2617007d, 0x00000000, 0x00000000, 0x00000000}},  //   नामी_,   ,   ,
  { {0xad2600a2, 0x7d1c06ec, 0x00000000, 0x00000000}},  //   _مربو, ørss,   ,
  { {0x6cc6007e, 0x6aa40016, 0x00000000, 0x00000000}},  //   _сёле, _etif,   ,
  { {0x3e79009d, 0xfbdf00fa, 0x00000000, 0x00000000}},  //   rète_, rnês_,   ,
  { {0x26d2015e, 0x248d00bb, 0x6fdc01f5, 0x00000000}},  // [c8f0] guyo_, _riem_, _यानं,
  { {0x26c700ee, 0x3b09006b, 0x7aed1899, 0x00000000}},  //   čno_, _iraq_, _ipat,
  { {0xfbdf0011, 0x248d0089, 0x229901aa, 0x00000000}},  //   hiêm_, _piem_, _sèk_,
  { {0x81bc0089, 0x26d238c3, 0xe3b00025, 0x00000000}},  //   _slēp, buyo_, كره_,
  { {0x63b90036, 0x645838c4, 0x248d0142, 0x00000000}},  //   rawn, évia, _viem_,
  { {0x248d0046, 0x23260140, 0x7aed00e7, 0x00000000}},  //   _wiem_, роши_, _mpat,
  { {0x248d001e, 0xd6a505b8, 0x00000000, 0x00000000}},  //   _tiem_, гiчн,   ,
  { {0x7aed01ca, 0xaec50081, 0x60092898, 0x00000000}},  //   _opat, абил, тним_,
  { {0x20030224, 0x644b011c, 0xb3a90279, 0x00000000}},  //   ěji_, migi, ğıdı,
  { {0x7d09012b, 0xcee80379, 0xb3a9005d, 0x00000000}},  //   вног_, ارين_, şıdı,
  { {0xed590517, 0x7aed3047, 0x442f01ee, 0x00000000}},  //   тон_, _apat, okg_,
  { {0x5fdc0061, 0x00000000, 0x00000000, 0x00000000}},  //   _यायल,   ,   ,
  { {0x7aed0061, 0x683800b9, 0x628f009d, 0x00000000}},  //   _cpat, _jíde, _écos,
  { {0x644b011c, 0x2605006e, 0xa2cd007d, 0x00000000}},  //   higi, _होली_, _सिन्,
  { {0x683800d6, 0x7aed0197, 0xdb0f1d59, 0x00000000}},  //   _líde, _epat, racá,
  { {0x7a301653, 0x26d21c09, 0x69c50023, 0x00000000}},  //   _täto, tuyo_, _edhe,
  { {0x6e2338c5, 0xde880011, 0x6aa438c6, 0x00000000}},  // [c900] _konb, _kịp_, _utif,
  { {0x09e40055, 0x27f2006b, 0x3ebf00b0, 0x00000000}},  //   _ফোরা, seyn_, isut_,
  { {0x644b0051, 0x7c2406d5, 0x37e60072, 0x00000000}},  //   figi, _koir, _конг,
  { {0x644b006a, 0x7aed0006, 0x73e605b8, 0x00000000}},  //   gigi, _ypat, родз,
  { {0x7c2421b3, 0x69c1000c, 0x41b60025, 0x00000000}},  //   _moir, ðleg, لمشر,
  { {0x7c241184, 0x6e23002d, 0xd043006b, 0x00000000}},  //   _loir, _nonb, munə,
  { {0x644b011c, 0x26c00006, 0x00000000, 0x00000000}},  //   bigi, lsio_,   ,
  { {0x7c2400f4, 0xb7bb0082, 0x2cbe0009, 0x00000000}},  //   _noir, _loãn, vstd_,
  { {0xe29a1561, 0x6e23002d, 0xfba7007d, 0x00000000}},  //   _раз_, _bonb, _क्षम,
  { {0x44240343, 0x26c00016, 0x7c240048, 0x00000000}},  //   _hom_, isio_, _aoir,
  { {0x7aed000d, 0x44240944, 0xde880011, 0x00000000}},  //   _spat, _kom_, _dịp_,
  { {0xdee6013b, 0x7c240051, 0x7aed0093, 0x00000000}},  //   _води, _coir, _ppat,
  { {0x2f0f000c, 0x7c240051, 0x442400ab, 0x00000000}},  //   rögð_, _doir, _mom_,
  { {0x2ba7007d, 0xfba70309, 0x6e23002d, 0x00000000}},  //   _क्रा, _क्रम, _gonb,
  { {0x7c242dc6, 0x44240343, 0x644b0061, 0x00000000}},  //   _foir, _oom_, yigi,
  { {0x442403d5, 0x62830142, 0x6e2338c7, 0x00000000}},  //   _nom_, zmno, _zonb,
  { {0x7aed0020, 0x25b80240, 0xd5bb007c, 0x00000000}},  // [c910] _upat, _berl_, все_,
  { {0x69c50065, 0x644b13a7, 0x4424098e, 0x00000000}},  //   _udhe, wigi, _aom_,
  { {0x442438c8, 0x644b26df, 0x78a90107, 0x00000000}},  //   _bom_, tigi, ćevs,
  { {0x442416b1, 0x3ea604cb, 0x6838008e, 0x00000000}},  //   _com_, _otot_, _píde,
  { {0x81ae0055, 0x13a900a1, 0x26c0005b, 0x00000000}},  //   _কাজ_, پنڈی_, csio_,
  { {0x683838c9, 0x644b26cc, 0xdb0601ca, 0x00000000}},  //   _víde, sigi, jaký,
  { {0x644b036b, 0x44240173, 0x753e0009, 0x00000000}},  //   pigi, _fom_, czpz,
  { {0x2ba7007d, 0xf958009b, 0x44240082, 0x00000000}},  //   _क्ला, יסות_, _gom_,
  { {0x60060147, 0x672d0557, 0x64492984, 0x00000000}},  //   сным_, nyaj, _imei,
  { {0xee3604af, 0x30e701fb, 0x6e3a0197, 0x00000000}},  //   йны_, _відб, ghtb,
  { {0x2fd90879, 0x7c2407cd, 0x44240b3d, 0x00000000}},  //   _مواد_, _poir, _yom_,
  { {0xca2900b6, 0x26c00681, 0x6f950025, 0x00000000}},  //   _אם_, ysio_, _الإض,
  { {0x6e230263, 0x7c2400f4, 0x386900ea, 0x00000000}},  //   _tonb, _voir, doar_,
  { {0x6e3a07eb, 0xa2da0164, 0x09b80044, 0x00000000}},  //   chtb, _नमस्, _জাহা,
  { {0x7c240051, 0x26c00016, 0x00000000, 0x00000000}},  //   _toir, wsio_,   ,
  { {0x81ae0044, 0xccf200b3, 0x7a30082d, 0x00000000}},  //   _কাছ_, _זכה_, _kätk,
  { {0x7a30042b, 0x6f1d09b0, 0x26c00006, 0x00000000}},  // [c920] _jätk, äsch, usio_,
  { {0x4424067e, 0x64490020, 0x26c000b0, 0x00000000}},  //   _som_, _amei, rsio_,
  { {0xdcea0107, 0x26c008a6, 0x69fb00a3, 0x00000000}},  //   čiće, ssio_, _גליק,
  { {0x74690088, 0x26c005b9, 0x3c0d0006, 0x00000000}},  //   арів_, psio_, _tėvų_,
  { {0x442438ca, 0x2498021f, 0xdb0f00c4, 0x00000000}},  //   _vom_, _wurm_, racç,
  { {0x78a20363, 0xc5d501fb, 0x44240173, 0x00000000}},  //   _čovj, _місь, _wom_,
  { {0x442407ff, 0xa2c40309, 0x69de0146, 0x00000000}},  //   _tom_, _रिक्, _mcpe,
  { {0x44240555, 0x7a2b01a2, 0x50b70025, 0x00000000}},  //   _uom_, _hütt, حدود_,
  { {0x64430c7c, 0x63a200df, 0x7a2b006c, 0x00000000}},  //   ënie, mcon, _kütt,
  { {0x248609fc, 0x2a6a38cb, 0x63a2051b, 0x00000000}},  //   lmom_, jobb_, lcon,
  { {0xdd900070, 0x7a2b0c37, 0x40960025, 0x00000000}},  //   بود_, _mütt, _الصر,
  { {0x63a238cc, 0x7e680010, 0x00000000, 0x00000000}},  //   ncon, sodp,   ,
  { {0x386900e5, 0x3ea60058, 0x7e680471, 0x00000000}},  //   voar_, _utot_, podp,
  { {0x2bdb0164, 0x63a238cd, 0x6ab6005b, 0x00000000}},  //   _भावा, hcon, _dwyf,
  { {0x28d902fb, 0x48770025, 0xd90f00a6, 0x00000000}},  //   बंधि, مدرس, ریح_,
  { {0x98a5005a, 0x24860142, 0x2004108f, 0x00000000}},  //   çlı_, jmom_, ndmi_,
  { {0x63a20541, 0xf77300f9, 0xe3ce0044, 0x00000000}},  // [c930] dcon, سار_, রভাব,
  { {0x672d0022, 0x00000000, 0x00000000, 0x00000000}},  //   ryaj,   ,   ,
  { {0x63a200d9, 0x25a100d2, 0x00000000, 0x00000000}},  //   fcon, rchl_,   ,
  { {0x69d80073, 0xa2cd007d, 0x26170061, 0x00000000}},  //   _över, _सिद्, नाही_,
  { {0x387e028c, 0x27e90203, 0x7a2b2beb, 0x00000000}},  //   ître_, mfan_, _fütt,
  { {0x27e9018e, 0x63a21762, 0x64480006, 0x00000000}},  //   lfan_, acon, _įdie,
  { {0x66151f6c, 0x92d90044, 0x008501ab, 0x00000000}},  //   _inzk, ়বে_, олко,
  { {0x63a20207, 0x27e901aa, 0x2bdb007d, 0x00000000}},  //   ccon, nfan_, _भाषा,
  { {0xcdf50a78, 0x3255007e, 0x94160061, 0x00000000}},  //   очны, _двар, णारच_,
  { {0xa6e2009f, 0x7bdf38ce, 0x926b003b, 0x00000000}},  //   æðin, _acqu, _срба_,
  { {0xcb0900b6, 0x6155026c, 0x63bb04cb, 0x00000000}},  //   _של_, _بنائ, _keun,
  { {0x63bb028c, 0x645901aa, 0x20030089, 0x00000000}},  //   _jeun, nnwi, ējis_,
  { {0xa3e10316, 0x628138cf, 0x64db0061, 0x00000000}},  //   _दान_, _khlo, मंडळ,
  { {0x3ead023a, 0x63bb0599, 0x7bdf0026, 0x00000000}},  //   mpet_, _leun, _ecqu,
  { {0x290c38d0, 0x63a20009, 0x27e938d1, 0x00000000}},  //   ída_, ycon, ffan_,
  { {0x63a20061, 0x6ab60007, 0xe7aa004d, 0x00000000}},  //   xcon, _twyf, рвал_,
  { {0x464a38d2, 0xdb0d0181, 0x63a20009, 0x00000000}},  // [c940] азан_, _reaç, vcon,
  { {0xe61706b6, 0x63a20b2c, 0x683800d4, 0x00000000}},  //   оду_, wcon, _dída,
  { {0x69dc0061, 0x63a20061, 0x27e900d9, 0x00000000}},  //   mgre, tcon, bfan_,
  { {0x69dc0218, 0x87d60355, 0x6d41016e, 0x00000000}},  //   lgre, _بغدا, izla,
  { {0x6f09037e, 0x63a21017, 0x63bb0016, 0x00000000}},  //   jvec, rcon, _deun,
  { {0x6281002a, 0x63a22817, 0x24860213, 0x00000000}},  //   _chlo, scon, smom_,
  { {0x63a200bb, 0x24860606, 0x628101c3, 0x00000000}},  //   pcon, pmom_, _dhlo,
  { {0x3ec60057, 0x21200091, 0x3ae403ed, 0x00000000}},  //   особ, ćih_, köp_,
  { {0x3169005a, 0x2be1013d, 0xb69b00e5, 0x00000000}},  //   ğaza_, _काबू_, _frâu,
  { {0x20020059, 0x63bb0032, 0xb69b0035, 0x00000000}},  //   žki_, _zeun, _grâu,
  { {0xafe601fb, 0x69dc38d3, 0xc2230014, 0x00000000}},  //   _можл, dgre, _تکنو,
  { {0x09d3001c, 0x1ee90014, 0x69dc00bb, 0x00000000}},  //   तल्य, جویی_, egre,
  { {0xfad8005e, 0x69dc141a, 0x00000000, 0x00000000}},  //   одящ_, fgre,   ,
  { {0x69dc0460, 0xa2cd006e, 0xfc46000c, 0x00000000}},  //   ggre, _सिस्, _þína_,
  { {0x260503d7, 0x7a3f0224, 0x199406c4, 0x00000000}},  //   _होगी_, vště, даря,
  { {0xdc2b0014, 0x6483006c, 0x69d70061, 0x00000000}},  //   _خسته_, mõig, _बाकी,
  { {0x63bb03d1, 0x27e90a2d, 0x69dc0b3a, 0x00000000}},  // [c950] _reun, rfan_, bgre,
  { {0x63bb0007, 0x61f8041a, 0x1a6500a2, 0x00000000}},  //   _seun, jevl, _ریزی_,
  { {0x61f80007, 0x63bb0022, 0x00000000, 0x00000000}},  //   devl, _peun,   ,
  { {0x7bdd2375, 0x29010065, 0x9404006b, 0x00000000}},  //   ngsu, _isha_, _kimə_,
  { {0x62810863, 0x683138d4, 0x78a20243, 0x00000000}},  //   _phlo, _rådh, _čovi,
  { {0x960b007e, 0x2c560089, 0xddda00b9, 0x00000000}},  //   _тэма_, rādi_, potř,
  { {0x63bb1ad9, 0x00000000, 0x00000000, 0x00000000}},  //   _teun,   ,   ,
  { {0x6f090039, 0x3ead0082, 0x68310146, 0x00000000}},  //   tvec, tpet_, _bådi,
  { {0x69dc024d, 0xf1a701ee, 0xed6300b9, 0x00000000}},  //   ygre, _дрен, _mužů_,
  { {0xee390113, 0x6f090ce3, 0x7a30010f, 0x00000000}},  //   сно_, rvec, _täti,
  { {0x6f09016c, 0x69dc03b1, 0x00000000, 0x00000000}},  //   svec, vgre,   ,
  { {0x3ead27a1, 0xaa7b00b9, 0x2bbe01f5, 0x00000000}},  //   ppet_, stýl, ्णधा,
  { {0x7ae4001c, 0xc052007b, 0x69dc38d5, 0x00000000}},  //   _qqit, _אזא_, tgre,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69dc000c, 0x32050a32, 0x7d1c00f8, 0x00000000}},  //   rgre, _maly_, ärst,
  { {0x69dc021a, 0x7a300039, 0x61e10093, 0x00000000}},  //   sgre, _nätv, _lcll,
  { {0x29010093, 0x61f8006b, 0xfc57009b, 0x00000000}},  // [c960] _esha_, yevl, _מבקש_,
  { {0xd6cf023c, 0x68fc005b, 0x8ebd0044, 0x00000000}},  //   اقل_, pwrd, _আমাগ,
  { {0xb3a901f6, 0x399b00a3, 0x7a2b006c, 0x00000000}},  //   ğını, _לייד, _tütr,
  { {0xb3a9005d, 0x1459007e, 0xb69b00e5, 0x00000000}},  //   şını, ошчы_, _crâs,
  { {0x224c0093, 0x81ad0044, 0x00000000, 0x00000000}},  //   _pmdk_, _কয়_,   ,
  { {0xd5b2004b, 0xa2cd03d7, 0x5693007e, 0x00000000}},  //   _سفر_, _सिर्, _паўт,
  { {0x490f03d7, 0x3205013e, 0x61f8014a, 0x00000000}},  //   डियो_, _daly_, revl,
  { {0x61f80107, 0x8f460265, 0xf99300b3, 0x00000000}},  //   sevl, зход, ערה_,
  { {0x141b009b, 0x09e30044, 0x00000000, 0x00000000}},  //   _פומב, য়তা,   ,
  { {0x7bc0000c, 0x2d9805ba, 0x6838008e, 0x00000000}},  //   ðmun, øre_, _oído,
  { {0xfc3f002a, 0xe0d200a1, 0x1ddd0164, 0x00000000}},  //   thí_, _سزا_, _मारत,
  { {0x2fc0009f, 0x2c560089, 0x628a00f8, 0x00000000}},  //   _þig_, kādu_, lmfo,
  { {0x7afd00b5, 0x764e1a95, 0x6483006c, 0x00000000}},  //   uwst, _omby, sõig,
  { {0x6f021cbd, 0x00000000, 0x00000000, 0x00000000}},  //   _isoc,   ,   ,
  { {0x7d1c03b1, 0x00000000, 0x00000000, 0x00000000}},  //   årsd,   ,   ,
  { {0x764e0544, 0x00000000, 0x00000000, 0x00000000}},  //   _amby,   ,   ,
  { {0x387e009d, 0x7bcd0288, 0x00000000, 0x00000000}},  // [c970] îtra_, _idau,   ,
  { {0x6aad38d6, 0x20060048, 0x00000000, 0x00000000}},  //   _itaf, _laoi_,   ,
  { {0xdb04000c, 0x290138d7, 0xa8a4005e, 0x00000000}},  //   _heið, _usha_, _пряк,
  { {0x4429009f, 0x628a0007, 0x683800b9, 0x00000000}},  //   ða_, emfo, _jídl,
  { {0xfe780006, 0x15ab02dc, 0x6483010e, 0x00000000}},  //   klį_, _гъби_, võid,
  { {0x6aad00e7, 0x24840026, 0xd49b0088, 0x00000000}},  //   _mtaf, _ehmm_, _гра_,
  { {0xdb04009f, 0x208901e0, 0x94770014, 0x00000000}},  //   _leið, ойки_, _فدرا,
  { {0x7a3038d8, 0x66070107, 0xdb060010, 0x00000000}},  //   _hätt, _hajk, makö,
  { {0x7a300934, 0x2c210061, 0x1f6502d3, 0x00000000}},  //   _kätt, यानं_, ьким,
  { {0xf1a70265, 0x7a3038d9, 0x7bcd000d, 0x00000000}},  //   _хран, _jätt, _adau,
  { {0x20060195, 0x66070119, 0xd9e30055, 0x00000000}},  //   _faoi_, _majk, য়াম,
  { {0x7a300e2b, 0x6fd6005d, 0xdb04000c, 0x00000000}},  //   _lätt, rücü, _beið,
  { {0x8d7702fd, 0x00000000, 0x00000000, 0x00000000}},  //   _کاشا,   ,   ,
  { {0x660709fc, 0x7a3009f0, 0x00000000, 0x00000000}},  //   _najk, _nätt,   ,
  { {0x20060061, 0x6f0d334d, 0x00000000, 0x00000000}},  //   _yaoi_, _šach,   ,
  { {0xf77201b7, 0x00000000, 0x00000000, 0x00000000}},  //   ناء_,   ,   ,
  { {0x6607016c, 0x7a300073, 0x2fc0006c, 0x00000000}},  // [c980] _bajk, _bätt, _õige_,
  { {0xaad30061, 0x6607016e, 0x644301d6, 0x00000000}},  //   _तितक, _cajk, ënin,
  { {0x29040089, 0x88860256, 0xca37009b, 0x00000000}},  //   āmas_, _олож, _חניה_,
  { {0x25fa03d7, 0x66070032, 0x3b120023, 0x00000000}},  //   _उसकी_, _eajk, _kryq_,
  { {0x59d201f5, 0x7c3d0065, 0x00000000, 0x00000000}},  //   _तयार, ërri,   ,
  { {0x27e01402, 0x386d0626, 0x63a9014a, 0x00000000}},  //   lgin_, čere_, _efen,
  { {0x2c0e03d7, 0x63a9018e, 0x6abd0164, 0x00000000}},  //   ियां_, _ffen, _्ट्र,
  { {0x27e0006a, 0x161c0061, 0x24840058, 0x00000000}},  //   ngin_, नावर_, _uhmm_,
  { {0x6442002a, 0x7a3031e5, 0x00000000, 0x00000000}},  //   mhoi, _jäts,   ,
  { {0x442601d9, 0xddc80036, 0xdb04000c, 0x00000000}},  //   ljo_, widł, _reið,
  { {0x6aad0787, 0xb1430517, 0x44260006, 0x00000000}},  //   _staf, _инфл, ojo_,
  { {0x44260059, 0x3cdf013d, 0x800b00a1, 0x00000000}},  //   njo_, _कमरे_, _ورنہ_,
  { {0xf04704e1, 0x442600c4, 0xa3e1007d, 0x00000000}},  //   _تعلی, ijo_, _दास_,
  { {0xdb04000c, 0xc3330097, 0x44260022, 0x00000000}},  //   _veið, דוש_, hjo_,
  { {0x7a300073, 0x66070107, 0x8c670aa2, 0x00000000}},  //   _rätt, _rajk, _отид,
  { {0x7a300274, 0x27e001e5, 0x44262123, 0x00000000}},  //   _sätt, ggin_, jjo_,
  { {0x4426002b, 0x6aad38da, 0x290c0039, 0x00000000}},  // [c990] djo_, _utaf, ådar_,
  { {0xb3a9005d, 0x4426007f, 0x3e7900f6, 0x00000000}},  //   ğımı, ejo_, gèth_,
  { {0xb3a9005d, 0x38c902fd, 0x7c2d1b61, 0x00000000}},  //   şımı, _عادی_, _koar,
  { {0x442638db, 0xdb16000a, 0x00000000, 0x00000000}},  //   gjo_, _idyò,   ,
  { {0x7c2d001a, 0x6607021c, 0x160a013d, 0x00000000}},  //   _moar, _tajk, _होकर_,
  { {0xdd8605f3, 0x13080088, 0x7c2d0288, 0x00000000}},  //   _مو_, ьній_, _loar,
  { {0x44260087, 0x2eff0145, 0x00000000, 0x00000000}},  //   bjo_, wwuf_,   ,
  { {0x2bdb001c, 0x2c64005f, 0x644207cd, 0x00000000}},  //   _भागा, kıda_, choi,
  { {0x443f0acc, 0x26c900fa, 0x8e550245, 0x00000000}},  //   _ilu_, nsao_, етні,
  { {0x442d0100, 0x26c90011, 0x26cb00f6, 0x00000000}},  //   _hoe_, isao_, _mvco_,
  { {0x7c2d0038, 0x9f4f008e, 0x443f01a3, 0x00000000}},  //   _boar, _pagó_, _klu_,
  { {0xcfe90014, 0x7c2d1e47, 0x644a009d, 0x00000000}},  //   _رفته_, _coar, éfix,
  { {0x442d1696, 0x7c2d001a, 0x9f4f00f6, 0x00000000}},  //   _moe_, _doar, _vagó_,
  { {0x442d0004, 0x0f56009b, 0x7a300e4d, 0x00000000}},  //   _loe_, _אינם_, _räts,
  { {0x7c2d000d, 0x3da601fb, 0x44260173, 0x00000000}},  //   _foar, _якщо_, yjo_,
  { {0x442d0292, 0x7b0500b0, 0xdcf80089, 0x00000000}},  //   _noe_, ättä, _uzvā,
  { {0x7bc60ea6, 0x27e00472, 0x44260059, 0x00000000}},  // [c9a0] maku, rgin_, vjo_,
  { {0x7bc60149, 0x442d0082, 0x7a3000f8, 0x00000000}},  //   laku, _aoe_, _väts,
  { {0x6442002a, 0x442d00d4, 0x61fe006b, 0x00000000}},  //   thoi, _boe_, _özlə,
  { {0x7bc60020, 0x44261be5, 0x443f00e5, 0x00000000}},  //   naku, ujo_, _clu_,
  { {0x68e30073, 0x44260022, 0x779400a6, 0x00000000}},  //   _ändr, rjo_, _شیطا,
  { {0x443f0004, 0x644201c2, 0x6b840020, 0x00000000}},  //   _elu_, shoi, _mzig,
  { {0x7bc6272e, 0x443f2528, 0x64420051, 0x00000000}},  //   kaku, _flu_, phoi,
  { {0x386006d6, 0x68e305b7, 0x442d00bb, 0x00000000}},  //   nnir_, _ånde, _goe_,
  { {0x64400297, 0xcee7003b, 0x7bc60032, 0x00000000}},  //   _ilmi, едње_, daku,
  { {0x7c2d03c7, 0x9f4f0026, 0x443f0466, 0x00000000}},  //   _soar, _pagò_, _zlu_,
  { {0x3860009f, 0x443f0009, 0x7c2d001a, 0x00000000}},  //   knir_, _ylu_, _poar,
  { {0x629a0733, 0x09a90061, 0x00000000, 0x00000000}},  //   _hito, कड्य,   ,
  { {0x629a010a, 0x2aab01e0, 0x3eaf0082, 0x00000000}},  //   _kito, ятно_, _gtgt_,
  { {0x629a002b, 0x2c64005a, 0x6b84012d, 0x00000000}},  //   _jito, rıda_, _dzig,
  { {0x38602abb, 0x7c2d0035, 0xa3e10309, 0x00000000}},  //   fnir_, _toar, _दाल_,
  { {0xc6a70194, 0x3860000c, 0x6d7b009b, 0x00000000}},  //   ержи, gnir_, _מאוח,
  { {0x64430065, 0x7c3d0065, 0xf1be002b, 0x00000000}},  // [c9b0] ënim, ërru, ġġja_,
  { {0x64400030, 0x629a011c, 0x443f38dc, 0x00000000}},  //   _almi, _nito, _slu_,
  { {0x442d010e, 0x69c725c2, 0x443f2b60, 0x00000000}},  //   _poe_, maje, _plu_,
  { {0x13a7007a, 0x629a002d, 0xe3b30464, 0x00000000}},  //   رنتی_, _aito, ارض_,
  { {0x661c0009, 0x443f01c3, 0x00000000, 0x00000000}},  //   _fnrk, _vlu_,   ,
  { {0x69c70390, 0x6440006b, 0x00000000, 0x00000000}},  //   naje, _elmi,   ,
  { {0xfa130055, 0x7bc60020, 0x442d26c5, 0x00000000}},  //   _সকাল_, yaku, _toe_,
  { {0x6288021e, 0x443f200f, 0x6458009d, 0x00000000}},  //   _ehdo, _ulu_, évit,
  { {0x629a008d, 0x7bc61f47, 0x60060783, 0x00000000}},  //   _fito, vaku, тным_,
  { {0x7bc6000b, 0x69c700ee, 0x629a38dd, 0x00000000}},  //   waku, jaje, _gito,
  { {0x69c7016c, 0x7bc60eac, 0x0d8207ca, 0x00000000}},  //   daje, taku, ильн,
  { {0x629a00e7, 0x6f0d012d, 0x7d1c05fe, 0x00000000}},  //   _zito, _šacu, årsa,
  { {0x7bc600b0, 0xdee5007c, 0xde051fd9, 0x00000000}},  //   raku, _роли, _апли,
  { {0xc33200b6, 0x69c7001a, 0x7bc6006c, 0x00000000}},  //   סום_, gaje, saku,
  { {0x7bc616d8, 0x3860000c, 0x929d00b4, 0x00000000}},  //   paku, tnir_, _osło,
  { {0x200d0bc0, 0x64430964, 0x6b840a86, 0x00000000}},  //   ndei_, ūnij, _tzig,
  { {0x3860009f, 0xe9f9001d, 0xe5a60200, 0x00000000}},  // [c9c0] rnir_, _quả_, визи,
  { {0x69c7037e, 0x68380181, 0x386d0142, 0x00000000}},  //   caje, _mídi, čera_,
  { {0x69d9007b, 0x629a0207, 0xf8660b81, 0x00000000}},  //   _אַרו, _rito, _авно,
  { {0x629a0fa8, 0x779400a6, 0x6aa422fc, 0x00000000}},  //   _sito, _میزا, _kuif,
  { {0x629a016e, 0x6aa4009d, 0x200d0026, 0x00000000}},  //   _pito, _juif, ddei_,
  { {0x7bc4006c, 0x53331947, 0x9c7d016c, 0x00000000}},  //   _leiu, решт, rtči,
  { {0x645800f4, 0x2576007a, 0x6aa400d9, 0x00000000}},  //   évis, _شهرس, _luif,
  { {0xdfd00025, 0x69c70010, 0x7bc4010e, 0x00000000}},  //   حية_, zaje, _neiu,
  { {0x629a0198, 0x26170061, 0x26c70091, 0x00000000}},  //   _tito, नाची_, ćnog_,
  { {0x4375008b, 0x629a0112, 0x200d0035, 0x00000000}},  //   _суст, _uito, adei_,
  { {0x69c700ca, 0x6d480a14, 0x7bc40035, 0x00000000}},  //   vaje, uzda, _beiu,
  { {0x26cf0010, 0x69c700e7, 0x683800f6, 0x00000000}},  //   ágok_, waje, _fídi,
  { {0x9c7d1034, 0xa3ea0309, 0xfe4600e2, 0x00000000}},  //   juče, _मान_, _индо,
  { {0xaa6403f3, 0x6aa401c3, 0x00000000, 0x00000000}},  //   атск, _duif,   ,
  { {0x69c7016c, 0x27f20016, 0x67d50088, 0x00000000}},  //   raje, ffyn_, лову,
  { {0x69c7050a, 0x6ebf03d7, 0x64430089, 0x00000000}},  //   saje, लीवु, īnik,
  { {0x81cd0055, 0x09d80055, 0xc6a4025f, 0x00000000}},  // [c9d0] ষ্ট_, দ্ধা, архи,
  { {0x7c3d0007, 0x00000000, 0x00000000, 0x00000000}},  //   lksr,   ,   ,
  { {0x657c0016, 0x97830014, 0x73d900e2, 0x00000000}},  //   _cyrh, _چیزه, едер_,
  { {0x69c51312, 0xccf3007b, 0x7a2b010f, 0x00000000}},  //   _hehe, יכע_, _nütz,
  { {0x623500ed, 0x69c5003f, 0x645800d4, 0x00000000}},  //   леду, _kehe, èvia,
  { {0x683800d4, 0x016509ae, 0x00000000, 0x00000000}},  //   _rídi, лкло,   ,
  { {0x69c52de6, 0x63a40006, 0x320c0173, 0x00000000}},  //   _mehe, žina, _dady_,
  { {0x69c538de, 0xa3ea0164, 0x00000000, 0x00000000}},  //   _lehe, _माय_,   ,
  { {0x200d1290, 0xe8e10082, 0x645901a3, 0x00000000}},  //   rdei_, _ướp_, miwi,
  { {0x69c50010, 0x41c7013d, 0x64590036, 0x00000000}},  //   _nehe, _रजिस, liwi,
  { {0xdb1d0010, 0x00000000, 0x00000000, 0x00000000}},  //   vasá,   ,   ,
  { {0x9f0503ab, 0x6aa400d9, 0x00000000, 0x00000000}},  //   _موصو, _puif,   ,
  { {0xa2db006e, 0xa3e101f5, 0xc0b9013e, 0x00000000}},  //   _निफ्, _दाई_, žádá,
  { {0x9c7d0091, 0xfaa300e2, 0x69c5005a, 0x00000000}},  //   vuče, саро, _cehe,
  { {0x7aef001c, 0x69c5002b, 0xd943007c, 0x00000000}},  //   atct, _dehe, бери,
  { {0x2b55007a, 0x7d7a0049, 0x69c50058, 0x00000000}},  //   ایید_, _אנצו, _eehe,
  { {0x7aef001c, 0x27f238df, 0x645901d6, 0x00000000}},  // [c9e0] ctct, rfyn_, diwi,
  { {0x69c50683, 0x9c7d01ca, 0x1a0609bb, 0x00000000}},  //   _gehe, ruče, _спом,
  { {0x320c08e2, 0x9916007e, 0x2e3a0049, 0x00000000}},  //   _rady_, _сьпі, עגענ,
  { {0x320c01ca, 0x69c501a2, 0x00000000, 0x00000000}},  //   _sady_, _zehe,   ,
  { {0x4caa0055, 0x69c50058, 0x00000000, 0x00000000}},  //   _কিছু, _yehe,   ,
  { {0x69c538e0, 0xe2970887, 0xc4c61289, 0x00000000}},  //   _xehe, гач_, _مترو,
  { {0x69c1000c, 0xca7b0049, 0x00000000, 0x00000000}},  //   ðlei, ענצט,   ,
  { {0x044305b5, 0xc0340184, 0xaa7b000c, 0x00000000}},  //   _лесн, рниј, ntýr,
  { {0x320c093f, 0x627b0036, 0x44ee01ca, 0x00000000}},  //   _tady_, _słoń, lý_,
  { {0x1ef70054, 0x98ac013e, 0x00000000, 0x00000000}},  //   اعية_, ádě_,   ,
  { {0x44ee01ca, 0x2d98010f, 0x69c533be, 0x00000000}},  //   ný_, äre_, _rehe,
  { {0x7aef001c, 0x69c52934, 0xa2db007d, 0x00000000}},  //   ttct, _sehe, _निम्,
  { {0xe457007b, 0x98aa0006, 0x7c3d05d5, 0x00000000}},  //   ריכט_, mybę_, rksr,
  { {0x645900b4, 0x00000000, 0x00000000, 0x00000000}},  //   ziwi,   ,   ,
  { {0x69c50010, 0x19950c4e, 0x61f5014a, 0x00000000}},  //   _vehe, равя, _özle,
  { {0x57b50517, 0x36d5007c, 0x3ea600e0, 0x00000000}},  //   рбат, иобр, _kuot_,
  { {0x69c50010, 0x660e0ad0, 0x00000000, 0x00000000}},  // [c9f0] _tehe, _babk,   ,
  { {0x81c20089, 0x645900e0, 0x443d0022, 0x00000000}},  //   šēja, wiwi, wkw_,
  { {0x64590007, 0xc66800ed, 0x98aa0006, 0x00000000}},  //   tiwi, уште_, kybę_,
  { {0xe315003b, 0x00000000, 0x00000000, 0x00000000}},  //   имењ,   ,   ,
  { {0x6459023a, 0x3a331445, 0x00000000, 0x00000000}},  //   riwi, _koxp_,   ,
  { {0x645938e1, 0x8627007e, 0xd5f90049, 0x00000000}},  //   siwi, _сьме, _בפֿר,
  { {0x90c20680, 0x00000000, 0x00000000, 0x00000000}},  //   обще,   ,   ,
  { {0x44d1010a, 0xc0a8023c, 0x3ea60058, 0x00000000}},  //   mą_, داول_, _buot_,
  { {0x41e706b4, 0x5347012b, 0x44d10a67, 0x00000000}},  //   _مساف, _схва, lą_,
  { {0xee360057, 0x611c0035, 0x00000000, 0x00000000}},  //   ины_, _bălă,   ,
  { {0x44d10a66, 0x2167008b, 0x611c001a, 0x00000000}},  //   ną_, _стаг, _călă,
  { {0xed560cab, 0x5c5601e0, 0x2fc600e0, 0x00000000}},  //   рою_, ртоф, _geog_,
  { {0xfaa6007e, 0x00000000, 0x00000000, 0x00000000}},  //   раго,   ,   ,
  { {0x44d10eda, 0x7f840054, 0x200f0129, 0x00000000}},  //   ką_, _الهن, _hagi_,
  { {0x44d11d6e, 0x5d79007b, 0x611c0035, 0x00000000}},  //   ją_, _באַק, _gălă,
  { {0x44ee0428, 0x44d10bd7, 0x09e30044, 0x00000000}},  //   vý_, dą_, য়গা,
  { {0xe7370057, 0x2ca700eb, 0x66e6007e, 0x00000000}},  // [ca00] ает_, _hund_, роза,
  { {0x200f117c, 0x248d0058, 0x2ca70039, 0x00000000}},  //   _lagi_, _ahem_, _kund_,
  { {0x89db034e, 0x44d1093c, 0x4ca70044, 0x00000000}},  //   _בחיי, gą_, _কৌতু,
  { {0x2ca7048a, 0x44ee0428, 0x66e602b8, 0x00000000}},  //   _mund_, rý_, _кома,
  { {0x63a40dc6, 0x2ca701bf, 0xddc10059, 0x00000000}},  //   žino, _lund_, dolž,
  { {0x248d0f5e, 0x32530088, 0x44d1093c, 0x00000000}},  //   _ehem_, овір, bą_,
  { {0x200f020c, 0xa3ea005e, 0x3ea6011c, 0x00000000}},  //   _bagi_, _идва_, _suot_,
  { {0x64a3008b, 0x63ad008e, 0x3ea600e0, 0x00000000}},  //   _фата, ñant, _puot_,
  { {0x3ea60032, 0x9c7d0ce4, 0x91e60fc0, 0x00000000}},  //   _quot_, juča, _возе,
  { {0x2ca70c53, 0x63790147, 0x68fe0292, 0x00000000}},  //   _bund_, _ссср_, _oppd,
  { {0x2a7800f6, 0x00000000, 0x00000000, 0x00000000}},  //   dorb_,   ,   ,
  { {0x2ca00009, 0xdb060010, 0x00000000, 0x00000000}},  //   _ciid_, bbkü,   ,
  { {0xba770025, 0x291a38e2, 0xbf1600a6, 0x00000000}},  //   لاست, _arpa_, _خوشب,
  { {0x2004014a, 0x6483006c, 0x2ca7071e, 0x00000000}},  //   lemi_, võim, _fund_,
  { {0x6cd4025a, 0x2ca7000a, 0xdd8f023c, 0x00000000}},  //   _اقبا, _gund_, _قوه_,
  { {0x200438e3, 0x9c7d02aa, 0x44d10006, 0x00000000}},  //   nemi_, buča, vą_,
  { {0x44d10046, 0xcf930049, 0xe0e20044, 0x00000000}},  // [ca10] wą_, ַטע_, _মনোন,
  { {0x44d10a66, 0x20040065, 0xaae600a1, 0x00000000}},  //   tą_, hemi_, _اسٹو,
  { {0x20040066, 0xd041006b, 0xb342006b, 0x00000000}},  //   kemi_, _evlə, əçil,
  { {0x44d10a66, 0x20041080, 0xa9160049, 0x00000000}},  //   rą_, jemi_, _פֿיס_,
  { {0x77640265, 0x200401a3, 0x44d10bd7, 0x00000000}},  //   _държ, demi_, są_,
  { {0x27e91ad4, 0x2169003b, 0x44d10bd7, 0x00000000}},  //   lgan_, лили_, pą_,
  { {0x248d38e4, 0x200f04cb, 0x660538e5, 0x00000000}},  //   _them_, _pagi_, mehk,
  { {0x27e91535, 0x2ca7010f, 0x683800c4, 0x00000000}},  //   ngan_, _rund_, _hídr,
  { {0x2ca7158f, 0x200f0129, 0x27e9004a, 0x00000000}},  //   _sund_, _vagi_, igan_,
  { {0xf1f800a6, 0xd2510025, 0x200f00b4, 0x00000000}},  //   _نعمت_, _عنا_, _wagi_,
  { {0x200f0036, 0x802700a1, 0x3dc700d9, 0x00000000}},  //   _tagi_, _پرام, _venw_,
  { {0x69d7049a, 0x200400b9, 0x6f19005b, 0x00000000}},  //   _adxe, cemi_, _trwc,
  { {0x291a016c, 0x70740025, 0x6da502dc, 0x00000000}},  //   _srpa_, _بالذ, _лила,
  { {0x9c7d0166, 0x2ca7006c, 0x2ca001d6, 0x00000000}},  //   ruča, _tund_, _wiid_,
  { {0xceb4006b, 0x6e2335dd, 0xa3e70061, 0x00000000}},  //   _çər_, _innb, पला_,
  { {0x9c7d040d, 0x27e901a3, 0x2a780a6b, 0x00000000}},  //   lučn, ggan_, sorb_,
  { {0x81df0044, 0x7c24011c, 0x644a0023, 0x00000000}},  // [ca20] ধ্য_, _inir, ëfim,
  { {0xa3ea013d, 0x27e938e6, 0x7ae6033b, 0x00000000}},  //   _माह_, agan_, mukt,
  { {0xeafa01ef, 0x68fe0073, 0x7ae6066b, 0x00000000}},  //   _شرکت_, _uppd, lukt,
  { {0x69ce022b, 0x6283145e, 0x03260741, 0x00000000}},  //   labe, elno, йден,
  { {0x06b20044, 0x26cf0010, 0x61fa0085, 0x00000000}},  //   _চিকি, ágot_, _pbtl,
  { {0xfe670379, 0x9c7d01ae, 0xd250067a, 0x00000000}},  //   _رد_, jučn, بنت_,
  { {0x20040617, 0xb3a90180, 0x1a9b0049, 0x00000000}},  //   temi_, ğırı, ניצע,
  { {0x62831091, 0x09e10044, 0x69ce03ae, 0x00000000}},  //   alno, ম্পা, habe,
  { {0x69ce0018, 0x200401aa, 0xd0070143, 0x00000000}},  //   kabe, remi_, сење_,
  { {0x2004000c, 0x7c240129, 0x0737009b, 0x00000000}},  //   semi_, _anir, צאים_,
  { {0x667b007b, 0x38ae000c, 0x78bc00b9, 0x00000000}},  //   רטיק, _nýr_, jprv,
  { {0xdee60072, 0x4424000a, 0x644200b0, 0x00000000}},  //   _годи, _jnm_, nkoi,
  { {0x69ce049a, 0x27e9000a, 0xf1ac013d, 0x00000000}},  //   fabe, vgan_, _चलान,
  { {0x69ce084b, 0x7c2438e7, 0x61ea000c, 0x00000000}},  //   gabe, _enir, ngfl,
  { {0x442400bb, 0x27e938e8, 0x644200b0, 0x00000000}},  //   _onm_, tgan_, kkoi,
  { {0x7ae638e9, 0x38ae000c, 0x44240009, 0x00000000}},  //   bukt, _dýr_, _nnm_,
  { {0x7bcf106f, 0x69ce0232, 0x27e902f1, 0x00000000}},  // [ca30] macu, babe, rgan_,
  { {0x69ce0211, 0x6b8d0032, 0x27e91a16, 0x00000000}},  //   cabe, _izag, sgan_,
  { {0x442401a3, 0x6f0901a2, 0x00000000, 0x00000000}},  //   _bnm_, zwec,   ,
  { {0x26cf0010, 0x7bcf0035, 0x44240095, 0x00000000}},  //   ágos_, nacu, _cnm_,
  { {0x386903ed, 0xa3ea006e, 0x23291074, 0x00000000}},  //   mnar_, _मार_, роли_,
  { {0x386900d0, 0x41e70088, 0x7a3001a2, 0x00000000}},  //   lnar_, сіда, _sätz,
  { {0x386938ea, 0x64430a5b, 0x00000000, 0x00000000}},  //   onar_, ënis,   ,
  { {0x38690635, 0xd259000a, 0x7ae60022, 0x00000000}},  //   nnar_, _kwņk_, yukt,
  { {0x3869009f, 0x09e10044, 0xdb1d0010, 0x00000000}},  //   inar_, ম্যা, bbsé,
  { {0xc0cb01fb, 0x3f83001e, 0x6f0901a2, 0x00000000}},  //   _буде_, āju_, rwec,
  { {0x9c7d0c76, 0x64491440, 0x320707e4, 0x00000000}},  //   ručn, _klei, meny_,
  { {0x32070062, 0x7f190088, 0x09e10044, 0x00000000}},  //   leny_, _віку_, ম্মা,
  { {0xe04201fb, 0x69ce0181, 0x386938eb, 0x00000000}},  //   _інши, tabe, dnar_,
  { {0x644938ec, 0x98a6025f, 0x2caa0051, 0x00000000}},  //   _llei, живе, úidí_,
  { {0x69ce014a, 0x6b8d022b, 0x3ce0013d, 0x00000000}},  //   rabe, _ezag, _किये_,
  { {0x7c24106f, 0x386906a1, 0x00000000, 0x00000000}},  //   _unir, gnar_,   ,
  { {0xa2db0309, 0x63a40006, 0x29010058, 0x00000000}},  // [ca40] _निष्, žink, _epha_,
  { {0x09e10044, 0x645b0051, 0xf65f0030, 0x00000000}},  //   ম্বা, _amui, _svær_,
  { {0x6449001f, 0x8506007a, 0x320701ca, 0x00000000}},  //   _blei, توان, deny_,
  { {0x644921b2, 0xa2db0309, 0x9c830027, 0x00000000}},  //   _clei, _निश्, _účto,
  { {0x6442021e, 0x442438ed, 0x00000000, 0x00000000}},  //   rkoi, _vnm_,   ,
  { {0xa2db02fb, 0x644902d5, 0x644200b0, 0x00000000}},  //   _निर्, _elei, skoi,
  { {0x644938ee, 0xf65f000c, 0x7bcf004a, 0x00000000}},  //   _flei, _tvær_, yacu,
  { {0x6449001f, 0x09b70201, 0x44240022, 0x00000000}},  //   _glei, _अभ्य, _unm_,
  { {0x7bcf00e5, 0x7e2a007e, 0x32070062, 0x00000000}},  //   vacu, аіна_, beny_,
  { {0x24860292, 0xa3ea013d, 0x386d0091, 0x00000000}},  //   llom_, _माँ_, čeri_,
  { {0x6449021e, 0x7bcf0285, 0x38690477, 0x00000000}},  //   _ylei, tacu, ynar_,
  { {0xa2c1007d, 0x6b840009, 0x00000000, 0x00000000}},  //   रीक्, _byig,   ,
  { {0x997c0089, 0x6b840045, 0x7e7a04eb, 0x00000000}},  //   _jāņa_, _cyig, potp,
  { {0x6f02237d, 0x7bcf008e, 0xda7b213f, 0x00000000}},  //   _ipoc, sacu, рям_,
  { {0xa3ea013d, 0x7bcf0035, 0x3869000c, 0x00000000}},  //   _मां_, pacu, tnar_,
  { {0x765c018e, 0x2486041a, 0x32070802, 0x00000000}},  //   _amry, jlom_, zeny_,
  { {0x386938ef, 0xf7730076, 0x24860142, 0x00000000}},  // [ca50] rnar_, ذار_, dlom_,
  { {0x64491f1c, 0xf1bf0011, 0x386901e5, 0x00000000}},  //   _slei, _đáo_, snar_,
  { {0x6449028c, 0xd49b0517, 0x38690039, 0x00000000}},  //   _plei, ард_, pnar_,
  { {0x24860107, 0x3cfb0049, 0x44270025, 0x00000000}},  //   glom_, שלאנ, غراف,
  { {0x069b007a, 0x64490007, 0x7bcd009d, 0x00000000}},  //   _نخست_, _vlei, _meau,
  { {0x6aad38f0, 0x64490016, 0xe60100b0, 0x00000000}},  //   _muaf, _wlei, ävää,
  { {0x24860007, 0x6615002d, 0x768b014a, 0x00000000}},  //   blom_, _iazk, lüyo,
  { {0x32070129, 0xe45f38f1, 0x6615002d, 0x00000000}},  //   seny_, _öö_, _hazk,
  { {0x63a938f2, 0x6615010a, 0x768b011f, 0x00000000}},  //   _igen, _kazk, nüyo,
  { {0x5bb6024c, 0xfe710025, 0x3eb90089, 0x00000000}},  //   ूर्व, عدة_, īst_,
  { {0x7bcd0549, 0x3eb90089, 0x6f021d28, 0x00000000}},  //   _beau, ūst_, _epoc,
  { {0x801401fb, 0x7bcd001a, 0x6615002d, 0x00000000}},  //   _офіц, _ceau, _lazk,
  { {0x7ff400a6, 0x63a90020, 0x7bcd009d, 0x00000000}},  //   _آسما, _mgen, _deau,
  { {0xdb0f002a, 0x3ebf033b, 0x66150032, 0x00000000}},  //   ódái, mput_, _nazk,
  { {0x660a005f, 0x929d0046, 0x63a938f3, 0x00000000}},  //   _ölkə, _usłu, _ogen,
  { {0x63a40dc6, 0x7bcd00bb, 0x6d41005b, 0x00000000}},  //   žini, _geau, myla,
  { {0x6615002d, 0x6d4138f4, 0x3ebf016e, 0x00000000}},  // [ca60] _bazk, lyla, nput_,
  { {0xa596007c, 0x00000000, 0x00000000, 0x00000000}},  //   прещ,   ,   ,
  { {0x6d410010, 0x2c21001c, 0xe9f90011, 0x00000000}},  //   nyla, याचं_, _huế_,
  { {0x3a3a0039, 0x6d5c0048, 0x00000000, 0x00000000}},  //   _hopp_, úrai,   ,
  { {0x3a3a00f8, 0x3ebf041d, 0x937a05d4, 0x00000000}},  //   _kopp_, jput_, حصار_,
  { {0x26c00198, 0x248604a3, 0x63a905cb, 0x00000000}},  //   mpio_, slom_, _egen,
  { {0x2bed0061, 0x40340242, 0x6f0214a6, 0x00000000}},  //   _झालं_, дейс, _spoc,
  { {0x6d410190, 0x3a3a00f8, 0xa0a300e2, 0x00000000}},  //   dyla, _lopp_, најд,
  { {0x7bcd121e, 0x44d838f5, 0x00000000, 0x00000000}},  //   _reau, lč_,   ,
  { {0x78a60142, 0x9325007a, 0x00000000, 0x00000000}},  //   _likv, _ترفن,   ,
  { {0xc04f01fb, 0x44d80173, 0x7d030093, 0x00000000}},  //   _зі_, nč_, _cpns,
  { {0xf04402fd, 0x78a601ee, 0x3a3a0045, 0x00000000}},  //   _تعطی, _nikv, _aopp_,
  { {0xa3ea0164, 0x9c7d0ebe, 0x7e61002d, 0x00000000}},  //   _माई_, lučk, bilp,
  { {0x8f9b009b, 0xadbc007e, 0x00000000, 0x00000000}},  //   _הידי, _такi,   ,
  { {0x66150059, 0x44d838f6, 0x6d4138f7, 0x00000000}},  //   _razk, jč_, cyla,
  { {0xf1bf0011, 0xb9050309, 0xe8e00011, 0x00000000}},  //   _đám_, _नि_, _giọt_,
  { {0x2bc30164, 0xb8f4007d, 0x66150032, 0x00000000}},  // [ca70] _व्या, _सौ_, _pazk,
  { {0x929d0036, 0x768b014a, 0xe2a30082, 0x00000000}},  //   _opła, rüyo, _chữ_,
  { {0x58d40057, 0x9c7d08fb, 0x6f1b0107, 0x00000000}},  //   _поэт, jučk, zvuc,
  { {0x9f9d02d5, 0x27ed0190, 0x997500b4, 0x00000000}},  //   nção_, _øen_, _męża_,
  { {0x9f9d0181, 0xddc801ed, 0x44f50374, 0x00000000}},  //   ição_, dodž, så_,
  { {0xc244007e, 0x386d016e, 0x00000000, 0x00000000}},  //   ннік, čeru_,   ,
  { {0x25fd0204, 0x62810059, 0x7e61245c, 0x00000000}},  //   र्णी_, _vklo, vilp,
  { {0x63a90030, 0x3ebf00ab, 0xf9940049, 0x00000000}},  //   _ugen, tput_, ערק_,
  { {0x25fd0164, 0x59bf01f5, 0x7e610089, 0x00000000}},  //   र्थी_, ्रार, tilp,
  { {0x62810182, 0x9c7d145e, 0x6d410133, 0x00000000}},  //   _uklo, bučk, tyla,
  { {0xac0a1662, 0x3ebf013f, 0x00000000, 0x00000000}},  //   онна_, sput_,   ,
  { {0x25fd0164, 0x6d41112b, 0x6483006c, 0x00000000}},  //   र्ती_, ryla, mõis,
  { {0xa2c10061, 0x6d410075, 0xe9f90082, 0x00000000}},  //   रीच्, syla, _quế_,
  { {0x9f9d02d5, 0x00000000, 0x00000000, 0x00000000}},  //   ação_,   ,   ,
  { {0xfaa31deb, 0xab5b1a6f, 0x00000000, 0x00000000}},  //   таро, lbül,   ,
  { {0x9f9d0181, 0x3ea71205, 0x00000000, 0x00000000}},  //   cção_, _hint_,   ,
  { {0x3a3a38f8, 0xd7ef0025, 0x186700ed, 0x00000000}},  // [ca80] _topp_, شكل_, фати_,
  { {0x26c0007f, 0xa5f7012b, 0xb9c6006d, 0x00000000}},  //   rpio_, међу_, _تقدي,
  { {0x3ea70e69, 0x78a604eb, 0x291c0010, 0x00000000}},  //   _mint_, _tikv, _éva_,
  { {0x26c00207, 0x2d870007, 0x00000000, 0x00000000}},  //   ppio_, _myne_,   ,
  { {0x2d8701d6, 0xd12f0014, 0x17c70088, 0x00000000}},  //   _lyne_, یمه_, _ігри_,
  { {0x2d8b0046, 0x9343005e, 0x8b5701ce, 0x00000000}},  //   ęcej_, ънче, וינס_,
  { {0xd5ad026c, 0xa6b00044, 0x20d30379, 0x00000000}},  //   _اہم_, _ছবিট, نتيج,
  { {0x8f4604ef, 0x3ea70c78, 0xddc10006, 0x00000000}},  //   дход, _aint_, bilū,
  { {0x3ea71a07, 0xdefa007e, 0x69de0059, 0x00000000}},  //   _bint_, цый_, _odpe,
  { {0x9c7d1322, 0x3eb90b33, 0x6483006c, 0x00000000}},  //   muči, ísta_, sõit,
  { {0x9c7d0363, 0x3ea7121e, 0x00000000, 0x00000000}},  //   luči, _dint_,   ,
  { {0x628a0061, 0x69de0022, 0x2d8738f9, 0x00000000}},  //   llfo, _adpe, _dyne_,
  { {0xccf80224, 0x3ea71a95, 0x9c7d0006, 0x00000000}},  //   stě_, _fint_, nuči,
  { {0x2d8701c3, 0x00000000, 0x00000000, 0x00000000}},  //   _fyne_,   ,   ,
  { {0x9f9d0181, 0x00000000, 0x00000000, 0x00000000}},  //   pção_,   ,   ,
  { {0x9c7d366d, 0xdb250035, 0x764e005b, 0x00000000}},  //   kuči, ăpân, _alby,
  { {0x81e60055, 0x9c7d0c1e, 0xa03b0049, 0x00000000}},  // [ca90] য্য_, juči, קעמפ,
  { {0x9c7d0391, 0x2ca90048, 0xa56728b7, 0x00000000}},  //   duči, _hiad_, ودان,
  { {0xdcf8001e, 0x67d503f3, 0x69d50181, 0x00000000}},  //   _izvē, _пону, maze,
  { {0x442938fa, 0x6483006c, 0x33750888, 0x00000000}},  //   ña_, võis, нгер,
  { {0x38b503bd, 0xba740014, 0x9c7d0391, 0x00000000}},  //   _hår_, _سایت, guči,
  { {0x6113006b, 0x2ca90022, 0x69d50095, 0x00000000}},  //   _hələ, _liad_, naze,
  { {0xd1310076, 0x2fcf0087, 0x7d1c000c, 0x00000000}},  //   امع_, _pegg_, ærsl,
  { {0x3ea718a6, 0x9c7d0006, 0x38b50039, 0x00000000}},  //   _sint_, buči, _mår_,
  { {0x69d5061b, 0x2d871810, 0x6113006b, 0x00000000}},  //   kaze, _syne_, _mələ,
  { {0x7bdf1195, 0x69d500ca, 0x69c738fb, 0x00000000}},  //   _adqu, jaze, jbje,
  { {0x38b52ad9, 0x63a4010a, 0x3ea70129, 0x00000000}},  //   _når_, žint, _vint_,
  { {0x3ea700bb, 0x6113006b, 0x2ca900e5, 0x00000000}},  //   _wint_, _nələ, _ciad_,
  { {0x63bb0020, 0x69d52d5b, 0xe7e3007d, 0x00000000}},  //   _mfun, faze, गणना_,
  { {0x69d538fc, 0x2d872595, 0x200d002d, 0x00000000}},  //   gaze, _tyne_, leei_,
  { {0x6113006b, 0x9c830059, 0x00000000, 0x00000000}},  //   _bələ, ščaj,   ,
  { {0xf7720025, 0x25fd013d, 0x1602006e, 0x00000000}},  //   هاء_, र्सी_, र्नर_,
  { {0xc05200a3, 0x628a0146, 0x69da21eb, 0x00000000}},  // [caa0] אזן_, ylfo, ótes,
  { {0x63bb337e, 0x38b50cb2, 0xe61702be, 0x00000000}},  //   _afun, _får_, нду_,
  { {0x38b50cb2, 0x044638fd, 0x6113006b, 0x00000000}},  //   _går_, нежн, _fələ,
  { {0x6113005f, 0x29370049, 0x00000000, 0x00000000}},  //   _gələ, _נאכן_,   ,
  { {0xbb3b007b, 0x200d002d, 0x338302dc, 0x00000000}},  //   ּעצי, deei_, лушв,
  { {0x63bb01c3, 0xb4250bb6, 0x00000000, 0x00000000}},  //   _efun, _یعقو,   ,
  { {0xa507132e, 0x00000000, 0x00000000, 0x00000000}},  //   _пера_,   ,   ,
  { {0x69c7037e, 0xdfd00025, 0x9c7d007f, 0x00000000}},  //   zbje, جية_, puči,
  { {0x64ac011f, 0x25fd0201, 0x2ca9205b, 0x00000000}},  //   _eğit, र्वी_, _riad_,
  { {0x2ca9002a, 0x63a40059, 0x3f8a0089, 0x00000000}},  //   _siad_, žins, ābu_,
  { {0x82770049, 0x4d980088, 0x10f800a1, 0x00000000}},  //   _טעמע_, ькою_, _زباں_,
  { {0xf1bf0082, 0x38b500ea, 0x00000000, 0x00000000}},  //   _đái_, _rår_,   ,
  { {0xdb1d0010, 0x38b50b16, 0x3d280241, 0x00000000}},  //   vasó, _sår_, ستگی_,
  { {0x63ad0211, 0x79a700e2, 0x8fa3003b, 0x00000000}},  //   ñanz, ербе, _саче,
  { {0x67d50500, 0x2db7009b, 0xdb1d0051, 0x00000000}},  //   кову, _אלון_, tasó,
  { {0x38b5143e, 0x6113006b, 0x69d500b9, 0x00000000}},  //   _vår_, _qələ, saze,
  { {0xdb1d0051, 0x69d50181, 0x7c2d0eac, 0x00000000}},  // [cab0] rasó, paze, _inar,
  { {0xb714007c, 0x2b530276, 0x00000000, 0x00000000}},  //   ыдущ, ıncı_,   ,
  { {0x6113005f, 0x7c2d0039, 0x7afd0da6, 0x00000000}},  //   _tələ, _knar, ltst,
  { {0x7afd257d, 0x7af200b9, 0x9fb500b9, 0x00000000}},  //   otst, šetř, třík_,
  { {0x147401d8, 0x7c2d38fe, 0x7c3f0066, 0x00000000}},  //   دالج, _mnar, _moqr,
  { {0xdd8604e8, 0x98be0006, 0x68e3043e, 0x00000000}},  //   _نو_, štą_, _ånds,
  { {0x7c2d37f7, 0x9c7d0466, 0x7afd095d, 0x00000000}},  //   _onar, luču, htst,
  { {0x63bb0020, 0x7afd02e1, 0x00000000, 0x00000000}},  //   _ufun, ktst,   ,
  { {0xe803001c, 0x442d0142, 0xc6140044, 0x00000000}},  //   ऱ्या_, _ine_, সারা_,
  { {0x443f06b2, 0x3384007e, 0x7afd27b7, 0x00000000}},  //   _hou_, _сусв, dtst,
  { {0x2bc3024c, 0x443f0263, 0x7afd38ff, 0x00000000}},  //   _व्हा, _kou_, etst,
  { {0x443f3900, 0x442d3901, 0x7afd04fb, 0x00000000}},  //   _jou_, _jne_, ftst,
  { {0x7afd001c, 0x443f3902, 0x442d06b8, 0x00000000}},  //   gtst, _mou_, _mne_,
  { {0x443f01aa, 0x6283011c, 0x7c2d04de, 0x00000000}},  //   _lou_, nono, _enar,
  { {0x442d0038, 0x7afd00b5, 0x7c3f0066, 0x00000000}},  //   _one_, atst, _foqr,
  { {0x443f0607, 0x442d0020, 0x63ad0f3a, 0x00000000}},  //   _nou_, _nne_, žanj,
  { {0x98a30001, 0x62830cce, 0xa68601fc, 0x00000000}},  // [cac0] рите, kono, влад,
  { {0x442d0263, 0x62830aa9, 0x443f1339, 0x00000000}},  //   _ane_, jono, _aou_,
  { {0x443f0007, 0x64a60245, 0x25ba0089, 0x00000000}},  //   _bou_, важа, rcpl_,
  { {0xb6090089, 0x3d19013d, 0x443f009d, 0x00000000}},  //   _atšķ, _बनने_, _cou_,
  { {0x62830885, 0x442d3903, 0xd36f0054, 0x00000000}},  //   fono, _dne_, يهم_,
  { {0x62830016, 0xfe6705f3, 0xcb1300a0, 0x00000000}},  //   gono, _ضد_, ילד_,
  { {0x443f1b43, 0xd1300025, 0x442d0085, 0x00000000}},  //   _fou_, صمة_, _fne_,
  { {0x44fc3904, 0x661c00b0, 0x443f3905, 0x00000000}},  //   mí_, _hark, _gou_,
  { {0x44fc004f, 0xd00700e1, 0x661c00b0, 0x00000000}},  //   lí_, тење_, _kark,
  { {0x443f02ae, 0x62830e1d, 0x644000d6, 0x00000000}},  //   _zou_, cono, _homi,
  { {0x443f0a8a, 0x64403906, 0x44fc004f, 0x00000000}},  //   _you_, _komi, ní_,
  { {0x7afd0056, 0x98aa0006, 0x6440007f, 0x00000000}},  //   ttst, mybė_, _jomi,
  { {0x7b6400ed, 0x44fc0142, 0x98aa007f, 0x00000000}},  //   атре, hí_, lybė_,
  { {0x6440037e, 0x7aef0038, 0x7afd010f, 0x00000000}},  //   _lomi, ruct, rtst,
  { {0x44fc01c8, 0x7afd05b4, 0x2b4d3907, 0x00000000}},  //   jí_, stst, šec_,
  { {0x44fc0387, 0x7afd010f, 0x6ca4007e, 0x00000000}},  //   dí_, ptst, _крыж,
  { {0x661c2b1c, 0x443f0007, 0x63ad1332, 0x00000000}},  // [cad0] _bark, _rou_, žank,
  { {0x443f0607, 0x9c7d0224, 0x442d0179, 0x00000000}},  //   _sou_, ruču, _sne_,
  { {0x443f1631, 0xd9d90044, 0x62830253, 0x00000000}},  //   _pou_, _তাপম, vono,
  { {0x62832b98, 0x6d5a0032, 0x661c0288, 0x00000000}},  //   wono, izta, _eark,
  { {0x6283117a, 0x661c011f, 0x443f02d5, 0x00000000}},  //   tono, _fark, _vou_,
  { {0x443f3900, 0x661c01c5, 0x44fc0161, 0x00000000}},  //   _wou_, _gark, bí_,
  { {0xfaff048a, 0x443f0607, 0x44fc388c, 0x00000000}},  //   htë_, _tou_, cí_,
  { {0x442d0a8d, 0xef190920, 0x6440016c, 0x00000000}},  //   _une_, еми_, _gomi,
  { {0xfaff008d, 0x62830036, 0x6b8d3908, 0x00000000}},  //   jtë_, pono, _nyag,
  { {0x6d48005b, 0x41b50025, 0x00000000, 0x00000000}},  //   fyda, _إمار,   ,
  { {0x64403909, 0x38690288, 0x6b8d390a, 0x00000000}},  //   _yomi, kiar_, _ayag,
  { {0xfaff008d, 0x6b8d0061, 0x80d00044, 0x00000000}},  //   ftë_, _byag, সংখ্,
  { {0x3869390b, 0x44fc01ca, 0x6d5a002d, 0x00000000}},  //   diar_, zí_, azta,
  { {0x64b7012d, 0x6b8d0173, 0x01e50044, 0x00000000}},  //   _aćim, _dyag, প্রদ,
  { {0x7c2f0051, 0x610a006b, 0x2d94005e, 0x00000000}},  //   áirí, _gəld, _кръс,
  { {0x44fc390c, 0x38692609, 0x201f1569, 0x00000000}},  //   ví_, giar_, ndui_,
  { {0x6440001a, 0x2905011f, 0x5baa0088, 0x00000000}},  // [cae0] _romi, çlar_, _яким_,
  { {0x44fc004f, 0x6440125c, 0x661c0065, 0x00000000}},  //   tí_, _somi, _qark,
  { {0x64400213, 0x44fc0181, 0xd94602ea, 0x00000000}},  //   _pomi, uí_, _сени,
  { {0x44fc390d, 0x629a0065, 0x291a390e, 0x00000000}},  //   rí_, _shto, _ispa_,
  { {0x661c021e, 0x44fc0b88, 0x291a05ae, 0x00000000}},  //   _tark, sí_, _hspa_,
  { {0x5b7b0049, 0x44fc01ca, 0x98aa0006, 0x00000000}},  //   ערסא, pí_, tybė_,
  { {0x6440016e, 0x05270256, 0x291a390f, 0x00000000}},  //   _tomi, _йорк_, _jspa_,
  { {0x64400207, 0x6d482d4e, 0x00000000, 0x00000000}},  //   _uomi, vyda,   ,
  { {0x6d480016, 0x61f60025, 0x629a0009, 0x00000000}},  //   wyda, _مساء, _thto,
  { {0x715a029b, 0x3869002d, 0x6d4833cd, 0x00000000}},  //   _прес_, ziar_, tyda,
  { {0xdd94007e, 0x127b0049, 0x5c750478, 0x00000000}},  //   раны, _טאמע, илот,
  { {0x6d4807be, 0x09bf01f5, 0xc0ff0011, 0x00000000}},  //   ryda, ्र्य, _lướt_,
  { {0x38691195, 0x6d5a182e, 0x321e0253, 0x00000000}},  //   viar_, szta, _katy_,
  { {0xfaff008d, 0xc9870216, 0x24570095, 0x00000000}},  //   rtë_, губи, _içme_,
  { {0xfaff0065, 0x6724001e, 0xf8070081, 0x00000000}},  //   stë_, evij, лчан,
  { {0x6b8d00e0, 0x610a006b, 0xfaff0023, 0x00000000}},  //   _tyag, _kəlb, ptë_,
  { {0x38690056, 0xfaff0065, 0x291a206d, 0x00000000}},  // [caf0] riar_, qtë_, _espa_,
  { {0xd01d0055, 0x00000000, 0x00000000, 0x00000000}},  //   থায়_,   ,   ,
  { {0x386900d6, 0x291a012d, 0x2cf20164, 0x00000000}},  //   piar_, _gspa_, _अमोल_,
  { {0x69d701a2, 0x3eae0133, 0x59bf0204, 0x00000000}},  //   _hexe, _lift_, ्रकर,
  { {0xb7da009b, 0x201d0085, 0x26c7012d, 0x00000000}},  //   _בקרי, _rawi_, ćnos_,
  { {0xd25b007e, 0x201d1463, 0xe2990098, 0x00000000}},  //   эце_, _sawi_, њак_,
  { {0x2486018d, 0x20550517, 0x69d700c4, 0x00000000}},  //   boom_, итир, _mexe,
  { {0xdb1d006c, 0x69d7009d, 0x4ab50316, 0x00000000}},  //   lasõ, _lexe, ंदाव,
  { {0x201f007f, 0x00000000, 0x00000000, 0x00000000}},  //   rdui_,   ,   ,
  { {0x3eae16b4, 0xdb1d010e, 0xc0ff0082, 0x00000000}},  //   _cift_, nasõ, _xướt_,
  { {0xa11510fc, 0x67240e3b, 0x201d0020, 0x00000000}},  //   _خوات, zvij, _tawi_,
  { {0x8b26007e, 0x20d30035, 0x645a007f, 0x00000000}},  //   адме, mţi_, _įtik,
  { {0x30840054, 0x20d3001a, 0xe8e00011, 0x00000000}},  //   _النف, lţi_, _kiệt_,
  { {0x24860030, 0x3eae00ab, 0x291a01f3, 0x00000000}},  //   zoom_, _gift_, _pspa_,
  { {0x20d3001a, 0x290c2560, 0x6846005e, 0x00000000}},  //   nţi_, ïda_, анва,
  { {0x67240089, 0xe8e00011, 0x7ae90091, 0x00000000}},  //   tvij, _liệt_, šeta,
  { {0x69d70927, 0x2486016c, 0x09e60072, 0x00000000}},  // [cb00] _fexe, voom_, _копн,
  { {0x67240089, 0xcb9b0097, 0xdb9b009b, 0x00000000}},  //   rvij, _בספט, _בספר,
  { {0x69dc26c4, 0x2eed0009, 0x6724016e, 0x00000000}},  //   mare, href_, svij,
  { {0x69dc02f5, 0x03260264, 0xe482019a, 0x00000000}},  //   lare, иден, _öpüş,
  { {0xe8e0001d, 0x2486066a, 0xd387007e, 0x00000000}},  //   _biệt_, room_, айце_,
  { {0x69dc3910, 0x2eed018e, 0x64ac019a, 0x00000000}},  //   nare, dref_, _işim,
  { {0xe8e00011, 0xdb1f1396, 0x69dc3911, 0x00000000}},  //   _diệt_, _seqü, iare,
  { {0x64590b70, 0xc034012b, 0x38bc1d6c, 0x00000000}},  //   chwi, сниј, _mír_,
  { {0x69dc002d, 0x610a006b, 0x25fd013d, 0x00000000}},  //   kare, _qəlb, र्की_,
  { {0x69dc001a, 0x38bc3912, 0x62720036, 0x00000000}},  //   jare, _oír_, dłog,
  { {0x45b70049, 0x69d700d2, 0x20d30035, 0x00000000}},  //   יפיל_, _rexe, cţi_,
  { {0x98be0224, 0x69d722d7, 0x4cb80044, 0x00000000}},  //   ště_, _sexe, _আবদু,
  { {0x69dc0039, 0x3eae0066, 0x00000000, 0x00000000}},  //   fare, _tift_,   ,
  { {0xdb1d0010, 0x5ef30061, 0x3b000066, 0x00000000}},  //   ncsé, ंढर्_, _dqiq_,
  { {0x7e7d008e, 0xa3e60061, 0x6e3c0039, 0x00000000}},  //   éspe, पणा_, örbu,
  { {0x08540088, 0x8bd5003b, 0x00000000, 0x00000000}},  //   овсю, _ужиц,   ,
  { {0x7bdd04cb, 0x57a7005e, 0x69d700bb, 0x00000000}},  // [cb10] masu, ршва, _texe,
  { {0x69dc149f, 0x7bdd010e, 0x78a4010e, 0x00000000}},  //   care, lasu, amiv,
  { {0x74a706e3, 0x64590ca4, 0xd5b80088, 0x00000000}},  //   ајде, thwi, рсу_,
  { {0x7bdd0503, 0x68f5005a, 0xd0060025, 0x00000000}},  //   nasu, muzd, _عل_,
  { {0x2458007e, 0x00000000, 0x00000000, 0x00000000}},  //   шаць_,   ,   ,
  { {0xf207004c, 0x7bdd0f7c, 0xd2640088, 0x00000000}},  //   рядо, hasu, окій,
  { {0xe8e000ad, 0x2a58009b, 0x7bdd14f7, 0x00000000}},  //   _việt_, שבון_, kasu,
  { {0x2eed3913, 0x69dc04f4, 0x20d3000d, 0x00000000}},  //   tref_, zare, rţi_,
  { {0x69dc011f, 0x7bdd002d, 0xe8e00082, 0x00000000}},  //   yare, dasu, _tiệt_,
  { {0xee39012b, 0x20d30035, 0x00000000, 0x00000000}},  //   уно_, pţi_,   ,
  { {0x69dc0378, 0x4c860d99, 0x29030af9, 0x00000000}},  //   vare, йлов, jtja_,
  { {0x69dc0270, 0x7bdd0058, 0xed560088, 0x00000000}},  //   ware, gasu, сою_,
  { {0x69dc04f4, 0x224500ca, 0x249f0022, 0x00000000}},  //   tare, _kolk_, _mhum_,
  { {0x610a006b, 0x69dc1ea8, 0x00000000, 0x00000000}},  //   _həla, uare,   ,
  { {0x69dc28f8, 0x7d1c344a, 0x7bdd0145, 0x00000000}},  //   rare, ærst, basu,
  { {0x69dc15cd, 0x7bdd0035, 0x8d740014, 0x00000000}},  //   sare, casu, _باها,
  { {0xe737030d, 0xfc57009b, 0xf5b60025, 0x00000000}},  // [cb20] бет_, _לבקש_, مصاد,
  { {0xcf92007b, 0x38bc0051, 0x69dc3914, 0x00000000}},  //   לטן_, _tír_, qare,
  { {0xf1bf001d, 0xab5b0477, 0x186a073b, 0x00000000}},  //   _đáp_, bbüs, _бани_,
  { {0x7ae40056, 0x98160426, 0x249f0048, 0x00000000}},  //   _kvit, _ابدا, _chum_,
  { {0xf7720025, 0x31cf0044, 0x00000000, 0x00000000}},  //   _راح_, _রাজশ,   ,
  { {0x9416005f, 0x46a30088, 0x38cb0014, 0x00000000}},  //   _əgər_, _наяв, _جایی_,
  { {0x29360049, 0x9c830e54, 0xab5b01a2, 0x00000000}},  //   מאַן_, ščij, nbür,
  { {0x7ae400ca, 0xc5630783, 0xd1380036, 0x00000000}},  //   _ovit, _экск, _rząd_,
  { {0x22453915, 0x7ae400ea, 0x934300e2, 0x00000000}},  //   _folk_, _nvit, _енте,
  { {0x2903000c, 0x7bdd1b87, 0x00000000, 0x00000000}},  //   ytja_, wasu,   ,
  { {0x7bdd022b, 0x25fd062e, 0x610a006b, 0x00000000}},  //   tasu, र्टी_, _fəla,
  { {0x628a00b5, 0x2ca021a4, 0x00000000, 0x00000000}},  //   lofo, _chid_,   ,
  { {0x3f67007c, 0xab872b20, 0x7ae401ed, 0x00000000}},  //   _лицо_, сунк, _cvit,
  { {0x29033916, 0x09d90044, 0x7bdd03b6, 0x00000000}},  //   ttja_, _তাহা, sasu,
  { {0x7bdd011c, 0x1958007e, 0x00000000, 0x00000000}},  //   pasu, бары_,   ,
  { {0x29033917, 0x2ca03918, 0x4cf700b3, 0x00000000}},  //   rtja_, _ghid_, _הזהב_,
  { {0x2903002b, 0x95d90517, 0x61e837d6, 0x00000000}},  // [cb30] stja_, идат_, _oddl,
  { {0x249f008d, 0xceb300a0, 0x95d8007c, 0x00000000}},  //   _shum_, פיע_, йдут_,
  { {0x7d0d0521, 0x628a0093, 0x69c50066, 0x00000000}},  //   _ćask, dofo, _ifhe,
  { {0x3cfb007b, 0x25fd03d7, 0xd3710380, 0x00000000}},  //   רלאנ, र्जी_, وها_,
  { {0x22450e9e, 0x60c80050, 0x92391ab7, 0x00000000}},  //   _polk_, _atdm, ичку_,
  { {0x610a006b, 0xa4d5007e, 0xa22901ab, 0x00000000}},  //   _səla, _могі, ржка_,
  { {0x22450343, 0x00000000, 0x00000000, 0x00000000}},  //   _volk_,   ,   ,
  { {0xaec50088, 0x2245040f, 0x5058007e, 0x00000000}},  //   обил, _wolk_, йшыя_,
  { {0x26060204, 0x628a0bc7, 0x224500ca, 0x00000000}},  //   स्वी_, bofo, _tolk_,
  { {0x13de0044, 0x63ad0091, 0xfce502dc, 0x00000000}},  //   _ডায়, žans, оооо,
  { {0xc5f2019b, 0x1d090331, 0xdca6012c, 0x00000000}},  //   ודי_, шени_, жани,
  { {0x69c51dab, 0xb4fa00b3, 0x6e3c074d, 0x00000000}},  //   _afhe, ספרי, örbr,
  { {0x12d70044, 0xcf2704b1, 0x00000000, 0x00000000}},  //   _সমুদ, _دراي,   ,
  { {0x769000b0, 0x2fdf07a8, 0xfc3f004a, 0x00000000}},  //   näyt, laug_, rmía_,
  { {0x81ab0044, 0xd826007c, 0x2ca00085, 0x00000000}},  //   কুর_, одви, _thid_,
  { {0x6e230142, 0xab5b3919, 0x2fdf00e0, 0x00000000}},  //   _hanb, rbür, naug_,
  { {0x6e232cab, 0x09d90044, 0x769000b0, 0x00000000}},  // [cb40] _kanb, _তারা, käyt,
  { {0x7c24391a, 0x6e2301aa, 0x2fdf00ea, 0x00000000}},  //   _hair, _janb, haug_,
  { {0x7c24143d, 0x6e230173, 0x628a087a, 0x00000000}},  //   _kair, _manb, vofo,
  { {0x7c243890, 0x6e23391b, 0x7c2603a9, 0x00000000}},  //   _jair, _lanb, ndkr,
  { {0x628a2c69, 0x7c242d2e, 0x2fdf391c, 0x00000000}},  //   tofo, _mair, daug_,
  { {0x27e00149, 0xa9050014, 0x7aeb0030, 0x00000000}},  //   lain_, _ببین, _ægte,
  { {0x628a0142, 0x61e80026, 0x12d70044, 0x00000000}},  //   rofo, _vddl, _সমৃদ,
  { {0x6e23015c, 0x27e00016, 0x7c240020, 0x00000000}},  //   _aanb, nain_, _nair,
  { {0x44241824, 0x6e230173, 0x81ab0055, 0x00000000}},  //   _iam_, _banb, কুল_,
  { {0x44240018, 0x442602d5, 0x27e00051, 0x00000000}},  //   _ham_, ldo_, hain_,
  { {0x4424008d, 0x7c2402d5, 0x27e0006a, 0x00000000}},  //   _kam_, _bair, kain_,
  { {0x442620e4, 0x442407d7, 0x7c242a9b, 0x00000000}},  //   ndo_, _jam_, _cair,
  { {0x44241191, 0x7c24005d, 0x44260211, 0x00000000}},  //   _mam_, _dair, ido_,
  { {0x4424001d, 0x6442021e, 0xfe6f0025, 0x00000000}},  //   _lam_, hjoi, _لدى_,
  { {0x44260763, 0x7c24032c, 0x27e0005b, 0x00000000}},  //   kdo_, _fair, fain_,
  { {0x442400ad, 0x7c24391d, 0x27e00016, 0x00000000}},  //   _nam_, _gair, gain_,
  { {0x4426018e, 0xf7700025, 0xb902006e, 0x00000000}},  // [cb50] ddo_, ناك_, _नौ_,
  { {0x44260207, 0x44240145, 0xe6130025, 0x00000000}},  //   edo_, _aam_, بشر_,
  { {0x9c830e54, 0x00000000, 0x00000000, 0x00000000}},  //   ščuj,   ,   ,
  { {0x27e000f4, 0x4426007f, 0x660e0032, 0x00000000}},  //   cain_, gdo_, _ebbk,
  { {0x083a0049, 0x769000b0, 0x883a00b3, 0x00000000}},  //   _הערל, täyt, _התרו,
  { {0x44260977, 0xc244007e, 0x76ba009b, 0x00000000}},  //   ado_, мнік, _למשפ,
  { {0x44240016, 0x44260196, 0x6e231bcb, 0x00000000}},  //   _fam_, bdo_, _ranb,
  { {0x7cc1001e, 0x6e230263, 0x44240016, 0x00000000}},  //   _bērn, _sanb, _gam_,
  { {0x610a006b, 0xdbd9000c, 0xd00e00a1, 0x00000000}},  //   _həll, væði, ھلی_,
  { {0x44241338, 0x7c243544, 0x27e0002d, 0x00000000}},  //   _zam_, _sair, zain_,
  { {0x7c24062a, 0xdbd9000c, 0x645b0116, 0x00000000}},  //   _pair, tæði, _klui,
  { {0x160b007d, 0x6e23391e, 0x442412a2, 0x00000000}},  //   स्तर_, _wanb, _xam_,
  { {0x7c241a2f, 0x6449049b, 0xdbd9009f, 0x00000000}},  //   _vair, _moei, ræði,
  { {0x44260006, 0x27e03830, 0xd0190046, 0x00000000}},  //   zdo_, wain_, leń_,
  { {0x7c24002a, 0x27e0391f, 0xd946003b, 0x00000000}},  //   _tair, tain_, чеви,
  { {0x7c240051, 0xb3421a6f, 0x00000000, 0x00000000}},  //   _uair, şçil,   ,
  { {0x27e00675, 0x44240011, 0x4426089f, 0x00000000}},  // [cb60] rain_, _ram_, vdo_,
  { {0x177901fb, 0x27e00390, 0x44243920, 0x00000000}},  //   ість_, sain_, _sam_,
  { {0x44240016, 0x644900bb, 0x27e037ad, 0x00000000}},  //   _pam_, _boei, pain_,
  { {0x645b002a, 0x442600f4, 0x69de1237, 0x00000000}},  //   _clui, udo_, _hepe,
  { {0x44260851, 0x64420f3c, 0x44242a86, 0x00000000}},  //   rdo_, rjoi, _vam_,
  { {0xf788005f, 0x69de0065, 0x44240036, 0x00000000}},  //   _neçə_, _jepe, _wam_,
  { {0x69de1f0f, 0x644901c3, 0x00000000, 0x00000000}},  //   _mepe, _foei,   ,
  { {0xdb160047, 0x09b9001c, 0x64491f4b, 0x00000000}},  //   _egyé, _आल्य, _goei,
  { {0x09e20055, 0xa411005a, 0x41b602dc, 0x00000000}},  //   _বানা, lığı_, _есет,
  { {0x69de2e92, 0x7ae90091, 0x7e7a0190, 0x00000000}},  //   _nepe, šetk, untp,
  { {0x38600149, 0xfbe10044, 0xcfdb0044, 0x00000000}},  //   khir_, _ভাবত, _ধারন,
  { {0x6ab502f4, 0x00bb00b6, 0x09c50061, 0x00000000}},  //   ंद्र, _המאמ, वड्य,
  { {0x7ae6001c, 0x69de01b5, 0x7ac7213f, 0x00000000}},  //   gskt, _bepe, ясне,
  { {0x69de00f4, 0x1aef0044, 0xda7b04dd, 0x00000000}},  //   _cepe, _চঙদে_, сям_,
  { {0xdd93007e, 0x00000000, 0x00000000, 0x00000000}},  //   _пашы,   ,   ,
  { {0xa41101f6, 0x38600048, 0x00000000, 0x00000000}},  //   dığı_, ghir_,   ,
  { {0xf7730137, 0x06b700a6, 0x64490112, 0x00000000}},  // [cb70] رار_, سناک_, _roei,
  { {0x645b049b, 0x13d50183, 0x69de00bb, 0x00000000}},  //   _slui, दर्भ, _gepe,
  { {0x645b00f4, 0x38600033, 0x8c200044, 0x00000000}},  //   _plui, bhir_, ধারন_,
  { {0x38602587, 0x7bdf16b5, 0x69de1595, 0x00000000}},  //   chir_, _jequ, _zepe,
  { {0x7bdf00d4, 0x69de004a, 0x6ab70066, 0x00000000}},  //   _mequ, _yepe, _kixf,
  { {0x672d3921, 0x7bdf00f4, 0xc2930014, 0x00000000}},  //   mvaj, _lequ, ریاب,
  { {0x672d1ae2, 0x64490082, 0xf4970014, 0x00000000}},  //   lvaj, _toei, _فشرد,
  { {0x610a005f, 0x7bdf0288, 0x92f2014a, 0x00000000}},  //   _gəlm, _nequ, üğüm,
  { {0x2d980d85, 0x63bb00e7, 0xd9ed0164, 0x00000000}},  //   üren_, _igun, _जयंत_,
  { {0x6ab70066, 0x00000000, 0x00000000, 0x00000000}},  //   _nixf,   ,   ,
  { {0x61e3011f, 0x7bdf3922, 0x1602006e, 0x00000000}},  //   manl, _bequ, र्टर_,
  { {0x69de3923, 0x9ce7026c, 0x61e3005d, 0x00000000}},  //   _sepe, _ہوتے_, lanl,
  { {0x69de0127, 0xe8e00011, 0x09e20044, 0x00000000}},  //   _pepe, _thịt_, _বাবা,
  { {0x672d0059, 0x61e3014a, 0xeab200a1, 0x00000000}},  //   dvaj, nanl, ئٹس_,
  { {0x9423006b, 0x38603924, 0x69de0023, 0x00000000}},  //   şvət_, thir_, _vepe,
  { {0x6f090129, 0x63bb006a, 0x61e3006b, 0x00000000}},  //   otec, _ngun, hanl,
  { {0x6f0902d5, 0x69de0065, 0x61e314d7, 0x00000000}},  // [cb80] ntec, _tepe, kanl,
  { {0x63bb0169, 0x38600f3e, 0xa411014a, 0x00000000}},  //   _agun, shir_, tığı_,
  { {0x0446008b, 0x61e30fae, 0x3860068d, 0x00000000}},  //   межн, danl, phir_,
  { {0x6f09013e, 0x68fc010e, 0x1602013d, 0x00000000}},  //   ktec, murd, र्जर_,
  { {0x672d012d, 0x61e301e5, 0x68fc3925, 0x00000000}},  //   cvaj, fanl, lurd,
  { {0x63bb022b, 0x61e3014a, 0xf77300b3, 0x00000000}},  //   _egun, ganl, _יקר_,
  { {0x200d0026, 0x68fc0477, 0xe8e00082, 0x00000000}},  //   ffei_, nurd, _kiốt_,
  { {0xdfd00054, 0x2002006c, 0x00000000, 0x00000000}},  //   دية_, üki_,   ,
  { {0x7bdf0038, 0x41cf0309, 0xa20602e9, 0x00000000}},  //   _requ, _स्वस, _опад,
  { {0x3f98001e, 0x7bdf0e3e, 0x64ac0279, 0x00000000}},  //   āru_, _sequ, _eşit,
  { {0x7bdf1cca, 0xab5b0279, 0x6f0904c4, 0x00000000}},  //   _pequ, rcüm, atec,
  { {0x68fc018e, 0xfbad0044, 0x83fd0010, 0x00000000}},  //   durd, _ক্ষত, _előf,
  { {0x92bc0044, 0x6f0901c5, 0x3a3a00e0, 0x00000000}},  //   _আবু_, ctec, _bnpp_,
  { {0x8f9b009b, 0x00000000, 0x00000000, 0x00000000}},  //   _וידי,   ,   ,
  { {0x19940265, 0x7bdf008e, 0x69c70065, 0x00000000}},  //   варя, _tequ, rcje,
  { {0x61e3019a, 0x81ab0044, 0x00000000, 0x00000000}},  //   zanl, কুক_,   ,
  { {0x61e3047f, 0x610a006b, 0xe894007c, 0x00000000}},  // [cb90] yanl, _bəlk, тать,
  { {0x7afd3926, 0x68fc0032, 0x09d90044, 0x00000000}},  //   must, burd, _তাকা,
  { {0x3de30055, 0xb8f40055, 0x61e3006b, 0x00000000}},  //   _মামল, _হয়_, vanl,
  { {0x8c1c0049, 0x6f090036, 0x36d501ee, 0x00000000}},  //   ַווי, ytec, _помр,
  { {0x61e31bed, 0x09e20044, 0x6f0900d2, 0x00000000}},  //   tanl, _বাতা, xtec,
  { {0x78ad0006, 0x6f0900d9, 0x62720036, 0x00000000}},  //   lmav, vtec, słon,
  { {0x61e30279, 0x7afd0004, 0x8557026c, 0x00000000}},  //   ranl, hust, _تیار_,
  { {0x61e301f6, 0x63bb0089, 0x10a20f6f, 0x00000000}},  //   sanl, _ugun, лищн,
  { {0xef163927, 0xe8110061, 0xc6220044, 0x00000000}},  //   емы_, ड्या_, নারা_,
  { {0x6f090198, 0x61e3005f, 0x68fc0279, 0x00000000}},  //   rtec, qanl, yurd,
  { {0x6f0900b9, 0xc692009b, 0x61e10026, 0x00000000}},  //   stec, ראי_, _iell,
  { {0x61e100eb, 0x6459002b, 0x68fc01e3, 0x00000000}},  //   _hell, nkwi, vurd,
  { {0x61e10004, 0x200a006b, 0x60c13928, 0x00000000}},  //   _kell, əbi_, _hulm,
  { {0x61e10047, 0x60c100b0, 0x3e6001aa, 0x00000000}},  //   _jell, _kulm, _pòte_,
  { {0xdb1d0010, 0x60c11a17, 0x7afd007f, 0x00000000}},  //   rcsá, _julm, aust,
  { {0x7afd006c, 0xfbda0055, 0x61e13929, 0x00000000}},  //   bust, _থাকত, _lell,
  { {0xa5da0025, 0xdb1d0010, 0x00000000, 0x00000000}},  // [cba0] كبار_, pcsá,   ,
  { {0x61e10198, 0xa926008b, 0x78ad0197, 0x00000000}},  //   _nell, _здол, amav,
  { {0x89db00b3, 0xc7af009e, 0xc6220044, 0x00000000}},  //   _מחיי, لّہ_, নালা_,
  { {0x5ed50044, 0x00000000, 0x00000000, 0x00000000}},  //   _দিনে,   ,   ,
  { {0xe29a00ed, 0x61e1051b, 0xd25901c5, 0x00000000}},  //   пад_, _bell, _suņa_,
  { {0x61e10472, 0x60c1014a, 0x6726182f, 0x00000000}},  //   _cell, _bulm, _iskj,
  { {0x61e105d3, 0x26c2000b, 0x60c1001a, 0x00000000}},  //   _dell, _huko_, _culm,
  { {0x26c20a65, 0x64590b77, 0x60c1392a, 0x00000000}},  //   _kuko_, ckwi, _dulm,
  { {0x61e1392b, 0x764e23d9, 0x610a013f, 0x00000000}},  //   _fell, _koby, _məli,
  { {0x61e1018e, 0x3eb80039, 0x7afd0368, 0x00000000}},  //   _gell, ört_, vust,
  { {0x2d9805b7, 0x7afd01b5, 0x60c10c2c, 0x00000000}},  //   ære_, wust, _gulm,
  { {0x7afd08b2, 0x61e1010f, 0x7863010e, 0x00000000}},  //   tust, _zell, _kõve,
  { {0x26c20061, 0x61e100ab, 0x291e014a, 0x00000000}},  //   _nuko_, _yell, çtan_,
  { {0x7afd021e, 0x61e101d5, 0x764e011c, 0x00000000}},  //   rust, _xell, _noby,
  { {0x7afd0004, 0x19950401, 0x26c20058, 0x00000000}},  //   sust, тавя, _auko_,
  { {0x26c200e0, 0xbca50380, 0x610a006b, 0x00000000}},  //   _buko_, _جمعي, _cəli,
  { {0x78ad0993, 0x610a006b, 0x7afd006b, 0x00000000}},  // [cbb0] rmav, _dəli, qust,
  { {0xb8f70044, 0x4b7c009b, 0x26cf0089, 0x00000000}},  //   _সি_, _מאחו, īgo_,
  { {0x61e1392c, 0x7aed392d, 0x2ca900d9, 0x00000000}},  //   _rell, _hvat, _khad_,
  { {0x610a005f, 0x43751123, 0x61e10114, 0x00000000}},  //   _gəli, култ, _sell,
  { {0x60c10065, 0x645900b5, 0x44290027, 0x00000000}},  //   _sulm, rkwi, ľa_,
  { {0x4429264e, 0x60c1006c, 0x61e10065, 0x00000000}},  //   ža_, _pulm, _qell,
  { {0x26c201ee, 0x63730010, 0x00000000, 0x00000000}},  //   _zuko_, _bűnö,   ,
  { {0x26c20020, 0x7aed00b0, 0x9f5f392e, 0x00000000}},  //   _yuko_, _ovat, lgué_,
  { {0x61e1218f, 0x09e20055, 0xef1901fb, 0x00000000}},  //   _tell, _বাসা, ємо_,
  { {0x9f5f0115, 0x2ca921e6, 0x00000000, 0x00000000}},  //   ngué_, _ahad_,   ,
  { {0x42360049, 0x7aed0114, 0x00000000, 0x00000000}},  //   _שנעל_, _avat,   ,
  { {0xed5601fb, 0x91fc0089, 0x2ca903ef, 0x00000000}},  //   тою_, _glāb, _chad_,
  { {0x6e2a0026, 0x7aed016e, 0x00000000, 0x00000000}},  //   _fafb, _cvat,   ,
  { {0x26c20093, 0x7aed2267, 0x610a006b, 0x00000000}},  //   _ruko_, _dvat, _səli,
  { {0xfbe10055, 0x764e02e7, 0x09b50044, 0x00000000}},  //   _ভারত, _roby, _জ্বা,
  { {0x2ca9002b, 0x764e0058, 0x00000000, 0x00000000}},  //   _ghad_, _soby,   ,
  { {0x764e067f, 0xd70a007e, 0x7aed0ecf, 0x00000000}},  // [cbc0] _poby, ьнае_, _gvat,
  { {0x787b021e, 0x7ae901d5, 0xd099006b, 0x00000000}},  //   tävä, ġett, rçən,
  { {0x610a006b, 0x7aed0091, 0x09f7009b, 0x00000000}},  //   _təli, _zvat, _במים_,
  { {0x26c20020, 0x97da0025, 0x00000000, 0x00000000}},  //   _tuko_, _تبدأ_,   ,
  { {0x27fd0036, 0x7783005e, 0x00000000, 0x00000000}},  //   ówne_, _вляз,   ,
  { {0x672400d9, 0x291a01a3, 0x98b8007f, 0x00000000}},  //   mwij, _kppa_, tyrė_,
  { {0x672400bb, 0x9f44004a, 0x00000000, 0x00000000}},  //   lwij, mamé_,   ,
  { {0xc95300b6, 0x628f0d7b, 0x83fd0010, 0x00000000}},  //   שמה_, _ícon, _előb,
  { {0xa491007a, 0xb226017a, 0x2ca9018e, 0x00000000}},  //   _اینت, _имал, _rhad_,
  { {0x291a0082, 0x00000000, 0x00000000, 0x00000000}},  //   _oppa_,   ,   ,
  { {0x7aed091d, 0x7d0a001c, 0x2ca90145, 0x00000000}},  //   _svat, _qqfs, _phad_,
  { {0x672400bb, 0x00000000, 0x00000000, 0x00000000}},  //   kwij,   ,   ,
  { {0x291a00d4, 0xfe6f00a2, 0x00000000, 0x00000000}},  //   _appa_, صدی_,   ,
  { {0xc3330104, 0x672400bb, 0x25fe0316, 0x00000000}},  //   בוש_, dwij, _लागी_,
  { {0x2ca922af, 0x00000000, 0x00000000, 0x00000000}},  //   _thad_,   ,   ,
  { {0x1d07012b, 0x9c7d0006, 0x291a000a, 0x00000000}},  //   _рећи_, ksči, _dppa_,
  { {0x672432fd, 0xec380049, 0x2d9c392f, 0x00000000}},  // [cbd0] gwij, _יאהר_, _hyve_,
  { {0x7c2f012d, 0x7cc10089, 0x07080379, 0x00000000}},  //   ldcr, _sēri, ئيلي_,
  { {0x7c2d2e34, 0x9f5f0249, 0x98b902dc, 0x00000000}},  //   _kaar, rgué_, _плот_,
  { {0x7c2d01b5, 0x00000000, 0x00000000, 0x00000000}},  //   _jaar,   ,   ,
  { {0x610a005f, 0x27e9021e, 0x81e70044, 0x00000000}},  //   _məlu, maan_, _ভাব_,
  { {0xdd860025, 0x27e9272e, 0x7c2d015b, 0x00000000}},  //   _هو_, laan_, _laar,
  { {0xc69200b6, 0xa5f8003b, 0x78bd0010, 0x00000000}},  //   _האם_, _јесу_, _kisv,
  { {0x27e9033b, 0x7c2d178a, 0x349516b6, 0x00000000}},  //   naan_, _naar, _сабр,
  { {0xdd2e00b9, 0x78bd130e, 0xe3b30318, 0x00000000}},  //   měře, _misv, _ضرر_,
  { {0x27e90390, 0x8352026c, 0x442d021e, 0x00000000}},  //   haan_, _دھما, _hae_,
  { {0x27e93930, 0x2f0b0030, 0x443f0066, 0x00000000}},  //   kaan_, søg_, _knu_,
  { {0x27e90127, 0x442d0082, 0x78bd00ca, 0x00000000}},  //   jaan_, _jae_, _nisv,
  { {0x442d0bc4, 0x7c2d0100, 0x443f3931, 0x00000000}},  //   _mae_, _daar, _mnu_,
  { {0x7c2f0061, 0x442d3932, 0x62833933, 0x00000000}},  //   adcr, _lae_, nnno,
  { {0x443f038c, 0xa96a01f9, 0xfe7000a2, 0x00000000}},  //   _onu_, хива_, _بدن_,
  { {0x27e91cd3, 0x7c2d0056, 0x442d1423, 0x00000000}},  //   gaan_, _gaar, _nae_,
  { {0x98a30264, 0x78bd0026, 0x7ae90142, 0x00000000}},  // [cbe0] сите, _disv, šetr,
  { {0x672402ae, 0x443f011c, 0x3a26007c, 0x00000000}},  //   rwij, _anu_, _смог,
  { {0x69dc3247, 0x442d0016, 0x27e90d56, 0x00000000}},  //   mbre, _bae_, baan_,
  { {0x69dc0030, 0x442d04bf, 0xe4d702fd, 0x00000000}},  //   lbre, _cae_, اونت_,
  { {0x442d0343, 0x68e30018, 0xcec80011, 0x00000000}},  //   _dae_, _ændr, _mộc_,
  { {0x69dc07eb, 0x115401e0, 0xcec80011, 0x00000000}},  //   nbre, иклю, _lộc_,
  { {0x6e210002, 0x442d005b, 0xc0e301fc, 0x00000000}},  //   delb, _fae_, бојк,
  { {0x6283018e, 0x7863006c, 0x2ef401ee, 0x00000000}},  //   anno, _kõva, азир,
  { {0xd46701f9, 0x64403934, 0xa857009b, 0x00000000}},  //   _сите_, _inmi, טיקה_,
  { {0x7c2d3935, 0x6e2119cf, 0x5c140044, 0x00000000}},  //   _saar, gelb, িযোগ_,
  { {0x7c2d017d, 0x27e9033b, 0xf8b40061, 0x00000000}},  //   _paar, yaan_, ंगाय,
  { {0x61ea000c, 0xdee6013b, 0x4c95013b, 0x00000000}},  //   lafl, _боди, римс,
  { {0x7c2d0dde, 0x27e900b0, 0x78bd0197, 0x00000000}},  //   _vaar, vaan_, _risv,
  { {0x7c2d049b, 0x27e90fe7, 0x69dc0007, 0x00000000}},  //   _waar, waan_, gbre,
  { {0x27e9021e, 0x7c2d000b, 0x644000c7, 0x00000000}},  //   taan_, _taar, _onmi,
  { {0x20ca0011, 0x69dc0851, 0x765e01c3, 0x00000000}},  //   _mùi_, abre, ekpy,
  { {0x27e9027c, 0x6283010b, 0x6d5a0047, 0x00000000}},  // [cbf0] raan_, ynno, lyta,
  { {0x27e90127, 0x64400c10, 0x443f0091, 0x00000000}},  //   saan_, _anmi, _snu_,
  { {0x7bcf0207, 0x6d5a0010, 0x27e918ec, 0x00000000}},  //   occu, nyta, paan_,
  { {0x7afd0036, 0x62880059, 0xd0060025, 0x00000000}},  //   orst, _ajdo, _ظل_,
  { {0x290300b0, 0x38690051, 0x2911022b, 0x00000000}},  //   luja_, mhar_, ltza_,
  { {0x261403d7, 0x386902d5, 0x64403936, 0x00000000}},  //   न्दी_, lhar_, _enmi,
  { {0x29110756, 0x2903166f, 0x442d0ba7, 0x00000000}},  //   ntza_, nuja_, _tae_,
  { {0x3869357c, 0x2911022b, 0x443f0a29, 0x00000000}},  //   nhar_, itza_, _unu_,
  { {0xf8bf0211, 0x69dc0026, 0xaec207d0, 0x00000000}},  //   _mié_, ybre, обыл,
  { {0x63a9022b, 0xee36105c, 0x29033937, 0x00000000}},  //   _izen, ань_, kuja_,
  { {0xc05b01fb, 0x4c86003b, 0x6da50594, 0x00000000}},  //   _під_, илов, рина,
  { {0x6e21010f, 0xf8bf0dce, 0x814c0049, 0x00000000}},  //   selb, _nié_, _רעאַ,
  { {0x69dc0250, 0xdee5012b, 0x610a006b, 0x00000000}},  //   tbre, _толи, _fəls,
  { {0x6d5a3938, 0x610a006b, 0x20d10066, 0x00000000}},  //   byta, _təlt, _iġib_,
  { {0xdca60057, 0x69dc010f, 0xcec80011, 0x00000000}},  //   _каки, rbre, _tộc_,
  { {0xad1a009b, 0x69dc1177, 0x8cca0309, 0x00000000}},  //   _יוצר, sbre, _संतो,

  { {0x27fd0046, 0xf8bf0343, 0xf77f153d, 0x00000000}},  // [cc00] ówna_, _dié_, _peça_,
  { {0x29033939, 0x7df3007d, 0xfc3f00f6, 0x00000000}},  //   buja_, _आयोग_, bmís_,
  { {0x3869002a, 0xd94600aa, 0x63a90032, 0x00000000}},  //   bhar_, _тени, _azen,
  { {0x3869049a, 0x1d16007b, 0x20ca0011, 0x00000000}},  //   char_, יקער_, _rùi_,
  { {0x61ea000c, 0xcfe90044, 0x3860013f, 0x00000000}},  //   tafl, _গাঢ়_, mkir_,
  { {0x64580036, 0x7ae40020, 0x63a901c5, 0x00000000}},  //   _ścią, _mwit, _dzen,
  { {0x61ea005f, 0x361b0049, 0x63a90e0c, 0x00000000}},  //   rafl, _שולד, _ezen,
  { {0x14d7019b, 0x64402af8, 0x38600022, 0x00000000}},  //   _כולל_, _unmi, nkir_,
  { {0x7e7a001c, 0x2486049c, 0xd9e60204, 0x00000000}},  //   titp, mnom_, करात_,
  { {0x7afd0059, 0x3869393a, 0x24860466, 0x00000000}},  //   vrst, zhar_, lnom_,
  { {0x62980142, 0x160b007d, 0x63a00253, 0x00000000}},  //   movo, स्टर_, _hymn,
  { {0x62980209, 0x290300b0, 0x2486393b, 0x00000000}},  //   lovo, vuja_, nnom_,
  { {0x2011005f, 0x2486393c, 0x7afd0112, 0x00000000}},  //   əzi_, inom_, urst,
  { {0x6d5a0036, 0xda7b004c, 0xaa64025f, 0x00000000}},  //   pyta, тям_, отск,
  { {0x61e8256b, 0x3869002a, 0x07e70e82, 0x00000000}},  //   _medl, thar_, ицам,
  { {0x629809fc, 0x7cc1001e, 0x24860b54, 0x00000000}},  //   hovo, _vērt, jnom_,
  { {0x248609fc, 0xab5b005f, 0x395f0089, 0x00000000}},  // [cc10] dnom_, rcüs, ņus_,
  { {0x1a65026c, 0x61e805fe, 0x290300b0, 0x00000000}},  //   _ایسی_, _nedl, puja_,
  { {0x63a9393d, 0x629801d9, 0x91fc001e, 0x00000000}},  //   _szen, dovo, _plān,
  { {0xef1f011f, 0x24860c56, 0x83fd0010, 0x00000000}},  //   çük_, gnom_, _előn,
  { {0x2614001c, 0x8c380049, 0x28c0006e, 0x00000000}},  //   न्ही_, יטאס_, _शूटि,
  { {0x62980de0, 0x5ed50044, 0x95cb003b, 0x00000000}},  //   govo, _দিলে, _шума_,
  { {0x2486393e, 0x25a50010, 0x61e8012d, 0x00000000}},  //   bnom_, _áll_, _dedl,
  { {0x2486393f, 0x6add0044, 0x00000000, 0x00000000}},  //   cnom_, _বিনো,   ,
  { {0x629801ca, 0x63a9013e, 0x7cd30035, 0x00000000}},  //   bovo, _uzen, _măre,
  { {0x69c525da, 0x765501aa, 0x5e4902e9, 0x00000000}},  //   _nghe, _jozy, упом_,
  { {0x7ae400ab, 0xfaff0023, 0x00000000, 0x00000000}},  //   _swit, erë_,   ,
  { {0x69c500e5, 0x00000000, 0x00000000, 0x00000000}},  //   _aghe,   ,   ,
  { {0x2fdf0022, 0x408600a1, 0x00000000, 0x00000000}},  //   mbug_, _دھوپ_,   ,
  { {0x24860091, 0xfbd8007d, 0x00000000, 0x00000000}},  //   znom_, _भ्रम,   ,
  { {0xa96700e3, 0x291e0129, 0x7cc10089, 0x00000000}},  //   бира_, ïta_, _vērs,
  { {0x7cd3001a, 0x00000000, 0x00000000, 0x00000000}},  //   _căre,   ,   ,
  { {0x24863940, 0x38603941, 0xe7aa0893, 0x00000000}},  // [cc20] vnom_, rkir_, увал_,
  { {0x9a2a007c, 0x1a060a1e, 0x3860000c, 0x00000000}},  //   _сооб_, _упом, skir_,
  { {0x24860466, 0xd9100123, 0x629804c8, 0x00000000}},  //   tnom_, _تیز_, vovo,
  { {0x61e83942, 0xd49901fb, 0x248600e0, 0x00000000}},  //   _sedl, арі_, unom_,
  { {0x62980161, 0xa3c903d7, 0x27e00065, 0x00000000}},  //   tovo, ोड़_, mbin_,
  { {0x78a4006c, 0x24862f38, 0x27e0152b, 0x00000000}},  //   lliv, snom_, lbin_,
  { {0x61e83943, 0x64a6007e, 0x867b0049, 0x00000000}},  //   _vedl, _гава, _ערלו,
  { {0x74160084, 0x61e80fb6, 0x78a40161, 0x00000000}},  //   _دورا, _wedl, nliv,
  { {0x33660099, 0x6298040d, 0x7c2605d5, 0x00000000}},  //   _уваг, povo, dekr,
  { {0x44263944, 0x2baf013d, 0x78a40161, 0x00000000}},  //   leo_, _घरबा, hliv,
  { {0xe0da045e, 0x78a40062, 0x00000000, 0x00000000}},  //   _све_, kliv,   ,
  { {0x4426000b, 0x7c261267, 0x7cd3001a, 0x00000000}},  //   neo_, gekr, _bărb,
  { {0x78a404bb, 0x501b009b, 0xd2590089, 0x00000000}},  //   dliv, _תודו, _suņi_,
  { {0xfaff008d, 0x60c23945, 0x27ed01dc, 0x00000000}},  //   rrë_, _hiom, _žen_,
  { {0x4426000b, 0xe731006b, 0x7cd3001a, 0x00000000}},  //   keo_, _köçü, _păre,
  { {0xc7d9060e, 0x44261a71, 0x78a40635, 0x00000000}},  //   рмах_, jeo_, gliv,
  { {0x76550046, 0x00000000, 0x00000000, 0x00000000}},  // [cc30] _pozy,   ,   ,
  { {0x60c20048, 0x9f5f00c4, 0xc98702dc, 0x00000000}},  //   _liom, nguá_, _гуми,
  { {0x81e708b7, 0x44260e32, 0x27e0013f, 0x00000000}},  //   _ভাল_, feo_, bbin_,
  { {0x44260197, 0x24190147, 0xcec80011, 0x00000000}},  //   geo_, роды_, _rộn_,
  { {0x7eaf0056, 0x00000000, 0x00000000, 0x00000000}},  //   løpe,   ,   ,
  { {0x7c261072, 0x672f0243, 0x00000000, 0x00000000}},  //   zekr, _iscj,   ,
  { {0x4426262d, 0x7cd30035, 0xa3d50088, 0x00000000}},  //   beo_, _mărc, _мовч,
  { {0x26c30211, 0x60c2112d, 0x26cb016c, 0x00000000}},  //   _hijo_, _ciom, _kuco_,
  { {0x5347019d, 0x60c23946, 0x248d0022, 0x00000000}},  //   _ухва, _diom, _ijem_,
  { {0x248d01e3, 0x26cb2f43, 0x8cca0309, 0x00000000}},  //   _hjem_, _muco_, _संशो,
  { {0x7cd3001a, 0x248d0292, 0xf3f9001a, 0x00000000}},  //   _sărb, _kjem_, _alţi_,
  { {0x26d908d1, 0x8c46003b, 0x753601ce, 0x00000000}},  //   _otso_, цеме, קארד_,
  { {0x09c50044, 0x7c261929, 0xeb97004d, 0x00000000}},  //   ্রনা, rekr, жия_,
  { {0xfce50113, 0x7fb60076, 0x7c260695, 0x00000000}},  //   _доко, _ظهور_, sekr,
  { {0x78a40428, 0x442600e0, 0x9f44004a, 0x00000000}},  //   tliv, yeo_, mamá_,
  { {0x26cb0197, 0x248d3947, 0x4426008e, 0x00000000}},  //   _buco_, _njem_, xeo_,
  { {0x4426037e, 0x07a32cb4, 0x27e0013f, 0x00000000}},  // [cc40] veo_, датн, rbin_,
  { {0x9f442bc9, 0x27e00022, 0x26cb0022, 0x00000000}},  //   namá_, sbin_, _duco_,
  { {0x26c30219, 0x44260207, 0x78b60068, 0x00000000}},  //   _dijo_, teo_, pmyv,
  { {0xf74601bd, 0xa5da006e, 0x14170025, 0x00000000}},  //   _демо, _प्रौ, قيمة_,
  { {0x44260555, 0x26c30211, 0x248d0065, 0x00000000}},  //   reo_, _fijo_, _djem_,
  { {0x4426002a, 0x366a008b, 0x60c20124, 0x00000000}},  //   seo_, _таго_, _siom,
  { {0x4426003b, 0x60c20197, 0x26cb00f6, 0x00000000}},  //   peo_, _piom, _zuco_,
  { {0x3ea50039, 0x65630030, 0x9f540088, 0x00000000}},  //   ellt_, ønhe, звич,
  { {0xf8b301f8, 0xddc80790, 0xc47700a1, 0x00000000}},  //   ושה_, ridž, _بینچ_,
  { {0xb5e80044, 0xbbe30164, 0xddc8007f, 0x00000000}},  //   _পাঁচ, पर्क, sidž,
  { {0x60c2002a, 0xa06a3948, 0x200f0061, 0x00000000}},  //   _tiom, _кажа_, _fcgi_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x09e20055, 0x628a0606, 0x00000000, 0x00000000}},  //   _বাজা, onfo,   ,
  { {0x32d00011, 0x628a0056, 0x00000000, 0x00000000}},  //   _mày_, nnfo,   ,
  { {0x628a0056, 0x6e2801ee, 0x26cb00c4, 0x00000000}},  //   info, medb, _suco_,
  { {0x2c050061, 0x81ac0044, 0x00000000, 0x00000000}},  //   _वाटू_, _গলা_,   ,
  { {0x32d000ad, 0x7d080190, 0x96eb01ab, 0x00000000}},  // [cc50] _này_, luds, рьба_,
  { {0x249f07c4, 0x213e0333, 0xcec80082, 0x00000000}},  //   _skum_, _orth_, _nộm_,
  { {0x5fca0061, 0x27eb0a15, 0x7d080190, 0x00000000}},  //   ाखाल, _tecn_, nuds,
  { {0x81e70055, 0x32d00011, 0x69d500b4, 0x00000000}},  //   _ভাই_, _bày_, lcze,
  { {0x4c3c007b, 0x3ea53949, 0x9327023c, 0x00000000}},  //   יגאצ, yllt_, تران,
  { {0x32d00011, 0x99910010, 0x200f0009, 0x00000000}},  //   _dày_, lező_, _scgi_,
  { {0x82340054, 0xd24e0025, 0x00000000, 0x00000000}},  //   برنا, انى_,   ,
  { {0x09e20044, 0x11280088, 0x00000000, 0x00000000}},  //   _বাছা, юючи_,   ,
  { {0xd2590089, 0x2cb2005b, 0x00000000, 0x00000000}},  //   _suņu_, _rhyd_,   ,
  { {0x2ca00875, 0x313501e1, 0x3264005e, 0x00000000}},  //   _skid_, _незр, _отхв,
  { {0xcb0900b6, 0xdca61023, 0x69d50036, 0x00000000}},  //   _תל_, зани, dcze,
  { {0x69d50046, 0xfaff0023, 0x672d394a, 0x00000000}},  //   ecze, jzës_, kwaj,
  { {0x705201b7, 0x20d10011, 0x5ed50044, 0x00000000}},  //   _سنوا, _hái_, _দিকে,
  { {0x09e20055, 0x7d0828e0, 0xcd2800a6, 0x00000000}},  //   _বাঙা, buds, حسین_,
  { {0xd94300aa, 0x6f090009, 0x6da20918, 0x00000000}},  //   нери, luec, _пиша,
  { {0x20d10011, 0x786a06b8, 0xfc3f16b8, 0x00000000}},  //   _mái_, _býva, llín_,
  { {0x3e6001aa, 0x20d10011, 0x29030059, 0x00000000}},  // [cc60] _sòti_, _lái_, arja_,
  { {0x7c36014a, 0x20d10082, 0x00000000, 0x00000000}},  //   _hayr, _oái_,   ,
  { {0x4a5b009b, 0xfc3f0051, 0x20d11392, 0x00000000}},  //   _הדיו, ilín_, _nái_,
  { {0xc20e013d, 0x136a0088, 0x00000000, 0x00000000}},  //   _साहब_, йшли_,   ,
  { {0x7c36006a, 0x1b1a0044, 0x290a20b9, 0x00000000}},  //   _mayr, দিকে_, luba_,
  { {0x20d10011, 0x27f2028e, 0x628a00dc, 0x00000000}},  //   _bái_, layn_, unfo,
  { {0x20d1001d, 0x6e28394b, 0x628a01a2, 0x00000000}},  //   _cái_, vedb, rnfo,
  { {0x7d0801d2, 0x69d50036, 0x64a30088, 0x00000000}},  //   vuds, zcze, _заса,
  { {0x213e018e, 0x69d50036, 0x6f09004a, 0x00000000}},  //   _wrth_, ycze, guec,
  { {0x29180006, 0x290a0020, 0x20d1000c, 0x00000000}},  //   ktra_, kuba_, _fái_,
  { {0x7c36038c, 0x20d1001d, 0x6e281adc, 0x00000000}},  //   _bayr, _gái_, redb,
  { {0x7d080737, 0x672d0036, 0x6e2800ca, 0x00000000}},  //   ruds, ywaj, sedb,
  { {0xfc3f06c2, 0xe8e00082, 0x6e46007e, 0x00000000}},  //   blín_, _thớt_, _недз,
  { {0xfe6f0025, 0x7c3601d6, 0x290a0045, 0x00000000}},  //   _مدى_, _eayr, fuba_,
  { {0x8bec0044, 0x69d51072, 0x290a394c, 0x00000000}},  //   _কারন_, rcze, guba_,
  { {0x29030065, 0x7c36014a, 0x672d394d, 0x00000000}},  //   rrja_, _gayr, twaj,
  { {0x29180555, 0xcc34006d, 0x7bc02270, 0x00000000}},  // [cc70] atra_, _سريع, žmur,
  { {0x672d05cd, 0x00000000, 0x00000000, 0x00000000}},  //   rwaj,   ,   ,
  { {0x290a02e2, 0x291805ac, 0x27f200e0, 0x00000000}},  //   cuba_, ctra_, bayn_,
  { {0x09c50044, 0x00000000, 0x00000000, 0x00000000}},  //   ্রদা,   ,   ,
  { {0x9f590279, 0xe3b00380, 0x00000000, 0x00000000}},  //   üsü_, هره_,   ,
  { {0xa021014a, 0x3f98026d, 0x200201e5, 0x00000000}},  //   _çöze, ğrul_, ókin_,
  { {0xe1f00076, 0x6594004c, 0xd12e0379, 0x00000000}},  //   اسه_, _зару, لمو_,
  { {0x427700a2, 0x333f0066, 0x15eb0061, 0x00000000}},  //   _کارآ, _trux_, टरवर_,
  { {0x290a0009, 0x200d010e, 0x7cd30035, 0x00000000}},  //   zuba_, rgei_, _cărn,
  { {0x4d650245, 0x20d10011, 0xddc3001a, 0x00000000}},  //   дков, _tái_, _conş,
  { {0x90e7007a, 0xfc3f0051, 0x291828fa, 0x00000000}},  //   _رسان, rlín_, xtra_,
  { {0x645b00f4, 0xff510241, 0x25b100d9, 0x00000000}},  //   _joui, _لخت_, _mzzl_,
  { {0x20180163, 0x6f09394e, 0x25aa0164, 0x00000000}},  //   əri_, quec, _कर्ण,
  { {0x290a0bd5, 0x291800f4, 0xc33201ce, 0x00000000}},  //   tuba_, ttra_, דוך_,
  { {0x644900c7, 0xb86600a1, 0x485a007e, 0x00000000}},  //   _onei, وارو, ораў_,
  { {0x290a01ca, 0x6add0044, 0x7c95007e, 0x00000000}},  //   ruba_, _বিরো, _прыц,
  { {0x291816a3, 0x628300b0, 0x2b4000ca, 0x00000000}},  // [cc80] stra_, kino, _uric_,
  { {0x461a007e, 0x6283049c, 0x64490e42, 0x00000000}},  //   ўцаў_, jino, _anei,
  { {0x6283018e, 0x645b00f4, 0x00000000, 0x00000000}},  //   dino, _boui,   ,
  { {0x81e70044, 0x645b009d, 0xed560049, 0x00000000}},  //   _ভাগ_, _coui, ובער_,
  { {0x93cb00a1, 0x62830387, 0x645b009d, 0x00000000}},  //   زانہ_, fino, _doui,
  { {0xfe670014, 0x6449005b, 0x21250022, 0x00000000}},  //   _شد_, _enei, _bplh_,
  { {0xe5a60216, 0x65c3008b, 0x645b009d, 0x00000000}},  //   _циви, _абра, _foui,
  { {0xcec800ad, 0x6b9600ab, 0x644901e5, 0x00000000}},  //   _hội_, _oxyg, _gnei,
  { {0x62830142, 0x09b50044, 0xd426006b, 0x00000000}},  //   bino, _জ্ঞা, ışdı_,
  { {0xddc3006b, 0x7cd3001a, 0x5d5427f3, 0x00000000}},  //   _qonş, _căro, екот,
  { {0x645b00e0, 0x765c005b, 0x00000000, 0x00000000}},  //   _youi, _mory,   ,
  { {0x765c394f, 0xcec80082, 0x00000000, 0x00000000}},  //   _lory, _lội_,   ,
  { {0xa6db000c, 0x765c01c3, 0x2bc802dc, 0x00000000}},  //   _orða, _oory, дуро_,
  { {0x995800b9, 0xb06103b6, 0x28a7013d, 0x00000000}},  //   láře_, _ääre, _कीजि,
  { {0xcec800ad, 0xf77300a1, 0x787100ea, 0x00000000}},  //   _nội_, ھار_, _låve,
  { {0x6283022b, 0x995800b9, 0x6e383950, 0x00000000}},  //   zino, náře_, _havb,
  { {0xb8d6024c, 0x7bcd001e, 0x645b009d, 0x00000000}},  // [cc90] _ची_, _igau, _roui,
  { {0xb9050055, 0x644919cb, 0xcec80011, 0x00000000}},  //   _নি_, _snei, _bội_,
  { {0xd49b00ed, 0xcec80082, 0x645b009d, 0x00000000}},  //   орд_, _cội_, _poui,
  { {0x05df02d2, 0xd5df007d, 0xcec80082, 0x00000000}},  //   _प्रब, _प्रज, _dội_,
  { {0xe8df001d, 0x765c000c, 0xb7da0104, 0x00000000}},  //   _khỏe_, _fory, _מקרי,
  { {0x6e380061, 0x7aed0ed7, 0x38690a46, 0x00000000}},  //   _navb, _mwat, lkar_,
  { {0x442b00d6, 0x23690e3b, 0x610a006b, 0x00000000}},  //   _ºc_, šaj_, _zəlz,
  { {0x386902e1, 0x64493951, 0x442b0011, 0x00000000}},  //   nkar_, _unei, _úc_,
  { {0x62830161, 0x7f42009d, 0x38690fdc, 0x00000000}},  //   pino, _croq, ikar_,
  { {0x7bcd00d4, 0x38691a6f, 0x00000000, 0x00000000}},  //   _agau, hkar_,   ,
  { {0xd011025a, 0x38693952, 0x7aed00e7, 0x00000000}},  //   _ملا_, kkar_, _awat,
  { {0xeb9a0e75, 0x7aed0a5f, 0x3e690027, 0x00000000}},  //   зим_, _bwat, _túto_,
  { {0x386900f8, 0xbf670380, 0x661500b4, 0x00000000}},  //   dkar_, _تداو, _oczk,
  { {0x4279007b, 0x7aed0173, 0x386901c3, 0x00000000}},  //   לאָג, _dwat, ekar_,
  { {0xae78008b, 0x48b60f6f, 0xd82600aa, 0x00000000}},  //   _ўсіх_, ещат, ндви,
  { {0x786a0428, 0x63a9008e, 0xddca000a, 0x00000000}},  //   _vývo, _oyen, _anfň,
  { {0x7c242ac7, 0x7aed3953, 0x63a90020, 0x00000000}},  // [cca0] _ibir, _gwat, _nyen,
  { {0xba76007a, 0xdb9b00b3, 0x00000000, 0x00000000}},  //   _ساخت, _מספר,   ,
  { {0x387201d6, 0x7c2401d5, 0x78710737, 0x00000000}},  //   phyr_, _kbir, _såve,
  { {0x38690073, 0x66e60072, 0x787101c9, 0x00000000}},  //   ckar_, _пома, _påve,
  { {0x7cc20089, 0x3e72009d, 0x3a3a141a, 0x00000000}},  //   _bērz, _hâte_, _kapp_,
  { {0xcec80011, 0x63a909d7, 0x3a3a00f8, 0x00000000}},  //   _tội_, _dyen, _japp_,
  { {0xfd07035b, 0x3a3a00f8, 0x7c240087, 0x00000000}},  //   _حج_, _mapp_, _obir,
  { {0x7f42005f, 0x63a93954, 0xc953009b, 0x00000000}},  //   _proq, _fyen, רמה_,
  { {0x63060879, 0x44241f1b, 0x63a90010, 0x00000000}},  //   _سوال, _ibm_, _gyen,
  { {0x7c240020, 0xe0ce0044, 0xdbfb006e, 0x00000000}},  //   _abir, _রবীন, ्ल्ड_,
  { {0xdb160047, 0xfc3f0161, 0x44243955, 0x00000000}},  //   _együ, slím_, _kbm_,
  { {0x7f423956, 0x26ca3957, 0x4424016c, 0x00000000}},  //   _troq, _libo_, _jbm_,
  { {0x6d4311fe, 0x44240145, 0x38690910, 0x00000000}},  //   _erna, _mbm_, vkar_,
  { {0x7c240009, 0x44240c3b, 0x2ba50204, 0x00000000}},  //   _ebir, _lbm_, _गुणा,
  { {0x3e72001a, 0x3869006b, 0x44240085, 0x00000000}},  //   _câte_, tkar_, _obm_,
  { {0xe8e00011, 0x7aed38fc, 0x442400fa, 0x00000000}},  //   _chốt_, _twat, _nbm_,
  { {0x3869313a, 0x7c2f04bd, 0x7aed37dd, 0x00000000}},  // [ccb0] rkar_, mecr, _uwat,
  { {0x38690073, 0x7c2401ae, 0x26ca0207, 0x00000000}},  //   skar_, _zbir, _cibo_,
  { {0x4424023a, 0x941910e2, 0xf77f00f4, 0x00000000}},  //   _bbm_, джет_, _reçu_,
  { {0x7c3d0030, 0x628100b9, 0x6f1b0036, 0x00000000}},  //   ndsr, _smlo, ytuc,
  { {0xa7fb049a, 0x27e9089a, 0x7c3d0116, 0x00000000}},  //   _coñe, mban_, idsr,
  { {0x78ad1583, 0x7cc90036, 0x27e93958, 0x00000000}},  //   llav, _ośro, lban_,
  { {0x409507e1, 0x78ad0026, 0x27e900e0, 0x00000000}},  //   крит, olav, oban_,
  { {0x27e90047, 0x6f1b301e, 0x7c3d0190, 0x00000000}},  //   nban_, ttuc, jdsr,
  { {0x442f119e, 0x7c2f1ba1, 0x6d5c03b6, 0x00000000}},  //   meg_, decr, äran,
  { {0x83fd0047, 0x78ad01ca, 0x6f1b08d3, 0x00000000}},  //   _előt, hlav, rtuc,
  { {0x261903d7, 0x78ad01aa, 0x27e90047, 0x00000000}},  //   _पानी_, klav, kban_,
  { {0x442f0016, 0x7c2f0190, 0x20030006, 0x00000000}},  //   neg_, gecr, ėjis_,
  { {0x207a007b, 0x907a034e, 0x27e90010, 0x00000000}},  //   _קאנא, _קטני, dban_,
  { {0x24860036, 0x6d430027, 0x3e72009d, 0x00000000}},  //   ziom_, _trna, _pâte_,
  { {0xc212019b, 0x78ad000c, 0x26ca0de5, 0x00000000}},  //   יהם_, flav, _ribo_,
  { {0x442f0119, 0x78ad1032, 0x27e90010, 0x00000000}},  //   jeg_, glav, gban_,
  { {0xbc1b00b6, 0x442f1e3d, 0x6f0905c6, 0x00000000}},  // [ccc0] _חופש, deg_, nrec,
  { {0x27e901a3, 0x6d410521, 0x442412ea, 0x00000000}},  //   aban_, ovla, _sbm_,
  { {0x27e90047, 0x44240022, 0x6f09010f, 0x00000000}},  //   bban_, _pbm_, hrec,
  { {0x2541010a, 0x78ad2262, 0x69dc0190, 0x00000000}},  //   _dėl_, clav, lcre,
  { {0x24860253, 0x3eac0190, 0x00000000, 0x00000000}},  //   riom_, yldt_,   ,
  { {0x5b7b007b, 0x6f090016, 0x442f006c, 0x00000000}},  //   ורנא, drec, aeg_,
  { {0xcec800ad, 0x60cb01e5, 0x44240181, 0x00000000}},  //   _một_, _bigm, _tbm_,
  { {0x442f037e, 0x75370049, 0x6f09059b, 0x00000000}},  //   ceg_, _באלד_, frec,
  { {0x83fd0010, 0x6f0900c4, 0x60cb011c, 0x00000000}},  //   _elős, grec, _digm,
  { {0xa806047f, 0x91ba0879, 0x27e90010, 0x00000000}},  //   ldığ, _قطار_, zban_,
  { {0x7c2f041d, 0x6f09001a, 0x69dc0606, 0x00000000}},  //   tecr, arec, dcre,
  { {0x6f093959, 0xa806047f, 0x9ffa01f7, 0x00000000}},  //   brec, ndığ, _آراء_,
  { {0xcec80011, 0x6f09008e, 0x9b58005e, 0x00000000}},  //   _bột_, crec, вият_,
  { {0x2be30754, 0x442f115b, 0xcec80011, 0x00000000}},  //   _क्रं_, zeg_, _cột_,
  { {0x27e90047, 0x78ad01ee, 0xeb9f0190, 0x00000000}},  //   tban_, tlav, ggør_,
  { {0x764e0a34, 0x27e9009d, 0x60cb0203, 0x00000000}},  //   _anby, uban_, _xigm,
  { {0x27e9395a, 0x442f009f, 0x78ad1f38, 0x00000000}},  // [ccd0] rban_, veg_, rlav,
  { {0x61f801ae, 0x78ad13a1, 0x442f0270, 0x00000000}},  //   javl, slav, weg_,
  { {0x442f0010, 0x7afd000c, 0x27e90010, 0x00000000}},  //   teg_, lsst, pban_,
  { {0x25410006, 0xfc3f008e, 0xd3b905b8, 0x00000000}},  //   _vėl_, ndí_, нулі_,
  { {0x442f00ea, 0x2911395b, 0xfc3f0051, 0x00000000}},  //   reg_, luza_, idí_,
  { {0x7afd01a2, 0x24840145, 0xf6790049, 0x00000000}},  //   isst, _emmm_, _טאָמ,
  { {0x442f11d1, 0x6f0902c2, 0x2911395c, 0x00000000}},  //   peg_, wrec, nuza_,
  { {0x6f09001a, 0x83fd0047, 0x7afd02e1, 0x00000000}},  //   trec, _előr, ksst,
  { {0x61f80825, 0x29110009, 0x2f54007e, 0x00000000}},  //   bavl, huza_, атэс,
  { {0x7afd00eb, 0x29110020, 0x2ca90f55, 0x00000000}},  //   dsst, kuza_, _akad_,
  { {0x6f09010f, 0x29110066, 0xcc8a003b, 0x00000000}},  //   srec, juza_, ебне_,
  { {0x670302d2, 0x6f0903a1, 0x6d41046a, 0x00000000}},  //   _लिंक_, prec, rvla,
  { {0x6d411c81, 0x7afd06a1, 0x7cd3001a, 0x00000000}},  //   svla, gsst, _mări,
  { {0x2911395d, 0xa806005d, 0x78710b16, 0x00000000}},  //   fuza_, zdığ, _råva,
  { {0x69dc00f4, 0x2911395e, 0xa8060279, 0x00000000}},  //   rcre, guza_, ydığ,
  { {0x61f808de, 0x7afd27b7, 0x1ddf0061, 0x00000000}},  //   zavl, bsst, पुरत,
  { {0xcec80082, 0x3f89002b, 0x00000000, 0x00000000}},  // [cce0] _tột_, _uċuħ_,   ,
  { {0x2619001c, 0x29110009, 0x66c90006, 0x00000000}},  //   _पाणी_, buza_, _užkl,
  { {0x044602be, 0xa806006b, 0x29110c99, 0x00000000}},  //   лежн, tdığ, cuza_,
  { {0x3ea5010f, 0x32d9000a, 0x7cd300e5, 0x00000000}},  //   holt_, _bèy_, _cări,
  { {0x61f800ee, 0xa8060279, 0x3ea50232, 0x00000000}},  //   tavl, rdığ, kolt_,
  { {0xd13a0ae0, 0xfc3f0062, 0x32d90173, 0x00000000}},  //   ехи_, zdí_, _dèy_,
  { {0x61f8092f, 0x386235f5, 0x00000000, 0x00000000}},  //   ravl, _kokr_,   ,
  { {0x61f805fa, 0x32d901aa, 0x6d5c006c, 0x00000000}},  //   savl, _fèy_, äram,
  { {0x7ae40009, 0x5f94007c, 0x2911395f, 0x00000000}},  //   _ntit, рипт, zuza_,
  { {0x7afd1a95, 0x07370104, 0xd3b901e1, 0x00000000}},  //   vsst, נאים_, _русі_,
  { {0x7ae42005, 0x628a0190, 0xa1960184, 0x00000000}},  //   _atit, mifo, _сјај,
  { {0x628a00ab, 0x29113960, 0x00000000, 0x00000000}},  //   lifo, vuza_,   ,
  { {0x2f18004c, 0x3ea53961, 0xfc3f0387, 0x00000000}},  //   _роль_, bolt_, rdí_,
  { {0x7afd000c, 0x29110202, 0x7ae40048, 0x00000000}},  //   rsst, tuza_, _dtit,
  { {0x7afd01a2, 0x7ae40058, 0xd5eb0082, 0x00000000}},  //   ssst, _etit, _đìn,
  { {0x29110032, 0x7ae401f3, 0x628a0197, 0x00000000}},  //   ruza_, _ftit, hifo,
  { {0x7c9400a6, 0xa7fb008e, 0x3cfe0009, 0x00000000}},  // [ccf0] _دشوا, _coña, lstv_,
  { {0x32d901aa, 0x2b490016, 0x7cd30035, 0x00000000}},  //   _rèy_, _irac_, _sări,
  { {0xceb3061e, 0x7cd3001a, 0x3cfe1c2b, 0x00000000}},  //   ציע_, _pări, nstv_,
  { {0xd3710054, 0xf48500a1, 0x7c3f002b, 0x00000000}},  //   يها_, جائی, _jaqr,
  { {0x81e60044, 0x6fcb006b, 0x6d5c0bac, 0x00000000}},  //   _ভয়_, _möcü, äraj,
  { {0x45d400c0, 0x628a013e, 0x15ab02dc, 0x00000000}},  //   _горс, gifo, _зъби_,
  { {0xc692009b, 0x7cd30035, 0xf4020035, 0x00000000}},  //   _ואם_, _tări, faţă_,
  { {0xaf050088, 0x2019006c, 0xfaff0023, 0x00000000}},  //   апил, üsi_, ksë_,
  { {0x3255005c, 0x443f3962, 0xcf8e007a, 0x00000000}},  //   _квар, _iau_, وژه_,
  { {0x443f022b, 0xa2b30061, 0xddca0173, 0x00000000}},  //   _hau_, ेगळ्, _enfō,
  { {0x7ae4001a, 0xb035007c, 0x443f0127, 0x00000000}},  //   _stit, _внеш, _kau_,
  { {0x443f0ebc, 0xcb6a0200, 0x7ae43963, 0x00000000}},  //   _jau_, ваме_, _ptit,
  { {0x443f0475, 0xe7b00044, 0x386212a9, 0x00000000}},  //   _mau_, _কল্য, _rokr_,
  { {0x443f022b, 0x2b490129, 0xee090081, 0x00000000}},  //   _lau_, _drac_, _рекл_,
  { {0xa7fb0211, 0x443f3964, 0x2eff0022, 0x00000000}},  //   _soña, _oau_, lsuf_,
  { {0xcec80011, 0x443f0ed6, 0xad1a00a0, 0x00000000}},  //   _hộp_, _nau_, _סופר,
  { {0x7e6338c5, 0x787802d5, 0x41d50061, 0x00000000}},  // [cd00] _konp, _níve, दशास,
  { {0x61400010, 0x443f0190, 0x8afb009b, 0x00000000}},  //   nálá, _aau_, _שהיי,
  { {0x443f293e, 0x7e631339, 0x75560184, 0x00000000}},  //   _bau_, _monp, шњац,
  { {0x499b012f, 0x443f085b, 0x320505ae, 0x00000000}},  //   _ישיב, _cau_, _adly_,
  { {0x443f3965, 0x628a113d, 0x78780181, 0x00000000}},  //   _dau_, tifo, _cíve,
  { {0x443f028c, 0xcec80011, 0x7e630133, 0x00000000}},  //   _eau_, _nộp_, _nonp,
  { {0xd1300054, 0x628a0016, 0x5275003b, 0x00000000}},  //   سمة_, rifo, ључу,
  { {0x443f0c54, 0x741600a6, 0x27e001a3, 0x00000000}},  //   _gau_, _خورا, ncin_,
  { {0x442601c3, 0x27e00145, 0xd46700ed, 0x00000000}},  //   mfo_, icin_, _тите_,
  { {0x442608d3, 0x6442002d, 0xd337009b, 0x00000000}},  //   lfo_, ldoi, _דרמה_,
  { {0x64400b9a, 0x7e632f75, 0x44260026, 0x00000000}},  //   _kami, _donp, ofo_,
  { {0x44260004, 0x644032ca, 0x4fa6007c, 0x00000000}},  //   nfo_, _jami, _киев,
  { {0x7b640057, 0xdd390035, 0xfbdf00fa, 0x00000000}},  //   отре, păşe, rcê_,
  { {0x28db0309, 0x4efb00b3, 0x644200b0, 0x00000000}},  //   _मंदि, _יהדו, hdoi,
  { {0x7c3f002b, 0x888700e2, 0x00000000, 0x00000000}},  //   _taqr, аѓал,   ,
  { {0x6440026a, 0x2b49005b, 0x6d4a01a3, 0x00000000}},  //   _nami, _trac_, _irfa,
  { {0x443f3240, 0xd7f8007e, 0x62880030, 0x00000000}},  // [cd10] _rau_, рус_, _omdo,
  { {0x443f3966, 0x64400dc7, 0xe61301fa, 0x00000000}},  //   _sau_, _aami, تشر_,
  { {0x443f0129, 0xf8b101ef, 0x44260197, 0x00000000}},  //   _pau_, _فکر_, ffo_,
  { {0x64400df9, 0x2936007b, 0x6f020161, 0x00000000}},  //   _cami, _פארן_, _ovoc,
  { {0x64400e42, 0xa6db009f, 0x443f00d4, 0x00000000}},  //   _dami, _orði, _vau_,
  { {0x443f0145, 0x7878004a, 0x20060145, 0x00000000}},  //   _wau_, _víve, _adoi_,
  { {0x443f2c5f, 0x26d91d12, 0x659406b6, 0x00000000}},  //   _tau_, _huso_, _дару,
  { {0x6440181a, 0x26d12ca2, 0xfc3f0051, 0x00000000}},  //   _gami, _hizo_, ilís_,
  { {0x7e633967, 0x6d4a0016, 0x26d1016c, 0x00000000}},  //   _ponp, _arfa, _kizo_,
  { {0x6440091e, 0x7e550594, 0xf1a7012b, 0x00000000}},  //   _zami, стиц, _крен,
  { {0x64400093, 0x6f02060c, 0x41b506b4, 0x00000000}},  //   _yami, _evoc, _امار,
  { {0xf8bf001d, 0x672f0036, 0xfc320025, 0x00000000}},  //   _nhé_, _opcj, أحد_,
  { {0x6d4a001f, 0x9f40009f, 0x2d8b0036, 0x00000000}},  //   _erfa, _þið_, ńce_,
  { {0x7e7a054e, 0x63bb0020, 0x09e30140, 0x00000000}},  //   chtp, _mzun, зорн,
  { {0x5ef90044, 0x6a6b005d, 0x0dc8003b, 0x00000000}},  //   _আমিও_, _nüfu, _кући_,
  { {0xf8bf0197, 0x26d90026, 0xbc930098, 0x00000000}},  //   _ché_, _buso_, _најј,
  { {0x64403540, 0x27e02803, 0x44f50027, 0x00000000}},  // [cd20] _rami, rcin_, eť_,
  { {0x77c70106, 0x26d904eb, 0x00000000, 0x00000000}},  //   слуг_, _duso_,   ,
  { {0x64400a71, 0xa96a012d, 0xd6cf0025, 0x00000000}},  //   _pami, _сина_, رقم_,
  { {0xf8bf0011, 0x26d908eb, 0x7af60007, 0x00000000}},  //   _ghé_, _fuso_, _kwyt,
  { {0x8c1b01f8, 0x64423968, 0x9f4f00f6, 0x00000000}},  //   רוני, rdoi, _negà_,
  { {0x66e30265, 0x8b060036, 0x64400020, 0x00000000}},  //   _хора, częś, _wami,
  { {0x67240ba5, 0x26d90061, 0x2ee63969, 0x00000000}},  //   ltij, _zuso_, _stof_,
  { {0x04960647, 0x38600169, 0x64400020, 0x00000000}},  //   _الرح, njir_, _uami,
  { {0x421a0d0b, 0x6d4a0087, 0x9f53007e, 0x00000000}},  //   _مزاج_, _srfa, звыч,
  { {0xa3e402d2, 0x62650054, 0x1ed70025, 0x00000000}},  //   पुर_, _والق, حبيب_,
  { {0x6724016e, 0x321e02b5, 0x6a6b026d, 0x00000000}},  //   htij, _icty_, _müft,
  { {0x672400b5, 0xac190152, 0x7af60016, 0x00000000}},  //   ktij, шому_, _bwyt,
  { {0x0b8b0f93, 0x38600022, 0x00000000, 0x00000000}},  //   усни_, djir_,   ,
  { {0x26d90dfb, 0xb69b001a, 0x6298010f, 0x00000000}},  //   _ruso_, _avân, nnvo,
  { {0xdd93008b, 0x26d9011c, 0x629801c3, 0x00000000}},  //   _нашы, _suso_, invo,
  { {0x26d9396a, 0x672400b5, 0x5b15041f, 0x00000000}},  //   _puso_, ftij, _дмит,
  { {0x7c2d177c, 0x6d4800ea, 0x00000000, 0x00000000}},  // [cd30] _ibar, lvda,   ,
  { {0x32f600b4, 0x00000000, 0x00000000, 0x00000000}},  //   dły_,   ,   ,
  { {0xf8bf009d, 0x67242c1b, 0x60da010e, 0x00000000}},  //   _thé_, atij, _nutm,
  { {0x62980328, 0x26d90e20, 0x9a25009e, 0x00000000}},  //   envo, _tuso_, _اٹھن,
  { {0x7c2d396b, 0x44f513a1, 0x4ad90061, 0x00000000}},  //   _mbar, sť_, ढदिव,
  { {0xf99002fd, 0x60da012d, 0x6d460089, 0x00000000}},  //   _آبی_, _butm, ākaj,
  { {0x32f60036, 0x61fa01a2, 0x7c2d0340, 0x00000000}},  //   ały_, _detl, _obar,
  { {0x4f09003b, 0x7c2d0009, 0x61fa0112, 0x00000000}},  //   анин_, _nbar, _eetl,
  { {0x63bb0279, 0x442d0058, 0x61fa00ea, 0x00000000}},  //   _uzun, _ibe_, _fetl,
  { {0x7c2d0885, 0x61fa396c, 0xd10903ec, 0x00000000}},  //   _abar, _getl, _نقطه_,
  { {0x60da01a2, 0x00000000, 0x00000000, 0x00000000}},  //   _gutm,   ,   ,
  { {0xc0cb003b, 0x290300ea, 0x6f0e0276, 0x00000000}},  //   _сузе_, dsja_, üncü,
  { {0xc6110055, 0x543a0049, 0x3b8301ff, 0x00000000}},  //   স্যা_, בערא, дляг,
  { {0x3e7b009d, 0x60c4002b, 0x7c2d1683, 0x00000000}},  //   _bête_, ċime, _ebar,
  { {0xd943005e, 0x442d0465, 0x7cd30035, 0x00000000}},  //   мери, _obe_, _vărs,
  { {0x672401d5, 0xf7720b6c, 0x7c2d0026, 0x00000000}},  //   ttij, واء_, _gbar,
  { {0x1666060e, 0x3860000c, 0xd5b80089, 0x00000000}},  // [cd40] овам, rjir_, _šā_,
  { {0x442d0061, 0x3e7b00f4, 0x7c2d043f, 0x00000000}},  //   _abe_, _fête_, _zbar,
  { {0x672401d5, 0x7c2d0058, 0x442d1494, 0x00000000}},  //   stij, _ybar, _bbe_,
  { {0x76551153, 0x61fa396d, 0xfbae0061, 0x00000000}},  //   _enzy, _setl, _घडाम,
  { {0x291801d5, 0x442d0009, 0x83360137, 0x00000000}},  //   lura_, _dbe_, تراض,
  { {0xa6e2000c, 0x60da00d9, 0x78a90e0d, 0x00000000}},  //   áðun, _putm, čeve,
  { {0x291807ec, 0xa50702e9, 0x61fa396e, 0x00000000}},  //   nura_, _мера_, _vetl,
  { {0x61fa0436, 0xb4d6013d, 0x3a3800bb, 0x00000000}},  //   _wetl, सदी_, herp_,
  { {0x29180065, 0x63060123, 0x7eaf00ea, 0x00000000}},  //   hura_, _ذوال, jøps,
  { {0x29180307, 0x60da0279, 0x35af013d, 0x00000000}},  //   kura_, _tutm, _जुड़,
  { {0x29180035, 0x2b400288, 0x98ba0173, 0x00000000}},  //   jura_, _asic_, _aspč_,
  { {0x2918022b, 0x00000000, 0x00000000, 0x00000000}},  //   dura_,   ,   ,
  { {0x8ae40088, 0xa09b009b, 0x2b40004a, 0x00000000}},  //   дісл, _דיאט, _csic_,
  { {0x29181131, 0x29110036, 0x2903010e, 0x00000000}},  //   fura_, trza_, tsja_,
  { {0x2b4000f6, 0x60c200e7, 0x29050e34, 0x00000000}},  //   _esic_, _khom, éla_,
  { {0x29030036, 0x1a6500a1, 0xda17007d, 0x00000000}},  //   rsja_, _کیسی_, _ताकत_,
  { {0xb6c900a1, 0x2903002b, 0x2b400009, 0x00000000}},  // [cd50] مائے_, ssja_, _gsic_,
  { {0x29180ac9, 0x3e7b00f4, 0x454b0194, 0x00000000}},  //   bura_, _tête_, ичем_,
  { {0x2918049a, 0xe4a70088, 0x76450023, 0x00000000}},  //   cura_, ордо, rdhy,
  { {0xe787003b, 0x91fc0089, 0x00000000, 0x00000000}},  //   _дуго, _glāz,   ,
  { {0xa85a009b, 0x91e5030d, 0x442d007f, 0x00000000}},  //   _הדרכ, поле, _vbe_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x999a0087, 0x00000000, 0x00000000, 0x00000000}},  //   _kapš_,   ,   ,
  { {0x60c2002a, 0xd12e0380, 0x442d0058, 0x00000000}},  //   _chom, امي_, _ube_,
  { {0x60c21c75, 0x2918016e, 0x248d0087, 0x00000000}},  //   _dhom, zura_, _imem_,
  { {0x291824a8, 0xc33201ce, 0x78ad2fa3, 0x00000000}},  //   yura_, _אומ_, hoav,
  { {0xc6110055, 0x3eb90089, 0x2918002d, 0x00000000}},  //   স্থা_, ēst_, xura_,
  { {0x29180a15, 0x2245014a, 0x3a3800c7, 0x00000000}},  //   vura_, _halk_, werp_,
  { {0x60c9027b, 0xeb972aa3, 0xf092009b, 0x00000000}},  //   mmem, зия_, _אנא_,
  { {0x60c9014a, 0xc6110044, 0x20c10048, 0x00000000}},  //   lmem, স্তা_, sóid_,
  { {0x6d5c006c, 0xfaa3007e, 0xa6db01e5, 0x00000000}},  //   ärat, харо, _orðs,
  { {0x60c917d4, 0x83fd0047, 0xa3d70061, 0x00000000}},  //   nmem, _előz, _सलग_,
  { {0x27f2018e, 0x601601df, 0xe7ba0044, 0x00000000}},  // [cd60] rbyn_, lümü, ংখ্য,
  { {0x291804cb, 0xf1cb0204, 0x248d00fa, 0x00000000}},  //   pura_, ाधान, _amem_,
  { {0x89db0104, 0x6016005a, 0xf9920014, 0x00000000}},  //   _לחיי, nümü, _سبد_,
  { {0x7eb40129, 0xe8e00082, 0x161e013d, 0x00000000}},  //   ràpi, _nhứt_, _पावर_,
  { {0x224500bb, 0x6d460089, 0x44200089, 0x00000000}},  //   _balk_, ākai, ļi_,
  { {0x442001d5, 0x60c2191a, 0x25080123, 0x00000000}},  //   żi_, _shom, _ورزی_,
  { {0x22450343, 0x78710cf5, 0x29360049, 0x00000000}},  //   _dalk_, _såvi, לאַן_,
  { {0x78712314, 0x859b00b3, 0x60c9011c, 0x00000000}},  //   _påvi, _השלו, gmem,
  { {0x22450210, 0x00000000, 0x00000000, 0x00000000}},  //   _falk_,   ,   ,
  { {0xd091005f, 0x78ad00c4, 0xe2450025, 0x00000000}},  //   _müəl, zoav, _يخلي,
  { {0x70f60a4f, 0x2ba5013d, 0x00000000, 0x00000000}},  //   _رسائ, _गुजा,   ,
  { {0xef1901d5, 0xf3f9001a, 0x515b00a0, 0x00000000}},  //   buż_, _poţi_, _לכבו,
  { {0x7680396f, 0x2ca00045, 0x4ae7007e, 0x00000000}},  //   _köyd, _djid_, яўна,
  { {0x6d5c006c, 0x6016014a, 0xa6db01e5, 0x00000000}},  //   äras, bümü, _orðr,
  { {0x78ad06d5, 0x39a400e2, 0x79a40900, 0x00000000}},  //   toav, ештв, ерте,
  { {0x7d1a0c3f, 0x768000b0, 0xf3f9001a, 0x00000000}},  //   muts, _löyd, _toţi_,
  { {0x7d1a006c, 0x9773007e, 0x78ad00fa, 0x00000000}},  // [cd70] luts, лiся_, roav,
  { {0xfbd00054, 0xf7700d3a, 0x7aed0503, 0x00000000}},  //   _حتى_, داف_, _itat,
  { {0x9475089d, 0x7d1a010e, 0x60c916b4, 0x00000000}},  //   وگرا, nuts, ymem,
  { {0xe3b000a6, 0x320c0145, 0x22450087, 0x00000000}},  //   گرم_, _addy_, _salk_,
  { {0x2245006c, 0x6e3a01c3, 0x6016005d, 0x00000000}},  //   _palk_, ketb, zümü,
  { {0x7d1a0d49, 0x7aed00e7, 0x60c9016b, 0x00000000}},  //   kuts, _mtat, wmem,
  { {0x7d1a00f8, 0x2245015b, 0xa156003b, 0x00000000}},  //   juts, _valk_, дају_,
  { {0x443904bd, 0x248d05fa, 0x6a700a5d, 0x00000000}},  //   _ús_, _umem_, _häft,
  { {0x224500ab, 0x60c9014a, 0x7aed3970, 0x00000000}},  //   _talk_, rmem, _ntat,
  { {0x3e8901fb, 0x4df4004c, 0xfe710025, 0x00000000}},  //   ійно_, няют, ئدة_,
  { {0x7aed011f, 0xdca60069, 0x7d1a006c, 0x00000000}},  //   _atat, дани, guts,
  { {0xa0c40025, 0x6016005a, 0x00000000, 0x00000000}},  //   _كيلو, rümü,   ,
  { {0x6d5c0e2b, 0x3af60454, 0x9f4f07c4, 0x00000000}},  //   ärar, ьянс, _begå_,
  { {0xaec40088, 0x7d1a09e7, 0x201f0129, 0x00000000}},  //   _збіл, buts, lgui_,
  { {0x7aed1ca7, 0x2d94005e, 0x7d1a0288, 0x00000000}},  //   _etat, _пръс, cuts,
  { {0x201f0129, 0x00000000, 0x00000000, 0x00000000}},  //   ngui_,   ,   ,
  { {0x76470009, 0x7c243971, 0x2d853972, 0x00000000}},  // [cd80] _bajy, _icir, lzle_,
  { {0x78a901d9, 0x00000000, 0x00000000, 0x00000000}},  //   čeva,   ,   ,
  { {0x186a1984, 0x29050010, 0xf65100a1, 0x00000000}},  //   _дани_, álat_, ھئے_,
  { {0xf4870cd9, 0xe3ba22bb, 0x6e3a0c57, 0x00000000}},  //   وانی, обе_, zetb,
  { {0x63be0036, 0x768000b0, 0x00000000, 0x00000000}},  //   ępno, _pöyd,   ,
  { {0x6d430e42, 0xfbc00044, 0x00000000, 0x00000000}},  //   _osna, _ইলাত,   ,
  { {0x28c303d7, 0xfd0700a1, 0x00000000, 0x00000000}},  //   _वीडि, _جج_,   ,
  { {0x7d1a1add, 0x26d83973, 0x055712c0, 0x00000000}},  //   vuts, _hiro_, _تلفظ_,
  { {0x26d80087, 0x4226003b, 0x76470009, 0x00000000}},  //   _kiro_, _одав, _yajy,
  { {0x4424001d, 0x7d1a3974, 0x7c2408eb, 0x00000000}},  //   _hcm_, tuts, _acir,
  { {0xb80e007d, 0x26d80142, 0x44240022, 0x00000000}},  //   िणाम_, _miro_, _kcm_,
  { {0x7d1a093b, 0xdefa0642, 0xceb80a62, 0x00000000}},  //   ruts, _дык_, slę_,
  { {0xc0a903ec, 0x44240127, 0x200405fd, 0x00000000}},  //   _عامل_, _mcm_, mami_,
  { {0x20040f55, 0x26d80058, 0x44240082, 0x00000000}},  //   lami_, _niro_, _lcm_,
  { {0x44240082, 0x9983007f, 0x4c950a85, 0x00000000}},  //   _ocm_, vejų_, _пикс,
  { {0x030e062e, 0x20040142, 0x78780010, 0x00000000}},  //   _सिंह_, nami_, _hívj,
  { {0x7aed0020, 0x7c3d01a3, 0x20c100fa, 0x00000000}},  // [cd90] _utat, mesr, nóia_,
  { {0xd5bb0175, 0x2004033b, 0x26d80851, 0x00000000}},  //   осе_, hami_, _ciro_,
  { {0x26d80026, 0x44241091, 0xe4e40088, 0x00000000}},  //   _diro_, _bcm_, вічн,
  { {0x44241077, 0x20040042, 0x26d80089, 0x00000000}},  //   _ccm_, jami_, _eiro_,
  { {0x2004010a, 0x92950131, 0xf8b200a3, 0x00000000}},  //   dami_, надц, _תשכ_,
  { {0x26d8064c, 0x659500e3, 0x27e90035, 0x00000000}},  //   _giro_, _загу, lcan_,
  { {0x44242121, 0x6605003f, 0xf2040088, 0x00000000}},  //   _fcm_, mahk, тячо,
  { {0x40941036, 0x66050169, 0x27e9014a, 0x00000000}},  //   крыт, lahk, ncan_,
  { {0x443d0066, 0x64a400ed, 0xd426014a, 0x00000000}},  //   mew_, _раѓа, ıştı_,
  { {0x7c240638, 0x4d65003b, 0xef8209b5, 0x00000000}},  //   _scir, еков, ульп,
  { {0x50670242, 0x20040c30, 0x645b00d9, 0x00000000}},  //   _отда, bami_, _knui,
  { {0x443d1a8d, 0x20040d0a, 0x644b02a9, 0x00000000}},  //   new_, cami_, ndgi,
  { {0x660505cd, 0x7c2401f3, 0x00000000, 0x00000000}},  //   kahk, _vcir,   ,
  { {0xddc3001a, 0x6f09149f, 0x443d0133, 0x00000000}},  //   _conţ, msec, hew_,
  { {0x443d1cdc, 0x19b90088, 0x6f090cfe, 0x00000000}},  //   kew_, дуть_, lsec,
  { {0x443d11ac, 0xdb0f0010, 0x7c3d00d9, 0x00000000}},  //   jew_, őjár, cesr,
  { {0x6f090f6a, 0xa7a73975, 0xe73708d6, 0x00000000}},  // [cda0] nsec, екта_, нет_,
  { {0x2004006b, 0x98c00279, 0x645b3976, 0x00000000}},  //   zami_, ırır_, _anui,
  { {0x44240606, 0x200401aa, 0xc5d5007e, 0x00000000}},  //   _pcm_, yami_, віць,
  { {0x73e6008b, 0x44240068, 0x26d80022, 0x00000000}},  //   ходз, _qcm_, _wiro_,
  { {0x2586093f, 0x20040465, 0x66050145, 0x00000000}},  //   _bílé_, vami_, bahk,
  { {0x6f09003b, 0xfe6704e8, 0x20043977, 0x00000000}},  //   dsec, _صد_, wami_,
  { {0x20040871, 0x44240253, 0x443d0066, 0x00000000}},  //   tami_, _tcm_, bew_,
  { {0x6449002a, 0x442f0009, 0xbf34005e, 0x00000000}},  //   _gaei, cfg_, внищ,
  { {0x2004006a, 0x03a30113, 0x7c3d00f6, 0x00000000}},  //   rami_, _бито, vesr,
  { {0x20040036, 0x27e93978, 0x64622e90, 0x00000000}},  //   sami_, zcan_, štič,
  { {0x27e90163, 0x6d410016, 0x200414a6, 0x00000000}},  //   ycan_, gwla, pami_,
  { {0xdee601e0, 0x787800b9, 0x29180065, 0x00000000}},  //   _зоди, _dívk, drra_,
  { {0x9f490359, 0x5f730084, 0x7c3d00f8, 0x00000000}},  //   _það_, _ماور, resr,
  { {0x7bc40fed, 0x443d3979, 0x2bc701f5, 0x00000000}},  //   _dziu, zew_, रेगा,
  { {0x443d0173, 0x19580930, 0x38c702dc, 0x00000000}},  //   yew_, нары_, ещав,
  { {0x66050022, 0x00000000, 0x00000000, 0x00000000}},  //   wahk,   ,   ,
  { {0x27e9014a, 0x443d0066, 0x2918002d, 0x00000000}},  // [cdb0] rcan_, vew_, arra_,
  { {0x27e9397a, 0x64490089, 0xdb9c009b, 0x00000000}},  //   scan_, _saei, _מסחר,
  { {0x443d0ee1, 0x660504cb, 0xd00600a6, 0x00000000}},  //   tew_, rahk, _پل_,
  { {0x660504cb, 0x756800a1, 0x6f09004a, 0x00000000}},  //   sahk, ریقہ_, ysec,
  { {0x6283018e, 0x387e009d, 0x443d1e4c, 0x00000000}},  //   thno, être_, rew_,
  { {0x38690056, 0x443d2a04, 0x672d397b, 0x00000000}},  //   ljar_, sew_, mtaj,
  { {0x672d317c, 0x443d002b, 0x6f09397c, 0x00000000}},  //   ltaj, pew_, wsec,
  { {0xfd65001d, 0x38693632, 0x6f091a5b, 0x00000000}},  //   _thuậ, njar_, tsec,
  { {0x672d397d, 0x00000000, 0x00000000, 0x00000000}},  //   ntaj,   ,   ,
  { {0x6f09121e, 0xd01100a1, 0x63bb2e24, 0x00000000}},  //   rsec, _چلا_, _iyun,
  { {0x63bb01cf, 0x6281002b, 0xfa270055, 0x00000000}},  //   _hyun, _illo, য়াল_,
  { {0xeb9a017f, 0x3869002b, 0x672d0089, 0x00000000}},  //   дим_, jjar_, ktaj,
  { {0xc4d2007b, 0x3869274a, 0x28db006e, 0x00000000}},  //   יגט_, djar_, _मंजि,
  { {0x672d016c, 0x32070036, 0x63bb02d4, 0x00000000}},  //   dtaj, nany_, _myun,
  { {0x23e10061, 0x9d450131, 0x00000000, 0x00000000}},  //   _फलंद, _рейд,   ,
  { {0x63bb047f, 0xbb860025, 0x63b60036, 0x00000000}},  //   _oyun, _للبي, żyni,
  { {0xb8e903d7, 0x63a90065, 0x63bb00e7, 0x00000000}},  // [cdc0] _ली_, _nxen, _nyun,
  { {0xe8e00011, 0x32072daa, 0x00000000, 0x00000000}},  //   _chợt_, jany_,   ,
  { {0x63a9049a, 0x63bb0211, 0x7ae40b37, 0x00000000}},  //   _axen, _ayun, _huit,
  { {0x74130a4f, 0x7ae41aa2, 0x6281130f, 0x00000000}},  //   لوما, _kuit, _allo,
  { {0x62810065, 0x7ae400f6, 0xfe21006e, 0x00000000}},  //   _bllo, _juit, _मांस_,
  { {0x7ae402d5, 0xc7b300b6, 0x32070036, 0x00000000}},  //   _muit, _כבר_, gany_,
  { {0x4a9b007b, 0x30a600c0, 0x1a9b007b, 0x00000000}},  //   ויסג, крив, ויסע,
  { {0x62810219, 0xd0100025, 0x44221565, 0x00000000}},  //   _ello, حلة_, _øk_,
  { {0xa2e60c50, 0x78780129, 0x320704d2, 0x00000000}},  //   _розд, _cívi, bany_,
  { {0x248601d5, 0xb061021e, 0x78780181, 0x00000000}},  //   lhom_, _ääne, _dívi,
  { {0x7e7a07eb, 0xfe6f0054, 0x62980059, 0x00000000}},  //   rktp, تدي_, mivo,
  { {0x7ae4397e, 0x62980027, 0x2486002b, 0x00000000}},  //   _buit, livo, nhom_,
  { {0x7ae40666, 0xfc3f00c4, 0x00000000, 0x00000000}},  //   _cuit, reí_,   ,
  { {0x7ae401b5, 0x62980471, 0x00000000, 0x00000000}},  //   _duit, nivo,   ,
  { {0xfce3012b, 0x38690129, 0x2486233d, 0x00000000}},  //   _којо, tjar_, khom_,
  { {0x672d021e, 0x7ae4009d, 0x62980035, 0x00000000}},  //   ttaj, _fuit, hivo,
  { {0x38692d47, 0x2486002b, 0x672d0f81, 0x00000000}},  // [cdd0] rjar_, dhom_, utaj,
  { {0xd04b005f, 0x672d002d, 0x62980e3b, 0x00000000}},  //   _digə, rtaj, jivo,
  { {0xdc4300b9, 0x3869002b, 0x32070161, 0x00000000}},  //   _léčb, pjar_, vany_,
  { {0x32070046, 0x672d1220, 0x62810065, 0x00000000}},  //   wany_, ptaj, _sllo,
  { {0x32070129, 0x7d1a01a2, 0x862502fd, 0x00000000}},  //   tany_, hrts, _مکال,
  { {0x6298017b, 0x00000000, 0x00000000, 0x00000000}},  //   givo,   ,   ,
  { {0x3207067f, 0x99980035, 0x00000000, 0x00000000}},  //   rany_, merţ_,   ,
  { {0x248601ca, 0x32070036, 0xc44600a1, 0x00000000}},  //   chom_, sany_, _میمن_,
  { {0x99bf0055, 0xf076009e, 0x3207397f, 0x00000000}},  //   _আলোক, طیوں_, pany_,
  { {0x7ae40112, 0x7d1a0009, 0x6281004a, 0x00000000}},  //   _ruit, frts, _ullo,
  { {0x7ae4032c, 0x78a90059, 0x00000000, 0x00000000}},  //   _suit, čevj,   ,
  { {0x7ae4044e, 0x32050010, 0xdb0d0885, 0x00000000}},  //   _puit, _hely_, _azañ,
  { {0x7ae41468, 0x7d1a0116, 0x00000000, 0x00000000}},  //   _quit, arts,   ,
  { {0x7ae400d4, 0xbf9a00a3, 0x1e840245, 0x00000000}},  //   _vuit, _אינש, _клім,
  { {0x63be0036, 0x32050010, 0xa3d30061, 0x00000000}},  //   ępni, _mely_, हेत_,
  { {0x62980091, 0x320508d9, 0x7ae40133, 0x00000000}},  //   zivo, _lely_, _tuit,
  { {0x9b460774, 0x47c600e2, 0x00000000, 0x00000000}},  // [cde0] _صندو, убав,   ,
  { {0x4a4611a6, 0x2486002b, 0x00000000, 0x00000000}},  //   _снов, whom_,   ,
  { {0x24861f48, 0x2956005e, 0xd6cf0025, 0x00000000}},  //   thom_, _съпр, أقل_,
  { {0x7c260169, 0xb386007c, 0x2db60049, 0x00000000}},  //   ngkr, ллел, אלען_,
  { {0x62980325, 0x2486002b, 0xe29a019d, 0x00000000}},  //   tivo, rhom_, над_,
  { {0x6f1b3980, 0x2486002b, 0x55e3004c, 0x00000000}},  //   druc, shom_, _горб,
  { {0x62980733, 0x00000000, 0x00000000, 0x00000000}},  //   rivo,   ,   ,
  { {0x62980489, 0x764e14a5, 0x78a405e0, 0x00000000}},  //   sivo, _haby, nniv,
  { {0x64420051, 0x764e009d, 0x62980145, 0x00000000}},  //   meoi, _kaby, pivo,
  { {0x44260059, 0x64420051, 0x32053981, 0x00000000}},  //   lgo_, leoi, _gely_,
  { {0x527500ed, 0x44263982, 0x764e000a, 0x00000000}},  //   _туту, ogo_, _maby,
  { {0x44260bb2, 0x64420051, 0x6f1b125c, 0x00000000}},  //   ngo_, neoi, bruc,
  { {0x6f1b058b, 0x4426008e, 0xdfd20025, 0x00000000}},  //   cruc, igo_, _ايش_,
  { {0x64420051, 0x68e500b0, 0x00000000, 0x00000000}},  //   heoi, _puhd,   ,
  { {0x82770049, 0xd9180454, 0x00000000, 0x00000000}},  //   נעלע_, льт_,   ,
  { {0x6d4a0066, 0x57f50088, 0x6f0207a3, 0x00000000}},  //   _isfa, рпат, _kwoc,
  { {0x6d5810f7, 0x6442002a, 0x66cb1a6f, 0x00000000}},  // [cdf0] _hrva, deoi, yükd,
  { {0x44260046, 0x6d580213, 0xe4e70088, 0x00000000}},  //   ego_, _krva, гідн,
  { {0x290c2688, 0x320508d0, 0x27e6012d, 0x00000000}},  //   ádat_, _rely_, žona_,
  { {0x442606b1, 0xd5b80088, 0x6f020036, 0x00000000}},  //   ggo_, усу_, _owoc,
  { {0xd5af009c, 0x7680014a, 0x44290089, 0x00000000}},  //   _کہا_, _köyl, ļa_,
  { {0x442602f5, 0x44293983, 0x764e058b, 0x00000000}},  //   ago_, ża_, _gaby,
  { {0x201900c4, 0x272f005d, 0xfa78009b, 0x00000000}},  //   ósio_, lün_, רעות_,
  { {0x69c80036, 0x764e0036, 0x64420048, 0x00000000}},  //   żdeg, _zaby, ceoi,
  { {0x6d580004, 0x8fa5008b, 0x272f01f6, 0x00000000}},  //   _arva, рапе, nün_,
  { {0x6f1b0207, 0x78a40059, 0x2ca9006c, 0x00000000}},  //   rruc, zniv, _ajad_,
  { {0x7e54007e, 0x26c100fa, 0x00000000, 0x00000000}},  //   стыц, ilho_,   ,
  { {0x6d580e00, 0x6f1b010f, 0x673d1a84, 0x00000000}},  //   _drva, pruc, _opsj,
  { {0x6d58049b, 0x7680011f, 0x9848005f, 0x00000000}},  //   _erva, _böyl, xşı_,
  { {0x44263984, 0x660700b9, 0x8f1a00a0, 0x00000000}},  //   zgo_, _nejk, _יונת,
  { {0xd946003b, 0x44260544, 0xc8960098, 0x00000000}},  //   шеви, ygo_, арањ,
  { {0x7d56009b, 0x78a407c8, 0x7d1c0f3b, 0x00000000}},  //   _כיצד_, univ, árse,
  { {0x753c0046, 0x272f047f, 0x78a40a6b, 0x00000000}},  // [ce00] _sprz, gün_, rniv,
  { {0x9848038c, 0x290c0051, 0x7680006b, 0x00000000}},  //   rşı_, ádas_, _göyl,
  { {0x6442002a, 0x44260085, 0x92020089, 0x00000000}},  //   teoi, tgo_, šāka,
  { {0x44260006, 0x58d300e2, 0x764e0045, 0x00000000}},  //   ugo_, _моќт, _waby,
  { {0x44260219, 0x6442002a, 0x6607035f, 0x00000000}},  //   rgo_, reoi, _fejk,
  { {0x44260966, 0x8b57007b, 0x64423236, 0x00000000}},  //   sgo_, יינס_, seoi,
  { {0x753c0036, 0xa50701ab, 0x00000000, 0x00000000}},  //   _uprz, _веса_,   ,
  { {0x6f0201aa, 0x64a60264, 0x9f4f008e, 0x00000000}},  //   _pwoc, _таба, _negó_,
  { {0x08770049, 0x00000000, 0x00000000, 0x00000000}},  //   שעפט_,   ,   ,
  { {0x6d581032, 0x78a90c1e, 0xd737009b, 0x00000000}},  //   _prva, čevi, סטית_,
  { {0x272f005d, 0x395a00d9, 0x00000000, 0x00000000}},  //   zün_, _nrps_,   ,
  { {0x7680047f, 0xb17b007b, 0xc19b00b6, 0x00000000}},  //   _söyl, _שטאר, _בשבי,
  { {0xdef407d0, 0x9fe50379, 0xd00f0380, 0x00000000}},  //   _уплы, _اسمه, _آله_,
  { {0x8af0005f, 0x6d580161, 0x3862000a, 0x00000000}},  //   _irəl, _trva, _ankr_,
  { {0x6d580039, 0xf807005e, 0xdd93007e, 0x00000000}},  //   _urva, ичан, _машы,
  { {0x272f038c, 0x00000000, 0x00000000, 0x00000000}},  //   tün_,   ,   ,
  { {0x7c2d006b, 0x35e70088, 0x395a00d9, 0x00000000}},  // [ce10] _icar, ацев, _erps_,
  { {0xbebd0ebc, 0xc61f0044, 0x272f3985, 0x00000000}},  //   ltūr, ন্না_, rün_,
  { {0x19ab00ed, 0xf3f9005e, 0x66073986, 0x00000000}},  //   _штип_, гнеш_, _vejk,
  { {0xdd86009c, 0xbebd0ebc, 0xe4a40088, 0x00000000}},  //   _ہو_, ntūr, орчо,
  { {0x66070065, 0x00000000, 0x00000000, 0x00000000}},  //   _tejk,   ,   ,
  { {0xa5f825aa, 0xa22900a5, 0xdd8603e6, 0x00000000}},  //   _веру_, ужка_, _فو_,
  { {0xbebd0a5c, 0x7c2d09fc, 0x9877006b, 0x00000000}},  //   ktūr, _ocar, lçı_,
  { {0xfbdf00c4, 0xd7f80082, 0x00000000, 0x00000000}},  //   ndês_, _đăk_,   ,
  { {0x442d00ab, 0x9877006b, 0x249d005b, 0x00000000}},  //   _ice_, nçı_, miwm_,
  { {0xe1f00a4f, 0x7c2d0149, 0x628a010f, 0x00000000}},  //   _قسم_, _acar, chfo,
  { {0xa3d3001c, 0xc212034e, 0x7af6000c, 0x00000000}},  //   हेर_, _זהב_, _styt,
  { {0xcb6a05f6, 0x249d0016, 0x9877005d, 0x00000000}},  //   гаме_, niwm_, kçı_,
  { {0x442d0007, 0x929d0036, 0xc61f0044, 0x00000000}},  //   _mce_, _zwła, ন্যা_,
  { {0x7c2d009d, 0x00000000, 0x00000000, 0x00000000}},  //   _ecar,   ,   ,
  { {0xada22194, 0xbcf50647, 0x7e7c01a2, 0x00000000}},  //   _нашл, _استغ, örpe,
  { {0x442d24ac, 0x7c2d0051, 0xf825013f, 0x00000000}},  //   _nce_, _gcar, şünə_,
  { {0xa6860741, 0x249d0016, 0x00000000, 0x00000000}},  // [ce20] блад, diwm_,   ,
  { {0x49ba01b7, 0x7c2d0146, 0x7ebd00d4, 0x00000000}},  //   _ماجد_, _zcar, cèpt,
  { {0x64a60088, 0x09d60044, 0xfc3f0048, 0x00000000}},  //   бажа, _ত্রা, inín_,
  { {0xa50708f3, 0x186a051f, 0x442d11c8, 0x00000000}},  //   сеца_, _сами_, _cce_,
  { {0x442d088a, 0x628a0019, 0x672404f3, 0x00000000}},  //   _dce_, thfo, quij,
  { {0x4616026c, 0x442d0095, 0xbb3b0049, 0x00000000}},  //   _دوسر, _ece_, רעסי,
  { {0x442d00b4, 0x00000000, 0x00000000, 0x00000000}},  //   _fce_,   ,   ,
  { {0x442d0288, 0x2b4000ca, 0x00000000, 0x00000000}},  //   _gce_, _opic_,   ,
  { {0x93aa00a1, 0x3f820861, 0x00000000, 0x00000000}},  //   _صارف_, áku_,   ,
  { {0x7c2d0198, 0x6e6602b8, 0x00000000, 0x00000000}},  //   _scar, стиж,   ,
  { {0xb6bb007b, 0x2b4000f6, 0x6288002d, 0x00000000}},  //   רציי, _apic_, _ildo,
  { {0x69c12f68, 0x320e0093, 0x00000000, 0x00000000}},  //   ülem, lafy_,   ,
  { {0x291100b4, 0x00000000, 0x00000000, 0x00000000}},  //   wsza_,   ,   ,
  { {0xa3da007d, 0x00000000, 0x00000000, 0x00000000}},  //   डेय_,   ,   ,
  { {0x628800f6, 0xc61f0044, 0x2b400133, 0x00000000}},  //   _mldo, ন্ডা_, _epic_,
  { {0xc4c4024a, 0x9877005d, 0xdca401fc, 0x00000000}},  //   _سے_, tçı_, _наји,
  { {0x29110047, 0xe730006d, 0x442d0606, 0x00000000}},  // [ce30] ssza_, فصل_, _rce_,
  { {0x7afd0056, 0xf7700426, 0x7bcd0089, 0x00000000}},  //   mpst, راق_, _izau,
  { {0x442d00d4, 0x7afd1903, 0x2cfb0049, 0x00000000}},  //   _pce_, lpst, ָלדא,
  { {0x6288007f, 0xccf30049, 0x7afd00b5, 0x00000000}},  //   _aldo, לכע_, opst,
  { {0xa3d3007d, 0xe3b30025, 0xa2c50061, 0x00000000}},  //   हें_, أرض_, ितल्,
  { {0xd9fb007d, 0x00000000, 0x00000000, 0x00000000}},  //   ्रित_,   ,   ,
  { {0x442d00c4, 0xdcf50089, 0xb1450088, 0x00000000}},  //   _tce_, ēcīg, інил,
  { {0xef190373, 0x62882986, 0x442d00f6, 0x00000000}},  //   ами_, _eldo, _uce_,
  { {0xd9fb0061, 0x70760025, 0xa4d40088, 0x00000000}},  //   ्रात_, تميز_, _хоті,
  { {0x273b001a, 0xee360b21, 0x00000000, 0x00000000}},  //   mână_, онь_,   ,
  { {0xf8bf0e24, 0x8c460088, 0xd0190380, 0x00000000}},  //   _oké_, оене, _نقاش_,
  { {0x2d8b0046, 0x7d1c0010, 0x2247035a, 0x00000000}},  //   ące_, ársa, lenk_,
  { {0x2d8307a0, 0x25c6007d, 0x10d80025, 0x00000000}},  //   šje_, _वर्ण, _ابلغ_,
  { {0xc61f0055, 0xefb30014, 0xf8bf0142, 0x00000000}},  //   ন্তা_, _ویژگ, _aké_,
  { {0x38c801ef, 0x7bcd002d, 0x7afd00d9, 0x00000000}},  //   ماری_, _ezau, apst,
  { {0x22471265, 0x00000000, 0x00000000, 0x00000000}},  //   henk_,   ,   ,
  { {0xe1ff0011, 0x628300d9, 0x2b4000f6, 0x00000000}},  // [ce40] _đón_, kkno, _upic_,
  { {0xd6260025, 0x00000000, 0x00000000, 0x00000000}},  //   تعري,   ,   ,
  { {0x22470112, 0xa96a3370, 0x44f60014, 0x00000000}},  //   denk_, _тина_, زساز,
  { {0x657e0085, 0x629a0087, 0x6abc2fe4, 0x00000000}},  //   ryph, _smto, lorf,
  { {0x133900a1, 0x926a017f, 0x657e0068, 0x00000000}},  //   متوں_, ирка_, syph,
  { {0x27343987, 0xdce900b9, 0xda0a007d, 0x00000000}},  //   män_, íněn, वरित_,
  { {0x273400b0, 0xe57a003b, 0x67360205, 0x00000000}},  //   län_, _тзв_, ltyj,
  { {0xb97b0476, 0xc61f0044, 0xf8bf0026, 0x00000000}},  //   ינצי, ন্দা_, _xké_,
  { {0xeeaa0088, 0x03a30088, 0x228b0056, 0x00000000}},  //   иток_, _жито, _søke_,
  { {0x69c1225a, 0x67360006, 0x42230e82, 0x00000000}},  //   ülek, ityj, _одув,
  { {0x2734021e, 0xc5f30104, 0x7ebd01aa, 0x00000000}},  //   hän_, ודת_, tèpr,
  { {0xdee6003b, 0x320c00e0, 0x656800d4, 0x00000000}},  //   _доди, _hedy_, _àdhu,
  { {0x2734021e, 0x6abc068f, 0x320c0027, 0x00000000}},  //   jän_, forf, _kedy_,
  { {0x2734021e, 0x7afd3988, 0xfc3f013e, 0x00000000}},  //   dän_, rpst, mním_,
  { {0xfc3f01dc, 0x00000000, 0x00000000, 0x00000000}},  //   lním_,   ,   ,
  { {0x7afd01c9, 0x5b153989, 0x3aef014a, 0x00000000}},  //   ppst, _емит, _tüp_,
  { {0xfc3f013e, 0x6283013e, 0x00000000, 0x00000000}},  // [ce50] nním_, ykno,   ,
  { {0xeb9f0374, 0x00000000, 0x00000000, 0x00000000}},  //   rbød_,   ,   ,
  { {0xea000011, 0x7aed0051, 0x00000000, 0x00000000}},  //   _hiếu_, _huat,   ,
  { {0xe3b300a2, 0x7aed16da, 0x78a900ca, 0x00000000}},  //   ورش_, _kuat, čevs,
  { {0xeab000a2, 0x1304007e, 0x6d5e11ae, 0x00000000}},  //   _سعی_, дзім, _špal,
  { {0x09df0055, 0xe1f100a6, 0xfc3f0224, 0x00000000}},  //   _ব্যা, رست_, dním_,
  { {0x91e21e03, 0x7aed0fff, 0x62830168, 0x00000000}},  //   ноше, _luat, rkno,
  { {0x7ae50004, 0x628300b9, 0x22470173, 0x00000000}},  //   _liht, skno, senk_,
  { {0x60060147, 0x443f020c, 0x66d00a3c, 0x00000000}},  //   чным_, _ibu_, säke,
  { {0x76550428, 0x320c0abb, 0x00000000, 0x00000000}},  //   _jazy, _gedy_,   ,
  { {0x69c50c7b, 0x7f42009d, 0x7655007f, 0x00000000}},  //   _nyhe, _epoq, _mazy,
  { {0x7aed231c, 0x7655016b, 0xfc3f00b9, 0x00000000}},  //   _buat, _lazy, bním_,
  { {0x7aed0211, 0x6abc0af1, 0x443f00e7, 0x00000000}},  //   _cuat, torf, _mbu_,
  { {0x27343987, 0x7aed398a, 0x76550024, 0x00000000}},  //   vän_, _duat, _nazy,
  { {0x186a0ffa, 0x6d460036, 0x443f0036, 0x00000000}},  //   бави_, łkar, _obu_,
  { {0x38660211, 0x27340ba4, 0x7aed161f, 0x00000000}},  //   ñor_, tän_, _fuat,
  { {0x7aed0211, 0xf743072b, 0xa68600ed, 0x00000000}},  // [ce60] _guat, нето, плад,
  { {0x443f033b, 0x27340a2b, 0x4cd10044, 0x00000000}},  //   _abu_, rän_, _সংযু,
  { {0x273400b0, 0x67360ecb, 0x20c10048, 0x00000000}},  //   sän_, styj, nóis_,
  { {0x443f033b, 0x76550146, 0xd4990088, 0x00000000}},  //   _cbu_, _eazy, орі_,
  { {0x443f0190, 0x833a007c, 0x2a7a00ca, 0x00000000}},  //   _dbu_, счет_, _kopb_,
  { {0xfc3f0224, 0x67240066, 0x6d432315, 0x00000000}},  //   vním_, mrij, _opna,
  { {0x1543012b, 0x672400bb, 0x443f0544, 0x00000000}},  //   _перм, lrij, _fbu_,
  { {0xfc3f00b9, 0x443f0145, 0x7e7807f9, 0x00000000}},  //   tním_, _gbu_, _sovp,
  { {0x320c0224, 0x7e7801d9, 0x2bde0164, 0x00000000}},  //   _tedy_, _povp, नेमा,
  { {0x660e001e, 0x2486398b, 0xfc3f00b9, 0x00000000}},  //   _jebk, lkom_, rním_,
  { {0x672402ae, 0x7aed0149, 0x7ae50b2e, 0x00000000}},  //   hrij, _suat, _riht,
  { {0x68e6004f, 0x7ae501c2, 0x67240213, 0x00000000}},  //   _nikd, _siht, krij,
  { {0x60c2002b, 0xfc3f01ca, 0x672400d9, 0x00000000}},  //   _ikom, lník_, jrij,
  { {0x672402ae, 0xdfa50054, 0x00000000, 0x00000000}},  //   drij, _تحمي,   ,
  { {0x7ae501c2, 0x60c20066, 0xfc3f0027, 0x00000000}},  //   _viht, _kkom, nník_,
  { {0x3ebe0010, 0x672401ee, 0xdd8e00a1, 0x00000000}},  //   lott_, frij, _لوڈ_,
  { {0x6724398c, 0x4735008b, 0x7ae5006c, 0x00000000}},  // [ce70] grij, ьнас, _tiht,
  { {0xcb1200b6, 0x20c10051, 0x443f398d, 0x00000000}},  //   _שלי_, nóir_, _sbu_,
  { {0x60c2047c, 0x63a41a13, 0x6d5e0253, 0x00000000}},  //   _okom, úinn, _špaj,
  { {0x60c20066, 0x20c10051, 0x986500a1, 0x00000000}},  //   _nkom, hóir_, _تیرے_,
  { {0x3ebe398e, 0x78ad00bb, 0x00000000, 0x00000000}},  //   kott_, mnav,   ,
  { {0x60c20065, 0x78ad398f, 0xa1c509e6, 0x00000000}},  //   _akom, lnav, мблд,
  { {0x3ebe2c71, 0x20c10051, 0x00000000, 0x00000000}},  //   dott_, dóir_,   ,
  { {0x78ad0004, 0x443f0061, 0x24863190, 0x00000000}},  //   nnav, _ubu_, ckom_,
  { {0x66d00510, 0x66cb005a, 0x644b2b0e, 0x00000000}},  //   läka, yükl, megi,
  { {0x645900b5, 0x20c10051, 0x3ebe0010, 0x00000000}},  //   ldwi, góir_, gott_,
  { {0x248d0007, 0x67243990, 0x645901c3, 0x00000000}},  //   _klem_, zrij, odwi,
  { {0x6459010f, 0x644b0016, 0x442f0145, 0x00000000}},  //   ndwi, negi, ngg_,
  { {0xeb970001, 0x3ebe04e7, 0xee2e00ed, 0x00000000}},  //   дия_, bott_, _ин_,
  { {0x60c92fd8, 0x67243991, 0x78ad0009, 0x00000000}},  //   llem, vrij, enav,
  { {0xb9b5005e, 0x644b1f34, 0x200f0022, 0x00000000}},  //   естъ, kegi, _kegi_,
  { {0x67243992, 0x7680021e, 0x60c93993, 0x00000000}},  //   trij, _löyt, nlem,
  { {0xe7370517, 0x07a3012b, 0x644b114f, 0x00000000}},  // [ce80] мет_, ватн, degi,
  { {0x67243994, 0x200f05f7, 0x2d81006c, 0x00000000}},  //   rrij, _legi_, _ühes_,
  { {0x60c9011f, 0x2486049c, 0x78ad0d4d, 0x00000000}},  //   klem, tkom_, bnav,
  { {0x660e3184, 0x3ebe0047, 0x67240119, 0x00000000}},  //   _webk, zott_, prij,
  { {0x24860007, 0x60c90b16, 0x228b00ea, 0x00000000}},  //   rkom_, dlem, _søka_,
  { {0x2486049c, 0x60c20036, 0x248d0010, 0x00000000}},  //   skom_, _skom, _elem_,
  { {0x644b01a3, 0x200f002d, 0xe29700ed, 0x00000000}},  //   begi, _begi_, ќај_,
  { {0x21200746, 0x60c906f0, 0x30a30783, 0x00000000}},  //   čih_, glem, крыв,
  { {0x3ebe0047, 0x200f000c, 0x20c10051, 0x00000000}},  //   tott_, _degi_, tóir_,
  { {0x2ca03995, 0x60c900f4, 0x78ad0340, 0x00000000}},  //   _amid_, alem, znav,
  { {0x3ebe0039, 0x20c10051, 0x60c2002b, 0x00000000}},  //   rott_, róir_, _tkom,
  { {0x10160167, 0x60c20020, 0x60c90919, 0x00000000}},  //   _آباد, _ukom, clem,
  { {0x3ebe0010, 0x78ad1a2d, 0x60c03996, 0x00000000}},  //   pott_, vnav, momm,
  { {0x60c00010, 0x00000000, 0x00000000, 0x00000000}},  //   lomm,   ,   ,
  { {0x78ad00bb, 0x442f2b89, 0x768000b0, 0x00000000}},  //   tnav, ygg_, _löys,
  { {0x58d407ca, 0x60c0010f, 0x31570049, 0x00000000}},  //   вост, nomm, וילן_,
  { {0x78ad05d5, 0x442f021f, 0x644b000c, 0x00000000}},  // [ce90] rnav, vgg_, vegi,
  { {0x644b01b5, 0x78ad0056, 0x60c918cf, 0x00000000}},  //   wegi, snav, zlem,
  { {0x644b022b, 0x60c0001f, 0x78ad3997, 0x00000000}},  //   tegi, komm, pnav,
  { {0x9475007a, 0x3f840006, 0x7d0d00b4, 0x00000000}},  //   رگزا, kymu_, _łask,
  { {0x645900b5, 0xa3da0164, 0x60c005d5, 0x00000000}},  //   rdwi, डेल_, domm,
  { {0x200f0127, 0x644b002d, 0x672d00e7, 0x00000000}},  //   _segi_, segi, muaj,
  { {0x349524dd, 0x60c91462, 0x200f01a3, 0x00000000}},  //   _завр, tlem, _pegi_,
  { {0x45d40057, 0x249f020c, 0x60c9009d, 0x00000000}},  //   _росс, _umum_, ulem,
  { {0x60c90563, 0x200f3998, 0x00000000, 0x00000000}},  //   rlem, _vegi_,   ,
  { {0xfe710054, 0x60c9014a, 0x2ca0004e, 0x00000000}},  //   ادة_, slem, _smid_,
  { {0x200f006c, 0x2ca00133, 0x60c000bb, 0x00000000}},  //   _tegi_, _pmid_, bomm,
  { {0x60c0030a, 0x26c1008a, 0x672d0bd5, 0x00000000}},  //   comm, hoho_, kuaj,
  { {0xdd8e0167, 0x6d5c0039, 0x26c10161, 0x00000000}},  //   لوی_, årar, koho_,
  { {0x3f7a0049, 0x291e0091, 0x00000000, 0x00000000}},  //   _מאנס, štam_,   ,
  { {0xd94300aa, 0x78a408b2, 0x3ea900b9, 0x00000000}},  //   лери, tiiv, čitě_,
  { {0x33260146, 0x3ea5010e, 0x00000000, 0x00000000}},  //   yrox_, lilt_,   ,
  { {0x672d1f7c, 0x29183999, 0xdbd2006c, 0x00000000}},  // [cea0] guaj, ssra_, nüüm,
  { {0x78bb1435, 0xb7d7023c, 0x3ea5006c, 0x00000000}},  //   čuva, رولا_, nilt_,
  { {0x1a9b00bd, 0x69c1399a, 0x4a9b0049, 0x00000000}},  //   _זייע, ület, _זייג,
  { {0x3326399b, 0x3ea513d8, 0xb4aa0061, 0x00000000}},  //   trox_, hilt_, गचे_,
  { {0x3ea50039, 0x93f3007e, 0x00000000, 0x00000000}},  //   kilt_, упіц,   ,
  { {0x2d850190, 0x3326004a, 0xd1300025, 0x00000000}},  //   kyle_, rrox_, لمت_,
  { {0xd5b2031d, 0x60c001d6, 0x3ea5010e, 0x00000000}},  //   _صفر_, tomm, dilt_,
  { {0x653b0049, 0x33260133, 0x3f840006, 0x00000000}},  //   _מעלד, prox_, tymu_,
  { {0x60c00056, 0x4ea6005c, 0x3ce90082, 0x00000000}},  //   romm, ерна, _riav_,
  { {0x60c026d8, 0xaca700a1, 0x3ea5399c, 0x00000000}},  //   somm, کھتے_, gilt_,
  { {0xc693009b, 0x291e0091, 0x4c95025f, 0x00000000}},  //   ראת_, štaj_, винс,
  { {0xe1ff0011, 0x66cb0d88, 0x00000000, 0x00000000}},  //   _đói_, tükk,   ,
  { {0x9f340088, 0xab8701ff, 0x3ea501bf, 0x00000000}},  //   _релі, хунк, bilt_,
  { {0xdfcf0025, 0x628a00ea, 0x2d85009d, 0x00000000}},  //   _ايه_, nkfo, byle_,
  { {0x3cea03d7, 0x9e6500a1, 0x2d850085, 0x00000000}},  //   _घंटे_, _جانن, cyle_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66d00039, 0x628a00ea, 0x7d1a01c5, 0x00000000}},  // [ceb0] räkn, kkfo, lsts,
  { {0xc13b0011, 0x672d0065, 0xd3710014, 0x00000000}},  //   _cướp_, ruaj, یها_,
  { {0x09df0055, 0x7d1a010f, 0x26c108c1, 0x00000000}},  //   _ব্রা, nsts, roho_,
  { {0xe4e40106, 0x2bde0309, 0x6aa700b5, 0x00000000}},  //   гічн, नेवा, lijf,
  { {0x672d0065, 0x69d80142, 0x00000000, 0x00000000}},  //   quaj, _úver,   ,
  { {0x7d1a0292, 0x59d80061, 0x00000000, 0x00000000}},  //   ksts, णेकर,   ,
  { {0x45d4005e, 0xd49b1deb, 0x00000000, 0x00000000}},  //   _борс, _ера_,   ,
  { {0x42d10055, 0xa4d50099, 0x44f701df, 0x00000000}},  //   াদেশ, _робі, _iç_,
  { {0x3ea50056, 0x91f50082, 0x3f8b0142, 0x00000000}},  //   tilt_, _các, ácu_,
  { {0x2d850011, 0x4d6502e9, 0x81e60044, 0x00000000}},  //   tyle_, вков, পড়_,
  { {0xc5f20104, 0x7d1a0089, 0x3ea5006c, 0x00000000}},  //   ידי_, gsts, rilt_,
  { {0xdca60c96, 0x3ea5010e, 0x00000000, 0x00000000}},  //   тами, silt_,   ,
  { {0x7d1a0c7d, 0x3ea5399d, 0x2901399e, 0x00000000}},  //   asts, pilt_, _atha_,
  { {0xc33201ce, 0x66d000b0, 0x6f1b01a2, 0x00000000}},  //   בוך_, väko, msuc,
  { {0x6f1b01a2, 0x18a600e2, 0x00000000, 0x00000000}},  //   lsuc, вавм,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1b010f, 0x69c1014a, 0x44f701df, 0x00000000}},  // [cec0] nsuc, üler, _aç_,
  { {0x6aa700bb, 0x06b50044, 0x66170032, 0x00000000}},  //   cijf, _জীবি, gaxk,
  { {0xd82600ed, 0x6f1b010f, 0x98ad014a, 0x00000000}},  //   _идни, hsuc, _çoğu_,
  { {0x2b490006, 0xe475007e, 0x00000000, 0x00000000}},  //   _ypac_, лучэ,   ,
  { {0x26d81ad0, 0xe3b20070, 0xe29a01ee, 0x00000000}},  //   _thro_, جرا_, мад_,
  { {0x6603041f, 0x7d1a0146, 0x00000000, 0x00000000}},  //   _впра, ysts,   ,
  { {0x628a1205, 0x91f50082, 0x00000000, 0x00000000}},  //   rkfo, _sác,   ,
  { {0x765c023a, 0x51830888, 0x8557009b, 0x00000000}},  //   _hary, руша, _בשלב_,
  { {0x765c020c, 0x6d4d012d, 0x2f13007e, 0x00000000}},  //   _kary, _ćaaa, адыё,
  { {0xd33700b3, 0x66cb006c, 0x00000000, 0x00000000}},  //   _ברמה_, tüki,   ,
  { {0x765c399f, 0xf297009b, 0x91e60920, 0x00000000}},  //   _mary, _שכבר_, _роже,
  { {0x4fc602b0, 0x7d1a054e, 0x64420a65, 0x00000000}},  //   _исла, rsts, nfoi,
  { {0x7d1a01a2, 0x2bd80061, 0x98a30036, 0x00000000}},  //   ssts, _ठरणा, nują_,
  { {0x765c010a, 0x6f0201f3, 0xbea301ee, 0x00000000}},  //   _nary, _itoc, _качк,
  { {0x63be0036, 0x3ed90049, 0x6aa700bb, 0x00000000}},  //   ępny, _אַקא, rijf,
  { {0x6d580006, 0x2aad0243, 0x98a30036, 0x00000000}},  //   _isva, džbe_, kują_,
  { {0x765c049a, 0xd7d5003b, 0x00000000, 0x00000000}},  // [ced0] _bary, ужањ,   ,
  { {0xba55098c, 0x765c005b, 0xa507007e, 0x00000000}},  //   _свој, _cary, вядл,
  { {0x765c010a, 0x645b02d0, 0x00000000, 0x00000000}},  //   _dary, _paui,   ,
  { {0x6f0239a0, 0xa31901ab, 0x00000000, 0x00000000}},  //   _otoc, ежду_,   ,
  { {0x4c9c00a3, 0x6d5d0089, 0x645b00d9, 0x00000000}},  //   ובאו, āsai, _vaui,
  { {0x6d4a0030, 0x6d580091, 0xfb160049, 0x00000000}},  //   _opfa, _osva, אַקט_,
  { {0x81cb0055, 0xc6920049, 0x6f020016, 0x00000000}},  //   রেন_, _פאל_, _atoc,
  { {0x661539a1, 0x30190025, 0x765c271d, 0x00000000}},  //   _hezk, رتبة_, _zary,
  { {0x6d58016c, 0x6615002d, 0x765c0045, 0x00000000}},  //   _asva, _kezk, _yary,
  { {0x6f1b001f, 0x291e007f, 0x00000000, 0x00000000}},  //   rsuc, štai_,   ,
  { {0x273d0011, 0xd0110025, 0x6f1b01a2, 0x00000000}},  //   hìn_, _هلا_, ssuc,
  { {0x7bc10279, 0x66150032, 0x00000000, 0x00000000}},  //   ğlun, _lezk,   ,
  { {0x6281149d, 0x4fa401fb, 0x6d5e00b9, 0x00000000}},  //   _kolo, _київ, _špat,
  { {0x62810145, 0x6615013e, 0xc3320049, 0x00000000}},  //   _jolo, _nezk, זוך_,
  { {0x62810066, 0x98a30036, 0x291e39a2, 0x00000000}},  //   _molo, zują_, éta_,
  { {0x48c40055, 0x63bb005f, 0x88e6025f, 0x00000000}},  //   ্দ্র, _oxun, ужбе,
  { {0x7c24002a, 0x66151712, 0x99980006, 0x00000000}},  // [cee0] _idir, _bezk, terų_,
  { {0xa68301c0, 0x62810052, 0x00000000, 0x00000000}},  //   блуд, _nolo,   ,
  { {0x765c01aa, 0x63bb006b, 0xd0190036, 0x00000000}},  //   _vary, _axun, kań_,
  { {0xa85602a8, 0x98a300b4, 0xb4c001f5, 0x00000000}},  //   _стој, tują_, ुते_,
  { {0x386039a3, 0x62810207, 0x644200f4, 0x00000000}},  //   mdir_, _bolo, rfoi,
  { {0x628139a4, 0x386039a5, 0xc69200a1, 0x00000000}},  //   _colo, ldir_, _اِس_,
  { {0x628101d9, 0x6f020aa4, 0x98a30036, 0x00000000}},  //   _dolo, _stoc, sują_,
  { {0x3860009f, 0xf99300b3, 0x3e8100b9, 0x00000000}},  //   ndir_, מרו_, _létě_,
  { {0x6281000d, 0x44240082, 0x38600085, 0x00000000}},  //   _folo, _idm_, idir_,
  { {0xa2e61ae1, 0x62810127, 0x7c240145, 0x00000000}},  //   _созд, _golo, _adir,
  { {0x3860005f, 0x64bc01ee, 0x44240145, 0x00000000}},  //   kdir_, pčid, _kdm_,
  { {0xd00f0447, 0xfbcd0044, 0x00000000, 0x00000000}},  //   _فلم_, রেফত,   ,
  { {0x386039a6, 0x69c0014a, 0x7c240016, 0x00000000}},  //   ddir_, şmel, _ddir,
  { {0x8f9b0476, 0x7c2402b9, 0x6d5800e7, 0x00000000}},  //   _אידי, _edir, _tsva,
  { {0x442413e1, 0x6d580107, 0x661500ca, 0x00000000}},  //   _odm_, _usva, _rezk,
  { {0x69470091, 0x38601ce1, 0x00000000, 0x00000000}},  //   jčeš, gdir_,   ,
  { {0x3a3a00f6, 0x2eee0068, 0x00000000, 0x00000000}},  // [cef0] _fcpp_, _kiff_,   ,
  { {0x442439a7, 0x386006c2, 0xd5bb132e, 0x00000000}},  //   _adm_, adir_, нсе_,
  { {0x3860006b, 0x628110d3, 0xf48700e2, 0x00000000}},  //   bdir_, _rolo, лудн,
  { {0x44240bd6, 0x297a01ce, 0xa7fb008e, 0x00000000}},  //   _cdm_, _סטרא, _bañe,
  { {0x62810428, 0x862500a1, 0xa7fb008e, 0x00000000}},  //   _polo, _نکال, _cañe,
  { {0xe8e0001d, 0x8afc0049, 0xd0190036, 0x00000000}},  //   _đức_, עהוי, wań_,
  { {0x62811733, 0x44240030, 0xd0190036, 0x00000000}},  //   _volo, _fdm_, tań_,
  { {0x5f75023c, 0x2eee005b, 0x628100b4, 0x00000000}},  //   لاخر, _aiff_, _wolo,
  { {0x62810653, 0xef160783, 0x98b80089, 0x00000000}},  //   _tolo, амы_, ntrā_,
  { {0x99980047, 0x6298010f, 0x3860005d, 0x00000000}},  //   zerű_, chvo, zdir_,
  { {0x2eee05d8, 0x672d0161, 0x3860019a, 0x00000000}},  //   _diff_, hraj, ydir_,
  { {0x672d0059, 0x64bc06ac, 0x68ef005b, 0x00000000}},  //   kraj, mčic, _nicd,
  { {0x6449002a, 0x5f770151, 0x7ff41095, 0x00000000}},  //   _mbei, _حاضر, _اسما,
  { {0x6f09008e, 0x8f9a009b, 0xb69b001a, 0x00000000}},  //   mpec, _ביני, _stân,
  { {0x09e602b0, 0x3860006b, 0x64bc016e, 0x00000000}},  //   ровн, tdir_, nčic,
  { {0xf7720054, 0x6d410039, 0x7c240026, 0x00000000}},  //   ياء_, mtla, _udir,
  { {0x386001f6, 0x672d0059, 0xdd9100a1, 0x00000000}},  // [cf00] rdir_, graj, _دوں_,
  { {0x644939a8, 0x4424023a, 0xaa46003b, 0x00000000}},  //   _abei, _sdm_, _теол,
  { {0x6d4139a9, 0x64bc10ec, 0x4424175f, 0x00000000}},  //   ntla, jčic, _pdm_,
  { {0x0446058f, 0x6d410270, 0x672d0091, 0x00000000}},  //   редн, itla, braj,
  { {0x68e4006c, 0x6d41006c, 0x44240068, 0x00000000}},  //   mmid, htla, _vdm_,
  { {0xd36f0025, 0x68e4006c, 0x6d41006b, 0x00000000}},  //   بهه_, lmid, ktla,
  { {0x5bd30201, 0x6493047f, 0xddc80036, 0x00000000}},  //   _सर्व, _için, zedł,
  { {0x8f4602f0, 0x68e40116, 0x78b60232, 0x00000000}},  //   аход, nmid, nnyv,
  { {0xa067025f, 0x6d410036, 0x749b0097, 0x00000000}},  //   рања_, etla, _סימפ,
  { {0x26c70091, 0x68e404fb, 0x3ea70087, 0x00000000}},  //   čnog_, hmid, _cmnt_,
  { {0x85f70049, 0x24840e42, 0xac1901ee, 0x00000000}},  //   יציע_, _komm_, лону_,
  { {0x2366016c, 0x2aad01ed, 0x98a300b4, 0x00000000}},  //   ovoj_, džba_, buję_,
  { {0x2eee00ea, 0xa3da0061, 0x6d4139aa, 0x00000000}},  //   _tiff_, डेच_, atla,
  { {0x68e4006c, 0xadbc007e, 0x248400d9, 0x00000000}},  //   emid, _палi, _lomm_,
  { {0x2bd302fb, 0x3eac0190, 0xddc8012d, 0x00000000}},  //   _सरका, midt_, ljdž,
  { {0x8894007c, 0x1410013d, 0x7d7b0049, 0x00000000}},  //   оисх, ारोह_, _ינוו,
  { {0xaa890151, 0x68ef0279, 0x2d8c05a6, 0x00000000}},  // [cf10] _منظم_, _vicd, lyde_,
  { {0x672d022b, 0x68e4010e, 0x64491e28, 0x00000000}},  //   rraj, amid, _sbei,
  { {0x98b80089, 0xbdf80044, 0x672d01b1, 0x00000000}},  //   strā_, _আজাদ_, sraj,
  { {0x24840d46, 0xb4b10061, 0x00000000, 0x00000000}},  //   _comm_, टचे_,   ,
  { {0xe3b0006d, 0x08760049, 0x6f090133, 0x00000000}},  //   وره_, _הערט_, xpec,
  { {0x78ad0006, 0x6d41006b, 0x2fcf0479, 0x00000000}},  //   liav, ytla, _rygg_,
  { {0xb5e50055, 0xf5950054, 0x6d41006b, 0x00000000}},  //   _প্রচ, _الأج, xtla,
  { {0x19b800b6, 0xf3f9001a, 0x212900ca, 0x00000000}},  //   יפור_, _faţa_, čah_,
  { {0x200d010f, 0x63a40051, 0x439410f3, 0x00000000}},  //   rbei_, úint, _датс,
  { {0x78ad0207, 0x6f09008a, 0x2ca90022, 0x00000000}},  //   hiav, rpec, _amad_,
  { {0x2ca90022, 0xddd8112e, 0x2d9101dc, 0x00000000}},  //   _bmad_, _povš, áze_,
  { {0x6d41049d, 0xc18c0049, 0x3b0a00ed, 0x00000000}},  //   rtla, _שטאָ, лемо_,
  { {0x6d410004, 0x64bc0dc6, 0x78ad39ab, 0x00000000}},  //   stla, nčia, diav,
  { {0x64bc0006, 0x60c92b9e, 0x2ca9010e, 0x00000000}},  //   ičia, loem, _emad_,
  { {0x236607ac, 0xfaa301e0, 0xfce60256, 0x00000000}},  //   zvoj_, чаро, _локо,
  { {0x60c90250, 0x98a3007c, 0x78ad007f, 0x00000000}},  //   noem, писе, giav,
  { {0xac97031d, 0x3f8d2daf, 0x64bc0142, 0x00000000}},  // [cf20] _دنيا_, nyeu_, jčia,
  { {0x68e41e7f, 0x60c90007, 0xe6170454, 0x00000000}},  //   smid, hoem, йду_,
  { {0x64bc0006, 0x452a02b0, 0x2484010e, 0x00000000}},  //   ečia, ужен_, _pomm_,
  { {0x291e010a, 0x93cb00a1, 0x00000000, 0x00000000}},  //   štas_, گامہ_,   ,
  { {0x60c90030, 0xcc3b0049, 0x649301df, 0x00000000}},  //   doem, רענט, _içil,
  { {0xa30b00a1, 0x00000000, 0x00000000, 0x00000000}},  //   ارنے_,   ,   ,
  { {0x321c0428, 0x361b0097, 0x81cb0044, 0x00000000}},  //   ravy_, _תולד, রেস_,
  { {0x831a0084, 0x661e07e7, 0x63a40048, 0x00000000}},  //   _مقرر_, lapk, úins,
  { {0xdfd00054, 0x93fb0097, 0x08770049, 0x00000000}},  //   بية_, _תלמי, מעקט_,
  { {0xa7fb0211, 0x2d9e001f, 0xb87b0011, 0x00000000}},  //   _maña, tzte_, _khíc,
  { {0x3eac0637, 0xf8c80316, 0x60c901c3, 0x00000000}},  //   ridt_, लवाय, boem,
  { {0xb87b0051, 0x2d8c39ac, 0x2d9e01a2, 0x00000000}},  //   _mhíc, ryde_, rzte_,
  { {0x661e0169, 0xd90f00a1, 0x78ad010e, 0x00000000}},  //   kapk, کیج_, viav,
  { {0xdd940783, 0x6493026d, 0x00000000, 0x00000000}},  //   _малы, _açil,   ,
  { {0x66d000b0, 0x661e008a, 0x386239ad, 0x00000000}},  //   näku, dapk, _bakr_,
  { {0xa7fb04de, 0xb715005e, 0x64bc0006, 0x00000000}},  //   _baña, ждащ, yčia,
  { {0xa7fb008e, 0x78ad1afb, 0x69c801a2, 0x00000000}},  // [cf30] _caña, riav, üder,
  { {0xa7fb008e, 0x6c3502fd, 0x3ce0012d, 0x00000000}},  //   _daña, _افکا, _zhiv_,
  { {0xb87b2088, 0x291e183b, 0xf3f902dc, 0x00000000}},  //   _chíc, štar_, анеш_,
  { {0xb87b0051, 0x00000000, 0x00000000, 0x00000000}},  //   _dhíc,   ,   ,
  { {0x98b8001a, 0x083a0049, 0x78bd00d9, 0x00000000}},  //   stră_, _דערל, _ijsv,
  { {0x64bc0dc6, 0x661e04cb, 0x6493005a, 0x00000000}},  //   rčia, capk, _içim,
  { {0x91e239ae, 0x64bc39af, 0xb495003b, 0x00000000}},  //   моше, sčia, _дивљ,
  { {0x3f42009f, 0x64bc0dc6, 0x20190b22, 0x00000000}},  //   fðu_, lčin, úsi_,
  { {0x443f0145, 0x3f42000c, 0x60c90112, 0x00000000}},  //   _icu_, gðu_, roem,
  { {0x64bc0142, 0x92b703d6, 0xfd4916e8, 0x00000000}},  //   nčin, _احرا, азок_,
  { {0xa2c6006e, 0x226400b9, 0x66d00039, 0x00000000}},  //   िवर्, řská_, mäkt,
  { {0x25e1013d, 0x1bea0954, 0xceb80036, 0x00000000}},  //   _करनी_, идни_, anę_,
  { {0x98b8007f, 0xe79c0095, 0x00000000, 0x00000000}},  //   ntrą_, düğü,   ,
  { {0x64bc2479, 0x201f008a, 0x7bda013f, 0x00000000}},  //   jčin, laui_, ətul,
  { {0x81cb08b7, 0xada50057, 0x1987031b, 0x00000000}},  //   রের_, _файл, обри_,
  { {0xa7fb008e, 0x7d0500e5, 0x00000000, 0x00000000}},  //   _paña, _cîrţ,   ,
  { {0xe73a07ca, 0x7e6339b0, 0x661e04cb, 0x00000000}},  // [cf40] рез_, _kanp, tapk,
  { {0x443f002a, 0xd62a007c, 0x6f040048, 0x00000000}},  //   _acu_, роже_, _éice,
  { {0x661e0149, 0x00000000, 0x00000000, 0x00000000}},  //   rapk,   ,   ,
  { {0x7e63002d, 0x938a00ed, 0x443f00e5, 0x00000000}},  //   _lanp, исла_, _ccu_,
  { {0x66e6007e, 0x6609014a, 0x443f39b1, 0x00000000}},  //   _мома, _şeke, _dcu_,
  { {0x443f0066, 0xb87b001d, 0x672405fa, 0x00000000}},  //   _ecu_, _thíc, msij,
  { {0xd1300025, 0xca7b0097, 0x67240e07, 0x00000000}},  //   رمة_, ינסט, lsij,
  { {0x661c011f, 0x7e630250, 0x443f0022, 0x00000000}},  //   _herk, _aanp, _gcu_,
  { {0x661c39b2, 0x672411cb, 0x81cb0044, 0x00000000}},  //   _kerk, nsij, রেল_,
  { {0x3f42009f, 0x63a20197, 0x661c01ed, 0x00000000}},  //   rðu_, mzon, _jerk,
  { {0x63a20030, 0x64bc010a, 0x81e40044, 0x00000000}},  //   lzon, nčio, ভুজ_,
  { {0x06de0044, 0xceb80a67, 0x67240091, 0x00000000}},  //   _ভূমি, snę_, ksij,
  { {0x63a20fa9, 0x69de002d, 0x7d0d00b9, 0x00000000}},  //   nzon, _azpe, _čase,
  { {0x6288003f, 0x63a20026, 0x661c00b4, 0x00000000}},  //   _jodo, izon, _nerk,
  { {0x62880325, 0x2d830030, 0x48ab007e, 0x00000000}},  //   _modo, øjet_, атам_,
  { {0x63a200d9, 0x7e630de2, 0x628800b4, 0x00000000}},  //   kzon, _zanp, _lodo,
  { {0x661c020c, 0x63a200b5, 0x64bc10b1, 0x00000000}},  // [cf50] _berk, jzon, tčin,
  { {0x63a20046, 0x6288001e, 0x7bdf0211, 0x00000000}},  //   dzon, _nodo, _izqu,
  { {0x661c014a, 0x63a239b3, 0x64bc0466, 0x00000000}},  //   _derk, ezon, rčin,
  { {0x236d39b4, 0xb4d502d2, 0x18350049, 0x00000000}},  //   _prej_, हते_, _צאָל_,
  { {0x62880027, 0x64bc1890, 0x66d00039, 0x00000000}},  //   _bodo, mčil, täkt,
  { {0x62880675, 0x661c007f, 0x443f0022, 0x00000000}},  //   _codo, _gerk, _wcu_,
  { {0x6288315e, 0x7e630263, 0x45d40245, 0x00000000}},  //   _dodo, _ranp, _жорс,
  { {0x63a21ead, 0x64bc0387, 0x236d361a, 0x00000000}},  //   bzon, nčil, _trej_,
  { {0x63a20046, 0x628839b5, 0x7e630032, 0x00000000}},  //   czon, _fodo, _panp,
  { {0x645939b6, 0x66050203, 0x479c009b, 0x00000000}},  //   lewi, nchk, ייחס,
  { {0x7e63156f, 0xfbc90104, 0x2006005b, 0x00000000}},  //   _vanp, _עת_, _ffoi_,
  { {0x64590016, 0x62830825, 0x7e6300d9, 0x00000000}},  //   newi, ljno, _wanp,
  { {0x7e6339b7, 0xee2e0121, 0xaff60025, 0x00000000}},  //   _tanp, _пн_, _عفوا_,
  { {0xa7fb0211, 0x64bc0006, 0x9e640088, 0x00000000}},  //   _baño, yčio, _овід,
  { {0x63a201bc, 0xa7fb008e, 0xe7f8013d, 0x00000000}},  //   zzon, _caño, ंखला_,
  { {0xa7fb0211, 0x6e2100d4, 0xb4d50061, 0x00000000}},  //   _daño, lalb, हतो_,
  { {0x661c117c, 0x98a30517, 0x64590016, 0x00000000}},  // [cf60] _perk, хите, dewi,
  { {0x67240ebc, 0x6e210030, 0xddc10047, 0x00000000}},  //   rsij, nalb, lelő,
  { {0x628839b8, 0x67240acc, 0x645901c3, 0x00000000}},  //   _rodo, ssij, fewi,
  { {0x661c2295, 0x645901a0, 0x628839b9, 0x00000000}},  //   _werk, gewi, _sodo,
  { {0x661c020c, 0xd7f20025, 0x6e21010a, 0x00000000}},  //   _terk, _سكس_, kalb,
  { {0x63a2326f, 0x6e2100ca, 0xf655007c, 0x00000000}},  //   rzon, jalb, _отсю,
  { {0x63a20e17, 0x6f0b001c, 0x81d40055, 0x00000000}},  //   szon, _atgc, সেন_,
  { {0x645939ba, 0x25e1013d, 0x63a239bb, 0x00000000}},  //   cewi, _करती_, pzon,
  { {0x62880977, 0x201d39bc, 0xa87b0049, 0x00000000}},  //   _todo, _dewi_, מאקר,
  { {0x6e21010a, 0x81cb0044, 0x00000000, 0x00000000}},  //   galb, রেই_,   ,
  { {0x7bd60022, 0x00000000, 0x00000000, 0x00000000}},  //   _ayyu,   ,   ,
  { {0xd197009b, 0xddc10010, 0xeb9f1565, 0x00000000}},  //   _מכבי_, gelő, dbør_,
  { {0x6e2134d4, 0xa0c90025, 0x2d830030, 0x00000000}},  //   balb, _بذلك_, øjer_,
  { {0xb87b00ad, 0x64590036, 0x2ec70309, 0x00000000}},  //   _chín, zewi, रकृत,
  { {0xb89500a1, 0xa9c400a5, 0x58d500e2, 0x00000000}},  //   وارڈ, естк, довт,
  { {0x321e00b9, 0x64bc016e, 0x50cc0204, 0x00000000}},  //   _lety_, učil, ाविष,
  { {0x7c2d1b94, 0xb90402fb, 0x00000000, 0x00000000}},  // [cf70] _idar, _पी_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d4806ed, 0x64bc0059, 0x66050b19, 0x00000000}},  //   ntda, mčij, rchk,
  { {0x6605010f, 0x23b5023c, 0xbb4808d4, 0x00000000}},  //   schk, وماس, _بلین_,
  { {0x645939bd, 0x626501ee, 0x321e05d2, 0x00000000}},  //   rewi, двла, _bety_,
  { {0x3869000c, 0x7af701d5, 0x66d00039, 0x00000000}},  //   ldar_, _jixt, säkr,
  { {0x776d027b, 0x7af725b0, 0x443d0009, 0x00000000}},  //   lvax, _mixt, pgw_,
  { {0x386904be, 0x7c2d0065, 0xd498007e, 0x00000000}},  //   ndar_, _ndar, _еру_,
  { {0x442d1b6d, 0x6e2103f1, 0x533400ed, 0x00000000}},  //   _ide_, talb, _петт,
  { {0x3eae0009, 0x7c2d0d58, 0x7af7002b, 0x00000000}},  //   _cmft_, _adar, _nixt,
  { {0x442d004f, 0x6d48001c, 0x6da500ed, 0x00000000}},  //   _kde_, gtda, фина,
  { {0x442d00b9, 0x6e211fc4, 0xb87b0051, 0x00000000}},  //   _jde_, salb, _shín,
  { {0x7c2d018e, 0x38691b29, 0x442d214e, 0x00000000}},  //   _ddar, ddar_, _mde_,
  { {0xb87b002a, 0x7c2d0beb, 0xddc10010, 0x00000000}},  //   _bhío, _edar, selő,
  { {0x442d042e, 0xa967005e, 0xf2d201ce, 0x00000000}},  //   _ode_, мира_, דעם_,
  { {0xb87b002a, 0x442d2cc3, 0x7f490129, 0x00000000}},  //   _dhío, _nde_, oteq,
  { {0x4b26007e, 0x7f490886, 0xb87b0082, 0x00000000}},  // [cf80] _ўмов, nteq, _thín,
  { {0x7c2d197c, 0x442d0127, 0xb87b0051, 0x00000000}},  //   _zdar, _ade_, _fhío,
  { {0x442d211e, 0x00000000, 0x00000000, 0x00000000}},  //   _bde_,   ,   ,
  { {0x69c0011f, 0x61fa0145, 0x00000000, 0x00000000}},  //   şmes, _sgtl,   ,
  { {0x442d0016, 0xb87b0051, 0xf4870123, 0x00000000}},  //   _dde_, _mhíl, بالی,
  { {0x442d0263, 0x68e9002b, 0xe29702dc, 0x00000000}},  //   _ede_, ċede, мач_,
  { {0x442d0d3f, 0x6d4839be, 0x64bc0e07, 0x00000000}},  //   _fde_, xtda, nčik,
  { {0x442d003b, 0xd0100025, 0xb89b0049, 0x00000000}},  //   _gde_, دلة_, ַביש,
  { {0xc2460098, 0x2ef401e0, 0x2486012d, 0x00000000}},  //   _онак, нзир, mjom_,
  { {0x442d0224, 0x24860091, 0x6d480056, 0x00000000}},  //   _zde_, ljom_, ttda,
  { {0x2d980027, 0x600a041f, 0x442d0190, 0x00000000}},  //   áre_, _днем_, _yde_,
  { {0x6d4839bf, 0x24860091, 0x7af700ab, 0x00000000}},  //   rtda, njom_, _sixt,
  { {0xfc3f002a, 0x6d4800bb, 0x386939c0, 0x00000000}},  //   rgí_, stda, vdar_,
  { {0xda7b01ff, 0xb87b0048, 0x00000000, 0x00000000}},  //   цям_, _phío,   ,
  { {0xa2b103d7, 0x64bc0e54, 0x3869006b, 0x00000000}},  //   _अगस्, rčij, tdar_,
  { {0x7c2d0209, 0xdd8e026c, 0x81cb0044, 0x00000000}},  //   _udar, _موڈ_, রেক_,
  { {0x3869206d, 0x7af701d5, 0x24860107, 0x00000000}},  // [cf90] rdar_, _tixt, djom_,
  { {0x76d50054, 0xb87b0051, 0x38690022, 0x00000000}},  //   رياض, _thío, sdar_,
  { {0x442d08e3, 0x38690093, 0x4420007e, 0x00000000}},  //   _pde_, pdar_, кi_,
  { {0xb69b001a, 0x442d116c, 0x60c2016e, 0x00000000}},  //   _atât, _qde_, _njom,
  { {0x68ed023a, 0xf1b80066, 0x442d01a2, 0x00000000}},  //   mmad, _reġa_, _vde_,
  { {0x290103dd, 0x68ed014a, 0x216902d3, 0x00000000}},  //   _kuha_, lmad, зики_,
  { {0x2419008b, 0x290100b0, 0x68ed010e, 0x00000000}},  //   _новы_, _juha_, omad,
  { {0x442d0030, 0x68ed005d, 0x2901199a, 0x00000000}},  //   _ude_, nmad, _muha_,
  { {0xda1f0061, 0x68ed00c4, 0x2901011c, 0x00000000}},  //   भरात_, imad, _luha_,
  { {0x0d8500ed, 0x68ed39c1, 0x629801a2, 0x00000000}},  //   елон, hmad, ckvo,
  { {0x68ed1a9d, 0x22450009, 0xa6e2000c, 0x00000000}},  //   kmad, _iclk_, íðin,
  { {0x859a00b3, 0x80270014, 0x1eea00a1, 0x00000000}},  //   פשרו, _آرام, _ہونی_,
  { {0x0c23007e, 0xf3f900e5, 0x68ed00d2, 0x00000000}},  //   ымян, _baţi_, dmad,
  { {0x60db006c, 0x249f2067, 0x68ed010e, 0x00000000}},  //   llum, _llum_, emad,
  { {0xf3f90035, 0x22450009, 0x3a210203, 0x00000000}},  //   _daţi_, _mclk_, _dehp_,
  { {0x248d01bb, 0x29010091, 0x68ed0058, 0x00000000}},  //   _noem_, _duha_, gmad,
  { {0x7c2639c2, 0x60db0052, 0x17c70088, 0x00000000}},  // [cfa0] makr, ilum, егти_,
  { {0xe5a6026b, 0x7c260232, 0x60db01a2, 0x00000000}},  //   низи, lakr, hlum,
  { {0x60db0127, 0x249f008a, 0x29010009, 0x00000000}},  //   klum, _blum_, _guha_,
  { {0x24070726, 0x248d0026, 0x00000000, 0x00000000}},  //   енци_, _coem_,   ,
  { {0x7cfe001e, 0xe3b20445, 0x248d39c3, 0x00000000}},  //   _vīri, درا_, _doem_,
  { {0x7d0d02db, 0x2ca0005b, 0x00000000, 0x00000000}},  //   _časn, _llid_,   ,
  { {0x55e31123, 0x64a60099, 0x2ca00004, 0x00000000}},  //   _борб, _зава, _olid_,
  { {0x60db000c, 0x62980006, 0x7c2616eb, 0x00000000}},  //   glum, skvo, jakr,
  { {0x59d2024c, 0x64a3003b, 0x44260091, 0x00000000}},  //   _दुसर, _сата, mao_,
  { {0x2ef8000c, 0xddd800b9, 0xe357009b, 0x00000000}},  //   örf_, _zavř, _אשמח_,
  { {0xb6370049, 0x5fe20061, 0x01360137, 0x00000000}},  //   ערטס_, _परवल, _سعاد,
  { {0x442609bd, 0x64420e33, 0x7b670264, 0x00000000}},  //   nao_, ngoi, нтге,
  { {0x7ac7003b, 0xc3140044, 0x2901073a, 0x00000000}},  //   есве, _সিডি_, _suha_,
  { {0x81cb0044, 0x442601ed, 0x290139c4, 0x00000000}},  //   রেও_, hao_, _puha_,
  { {0x442639c5, 0x2ca00991, 0x68ed005d, 0x00000000}},  //   kao_, _flid_, tmad,
  { {0x26c71c61, 0x44260119, 0x58d40131, 0x00000000}},  //   čnom_, jao_, гост,
  { {0x44260119, 0x248d01d6, 0x00000000, 0x00000000}},  // [cfb0] dao_, _roem_,   ,
  { {0x68ed0ee4, 0x81cb0044, 0xe8e00082, 0x00000000}},  //   smad, রেট_, _đục_,
  { {0x249f3196, 0xceb300a3, 0x442600e7, 0x00000000}},  //   _plum_, ניע_, fao_,
  { {0x44260119, 0xf4840545, 0x00000000, 0x00000000}},  //   gao_, лучн,   ,
  { {0xa3cb013d, 0x6f021746, 0x290e0023, 0x00000000}},  //   _रुख_, _nuoc, _çfar_,
  { {0xc61b0055, 0x6d5819a4, 0x4426012d, 0x00000000}},  //   _ঢাকা_, _opva, aao_,
  { {0x442639c6, 0x7d0d0410, 0xa156012b, 0x00000000}},  //   bao_, _časo, вају_,
  { {0x442615f7, 0x249f008a, 0xe610009e, 0x00000000}},  //   cao_, _ulum_, _نشہ_,
  { {0xc6240055, 0x6f0202cd, 0x6d580d90, 0x00000000}},  //   _পাতা_, _cuoc, _apva,
  { {0xf1a70216, 0x2ca00875, 0x60db000c, 0x00000000}},  //   _прен, _slid_, slum,
  { {0xdca60057, 0x4df4041f, 0x60db014a, 0x00000000}},  //   вани, ляют, plum,
  { {0x6f020207, 0x6609014a, 0x657501ee, 0x00000000}},  //   _fuoc, _şekl, _mrzh,
  { {0x7c2604be, 0x26c70091, 0xab6302d9, 0x00000000}},  //   rakr, čnoj_, авял,
  { {0xd0260055, 0x442639c7, 0x7c260065, 0x00000000}},  //   _যায়_, zao_, sakr,
  { {0x4426107e, 0x64bc11e4, 0x2d8a0030, 0x00000000}},  //   yao_, mčiv, øbet_,
  { {0x6e2305b7, 0x442628f0, 0x2aad01ed, 0x00000000}},  //   _henb, xao_, džbu_,
  { {0x442601cd, 0x6e230263, 0x7d031642, 0x00000000}},  // [cfc0] vao_, _kenb, _huns,
  { {0x78a40f87, 0xb6cb00a1, 0x442600e7, 0x00000000}},  //   shiv, والے_, wao_,
  { {0x44260119, 0x9586005e, 0x6e23008a, 0x00000000}},  //   tao_, ълже, _menb,
  { {0x7d033579, 0x6e232cab, 0x6fc10204, 0x00000000}},  //   _muns, _lenb, शपां,
  { {0x7c24009f, 0x44260119, 0x04430264, 0x00000000}},  //   _meir, rao_, речн,
  { {0x442601cd, 0xe8e0001d, 0x386000ea, 0x00000000}},  //   sao_, _độc_, leir_,
  { {0x6f0239c8, 0x44260091, 0x7c2400c4, 0x00000000}},  //   _suoc, pao_, _oeir,
  { {0xe0cf0b59, 0xf99300b3, 0x7c2401c5, 0x00000000}},  //   يزي_, שרה_, _neir,
  { {0xf8b300b6, 0x442407e8, 0x48f30061, 0x00000000}},  //   ישה_, _iem_, ंगतो_,
  { {0x7d031740, 0x33d5007e, 0x15e6007d, 0x00000000}},  //   _buns, _сіст, _करार_,
  { {0x7c240016, 0x6e23022b, 0x0697009b, 0x00000000}},  //   _beir, _denb, דדים_,
  { {0x80e00055, 0x44241e8d, 0x7c2431f0, 0x00000000}},  //   _পূর্, _jem_, _ceir,
  { {0x395a0e40, 0x7c2426b6, 0xd00715c4, 0x00000000}},  //   _apps_, _deir, _рече_,
  { {0x6e230030, 0x44242a2b, 0x7d030d78, 0x00000000}},  //   _genb, _lem_, _funs,
  { {0x4424002b, 0x7c2408da, 0x81d40055, 0x00000000}},  //   _oem_, _feir, সের_,
  { {0x44241bc0, 0x6e23022b, 0x6e280161, 0x00000000}},  //   _nem_, _zenb, ladb,
  { {0xf77301f7, 0x64bc0006, 0x5884007e, 0x00000000}},  // [cfd0] جاز_, nčiu, шыра,
  { {0xed4d009c, 0xceb80046, 0x64bc010a, 0x00000000}},  //   _بھی_, nię_, ičiu,
  { {0x442402d5, 0xa9c42b77, 0x950500a1, 0x00000000}},  //   _bem_, _всяк, اہرے_,
  { {0x4424077c, 0x6ba8014a, 0xd4e40088, 0x00000000}},  //   _cem_, _örgü, аючи,
  { {0x44240109, 0xe7840256, 0x4734007e, 0x00000000}},  //   _dem_, _куро, _княс,
  { {0xdce400b9, 0x98b80089, 0x672d00e7, 0x00000000}},  //   _brně, murā_, msaj,
  { {0x6e2300ea, 0x672d0039, 0x80cc0044, 0x00000000}},  //   _renb, lsaj, াতন্,
  { {0x44240030, 0x6e230a7b, 0x2fc00e0d, 0x00000000}},  //   _gem_, _senb, _žiga_,
  { {0x672d0219, 0x68fd01bb, 0x7d0300ab, 0x00000000}},  //   nsaj, _misd, _suns,
  { {0x7c24002a, 0x442410d9, 0x7d03309b, 0x00000000}},  //   _seir, _zem_, _puns,
  { {0xb115017f, 0x7c240fb8, 0xc115003b, 0x00000000}},  //   _смеш, _peir, _смеј,
  { {0x442400ad, 0x672d1c79, 0x6e2301c3, 0x00000000}},  //   _xem_, ksaj, _wenb,
  { {0x7d03010f, 0xceb80036, 0x7c2401e5, 0x00000000}},  //   _wuns, bię_, _veir,
  { {0xd94600c0, 0x7d03027a, 0xdc14006b, 0x00000000}},  //   леги, _tuns, rğız,
  { {0x7c2432d7, 0x38600016, 0x68fd39c9, 0x00000000}},  //   _teir, teir_, _bisd,
  { {0x1c460265, 0x186700ec, 0x661b0107, 0x00000000}},  //   _сним, ласи_, _đuka,
  { {0x6d4100d6, 0xe7c40055, 0x68fd1b3e, 0x00000000}},  // [cfe0] lula, ্ধ্য, _disd,
  { {0x44240e34, 0xda66234c, 0x644939ca, 0x00000000}},  //   _sem_, _свои, _acei,
  { {0x6d41011f, 0x672311af, 0x00000000, 0x00000000}},  //   nula, ćnja,   ,
  { {0x29180977, 0x7e610d4d, 0x64bc003b, 0x00000000}},  //   mpra_, help, jčit,
  { {0x69de0161, 0x442439cb, 0x6d410ea4, 0x00000000}},  //   _hype, _vem_, hula,
  { {0x6d413453, 0x6ffb001e, 0x93cb00a1, 0x00000000}},  //   kula, _mācī, رانہ_,
  { {0x442438c8, 0x7e611ce2, 0xc5f5005e, 0x00000000}},  //   _tem_, delp, _вятъ,
  { {0x6449002a, 0xa4f80123, 0x7afe0027, 0x00000000}},  //   _gcei, _شکار_, _lipt,
  { {0x74130063, 0x7e610270, 0x04930025, 0x00000000}},  //   _طولا, felp, _القح,
  { {0x6e980893, 0xe3b70aef, 0x7e6105da, 0x00000000}},  //   твор_, _сбу_, gelp,
  { {0x6d410b25, 0xac1901fb, 0x6e2839cc, 0x00000000}},  //   gula, кону_, radb,
  { {0xbd87007a, 0x7afe0022, 0x459b0049, 0x00000000}},  //   چنین_, _aipt, גסטע,
  { {0x7e610109, 0xceb80036, 0x68fd0145, 0x00000000}},  //   belp, pię_, _risd,
  { {0x7afe04cb, 0x6d4139cd, 0x68fd39ce, 0x00000000}},  //   _cipt, bula, _sisd,
  { {0x6d4105f0, 0x69de154f, 0xc27b0049, 0x00000000}},  //   cula, _cype, ערלי,
  { {0x672d016c, 0x8afb006b, 0xc4c4009e, 0x00000000}},  //   tsaj, fiəç, _رے_,
  { {0x68fd0089, 0x00000000, 0x00000000, 0x00000000}},  // [cff0] _visd,   ,   ,
  { {0xba55098c, 0x64490051, 0x672d00f8, 0x00000000}},  //   _твој, _scei, rsaj,
  { {0x68fd0039, 0x672d059f, 0x00000000, 0x00000000}},  //   _tisd, ssaj,   ,
  { {0xc8670057, 0x48670265, 0xddc30059, 0x00000000}},  //   _стои, _съоб, _janš,
  { {0x6d4123d0, 0x64bc0e0d, 0xa7fb008e, 0x00000000}},  //   zula, včit, _pañu,
  { {0x6d410279, 0x8237004b, 0x00000000, 0x00000000}},  //   yula, ارشا,   ,
  { {0x21a50cbc, 0x00000000, 0x00000000, 0x00000000}},  //   рийм,   ,   ,
  { {0x6d41194a, 0x27e60036, 0x2f55173a, 0x00000000}},  //   vula, żone_, атос,
  { {0x2d9805b7, 0x6d410093, 0x200d0035, 0x00000000}},  //   øren_, wula, rcei_,
  { {0x6d41006a, 0xcdf50057, 0x6ea700a1, 0x00000000}},  //   tula, ичны, اندہ_,
  { {0x628139cf, 0x00000000, 0x00000000, 0x00000000}},  //   _inlo,   ,   ,
  { {0x6d41011f, 0xeb9a0bbd, 0x7afe01ee, 0x00000000}},  //   rula, вим_, _sipt,
  { {0x6d41006a, 0xe0d00084, 0x7e6100d9, 0x00000000}},  //   sula, _عزم_, pelp,
  { {0xdaba007e, 0x00000000, 0x00000000, 0x00000000}},  //   тымі_,   ,   ,
  { {0xfce6017f, 0x48b60ae0, 0x7bcd13f6, 0x00000000}},  //   _коко, ащат, _exau,
  { {0x98b80035, 0x00000000, 0x00000000, 0x00000000}},  //   dură_,   ,   ,

  { {0x62810061, 0x7afe013f, 0x98a30a94, 0x00000000}},  // [d000] _onlo, _tipt, ците,
  { {0x61110089, 0xe6172e4e, 0x291800f8, 0x00000000}},  //   _zāle, иду_, ppra_,
  { {0x05662b26, 0x98b8001a, 0x00000000, 0x00000000}},  //   рвен, gură_,   ,
  { {0xed560049, 0x64a600e2, 0x00000000, 0x00000000}},  //   יבער_, јада,   ,
  { {0x78a30035, 0x00000000, 0x00000000, 0x00000000}},  //   _înva,   ,   ,
  { {0x387206ec, 0x00000000, 0x00000000, 0x00000000}},  //   ldyr_,   ,   ,
  { {0xe2970080, 0xc448007a, 0x1219007e, 0x00000000}},  //   рај_, _میان_, уючы_,
  { {0x04430867, 0xea000011, 0x62810285, 0x00000000}},  //   _месн, _giấu_, _enlo,
  { {0x6609011f, 0x64bc016c, 0x00000000, 0x00000000}},  //   _şeki, sčis,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa0a60057, 0x69d60061, 0x1ef70025, 0x00000000}},  //   _кажд, _मुली, جعية_,
  { {0xd00f06b4, 0x00000000, 0x00000000, 0x00000000}},  //   _قلم_,   ,   ,
  { {0xdfd20014, 0x7c36005b, 0x00000000, 0x00000000}},  //   _بيش_, _ddyr,   ,
  { {0x799c018e, 0x8f9b00b3, 0x00000000, 0x00000000}},  //   fyrw, _בידי,   ,
  { {0x9e650014, 0x61030010, 0x00000000, 0x00000000}},  //   _دانن, _tőle,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x28f80057, 0x7d0d00ca, 0x00000000, 0x00000000}},  // [d010] реть_, _časi,   ,
  { {0x98b8001a, 0xc7c40088, 0xd0b2006b, 0x00000000}},  //   tură_, істи, rşən,
  { {0x7cff0006, 0xb87b0048, 0x00000000, 0x00000000}},  //   _jūro, _bhít,   ,
  { {0xe43c00b9, 0x00000000, 0x00000000, 0x00000000}},  //   bříč,   ,   ,
  { {0xd7fb012b, 0xb87b0051, 0xf36700c0, 0x00000000}},  //   _јун_, _dhít, ртен,
  { {0xdd390035, 0xd51708d4, 0x00000000, 0x00000000}},  //   năţe, _نظرب,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe4a701fc, 0x26c70161, 0x00000000, 0x00000000}},  //   _трго, čnou_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x628103ca, 0x6b9d0016, 0x26e50309, 0x00000000}},  //   _unlo, dysg, _कठोर_,
  { {0xdd390035, 0x00000000, 0x00000000, 0x00000000}},  //   dăţe,   ,   ,
  { {0x6b9d018e, 0x00000000, 0x00000000, 0x00000000}},  //   fysg,   ,   ,
  { {0x61e105ad, 0xbf6702fd, 0x6abc000c, 0x00000000}},  //   _hyll, _خداو, tirf,
  { {0x61e1021e, 0x6f1b0011, 0x00000000, 0x00000000}},  //   _kyll, mpuc,   ,
  { {0x61e10030, 0x499901fb, 0x09e6017a, 0x00000000}},  //   _jyll, аття_, совн,
  { {0x4806007e, 0xa9280161, 0x3b861fd9, 0x00000000}},  //   спав, _nižš, _глиг,
  { {0x57ea2073, 0x00000000, 0x00000000, 0x00000000}},  // [d020] удам_,   ,   ,
  { {0x387208e0, 0x645b046a, 0x00000000, 0x00000000}},  //   sdyr_, _abui,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x0446012b, 0xe43c013e, 0xb87b0048, 0x00000000}},  //   седн, příč, _dhís,
  { {0xe29a0822, 0x68e4014a, 0x61e1004a, 0x00000000}},  //   лад_, mlid, _ayll,
  { {0x68e4006c, 0x290205e5, 0xb87b0048, 0x00000000}},  //   llid, _hika_, _fhís,
  { {0xa6c700d3, 0x290239d0, 0x61e10016, 0x00000000}},  //   _اوّل_, _kika_, _cyll,
  { {0x2902020c, 0x26da1f0f, 0x5066007e, 0x00000000}},  //   _jika_, lopo_, стка,
  { {0x290200b0, 0x68e43214, 0x7e2a05b8, 0x00000000}},  //   _mika_, ilid, ліна_,
  { {0x29020073, 0x61e139d1, 0x69c0014a, 0x00000000}},  //   _lika_, _fyll, şmey,
  { {0x61e10016, 0x68e4014a, 0xe0d6041f, 0x00000000}},  //   _gyll, klid, _людь,
  { {0xb5fb0049, 0x29020c8a, 0x00000000, 0x00000000}},  //   טליכ, _nika_,   ,
  { {0x26da39d2, 0x5f9405f6, 0xdd39001a, 0x00000000}},  //   kopo_, _филт, tăţe,
  { {0x0db9026c, 0x2902021e, 0xcef601fc, 0x00000000}},  //   ائیں_, _aika_, _учењ,
  { {0x29021431, 0x4c950c96, 0xdd390035, 0x00000000}},  //   _bika_, _микс, răţe,
  { {0x3ebe01f3, 0x0855007e, 0x2bda006e, 0x00000000}},  //   litt_, ўваю, _युवा,
  { {0x2d9e39d3, 0x7cff1a2f, 0x22b60036, 0x00000000}},  // [d030] lyte_, _jūrm, ałki_,
  { {0x7c2f00d4, 0x68e400d6, 0x3ebe05b4, 0x00000000}},  //   lacr, alid, nitt_,
  { {0x29022096, 0xb87b0051, 0x68e415d6, 0x00000000}},  //   _fika_, _dhír, blid,
  { {0x3ebe00c4, 0x290200e0, 0x27e60036, 0x00000000}},  //   hitt_, _gika_, żona_,
  { {0x6eef0030, 0x2ca90ecc, 0xb87b0051, 0x00000000}},  //   løbe, _mlad_, _fhír,
  { {0x26da08eb, 0x61e139d4, 0x236d0059, 0x00000000}},  //   copo_, _pyll, _vsej_,
  { {0xd9f90754, 0xa2d20054, 0x229901aa, 0x00000000}},  //   ंधित_, بيوت, _sèks_,
  { {0x78ad0018, 0x7f5901f9, 0x60090437, 0x00000000}},  //   nhav, ајот_, шним_,
  { {0xfa010055, 0x442f1892, 0x7d0a010f, 0x00000000}},  //   ্রিল_, mag_, _aufs,
  { {0x3ebe0292, 0x32050133, 0x61e1005b, 0x00000000}},  //   gitt_, _ugly_, _tyll,
  { {0x2ca90007, 0xfd44007e, 0x644b39d5, 0x00000000}},  //   _blad_, пэўн, oggi,
  { {0x442f006a, 0x22990263, 0x644b1463, 0x00000000}},  //   nag_, _tèks_, nggi,
  { {0xee2e3475, 0x7cd20089, 0x26da0020, 0x00000000}},  //   _он_, vārd, yopo_,
  { {0x6da501fc, 0xe8e00011, 0x60c900b5, 0x00000000}},  //   _мила, _đốc_, lnem,
  { {0x290215d6, 0x442f39d6, 0x2ca90190, 0x00000000}},  //   _pika_, kag_, _flad_,
  { {0x2ca9018d, 0x442f001e, 0x6f030211, 0x00000000}},  //   _glad_, jag_, _hinc,
  { {0x60c900f4, 0x6f030010, 0x29021f47, 0x00000000}},  // [d040] inem, _kinc, _vika_,
  { {0x68e40190, 0xc96610df, 0x2902006a, 0x00000000}},  //   slid, _двой, _wika_,
  { {0xa2d802fb, 0x2902001e, 0x7d0439d7, 0x00000000}},  //   यवस्, _tika_, _kiis,
  { {0x26da0058, 0xf48301ee, 0x60c900ca, 0x00000000}},  //   sopo_, душн, jnem,
  { {0x60c90142, 0xa3d40309, 0x26da00ca, 0x00000000}},  //   dnem, _सुख_, popo_,
  { {0x6f030047, 0x644b0207, 0x7d0403b6, 0x00000000}},  //   _ninc, aggi, _liis,
  { {0x6e2a057e, 0x40340887, 0x3ebe03f1, 0x00000000}},  //   _refb, пейс, vitt_,
  { {0x7d04003c, 0x60c900f4, 0x2240005d, 0x00000000}},  //   _niis, gnem, şik_,
  { {0x7d0a0007, 0x6f0301a3, 0xbe8a0a27, 0x00000000}},  //   _sufs, _binc, асне_,
  { {0x78ad01ee, 0xbdb406e3, 0x2d9e007f, 0x00000000}},  //   zhav, збој, tyte_,
  { {0x3ebe010f, 0x6f03001a, 0x867b00a3, 0x00000000}},  //   ritt_, _dinc, בריו,
  { {0x7d0d06b8, 0x60c9041a, 0x6b820089, 0x00000000}},  //   _čast, cnem, _šoga,
  { {0x6f030555, 0x7d0406cb, 0x7c2f0211, 0x00000000}},  //   _finc, _diis, racr,
  { {0x2ca90016, 0x7c2f008e, 0x60c000b0, 0x00000000}},  //   _wlad_, sacr, limm,
  { {0x644b0fdc, 0x442f39d8, 0x78ad00b5, 0x00000000}},  //   yggi, yag_, thav,
  { {0x6d48003f, 0x60c00cba, 0xa3aa013d, 0x00000000}},  //   muda, nimm, खना_,
  { {0x442f0e24, 0x69da39d9, 0x00000000, 0x00000000}},  // [d050] vag_, üter,   ,
  { {0x7c2d0038, 0x442f006a, 0x60c000f2, 0x00000000}},  //   _hear, wag_, himm,
  { {0x442f06d3, 0x6d481402, 0x7c2d04be, 0x00000000}},  //   tag_, nuda, _kear,
  { {0x5fca001c, 0xb4d5013d, 0x7c2d0173, 0x00000000}},  //   ापाल, सके_, _jear,
  { {0xdfc60054, 0x442f001f, 0x7c2d094e, 0x00000000}},  //   _أي_, rag_, _mear,
  { {0x3869029a, 0x7c2d0038, 0x442f11fa, 0x00000000}},  //   lear_, _lear, sag_,
  { {0x442f006a, 0x6f0339da, 0x6d48274e, 0x00000000}},  //   pag_, _rinc, juda,
  { {0x386939db, 0x6f030038, 0x7c2d0531, 0x00000000}},  //   near_, _sinc, _near,
  { {0x60c91250, 0x6f031ae2, 0x7d0439dc, 0x00000000}},  //   rnem, _pinc, _riis,
  { {0x0ea90057, 0x7d040cfc, 0xe3b00076, 0x00000000}},  //   ской_, _siis, _شرق_,
  { {0x6f030198, 0x442d002b, 0x7d0401c2, 0x00000000}},  //   _vinc, _kee_, _piis,
  { {0x7c2d39dd, 0x6d410039, 0x3869008e, 0x00000000}},  //   _cear, rrla, jear_,
  { {0x7c2d002a, 0x442d02ae, 0xdd8e089d, 0x00000000}},  //   _dear, _mee_, نوی_,
  { {0x6d4804cb, 0x7d04113b, 0x00000000, 0x00000000}},  //   buda, _wiis,   ,
  { {0xea00001d, 0x38690051, 0x78a40e88, 0x00000000}},  //   _khẩu_, fear_, tkiv,
  { {0x7c2d002a, 0x442d0100, 0x386904bc, 0x00000000}},  //   _gear, _nee_, gear_,
  { {0x6843008b, 0x78a40292, 0xed1600a1, 0x00000000}},  // [d060] энта, rkiv, _وہیں_,
  { {0x78a400b0, 0x60c0010f, 0x6b7b00a3, 0x00000000}},  //   skiv, zimm, _פרינ,
  { {0x7c2d0038, 0x186a00ed, 0x6a9b009b, 0x00000000}},  //   _year, _лани_, _השינ,
  { {0x442d049a, 0x3869004a, 0x0d3a0049, 0x00000000}},  //   _cee_, cear_, מגעב,
  { {0x1ddd0061, 0x6d4828f0, 0x60c000b0, 0x00000000}},  //   _नुसत, zuda, vimm,
  { {0x3f80010a, 0x6d48033b, 0x60c039de, 0x00000000}},  //   _šiuo_, yuda, wimm,
  { {0x8233026c, 0x3958001e, 0x60c017f7, 0x00000000}},  //   رروا, ntrs_, timm,
  { {0x442d0343, 0x25ae014a, 0x98b80036, 0x00000000}},  //   _gee_, ıklı_, turę_,
  { {0x60c000b0, 0x7c2d0133, 0x00000000, 0x00000000}},  //   rimm, _rear,   ,
  { {0x7c2d0038, 0x60c0021e, 0x6d480a92, 0x00000000}},  //   _sear, simm, tuda,
  { {0x7c2d002a, 0x62881c13, 0x63a20ae5, 0x00000000}},  //   _pear, _indo, lyon,
  { {0x0cab026b, 0x629a01ca, 0x6d480020, 0x00000000}},  //   стои_, _hoto, ruda,
  { {0x629a00b0, 0x6d4804cb, 0x7ead0142, 0x00000000}},  //   _koto, suda, _súpe,
  { {0x7c2d00ab, 0x629a00e7, 0x7cff39df, 0x00000000}},  //   _wear, _joto, _mūri,
  { {0x3869002a, 0x63a20093, 0x7c2d0531, 0x00000000}},  //   tear_, hyon, _tear,
  { {0x6abe001f, 0xe894008b, 0x25e0013d, 0x00000000}},  //   _empf, нась, _कड़ी_,
  { {0x6288022b, 0x4c3c00b6, 0x386910c9, 0x00000000}},  // [d070] _ondo, _התחב, rear_,
  { {0x442d1eed, 0xcb14007b, 0x386910c9, 0x00000000}},  //   _see_, _אלץ_, sear_,
  { {0x26c139e0, 0x386900ab, 0xdbd700b0, 0x00000000}},  //   riho_, pear_, sääm,
  { {0x62880948, 0x442d004a, 0x63a200e7, 0x00000000}},  //   _ando, _qee_, fyon,
  { {0x442d095a, 0xe299103d, 0xc5de0044, 0x00000000}},  //   _vee_, жал_, ভেলপ,
  { {0x442d01d6, 0x91e501e0, 0x629a11c6, 0x00000000}},  //   _wee_, моле, _coto,
  { {0x442d0004, 0x2419008b, 0x629a0347, 0x00000000}},  //   _tee_, _мовы_, _doto,
  { {0x92bf0055, 0x628800ab, 0x92cd0044, 0x00000000}},  //   ীতে_, _endo, রতে_,
  { {0x2d9839e1, 0x00000000, 0x00000000, 0x00000000}},  //   ären_,   ,   ,
  { {0x629a39e2, 0xddc80dec, 0x6da50081, 0x00000000}},  //   _goto, cedū, диоа,
  { {0x8c46007c, 0xed1600a1, 0x2a6a0010, 0x00000000}},  //   мене, وہوں_, vebb_,
  { {0x629a39e3, 0xe45f010e, 0x4c830088, 0x00000000}},  //   _zoto, _ööd_, влюв,
  { {0x2a6a27a5, 0x629a000a, 0x7f4900fa, 0x00000000}},  //   tebb_, _yoto, queq,
  { {0xddc5003b, 0xf8bf004a, 0x00000000, 0x00000000}},  //   _обли, _amé_,   ,
  { {0x09e30113, 0x63a22047, 0x00000000, 0x00000000}},  //   ворн, zyon,   ,
  { {0x2a6a0047, 0x394a0133, 0x00000000, 0x00000000}},  //   sebb_, rubs_,   ,
  { {0x39580089, 0x00000000, 0x00000000, 0x00000000}},  // [d080] strs_,   ,   ,
  { {0x290c029d, 0xe5a60256, 0x63a211f3, 0x00000000}},  //   ídas_, мизи, vyon,
  { {0xd826041f, 0x7cff0006, 0x00000000, 0x00000000}},  //   _одни, _sūri,   ,
  { {0x63a201aa, 0x629a016e, 0x2eaa006e, 0x00000000}},  //   tyon, _soto, _छत्त,
  { {0x629a0027, 0x41c3006e, 0x6f0d0051, 0x00000000}},  //   _poto, _वेबस, _éach,
  { {0x63a239e4, 0x68e30065, 0x629a12d7, 0x00000000}},  //   ryon, _ëndr, _qoto,
  { {0x63a22691, 0x629a39e5, 0x6603007e, 0x00000000}},  //   syon, _voto, _апра,
  { {0x7cff1a2f, 0xc9530104, 0x63a20156, 0x00000000}},  //   _tūri, דמה_, pyon,
  { {0x44260be3, 0x629a006a, 0xb4bc0061, 0x00000000}},  //   mbo_, _toto, ेची_,
  { {0x7e980054, 0x4426002d, 0x628839e6, 0x00000000}},  //   سنجر_, lbo_, _undo,
  { {0xfeb70379, 0xfe78007f, 0x1d34007e, 0x00000000}},  //   بايت_, rdį_, эння,
  { {0x44260173, 0x7cd20089, 0xf5370097, 0x00000000}},  //   nbo_, tāra, ונטי_,
  { {0x9be40088, 0x78a3001a, 0x8ae70088, 0x00000000}},  //   вірк, _învi, дівл,
  { {0xc333009b, 0xe7e2006e, 0x00000000, 0x00000000}},  //   כוש_, _खड़ा_,   ,
  { {0x4426006a, 0x00000000, 0x00000000, 0x00000000}},  //   kbo_,   ,   ,
  { {0x2d5800f4, 0x442639e7, 0x7e780146, 0x00000000}},  //   mée_, jbo_, _havp,
  { {0x2d5800f4, 0x442601d9, 0x6d5a00b0, 0x00000000}},  // [d090] lée_, dbo_, ltta,
  { {0x4975025f, 0x44261770, 0x7c3b000c, 0x00000000}},  //   _злос, ebo_, ðurf,
  { {0x2d58028c, 0x6d5a0b90, 0x7ea40129, 0x00000000}},  //   née_, ntta, _còpi,
  { {0x6d5a021e, 0x44260058, 0x7e780190, 0x00000000}},  //   itta, gbo_, _lavp,
  { {0x2d5800f4, 0x62650088, 0x00000000, 0x00000000}},  //   hée_, евла,   ,
  { {0x61e8004f, 0x7e7800ca, 0x6d5a04ce, 0x00000000}},  //   _bydl, _navp, ktta,
  { {0x91e2025f, 0x6d5a0030, 0x38a7006c, 0x00000000}},  //   лоше, jtta, _nõrk_,
  { {0x2d5800f4, 0x00000000, 0x00000000, 0x00000000}},  //   dée_,   ,   ,
  { {0x41df02f4, 0x443f0091, 0x6d5a39e8, 0x00000000}},  //   _पुरस, _idu_, etta,
  { {0xf1a702d3, 0x6d5a02e1, 0x2d58009d, 0x00000000}},  //   _орен, ftta, fée_,
  { {0x6cc6008b, 0x2d5800f4, 0x6d5a0030, 0x00000000}},  //   ейна, gée_, gtta,
  { {0x443f07e4, 0x30840025, 0x00000000, 0x00000000}},  //   _jdu_, _للمف,   ,
  { {0x6d5a001c, 0x76550046, 0x69d70066, 0x00000000}},  //   atta, _oczy, _axxe,
  { {0x8f9a012f, 0x442600ca, 0x6ee6000c, 0x00000000}},  //   _מיני, zbo_, fðbu,
  { {0x6d5a001c, 0x2d5800f4, 0x442639e9, 0x00000000}},  //   ctta, cée_, ybo_,
  { {0x291e0089, 0x443f00e5, 0x7afc016e, 0x00000000}},  //   īta_, _ndu_, smrt,
  { {0x2b460051, 0x1ae600e2, 0xf743007c, 0x00000000}},  // [d0a0] _íoc_, _поим, лето,
  { {0xfc3f0051, 0xddc30161, 0x45d60517, 0x00000000}},  //   bhís_, _manž, нцет,
  { {0x44260173, 0x7f5b0065, 0xca57071c, 0x00000000}},  //   tbo_, htuq, _אייז_,
  { {0xb4bc001c, 0x6b8405fe, 0x443f010f, 0x00000000}},  //   ेचे_, _krig, _cdu_,
  { {0x442639ea, 0x443f0016, 0x61e807c4, 0x00000000}},  //   rbo_, _ddu_, _sydl,
  { {0x443f10c5, 0x67240627, 0x44260059, 0x00000000}},  //   _edu_, mpij, sbo_,
  { {0x044601fb, 0x2d58009d, 0xf1c30164, 0x00000000}},  //   _певн, xée_, _वेदन,
  { {0x2d58028c, 0xea000011, 0x0f260088, 0x00000000}},  //   vée_, _nhậu_, ньом,
  { {0x3f820f1e, 0x68e30129, 0xb35500a1, 0x00000000}},  //   íku_, _índe, _لینا_,
  { {0x6d5a39eb, 0x2d5800f4, 0x61e80039, 0x00000000}},  //   ttta, tée_, _tydl,
  { {0xa00a0025, 0x6d5a00b0, 0x6b84010e, 0x00000000}},  //   _فقال_, utta, _arig,
  { {0x2d58028c, 0x61e4011f, 0x6d5a00b0, 0x00000000}},  //   rée_, ğild, rtta,
  { {0x2d58028c, 0xbea6007e, 0x69c8350c, 0x00000000}},  //   sée_, _падк, úden,
  { {0x2d5800f4, 0x2d9801e3, 0x6b840016, 0x00000000}},  //   pée_, øres_, _drig,
  { {0x81e208b7, 0x644005fd, 0x38600066, 0x00000000}},  //   নের_, _odmi, ffir_,
  { {0x61e5010f, 0x661c01c3, 0x6d480d9b, 0x00000000}},  //   ühli, _afrk, mrda,
  { {0xf773089d, 0x6b84060c, 0x443f01ee, 0x00000000}},  // [d0b0] داز_, _grig, _rdu_,
  { {0x443f0190, 0x7ae50022, 0x6d482c09, 0x00000000}},  //   _sdu_, _ukht, orda,
  { {0x15a8005e, 0x38790142, 0x00000000, 0x00000000}},  //   нъци_, _tasr_,   ,
  { {0x6b84004a, 0x00000000, 0x00000000, 0x00000000}},  //   _yrig,   ,   ,
  { {0x889a019b, 0xc886010f, 0x443f007f, 0x00000000}},  //   _חברי, ößen_, _vdu_,
  { {0x216910e1, 0xd6e20036, 0x76550036, 0x00000000}},  //   дики_, _całą_, _uczy,
  { {0x68ed002a, 0x8234023c, 0x290b016c, 0x00000000}},  //   olad, ارها, _kica_,
  { {0x68ed14c9, 0xd6c40044, 0x290b0022, 0x00000000}},  //   nlad, ্তৃপ, _jica_,
  { {0x290b05f7, 0x68ed018e, 0x6d48008e, 0x00000000}},  //   _mica_, ilad, erda,
  { {0x290b037e, 0x68ed0142, 0x38b501bf, 0x00000000}},  //   _lica_, hlad, _hård_,
  { {0x68ed0428, 0x6b840022, 0x09c60044, 0x00000000}},  //   klad, _srig, _শুনা,
  { {0x6b84016e, 0x290b0035, 0x68ed0190, 0x00000000}},  //   _prig, _nica_, jlad,
  { {0xeb970001, 0x2d980378, 0x6d480a47, 0x00000000}},  //   вия_, ører_, arda,
  { {0xc33200b6, 0x61e4014a, 0xf772025a, 0x00000000}},  //   שום_, şile, یاء_,
  { {0x68ed0240, 0x6cda0ae0, 0x09e60088, 0x00000000}},  //   flad, _офис_, товн,
  { {0x290b26bb, 0x7a3f014a, 0x291300f6, 0x00000000}},  //   _cica_, _açtı, _duxa_,
  { {0x290b39ec, 0x96ba0025, 0x6b840240, 0x00000000}},  // [d0c0] _dica_, وائز_, _urig,
  { {0x68ed18bd, 0xe610006b, 0x248d0129, 0x00000000}},  //   alad, _düşə, _anem_,
  { {0x68ed1ba1, 0x200f0198, 0x290b26b8, 0x00000000}},  //   blad, _oggi_, _fica_,
  { {0x68ed0489, 0x67243994, 0xb73400a1, 0x00000000}},  //   clad, ppij, _مہرب,
  { {0x2bc8001c, 0x29000625, 0x68e4089b, 0x00000000}},  //   रपटा, mmia_, moid,
  { {0xe737012b, 0x248d239d, 0x68e41747, 0x00000000}},  //   _јер_, _enem_, loid,
  { {0x29130d7b, 0x290b0045, 0x2ab401a2, 0x00000000}},  //   _xuxa_, _yica_, _gäbe_,
  { {0x68e400b0, 0x64a3007c, 0x290b06c2, 0x00000000}},  //   noid, _каса, _xica_,
  { {0x7306008b, 0x64a30888, 0xa067012b, 0x00000000}},  //   _апаз, _тата, тања_,
  { {0x3c3200ad, 0x68e403b6, 0xd35700b3, 0x00000000}},  //   _được_, hoid, _בימי_,
  { {0x68e400b0, 0x6d48046a, 0x68ed0095, 0x00000000}},  //   koid, urda, ylad,
  { {0x68e400b0, 0x38b505fe, 0x68ed39ed, 0x00000000}},  //   joid, _kåre_, xlad,
  { {0xe0b7007b, 0x290b0211, 0x68ed0213, 0x00000000}},  //   _בלאט_, _rica_, vlad,
  { {0x1ddd0061, 0x2900006c, 0x291316b5, 0x00000000}},  //   _नुकत, emia_, _puxa_,
  { {0x68ed014a, 0x1ea90025, 0xeef7009b, 0x00000000}},  //   tlad, _ثاني_, _שמור_,
  { {0xdc550098, 0x2ca00048, 0x68e40052, 0x00000000}},  //   _свињ, _goid_, goid,
  { {0x57f500ed, 0xc6f90121, 0x00000000, 0x00000000}},  // [d0d0] упат, енах_,   ,
  { {0x68ed0211, 0x7d0d39ee, 0x2ca001d6, 0x00000000}},  //   slad, _hias, _zoid_,
  { {0x68ed0030, 0x7d0d000b, 0xceb30049, 0x00000000}},  //   plad, _kias, סיע_,
  { {0x78b6010a, 0x73d90081, 0x24190783, 0x00000000}},  //   chyv, ндер_, ходы_,
  { {0x7d0d0046, 0xe3b02aea, 0x38b50039, 0x00000000}},  //   _mias, يره_, _vård_,
  { {0x7ead0051, 0x78ad0006, 0xe1f90081, 0x00000000}},  //   _cúpl, lkav, нгл_,
  { {0xe5340a78, 0x7ead0efe, 0x1a9c0049, 0x00000000}},  //   _весь, _dúpl, ויגע,
  { {0x78ad39ef, 0x3f8624cf, 0x2249014a, 0x00000000}},  //   nkav, _brou_, şak_,
  { {0xf1bf00b9, 0x7cf60010, 0x00000000, 0x00000000}},  //   _řád_, jára,   ,
  { {0x63a4021e, 0x81e20044, 0xe3b000a6, 0x00000000}},  //   äine, নেই_, _برف_,
  { {0xdca60081, 0x7d0d2943, 0x3cca0aa2, 0x00000000}},  //   гани, _bias, елно_,
  { {0x7d0d0e68, 0x61e501a2, 0x00000000, 0x00000000}},  //   _cias, ühlu,   ,
  { {0x7d0d39f0, 0x60c932b3, 0x68e439f1, 0x00000000}},  //   _dias, miem, void,
  { {0x7f3a0097, 0x60c90006, 0x00000000, 0x00000000}},  //   _טענו, liem,   ,
  { {0x1a6600d3, 0x39160014, 0xdb060010, 0x00000000}},  //   نیکی_, اورز, nyké,
  { {0x60c900b0, 0x290007a4, 0x7d0d02d4, 0x00000000}},  //   niem, umia_, _gias,
  { {0x68e41414, 0x29000197, 0x38cb0014, 0x00000000}},  // [d0e0] roid, rmia_, رافی_,
  { {0x7c3639f2, 0xd702008b, 0x68e400b0, 0x00000000}},  //   _heyr, пiса, soid,
  { {0xa9a60216, 0x7c36000c, 0x60c9093c, 0x00000000}},  //   _синд, _keyr, kiem,
  { {0x7ead0d8e, 0x60c939f3, 0x00000000, 0x00000000}},  //   _súpl, jiem,   ,
  { {0x044309bb, 0x13940088, 0x00000000, 0x00000000}},  //   сечн, рилю,   ,
  { {0x38b50292, 0x2d87009d, 0xe29701ee, 0x00000000}},  //   _våre_, _orne_, лач_,
  { {0x2ee5366b, 0xe5a30256, 0xb4260151, 0x00000000}},  //   dolf_, _лири, _معذو,
  { {0x3f860129, 0x60c90007, 0x89370049, 0x00000000}},  //   _prou_, giem, ארקע_,
  { {0xdfd00025, 0x2d8704d3, 0x7d0d39f4, 0x00000000}},  //   تية_, _arne_, _rias,
  { {0x7d0d0518, 0x3f860343, 0x7cf62c01, 0x00000000}},  //   _sias, _vrou_, vára,
  { {0x7d0d39f5, 0x2d870091, 0x7cfd0325, 0x00000000}},  //   _pias, _crne_, nérg,
  { {0x60c939f6, 0x3f8639f7, 0xab5b0a36, 0x00000000}},  //   ciem, _trou_, nzüg,
  { {0x2d870030, 0x7d0d0ba3, 0x7c360016, 0x00000000}},  //   _erne_, _vias, _deyr,
  { {0xbda6004b, 0x5b140098, 0xdb240010, 0x00000000}},  //   _محبو, смрт, ásáb,
  { {0x7cf60062, 0x78ad01b1, 0x2d8701ee, 0x00000000}},  //   márn, tkav, _grne_,
  { {0x7cf61a2c, 0x6e3a0047, 0x00000000, 0x00000000}},  //   lárn, latb,   ,
  { {0x963500aa, 0x78ad0d96, 0x00000000, 0x00000000}},  // [d0f0] инац, rkav,   ,
  { {0x78ad39f8, 0x60c90036, 0xda19007d, 0x00000000}},  //   skav, ziem, _दलित_,
  { {0x7ae70091, 0x78ad0089, 0x55750088, 0x00000000}},  //   mojt, pkav, ргет,
  { {0x81cd0055, 0x7c36006b, 0x60c9009d, 0x00000000}},  //   রথম_, _xeyr, xiem,
  { {0x60c939f9, 0xa8560104, 0x7cf60161, 0x00000000}},  //   viem, _דירה_, kárn,
  { {0xddda0047, 0x46b902fb, 0x38a7006c, 0x00000000}},  //   hető, _इतिह, _võru_,
  { {0x746b0264, 0x60c93988, 0x7cf60062, 0x00000000}},  //   _прав_, tiem, dárn,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60c90dc6, 0x229502fd, 0x6eef0030, 0x00000000}},  //   riem, _پلاس, løbi,
  { {0x60c92104, 0x4d650175, 0x7c36014a, 0x00000000}},  //   siem, аков, _seyr,
  { {0xcc8a0014, 0x60c90089, 0x7c36009d, 0x00000000}},  //   ننده_, piem, _peyr,
  { {0x7c36005f, 0xfce60088, 0x2d8700ca, 0x00000000}},  //   _qeyr, ромо, _vrne_,
  { {0x7c290553, 0x7cd20089, 0x7cc40010, 0x00000000}},  //   ñera, nāri, nőri,
  { {0xceb80036, 0x6eef0030, 0xab27142c, 0x00000000}},  //   chę_, købi, рора_,
  { {0x81130044, 0x7c360016, 0x00000000, 0x00000000}},  //   _সবুজ_, _teyr,   ,
  { {0xf1b20049, 0x7cf62fc2, 0x00000000, 0x00000000}},  //   קסן_, máro,   ,
  { {0xe801001c, 0xc87f001f, 0x2b4000d4, 0x00000000}},  // [d100] लेला_, _daß_, _uvic_,
  { {0x645b0325, 0x63ab0039, 0xda660d54, 0x00000000}},  //   _acui, dygn, _твои,
  { {0x7cf629c5, 0x00000000, 0x00000000, 0x00000000}},  //   náro,   ,   ,
  { {0x232a003b, 0x6e3a39fa, 0xe45f010e, 0x00000000}},  //   води_, zatb, _ööl_,
  { {0xf746012b, 0x93770054, 0xe29a012b, 0x00000000}},  //   _њего, لصور_, кад_,
  { {0xddda0047, 0x7cfd0010, 0xea000082, 0x00000000}},  //   zető, mére, _chầu_,
  { {0x7cf6015f, 0x7456005e, 0x6e3a0010, 0x00000000}},  //   várn, _възх, vatb,
  { {0x645b002a, 0x92d60044, 0x63ab0030, 0x00000000}},  //   _gcui, সতে_, bygn,
  { {0x7cfd00f4, 0x6e3a0056, 0xddda0010, 0x00000000}},  //   nére, tatb, vető,
  { {0x600b0095, 0x00000000, 0x00000000, 0x00000000}},  //   _sömü,   ,   ,
  { {0x7cfd0353, 0x7cf61ade, 0x6e3a0232, 0x00000000}},  //   hére, rárn, ratb,
  { {0x5577007b, 0x13aa0044, 0x7cf60a50, 0x00000000}},  //   בעטן_, _খেয়, sárn,
  { {0x00bb009b, 0x00000000, 0x00000000, 0x00000000}},  //   _במאמ,   ,   ,
  { {0x7cfd009d, 0x6b4c000c, 0xc87f01a2, 0x00000000}},  //   dére, _sögð, _saß_,
  { {0x7ae7008d, 0x98c70216, 0x63ab0036, 0x00000000}},  //   rojt, асал, zygn,
  { {0x7cfd028c, 0x290f0dac, 0x00000000, 0x00000000}},  //   fére, öga_,   ,
  { {0x7c3d0022, 0x7cfd1152, 0xd838007e, 0x00000000}},  // [d110] masr, gére, рэс_,
  { {0x94e8006b, 0x645b2264, 0x7c3d01a3, 0x00000000}},  //   _işə_, _scui, lasr,
  { {0x64150025, 0x68e32a65, 0xaadc009b, 0x00000000}},  //   مواط, _índo, _בחזר,
  { {0x7cfd01cc, 0x7cd20089, 0x00000000, 0x00000000}},  //   bére, tāri,   ,
  { {0x7bdf0082, 0x61fa004a, 0x22450173, 0x00000000}},  //   _jxqu, _aztl, _pdlk_,
  { {0x7c3d0052, 0x00000000, 0x00000000, 0x00000000}},  //   hasr,   ,   ,
  { {0xc6920049, 0x00000000, 0x00000000, 0x00000000}},  //   _צאל_,   ,   ,
  { {0x2602001c, 0x7cf60344, 0x00000000, 0x00000000}},  //   वेळी_, váro,   ,
  { {0x443d39fb, 0xea000011, 0x201f0026, 0x00000000}},  //   maw_, _thầu_, rcui_,
  { {0xe8e0001d, 0x443d39fc, 0x7cf61f2c, 0x00000000}},  //   _đọc_, law_, táro,
  { {0xd0110025, 0xea000011, 0x6281001a, 0x00000000}},  //   _فلا_, _khấu_, _ialo,
  { {0x62810a1f, 0x645901aa, 0x443d39fd, 0x00000000}},  //   _halo, ngwi, naw_,
  { {0x6281008d, 0x7cf607fd, 0x62830116, 0x00000000}},  //   _kalo, sáro, odno,
  { {0x443d103f, 0x628100b0, 0xed59007e, 0x00000000}},  //   haw_, _jalo, _бок_,
  { {0x62810868, 0x443d39fe, 0x38b503b1, 0x00000000}},  //   _malo, kaw_, _såra_,
  { {0x7cfd028c, 0x443d2612, 0x6281011c, 0x00000000}},  //   tére, jaw_, _lalo,
  { {0x98a301e0, 0x443d0066, 0x6d4101c9, 0x00000000}},  // [d120] чите, daw_, lsla,
  { {0x628101d9, 0x38b50073, 0x81e20044, 0x00000000}},  //   _nalo, _våra_, নেট_,
  { {0x99860054, 0xdb060c59, 0x2e3a0049, 0x00000000}},  //   _الجو, szkó, רגענ,
  { {0x7cfd1729, 0x443d006a, 0x6281011c, 0x00000000}},  //   mérc, gaw_, _aalo,
  { {0x62810209, 0x672600ea, 0xb801006e, 0x00000000}},  //   _balo, _utkj, लेआम_,
  { {0x248006a6, 0x6d410a5c, 0x628109d5, 0x00000000}},  //   žim_, ksla, _calo,
  { {0x443d31fe, 0x91860025, 0x7c24012d, 0x00000000}},  //   baw_, إجتم, _ofir,
  { {0x6d41004e, 0x236901d5, 0x442f000a, 0x00000000}},  //   dsla, ħajr_, cbg_,
  { {0x6281285a, 0x291a027c, 0x6d4100b5, 0x00000000}},  //   _falo, _lupa_, esla,
  { {0x6d4139ff, 0x7cf60047, 0xd36f0076, 0x00000000}},  //   fsla, sárl, _سهم_,
  { {0x7c290211, 0xdceb0b54, 0x6d4100f8, 0x00000000}},  //   ñero, žiča, gsla,
  { {0x628123d9, 0x6b820066, 0x00000000, 0x00000000}},  //   _zalo, _ġogr,   ,
  { {0x6111001e, 0x291a0a02, 0x6281014a, 0x00000000}},  //   _tālr, _aupa_, _yalo,
  { {0x62813a00, 0x291a0146, 0x443d0066, 0x00000000}},  //   _xalo, _bupa_, zaw_,
  { {0x44240066, 0x443d011c, 0x6d41003b, 0x00000000}},  //   _ofm_, yaw_, csla,
  { {0x291a000d, 0x4735008b, 0x7764002b, 0x00000000}},  //   _dupa_, жнас, ftix,
  { {0x7bda011f, 0xfc3f002a, 0xdd9000a1, 0x00000000}},  // [d130] ştur, maí_, _روک_,
  { {0xfc3f002a, 0x6b8d022b, 0x442400bb, 0x00000000}},  //   laí_, _irag, _afm_,
  { {0x443d3a01, 0x7c24009f, 0x62810173, 0x00000000}},  //   taw_, _yfir, _ralo,
  { {0xfc3f002a, 0x6b8d3a02, 0x44240061, 0x00000000}},  //   naí_, _krag, _cfm_,
  { {0x628100b0, 0xf36700d7, 0x20d3001a, 0x00000000}},  //   _palo, стен, nţie_,
  { {0xfc3f002a, 0x443d103f, 0x672d0107, 0x00000000}},  //   haí_, saw_, mpaj,
  { {0x443d39fb, 0x62830056, 0x44240f5e, 0x00000000}},  //   paw_, rdno, _ffm_,
  { {0x62810a71, 0x38690051, 0x7c3b000c, 0x00000000}},  //   _walo, nfar_, ðurl,
  { {0x6281021e, 0xef16045a, 0xfc3f002a, 0x00000000}},  //   _talo, омы_, daí_,
  { {0x8234089d, 0xee39026b, 0x6d4101b5, 0x00000000}},  //   _فرما, шно_, tsla,
  { {0x7cd2001e, 0x10e702be, 0xfc3f0051, 0x00000000}},  //   kārt, _людм, faí_,
  { {0xca2901f8, 0x6b8d0a92, 0xfc3f0051, 0x00000000}},  //   _ים_, _brag, gaí_,
  { {0x6d41093b, 0x2d9803a2, 0x291a0035, 0x00000000}},  //   ssla, ärer_, _supa_,
  { {0x6b8d3a03, 0x6d410056, 0x38bc0048, 0x00000000}},  //   _drag, psla, _míre_,
  { {0xed592b26, 0x6b8d022b, 0x38690039, 0x00000000}},  //   _той_, _erag, ffar_,
  { {0x6b8d03a1, 0xfc3f07a7, 0x64490051, 0x00000000}},  //   _frag, caí_, _ndei,
  { {0x3ea703bb, 0xc31f0055, 0x20d3001a, 0x00000000}},  // [d140] _kont_, নীতি_, cţie_,
  { {0x6449018e, 0x7cfd00f4, 0x291a011c, 0x00000000}},  //   _adei, méra, _tupa_,
  { {0x3ea700f4, 0x7cfd00f4, 0x44240145, 0x00000000}},  //   _mont_, léra, _pfm_,
  { {0x39580089, 0x38690051, 0x3ea701c3, 0x00000000}},  //   murs_, cfar_, _lont_,
  { {0x7cfd028c, 0xf48702fd, 0x64490016, 0x00000000}},  //   néra, تالی, _ddei,
  { {0x68f60016, 0xe73700ec, 0x26ca00e7, 0x00000000}},  //   llyd, _фер_, _umbo_,
  { {0x1a9b0049, 0x7cfd3a04, 0x68f60016, 0x00000000}},  //   ייסע, héra, olyd,
  { {0x8f46041f, 0xddd80161, 0xdb1d0010, 0x00000000}},  //   оход, _navš, szsé,
  { {0x629e021e, 0x3ea70016, 0x24840026, 0x00000000}},  //   öpos, _bont_, _iamm_,
  { {0x3ea7000d, 0x7cfd028c, 0x3eb821d9, 0x00000000}},  //   _cont_, déra, órt_,
  { {0xfc3f0195, 0x3ea7028c, 0xdd900426, 0x00000000}},  //   taí_, _dont_, روح_,
  { {0x6b8d3a05, 0xe5710049, 0x2e0e006b, 0x00000000}},  //   _prag, ײַט_, rəf_,
  { {0x3ea70365, 0xfc3f3244, 0x395800f4, 0x00000000}},  //   _font_, raí_, eurs_,
  { {0x6b8d02ae, 0xfc3f002a, 0x24840210, 0x00000000}},  //   _vrag, saí_, _lamm_,
  { {0x2988058e, 0x24863a06, 0x6b8d01d6, 0x00000000}},  //   осто_, kdom_, _wrag,
  { {0x7cfd00f4, 0x20d3001a, 0x23660023, 0x00000000}},  //   béra, pţie_, ktoj_,
  { {0x23660065, 0x7cfd0ee5, 0x24863a07, 0x00000000}},  // [d150] jtoj_, céra, ddom_,
  { {0x6127011f, 0x672d023a, 0xe801013d, 0x00000000}},  //   _yıld, rpaj, लेगा_,
  { {0x39583a08, 0x7cd20089, 0x38690d28, 0x00000000}},  //   curs_, pārt, pfar_,
  { {0x2486004e, 0xa8790049, 0x2458007e, 0x00000000}},  //   gdom_, _פאָר, жаць_,
  { {0x889a00b6, 0xd37b026b, 0x248401b8, 0x00000000}},  //   _הברי, рче_, _damm_,
  { {0x68ed0f44, 0x2ca9190f, 0x290900b0, 0x00000000}},  //   load, _load_, lmaa_,
  { {0x3ea73a09, 0x248417cf, 0x00000000, 0x00000000}},  //   _ront_, _famm_,   ,
  { {0x3ea7028c, 0x38bc0051, 0x2ca905a1, 0x00000000}},  //   _sont_, _tíre_, _noad_,
  { {0x3ea70010, 0xd040006b, 0x29090052, 0x00000000}},  //   _pont_, nimə, imaa_,
  { {0x92b7035b, 0x7cf61b62, 0xddd80087, 0x00000000}},  //   _بحرا, mári, _savš,
  { {0x7cf605e2, 0x3ea700f4, 0xf6520049, 0x00000000}},  //   lári, _vont_, עצט_,
  { {0x7cfd3a0a, 0x2a78010f, 0x7cff0006, 0x00000000}},  //   téra, werb_, _kūry,
  { {0x7cf602d5, 0x60db00ea, 0x68ed00fa, 0x00000000}},  //   nári, mnum, doad,
  { {0x39580089, 0x248609fc, 0xdd010089, 0x00000000}},  //   turs_, zdom_, ītāj,
  { {0x24860203, 0xda79007e, 0x8a03013b, 0x00000000}},  //   ydom_, цяў_, езре,
  { {0x7cfd00f4, 0xb87b000c, 0x98a300e2, 0x00000000}},  //   péra, _skír, нисе,
  { {0x24860107, 0x68f605a6, 0xfaff0023, 0x00000000}},  // [d160] vdom_, rlyd, mtën_,
  { {0x7cf63a0b, 0x39580066, 0x2484010e, 0x00000000}},  //   dári, purs_, _samm_,
  { {0x3a3700a0, 0x3f8f01c3, 0x2486004a, 0x00000000}},  //   _מרים_, _lrgu_, tdom_,
  { {0xa5070e8a, 0xeab200a1, 0x04570025, 0x00000000}},  //   пеха_, _آٹھ_, كلمة_,
  { {0x24861656, 0x33f60025, 0x60db1dcd, 0x00000000}},  //   rdom_, أساس, dnum,
  { {0x78a40295, 0xa3a500b9, 0x2366116b, 0x00000000}},  //   ljiv, nářů_, rtoj_,
  { {0x60db2967, 0x386b0051, 0x7c3b000c, 0x00000000}},  //   fnum, _éirí_, ðurk,
  { {0x78a40091, 0xfaff0065, 0x23660065, 0x00000000}},  //   njiv, jtën_, ptoj_,
  { {0x442601ca, 0x2ca900ab, 0x7cf600c4, 0x00000000}},  //   mco_, _road_, cári,
  { {0x44260851, 0x64420051, 0x7d04010e, 0x00000000}},  //   lco_, laoi, _ahis,
  { {0xfaff0065, 0x44260026, 0xd6be0044, 0x00000000}},  //   ftën_, oco_, _আদায,
  { {0x44263442, 0x64423a0c, 0x00000000, 0x00000000}},  //   nco_, naoi,   ,
  { {0x68e300d6, 0x78a405fa, 0x44260a15, 0x00000000}},  //   _índi, djiv, ico_,
  { {0x64420048, 0xd040013f, 0x00000000, 0x00000000}},  //   haoi, vimə,   ,
  { {0x2ca9010e, 0x68ed0462, 0x44263a0d, 0x00000000}},  //   _toad_, toad, kco_,
  { {0x6d5a3a0e, 0x7cfd00f4, 0xe8b5014a, 0x00000000}},  //   muta, méro, _dışı,
  { {0x6d5a0198, 0x44261fb8, 0x20d3001a, 0x00000000}},  // [d170] luta, dco_, nţia_,
  { {0x29090934, 0x60c00058, 0x7cf608aa, 0x00000000}},  //   smaa_, hhmm, vári,
  { {0x6d5a21c2, 0xf5790355, 0x44260253, 0x00000000}},  //   nuta, تماع_, fco_,
  { {0x7cf602d5, 0xdd860123, 0x43750264, 0x00000000}},  //   tári, _یو_, дукт,
  { {0x6d5a3a0f, 0x60db00ea, 0x7c3f0066, 0x00000000}},  //   huta, vnum, _meqr,
  { {0x7cf602d5, 0x6d5a1cce, 0x44261278, 0x00000000}},  //   rári, kuta, aco_,
  { {0x6d5a017b, 0x7cf63a10, 0x60db00bb, 0x00000000}},  //   juta, sári, tnum,
  { {0x44260198, 0x6d5a006c, 0x64420048, 0x00000000}},  //   cco_, duta, caoi,
  { {0x60db006c, 0x7d04005b, 0x00000000, 0x00000000}},  //   rnum, _rhis,   ,
  { {0x443f0129, 0x7d040065, 0x60db0056, 0x00000000}},  //   _heu_, _shis, snum,
  { {0x6d5a14f7, 0x1d0a10d8, 0xfce60072, 0x00000000}},  //   guta, жени_, доно,
  { {0x443f028c, 0x3f8f092f, 0xa3b8026c, 0x00000000}},  //   _jeu_, _trgu_, _باہر_,
  { {0x443f3a11, 0x20d3001a, 0xfaff0065, 0x00000000}},  //   _meu_, cţia_, rtën_,
  { {0x443f3a12, 0x44260211, 0xfaff0065, 0x00000000}},  //   _leu_, zco_, stën_,
  { {0x7d040606, 0x3f8d0181, 0x6d550010, 0x00000000}},  //   _this, lveu_, ázad,
  { {0x443f0b70, 0xe8fa02f0, 0x4426316c, 0x00000000}},  //   _neu_, іла_, xco_,
  { {0x2ab40004, 0x7c85012b, 0x61e4014a, 0x00000000}},  // [d180] _läbi_, _чује, ğili,
  { {0x61e401df, 0x6b840006, 0x257e00b9, 0x00000000}},  //   şili, _isig, _půl_,
  { {0x44260082, 0xf1c30006, 0x443f3a13, 0x00000000}},  //   tco_, nešė_, _beu_,
  { {0x4426027b, 0x69da009d, 0x00000000, 0x00000000}},  //   uco_, ûteu,   ,
  { {0x44260198, 0x7c3b009f, 0x443f09f7, 0x00000000}},  //   rco_, ðuri, _deu_,
  { {0x442620e4, 0x443f0007, 0x7bc60059, 0x00000000}},  //   sco_, _eeu_, izku,
  { {0x443f0fdb, 0x6d5a0032, 0xdc30007f, 0x00000000}},  //   _feu_, xuta, _užėm,
  { {0x38603a14, 0x6b840091, 0x6d5a006c, 0x00000000}},  //   ngir_, _osig, vuta,
  { {0x4fc600a5, 0x27240010, 0x6d5a0022, 0x00000000}},  //   ьска, _jön_, wuta,
  { {0x6d5a022b, 0x6440003b, 0x41b6003b, 0x00000000}},  //   tuta, _hemi, _осет,
  { {0x629a0412, 0x6b843a15, 0x443f0011, 0x00000000}},  //   _into, _asig, _yeu_,
  { {0x6d5a020c, 0x628a0240, 0xe5710049, 0x00000000}},  //   ruta, ldfo, אַך_,
  { {0x6d5a061f, 0x64400149, 0x62883a16, 0x00000000}},  //   suta, _memi, _kado,
  { {0x628a0030, 0x644038c0, 0x62882480, 0x00000000}},  //   ndfo, _lemi, _jado,
  { {0x6b840207, 0xaf070025, 0x6127014a, 0x00000000}},  //   _esig, _تقوم_, _kıla,
  { {0xfb1a026c, 0x62880d8e, 0x64400091, 0x00000000}},  //   _کريں_, _lado, _nemi,
  { {0x6d4805b7, 0x443f00bb, 0x2b4901ee, 0x00000000}},  // [d190] lsda, _reu_, _uvac_,
  { {0x443f2b7d, 0x272401df, 0xceb8093c, 0x00000000}},  //   _seu_, _dön_, nkę_,
  { {0x443f0293, 0x6d4801b5, 0x628a018e, 0x00000000}},  //   _peu_, nsda, ddfo,
  { {0x629a022b, 0x64403a17, 0x443f2a65, 0x00000000}},  //   _anto, _cemi, _qeu_,
  { {0x66c00073, 0x443f0129, 0x62880032, 0x00000000}},  //   _söke, _veu_, _bado,
  { {0x2919000b, 0x6288001a, 0x6d480039, 0x00000000}},  //   _hisa_, _cado, ksda,
  { {0x64403a18, 0x29190263, 0x628802d5, 0x00000000}},  //   _femi, _kisa_, _dado,
  { {0x629a0919, 0x64400397, 0x6d4805d5, 0x00000000}},  //   _ento, _gemi, dsda,
  { {0xb2750216, 0x291938a5, 0x6d4a093b, 0x00000000}},  //   _плаш, _misa_, _avfa,
  { {0x29190004, 0x62880089, 0x7ce802b9, 0x00000000}},  //   _lisa_, _gado, zırd,
  { {0xab5b0047, 0x6f1801ee, 0x6d481642, 0x00000000}},  //   szül, _divc, gsda,
  { {0x628801d9, 0x2919097f, 0x0fd00061, 0x00000000}},  //   _zado, _nisa_, _तेवढ,
  { {0x2bba0025, 0x6d4801c3, 0x00000000, 0x00000000}},  //   ساحة_, asda,   ,
  { {0xc332019b, 0xf8bf0e6d, 0x29190032, 0x00000000}},  //   רום_, _alé_, _aisa_,
  { {0x29190762, 0x27240039, 0xf8bf009d, 0x00000000}},  //   _bisa_, _sön_, _blé_,
  { {0xf8bf1321, 0x291900f6, 0xad1a0049, 0x00000000}},  //   _clé_, _cisa_, _צופר,
  { {0x2919008d, 0x3860009f, 0x27e600f4, 0x00000000}},  // [d1a0] _disa_, rgir_, çon_,
  { {0x5986013b, 0xf8bf0010, 0x291e00fa, 0x00000000}},  //   _злоб, _elé_, ítas_,
  { {0x62880b54, 0x6440020c, 0x29190bc2, 0x00000000}},  //   _rado, _pemi, _fisa_,
  { {0x2919022b, 0x63a23a19, 0x44f60014, 0x00000000}},  //   _gisa_, txon, رساز,
  { {0x6288001e, 0x7cf60142, 0xceb81f00, 0x00000000}},  //   _pado, lárs, ykę_,
  { {0x764e0030, 0x76450022, 0x29190035, 0x00000000}},  //   _udby, cahy, _zisa_,
  { {0x66e301f9, 0x6288010a, 0x6440011f, 0x00000000}},  //   _сора, _vado, _temi,
  { {0xd5b9008b, 0x62880020, 0x6d4e008e, 0x00000000}},  //   _ўсё_, _wado, ábam,
  { {0x62880af2, 0x6f1810c1, 0xdfd0023c, 0x00000000}},  //   _tado, _pivc, شيد_,
  { {0x69c70036, 0xc7b3009b, 0x201d000a, 0x00000000}},  //   yzje, טבח_, _egwi_,
  { {0xceb81f00, 0x6d48007f, 0x6ef400f6, 0x00000000}},  //   rkę_, usda, fàbr,
  { {0xdd12005d, 0x6d483a1a, 0x7cf60027, 0x00000000}},  //   rüşl, rsda, dárs,
  { {0x291911c4, 0x6d480056, 0xceb800b4, 0x00000000}},  //   _risa_, ssda, pkę_,
  { {0x291904d4, 0x8f9b0097, 0x6d4802e1, 0x00000000}},  //   _sisa_, _מידי, psda,
  { {0xf8bf002a, 0x2919133a, 0x7cf6140e, 0x00000000}},  //   _plé_, _pisa_, tárt,
  { {0xc4c400a1, 0x3f86000a, 0x7645008a, 0x00000000}},  //   _طے_, _ksou_, wahy,
  { {0x29190073, 0x3f860224, 0xddc810d9, 0x00000000}},  // [d1b0] _visa_, _jsou_, nedž,
  { {0x65950407, 0x35e7004c, 0x1a6500a1, 0x00000000}},  //   казу, нцев, _جیسی_,
  { {0x29190020, 0x76450093, 0x7c3b014a, 0x00000000}},  //   _tisa_, rahy, ıurf,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x45180123, 0x7c2d00e7, 0x80a400e8, 0x00000000}},  //   رآمد_, _mfar, काने,
  { {0x2489325c, 0xbb3c0104, 0x00000000, 0x00000000}},  //   žam_, לעדי,   ,
  { {0x3f860173, 0x7cfd0010, 0xe0570bb6, 0x00000000}},  //   _asou_, gérk, فیات_,
  { {0xa99c00a3, 0xddc8012d, 0x712403ec, 0x00000000}},  //   לבור, fedž, درول,
  { {0x776d027b, 0x442d1595, 0x2480010e, 0x00000000}},  //   ntax, _ife_, õime_,
  { {0x7c2d001a, 0xf77200a0, 0x1e950256, 0x00000000}},  //   _afar, סקי_, трир,
  { {0x7f490026, 0xdcf4016c, 0x22473a1b, 0x00000000}},  //   sseq, žača, mank_,
  { {0x7c2d008d, 0x22470007, 0x442d17fe, 0x00000000}},  //   _cfar, lank_, _jfe_,
  { {0x30d80049, 0x3b83007e, 0xef0e004d, 0x00000000}},  //   _אַװע, аляг, _вм_,
  { {0x7cf607fd, 0x442d0943, 0x00000000, 0x00000000}},  //   társ, _lfe_,   ,
  { {0xaa4302d3, 0x78af003b, 0xa967017a, 0x00000000}},  //   ресл, _bocv, кира_,
  { {0x442d00fa, 0x00000000, 0x00000000, 0x00000000}},  //   _nfe_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [d1c0]   ,   ,   ,
  { {0x442d01aa, 0xa926003b, 0xaca800a1, 0x00000000}},  //   _afe_, _идол, _آپکے_,
  { {0x05660057, 0x22470007, 0x442d3a1c, 0x00000000}},  //   твен, dank_, _bfe_,
  { {0x6b960007, 0x442d06d2, 0x2b4000ea, 0x00000000}},  //   _kryg, _cfe_, _kwic_,
  { {0x442d0009, 0x61ed005d, 0x7cf600d6, 0x00000000}},  //   _dfe_, şall, nárq,
  { {0x6263012b, 0x66e60b81, 0x61fa3a1d, 0x00000000}},  //   авља, _рога, _pytl,
  { {0xe29700e1, 0xe5a30517, 0x442d0009, 0x00000000}},  //   тај_, _кири, _ffe_,
  { {0x6b960036, 0x3eae3a1e, 0x442d02c2, 0x00000000}},  //   _oryg, _soft_, _gfe_,
  { {0xd3f4007e, 0xb3550241, 0x00000000, 0x00000000}},  //   _лiст, _مینا_,   ,
  { {0x7cfd00f4, 0x7c2d3a1f, 0x38b50039, 0x00000000}},  //   méri, _sfar, _hårt_,
  { {0x7cfd1b6d, 0x7c2d010f, 0x61e4014a, 0x00000000}},  //   léri, _pfar, ğils,
  { {0x6b9600eb, 0x776d006b, 0xc5f3009b, 0x00000000}},  //   _bryg, ytax, ידת_,
  { {0x3f8600c4, 0x3eae0190, 0x2d870032, 0x00000000}},  //   _usou_, _toft_, _esne_,
  { {0x6b960039, 0x00000000, 0x00000000, 0x00000000}},  //   _dryg,   ,   ,
  { {0x7c3b009f, 0x60c20007, 0x7cfd009d, 0x00000000}},  //   ðurs, _klom, héri,
  { {0x7c2d0020, 0x38720016, 0x6b960030, 0x00000000}},  //   _ufar, gfyr_, _fryg,
  { {0x66c00039, 0x442d013f, 0x7cf6004a, 0x00000000}},  // [d1d0] _söka, _rfe_, párr,
  { {0x776d027b, 0x60c21460, 0xe3b30014, 0x00000000}},  //   rtax, _llom, یرش_,
  { {0x6d5a001c, 0x776d049a, 0x60c200b9, 0x00000000}},  //   nrta, stax, _olom,
  { {0x7cfd00f4, 0x6d5a0056, 0xde150049, 0x00000000}},  //   féri, irta, אַנץ_,
  { {0x7cfd00f4, 0x22470190, 0x42d50245, 0x00000000}},  //   géri, tank_, ліку,
  { {0x60c201d6, 0x91e500da, 0xf9900167, 0x00000000}},  //   _alom, лоле, _ابی_,
  { {0xfa7800b6, 0x22470c30, 0x36d4007c, 0x00000000}},  //   דעות_, rank_, _торр,
  { {0x60c224be, 0x7cfd0f07, 0x442d0258, 0x00000000}},  //   _clom, béri, _ufe_,
  { {0x7af50047, 0x62350783, 0x6d5a24c6, 0x00000000}},  //   kozt, _безу, erta,
  { {0x6127011f, 0x52740167, 0x7ce8019a, 0x00000000}},  //   _yıll, _نامز, dıra,
  { {0x60c23a20, 0x8c460256, 0x61270095, 0x00000000}},  //   _flom, лене, _kılm,
  { {0x7cf600c4, 0x60c22f3d, 0x55760049, 0x00000000}},  //   tárq, _glom, נערן_,
  { {0xfc471526, 0xeb9701e0, 0x20240027, 0x00000000}},  //   ñías_, гия_, ásiť_,
  { {0x7cc40010, 0x6b960007, 0x7cf60d7b, 0x00000000}},  //   nőrz, _vryg, rárq,
  { {0x5d790049, 0x224500c7, 0x2d870166, 0x00000000}},  //   _טאַק, _melk_, _usne_,
  { {0x6b96009f, 0xbc66213a, 0x4dfa0049, 0x00000000}},  //   _tryg, _свик, _אפצא,
  { {0x48060887, 0x2d000061, 0xc7a3003b, 0x00000000}},  // [d1e0] упав, ईतील_, битк,
  { {0xe5a60c96, 0x8c1b009b, 0x249f0145, 0x00000000}},  //   лизи, _אופי, _anum_,
  { {0xd946022a, 0xe45a003b, 0x96f9007e, 0x00000000}},  //   _щени, еже_, тэту_,
  { {0x7cfd3a21, 0xa34a003b, 0x136a00e3, 0x00000000}},  //   téri, езда_, ешки_,
  { {0x38b501c9, 0xcc3b0049, 0x68e41319, 0x00000000}},  //   _vårt_, גענט, mnid,
  { {0x29000dc9, 0x60c20091, 0x249f00ea, 0x00000000}},  //   llia_, _slom, _enum_,
  { {0x60c200f4, 0x68e4006c, 0x8cc70061, 0x00000000}},  //   _plom, onid, ासमो,
  { {0x7cfd028c, 0x92e40055, 0x26da0020, 0x00000000}},  //   péri, নতে_, lipo_,
  { {0x68e40016, 0x290017b4, 0x7ce8006b, 0x00000000}},  //   inid, ilia_, xıra,
  { {0x29003015, 0x224501f3, 0xe3eb0049, 0x00000000}},  //   hlia_, _gelk_, _אַבֿ,
  { {0xd6db00b3, 0x29000020, 0x6127014a, 0x00000000}},  //   תחיל, klia_, _yılm,
  { {0x7ce8005d, 0x6d5a0048, 0x2ca00009, 0x00000000}},  //   tıra, rrta, _cnid_,
  { {0x7af53a22, 0xd0120025, 0xda7b0131, 0x00000000}},  //   tozt, _الش_, няв_,
  { {0x66c03a23, 0x2ca01e11, 0x3d940088, 0x00000000}},  //   _sökn, _enid_, _викр,
  { {0x68e40016, 0x7af5028d, 0x26da0026, 0x00000000}},  //   fnid, rozt, dipo_,
  { {0x29000198, 0x68e40b33, 0x7ebf01c3, 0x00000000}},  //   glia_, gnid, _lêpl,
  { {0x96f900ed, 0xe894007c, 0x7d0d00b0, 0x00000000}},  // [d1f0] веат_, щать, _ihas,
  { {0x29003a24, 0xaa670256, 0x67260065, 0x00000000}},  //   alia_, _стик, _dukj,
  { {0x2900011c, 0x7d0d1636, 0x00000000, 0x00000000}},  //   blia_, _khas,   ,
  { {0x63b90046, 0x29000129, 0xddc80027, 0x00000000}},  //   tywn, clia_, radň,
  { {0x7d0d00e7, 0x66c0019a, 0x248d012d, 0x00000000}},  //   _mhas, _kökl, _vaem_,
  { {0x26da0207, 0x2d85005b, 0xb7da009b, 0x00000000}},  //   cipo_, ywle_, _יקרי,
  { {0x02c50061, 0x63b90036, 0xe2c900a6, 0x00000000}},  //   _वतीन, sywn, _یورو_,
  { {0x78ad0a0f, 0x224500b5, 0xb97c0049, 0x00000000}},  //   njav, _welk_, גנהי,
  { {0x644b1921, 0x09d2001c, 0x4f2501f9, 0x00000000}},  //   magi, _सध्य, јдоб,
  { {0x644b3a25, 0x7f5b0f57, 0x7d0d12ea, 0x00000000}},  //   lagi, rruq, _ahas,
  { {0x7d0d1fec, 0x29003a26, 0x00000000, 0x00000000}},  //   _bhas, ylia_,   ,
  { {0x644b011c, 0x62833a27, 0x30e4007e, 0x00000000}},  //   nagi, leno, _лічб,
  { {0x78ad1985, 0x60db01a2, 0xee2e005e, 0x00000000}},  //   djav, mium, _мн_,
  { {0x644b117c, 0x60db0d8f, 0xfc030088, 0x00000000}},  //   hagi, lium, іпро,
  { {0xd9460175, 0x66c00039, 0x644b22f6, 0x00000000}},  //   реби, _söko, kagi,
  { {0x6283005b, 0x60c920ac, 0x7d0d0020, 0x00000000}},  //   heno, nhem, _ghas,
  { {0x644b3a28, 0x68e400d6, 0x26da0325, 0x00000000}},  // [d200] dagi, rnid, tipo_,
  { {0xfd4c001d, 0x62830213, 0xdcf900b9, 0x00000000}},  //   _nhiệ, jeno, _osvě,
  { {0x1426019d, 0x4a5b00b6, 0x29000919, 0x00000000}},  //   адем, _בדיו, plia_,
  { {0x644b05af, 0x26da0020, 0x7cfd0ee5, 0x00000000}},  //   gagi, sipo_, sérv,
  { {0x60db2af8, 0x20d3001a, 0x66c0006b, 0x00000000}},  //   dium, cţii_, _hökm,
  { {0x628302ae, 0x6d430943, 0xfd4c0082, 0x00000000}},  //   geno, _owna, _chiệ,
  { {0x644b023a, 0x6d55139d, 0x22420011, 0x00000000}},  //   bagi, ázal, _đkkd_,
  { {0x7c243a29, 0x92c80044, 0x60c900e7, 0x00000000}},  //   _ngir, োকে_, ghem,
  { {0x4ea6007e, 0xa805004a, 0x232a02dc, 0x00000000}},  //   арна, muñé, _рози_,
  { {0x62830089, 0x7c24022b, 0x6233012b, 0x00000000}},  //   ceno, _agir, _међу,
  { {0x0697009b, 0x7d0d00ab, 0x7cfd0010, 0x00000000}},  //   בדים_, _phas, kért,
  { {0x60c9084d, 0x60db0035, 0x211a0014, 0x00000000}},  //   chem, cium, _شتاب_,
  { {0x44240253, 0xdee601ab, 0x00000000, 0x00000000}},  //   _mgm_, _коди,   ,
  { {0x644b002d, 0xd007017f, 0x7ce8005d, 0x00000000}},  //   zagi, _тече_, lırl,
  { {0x1fe80055, 0x7d0d0065, 0x764701aa, 0x00000000}},  //   _পরিস, _thas, _rejy,
  { {0x6283137e, 0x31570049, 0x26d800bb, 0x00000000}},  //   zeno, יילן_, _amro_,
  { {0x78ad3a2a, 0x644b313b, 0x628300bb, 0x00000000}},  // [d210] rjav, vagi, yeno,
  { {0xed4d026c, 0x644b11b3, 0x6b8d0be4, 0x00000000}},  //   _تھی_, wagi, _isag,
  { {0x62833a2b, 0x442400f6, 0xb9950025, 0x00000000}},  //   veno, _bgm_, _الجب,
  { {0x77640129, 0x6b8d1174, 0x20d30035, 0x00000000}},  //   buix, _ksag, pţii_,
  { {0x62833000, 0x7ce80279, 0x38690022, 0x00000000}},  //   teno, dırl, mgar_,
  { {0x38690181, 0x442f012d, 0x6b8d3a2c, 0x00000000}},  //   lgar_, scg_, _msag,
  { {0x644b02ae, 0x62830091, 0x3495004c, 0x00000000}},  //   pagi, reno, _лавр,
  { {0x38692161, 0x62830073, 0x6b8d002d, 0x00000000}},  //   ngar_, seno, _osag,
  { {0xfd4c001d, 0x60db06aa, 0x6283003b, 0x00000000}},  //   _thiệ, rium, peno,
  { {0x60db0c75, 0x60c90f3e, 0x3869005b, 0x00000000}},  //   sium, shem, hgar_,
  { {0xa2940088, 0x7cfd0010, 0x02fa0049, 0x00000000}},  //   _фахі, yért, _עלעמ,
  { {0xe1f0083e, 0xb1152337, 0x00000000, 0x00000000}},  //   _غسل_, _умеш,   ,
  { {0xfaff0065, 0x386900f8, 0x66c03a2d, 0x00000000}},  //   jtës_, dgar_, _sökm,
  { {0xa3af0316, 0x69ce010f, 0x6d5c1866, 0x00000000}},  //   _ओपन_, tzbe, árac,
  { {0xcd3503ec, 0x6b8d0197, 0x68fd0022, 0x00000000}},  //   _ارتب, _esag, _bksd,
  { {0x38692d47, 0xfaff0065, 0x69ce010f, 0x00000000}},  //   ggar_, ftës_, rzbe,
  { {0x03e20044, 0xc7a301e0, 0xdc3b0049, 0x00000000}},  // [d220] _বর্ণ, питк, _געפר,
  { {0x7ce8038c, 0x38693a2e, 0x44240145, 0x00000000}},  //   zırl, agar_, _sgm_,
  { {0xb8ce0055, 0x6449010f, 0x7ce8005d, 0x00000000}},  //   _কত_, _beei, yırl,
  { {0xed56007b, 0xfaff0065, 0x232a0603, 0x00000000}},  //   מבער_, stët_, годи_,
  { {0x20d30035, 0x33f60025, 0x00000000, 0x00000000}},  //   nţiu_, حساس,   ,
  { {0xd62700e3, 0x26d80091, 0x954a01d8, 0x00000000}},  //   _горе_, _umro_, _مشرق_,
  { {0x7ce801f6, 0x44243a2f, 0xfc3f093f, 0x00000000}},  //   tırl, _tgm_, ybí_,
  { {0x6449010f, 0x4424023a, 0x399b0049, 0x00000000}},  //   _geei, _ugm_, ריקד,
  { {0xdbf100b9, 0x30770025, 0x7ce81a6f, 0x00000000}},  //   _příc, صحية_, rırl,
  { {0x66fa0164, 0x3869014a, 0x91e6005e, 0x00000000}},  //   ्तिक_, zgar_, _лозе,
  { {0xd24f083e, 0x00000000, 0x00000000, 0x00000000}},  //   _سنن_,   ,   ,
  { {0x7cfd0e03, 0xac190e82, 0x7bcf004a, 0x00000000}},  //   vérs, иону_, tzcu,
  { {0x06fa007d, 0xc4d3009b, 0x00000000, 0x00000000}},  //   ्ताव_, פגש_,   ,
  { {0x38bc00b9, 0x3da6041f, 0x38690016, 0x00000000}},  //   _míru_, _гриб, wgar_,
  { {0xf8bf009d, 0xa803014a, 0x386900e0, 0x00000000}},  //   _liée_, ğıms, tgar_,
  { {0x320c04bb, 0x6b8d3a30, 0x00000000, 0x00000000}},  //   _mzdy_, _tsag,   ,
  { {0x38693a31, 0xf7700025, 0x2cf70061, 0x00000000}},  // [d230] rgar_, فال_, ीतील_,
  { {0x6efd00f4, 0x3869005b, 0x644900ab, 0x00000000}},  //   lèbr, sgar_, _seei,
  { {0x64490719, 0x986500a1, 0xfaff0065, 0x00000000}},  //   _peei, _ویسے_, stës_,
  { {0xe61000a1, 0x6efd009d, 0x7ce828fc, 0x00000000}},  //   رشل_, nèbr, yırm,
  { {0x69d8000c, 0x00000000, 0x00000000, 0x00000000}},  //   _þver,   ,   ,
  { {0xe299132e, 0x04fb0044, 0x715902dc, 0x00000000}},  //   рак_, েদের_, арис_,
  { {0x96080551, 0x32cb0056, 0x00000000, 0x00000000}},  //   _гэта_, _nøye_,   ,
  { {0x7ce8005d, 0x69da00c4, 0x00000000, 0x00000000}},  //   tırm, útei,   ,
  { {0x2d981565, 0x2d9c010e, 0x00000000, 0x00000000}},  //   æren_, _arve_,   ,
  { {0x20030089, 0xd2510084, 0x00000000, 0x00000000}},  //   āji_, _آنا_,   ,
  { {0xb035005e, 0xdb060036, 0xf8c90061, 0x00000000}},  //   _днеш, zykó, रसाय,
  { {0xc0ab1298, 0x236001ed, 0x6efd0068, 0x00000000}},  //   _حائل_, šije_, gèbr,
  { {0xab2a0888, 0xb4fa01ce, 0x4438006b, 0x00000000}},  //   рога_, שפרי, _ər_,
  { {0x81cc0055, 0x66c0014a, 0xc332009b, 0x00000000}},  //   রপর_, _gökh, ווך_,
  { {0x2d98044f, 0x7ce8014a, 0x00000000, 0x00000000}},  //   året_, nırk,   ,
  { {0xdb060036, 0x00000000, 0x00000000, 0x00000000}},  //   tykó,   ,   ,
  { {0xe8f70c50, 0x464a003b, 0xfaff0065, 0x00000000}},  // [d240] ілу_, изан_, rtër_,
  { {0xfaff0065, 0x7ce80095, 0x00000000, 0x00000000}},  //   stër_, kırk,   ,
  { {0x7afc02f1, 0x08fa0025, 0x00000000, 0x00000000}},  //   mort, _نرحب_,   ,
  { {0x7afc0203, 0x66c000b0, 0xc7a60c96, 0x00000000}},  //   lort, _möki, _димк,
  { {0x78a600ea, 0x00000000, 0x00000000, 0x00000000}},  //   _inkv,   ,   ,
  { {0x7afc0016, 0x62340545, 0x7cf60010, 0x00000000}},  //   nort, чеку, gárz,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afc0e67, 0x2002009f, 0x64422665, 0x00000000}},  //   kort, æki_, mboi,
  { {0x2d9c1a2d, 0x7afc032e, 0x644200f6, 0x00000000}},  //   _prve_, jort, lboi,
  { {0xa2a7007d, 0x7afc06d4, 0x1df80930, 0x00000000}},  //   चार्, dort, сены_,
  { {0x64420288, 0x61ed019a, 0xff0a0044, 0x00000000}},  //   nboi, ğalt, রদেশ_,
  { {0x7afc06da, 0xd007003b, 0xdb1d33df, 0x00000000}},  //   fort, _деце_, lysé,
  { {0x7afc04a0, 0x00000000, 0x00000000, 0x00000000}},  //   gort,   ,   ,
  { {0xdb1d0047, 0x7c360016, 0x0994003b, 0x00000000}},  //   nysé, _ffyr, марџ,
  { {0x26ca0046, 0x473503f6, 0xa2a70061, 0x00000000}},  //   _albo_, знас, चाऱ्,
  { {0x7afc0016, 0x7ce8006b, 0x00000000, 0x00000000}},  // [d250] bort, zırk,   ,
  { {0x501b009b, 0x7afc3a32, 0x78a60087, 0x00000000}},  //   שומו, cort, _enkv,
  { {0x63b600b0, 0x00000000, 0x00000000, 0x00000000}},  //   äynn,   ,   ,
  { {0xf9fa009b, 0x26ca0146, 0x224c0288, 0x00000000}},  //   _להתמ, _elbo_, _aedk_,
  { {0xb87b004a, 0x00000000, 0x00000000, 0x00000000}},  //   _amíg,   ,   ,
  { {0x02c5024c, 0x77ba00b6, 0x67ba009b, 0x00000000}},  //   वसेन, _המשח, _המשק,
  { {0xca7c0097, 0x20090089, 0xe0570123, 0x00000000}},  //   ינגט, _šai_, قیات_,
  { {0x25750634, 0x7afc3a33, 0x00000000, 0x00000000}},  //   mål_, zort,   ,
  { {0xb4e7001c, 0xf07600a1, 0x00000000, 0x00000000}},  //   यची_, سیوں_,   ,
  { {0xf1950088, 0x4d6500e2, 0x00000000, 0x00000000}},  //   _низь, пков,   ,
  { {0x6da50057, 0x7cfd0b33, 0x7afc0716, 0x00000000}},  //   чина, térp, vort,
  { {0x7afc001f, 0xbfb70f8b, 0xdb0d0142, 0x00000000}},  //   wort, _وحشت, ľkýc,
  { {0x7afc001e, 0x7f19007e, 0xa2d200e8, 0x00000000}},  //   tort, _ліку_, भोक्,
  { {0x6442001a, 0x8f9a00a3, 0x8d5507e1, 0x00000000}},  //   zboi, _ליני, _етич,
  { {0x7d110047, 0x7afc0d90, 0x9998007f, 0x00000000}},  //   üksé, rort, varų_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [d260]   ,   ,   ,
  { {0x645b0085, 0x6b840258, 0x00000000, 0x00000000}},  //   _adui, _ipig,   ,
  { {0x3abb00b3, 0x7abb009b, 0x02c50316, 0x00000000}},  //   _המינ, _הציו, वसैन,
  { {0x27ed0119, 0x00000000, 0x00000000, 0x00000000}},  //   _žene_,   ,   ,
  { {0x29020004, 0xa3fc0044, 0xa2940245, 0x00000000}},  //   _ikka_, েশ্য_, далі,
  { {0x32051167, 0x6b840020, 0x26ca00e0, 0x00000000}},  //   _byly_, _mpig, _ulbo_,
  { {0xb9090011, 0xa13c01c5, 0x00000000, 0x00000000}},  //   _nghỉ_, _orķe,   ,
  { {0xf48400a2, 0xc1040025, 0x00000000, 0x00000000}},  //   _تاسی, بوعي,   ,
  { {0xdd1f00b9, 0x4fc6094b, 0x00000000, 0x00000000}},  //   tížn, яска,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x255801aa, 0x6b8400e7, 0xaab00309, 0x00000000}},  //   nčl_, _apig, ञानक,
  { {0x629800bb, 0x63a005d2, 0x00000000, 0x00000000}},  //   ldvo, _krmn,   ,
  { {0x66c0005f, 0xde5801ff, 0x00000000, 0x00000000}},  //   _höku, _далі_,   ,
  { {0x765c008d, 0x753c0046, 0x764e0802, 0x00000000}},  //   _ndry, _otrz, _neby,
  { {0x25dc001c, 0xc984019d, 0x66c0000c, 0x00000000}},  //   _गेली_, нути, _jöku,
  { {0x628a0190, 0x765c0208, 0xf773009e, 0x00000000}},  //   hefo, _adry, ٹار_,
  { {0xf7730d3a, 0x628a00ea, 0x23db0061, 0x00000000}},  // [d270] عار_, kefo, _मेंद,
  { {0x628a3a34, 0xda4b09da, 0x00000000, 0x00000000}},  //   jefo, _учил_,   ,
  { {0x764e018e, 0x765c0016, 0x00000000, 0x00000000}},  //   _deby, _ddry,   ,
  { {0xb4e7001c, 0x765c018e, 0x2458008b, 0x00000000}},  //   यचे_, _edry, заць_,
  { {0x68ed0039, 0x6d4a0016, 0x889a009b, 0x00000000}},  //   mnad, _lwfa, _וברי,
  { {0x628a0302, 0x68ed0056, 0x764e0030, 0x00000000}},  //   gefo, lnad, _geby,
  { {0x68ed0489, 0x236001d5, 0x95c50025, 0x00000000}},  //   onad, ġija_, _غيره,
  { {0x7f5901f9, 0x68ed13d8, 0x672700e7, 0x00000000}},  //   ојот_, nnad, _hijj,
  { {0x6d5801d5, 0x68ed0181, 0xa2270014, 0x00000000}},  //   _avva, inad, _فراه,
  { {0x628a0190, 0x68ed0016, 0x85430006, 0x00000000}},  //   cefo, hnad, _įėji,
  { {0x6b840197, 0x628101d6, 0x6727219f, 0x00000000}},  //   _spig, _iblo, _mijj,
  { {0x81b60044, 0x00000000, 0x00000000, 0x00000000}},  //   _চেক_,   ,   ,
  { {0x68ed035f, 0xdce20089, 0x6d580026, 0x00000000}},  //   dnad, gulā, _evva,
  { {0x7d0700f4, 0x255801aa, 0x3200014a, 0x00000000}},  //   térê, yčl_, şiye_,
  { {0x62812a5e, 0x764e00e0, 0xacf6003b, 0x00000000}},  //   _mblo, _reby, _очиј,
  { {0x68ed003d, 0x77640066, 0x629804eb, 0x00000000}},  //   gnad, trix, zdvo,
  { {0x6d41006c, 0x753c0036, 0x7d04049d, 0x00000000}},  // [d280] lpla, _strz, _ikis,
  { {0x6d4100f6, 0x7764002d, 0x68ed0051, 0x00000000}},  //   opla, rrix, anad,
  { {0x6d4102ae, 0x628a0606, 0x7e7e0039, 0x00000000}},  //   npla, vefo, _öppe,
  { {0x628100f8, 0xcdb6009b, 0x6d41037f, 0x00000000}},  //   _ablo, ופעה_, ipla,
  { {0x628a00f4, 0x764e0016, 0x6298016c, 0x00000000}},  //   tefo, _teby, tdvo,
  { {0x6d410a5e, 0x68e4224c, 0xd13a02d3, 0x00000000}},  //   kpla, liid, охи_,
  { {0x62810c08, 0x753c0036, 0xf623007e, 0x00000000}},  //   _dblo, _utrz, _адро,
  { {0x6d410142, 0x628104e6, 0x628a0287, 0x00000000}},  //   dpla, _eblo, sefo,
  { {0x7c2906ac, 0x628a00bb, 0xa29f0061, 0x00000000}},  //   žerk, pefo, _गोव्,
  { {0x7d040020, 0x2ca90802, 0x68ed0821, 0x00000000}},  //   _akis, _snad_, znad,
  { {0x6f0801d0, 0x29000032, 0x68ed3a35, 0x00000000}},  //   rldc, koia_, ynad,
  { {0xbfc6005e, 0x66c03a2d, 0x7d163a36, 0x00000000}},  //   _обек, _köks, _chys,
  { {0x5c04007e, 0x68ed00f8, 0xf8bf008e, 0x00000000}},  //   вяра, vnad, _bién_,
  { {0x6d413a37, 0x7d043a38, 0x00000000, 0x00000000}},  //   bpla, _ekis,   ,
  { {0x6d550344, 0x68ed0056, 0xe9190088, 0x00000000}},  //   ázat, tnad, зові_,
  { {0xdce2001e, 0x29000032, 0xddc80036, 0x00000000}},  //   pulā, goia_, padł,
  { {0x68ed03d1, 0x7c2d167f, 0x00000000, 0x00000000}},  // [d290] rnad, _igar,   ,
  { {0x68ed3a39, 0x672f016c, 0x7d1d1faf, 0x00000000}},  //   snad, _vucj, lmss,
  { {0xa29f0183, 0xe3b0007a, 0x68ed0039, 0x00000000}},  //   _गोष्, یره_, pnad,
  { {0x62813a3a, 0x66c00d47, 0x290000f6, 0x00000000}},  //   _sblo, _sökt, coia_,
  { {0x6d41086e, 0x673d02e8, 0x9cd800b3, 0x00000000}},  //   zpla, _utsj, וואה_,
  { {0x6d411f4c, 0x7c2d00f6, 0x00000000, 0x00000000}},  //   ypla, _lgar,   ,
  { {0x7c2d00b4, 0x00000000, 0x00000000, 0x00000000}},  //   _ogar,   ,   ,
  { {0x1fb5003b, 0x7c2d0065, 0x6d41032e, 0x00000000}},  //   есор, _ngar, vpla,
  { {0x442d0695, 0x6d4100bb, 0x2366012d, 0x00000000}},  //   _ige_, wpla, croj_,
  { {0x6d413a3b, 0x1dca001c, 0x7c2d0211, 0x00000000}},  //   tpla, ानंत, _agar,
  { {0x7d163a3c, 0x1d0a05f6, 0x752900b5, 0x00000000}},  //   _phys, зени_, _kiez,
  { {0x55da0049, 0xeafa01f5, 0x425300a1, 0x00000000}},  //   פֿינ, ृत्त_, _سنچر,
  { {0x75293a3d, 0x2900174b, 0x442d0178, 0x00000000}},  //   _miez, voia_, _mge_,
  { {0x6d410039, 0x60c92fac, 0x75292ba6, 0x00000000}},  //   ppla, lkem, _liez,
  { {0x2cab0051, 0x7d16005b, 0x38c800a6, 0x00000000}},  //   áidí_, _thys, واری_,
  { {0x75290046, 0x27ed049c, 0x442d0093, 0x00000000}},  //   _niez, _žena_, _nge_,
  { {0x68e401c2, 0xfaff0065, 0xdbc7006c, 0x00000000}},  // [d2a0] riid, mrën_, _sööm,
  { {0x442d0549, 0x60c91252, 0x7c2d1507, 0x00000000}},  //   _age_, hkem, _zgar,
  { {0x75290089, 0x60c90bbc, 0x7bc60006, 0x00000000}},  //   _biez, kkem, lyku,
  { {0x23660161, 0xe452004b, 0xd497007e, 0x00000000}},  //   troj_, اضا_, ерш_,
  { {0x75291f2e, 0x6abe010f, 0x4394007c, 0x00000000}},  //   _diez, _kopf, талс,
  { {0x23600e54, 0x442d014a, 0x23660065, 0x00000000}},  //   šijo_, _ege_, rroj_,
  { {0x6f010197, 0x7ce8005a, 0xa29f0061, 0x00000000}},  //   dolc, nırs, _गोळ्,
  { {0x23660023, 0x00000000, 0x00000000, 0x00000000}},  //   proj_,   ,   ,
  { {0xb4be006e, 0x6f010026, 0xfaff0023, 0x00000000}},  //   ेसी_, folc, drën_,
  { {0x7c2d09f9, 0xfaff0023, 0x75293a3e, 0x00000000}},  //   _sgar, erën_, _ziez,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x629a17b0, 0x60c91962, 0xe3a700a1, 0x00000000}},  //   _hato, ckem, _تشہی,
  { {0x9b580265, 0x6f010010, 0x2b4000f6, 0x00000000}},  //   ният_, bolc, _ctic_,
  { {0x2f9700b6, 0x629a002d, 0xd00f006d, 0x00000000}},  //   _נכון_, _jato, _اله_,
  { {0x629a3a3f, 0x3a250073, 0x78bd0340, 0x00000000}},  //   _mato, älp_, _posv,
  { {0x6d5a2f9a, 0x629a01aa, 0x7c2d022b, 0x00000000}},  //   msta, _lato, _ugar,
  { {0x7c840057, 0xe73306dd, 0x2aab01ee, 0x00000000}},  // [d2b0] _суще, اصر_, _етно_,
  { {0x629a0036, 0x6d5a0213, 0x66c00039, 0x00000000}},  //   _nato, osta, _sökr,
  { {0x6c6a026c, 0x75293a40, 0xeef70049, 0x00000000}},  //   _علیہ_, _piez, עמבר_,
  { {0x6d5a00b0, 0xe5070014, 0x7ae701ed, 0x00000000}},  //   ista, رباي, lijt,
  { {0xe2990069, 0x75291768, 0x66d20146, 0x00000000}},  //   дал_, _viez, _dækb,
  { {0x629a0e98, 0x6d5a2018, 0x91e50242, 0x00000000}},  //   _cato, ksta, коле,
  { {0x6f01004a, 0x60c901b1, 0x00000000, 0x00000000}},  //   volc, tkem,   ,
  { {0x442d0018, 0xceb80036, 0x6fa9034b, 0x00000000}},  //   _uge_, eję_, двиг_,
  { {0x6d5a0211, 0x60c904d4, 0x629a3a41, 0x00000000}},  //   esta, rkem, _fato,
  { {0x6d5a00c7, 0x37e30044, 0xfbd70044, 0x00000000}},  //   fsta, _মডার, সপাত,
  { {0x6d5a0006, 0xfaff0065, 0x2d9a012d, 0x00000000}},  //   gsta, trën_, _šper_,
  { {0x7bc60046, 0x83fd0010, 0x629a0874, 0x00000000}},  //   tyku, _időb, _zato,
  { {0x6d5a002a, 0x629a0020, 0x7ae70065, 0x00000000}},  //   asta, _yato, fijt,
  { {0xceb80046, 0x6d5a0b25, 0x3d12007d, 0x00000000}},  //   cję_, bsta, _धीरे_,
  { {0xab27102a, 0x6d5a00bb, 0xfaff0065, 0x00000000}},  //   тора_, csta, prën_,
  { {0x09e10044, 0x2018006b, 0x26d1069d, 0x00000000}},  //   _মুহা, ərib_, _alzo_,
  { {0xc052052f, 0x7ae70c76, 0x97c320e6, 0x00000000}},  // [d2c0] יזן_, bijt, айте,
  { {0xb8c90164, 0x00000000, 0x00000000, 0x00000000}},  //   _गो_,   ,   ,
  { {0x629a037e, 0xd946022a, 0xbebc0089, 0x00000000}},  //   _rato, _шени, smīg,
  { {0x6d5c002a, 0x629a0e88, 0xa3ce0316, 0x00000000}},  //   árai, _sato, शनल_,
  { {0x629a0006, 0x6d5a0059, 0x93930025, 0x00000000}},  //   _pato, zsta, لجوا,
  { {0x6d5a3a42, 0x6d5c08ad, 0xf8bf0068, 0x00000000}},  //   ysta, šrai, _zoé_,
  { {0xdb1d0010, 0x6d5a013f, 0x32cb00ea, 0x00000000}},  //   nysá, xsta, _gøym_,
  { {0x629a000b, 0x6d5a20dc, 0x23760b03, 0x00000000}},  //   _wato, vsta, _لائح,
  { {0x6d5a0046, 0x69c70036, 0xdfd00025, 0x00000000}},  //   wsta, zyje, صيد_,
  { {0x6d5a0270, 0x4ea60a85, 0x00000000, 0x00000000}},  //   tsta, триа,   ,
  { {0x63a201ba, 0x42d5007e, 0xdb041155, 0x00000000}},  //   lvon, _сіту, _triê,
  { {0x13c60044, 0xceb80036, 0x61fa004a, 0x00000000}},  //   _শেয়, sję_, _ixtl,
  { {0x6d5a05b4, 0x3f98001e, 0x6e960025, 0x00000000}},  //   ssta, ārus_, _للشا,
  { {0x6d5a0007, 0xaa6400e2, 0x27ed0059, 0x00000000}},  //   psta, итск, _ženo_,
  { {0xa9c40783, 0x6d5a002b, 0xdb1d0010, 0x00000000}},  //   астк, qsta, gysá,
  { {0xc19b0452, 0x257c00b9, 0x63a22277, 0x00000000}},  //   ושלי, díl_, kvon,
  { {0xf7700025, 0x09e10044, 0x00000000, 0x00000000}},  // [d2d0] قال_, _মুশা,   ,
  { {0x257c0051, 0x63a20725, 0x00000000, 0x00000000}},  //   fíl_, dvon,   ,
  { {0x1bab00a1, 0x00000000, 0x00000000, 0x00000000}},  //   _راکٹ_,   ,   ,
  { {0xb87b3a43, 0xe791014a, 0xdb04009d, 0x00000000}},  //   _zmín, _göğü, _ariè,
  { {0x2f19009d, 0xdb04009d, 0x00000000, 0x00000000}},  //   lège_, _briè,   ,
  { {0xe3b006b4, 0x257c000c, 0x00000000, 0x00000000}},  //   ترم_, bíl_,   ,
  { {0x45d5007c, 0xa3e30164, 0x2f19009d, 0x00000000}},  //   _совс, _फेर_, nège_,
  { {0xd6c50044, 0x320c0016, 0x00000000, 0x00000000}},  //   _এগিয, _dydy_,   ,
  { {0x61fa0009, 0x645935a8, 0x443d00c4, 0x00000000}},  //   _extl, mawi, mcw_,
  { {0x1e95012b, 0x64590bc9, 0xe7aa010e, 0x00000000}},  //   урир, lawi, _tööõ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7e7e0073, 0x75350c7d, 0x64593a44, 0x00000000}},  //   _öppn, _muzz, nawi,
  { {0x75350026, 0x31a3014a, 0x443f00e7, 0x00000000}},  //   _luzz, _hız_, _mfu_,
  { {0x2d9500ec, 0x31a3014a, 0x645909bd, 0x00000000}},  //   _брис, _kız_, hawi,
  { {0x64590036, 0x75350026, 0x2d9808e0, 0x00000000}},  //   kawi, _nuzz, æret_,
  { {0x64590036, 0xddc800b9, 0x443f3a45, 0x00000000}},  //   jawi, jadř, _nfu_,
  { {0xad1b01ce, 0x9d1b0104, 0x98a30ae0, 0x00000000}},  // [d2e0] _אוקר, _אוקט, щите,
  { {0x7d063a46, 0x443f04c0, 0x75350133, 0x00000000}},  //   loks, _afu_, _buzz,
  { {0x76553a47, 0x4a7b0049, 0x2d5100ca, 0x00000000}},  //   _dezy, _אריב, nše_,
  { {0x257c1185, 0x6459006a, 0x7d0600b0, 0x00000000}},  //   ríl_, gawi, noks,
  { {0xdb0400f4, 0x443f0190, 0x63a20dd9, 0x00000000}},  //   _priè, _dfu_, uvon,
  { {0x75350403, 0x63a208a6, 0x2d510091, 0x00000000}},  //   _fuzz, rvon, kše_,
  { {0x2d5101d9, 0x91860025, 0x75350197, 0x00000000}},  //   jše_, اجتم, _guzz,
  { {0xc953009b, 0x00000000, 0x00000000, 0x00000000}},  //   זמה_,   ,   ,
  { {0x7d060110, 0x6d430006, 0x752217f8, 0x00000000}},  //   doks, _atna, mmoz,
  { {0x61fa0009, 0xb77b0049, 0x75220232, 0x00000000}},  //   _txtl, עאיש, lmoz,
  { {0x672e002b, 0x00000000, 0x00000000, 0x00000000}},  //   _mibj,   ,   ,
  { {0x672e0066, 0x7f830241, 0x00000000, 0x00000000}},  //   _libj, جلین,   ,
  { {0x6d430026, 0x3eb800f8, 0x00000000, 0x00000000}},  //   _etna, örts_,   ,
  { {0x945d0046, 0x64590036, 0x2f19009d, 0x00000000}},  //   _końc, zawi, tège_,
  { {0x7d060056, 0x48ab0888, 0x60c201c2, 0x00000000}},  //   boks, нтам_, _koom,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x628811b0, 0x466b3a48, 0x00000000, 0x00000000}},  // [d2f0] _obdo, ерем_,   ,
  { {0x60c20004, 0x7c290c76, 0x6b8d011c, 0x00000000}},  //   _loom, žers, _ipag,
  { {0x64590046, 0x64400009, 0x81c90044, 0x00000000}},  //   tawi, _bfmi, _লেন_,
  { {0xfc3f23aa, 0x5c380049, 0xc50b0014, 0x00000000}},  //   ncí_, ָרגן_, رتال_,
  { {0x64590046, 0x20d8002a, 0x6b8d3a49, 0x00000000}},  //   rawi, _méid_, _jpag,
  { {0x64590058, 0x21690264, 0x20d10048, 0x00000000}},  //   sawi, вики_, _cáin_,
  { {0x31a3006b, 0xfc3f0802, 0x64590058, 0x00000000}},  //   _qız_, kcí_, pawi,
  { {0x6b8d3a4a, 0x26c300ca, 0x2d510213, 0x00000000}},  //   _opag, _hojo_, vše_,
  { {0x26c3016c, 0x98a50006, 0x7d0631d5, 0x00000000}},  //   _kojo_, ūlė_, voks,
  { {0x66d2009f, 0x26c30253, 0x0d8500c0, 0x00000000}},  //   _lækn, _jojo_, алон,
  { {0x249f3a4b, 0x7d06021e, 0x6b8d00d6, 0x00000000}},  //   _kaum_, toks, _apag,
  { {0x63a90119, 0xe1f00076, 0x2d510059, 0x00000000}},  //   _kren, _عسل_, rše_,
  { {0x9f6b0265, 0x7d063a4c, 0x2d980030, 0x00000000}},  //   _чрез_, roks, ærer_,
  { {0x212f0038, 0x6da5026b, 0x2d5102db, 0x00000000}},  //   _high_, _вика, pše_,
  { {0x7d0608a8, 0x6b8d00fa, 0xa8560098, 0x00000000}},  //   poks, _epag, итај,
  { {0xfc3206dd, 0x6b8d3a4d, 0x249f00c4, 0x00000000}},  //   _بحث_, _fpag, _naum_,
  { {0x26c33a4e, 0xa6e60088, 0x66d20190, 0x00000000}},  // [d300] _bojo_, ажал, _dækn,
  { {0x26c3008e, 0x2ca001a3, 0x00000000, 0x00000000}},  //   _cojo_, _haid_,   ,
  { {0x63a90004, 0x26c300ea, 0x249f01a2, 0x00000000}},  //   _aren, _dojo_, _baum_,
  { {0x63a93a4f, 0x776d049a, 0x212f3a50, 0x00000000}},  //   _bren, brax, _nigh_,
  { {0x24070331, 0x63a90181, 0xcc3b0049, 0x00000000}},  //   анци_, _cren, דענט,
  { {0x63a9158f, 0x60c20004, 0x809e03d7, 0x00000000}},  //   _dren, _soom, _खोजे,
  { {0xd5b2025a, 0x63a90095, 0x649a0081, 0x00000000}},  //   _ظفر_, _eren, _итар_,
  { {0x63a93861, 0x68f6018e, 0x2ca00675, 0x00000000}},  //   _fren, nnyd, _naid_,
  { {0x63a90292, 0x68f60016, 0x1eaa0025, 0x00000000}},  //   _gren, inyd, نادي_,
  { {0x68f6000a, 0x60c201c3, 0x00000000, 0x00000000}},  //   hnyd, _woom,   ,
  { {0x6b8d0207, 0x60c2006c, 0x63a911e4, 0x00000000}},  //   _spag, _toom, _zren,
  { {0x2018005f, 0x9b953a51, 0x0ea60061, 0x00000000}},  //   ərin_, бимц, _कोरड,
  { {0xd0100014, 0x2ca022f0, 0xfc3f0916, 0x00000000}},  //   _علت_, _daid_, rcí_,
  { {0xfc3f0051, 0x0ead01f5, 0x6d480056, 0x00000000}},  //   scí_, _झोपड, ppda,
  { {0x68f60bc4, 0x0dca01f9, 0x26c30211, 0x00000000}},  //   fnyd, _јули_, _rojo_,
  { {0xfce401fc, 0x2f0b0190, 0x26c32a7a, 0x00000000}},  //   _мојо, søgt_, _sojo_,
  { {0x7d0d0756, 0x693c16d0, 0x249f010f, 0x00000000}},  // [d310] _ikas, _učen, _raum_,
  { {0x63a90065, 0xba990088, 0x85a7003b, 0x00000000}},  //   _rren, _своє_, ијед,
  { {0x66d2000c, 0x63a90093, 0x8c090044, 0x00000000}},  //   _tækn, _sren, রেশন_,
  { {0x20d10051, 0x776d01a2, 0x9848005e, 0x00000000}},  //   _cáil_, prax, _вяра_,
  { {0x68ed06c0, 0x26c30066, 0xd37b17a4, 0x00000000}},  //   miad, _tojo_, тче_,
  { {0x68ed018e, 0x130801ff, 0x057700a6, 0x00000000}},  //   liad, аній_, _پاسد,
  { {0x20d1002a, 0x70130044, 0xf9940049, 0x00000000}},  //   _fáil_, _হলেও_, ַרץ_,
  { {0x68ed018e, 0x09f80104, 0x00000000, 0x00000000}},  //   niad, ימום_,   ,
  { {0xc0c8003b, 0x63a92917, 0x2d9c012d, 0x00000000}},  //   рује_, _uren, _asve_,
  { {0x2ca00038, 0x7d0d0020, 0x68ed0016, 0x00000000}},  //   _said_, _akas, hiad,
  { {0xdca601fc, 0x68f6018e, 0x2ca000ab, 0x00000000}},  //   бани, ynyd, _paid_,
  { {0x32d9000a, 0xdb0e013e, 0x00000000, 0x00000000}},  //   _dèye_, ějíc,   ,
  { {0x68ed018e, 0x2ca00004, 0x8f6a00a1, 0x00000000}},  //   diad, _vaid_, _ملنے_,
  { {0x6449006b, 0x3ce900f6, 0x60db004a, 0x00000000}},  //   əmiş, _emav_, lhum,
  { {0x68ed018e, 0x186a0517, 0x00000000, 0x00000000}},  //   fiad, лави_,   ,
  { {0xa3d702fb, 0x68ed3a52, 0x60db0181, 0x00000000}},  //   ाना_, giad, nhum,
  { {0xbb860054, 0x2fdf01a2, 0x386f0048, 0x00000000}},  // [d320] _الخي, nzug_, ógra_,
  { {0x68f601d6, 0x00000000, 0x00000000, 0x00000000}},  //   snyd,   ,   ,
  { {0x9412005f, 0x1a9b0049, 0x68ed0b9b, 0x00000000}},  //   ədən_, _גייע, biad,
  { {0x68ed0489, 0x045a0426, 0x69ce0006, 0x00000000}},  //   ciad, اجات_, mybe,
  { {0x69ce3a53, 0x60db0020, 0xd46700e2, 0x00000000}},  //   lybe, dhum, сиче_,
  { {0x78a4006c, 0xf743025f, 0xd5d60783, 0x00000000}},  //   ldiv, _херо, _любы,
  { {0x69ce29f6, 0x6f080142, 0xc5d50088, 0x00000000}},  //   nybe, vodc, _діть,
  { {0x78a43a54, 0x765e0006, 0x27ed0825, 0x00000000}},  //   ndiv, lapy, _ženi_,
  { {0x27e0006b, 0xd0100025, 0x00000000, 0x00000000}},  //   nzin_, بلة_,   ,
  { {0x693c037e, 0x7d0d00b4, 0x66fa0316, 0x00000000}},  //   _pčel, _skas, ौकिक_,
  { {0xc04f0822, 0xb8000055, 0x4c95234c, 0x00000000}},  //   _ні_, ্ধিত_, оинс,
  { {0x64421b30, 0x6913011f, 0x60db1dec, 0x00000000}},  //   ncoi, rçek, chum,
  { {0x68ed253d, 0x78a40197, 0x00000000, 0x00000000}},  //   viad, ddiv,   ,
  { {0x68ed34c3, 0x27e00036, 0x7c360010, 0x00000000}},  //   wiad, dzin_, _egyr,
  { {0x68ed018e, 0x6ce703e8, 0x27e00288, 0x00000000}},  //   tiad, _гіпе, ezin_,
  { {0x98c4004d, 0x7d0d00e7, 0x32cb00ea, 0x00000000}},  //   псул, _ukas, _høyt_,
  { {0x68ed0027, 0x799e01aa, 0x7aee1b5f, 0x00000000}},  // [d330] riad, _espw, bibt,
  { {0x68ed3a55, 0xa3ac013d, 0x69ce0a5e, 0x00000000}},  //   siad, गिन_, bybe,
  { {0x68ed0211, 0x69ce00b5, 0x78a40133, 0x00000000}},  //   piad, cybe, bdiv,
  { {0x76490279, 0x26d80146, 0x00000000, 0x00000000}},  //   _şeyd, _elro_,   ,
  { {0xd0061095, 0x987a0049, 0x7cef01aa, 0x00000000}},  //   _آل_, _דארט, _zòrè,
  { {0x23690059, 0x799e0045, 0x66d203e3, 0x00000000}},  //   šajo_, _yspw, _lækj,
  { {0xa4d501fb, 0x60db0009, 0xe5c401bd, 0x00000000}},  //   _дові, thum, _есто,
  { {0x2b490091, 0x20d10051, 0xdce20089, 0x00000000}},  //   _otac_, _táim_, rtlī,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60db0035, 0x4d651662, 0xdb04004a, 0x00000000}},  //   shum, оков, _prií,
  { {0x27e0057e, 0xed59012b, 0x2b493a56, 0x00000000}},  //   zzin_, јом_, _atac_,
  { {0x7fd502f0, 0x1d0a017f, 0x69ce3a57, 0x00000000}},  //   _мілі, реми_, vybe,
  { {0xf8bf00f4, 0x78a404bb, 0xf8b80082, 0x00000000}},  //   _liés_, vdiv, _đĩ_,
  { {0x69ce0006, 0x201d0045, 0x00000000, 0x00000000}},  //   tybe, _izwi_,   ,
  { {0x78a42fec, 0xde02003b, 0x19b90152, 0x00000000}},  //   tdiv, _опши, буть_,
  { {0x27e00c2f, 0x645b3a58, 0x69ce007f, 0x00000000}},  //   tzin_, _neui, rybe,
  { {0xeb9a01e0, 0x78a408a7, 0xf092009b, 0x00000000}},  // [d340] _тип_, rdiv, ונן_,
  { {0x78a423b5, 0x3200026d, 0x00000000, 0x00000000}},  //   sdiv, şiyi_,   ,
  { {0x66d207a8, 0x765e103b, 0xfc3f02a0, 0x00000000}},  //   _hækk, rapy, ldía_,
  { {0x2d850009, 0x83fd0010, 0x00000000, 0x00000000}},  //   itle_, _időj,   ,
  { {0x693c3a59, 0xfc3f008e, 0x6442009d, 0x00000000}},  //   _oček, ndía_, rcoi,
  { {0x386000b5, 0x644207a7, 0x248d08df, 0x00000000}},  //   lair_, scoi, _ebem_,
  { {0xd2590ee0, 0x645b00f4, 0x66d20dba, 0x00000000}},  //   сці_, _feui, _lækk,
  { {0x38601625, 0xf48600a1, 0xf8bf01c3, 0x00000000}},  //   nair_, _گاڑی, _hiér_,
  { {0x60f7008b, 0xb60200b9, 0x7bcf00ea, 0x00000000}},  //   ўныя_, řádn, xycu,
  { {0x3860002a, 0x66d2000c, 0x61010089, 0x00000000}},  //   hair_, _sækj, vēle,
  { {0x765c330c, 0xf8bf008e, 0x25a50010, 0x00000000}},  //   _mery, _miér_, _állt_,
  { {0x628a0016, 0xa6db000c, 0x66d20190, 0x00000000}},  //   lffo, _guðf, _bækk,
  { {0x38600fb8, 0xd0f90049, 0x61350006, 0x00000000}},  //   dair_, _פּער, _išla,
  { {0x66d20030, 0x32cb00ea, 0x765c007f, 0x00000000}},  //   _dækk, _høyr_, _nery,
  { {0x38600905, 0x32cb00ea, 0x66d2000c, 0x00000000}},  //   fair_, _køyr_, _tækj,
  { {0x386031f0, 0x765c000a, 0x66d2000c, 0x00000000}},  //   gair_, _aery, _fækk,
  { {0x14ab007d, 0x765c0016, 0xb8e3007d, 0x00000000}},  // [d350] _घोषण, _bery, _एच_,
  { {0x753c0142, 0x6298016e, 0x645b009d, 0x00000000}},  //   _burz, jevo, _seui,
  { {0x62980197, 0x753c0026, 0x38600051, 0x00000000}},  //   devo, _curz, bair_,
  { {0x38601aed, 0x27ed016e, 0x291e0129, 0x00000000}},  //   cair_, _ženu_, ïtat_,
  { {0x645b00f4, 0x6aa504d4, 0x753c0087, 0x00000000}},  //   _veui, _kahf, _eurz,
  { {0x62980100, 0x753c01f3, 0x765c01d6, 0x00000000}},  //   gevo, _furz, _gery,
  { {0x248d00fa, 0x6d4a01f3, 0x00000000, 0x00000000}},  //   _tbem_, _ntfa,   ,
  { {0x673d3a5a, 0x7645005b, 0xbebc01c5, 0x00000000}},  //   _kusj, lchy, smīl,
  { {0x73d90517, 0x62980125, 0x32cb00ea, 0x00000000}},  //   _удар_, bevo, _døyr_,
  { {0x2d850038, 0xd2510054, 0x629836e1, 0x00000000}},  //   ttle_, _أنا_, cevo,
  { {0xdca601e0, 0x62810146, 0x67350066, 0x00000000}},  //   пани, _iclo, _mizj,
  { {0xeb9a3975, 0x386001f3, 0x2d850133, 0x00000000}},  //   бим_, xair_, rtle_,
  { {0x386000d4, 0x2d8500ab, 0xcee800a1, 0x00000000}},  //   vair_, stle_, صرین_,
  { {0xfaff0065, 0x255801aa, 0xfc3f13ac, 0x00000000}},  //   drës_, yōl_, rdía_,
  { {0x38600882, 0x6281004a, 0xfaff0023, 0x00000000}},  //   tair_, _mclo, erës_,
  { {0x765c3a5b, 0x76450016, 0xe2070036, 0x00000000}},  //   _sery, echy, ciół_,
  { {0x38603a5c, 0x96960242, 0x765c1cdf, 0x00000000}},  // [d360] rair_, зреш, _pery,
  { {0xfc3f0d62, 0x38600048, 0x00000000, 0x00000000}},  //   ndín_, sair_,   ,
  { {0x765c2238, 0x80db006e, 0x2a57034e, 0x00000000}},  //   _very, बसाइ, _מבין_,
  { {0xa3d70061, 0x628100f6, 0xfaff0023, 0x00000000}},  //   ानं_, _aclo, brës_,
  { {0x7e61001e, 0x62982100, 0xaae50014, 0x00000000}},  //   kalp, tevo, _رسیو,
  { {0x753c0716, 0x00000000, 0x00000000, 0x00000000}},  //   _turz,   ,   ,
  { {0x78a601cd, 0x628a018e, 0x6298321f, 0x00000000}},  //   _kakv, rffo, revo,
  { {0x64a33a5d, 0x4034005e, 0x318e006b, 0x00000000}},  //   _паса, мейс, _cəza_,
  { {0x20d8002a, 0x2002005f, 0x62983a5e, 0x00000000}},  //   _féin_, çki_, pevo,
  { {0x7e610dfb, 0xe804013d, 0x62810048, 0x00000000}},  //   galp, _रखना_, _gclo,
  { {0x26ca1b3e, 0xdc990088, 0x00000000, 0x00000000}},  //   _mobo_, овні_,   ,
  { {0x26ca1a16, 0x78a60006, 0x98ab001a, 0x00000000}},  //   _lobo_, _nakv, _mică_,
  { {0x7e6107ef, 0x6b9d00bb, 0x66d3014a, 0x00000000}},  //   balp, uwsg, _yıkı,
  { {0x7e61004a, 0x6125000c, 0x8f9b034e, 0x00000000}},  //   calp, gólf, _לידי,
  { {0x673d0243, 0x6d4a02e1, 0x78a62259, 0x00000000}},  //   _susj, _utfa, _bakv,
  { {0xfaff0065, 0x23660023, 0x6934030d, 0x00000000}},  //   trës_, ksoj_, енсу,
  { {0x26ca34bd, 0x4735008b, 0x78a600d9, 0x00000000}},  // [d370] _bobo_, днас, _dakv,
  { {0xfaff0065, 0xb9990088, 0x26ca0919, 0x00000000}},  //   rrës_, _двох_, _cobo_,
  { {0x76450016, 0x26ca00ca, 0xfc3f004a, 0x00000000}},  //   rchy, _dobo_, ndío_,
  { {0xe4e401e1, 0x66d3014a, 0x661500b9, 0x00000000}},  //   нічн, _sıkı, _vyzk,
  { {0x656510e8, 0xa7fb0288, 0x00000000, 0x00000000}},  //   sshh, _beñe,   ,
  { {0x26ca0087, 0x90d50082, 0xf2c70930, 0x00000000}},  //   _gobo_, _cùn, ясен,
  { {0x65941734, 0x26fb006e, 0x7e610239, 0x00000000}},  //   _пару, ्वीर_, valp,
  { {0xb4650014, 0x318e006b, 0xe1f00439, 0x00000000}},  //   _آگاه, _qəza_, دسه_,
  { {0x7e61215b, 0x7d0f230c, 0x66d2000c, 0x00000000}},  //   talp, docs, _sæki,
  { {0xe3b00318, 0xef160057, 0xb87b00b9, 0x00000000}},  //   _حرف_, ммы_, _hlíd,
  { {0xfc3f03bc, 0x7e610240, 0x213e0051, 0x00000000}},  //   rdín_, ralp, _guth_,
  { {0x2d670107, 0xe3e40044, 0x00000000, 0x00000000}},  //   rđe_, _ফুটব,   ,
  { {0x78a6006c, 0x7e610058, 0xef0e094b, 0x00000000}},  //   _rakv, palp, _ам_,
  { {0xed59012b, 0x66d2000c, 0x6913014a, 0x00000000}},  //   _док_, _tæki, kçes,
  { {0x26ca113f, 0x78a60006, 0x7d0f0010, 0x00000000}},  //   _robo_, _pakv, bocs,
  { {0x693c0091, 0x26ca0059, 0x00000000, 0x00000000}},  //   _očev, _sobo_,   ,
  { {0xf7720025, 0x3ea700c7, 0x59ba03d7, 0x00000000}},  // [d380] ضاء_, _kant_, _उपकर,
  { {0x60cb0190, 0x2366016c, 0x6125000c, 0x00000000}},  //   _logm, vsoj_, bólg,
  { {0x78a61353, 0xa9263a5f, 0x3ea7000a, 0x00000000}},  //   _takv, _одол, _mant_,
  { {0x26ca0263, 0x60cb00c1, 0x3ea71a50, 0x00000000}},  //   _wobo_, _nogm, _lant_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x64490181, 0x61010089, 0x3ea70016, 0x00000000}},  //   _efei, vēla, _nant_,
  { {0x60cb0eea, 0x6449018e, 0xdb0400f6, 0x00000000}},  //   _bogm, _ffei, _eriç,
  { {0xa6db000c, 0x3ea700d9, 0xd702007e, 0x00000000}},  //   _guðb, _aant_, нiча,
  { {0xa7fb049a, 0xe2920076, 0x00000000, 0x00000000}},  //   _teñe, _لذا_,   ,
  { {0x3ea70675, 0x2018001e, 0x2902012d, 0x00000000}},  //   _cant_, āri_, _ljka_,
  { {0x8af7006b, 0x3ea7005b, 0x6b960006, 0x00000000}},  //   şəka, _dant_, _apyg,
  { {0xfc3f004a, 0x00000000, 0x00000000, 0x00000000}},  //   rdío_,   ,   ,
  { {0x800800a1, 0x9b58005e, 0x3ea71bc1, 0x00000000}},  //   _عرصہ_, мият_, _fant_,
  { {0x3ea70f75, 0x00000000, 0x00000000, 0x00000000}},  //   _gant_,   ,   ,
  { {0x20d80051, 0xdb0d009d, 0xdce20089, 0x00000000}},  //   _léim_, _fraî, gulē,
  { {0xe894007e, 0xcd2b0014, 0x2369066c, 0x00000000}},  //   кась, _بستن_, šaji_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [d390]   ,   ,   ,
  { {0x4a550088, 0xfc3f00b9, 0x20d10051, 0x00000000}},  //   _якос, zdíl_, _háit_,
  { {0x6449010f, 0x7cf6012d, 0x00000000, 0x00000000}},  //   _pfei, lšra,   ,
  { {0x2458008b, 0x20d80051, 0x00000000, 0x00000000}},  //   даць_, _béim_,   ,
  { {0xe6670072, 0x20d80051, 0x69d51688, 0x00000000}},  //   _отво, _céim_, lyze,
  { {0x66d2000c, 0x2ca9015b, 0x7af51113, 0x00000000}},  //   _bæku, _laad_, nizt,
  { {0xb87b00b9, 0x3ea719aa, 0x00000000, 0x00000000}},  //   _umís, _rant_,   ,
  { {0x3a3800b6, 0x3ea704bd, 0x00000000, 0x00000000}},  //   ורום_, _sant_,   ,
  { {0x3ea70190, 0x00000000, 0x00000000, 0x00000000}},  //   _pant_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3d70309, 0x3ea71129, 0xc69201ce, 0x00000000}},  //   ानक_, _vant_, נאט_,
  { {0x3ea73a60, 0xeb9a3a61, 0x98ac0089, 0x00000000}},  //   _want_, пим_, īdī_,
  { {0x3ea704bd, 0x2ca900c7, 0x00000000, 0x00000000}},  //   _tant_, _daad_,   ,
  { {0x693c08fb, 0x7af52512, 0xbea22882, 0x00000000}},  //   _očet, gizt, _башк,
  { {0x09e60407, 0xc5fa0044, 0x682a0010, 0x00000000}},  //   ховн, _অর্থ_, ködé,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xcb6a0014, 0x66760014, 0x7af50e0c, 0x00000000}},  // [d3a0] _عمده_, فدار, bizt,
  { {0x2ca900bb, 0x20d80048, 0x69c808e0, 0x00000000}},  //   _zaad_, _réim_, ødes,
  { {0x69c1006c, 0x61010089, 0x00000000, 0x00000000}},  //   älet, vēln,   ,
  { {0x20d1081d, 0xe73a007c, 0x00000000, 0x00000000}},  //   _máis_, _нем_,   ,
  { {0x883b00b6, 0x29000208, 0x98160647, 0x00000000}},  //   _מתכו, mnia_, _سبحا,
  { {0x68e40181, 0x21260065, 0x29003a62, 0x00000000}},  //   lhid, _shoh_, lnia_,
  { {0x0496008b, 0x3ce001aa, 0x290001b1, 0x00000000}},  //   _праў, _oliv_, onia_,
  { {0x7c2401d9, 0x29000056, 0xb87b0285, 0x00000000}},  //   _ozir, nnia_, _ilíc,
  { {0xd2520054, 0x2ca900c7, 0x7c2414a5, 0x00000000}},  //   _منذ_, _raad_, _nzir,
  { {0x15f402d2, 0x7d040ed7, 0x2ca9006c, 0x00000000}},  //   _आधार_, _ajis, _saad_,
  { {0x20d601fb, 0x3ce00030, 0x7c240202, 0x00000000}},  //   _підс, _bliv_, _azir,
  { {0xa7fb004a, 0x212601c3, 0x00000000, 0x00000000}},  //   _leña, _uhoh_,   ,
  { {0x29003a63, 0x29121d42, 0x63a21248, 0x00000000}},  //   dnia_, doya_, nwon,
  { {0x29000046, 0x7c240089, 0xf8bf0011, 0x00000000}},  //   enia_, _dzir, _chén_,
  { {0x20d10051, 0xe9190088, 0x7de601cc, 0x00000000}},  //   _gáis_, дові_, _désé,
  { {0x29000207, 0x5ba70088, 0x68e40051, 0x00000000}},  //   gnia_, _зроз, ghid,
  { {0xb87b19bf, 0xa7fb0032, 0x7c240066, 0x00000000}},  // [d3b0] _alíc, _beña, _gzir,
  { {0x2900006c, 0x7d0400b9, 0x7d1d074d, 0x00000000}},  //   ania_, _zjis, llss,
  { {0x66d2000c, 0x63a200bb, 0x68e420c4, 0x00000000}},  //   _rækt, ewon, bhid,
  { {0x693c0224, 0xdb04000a, 0x68e40585, 0x00000000}},  //   _včet, _asiè, chid,
  { {0xd414007e, 0x78ad2b0e, 0x00000000, 0x00000000}},  //   льшы, mdav,   ,
  { {0xe2960aa2, 0x78ad006c, 0xf8bf0011, 0x00000000}},  //   ваш_, ldav, _khéo_,
  { {0x27e90066, 0x693c0059, 0x80aa0044, 0x00000000}},  //   lzan_, _hčer, কান্,
  { {0x78ad0ad1, 0x63a20009, 0x00000000, 0x00000000}},  //   ndav, bwon,   ,
  { {0x27e90211, 0x64590117, 0x60090088, 0x00000000}},  //   nzan_, mbwi, ьним_,
  { {0x7d160006, 0x29000036, 0x443f0022, 0x00000000}},  //   _skys, znia_, _hgu_,
  { {0x1d0a0794, 0x29000036, 0x68e40009, 0x00000000}},  //   дени_, ynia_, yhid,
  { {0x7649005a, 0xcb6a026b, 0x23690091, 0x00000000}},  //   _şeyl, маме_, šaju_,
  { {0x83fd0010, 0x60db0020, 0x3ce000b9, 0x00000000}},  //   _idős, mkum, _vliv_,
  { {0x78bd05cb, 0x68e43a64, 0x60c9006c, 0x00000000}},  //   _ansv, whid, ljem,
  { {0x29000036, 0x3f8d0129, 0x68e40048, 0x00000000}},  //   tnia_, lteu_, thid,
  { {0xa7fb0211, 0x60c92755, 0x443f0011, 0x00000000}},  //   _seña, njem, _ngu_,
  { {0xa6860099, 0x6d43018e, 0x7e630173, 0x00000000}},  // [d3c0] клад, _huna, _kenp,
  { {0x6d431448, 0x68e40727, 0x3946007c, 0x00000000}},  //   _kuna, shid, _иног,
  { {0x60db3a65, 0x64a600ed, 0x7e633a66, 0x00000000}},  //   kkum, кажа, _menp,
  { {0x385a00a1, 0x63a201aa, 0x443f009d, 0x00000000}},  //   _تشدد_, twon, _cgu_,
  { {0x6d431143, 0xa7fb027b, 0x60c90107, 0x00000000}},  //   _luna, _teña, djem,
  { {0x7e630263, 0x66d20030, 0x63a23a67, 0x00000000}},  //   _nenp, _væks, rwon,
  { {0x693c05fa, 0x63a23a68, 0x557927f9, 0x00000000}},  //   _učes, swon, _пётр_,
  { {0x75290afb, 0x63a200b5, 0x60c90023, 0x00000000}},  //   _ghez, pwon, gjem,
  { {0x673c0368, 0x68e3001a, 0x7ce60051, 0x00000000}},  //   _kirj, _înde, _mórd,
  { {0x6d43002a, 0x661c067e, 0x78ad3a69, 0x00000000}},  //   _buna, _kyrk, zdav,
  { {0x7e63023a, 0x867b009b, 0x6d430023, 0x00000000}},  //   _denp, וריו, _cuna,
  { {0x6d430142, 0x661c12de, 0x9f640010, 0x00000000}},  //   _duna, _myrk, ától_,
  { {0x78ad3a6a, 0x7d1d0039, 0x3f8d00d4, 0x00000000}},  //   vdav, rlss, cteu_,
  { {0x67da0089, 0x6d4300c4, 0x7e630146, 0x00000000}},  //   _mājā, _funa, _genp,
  { {0x6d4304cb, 0x7e680190, 0x661c00b0, 0x00000000}},  //   _guna, madp, _nyrk,
  { {0x7ce60211, 0x27e9002d, 0x2018006b, 0x00000000}},  //   _córd, tzan_, ərir_,
  { {0x78ad010a, 0x6d433a6b, 0x673c177c, 0x00000000}},  // [d3d0] rdav, _zuna, _birj,
  { {0xe719006d, 0x443f0030, 0x6d43049d, 0x00000000}},  //   ريات_, _sgu_, _yuna,
  { {0x673c023a, 0x693c1e90, 0xb87b3a6c, 0x00000000}},  //   _dirj, _včer, _elía,
  { {0x6125000c, 0x661c2314, 0xa6db000c, 0x00000000}},  //   kóla, _dyrk, _guðn,
  { {0xdfc606f1, 0x386901b5, 0xf8bf0027, 0x00000000}},  //   _اي_, maar_, _iné_,
  { {0x386900c7, 0x9f9c009f, 0x61350006, 0x00000000}},  //   laar_, _ræða_, _išli,
  { {0x628300ea, 0x7e68004a, 0x60c9037a, 0x00000000}},  //   rgno, dadp, tjem,
  { {0x6d430089, 0x38690100, 0x7e6301aa, 0x00000000}},  //   _runa, naar_, _senp,
  { {0x776d049a, 0x60db3a6d, 0x7e63134e, 0x00000000}},  //   nsax, rkum, _penp,
  { {0xfe710054, 0x6d4303b6, 0x63a935c8, 0x00000000}},  //   حدة_, _puna, _isen,
  { {0x38690100, 0x415501fc, 0x26d1008e, 0x00000000}},  //   kaar_, _свес, _mozo_,
  { {0x386901b5, 0x7e6301d6, 0x55960049, 0x00000000}},  //   jaar_, _wenp, נדרע_,
  { {0xf8bf0011, 0xd110006e, 0x7e63002d, 0x00000000}},  //   _chém_, ावरण_, _tenp,
  { {0x6d430503, 0xf8bf18d9, 0x7ce600d6, 0x00000000}},  //   _tuna, _ané_, _sórd,
  { {0x09e302a8, 0x6d430058, 0x00000000, 0x00000000}},  //   борн, _uuna,   ,
  { {0x673c0acc, 0x4c86005e, 0x386901d6, 0x00000000}},  //   _sirj, _слив, gaar_,
  { {0x6b8f001c, 0x673c1c79, 0x63a90020, 0x00000000}},  // [d3e0] ctcg, _pirj, _nsen,
  { {0x661c00b0, 0x29190022, 0x00000000, 0x00000000}},  //   _pyrk, _eksa_,   ,
  { {0x63a90368, 0x3869049b, 0x44220626, 0x00000000}},  //   _asen, baar_, _šk_,
  { {0x98ba000d, 0x938a005e, 0xb97b0097, 0x00000000}},  //   _după_, еска_, _אנטי,
  { {0x667402fd, 0x63a90010, 0x628800c4, 0x00000000}},  //   _نگار, _csen, _pcdo,
  { {0x26d122d1, 0x661c01e3, 0x610800b9, 0x00000000}},  //   _gozo_, _tyrk, děla,
  { {0x63a9106f, 0x7ce600fa, 0x7e68109c, 0x00000000}},  //   _esen, _mórb, vadp,
  { {0x6ad1006e, 0x26d10173, 0x6125134d, 0x00000000}},  //   _सक्र, _zozo_, tóla,
  { {0xdfd00379, 0x8406007e, 0x00000000, 0x00000000}},  //   زيد_, _спаж,   ,
  { {0x83fd0047, 0x61460175, 0x539b009b, 0x00000000}},  //   _időp, _бежа, _אימו,
  { {0x02d51662, 0x067b0049, 0xdd94007e, 0x00000000}},  //   _тютю, ענטל, шаны,
  { {0x13d80055, 0x248639d0, 0xc5f3009b, 0x00000000}},  //   _দেয়, ngom_, מדת_,
  { {0x386901bb, 0xfd1f0197, 0x7e680058, 0x00000000}},  //   vaar_, rlì_, padp,
  { {0xa7fb0211, 0xb87b0576, 0x386901b5, 0x00000000}},  //   _seño, _clín, waar_,
  { {0x318e005f, 0x3869256d, 0x29190022, 0x00000000}},  //   _bəzi_, taar_, _pksa_,
  { {0x3eae0239, 0x00000000, 0x00000000, 0x00000000}},  //   _haft_,   ,   ,
  { {0x386900c7, 0x26d1008e, 0xf7700025, 0x00000000}},  // [d3f0] raar_, _pozo_, كال_,
  { {0xa3d80204, 0x3869006c, 0xa3b3006e, 0x00000000}},  //   ाहन_, saar_, टिस_,
  { {0x63a9013f, 0xe8950139, 0x00000000, 0x00000000}},  //   _ssen, _кань,   ,
  { {0xb87b01dc, 0xa8a70242, 0xddc10035, 0x00000000}},  //   _zlín, _срок, lalţ,
  { {0x3cfd006e, 0xb4640088, 0x2738013f, 0x00000000}},  //   _लगने_, скіл, zünə_,
  { {0xe29908fd, 0x61250046, 0x321e06b8, 0x00000000}},  //   так_, góln, _byty_,
  { {0xd49b0551, 0x333e0288, 0x00000000, 0x00000000}},  //   _пра_, _ditx_,   ,
  { {0xdfd10054, 0x63a93a6e, 0x2a6a0010, 0x00000000}},  //   قيع_, _tsen, zabb_,
  { {0x78af01ee, 0x82870464, 0x6d4e0f3b, 0x00000000}},  //   _macv, _مجال, íban,
  { {0x2738006b, 0x877c0049, 0x00000000, 0x00000000}},  //   tünə_, גאזי,   ,
  { {0xf2c40ae0, 0x6cc6326d, 0xb2ba08cd, 0x00000000}},  //   _устн, айна, _שמער,
  { {0x6125004a, 0x00000000, 0x00000000, 0x00000000}},  //   mólo,   ,   ,
  { {0xb87b1050, 0x6125004a, 0x00000000, 0x00000000}},  //   _plín, lólo,   ,
  { {0xab2a16b6, 0x00000000, 0x00000000, 0x00000000}},  //   тога_,   ,   ,
  { {0x61253a6f, 0xb87b0048, 0x186a00c0, 0x00000000}},  //   nólo, _clío, кави_,
  { {0x2a6a0047, 0xb87b0048, 0x386600fa, 0x00000000}},  //   sabb_, _dlío, úor_,

  { {0xb8fe03d7, 0x974800a1, 0x9666007c, 0x00000000}},  // [d400] _तक_, اثرہ_, икае,
  { {0xe9da00e3, 0xf6560245, 0x3eae0066, 0x00000000}},  //   _ако_, ртаю, _xaft_,
  { {0xa6db000c, 0x546a0865, 0x7afc3a70, 0x00000000}},  //   _guðm, ваем_, mirt,
  { {0x7afc011f, 0x69dc00ea, 0x61250325, 0x00000000}},  //   lirt, myre, dólo,
  { {0x33f600ed, 0x24860010, 0x69dc0010, 0x00000000}},  //   јчес, rgom_, lyre,
  { {0x66e60113, 0x78a40006, 0x05260044, 0x00000000}},  //   _тога, leiv, যদের_,
  { {0x64a603e0, 0x69dc0065, 0x00000000, 0x00000000}},  //   _кава, nyre,   ,
  { {0xc953012f, 0x21100204, 0xa3b3006e, 0x00000000}},  //   חמה_, ावेश_, टिश_,
  { {0x61250036, 0x7afc007f, 0x69dc07c3, 0x00000000}},  //   póln, kirt, hyre,
  { {0x752200bb, 0x69dc0032, 0x00000000, 0x00000000}},  //   lloz, kyre,   ,
  { {0x61250285, 0x7afc2c50, 0x10a6026b, 0x00000000}},  //   cólo, dirt, _виен,
  { {0x69dc05d5, 0x00000000, 0x00000000, 0x00000000}},  //   dyre,   ,   ,
  { {0x8f5401fa, 0x60c20039, 0x799e00e5, 0x00000000}},  //   _انتش, _inom, _appw,
  { {0x3f84150a, 0x6e9400f9, 0x260f0061, 0x00000000}},  //   mumu_, _طلبا, _तुझी_,
  { {0x5d840025, 0x3f840020, 0x75223a71, 0x00000000}},  //   _العل, lumu_, kloz,
  { {0x6d5a0fdb, 0xdb0d0181, 0x91fc0089, 0x00000000}},  //   mpta, _oraç, _reāl,
  { {0x7afc049a, 0x3f843a72, 0x629a0059, 0x00000000}},  // [d410] birt, numu_, _obto,
  { {0x45450025, 0x7afc1363, 0x69dc0190, 0x00000000}},  //   منطق, cirt, byre,
  { {0xdb0d3a73, 0xc50b00a1, 0x60c20091, 0x00000000}},  //   _araç, پتال_, _onom,
  { {0x3f843a74, 0x451801fb, 0x78a40038, 0x00000000}},  //   kumu_, ація_, ceiv,
  { {0x3f84001e, 0x889a00b3, 0x07a4007e, 0x00000000}},  //   jumu_, _גברי, _даўн,
  { {0x60c20129, 0x3f8412bd, 0x61253a75, 0x00000000}},  //   _anom, dumu_, tólo,
  { {0xe05702fd, 0xfa7800b3, 0x75220173, 0x00000000}},  //   لیات_, בעות_, bloz,
  { {0xb87b3a76, 0x27ed0428, 0x8505025a, 0x00000000}},  //   _olím, _ženy_, _اورن,
  { {0x3f843a74, 0xdb0d0181, 0xef190265, 0x00000000}},  //   gumu_, _graç, лми_,
  { {0x63bb002d, 0xa1f700a1, 0x0d85007c, 0x00000000}},  //   _irun, _پڑتا_, блон,
  { {0xdc6a00ed, 0x6da5005e, 0x63bb000c, 0x00000000}},  //   ланд_, щина, _hrun,
  { {0x7afc010f, 0x3f8410d9, 0x63bb0cde, 0x00000000}},  //   wirt, bumu_, _krun,
  { {0x7ce6002a, 0x7afc0006, 0x3f843443, 0x00000000}},  //   _córa, tirt, cumu_,
  { {0x7522037e, 0x69dc0ce3, 0x7c28006b, 0x00000000}},  //   zloz, tyre, ədrl,
  { {0xf2d2007b, 0x7afc009f, 0x3ea53a77, 0x00000000}},  //   לעך_, rirt, melt_,
  { {0x7ce6002a, 0xdcfb0089, 0x26c300c4, 0x00000000}},  //   _fóra, putā, _anjo_,
  { {0x7afc3a78, 0x2d850938, 0x69dc121d, 0x00000000}},  // [d420] pirt, lule_, syre,
  { {0x3ea50056, 0x69c83a79, 0x7c5700a2, 0x00000000}},  //   nelt_, ädes, _پلیر_,
  { {0x63bb001a, 0xfad70049, 0x41a6013d, 0x00000000}},  //   _arun, _הויך_, _कैंस,
  { {0x20d8002a, 0xdb0d0181, 0x63bb288f, 0x00000000}},  //   _léir_, _praç, _brun,
  { {0x2d85001f, 0x3ea501e2, 0xd91b009b, 0x00000000}},  //   hule_, kelt_, _תוכל,
  { {0x2d850004, 0x6d5a2671, 0x3f840089, 0x00000000}},  //   kule_, ypta, vumu_,
  { {0xd13004e1, 0x2167012b, 0x3ea5006c, 0x00000000}},  //   ومت_, бији_, delt_,
  { {0x3f8427dc, 0x63bb2ed2, 0x9f5402d3, 0x00000000}},  //   tumu_, _frun, ович,
  { {0x39420004, 0x3ea50056, 0x386000c4, 0x00000000}},  //   _miks_, felt_, ibir_,
  { {0x3f843a7a, 0x3ea50eaa, 0xd36f0025, 0x00000000}},  //   rumu_, gelt_, _أهل_,
  { {0x3f8401c5, 0x2d85006c, 0x171b0049, 0x00000000}},  //   sumu_, gule_, רויע,
  { {0x39423a7b, 0x6d5a0ebc, 0xf1b30104, 0x00000000}},  //   _niks_, rpta, _מסע_,
  { {0x3ea50193, 0x38603a7c, 0xddc10b18, 0x00000000}},  //   belt_, dbir_, ralš,
  { {0x628a0193, 0xde580099, 0x3ea5001e, 0x00000000}},  //   ngfo, _такі_, celt_,
  { {0x2d853a7d, 0x13c30044, 0xf3f9001a, 0x00000000}},  //   cule_, ্নয়, _veţi_,
  { {0x7ce63a7e, 0x6f1a0943, 0x2a7f013f, 0x00000000}},  //   _tóra, lotc, şub_,
  { {0x6bda00a1, 0x69c803a2, 0x6d4a0020, 0x00000000}},  // [d430] _نوٹس_, äder, _hufa,
  { {0x6d4a000b, 0x7c2d3138, 0x6f1a0085, 0x00000000}},  //   _kufa, _izar, notc,
  { {0x3860002b, 0xbb3c0049, 0x39422a2b, 0x00000000}},  //   bbir_, _געזי, _fiks_,
  { {0xa6340088, 0x3ea502fa, 0x63bb0585, 0x00000000}},  //   їнці, zelt_, _prun,
  { {0xd37b003b, 0x68ed0051, 0x2d850032, 0x00000000}},  //   уче_, mhad, zule_,
  { {0x68ed3a7f, 0x6d581435, 0xa5e71561, 0x00000000}},  //   lhad, _otva, _любл,
  { {0x20d8002a, 0x3ea51957, 0x23600089, 0x00000000}},  //   _réir_, velt_, ģija_,
  { {0x68ed0767, 0xe0d9005e, 0x63bb0a60, 0x00000000}},  //   nhad, рви_, _trun,
  { {0x443902d5, 0x3ea53a77, 0x6d580dec, 0x00000000}},  //   _às_, telt_, _atva,
  { {0x2d852836, 0x7d0d03b6, 0x7ce61343, 0x00000000}},  //   tule_, _ajas, _córn,
  { {0x3cca09ae, 0x3ea505b7, 0x7079089d, 0x00000000}},  //   ално_, relt_, _نماز_,
  { {0x3ea50004, 0x2d85006c, 0x8f6a00a1, 0x00000000}},  //   selt_, rule_, _چلنے_,
  { {0x7c2d0046, 0xdb040b33, 0x3ea50232, 0x00000000}},  //   _czar, _asiá, pelt_,
  { {0x76470065, 0x7ce60036, 0x2d85010e, 0x00000000}},  //   _ngjy, _górn, pule_,
  { {0x7c2d022b, 0x442d0224, 0x6d4a3a80, 0x00000000}},  //   _ezar, _lze_, _gufa,
  { {0xa3e90164, 0xa92601fb, 0x7d0d0065, 0x00000000}},  //   मना_, ідал, _gjas,
  { {0x442d0009, 0x6d4a0598, 0x386b0026, 0x00000000}},  // [d440] _nze_, _zufa, _decr_,
  { {0x98b90089, 0x7f43002b, 0x6125000c, 0x00000000}},  //   _visā_, _jinq, fólk,
  { {0x39420e3f, 0x68ed0051, 0x442d006b, 0x00000000}},  //   _tiks_, bhad, _aze_,
  { {0x76490279, 0x14260131, 0x6e2301d6, 0x00000000}},  //   _şeyt, одем, _mynb,
  { {0x442d0036, 0xf77205d4, 0x68e43a81, 0x00000000}},  //   _cze_, _تاج_, mkid,
  { {0x6d440b3e, 0xe57100a1, 0x272f014a, 0x00000000}},  //   _liia, بطے_, tüne_,
  { {0x442d0032, 0x7e6a04df, 0x628a0168, 0x00000000}},  //   _eze_, _refp, rgfo,
  { {0x6d4a0020, 0x68e43a82, 0x98a0050f, 0x00000000}},  //   _rufa, nkid, klič_,
  { {0x6d580825, 0xb87b009f, 0x27e001aa, 0x00000000}},  //   _stva, _slík, nyin_,
  { {0x232a0265, 0x7f430207, 0x6f080061, 0x00000000}},  //   _този_, _cinq, undc,
  { {0x7c2d115b, 0xf653009b, 0x68e4006c, 0x00000000}},  //   _szar, וצת_, kkid,
  { {0x26d80198, 0x6e230009, 0x44240142, 0x00000000}},  //   _loro_, _dynb, _kym_,
  { {0x7f4300d4, 0x6f1a0087, 0xa7fb008e, 0x00000000}},  //   _finq, potc, _teñi,
  { {0x26d82066, 0x6d4a0c04, 0x6e232c4a, 0x00000000}},  //   _noro_, _tufa, _fynb,
  { {0x5b1401fb, 0x6d5815b3, 0x68ed0051, 0x00000000}},  //   ємст, _utva, thad,
  { {0x7d0d3a83, 0x02b7007d, 0x7c2d15ed, 0x00000000}},  //   _ujas, _आफ्न, _tzar,
  { {0x68ed0149, 0x26d8016c, 0x7d1d0207, 0x00000000}},  // [d450] rhad, _boro_, moss,
  { {0x7d1d178a, 0x68ed0061, 0x26d808d3, 0x00000000}},  //   loss, shad, _coro_,
  { {0x25480279, 0x68ed297d, 0xdb04004a, 0x00000000}},  //   _oğlu_, phad, _griñ,
  { {0x7d1d00f2, 0xe4e401ff, 0x44240036, 0x00000000}},  //   noss, мічн, _bym_,
  { {0x26d80219, 0xa3a7031d, 0x27f20036, 0x00000000}},  //   _foro_, تحان, czyn_,
  { {0xa6db009f, 0x6d0203d7, 0xdb0d0181, 0x00000000}},  //   _auðv, _लगभग_, _araú,
  { {0x7d1d0ae4, 0xddc3001a, 0x1a9c0049, 0x00000000}},  //   koss, _menţ, ייגע,
  { {0x7f4308b6, 0x54550cee, 0xf8bf0011, 0x00000000}},  //   _sinq, _хват, _ghét_,
  { {0x7d1d0625, 0x6d44010e, 0xbebc0089, 0x00000000}},  //   doss, _riia, rlīn,
  { {0x68e4002d, 0x6d44006c, 0x62670688, 0x00000000}},  //   zkid, _siia, _ذائق,
  { {0xa3b3006e, 0x61253a84, 0x7d1d2bf1, 0x00000000}},  //   टिक_, hóli, foss,
  { {0x692c010f, 0x7d1d0010, 0x6eed06c2, 0x00000000}},  //   eßen, goss, _súbd,
  { {0xeb9701e0, 0x7f433a85, 0x6e2301d6, 0x00000000}},  //   пия_, _tinq, _wynb,
  { {0x2734006c, 0xddc300e5, 0x6fb20025, 0x00000000}},  //   mäng_, _cenţ, _أموا,
  { {0xc332009b, 0x26d83466, 0x7ced009d, 0x00000000}},  //   גום_, _roro_, _sûre,
  { {0xf1b20049, 0x7d1d00c4, 0x26d811c8, 0x00000000}},  //   עסן_, coss, _soro_,
  { {0xdb04000c, 0x68e43a86, 0x2ca006fa, 0x00000000}},  // [d460] _frið, rkid, _ibid_,
  { {0x68e4002d, 0x7cf60dec, 0x44242108, 0x00000000}},  //   skid, ršru, _rym_,
  { {0x44240f02, 0x27f20036, 0x26d800f8, 0x00000000}},  //   _sym_, szyn_, _voro_,
  { {0xf74602e9, 0xed560049, 0x61250285, 0x00000000}},  //   _немо, לבער_, bóli,
  { {0x26d8203d, 0x232a0478, 0xd8d70049, 0x00000000}},  //   _toro_, боди_, _זוכט_,
  { {0xe7370265, 0xd046006b, 0x00000000, 0x00000000}},  //   _нея_, əməl,   ,
  { {0xe5a300d7, 0x6f0100ca, 0xf8bf0082, 0x00000000}},  //   _пири, dilc, _thét_,
  { {0x442405fd, 0x2ca00066, 0x00000000, 0x00000000}},  //   _tym_, _nbid_,   ,
  { {0x40530054, 0x7d1d3a87, 0x00000000, 0x00000000}},  //   رئيس, voss,   ,
  { {0xd24f0025, 0xb23a0025, 0x69c100ea, 0x00000000}},  //   _منك_, _هكذا_, ålek,
  { {0x7d1d0ae4, 0x10a6041f, 0x6449019a, 0x00000000}},  //   toss, _нижн, şmiş,
  { {0x7ce61195, 0x7afe0007, 0x239e0089, 0x00000000}},  //   _fórm, _ampt, pājā_,
  { {0x00bb009b, 0x00000000, 0x00000000, 0x00000000}},  //   _למאמ,   ,   ,
  { {0x3f7b0049, 0x7d1d0052, 0x2ca0007f, 0x00000000}},  //   _פאוס, soss, _ebid_,
  { {0xd30800ad, 0x3a250018, 0x0e9b009b, 0x00000000}},  //   yện_, ælp_, _השול,
  { {0x58d40057, 0x6125029d, 0x7afe00ab, 0x00000000}},  //   ност, tóli, _empt,
  { {0xc64b0025, 0x00000000, 0x00000000, 0x00000000}},  // [d470] مجال_,   ,   ,
  { {0xac99026c, 0x3f520082, 0xdb0d00f6, 0x00000000}},  //   _اچھا_, _mâu_, _isaï,
  { {0x3f52001d, 0x612500dc, 0x94d50245, 0x00000000}},  //   _lâu_, sóli, можц,
  { {0x2cab0146, 0x612500c4, 0xb87b00c4, 0x00000000}},  //   necd_, póli, _alív,
  { {0xa6db000c, 0x3f520011, 0xddc30161, 0x00000000}},  //   _suðu, _nâu_, _menš,
  { {0xddc3012d, 0xf8bf0068, 0xceb800b4, 0x00000000}},  //   _lenš, _thés_, jdę_,
  { {0x950800a1, 0x6f0132cd, 0x6ab70b77, 0x00000000}},  //   _کہنے_, vilc, _maxf,
  { {0x6449005b, 0x00000000, 0x00000000, 0x00000000}},  //   _ugei,   ,   ,
  { {0x3f52001d, 0x442b0011, 0x00000000, 0x00000000}},  //   _câu_, _ác_,   ,
  { {0x60060147, 0x0ecd013d, 0x3f520011, 0x00000000}},  //   ьным_, ़ाधड, _dâu_,
  { {0x81bc0089, 0x6f010059, 0xdb0d01a2, 0x00000000}},  //   _dzēs, rilc, _spaß,
  { {0x13e10055, 0xeb9a007c, 0xc1050076, 0x00000000}},  //   _মেয়, оим_, _توصي,
  { {0x800900a1, 0xa2c20061, 0x6f010087, 0x00000000}},  //   _براہ_, लाच्, pilc,
  { {0xfe710167, 0x63a4005a, 0x3f98001a, 0x00000000}},  //   _شدت_, çini, ărut_,
  { {0xbb4300da, 0x61130035, 0xa3b4007d, 0x00000000}},  //   терк, călc, _छैन_,
  { {0xb87b000c, 0xddc3012d, 0x52da006e, 0x00000000}},  //   _olíu, _genš, _बक्स,
  { {0x3cf90065, 0x403a0049, 0x3f520082, 0x00000000}},  // [d480] ërve_, ַגעג, _xâu_,
  { {0x6c68026c, 0x61e30007, 0x7afe0022, 0x00000000}},  //   _بلکہ_, kynl, _umpt,
  { {0x27340039, 0x00000000, 0x00000000, 0x00000000}},  //   vänd_,   ,   ,
  { {0x2d85002a, 0x2d530181, 0xd467003b, 0x00000000}},  //   irle_, _mãe_, дице_,
  { {0x2d8510a2, 0x25ad016c, 0x00000000, 0x00000000}},  //   hrle_, _ćele_,   ,
  { {0x98b90006, 0x3f523a88, 0x24920036, 0x00000000}},  //   _visą_, _râu_, żym_,
  { {0x05660106, 0x3f520011, 0xf8bf0082, 0x00000000}},  //   _іван, _sâu_, _khép_,
  { {0xf99300b6, 0xceb80036, 0x612501e5, 0x00000000}},  //   דרה_, wdę_, kólu,
  { {0xb7db007b, 0x2cab3a89, 0x2d850026, 0x00000000}},  //   ַקטי, vecd_, erle_,
  { {0x81bc0089, 0x00000000, 0x00000000, 0x00000000}},  //   _dzēr,   ,   ,
  { {0x7ce60010, 0xdb210010, 0x61250d7b, 0x00000000}},  //   _kórh, _ítél, vólv,
  { {0x6ee40129, 0xf8bf0082, 0x4103005e, 0x00000000}},  //   _mòbi, _nhép_, _изхв,
  { {0x2d85203d, 0x69c811b8, 0x5eda0044, 0x00000000}},  //   arle_, åden, যোগে,
  { {0x1eaa00f3, 0x00000000, 0x00000000, 0x00000000}},  //   _ذاتي_,   ,   ,
  { {0x39150200, 0x26cd0011, 0x61130035, 0x00000000}},  //   емвр, _đeo_, lăla,
  { {0xf8bf0011, 0xdb0d0285, 0x2d8c0ec2, 0x00000000}},  //   _chép_, _isaí, mude_,
  { {0x2d8c006c, 0xf77005f3, 0x47350c4e, 0x00000000}},  // [d490] lude_, لال_, енас,
  { {0x6ee400f6, 0x00000000, 0x00000000, 0x00000000}},  //   _bòbi,   ,   ,
  { {0x2d8c3a8a, 0x00000000, 0x00000000, 0x00000000}},  //   nude_,   ,   ,
  { {0xf8bf0011, 0xb87b004a, 0xd7fb003b, 0x00000000}},  //   _ghép_, _clít, _дуг_,
  { {0xb87b0051, 0x78ad1254, 0x00000000, 0x00000000}},  //   _dlít, meav,   ,
  { {0x41b5003b, 0x78ad010e, 0x2d8c010e, 0x00000000}},  //   есит, leav, kude_,
  { {0xa3b3013d, 0x2d8c010e, 0x00000000, 0x00000000}},  //   टिङ_, jude_,   ,
  { {0x2d8c006c, 0xa6db000c, 0xfa0d0082, 0x00000000}},  //   dude_, _guðr, _đầu_,
  { {0xf076026c, 0x61e301e3, 0x2d8c01c3, 0x00000000}},  //   ریوں_, synl, eude_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2d8c006c, 0x00000000, 0x00000000, 0x00000000}},  //   gude_,   ,   ,
  { {0x998d0036, 0xa1070014, 0x6eed0051, 0x00000000}},  //   łeś_, _غذاه, _dúba,
  { {0x60cb0061, 0x78ad0133, 0x2d85012d, 0x00000000}},  //   _ingm, deav, srle_,
  { {0x2d8c0161, 0x91fc0089, 0x7ff4035b, 0x00000000}},  //   bude_, _teāt, _جسما,
  { {0xf8bf001d, 0x2d8c004a, 0x18a617b9, 0x00000000}},  //   _phép_, cude_, навм,
  { {0xb4ae0061, 0x395e0089, 0xfd1202fd, 0x00000000}},  //   _कसे_, īts_, _حجت_,
  { {0xf7720025, 0x5eb20044, 0xa7a70121, 0x00000000}},  // [d4a0] طاء_, জারে, нкта_,
  { {0x7d06011c, 0x8c1b009b, 0x5a662485, 0x00000000}},  //   liks, _מופי, _якоб,
  { {0xf8bf0011, 0xc486030d, 0x00000000, 0x00000000}},  //   _thép_, елек,   ,
  { {0x78ad001a, 0x7d0600b0, 0x798e0009, 0x00000000}},  //   ceav, niks, mubw,
  { {0xa2940245, 0xd3260077, 0xf77203ec, 0x00000000}},  //   валі, ньки, _حاج_,
  { {0xd24f03ec, 0x60cb00e0, 0x7ce600fa, 0x00000000}},  //   منه_, _angm, _dóri,
  { {0xe3d80044, 0x7d0600b0, 0xe7370d15, 0x00000000}},  //   _দেখব, kiks, _чер_,
  { {0xd372007a, 0x859b00b6, 0x7bc403c7, 0x00000000}},  //   _مهر_, _משלו, _oriu,
  { {0x7d060263, 0x3eac0002, 0x3f8d0129, 0x00000000}},  //   diks, tedt_, gueu_,
  { {0x2d8c062a, 0x798e000b, 0x60cb00f8, 0x00000000}},  //   tude_, kubw, _engm,
  { {0x7d061992, 0x3eac26fe, 0x69da00b0, 0x00000000}},  //   fiks, redt_, ätel,
  { {0x2d820119, 0x2d8c23fc, 0xb87b00d4, 0x00000000}},  //   čke_, rude_, _llír,
  { {0xdee602e9, 0x2d8c3a8a, 0xddd80010, 0x00000000}},  //   _поди, sude_, _vevő,
  { {0x78ad0436, 0x29023a8b, 0x00000000, 0x00000000}},  //   weav, _amka_,   ,
  { {0x98c701a4, 0xc9840184, 0x78ad3a8c, 0x00000000}},  //   нсал, лути, teav,
  { {0x7bc40207, 0x61f50047, 0x28d10061, 0x00000000}},  //   _friu, _üzle, हाधि,
  { {0x78ad11d1, 0x7bc43a8d, 0x00000000, 0x00000000}},  // [d4b0] reav, _griu,   ,
  { {0xb87b013e, 0x00000000, 0x00000000, 0x00000000}},  //   _plís,   ,   ,
  { {0xd915007e, 0x610800b9, 0x6b9d01a2, 0x00000000}},  //   _адны, něls, ltsg,
  { {0xa8790049, 0xdc9c0049, 0x00000000, 0x00000000}},  //   _קאָר, ּיגל,   ,
  { {0x38693a8e, 0x98ab0036, 0x765c005b, 0x00000000}},  //   mbar_, _chcą_, _ffry,
  { {0x7d0602ba, 0x38693a8f, 0x6b9d010f, 0x00000000}},  //   ziks, lbar_, itsg,
  { {0x75220009, 0x00000000, 0x00000000, 0x00000000}},  //   booz,   ,   ,
  { {0x3869010f, 0x610800b9, 0x629c00f8, 0x00000000}},  //   nbar_, děls, _öron,
  { {0x7d06003c, 0x38690022, 0x6ee400f6, 0x00000000}},  //   viks, ibar_, _lòbu,
  { {0x3f831034, 0x38693a90, 0x394b2271, 0x00000000}},  //   čju_, hbar_, _lics_,
  { {0xee3907ca, 0x7d06001e, 0x386910f8, 0x00000000}},  //   ьно_, tiks, kbar_,
  { {0x7bc40091, 0x60cb1dab, 0x6b9d01a2, 0x00000000}},  //   _priu, _ungm, ftsg,
  { {0x7d06033b, 0x2ef50216, 0x3f8d0129, 0x00000000}},  //   riks, _издр, queu_,
  { {0x7d06115d, 0x2d6e00b9, 0x63a90020, 0x00000000}},  //   siks, bře_, _mpen,
  { {0x6b9d20bf, 0x7d060052, 0xb87b00c4, 0x00000000}},  //   atsg, piks, _alíq,
  { {0x63a902ae, 0x7bc4183d, 0x38693a91, 0x00000000}},  //   _open, _triu, gbar_,
  { {0x7d040e1e, 0x628101d9, 0xd94302e9, 0x00000000}},  // [d4c0] _imis, _odlo, рети,
  { {0x75220009, 0x7d040066, 0x07a30425, 0x00000000}},  //   wooz, _hmis, рафн,
  { {0x63a902d5, 0x38692d00, 0x394b0325, 0x00000000}},  //   _apen, bbar_, _fics_,
  { {0x62810016, 0x80a10309, 0x7d0401d5, 0x00000000}},  //   _adlo, _कॉले, _jmis,
  { {0x29120149, 0x394029f9, 0x7d04191a, 0x00000000}},  //   mnya_, mmis_, _mmis,
  { {0x29120149, 0x39400004, 0x68f60039, 0x00000000}},  //   lnya_, lmis_, lhyd,
  { {0x7d04021e, 0x39400006, 0x291200e7, 0x00000000}},  //   _omis, omis_, onya_,
  { {0x29120149, 0x64a60816, 0x68f601a2, 0x00000000}},  //   nnya_, _шаба, nhyd,
  { {0x291204cb, 0xa8e00082, 0xb87b0048, 0x00000000}},  //   inya_, _độn, _hoíc,
  { {0x2912020c, 0x7d040779, 0x2d6e00b9, 0x00000000}},  //   hnya_, _amis, tře_,
  { {0x29120149, 0xfdd00044, 0x38690203, 0x00000000}},  //   knya_, ান্ড, ybar_,
  { {0x6b9d2ba1, 0x3940012d, 0x00000000, 0x00000000}},  //   ttsg, jmis_,   ,
  { {0x38690061, 0x394b00d4, 0x291204cb, 0x00000000}},  //   vbar_, _rics_, dnya_,
  { {0x7d041053, 0x6b9d0190, 0x38690319, 0x00000000}},  //   _emis, rtsg, wbar_,
  { {0x394b0365, 0x3869010f, 0x291204cb, 0x00000000}},  //   _pics_, tbar_, fnya_,
  { {0x7d160065, 0x2fc60059, 0x6f08000a, 0x00000000}},  //   _gjys, _krog_, lidc,
  { {0x38693a92, 0x383501e0, 0x38663a93, 0x00000000}},  // [d4d0] rbar_, унар, ñora_,
  { {0x2d9e01b5, 0x291204cb, 0xb6f4003b, 0x00000000}},  //   otte_, anya_, азуј,
  { {0x69c506e0, 0x63a92d8a, 0x38693a94, 0x00000000}},  //   _urhe, _spen, pbar_,
  { {0x7ce60321, 0x3ebc068f, 0x68f6005b, 0x00000000}},  //   _fóru, _lavt_, chyd,
  { {0xd2a93a5f, 0x568300a1, 0xd37b02dc, 0x00000000}},  //   екле_, _نگاہ, фче_,
  { {0xe29601f9, 0x68ed023a, 0x7c2d0c3f, 0x00000000}},  //   гаш_, lkad, _myar,
  { {0x78bd0368, 0x27e9165e, 0x45d4004d, 0x00000000}},  //   _kasv, lyan_, _корс,
  { {0x272f0010, 0x78bf0203, 0x7c2d004a, 0x00000000}},  //   künk_, ndqv, _oyar,
  { {0x27e9011c, 0x7c2d3a95, 0x63a90020, 0x00000000}},  //   nyan_, _nyar, _upen,
  { {0x7d040ecc, 0x2fc60039, 0xb06203b6, 0x00000000}},  //   _smis, _drog_, ääri,
  { {0xde0501fb, 0x7c2d011f, 0x442d0011, 0x00000000}},  //   упни, _ayar, _hye_,
  { {0x78bd01d9, 0x7c2d3a96, 0x442d27c1, 0x00000000}},  //   _nasv, _byar, _kye_,
  { {0xbea501f9, 0x8edf0055, 0x7c2d0009, 0x00000000}},  //   _балк, যোগগ, _cyar,
  { {0x27e90a1d, 0x442d0056, 0x7c2d09d7, 0x00000000}},  //   dyan_, _mye_, _dyar,
  { {0x29120149, 0x442d01aa, 0x68f60016, 0x00000000}},  //   tnya_, _lye_, thyd,
  { {0x442d008e, 0x27e90093, 0x35fb0044, 0x00000000}},  //   _oye_, fyan_, ্থাৎ_,
  { {0x2912020c, 0x27e924c4, 0x442d02cc, 0x00000000}},  // [d4e0] rnya_, gyan_, _nye_,
  { {0x2912020c, 0x7bcb0181, 0x394012e8, 0x00000000}},  //   snya_, _água, smis_,
  { {0x4a9b007b, 0x29120149, 0x1a9b007b, 0x00000000}},  //   _אייג, pnya_, _אייע,
  { {0x68ed0039, 0xdb0d000c, 0x78bd01d6, 0x00000000}},  //   ckad, _hrað, _gasv,
  { {0x6eed049a, 0xf487026c, 0x442d0009, 0x00000000}},  //   _públ, طانی, _cye_,
  { {0x442d2fdb, 0x2d9e01e3, 0x68e3001a, 0x00000000}},  //   _dye_, ytte_, _îndr,
  { {0x442d00ab, 0x6abe004a, 0x272f0010, 0x00000000}},  //   _eye_, _mapf, zünk_,
  { {0x442d0173, 0x7df3006b, 0x3ea700c4, 0x00000000}},  //   _fye_, cəsə, _abnt_,
  { {0x2ef40113, 0x442d0009, 0x98ab0036, 0x00000000}},  //   изир, _gye_, _chcę_,
  { {0x7c2d22b1, 0x68ed2d53, 0x2d9e0203, 0x00000000}},  //   _ryar, zkad, ttte_,
  { {0x7c2d027e, 0x442d01aa, 0x23600089, 0x00000000}},  //   _syar, _zye_, ģiju_,
  { {0x272f0047, 0x61e5010f, 0x2d9e08af, 0x00000000}},  //   tünk_, ähle, rtte_,
  { {0x78bd3a97, 0x6abe0009, 0xbed400ed, 0x00000000}},  //   _rasv, _bapf, _волј,
  { {0x78bd01cd, 0xbebc001e, 0x7ce60051, 0x00000000}},  //   _sasv, glīt, _sórt,
  { {0xc33300b6, 0x78bd0006, 0x68ed202e, 0x00000000}},  //   מוש_, _pasv, tkad,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68ed082c, 0x7c2d011f, 0xd795005e, 0x00000000}},  // [d4f0] rkad, _uyar, ризъ,
  { {0x68ed022b, 0x442d01d6, 0x2d8c01bb, 0x00000000}},  //   skad, _rye_, orde_,
  { {0x5455005e, 0x2bc30061, 0x27e90cae, 0x00000000}},  //   авет, शिवा, syan_,
  { {0x442d0263, 0xf795008b, 0x2d8c0051, 0x00000000}},  //   _pye_, _камэ, irde_,
  { {0xe29908d6, 0x6abe0009, 0x672500b0, 0x00000000}},  //   вал_, _yapf, pohj,
  { {0x442d0263, 0x629a0009, 0x6e38012d, 0x00000000}},  //   _vye_, _ccto, _ozvb,
  { {0x442d0007, 0x929200ed, 0x81c70089, 0x00000000}},  //   _wye_, цајц, ktēš,
  { {0x442d0007, 0x3f9f00b0, 0x0cc00044, 0x00000000}},  //   _tye_, ttuu_, _উক্ত,
  { {0x2d8c049b, 0x60db17f6, 0x80a10309, 0x00000000}},  //   erde_, rjum, क्षे,
  { {0x2ca90169, 0x63bb3a98, 0xaf050545, 0x00000000}},  //   _abad_, _isun, рпол,
  { {0xe80c006e, 0x3f9f021e, 0x5184007e, 0x00000000}},  //   _सेना_, stuu_, _гуча,
  { {0xdfd1006d, 0x6abe06ed, 0x00000000, 0x00000000}},  //   _ويا_, _sapf,   ,
  { {0x2d8c046a, 0x3f6701bd, 0x63ad00c4, 0x00000000}},  //   arde_, _стеб, çanh,
  { {0x7ce60a0a, 0x80a1007d, 0x7a400010, 0x00000000}},  //   _córr, क्रे, játé,
  { {0x2be20061, 0x00000000, 0x00000000, 0x00000000}},  //   _पथका,   ,   ,
  { {0xc955045a, 0x3f5b0011, 0x63bb1c79, 0x00000000}},  //   стры, _kêu_, _osun,
  { {0xb8de0754, 0x3706007e, 0x00000000, 0x00000000}},  // [d500] _इस_, апаг,   ,
  { {0x8ca703d7, 0x657e010f, 0x98ab0089, 0x00000000}},  //   ट्ठो, tsph, ījās_,
  { {0x63bb397d, 0x98a60072, 0xd9100167, 0x00000000}},  //   _asun, _кине, _فیس_,
  { {0x64a6008b, 0x26d1184e, 0x938a0c24, 0x00000000}},  //   рада, _enzo_, вска_,
  { {0xe3b2031d, 0x3f5b0011, 0x9676007e, 0x00000000}},  //   ترا_, _nêu_, _выбі,
  { {0x3f8d0129, 0x6d5a0065, 0xfc3f008e, 0x00000000}},  //   dreu_, yqta, nfía_,
  { {0x7e7a0039, 0x00000000, 0x00000000, 0x00000000}},  //   vatp,   ,   ,
  { {0x3860027b, 0x3f8d00c4, 0x1fa60888, 0x00000000}},  //   ncir_, freu_, арог,
  { {0xdfd0006d, 0x3f8d012d, 0x7649013f, 0x00000000}},  //   سيد_, greu_, _şeyx,
  { {0xe465000c, 0x9ed800ed, 0x00000000, 0x00000000}},  //   _þörf_, умот_,   ,
  { {0x63a21ec2, 0x0737009b, 0x667b0049, 0x00000000}},  //   lton, שאים_, כטיק,
  { {0xa06a0088, 0x3f8d00d4, 0x3fc800a2, 0x00000000}},  //   _рада_, breu_, _مدتی_,
  { {0x63a20b9a, 0x92d80055, 0x81c70089, 0x00000000}},  //   nton, াসী_, rtēš,
  { {0x62982053, 0xdce20006, 0x81c70089, 0x00000000}},  //   ngvo, kslė, stēš,
  { {0xed5701b3, 0x63a21c79, 0x58d500e3, 0x00000000}},  //   _кој_, hton, бовт,
  { {0x3f5b00ad, 0x63a2006a, 0xa3d60309, 0x00000000}},  //   _yêu_, kton, िमा_,
  { {0xfb8500a2, 0x63a223c6, 0xddda0e3f, 0x00000000}},  // [d510] _ادبی, jton, katū,
  { {0x6d58021e, 0x63a23a99, 0x39b80173, 0x00000000}},  //   _kuva, dton, _fōs_,
  { {0xdfc604e1, 0x24550426, 0x63a20052, 0x00000000}},  //   _کي_, مناس, eton,
  { {0x63a23a9a, 0x6d580823, 0x7e780087, 0x00000000}},  //   fton, _muva, _levp,
  { {0x7ae508b2, 0xd308001d, 0x6d583a9b, 0x00000000}},  //   _koht, yệt_, _luva,
  { {0x7ae5021e, 0x3f5b0082, 0x6d580022, 0x00000000}},  //   _joht, _rêu_, _ouva,
  { {0x6d583a9c, 0x256c01aa, 0x63a2010e, 0x00000000}},  //   _nuva, _vòlò_, aton,
  { {0x3f8d0191, 0x5a1800b3, 0x00000000, 0x00000000}},  //   treu_, יקון_,   ,
  { {0x63bb0046, 0xd3710063, 0x3de40044, 0x00000000}},  //   _usun, _رها_, _ফেলল,
  { {0x3f8d3a9d, 0x6d580006, 0x79950020, 0x00000000}},  //   rreu_, _buva, kuzw,
  { {0x6d5817ef, 0x69c70166, 0x6eed0325, 0x00000000}},  //   _cuva, jvje, _júbi,
  { {0x6d58014a, 0xf1c3010a, 0x69c71a84, 0x00000000}},  //   _duva, rašė_, dvje,
  { {0x7052004b, 0x21c70082, 0x7ae500f6, 0x00000000}},  //   _عنوا, _hđh_, _boht,
  { {0x543a007b, 0x6113001a, 0x643a0049, 0x00000000}},  //   טערא, dăli, טערנ,
  { {0x5d850379, 0xc332019b, 0x8d950025, 0x00000000}},  //   _البل, פול_, _العش,
  { {0x97da007c, 0x00000000, 0x00000000, 0x00000000}},  //   льзу_,   ,   ,
  { {0x38600129, 0xddc300b9, 0x63a2010e, 0x00000000}},  // [d520] rcir_, _jenž, xton,
  { {0x0656008b, 0x3860027b, 0xf6560230, 0x00000000}},  //   стаў, scir_, стаю,
  { {0x2a57009b, 0x463a0ae0, 0x27340039, 0x00000000}},  //   _לבין_, учая_, länk_,
  { {0x63a20207, 0x67230166, 0xb0a6001c, 0x00000000}},  //   tton, čnja, _कॉंग,
  { {0x63a20dd9, 0x00000000, 0x00000000, 0x00000000}},  //   uton,   ,   ,
  { {0x63a23a9e, 0x04fa0044, 0x21c70082, 0x00000000}},  //   rton, েকের_, _bđh_,
  { {0xddda0a5c, 0x00000000, 0x00000000, 0x00000000}},  //   ratū,   ,   ,
  { {0x64a302be, 0x63a20065, 0x92d80044, 0x00000000}},  //   _наса, pton, াসে_,
  { {0x6d580006, 0x69c70243, 0x00000000, 0x00000000}},  //   _suva, zvje,   ,
  { {0x395a009d, 0x00000000, 0x00000000, 0x00000000}},  //   _oups_,   ,   ,
  { {0x6b8400f4, 0x62880066, 0x7ae5010e, 0x00000000}},  //   _avig, _iddo, _roht,
  { {0xa157009b, 0x79950009, 0x69cc0204, 0x00000000}},  //   _הבאה_, vuzw, हिनी,
  { {0x7ae500b0, 0x6ab50068, 0x00000000, 0x00000000}},  //   _poht, tezf,   ,
  { {0x6d58078f, 0x6b84024f, 0xdce901df, 0x00000000}},  //   _tuva, _dvig, rtdı,
  { {0x6b840945, 0xb6c900a1, 0x395a0133, 0x00000000}},  //   _evig, یائے_, _cups_,
  { {0x3e4e005f, 0x6113001a, 0x799521a4, 0x00000000}},  //   mət_, tăli, ruzw,
  { {0x60c20020, 0x69c70243, 0x7ae50027, 0x00000000}},  // [d530] _maom, svje, _toht,
  { {0x7bcd022b, 0x6eed00d6, 0x00000000, 0x00000000}},  //   _irau, _púbi,   ,
  { {0x3e4e006b, 0x7bcd000c, 0x69c80bda, 0x00000000}},  //   nət_, _hrau, ådet,
  { {0x7bcd0006, 0x62880207, 0x60c21dec, 0x00000000}},  //   _krau, _addo, _naom,
  { {0x889a019b, 0x3e4e006b, 0x31a100b4, 0x00000000}},  //   _דברי, hət_, wóz_,
  { {0x3e4e006b, 0x4b7c01ce, 0xddc8012d, 0x00000000}},  //   kət_, נאוו, dadž,
  { {0x6aaa001f, 0x6a9c00b6, 0x6594007c, 0x00000000}},  //   _öffe, אשונ, _нару,
  { {0x7a40000c, 0x6f6500ed, 0x3e4e006b, 0x00000000}},  //   _hátí, овиз, dət_,
  { {0xb87b01ca, 0xc44700a1, 0x7b090062, 0x00000000}},  //   _blíz, _ایشن_, ržuj,
  { {0x3e4e006b, 0xe4500025, 0x0d850088, 0x00000000}},  //   fət_, _أضف_, олон,
  { {0x7bcd022b, 0x26c30059, 0x6b843a9f, 0x00000000}},  //   _arau, _majo_, _svig,
  { {0x7bcd3aa0, 0x2d8b00b9, 0x395a3aa1, 0x00000000}},  //   _brau, čce_, _rups_,
  { {0x6d5e009d, 0x7bcd00d9, 0x6d460397, 0x00000000}},  //   _épan, _crau, rmka,
  { {0x7bcd0ebc, 0x395a3aa2, 0x3e4e006b, 0x00000000}},  //   _drau, _pups_, bət_,
  { {0x7bcd0032, 0x60c200e7, 0x68e60022, 0x00000000}},  //   _erau, _yaom, _pokd,
  { {0x7bcd03a1, 0x7d0f3aa3, 0x00000000, 0x00000000}},  //   _frau, cics,   ,
  { {0x7bcd125b, 0x26c30219, 0x07a300e2, 0x00000000}},  // [d540] _grau, _bajo_, матн,
  { {0x249f000d, 0xeb910049, 0x69c800d8, 0x00000000}},  //   _acum_, _אָט_, ådes,
  { {0xe45a0175, 0x26c300ca, 0x249f00f6, 0x00000000}},  //   аже_, _dajo_, _bcum_,
  { {0x136a0072, 0x236a00e2, 0x00000000, 0x00000000}},  //   ашки_, ајко_,   ,
  { {0xf746189f, 0x44202e5c, 0x2ca00045, 0x00000000}},  //   _мемо, çi_, _mcid_,
  { {0x3e4e005f, 0x6b8b0637, 0x018a0131, 0x00000000}},  //   yət_, _ægge, ащий_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc0ca012b, 0x89db009b, 0x3e4e006b, 0x00000000}},  //   руке_, שחקי, vət_,
  { {0x63ad0065, 0xe29a007c, 0x00000000, 0x00000000}},  //   çant, _ваз_,   ,
  { {0xddc82270, 0x2018001a, 0x2ca000ab, 0x00000000}},  //   radž, ări_, _acid_,
  { {0xb65b007b, 0x7bcd0006, 0x14cf0061, 0x00000000}},  //   ידיש, _srau, _सोडण,
  { {0x3e4e005f, 0xcd0701fb, 0x7bcd007f, 0x00000000}},  //   rət_, ічни, _prau,
  { {0x7d0f297d, 0x7ac70216, 0x3e4e005f, 0x00000000}},  //   rics, осве, sət_,
  { {0x7d0f0387, 0x00000000, 0x00000000, 0x00000000}},  //   sics,   ,   ,
  { {0x7d0f00bb, 0x3e4e006b, 0x2ca00009, 0x00000000}},  //   pics, qət_, _fcid_,
  { {0x58d407ca, 0x5c75007c, 0x2ca00009, 0x00000000}},  //   мост, _элит, _gcid_,
  { {0x7cff008d, 0x7d0d3470, 0x69da3aa4, 0x00000000}},  // [d550] _përf, _imas, äter,
  { {0x8ca7007d, 0xc66b007e, 0x00000000, 0x00000000}},  //   ट्रो, ршае_,   ,
  { {0x2aba009b, 0x26c300ca, 0x3aba009b, 0x00000000}},  //   _המתא, _vajo_, _המתנ,
  { {0x7cff008d, 0xe80c02fb, 0xf99200a3, 0x00000000}},  //   _dërg, _सेवा_, _ארט_,
  { {0x3949001e, 0x26c31d12, 0x7d0d3aa5, 0x00000000}},  //   mmas_, _tajo_, _mmas,
  { {0x39490047, 0x1fd00055, 0xaacb0164, 0x00000000}},  //   lmas_, িহাস, ायिक,
  { {0xd49b01f9, 0x39490b76, 0x7d0d003c, 0x00000000}},  //   _врз_, omas_, _omas,
  { {0x69cc0061, 0x39490093, 0x6b4b01f3, 0x00000000}},  //   हिती, nmas_, _iżgu,
  { {0x4439049a, 0x3cdf0204, 0x39490089, 0x00000000}},  //   _ás_, गाने_, imas_,
  { {0x7d0d0c2b, 0x3f8600b9, 0x443f0032, 0x00000000}},  //   _amas, _dvou_, _izu_,
  { {0xdcfb010a, 0xcee80014, 0x39490022, 0x00000000}},  //   nutė, ترين_, kmas_,
  { {0xcb0900b3, 0xdcfb0089, 0x61130035, 0x00000000}},  //   _גל_, tstā, tălu,
  { {0x2fc90051, 0x7d0d0085, 0x2bba0025, 0x00000000}},  //   _éag_, _dmas, حاجة_,
  { {0xdcfb001e, 0x7d0d010e, 0xbf3700a1, 0x00000000}},  //   rstā, _emas, _برصغ,
  { {0x78af0082, 0x00000000, 0x00000000, 0x00000000}},  //   _bbcv,   ,   ,
  { {0x2d8500ea, 0x443f013f, 0x7d0d00fa, 0x00000000}},  //   msle_, _ozu_, _gmas,
  { {0x81b10055, 0x69d81288, 0x443f0009, 0x00000000}},  // [d560] টটি_, _šved, _nzu_,
  { {0x7cff008d, 0x6d56011c, 0xaa46007c, 0x00000000}},  //   _përg, _hiya, _непл,
  { {0x7e7e0004, 0x6d560cd7, 0x4a5b009b, 0x00000000}},  //   _õppe, _kiya, _לדיו,
  { {0x7cff0065, 0x7d0d01f3, 0x14c60061, 0x00000000}},  //   _gërd, _xmas, _रोखण,
  { {0x6d5601aa, 0x2912028e, 0x6d440051, 0x00000000}},  //   _miya, miya_, _mhia,
  { {0x2912006b, 0xd25000a1, 0x6ef600f4, 0x00000000}},  //   liya_, نچا_, _câbl,
  { {0x3f8600b9, 0x6d440e3a, 0x27e0002b, 0x00000000}},  //   _svou_, _ohia, lxin_,
  { {0x29120f95, 0x6d56006a, 0x29000181, 0x00000000}},  //   niya_, _niya, nhia_,
  { {0x7c240065, 0x7d0d00ea, 0x27e0272c, 0x00000000}},  //   _nxir, _rmas, nxin_,
  { {0x6440011f, 0x2912006a, 0x39490964, 0x00000000}},  //   _izmi, hiya_, zmas_,
  { {0x3949010a, 0x6d56011c, 0x2912013f, 0x00000000}},  //   ymas_, _biya, kiya_,
  { {0x6d442b7c, 0x6601011f, 0x00000000, 0x00000000}},  //   _chia, _ülke,   ,
  { {0x703a03ec, 0x6d561aa0, 0x6d443aa6, 0x00000000}},  //   _اساس_, _diya, _dhia,
  { {0xdee300c0, 0x1959008b, 0x3f820006, 0x00000000}},  //   _почи, жавы_, škus_,
  { {0x7cff008d, 0x6d56011f, 0x6d440051, 0x00000000}},  //   _përd, _fiya, _fhia,
  { {0x2912005f, 0x7d0d09bd, 0x6d440207, 0x00000000}},  //   giya_, _umas, _ghia,
  { {0xb8e502fb, 0xade500a1, 0x00000000, 0x00000000}},  // [d570] _एस_, _فہیم_,   ,
  { {0x6d5601f6, 0x4b7c009b, 0x98b20089, 0x00000000}},  //   _ziya, _האזו, ībās_,
  { {0x7d1d0b05, 0x29123aa7, 0x6d560009, 0x00000000}},  //   onss, biya_, _yiya,
  { {0x290027ce, 0x7d1d0c31, 0x6d56006b, 0x00000000}},  //   chia_, nnss, _xiya,
  { {0x7d1d000c, 0x03a50216, 0x27e00082, 0x00000000}},  //   inss, фило, cxin_,
  { {0x7d1d00f8, 0x4424059f, 0x2d850142, 0x00000000}},  //   hnss, _dxm_, ysle_,
  { {0xb4570123, 0x00000000, 0x00000000, 0x00000000}},  //   _فیاض_,   ,   ,
  { {0x443f0032, 0x78ad0026, 0x35b30088, 0x00000000}},  //   _tzu_, nfav, _обґр,
  { {0x6d563aa8, 0x6d440016, 0x248d0142, 0x00000000}},  //   _riya, _rhia, _idem_,
  { {0x6d563aa9, 0x2912006b, 0x8e7401e1, 0x00000000}},  //   _siya, ziya_, нуюч,
  { {0x57ba02d2, 0x112b07ca, 0x6d56014a, 0x00000000}},  //   _उन्ह, _люди_, _piya,
  { {0x6283018e, 0xd00e089d, 0x6d56006b, 0x00000000}},  //   lano, الی_, _qiya,
  { {0x78ad0009, 0xbea50242, 0x2d9a0056, 0x00000000}},  //   dfav, _жалк, _åpen_,
  { {0x62833973, 0x6d560022, 0x291206fe, 0x00000000}},  //   nano, _wiya, wiya_,
  { {0x6d56034f, 0x6d4421e7, 0xc33200b6, 0x00000000}},  //   _tiya, _thia, דום_,
  { {0xb4bc0365, 0x6283018e, 0x60c90670, 0x00000000}},  //   _असे_, hano, ndem,
  { {0x291235e1, 0x46ea0216, 0x3af400b0, 0x00000000}},  // [d580] riya_, одан_, _läpi_,
  { {0x2912005f, 0x6283037e, 0x2900000b, 0x00000000}},  //   siya_, jano, shia_,
  { {0x6283018e, 0x29000142, 0x6abc054e, 0x00000000}},  //   dano, phia_, merf,
  { {0x6abc0302, 0x60c90161, 0x799c0009, 0x00000000}},  //   lerf, jdem, murw,
  { {0x60c908e0, 0x628309fc, 0x69ce0030, 0x00000000}},  //   ddem, fano, lvbe,
  { {0x416a012b, 0x7cff0065, 0x645b28f0, 0x00000000}},  //   ојим_, _kërc, _egui,
  { {0xbebc0089, 0x65c300e2, 0x799c0009, 0x00000000}},  //   lnīg, _ибра, nurw,
  { {0xe643004c, 0x6abc04f2, 0x60c900ea, 0x00000000}},  //   _респ, herf, gdem,
  { {0x64400209, 0x6abc009f, 0x20040107, 0x00000000}},  //   _uzmi, kerf, uzmi_,
  { {0x62830489, 0x799c0a37, 0x6abc068f, 0x00000000}},  //   cano, kurw, jerf,
  { {0x069700b6, 0x60c904a5, 0x00000000, 0x00000000}},  //   ודים_, bdem,   ,
  { {0xb4bc0061, 0x7cff0023, 0x7afe0808, 0x00000000}},  //   _असो_, _sërb, _alpt,
  { {0x7cff008d, 0x6abc01a2, 0x7d1d01e5, 0x00000000}},  //   _përb, ferf, rnss,
  { {0x6abc2a1c, 0xdbdc000c, 0x73f90049, 0x00000000}},  //   gerf, ráðg, פּרו,
  { {0x799c0009, 0x0f570104, 0xbebc01c5, 0x00000000}},  //   gurw, _קיום_, enīg,
  { {0x6aaa010f, 0x7e6d01ed, 0x00000000, 0x00000000}},  //   _öffn, _đapi,   ,
  { {0x78ad275a, 0x62830010, 0x6abc010f, 0x00000000}},  // [d590] rfav, yano, berf,
  { {0x6283013f, 0x60c907fd, 0x645b0026, 0x00000000}},  //   xano, zdem, _sgui,
  { {0x6283010a, 0x60c91c39, 0x27340039, 0x00000000}},  //   vano, ydem, vänt_,
  { {0x26c71144, 0x69cc0061, 0xf7731739, 0x00000000}},  //   žno_, हिरी, _لاس_,
  { {0x7e6a00ea, 0x38690382, 0x6b9d00f8, 0x00000000}},  //   _offp, mcar_, nusg,
  { {0x3959006b, 0x38690232, 0x877a00a3, 0x00000000}},  //   _hiss_, lcar_, _מאשי,
  { {0x62833aaa, 0x60c9158a, 0x6b9d3aab, 0x00000000}},  //   rano, tdem, husg,
  { {0x62831b03, 0x38690129, 0x60c91408, 0x00000000}},  //   sano, ncar_, udem,
  { {0x6283011c, 0x60c922c2, 0x613e0023, 0x00000000}},  //   pano, rdem, mëll,
  { {0x60c90052, 0x3959098e, 0x0ea90a78, 0x00000000}},  //   sdem, _liss_, чкой_,
  { {0x62810089, 0x60c900f6, 0xee390088, 0x00000000}},  //   _ielo, pdem, яно_,
  { {0x628100c4, 0x6abc00ab, 0xfce60088, 0x00000000}},  //   _helo, werf, хомо,
  { {0x62813aac, 0x69c50133, 0x00000000, 0x00000000}},  //   _kelo, _ashe,   ,
  { {0x7cff008d, 0xa3d002fb, 0x799c01a2, 0x00000000}},  //   _përc, षित_, turw,
  { {0x395901d5, 0x6abc0240, 0x4efa009b, 0x00000000}},  //   _biss_, rerf, _מהסו,
  { {0x6abc0302, 0x0d820265, 0x6281065c, 0x00000000}},  //   serf, _слън, _lelo,
  { {0x69c51833, 0xc955007e, 0x628101c3, 0x00000000}},  // [d5a0] _eshe, ттры, _oelo,
  { {0xf1c5001d, 0x62810e88, 0x69c50065, 0x00000000}},  //   _đáng_, _nelo, _fshe,
  { {0xceb200a0, 0x3959002b, 0xeef60049, 0x00000000}},  //   ריב_, _fiss_, עמער_,
  { {0x6281018e, 0xe8110061, 0x142601ee, 0x00000000}},  //   _aelo, _ठेवा_, ндем,
  { {0x62810b8d, 0xe3af0151, 0x00000000, 0x00000000}},  //   _belo, مرو_,   ,
  { {0x31c60216, 0x00000000, 0x00000000, 0x00000000}},  //   есив,   ,   ,
  { {0x628101d9, 0x00000000, 0x00000000, 0x00000000}},  //   _delo,   ,   ,
  { {0x6d5e00f4, 0x6281010e, 0xf993009b, 0x00000000}},  //   _épai, _eelo, ארה_,
  { {0x62810010, 0x925a0014, 0x0326007c, 0x00000000}},  //   _felo, _فشار_, _здан,
  { {0x62810100, 0x1ddb02fb, 0xfaff0065, 0x00000000}},  //   _gelo, यमंत, hpër_,
  { {0x32070046, 0x2d8a0010, 0x123100a1, 0x00000000}},  //   czny_, ébe_, _پڑوس,
  { {0x26ca08f7, 0x628100ca, 0xac1917fa, 0x00000000}},  //   _labo_, _zelo, дому_,
  { {0xd12f025a, 0x62813aad, 0x6aa500ea, 0x00000000}},  //   _امن_, _yelo, _pchf,
  { {0x26ca1d03, 0x2fc600e0, 0x6b9d01c3, 0x00000000}},  //   _nabo_, _isog_, rusg,
  { {0x3959023a, 0x6b40010f, 0x318c00b9, 0x00000000}},  //   _piss_, mögl, něz_,
  { {0x2eee1014, 0x2d9e010e, 0xa2dd0061, 0x00000000}},  //   _hoff_, mute_, पाऱ्,
  { {0xf77001f7, 0x38690118, 0x2d9e0207, 0x00000000}},  // [d5b0] مال_, rcar_, lute_,
  { {0x38690219, 0x3ebe2fac, 0x26ca0489, 0x00000000}},  //   scar_, nett_, _cabo_,
  { {0x62810211, 0x2d9e3aae, 0x26ca0173, 0x00000000}},  //   _relo, nute_, _dabo_,
  { {0x62810c60, 0xd4e41523, 0xd046006b, 0x00000000}},  //   _selo, лючи, şməl,
  { {0x628102d5, 0x3ebe1341, 0x00000000, 0x00000000}},  //   _pelo, kett_,   ,
  { {0x2d9e006c, 0x3ebe0056, 0x26ca0253, 0x00000000}},  //   kute_, jett_, _gabo_,
  { {0x3ebe121b, 0x2d9e0079, 0x00000000, 0x00000000}},  //   dett_, jute_,   ,
  { {0x2d9e3aaf, 0x26ca0009, 0xed6301ca, 0x00000000}},  //   dute_, _zabo_, _leží_,
  { {0x3ebe002b, 0x62810c30, 0x26ca0061, 0x00000000}},  //   fett_, _telo, _yabo_,
  { {0x2d9e0258, 0x2eee0026, 0x6eff00c4, 0x00000000}},  //   fute_, _coff_, _bêba,
  { {0x2d9e002d, 0x6b8d1bd5, 0xcfa81125, 0x00000000}},  //   gute_, _avag, وایم_,
  { {0x7cff0023, 0x00000000, 0x00000000, 0x00000000}},  //   _përa,   ,   ,
  { {0x3ebe053d, 0x09ca0204, 0x00000000, 0x00000000}},  //   bett_, ाट्य,   ,
  { {0x2eee3ab0, 0x2d9e00ab, 0x6d4f008e, 0x00000000}},  //   _goff_, bute_, amca,
  { {0x19b90077, 0x26ca16ab, 0x6b400039, 0x00000000}},  //   нуть_, _rabo_, sögo,
  { {0x26ca0059, 0x60cb04a5, 0x00000000, 0x00000000}},  //   _sabo_, _jagm,   ,
  { {0x60cb011c, 0xf7720a4f, 0xccf300b6, 0x00000000}},  // [d5c0] _magm, شاء_, _ככה_,
  { {0xbebc0089, 0x60cb04d3, 0x00000000, 0x00000000}},  //   mnīc, _lagm,   ,
  { {0xd6cf002c, 0xc4863ab1, 0xd5d5007e, 0x00000000}},  //   تقل_, влек, люцы,
  { {0x3ebe0047, 0x3dc70061, 0x60cb3ab2, 0x00000000}},  //   zett_, _msnw_, _nagm,
  { {0xa3b40822, 0x2d9e3ab3, 0x64a303e0, 0x00000000}},  //   ублі, zute_, рача,
  { {0x78a43ab4, 0x7afc00d0, 0x934302dc, 0x00000000}},  //   lgiv, nkrt, анче,
  { {0x3ebe302e, 0x60cb0190, 0x2eee0c0e, 0x00000000}},  //   vett_, _bagm, _roff_,
  { {0x3ebe0003, 0x2d9e3ab5, 0x3f42000c, 0x00000000}},  //   wett_, vute_, gðun_,
  { {0x3ebe0047, 0x65690089, 0xbebc0089, 0x00000000}},  //   tett_, _čehi, jnīc,
  { {0x248401d5, 0x2d9e00ab, 0x75223ab6, 0x00000000}},  //   _hemm_, tute_, lnoz,
  { {0x6b8d1bce, 0x69d8010a, 0x4207005e, 0x00000000}},  //   _svag, _šven, _инфо_,
  { {0x2d9e058b, 0x3ebe0292, 0x60cb00e0, 0x00000000}},  //   rute_, sett_, _gagm,
  { {0x78a41a95, 0x6d4f00d4, 0x24843ab7, 0x00000000}},  //   dgiv, rmca, _memm_,
  { {0x2d9e0035, 0x9b58005e, 0x9b4503ec, 0x00000000}},  //   pute_, кият_, انسو,
  { {0xd90f00a1, 0xdbdd01d6, 0x3eab0161, 0x00000000}},  //   قید_, _dáár, žitý_,
  { {0x60c000b0, 0x78a40026, 0x00000000, 0x00000000}},  //   nemm, ggiv,   ,
  { {0x75220387, 0x5884007e, 0x613e01c3, 0x00000000}},  // [d5d0] dnoz, рыса, eëlk,
  { {0x60c000b0, 0x29020093, 0xb87b00b9, 0x00000000}},  //   hemm, _elka_, _sníd,
  { {0x60c0014a, 0x2d8c040f, 0x68ef0082, 0x00000000}},  //   kemm, nsde_, _tocd,
  { {0x60c03356, 0x21260065, 0x6d5e009d, 0x00000000}},  //   jemm, _njoh_, _épau,
  { {0x2458008b, 0x44290ca7, 0x25f3001c, 0x00000000}},  //   ваць_, ça_, ूनही_,
  { {0x05130044, 0x4429002b, 0x60cb01d6, 0x00000000}},  //   িকের_, ħa_, _sagm,
  { {0x60cb006a, 0x60c00197, 0xbebc0089, 0x00000000}},  //   _pagm, femm, znīc,
  { {0x5045005e, 0x75220197, 0xefc9358a, 0x00000000}},  //   лейб, cnoz, елил_,
  { {0x3f42000c, 0x7cff3ab8, 0x2d8c0116, 0x00000000}},  //   rðun_, _përn, esde_,
  { {0x26c10027, 0xfde92c0c, 0x63bb0058, 0x00000000}},  //   neho_, едок_, _ipun,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xeb9a02e9, 0xe0d00879, 0x60c000f4, 0x00000000}},  //   ним_, _وزن_, cemm,
  { {0x8ca503d7, 0x78a405b7, 0x26c10027, 0x00000000}},  //   _कारो, vgiv, keho_,
  { {0x26c1107b, 0x4e2900da, 0x6f920025, 0x00000000}},  //   jeho_, _полн_, _الوض,
  { {0xceb200b6, 0xbebc001e, 0x660900b9, 0x00000000}},  //   _היו_, snīc, _řekn,
  { {0x63bb00e5, 0xb87b0b33, 0xbebc0089, 0x00000000}},  //   _opun, _aníb, pnīc,
  { {0x7d040020, 0x6b8911cd, 0x3f8d00d4, 0x00000000}},  // [d5e0] _ilis, šegr, nseu_,
  { {0x78a40030, 0x4b7b0104, 0x7522261b, 0x00000000}},  //   sgiv, _ראיו, wnoz,
  { {0x63bb029a, 0x5efa0049, 0x3ce01afa, 0x00000000}},  //   _apun, עפעד, _kniv_,
  { {0xd76600a1, 0x00000000, 0x00000000, 0x00000000}},  //   _ماسٹ,   ,   ,
  { {0x26c13ab9, 0x7d041c27, 0x75220cd3, 0x00000000}},  //   beho_, _mlis, rnoz,
  { {0x3940006c, 0x7d0404bd, 0x26c10027, 0x00000000}},  //   llis_, _llis, ceho_,
  { {0x7d04021e, 0x60c00dd7, 0x2f00000a, 0x00000000}},  //   _olis, temm, _bògn_,
  { {0xb87b02d5, 0x76430036, 0x7522006b, 0x00000000}},  //   _iníc, żnyc, qnoz,
  { {0x60c000b0, 0x7dea005f, 0x69d83aba, 0x00000000}},  //   remm, məsi, _švel,
  { {0x7d04000b, 0xd24f007a, 0x7dea005f, 0x00000000}},  //   _alis, _کنم_, ləsi,
  { {0x394000c8, 0x073700b3, 0x7d043abb, 0x00000000}},  //   klis_, ראים_, _blis,
  { {0x26c10009, 0x39400127, 0x7d040051, 0x00000000}},  //   zeho_, jlis_, _clis,
  { {0x26c10061, 0x8ff70076, 0xab62014a, 0x00000000}},  //   yeho_, _مرور_, şüne,
  { {0xe1f1026c, 0x7dea005f, 0xc6bf0044, 0x00000000}},  //   _اسے_, həsi, _উচ্চ,
  { {0x63a23abc, 0x7d040ede, 0x1efb0049, 0x00000000}},  //   huon, _flis, _אלגע,
  { {0x7d0400f4, 0x26c10009, 0x39400089, 0x00000000}},  //   _glis, weho_, glis_,
  { {0x6c78006d, 0x7dea006b, 0x6d4d016c, 0x00000000}},  // [d5f0] _صحيح_, dəsi, _ihaa,
  { {0x39400013, 0x63a20ded, 0x7d16025d, 0x00000000}},  //   alis_, duon, _zmys,
  { {0x63bb000d, 0x26c1011c, 0x7dea006b, 0x00000000}},  //   _spun, reho_, fəsi,
  { {0x297a00a3, 0x39403abd, 0x6f1a1896, 0x00000000}},  //   _שטרא, clis_, hitc,
  { {0xdfc60464, 0x63a21875, 0x6f1a3abe, 0x00000000}},  //   _بي_, guon, kitc,
  { {0x68ed003b, 0x628a3abf, 0x6d5f006b, 0x00000000}},  //   ljad, gafo, _liqa,
  { {0x6f1a00b5, 0x7dea006b, 0xf07500a1, 0x00000000}},  //   ditc, bəsi, لیاں_,
  { {0x68ed0149, 0x7dea005f, 0xe0d90072, 0x00000000}},  //   njad, cəsi, тви_,
  { {0x63bb0020, 0x753b2170, 0x63a20082, 0x00000000}},  //   _upun, _ikuz, cuon,
  { {0x5187008b, 0x628a00d4, 0x7d0429da, 0x00000000}},  //   _буда, cafo, _slis,
  { {0x1d0a09ae, 0x3f8d00d4, 0x245a014a, 0x00000000}},  //   вени_, sseu_, _tümü_,
  { {0x443f16d4, 0xcb6a3ac0, 0x7fd501e1, 0x00000000}},  //   _kyu_, каме_, _вікі,
  { {0x2909000b, 0xdee50bbd, 0x6f1a0107, 0x00000000}},  //   dhaa_, _воли, bitc,
  { {0x7dea006b, 0xdce4002b, 0xbea2007e, 0x00000000}},  //   zəsi, _kunċ, _дашк,
  { {0xfc3f0211, 0x753b27e1, 0xda79007e, 0x00000000}},  //   rgía_, _okuz, ыяў_,
  { {0x3ce00c7d, 0x75290209, 0x7d040020, 0x00000000}},  //   _univ_, _njez, _ulis,
  { {0x7dea006b, 0x39403ac1, 0x443f35e1, 0x00000000}},  // [d600] vəsi, rlis_, _nyu_,
  { {0x39400007, 0x753b008d, 0x6d5f009d, 0x00000000}},  //   slis_, _akuz, _épar,
  { {0x394001aa, 0x7dea005f, 0x442d0923, 0x00000000}},  //   plis_, təsi, _axe_,
  { {0x63a2218d, 0x6b840061, 0x07a6007c, 0x00000000}},  //   tuon, _kwig, _камн,
  { {0xf86301fb, 0x7dea005f, 0xb607001e, 0x00000000}},  //   _євро, rəsi, ekšē,
  { {0x2900117b, 0x7dea006b, 0x61130035, 0x00000000}},  //   lkia_, səsi, călz,
  { {0xe81a02d2, 0x64490e65, 0x63a23ac2, 0x00000000}},  //   _नेता_, _ezei, suon,
  { {0x7cff008d, 0x3f42009f, 0x64a30c4e, 0x00000000}},  //   _përm, rðum_, _маса,
  { {0x29002d53, 0x6f1a00df, 0x63a2009d, 0x00000000}},  //   ikia_, titc, quon,
  { {0x6d4d0727, 0x3eb8000c, 0x6d5f006b, 0x00000000}},  //   _shaa, ýrt_, _siqa,
  { {0xb6d90049, 0x290000b0, 0x62880089, 0x00000000}},  //   אַרט, kkia_, _iedo,
  { {0x7cff0023, 0x215a0445, 0x6b840009, 0x00000000}},  //   _tërm, _شجاع_, _bwig,
  { {0x628810ed, 0x442d009d, 0x00000000, 0x00000000}},  //   _kedo, _xxe_,   ,
  { {0x7cff008d, 0x6288010f, 0x6d4d2d2d, 0x00000000}},  //   _kërk, _jedo, _whaa,
  { {0x6b841058, 0x8d940054, 0x6da301fc, 0x00000000}},  //   _ewig, _البش, _дија,
  { {0x7c2d022b, 0x6288013e, 0x7cff0065, 0x00000000}},  //   _txar, _ledo, _mërk,
  { {0x68ed0390, 0xf7730355, 0x62880016, 0x00000000}},  // [d610] rjad, تاز_, _oedo,
  { {0x7d1d0e23, 0x7bcd007f, 0x752900b9, 0x00000000}},  //   liss, _isau, _sjez,
  { {0x200d0a15, 0x442d0048, 0x7d1d00b0, 0x00000000}},  //   zzei_, _sxe_, oiss,
  { {0x7d1d0dc9, 0xd1260774, 0x81bc0044, 0x00000000}},  //   niss, _رم_, ইটা_,
  { {0x6288049b, 0x7cff0065, 0xe29901e0, 0x00000000}},  //   _bedo, _përj, гал_,
  { {0x7d1d1684, 0x62883982, 0xb0620933, 0x00000000}},  //   hiss, _cedo, ääni,
  { {0x7d1d1ced, 0xc5940098, 0x32010062, 0x00000000}},  //   kiss, _мирј, áhy_,
  { {0x7d1d3ac3, 0x200d1424, 0x753b047b, 0x00000000}},  //   jiss, tzei_, _ukuz,
  { {0x62881a7b, 0x7d1d00b0, 0x2d9e3ac4, 0x00000000}},  //   _fedo, diss, erte_,
  { {0x628806b2, 0xaf050404, 0x2900002d, 0x00000000}},  //   _gedo, спол, zkia_,
  { {0x7d1d3ac5, 0x26d10089, 0x7bcd00e0, 0x00000000}},  //   fiss, _mazo_, _asau,
  { {0x4155007e, 0x26d1008e, 0x6288277a, 0x00000000}},  //   _увес, _lazo_, _zedo,
  { {0x38c801ef, 0x2d9e0d48, 0x8fc70188, 0x00000000}},  //   یاری_, arte_, _خزان,
  { {0x26d10020, 0x63a40009, 0x29190085, 0x00000000}},  //   _nazo_, àini, _amsa_,
  { {0x7bcd0207, 0x290000b0, 0x00000000, 0x00000000}},  //   _esau, tkia_,   ,
  { {0x7d1d0197, 0x78660783, 0x29002eff, 0x00000000}},  //   ciss, сказ, ukia_,
  { {0x69030004, 0x2900002d, 0x26d100ca, 0x00000000}},  // [d620] _tõen, rkia_, _bazo_,
  { {0x29000006, 0x2bd50204, 0x656000f8, 0x00000000}},  //   skia_, दिरा, _simh,
  { {0xf99201b7, 0x62880119, 0x20a7007d, 0x00000000}},  //   _عبد_, _redo, _गांध,
  { {0xe76a004b, 0x6288008a, 0x133900a1, 0x00000000}},  //   _محسن_, _sedo, یتوں_,
  { {0x6903006c, 0x7dea006b, 0x54360025, 0x00000000}},  //   _mõel, ləst, حرار,
  { {0x7cff008d, 0x2d9e0056, 0x00000000, 0x00000000}},  //   _përk, yrte_,   ,
  { {0x64400046, 0x628801ca, 0x7e7e006c, 0x00000000}},  //   _wymi, _vedo, _õppi,
  { {0x65600051, 0x60f80401, 0x6288013e, 0x00000000}},  //   _uimh, рния_, _wedo,
  { {0x7d1d06d5, 0x6b40000c, 0x26d10045, 0x00000000}},  //   viss, lögu, _yazo_,
  { {0x7d1d0e42, 0x613e01d6, 0x00000000, 0x00000000}},  //   wiss, eëlt,   ,
  { {0x200201d9, 0x7d1d00b0, 0xa3d0007d, 0x00000000}},  //   ški_, tiss, षिक_,
  { {0xa06a003b, 0xc5f3009b, 0x2d9e2578, 0x00000000}},  //   _сада_, לדת_, rrte_,
  { {0x7d1d3ac6, 0x70560355, 0xa2dd0061, 0x00000000}},  //   riss, _انشا, पाच्,
  { {0xde58008b, 0x7d1d021e, 0x2d9e00ca, 0x00000000}},  //   _калі_, siss, prte_,
  { {0x7d1d0c7e, 0x7afa00f8, 0x00000000, 0x00000000}},  //   piss, ötta,   ,
  { {0x6b40000c, 0x00000000, 0x00000000, 0x00000000}},  //   dögu,   ,   ,
  { {0x26d1004a, 0x02fa0309, 0x56f500e2, 0x00000000}},  // [d630] _pazo_, ्साह_, опаѓ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7cff0065, 0x7e6d0095, 0x00000000, 0x00000000}},  //   _përh, _şapk,   ,
  { {0x2ec502f4, 0x26d10020, 0xb87b0051, 0x00000000}},  //   _वस्त, _wazo_, _inío,
  { {0x626502e9, 0x7af70288, 0x00000000, 0x00000000}},  //   овла, _koxt,   ,
  { {0x69d80dec, 0x00000000, 0x00000000, 0x00000000}},  //   _švei,   ,   ,
  { {0x945d0046, 0x7cff0065, 0xdce40166, 0x00000000}},  //   _pańs, _tërh, _sunč,
  { {0xdce411b9, 0x7af701c3, 0x33872337, 0x00000000}},  //   _punč, _loxt, _гужв,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xef190745, 0xbebc0089, 0x92940b81, 0x00000000}},  //   рмо_, lnīj, _науц,
  { {0x6b520030, 0xacea00ed, 0x7cff0065, 0x00000000}},  //   lægg, амна_, _zëri,
  { {0x7ae50082, 0x00000000, 0x00000000, 0x00000000}},  //   _anht,   ,   ,
  { {0x7af70e94, 0xb87b0051, 0x1b4a017f, 0x00000000}},  //   _boxt, _anío, изми_,
  { {0x613e0023, 0x00000000, 0x00000000, 0x00000000}},  //   bëls,   ,   ,
  { {0xfd120054, 0x6903006c, 0xab1901e1, 0x00000000}},  //   _يجب_, _tõel, сцях_,
  { {0x18670407, 0x48e30900, 0x00000000, 0x00000000}},  //   жати_, мосв,   ,
  { {0x7af70253, 0x9aa501b2, 0x00000000, 0x00000000}},  // [d640] _foxt, _کمپو,   ,
  { {0x6d46008d, 0x00000000, 0x00000000, 0x00000000}},  //   llka,   ,   ,
  { {0xb87b002a, 0xa2d40201, 0xe61a00e1, 0x00000000}},  //   _gnío, _योग्, јде_,
  { {0x69de0197, 0xec360049, 0xd94602dc, 0x00000000}},  //   _irpe, ֿאַר_, _феми,
  { {0x6b40000c, 0x00000000, 0x00000000, 0x00000000}},  //   sögu,   ,   ,
  { {0x2ae3013d, 0x6d4601a2, 0xb06200b0, 0x00000000}},  //   खाएँ_, hlka, äämi,
  { {0xaab203d7, 0x4ab2006e, 0x00000000, 0x00000000}},  //   _जानक, _जानव,   ,
  { {0xd1300025, 0x00000000, 0x00000000, 0x00000000}},  //   عمة_,   ,   ,
  { {0xc953012e, 0x5ed30044, 0xdde1012d, 0x00000000}},  //   ומה_, তানে, _ćušn,
  { {0x7b10010f, 0xeeb7007e, 0x69de3ac7, 0x00000000}},  //   _häuf, ольш_, _orpe,
  { {0x63a201c3, 0x7b10010f, 0x6b4000f8, 0x00000000}},  //   lron, _käuf, högs,
  { {0x3f8601aa, 0x7afa00f8, 0x00000000, 0x00000000}},  //   _twou_, öttn,   ,
  { {0x9f46010f, 0x69de3ac8, 0x00000000, 0x00000000}},  //   _groß_, _arpe,   ,
  { {0x7b10010f, 0x6d4601a3, 0xbd6a0478, 0x00000000}},  //   _läuf, alka, _крие_,
  { {0x63a20046, 0x59ce007d, 0x69de016c, 0x00000000}},  //   hron, _हैदर, _crpe,
  { {0x63a20065, 0x8d180d3a, 0xf77000a2, 0x00000000}},  //   kron, _وزير_, چال_,
  { {0xf77001fa, 0x63a22097, 0x466b0131, 0x00000000}},  // [d650] نال_, jron, арем_,
  { {0x63a20207, 0x3f7b0049, 0x629e00f7, 0x00000000}},  //   dron, יאמס, ópol,
  { {0x63a2009d, 0x7e7e010e, 0x6903010e, 0x00000000}},  //   eron, _õppu, _jõek,
  { {0x63a20207, 0xf9da0049, 0x613e0065, 0x00000000}},  //   fron, _פֿיל, këlq,
  { {0x63a200c7, 0x00000000, 0x00000000, 0x00000000}},  //   gron,   ,   ,
  { {0x78ad001e, 0xe738007e, 0xe9d80bb6, 0x00000000}},  //   lgav, _меў_, _اذیت_,
  { {0x63a20197, 0x00000000, 0x00000000, 0x00000000}},  //   aron,   ,   ,
  { {0x78ad000c, 0x63a20036, 0x7bdf03d1, 0x00000000}},  //   ngav, bron, _orqu,
  { {0x6b520030, 0x63a40045, 0x00000000, 0x00000000}},  //   læge, àint,   ,
  { {0x248d00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _heem_,   ,   ,
  { {0x7bdf02d5, 0xb87b008e, 0x628300ca, 0x00000000}},  //   _arqu, _aním, mbno,
  { {0xc1ba00a0, 0x71d600b3, 0x00000000, 0x00000000}},  //   _למעש, _מועד_,   ,
  { {0x80270054, 0x69de00b9, 0x60c90943, 0x00000000}},  //   _برام, _srpe, meem,
  { {0x3d020036, 0x63a40079, 0x2fcd054e, 0x00000000}},  //   _mówi_, šing, mweg_,
  { {0x2fcd3ac9, 0x23650089, 0x6f1800f3, 0x00000000}},  //   lweg_, _milj_, _بزنس_,
  { {0x248d0100, 0x60c9178a, 0x63a2070d, 0x00000000}},  //   _neem_, neem, yron,
  { {0x7cff008d, 0x2fcd0c4c, 0xb87b0048, 0x00000000}},  // [d660] _përv, nweg_, _gním,
  { {0x63a200f4, 0x69de0142, 0x60c901d6, 0x00000000}},  //   vron, _trpe, heem,
  { {0x69de3a19, 0x60c90961, 0x248d00fa, 0x00000000}},  //   _urpe, keem, _beem_,
  { {0x60c90045, 0x00000000, 0x00000000, 0x00000000}},  //   jeem,   ,   ,
  { {0x63a216cc, 0x248d08ce, 0x645d0062, 0x00000000}},  //   uron, _deem_, _úsil,
  { {0x23650059, 0xb3e901b7, 0x2fcd01a2, 0x00000000}},  //   _cilj_, تعمل_, dweg_,
  { {0x69dc3079, 0xe2970545, 0x39420022, 0x00000000}},  //   nvre, чај_, _kkks_,
  { {0x63a201b5, 0x859b009b, 0xe01d013d, 0x00000000}},  //   pron, _לשלו, _बेहद_,
  { {0x2fcd0116, 0x39420022, 0x00000000, 0x00000000}},  //   gweg_, _mkks_,   ,
  { {0x0dca026b, 0xdce40089, 0x75220459, 0x00000000}},  //   буми_, _runā, lioz,
  { {0x908a0054, 0x127b0049, 0xb87b01ca, 0x00000000}},  //   _هناك_, _האבע, _sním,
  { {0x75220032, 0x613e0023, 0x69dc01c3, 0x00000000}},  //   nioz, pëlq, dvre,
  { {0x673e1275, 0x8ae70088, 0x656e011c, 0x00000000}},  //   kopj, півл, _lubh,
  { {0x7b6401f9, 0x4ab20061, 0x75220026, 0x00000000}},  //   етсе, _जाणव, hioz,
  { {0x7cff0065, 0x78ad1696, 0xceb30097, 0x00000000}},  //   _bërt, tgav, _ניק_,
  { {0x8e470054, 0x6b520030, 0x78ad0e3f, 0x00000000}},  //   _عليك_, væge, ugav,
  { {0x78ad00b5, 0xc6f9004c, 0x75220032, 0x00000000}},  // [d670] rgav, онах_, dioz,
  { {0x04f90055, 0x7d0d0428, 0x248d00ab, 0x00000000}},  //   _আগের_, _hlas, _seem_,
  { {0x28f907ca, 0x78ad3aca, 0x75220023, 0x00000000}},  //   _день_, pgav, fioz,
  { {0x656e0051, 0x69c500f6, 0x75220091, 0x00000000}},  //   _dubh, _iphe, gioz,
  { {0xe28e05b8, 0x394908c9, 0x248d00fa, 0x00000000}},  //   ка_, mlas_, _veem_,
  { {0x49b8007a, 0x39490781, 0xe3b0023c, 0x00000000}},  //   _باید_, llas_, طره_,
  { {0x7d0d0148, 0x60c903b6, 0x3949007f, 0x00000000}},  //   _olas, teem, olas_,
  { {0x7c3a0046, 0x2fcd01a0, 0xa4d40088, 0x00000000}},  //   ętrz, tweg_, _посі,
  { {0xa2b50265, 0x69dc0107, 0x60c900ab, 0x00000000}},  //   _обач, zvre, reem,
  { {0x2fcd2e0b, 0x69c50116, 0x39493acb, 0x00000000}},  //   rweg_, _ophe, hlas_,
  { {0x7d0d002b, 0xdca602b0, 0x39490995, 0x00000000}},  //   _blas, мани, klas_,
  { {0x7d0d0365, 0x69dc012d, 0x3866012d, 0x00000000}},  //   _clas, vvre, žori_,
  { {0x69c51624, 0x2ef5137c, 0xed570088, 0x00000000}},  //   _aphe, _оздр, ьою_,
  { {0x39493acc, 0xada10027, 0x75220032, 0x00000000}},  //   elas_, ľúbe, zioz,
  { {0x7cff0065, 0xaa4300e2, 0x5ed30044, 0x00000000}},  //   _përt, верл, তাদে,
  { {0x39490211, 0x7d0d3a03, 0xdce4001a, 0x00000000}},  //   glas_, _glas, _dună,
  { {0x7cff008d, 0x69dc01d6, 0x6d4430b2, 0x00000000}},  // [d680] _vërt, svre, _ikia,
  { {0x7d0d0059, 0x61e10016, 0x63ab3acd, 0x00000000}},  //   _zlas, _orll, dugn,
  { {0x39490211, 0x673e0023, 0x75d60025, 0x00000000}},  //   blas_, ropj, بيضا,
  { {0x3949275a, 0x100d007d, 0x660300ea, 0x00000000}},  //   clas_, िनाश_, ønka,
  { {0x75220065, 0x31c6006e, 0x3940009d, 0x00000000}},  //   rioz, लब्ध, mois_,
  { {0x3940009d, 0x75221126, 0x00000000, 0x00000000}},  //   lois_, sioz,   ,
  { {0xaac0007d, 0x9663019d, 0x00000000, 0x00000000}},  //   श्यक, _акре,   ,
  { {0x3940084d, 0x399b00b3, 0x6285000c, 0x00000000}},  //   nois_, קיפד, ðhor,
  { {0x8fa300e1, 0x26d80006, 0x24860823, 0x00000000}},  //   вање, _karo_, mbom_,
  { {0x26d80062, 0x6d443ace, 0x7d0d1d7a, 0x00000000}},  //   _jaro_, _akia, _slas,
  { {0x7d0d3acf, 0x2d982fef, 0x26d80035, 0x00000000}},  //   _plas, ére_, _maro_,
  { {0x26d8006a, 0x7e6d001a, 0x3f42000c, 0x00000000}},  //   _laro_, _şapt, gður_,
  { {0x69c50133, 0x3ce93ad0, 0x3940263c, 0x00000000}},  //   _sphe, _vnav_, dois_,
  { {0x7cff008d, 0x6d44002d, 0x21240051, 0x00000000}},  //   _përs, _ekia, limh_,
  { {0x394000f4, 0x3eb9006b, 0x39490253, 0x00000000}},  //   fois_, əst_, tlas_,
  { {0x7d0d0127, 0x21240051, 0x7cff0023, 0x00000000}},  //   _ulas, nimh_, _vërs,
  { {0x20041551, 0x39490211, 0x8bd4007e, 0x00000000}},  // [d690] nymi_, rlas_, _ажыц,
  { {0x26d80a15, 0x08540057, 0x39490089, 0x00000000}},  //   _caro_, твую, slas_,
  { {0x39490154, 0x26d80006, 0x3940009d, 0x00000000}},  //   plas_, _daro_, bois_,
  { {0x6b8d3ad1, 0x2912000a, 0x3940009d, 0x00000000}},  //   _kwag, chya_, cois_,
  { {0x26d80851, 0xf3cb023c, 0xc3cb01d8, 0x00000000}},  //   _faro_, تباه_, تظام_,
  { {0x26d83ad2, 0x63ab00d9, 0x6b8d21a4, 0x00000000}},  //   _garo_, rugn, _mwag,
  { {0x6145003b, 0x63b90016, 0x2fc60058, 0x00000000}},  //   нека, stwn, _apog_,
  { {0x63ab08eb, 0x29090052, 0x00000000, 0x00000000}},  //   pugn, nkaa_,   ,
  { {0x83350822, 0xafe501ff, 0x249f0066, 0x00000000}},  //   _знах, хопл, _idum_,
  { {0x6d560058, 0x6d4405d2, 0x68fd00f6, 0x00000000}},  //   _shya, _skia, _losd,
  { {0x2909021e, 0xd12e00a6, 0x656900b0, 0x00000000}},  //   kkaa_, شمی_, _kieh,
  { {0x28df0201, 0xfd120647, 0x6b8d0dfc, 0x00000000}},  //   _पोलि, اجد_, _bwag,
  { {0xeb9701be, 0x3f42009f, 0x6569021e, 0x00000000}},  //   ния_, rður_, _mieh,
  { {0x3b0a0057, 0x60db002d, 0x6d5d01c3, 0x00000000}},  //   чего_, ldum, amsa,
  { {0xf2d2007b, 0x26d83ad3, 0xc3320104, 0x00000000}},  //   װען_, _raro_, אום_,
  { {0x60db006c, 0x65690066, 0x26d81fc4, 0x00000000}},  //   ndum, _nieh, _saro_,
  { {0x07a30057, 0x26d8008e, 0x3940009d, 0x00000000}},  // [d6a0] латн, _paro_, rois_,
  { {0x29123ad4, 0x7bd60058, 0x2a7a00c4, 0x00000000}},  //   shya_, _isyu, _ufpb_,
  { {0x394002d5, 0x68fd0026, 0x26d819ae, 0x00000000}},  //   pois_, _fosd, _varo_,
  { {0x98a013f1, 0xbebc01c5, 0x00000000, 0x00000000}},  //   dnić_, lnīt,   ,
  { {0x65690066, 0x7afe0056, 0x26d80016, 0x00000000}},  //   _dieh, _kopt, _taro_,
  { {0xbcfb009d, 0xeb930049, 0x656901c3, 0x00000000}},  //   mmée, אָק_, _eieh,
  { {0x27e01241, 0x64a6007e, 0x20040036, 0x00000000}},  //   lvin_, _пава, wymi_,
  { {0x7afe3ad5, 0x25bb009b, 0x2167003b, 0x00000000}},  //   _lopt, _מצלמ, нији_,
  { {0x27e03ad6, 0x21240051, 0x25af0036, 0x00000000}},  //   nvin_, rimh_, ągle_,
  { {0x6569010f, 0x2ca02c0b, 0x6b8d0009, 0x00000000}},  //   _zieh, _adid_, _rwag,
  { {0x6b8d0e9e, 0x80bd0061, 0x7bd60022, 0x00000000}},  //   _swag, व्हे, _asyu,
  { {0x7cff0065, 0x614600ed, 0x65690066, 0x00000000}},  //   _përq, _џеда, _xieh,
  { {0x6d5d104b, 0x68fd0145, 0x69d804a5, 0x00000000}},  //   rmsa, _rosd, _švep,
  { {0x7afe0023, 0x27e00190, 0x2ca03ad7, 0x00000000}},  //   _copt, dvin_, _edid_,
  { {0x68fd023a, 0x290900b0, 0xb9250025, 0x00000000}},  //   _posd, tkaa_, نفسي,
  { {0x58d4013b, 0x6b8d0117, 0x290f0051, 0x00000000}},  //   лост, _twag, óga_,
  { {0x6b8d0046, 0xbcfb1184, 0x07090774, 0x00000000}},  // [d6b0] _uwag, rméd, ويري_,
  { {0x6569001f, 0x81d70044, 0x6b520030, 0x00000000}},  //   _sieh, ামত_, lægn,
  { {0xfb1c009b, 0x3ce60067, 0x644921e6, 0x00000000}},  //   _מוזמ, टाचे_, _syei,
  { {0x48ab0057, 0x237f0059, 0x98a0012d, 0x00000000}},  //   _этом_, _ptuj_, vnić_,
  { {0xc6a700e1, 0x65690ba4, 0x98a000b4, 0x00000000}},  //   _први, _vieh, wnić_,
  { {0x6569002b, 0x8c1c009b, 0x13080088, 0x00000000}},  //   _wieh, הודי, нній_,
  { {0x15a80265, 0x63a4002b, 0x656918fb, 0x00000000}},  //   _пъти_, ġina, _tieh,
  { {0xf994061e, 0x60d90066, 0x98a011af, 0x00000000}},  //   ארק_, _qawm, rnić_,
  { {0xe0d60642, 0x200b01ca, 0x00000000, 0x00000000}},  //   твы_, áci_,   ,
  { {0xaf0500ed, 0x00000000, 0x00000000, 0x00000000}},  //   тпол,   ,   ,
  { {0x7cff008d, 0x60db0022, 0x6903006c, 0x00000000}},  //   _përp, pdum, _jões,
  { {0xeb9a004c, 0x7afe18be, 0x332704d2, 0x00000000}},  //   мим_, _sopt, linx_,
  { {0x7afe0224, 0x00000000, 0x00000000, 0x00000000}},  //   _popt,   ,   ,
  { {0xa3e202fb, 0xe8ff00f4, 0x00000000, 0x00000000}},  //   धित_, _aoû_,   ,
  { {0xcb670140, 0x00000000, 0x00000000, 0x00000000}},  //   таре_,   ,   ,
  { {0x2d85030a, 0x33270685, 0x27e0014a, 0x00000000}},  //   mple_, hinx_, tvin_,
  { {0x7afe1e54, 0x81d70044, 0xa696003b, 0x00000000}},  // [d6c0] _topt, ামি_, вреј,
  { {0xbcfb009d, 0x06830088, 0x00000000, 0x00000000}},  //   rmée, игун,   ,
  { {0x27e00239, 0x2d852ed5, 0xdbe3009d, 0x00000000}},  //   svin_, nple_, _rééc,
  { {0xd826051f, 0x779400a6, 0x7c22000c, 0x00000000}},  //   _адми, _میرا, _þors,
  { {0x6903006c, 0x290c0089, 0xd4670fa6, 0x00000000}},  //   _võet, ūdas_, вице_,
  { {0x8c1b00b3, 0xa89401c5, 0x00000000, 0x00000000}},  //   ווני, šķīr,   ,
  { {0x7bc10035, 0x00000000, 0x00000000, 0x00000000}},  //   ălui,   ,   ,
  { {0xf99300b6, 0x31ba0065, 0x66031598, 0x00000000}},  //   ברה_, rëz_, änke,
  { {0xa2bf001c, 0x2d850bd3, 0x2489004a, 0x00000000}},  //   ल्ह्, eple_, ñame_,
  { {0x9df800ed, 0xb87b06c2, 0x00000000, 0x00000000}},  //   енот_, _unív,   ,
  { {0x4c950088, 0x62980161, 0x320700b4, 0x00000000}},  //   линс, mavo, cyny_,
  { {0x629806ae, 0xd0260ae0, 0x00000000, 0x00000000}},  //   lavo, _имей,   ,
  { {0xdcfb001e, 0xd00f0025, 0x7ff315dd, 0x00000000}},  //   lstī, _ولم_, _نسوا,
  { {0xb3450181, 0x62983ad8, 0x5b270088, 0x00000000}},  //   moçã, navo, тьма,
  { {0x1db6007d, 0x6b520030, 0x236c00d9, 0x00000000}},  //   _अमित, mægl, _midj_,
  { {0x27ed002b, 0x6934060e, 0x00000000, 0x00000000}},  //   _ġenb_, ансу,   ,
  { {0x80be0044, 0x08550088, 0x320700b4, 0x00000000}},  // [d6d0] ্যপ্, уваю, zyny_,
  { {0xdcfb001e, 0x6d4f00d4, 0x629809fc, 0x00000000}},  //   kstī, llca, javo,
  { {0x63a40051, 0x62980dc6, 0x7c22000c, 0x00000000}},  //   áinn, davo, _þorr,
  { {0x588404af, 0x394d01d5, 0xf487019d, 0x00000000}},  //   _выра, ċess_, тужн,
  { {0xad1c007b, 0x4ac000e8, 0x9d1c01ce, 0x00000000}},  //   וואר, श्वव, וואט,
  { {0x6903006c, 0x62982289, 0x05950bb6, 0x00000000}},  //   _tões, gavo, _مارگ,
  { {0x80be0055, 0xb594005e, 0xd5b800ed, 0x00000000}},  //   ্যন্, _висш, _ист_,
  { {0xdfd10025, 0x7c3a0035, 0x657a0068, 0x00000000}},  //   ميع_, ştri, _étha,
  { {0x62980387, 0x657501f3, 0x00000000, 0x00000000}},  //   bavo, _huzh,   ,
  { {0x65750065, 0x637f0035, 0x00000000, 0x00000000}},  //   _kuzh, _vână,   ,
  { {0xd2510025, 0x4d660265, 0x2d850173, 0x00000000}},  //   _انا_, лков, uple_,
  { {0x637f001a, 0x2d850133, 0xdb060d24, 0x00000000}},  //   _tână, rple_, stkü,
  { {0x6575145d, 0x4fa500e3, 0xbebc0089, 0x00000000}},  //   _luzh, _силв, rnīr,
  { {0x8f9a007b, 0xe4560049, 0x6d4f0009, 0x00000000}},  //   _װיקי, טירט_, alca,
  { {0xfce60088, 0x98a601ee, 0x9404013f, 0x00000000}},  //   _бойо, ливе, _demə_,
  { {0x62983ad9, 0x00000000, 0x00000000, 0x00000000}},  //   zavo,   ,   ,
  { {0x6d46010a, 0x27e6002a, 0x46ea003b, 0x00000000}},  // [d6e0] moka, íon_, ндан_,
  { {0x6b840058, 0x00000000, 0x00000000, 0x00000000}},  //   _itig,   ,   ,
  { {0x69370243, 0xa3b601f5, 0x6b840066, 0x00000000}},  //   mćen, चून_, _htig,
  { {0xb87b0b76, 0x849600a1, 0x6575012d, 0x00000000}},  //   _caíd, اجائ, _duzh,
  { {0x6298001e, 0x4420001d, 0x06cf0044, 0x00000000}},  //   tavo, ài_, রাজি,
  { {0x63a41288, 0x533401fc, 0x65750066, 0x00000000}},  //   šino, јект, _fuzh,
  { {0x62980428, 0x290206ed, 0x6d463ada, 0x00000000}},  //   ravo, _koka_, koka,
  { {0x2902021e, 0xf993009b, 0x6d460006, 0x00000000}},  //   _joka_, זרה_, joka,
  { {0xe29206ea, 0x6298000c, 0x29020006, 0x00000000}},  //   _هذا_, pavo, _moka_,
  { {0x290227ad, 0x65620023, 0x3eb801a2, 0x00000000}},  //   _loka_, lmoh, ürt_,
  { {0x3f820089, 0x6d46253f, 0x10a60d51, 0x00000000}},  //   ūku_, foka, _биен,
  { {0x6d460010, 0x29020056, 0xdb0f0023, 0x00000000}},  //   goka, _noka_, pucë,
  { {0xdb1d0047, 0xc621007d, 0x3157009b, 0x00000000}},  //   ltsé, _मध्य_, _עידן_,
  { {0x501b00b6, 0x65620023, 0x00000000, 0x00000000}},  //   _אודו, hmoh,   ,
  { {0x13cd0055, 0x290201c9, 0x6d4607ef, 0x00000000}},  //   লিয়, _boka_, boka,
  { {0x2d9e0007, 0x6d463adb, 0x2902016c, 0x00000000}},  //   mste_, coka, _coka_,
  { {0x65750066, 0x2d9e01b5, 0xab5b01a2, 0x00000000}},  // [d6f0] _suzh, lste_, rtüb,
  { {0xb87b0181, 0x61e801c9, 0xeb9f1565, 0x00000000}},  //   _saíd, _ordl, msø_,
  { {0x2d9e0168, 0x290209c8, 0x44270241, 0x00000000}},  //   nste_, _foka_, گراف,
  { {0x2d9e3adc, 0x39a1010a, 0x01ba0044, 0x00000000}},  //   iste_, mės_, ংবাদ,
  { {0x39a1010a, 0x657501f3, 0x61e80048, 0x00000000}},  //   lės_, _wuzh, _ardl,
  { {0x2d9e3add, 0x6b7c0049, 0x6d46016a, 0x00000000}},  //   kste_, ערונ, zoka,
  { {0x39a10736, 0x6d4613df, 0xb87b052a, 0x00000000}},  //   nės_, yoka, _unís,
  { {0x2d9e0018, 0xd131057d, 0xb0f30044, 0x00000000}},  //   dste_, تمع_, জস্ব_,
  { {0x2d9e08ed, 0x02a7005e, 0x7f19007e, 0x00000000}},  //   este_, _брем, віну_,
  { {0x39a1010a, 0x2d9e3ade, 0x21260022, 0x00000000}},  //   kės_, fste_, _emoh_,
  { {0x2d9e018d, 0x6d46000b, 0x7bcd0ba5, 0x00000000}},  //   gste_, toka, _apau,
  { {0x39a10006, 0x00000000, 0x00000000, 0x00000000}},  //   dės_,   ,   ,
  { {0x2d9e0e66, 0x29020027, 0xef0e01ee, 0x00000000}},  //   aste_, _roka_, _дм_,
  { {0x29020020, 0x6d463adf, 0x5f74023c, 0x00000000}},  //   _soka_, soka, _طاهر,
  { {0xc89603f3, 0x6d463ae0, 0x6f030051, 0x00000000}},  //   ирањ, poka, _ionc,
  { {0xbcfb0010, 0xdb06014a, 0x00000000, 0x00000000}},  //   lmén, kukç,   ,
  { {0xa967005e, 0x3f9f00b0, 0x29022289, 0x00000000}},  // [d700] рита_, nsuu_, _voka_,
  { {0x39a1010a, 0xdb06014a, 0x6f03009d, 0x00000000}},  //   bės_, dukç, _jonc,
  { {0x6f0301aa, 0x29021de9, 0xab5b010f, 0x00000000}},  //   _monc, _toka_, stüc,
  { {0x628100b5, 0x7d04021e, 0x660309f0, 0x00000000}},  //   _aflo, _jois, änka,
  { {0x65623ae1, 0xbcfb0010, 0x00000000, 0x00000000}},  //   rmoh, kmén,   ,
  { {0x7d043ae2, 0x6f030207, 0x2d9e0c0f, 0x00000000}},  //   _lois, _nonc, yste_,
  { {0xbcfb0047, 0xe5a3017f, 0x60280089, 0x00000000}},  //   dmén, _мири, zīmī,
  { {0x7d0422d0, 0x628100fa, 0x7b1001a2, 0x00000000}},  //   _nois, _eflo, _säul,
  { {0x39a10006, 0x60f7007e, 0x6f030095, 0x00000000}},  //   zės_, рныя_, _bonc,
  { {0x2d9e049b, 0x7d160058, 0x7b1001a2, 0x00000000}},  //   tste_, _alys, _bäum,
  { {0x7bcd010a, 0x6f0304bd, 0x7d0411b1, 0x00000000}},  //   _spau, _donc, _bois,
  { {0x7d043ae3, 0x39a1010a, 0xf8bf008e, 0x00000000}},  //   _cois, vės_, _amén_,
  { {0x6f03028c, 0x2d9e3ae4, 0x7d04016e, 0x00000000}},  //   _fonc, sste_, _dois,
  { {0x6e940054, 0x39a1010a, 0x8f9b007b, 0x00000000}},  //   _الثا, tės_, _יידי,
  { {0x7d160030, 0x7cff0023, 0xba08005e, 0x00000000}},  //   _flys, _mërz, ахте_,
  { {0x9875008b, 0x39a1010a, 0x6f030026, 0x00000000}},  //   слац, rės_, _zonc,
  { {0x39a1010a, 0x6d4d3ae5, 0x63a43ae6, 0x00000000}},  // [d710] sės_, _ikaa, šinj,
  { {0x8aa7013b, 0x39a1010a, 0x67ca0089, 0x00000000}},  //   _трид, pės_, dējā,
  { {0x09f90054, 0x466b0878, 0x00000000, 0x00000000}},  //   _صفحة_, трам_,   ,
  { {0xbcfb0047, 0x3f860173, 0x26d3004a, 0x00000000}},  //   zmén, _otou_, sexo_,
  { {0x6d4d00e7, 0xd7f802be, 0x00000000, 0x00000000}},  //   _mkaa, _кур_,   ,
  { {0xc3240099, 0x973500a6, 0x00000000, 0x00000000}},  //   омік, _اکرا,   ,
  { {0x6f030197, 0x2002021e, 0x75820014, 0x00000000}},  //   _ronc, äkin_, _فیلم,
  { {0x6f030059, 0x7b10010f, 0x394900c4, 0x00000000}},  //   _sonc, _räum, noas_,
  { {0x6f030299, 0x7d04110a, 0xbcfb0010, 0x00000000}},  //   _ponc, _rois, tmén,
  { {0x7d16000c, 0x6d4d0020, 0x7d041063, 0x00000000}},  //   _slys, _akaa, _sois,
  { {0x7d040e4a, 0xb6da0049, 0x21ce006b, 0x00000000}},  //   _pois, אַכט, _cəhd_,
  { {0xcb0900b6, 0xd256009b, 0x27ed0066, 0x00000000}},  //   _אל_, _השעה_, _ġenn_,
  { {0x7d043ae7, 0x7f850054, 0x853a01ce, 0x00000000}},  //   _vois, _التن, רגרי,
  { {0x6f1a0270, 0x81bc0044, 0x00000000, 0x00000000}},  //   chtc, েটর_,   ,
  { {0x7d043ae8, 0x752900b9, 0x7d16005b, 0x00000000}},  //   _tois, _omez, _tlys,
  { {0x39490181, 0xb87b008e, 0x443f006b, 0x00000000}},  //   goas_, _raíc, _oxu_,
  { {0x66760426, 0x3952005b, 0xd7ea007e, 0x00000000}},  // [d720] مدار, rlys_, ымае_,
  { {0xe64601fb, 0x75292367, 0x395216a7, 0x00000000}},  //   безп, _amez, slys_,
  { {0x645b17df, 0x395204a5, 0x00000000, 0x00000000}},  //   _azui, plys_,   ,
  { {0x69de002b, 0x443f0066, 0x98ac0089, 0x00000000}},  //   _ispe, _bxu_, ēlēs_,
  { {0x7cff0065, 0x68e4014a, 0x5eaf0044, 0x00000000}},  //   _përz, mdid, জ্যে,
  { {0x67ca0089, 0x68e41e17, 0x00000000, 0x00000000}},  //   rējā, ldid,   ,
  { {0x443f3ae9, 0x80be0044, 0x68e4010e, 0x00000000}},  //   _exu_, ্যস্, odid,
  { {0xd1300025, 0x290000e7, 0x443f0066, 0x00000000}},  //   ظمة_, njia_, _fxu_,
  { {0xc6000044, 0x200d0010, 0x3dce00c4, 0x00000000}},  //   _এইটা_, gyei_, _spfw_,
  { {0x63a201c5, 0x6d4d0343, 0x69de064c, 0x00000000}},  //   mson, _skaa, _ospe,
  { {0x63a21fcb, 0x00000000, 0x00000000, 0x00000000}},  //   lson,   ,   ,
  { {0x629a3aea, 0x0db900a1, 0xe1f100a1, 0x00000000}},  //   _heto, گئیں_, _کسے_,
  { {0x63a22d2e, 0x68e422aa, 0xe04307e1, 0x00000000}},  //   nson, ddid, _енци,
  { {0x629a008d, 0xdd900084, 0x63a2009d, 0x00000000}},  //   _jeto, _قوت_, ison,
  { {0x80db0044, 0xc333009b, 0x127b0049, 0x00000000}},  //   ভার্, לוש_, ראלע,
  { {0x629a3692, 0x99550099, 0x29000065, 0x00000000}},  //   _leto, ікац, gjia_,
  { {0xdb0f0211, 0x394900c4, 0x63a200ea, 0x00000000}},  // [d730] lucí, roas_, json,
  { {0x629a0030, 0x63a200bb, 0x7bdf1343, 0x00000000}},  //   _neto, dson, _isqu,
  { {0x6eca0164, 0x63a201d6, 0x2489004a, 0x00000000}},  //   त्यु, eson, ñamo_,
  { {0x54550265, 0xa3b90070, 0x629a01d6, 0x00000000}},  //   овет, لاتر_, _aeto,
  { {0x63a23aeb, 0x29190146, 0x2bdf013d, 0x00000000}},  //   gson, _ilsa_, _पैमा,
  { {0x629a0a16, 0x6595007e, 0xdb063aec, 0x00000000}},  //   _ceto, _магу, stkö,
  { {0x27e9141a, 0x63a200d9, 0xf1a803ec, 0x00000000}},  //   lvan_, ason, مايه_,
  { {0x63a201c5, 0x753b0020, 0xdb0f008e, 0x00000000}},  //   bson, _ujuz, ducí,
  { {0xef190264, 0x63a20010, 0x60060147, 0x00000000}},  //   ими_, cson, жным_,
  { {0x629a0250, 0xc34b008b, 0x2ca93aed, 0x00000000}},  //   _geto, _сябе_, _adad_,
  { {0x2919005d, 0x7bdf008e, 0xab5b0010, 0x00000000}},  //   _olsa_, _asqu, ttün,
  { {0x69de1c1a, 0x629a21b0, 0x2ca9004a, 0x00000000}},  //   _rspe, _zeto, _cdad_,
  { {0x2d5900f4, 0xe134007e, 0x814c0049, 0x00000000}},  //   péen_, _энцы, _געאַ,
  { {0x2ca91433, 0x63a4002a, 0x3f8d1374, 0x00000000}},  //   _edad_, áini, mpeu_,
  { {0x7bdf0ca7, 0x2ca90045, 0x6ee43aee, 0x00000000}},  //   _esqu, _fdad_, _رسول,
  { {0x63a40006, 0x63a23aef, 0x7d1d01a2, 0x00000000}},  //   šini, yson, chss,
  { {0x68e40b76, 0x370601bd, 0x98a90036, 0x00000000}},  // [d740] rdid, опаг, znać_,
  { {0x2919130e, 0xab5b0676, 0xdceb012d, 0x00000000}},  //   _elsa_, ntül, _pufć,
  { {0x39460256, 0x629a028c, 0x69de0a38, 0x00000000}},  //   _мног, _reto, _uspe,
  { {0x629a0181, 0x63a20007, 0x938a003b, 0x00000000}},  //   _seto, tson, аска_,
  { {0x629a016c, 0x9346178d, 0xd403007c, 0x00000000}},  //   _peto, онде, дящи,
  { {0x47d9007b, 0x37d90049, 0xa3bb006e, 0x00000000}},  //   _פֿרײ, _פֿרע, _अमर_,
  { {0x65c30057, 0x629a00b0, 0x60c922c2, 0x00000000}},  //   _обра, _veto, ffem,
  { {0x63ad0580, 0x63a200bb, 0x1fa6041f, 0x00000000}},  //   šana, pson, орог,
  { {0x629a0065, 0xdfd00380, 0x50b70014, 0x00000000}},  //   _teto, ريد_, زديد_,
  { {0xcf260025, 0xbcfb00f4, 0x00000000, 0x00000000}},  //   تربي, rmém,   ,
  { {0x27e91140, 0x667b0097, 0xa3e2007d, 0x00000000}},  //   zvan_, יטיק, धिक_,
  { {0x27e9005a, 0xbfa30082, 0x7bc600ea, 0x00000000}},  //   yvan_, _kiế, ftku,
  { {0x1ae40055, 0x4ae7008b, 0xa06a012b, 0x00000000}},  //   খানে_, оўва, _тада_,
  { {0xb87b027b, 0xdce4012d, 0x00000000, 0x00000000}},  //   _caín, _dunđ,   ,
  { {0x7bc601a3, 0x00000000, 0x00000000, 0x00000000}},  //   atku,   ,   ,
  { {0x27e90232, 0x00000000, 0x00000000, 0x00000000}},  //   tvan_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [d750]   ,   ,   ,
  { {0x27e90100, 0xa92800b9, 0xd6db0184, 0x00000000}},  //   rvan_, _požá, јта_,
  { {0x657c0093, 0xab5b010f, 0x056b00ed, 0x00000000}},  //   _curh, ntüm, ајди_,
  { {0x657c0784, 0xbfa30082, 0x00000000, 0x00000000}},  //   _durh, _biế,   ,
  { {0x7ae501c2, 0x78fa009b, 0x69c700b5, 0x00000000}},  //   _kaht, _הפרו, ltje,
  { {0x20e70082, 0x7d1d0023, 0x00000000, 0x00000000}},  //   _ối_, ërsj,   ,
  { {0x4648008b, 0x9445026c, 0x69c700b5, 0x00000000}},  //   _дзён_, _کھان, ntje,
  { {0x212b0263, 0x7ae501c2, 0x04c90379, 0x00000000}},  //   òch_, _laht, _دوري_,
  { {0x60c9049a, 0x69c7016e, 0xe3e90123, 0x00000000}},  //   rfem, htje, _دکان_,
  { {0xa2b404b6, 0xef191020, 0x765500ea, 0x00000000}},  //   _обуч, смо_, _kyzy,
  { {0x69c7008d, 0xdce40645, 0xb87b0051, 0x00000000}},  //   jtje, _sunđ, _naío,
  { {0x8c4600ed, 0x7bc600ea, 0xab5b0010, 0x00000000}},  //   земе, ttku, stül,
  { {0x69c700b5, 0x7ae50145, 0x00000000, 0x00000000}},  //   etje, _baht,   ,
  { {0xa3ae03d7, 0x692c014a, 0x00000000, 0x00000000}},  //   _किस_, rşem,   ,
  { {0x7bc60dac, 0x00000000, 0x00000000, 0x00000000}},  //   stku,   ,   ,
  { {0x657a009d, 0x00000000, 0x00000000, 0x00000000}},  //   _éthi,   ,   ,
  { {0x68430057, 0x69c700b5, 0x1867019d, 0x00000000}},  // [d760] ента, atje, зати_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfebd0044, 0x00000000, 0x00000000, 0x00000000}},  //   _অসাধ,   ,   ,
  { {0x7ae51034, 0xd946025f, 0x00000000, 0x00000000}},  //   _zaht, _хеми,   ,
  { {0xf8b3019b, 0x2d980211, 0xdb1d0010, 0x00000000}},  //   _אשר_, árez_, ltsá,
  { {0x657c2316, 0xbfa30082, 0x3f82000c, 0x00000000}},  //   _turh, _viế, íkum_,
  { {0x7d1d0007, 0x6b520698, 0x672e0066, 0x00000000}},  //   ërsk, lægs, _imbj,
  { {0xbcfb0047, 0xbfa30011, 0xd259007e, 0x00000000}},  //   rmék, _tiế, цці_,
  { {0x61e100f6, 0x442200f8, 0x24860253, 0x00000000}},  //   _esll, _åk_, mcom_,
  { {0x24861401, 0x61e10066, 0x91e600e2, 0x00000000}},  //   lcom_, _fsll, _нозе,
  { {0x2d98028c, 0x1cd907d0, 0x68e60ace, 0x00000000}},  //   ère_, одны_, _oakd,
  { {0x24863af0, 0xf99300a1, 0x7ae508a7, 0x00000000}},  //   ncom_, ہبر_, _saht,
  { {0x61dc007d, 0x672e00ea, 0xab5b3af1, 0x00000000}},  //   _मनुष, _ombj, stüm,
  { {0x26da0182, 0xbcfb002a, 0x81cf0044, 0x00000000}},  //   jepo_, iméi, শির_,
  { {0x24860093, 0x7ae501c2, 0x68e600f8, 0x00000000}},  //   kcom_, _vaht, _bakd,
  { {0x672e0226, 0x69c700b5, 0x76550036, 0x00000000}},  //   _ambj, rtje, _ryzy,
  { {0x5ba4008b, 0x7ae53af2, 0x69c705d5, 0x00000000}},  // [d770] _прэз, _taht, stje,
  { {0x6d4f02d5, 0x6b8d011c, 0xec38009b, 0x00000000}},  //   loca, _itag, _מאחר_,
  { {0x692c014a, 0x60c2004a, 0x00000000, 0x00000000}},  //   kşeh, _ocom,   ,
  { {0x7d1d0065, 0x24860190, 0x32cf014a, 0x00000000}},  //   ërsh, gcom_, zıyı_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60c216b2, 0x63ad0089, 0x6d4f0051, 0x00000000}},  //   _acom, šano, hoca,
  { {0x24860062, 0x290b014a, 0xdb240010, 0x00000000}},  //   bcom_, _koca_, éséb,
  { {0x6b8d009d, 0x6d4f3af3, 0x290b3af4, 0x00000000}},  //   _otag, joca, _joca_,
  { {0x63a4002a, 0xd0a80025, 0xb4b90164, 0x00000000}},  //   áint, سطين_, चली_,
  { {0xee390057, 0x290b02a0, 0x3f8b0089, 0x00000000}},  //   жно_, _loca_, īcu_,
  { {0x9d4600ed, 0x63a9000c, 0x60c20009, 0x00000000}},  //   денд, _hven, _fcom,
  { {0x60c2002a, 0x63a9000c, 0x30150088, 0x00000000}},  //   _gcom, _kven, _одер,
  { {0xeb9702dd, 0x249f000a, 0x60db00e7, 0x00000000}},  //   мия_, _meum_, meum,
  { {0xdb1d0010, 0x6b8d0051, 0x60db00ea, 0x00000000}},  //   ttsá, _dtag, leum,
  { {0x290b0682, 0x68e60022, 0x6b8d04fb, 0x00000000}},  //   _boca_, _pakd, _etag,
  { {0x26da000b, 0x63a901e3, 0x6d4f033f, 0x00000000}},  //   wepo_, _oven, coca,
  { {0xcece0011, 0x290b3035, 0x68e600d9, 0x00000000}},  // [d780] _mộng_, _doca_, _vakd,
  { {0x36360014, 0xcece0082, 0x2ca000d9, 0x00000000}},  //   وراس, _lộng_, _heid_,
  { {0x68e63af5, 0x24861f1b, 0x26da0065, 0x00000000}},  //   _takd, tcom_, repo_,
  { {0xe45a019d, 0x290b0023, 0x00000000, 0x00000000}},  //   оже_, _goca_,   ,
  { {0xc3da03ec, 0x24860142, 0x136a01fc, 0x00000000}},  //   تباط_, rcom_, ошки_,
  { {0x6d4f037e, 0x60c20207, 0x24860253, 0x00000000}},  //   zoca, _scom, scom_,
  { {0x24860142, 0x7b10010f, 0x249f0009, 0x00000000}},  //   pcom_, _häus, _feum_,
  { {0xcece001d, 0x2ca00004, 0x78a40173, 0x00000000}},  //   _cộng_, _neid_, naiv,
  { {0x27e004c7, 0xc9530104, 0x692c014a, 0x00000000}},  //   nwin_, כמה_, rşeh,
  { {0x44260020, 0x2216005e, 0x3d9400ed, 0x00000000}},  //   mzo_, _офер, ниор,
  { {0x1d350822, 0x6d4f0207, 0x6b8d0e02, 0x00000000}},  //   ення, toca, _stag,
  { {0x66030ba4, 0x00000000, 0x00000000, 0x00000000}},  //   änki,   ,   ,
  { {0x44260fb1, 0x101606b4, 0x290b029a, 0x00000000}},  //   nzo_, _تباد, _roca_,
  { {0x290b03d1, 0x39420146, 0x00000000, 0x00000000}},  //   _soca_, _ajks_,   ,
  { {0x290b3af6, 0xd90f00d3, 0xc1dc0061, 0x00000000}},  //   _poca_, لید_, _मनोग,
  { {0x58d4004c, 0x80be0044, 0x78a4007f, 0x00000000}},  //   кост, ্যক্, gaiv,
  { {0x3fbc0055, 0x290b0107, 0x6b8d3af7, 0x00000000}},  // [d790] _অনুষ, _voca_, _utag,
  { {0x60db0010, 0x00000000, 0x00000000, 0x00000000}},  //   zeum,   ,   ,
  { {0xb8e50055, 0x63a902e1, 0x290b10af, 0x00000000}},  //   _এস_, _sven, _toca_,
  { {0xb4b90164, 0x7d0d2034, 0x00000000, 0x00000000}},  //   चले_, _joas,   ,
  { {0xcece001d, 0xdb1d0030, 0x7d0d0035, 0x00000000}},  //   _rộng_, rtsæ, _moas,
  { {0xfbb203d7, 0x31662512, 0xdb1d0030, 0x00000000}},  //   _जिसम, _ahoz_, stsæ,
  { {0xe5c4013b, 0x24800091, 0x4426007f, 0x00000000}},  //   _исто, žima_, azo_,
  { {0x75222e09, 0x7d0d000d, 0x3fe50216, 0x00000000}},  //   choz, _noas, ежив,
  { {0xe454008b, 0x61f80027, 0x20190344, 0x00000000}},  //   _акты, _ďalš, ási_,
  { {0x60db24c7, 0x2ca0010f, 0xeb0e0061, 0x00000000}},  //   seum, _seid_, _हवेत_,
  { {0xa2c40201, 0xed5a0256, 0x7d0d0133, 0x00000000}},  //   _रात्, зон_, _boas,
  { {0x7d0d00ab, 0xdb060062, 0x7c2601a2, 0x00000000}},  //   _coas, mské, tzkr,
  { {0xdb0601ca, 0x2ee7000a, 0x09a80061, 0x00000000}},  //   lské, _tanf_, गळ्य,
  { {0xada501a4, 0x316d014a, 0x00000000, 0x00000000}},  //   _закл, lmez_,   ,
  { {0x44260198, 0x3ea50004, 0xdb060428, 0x00000000}},  //   zzo_, malt_, nské,
  { {0x3ea510fb, 0x316d014a, 0x27e00253, 0x00000000}},  //   lalt_, nmez_, twin_,
  { {0x63ad01ae, 0x81d50055, 0x78a400c4, 0x00000000}},  // [d7a0] šanj, িটি_, raiv,
  { {0x27e00007, 0xff7a007b, 0x3ea501e3, 0x00000000}},  //   rwin_, פטעמ, nalt_,
  { {0x316d1db3, 0xba9b00b3, 0x362400a1, 0x00000000}},  //   kmez_, _מסיי, خواہ,
  { {0x3ea5001f, 0x27e00061, 0x81d50044, 0x00000000}},  //   halt_, pwin_, িটা_,
  { {0x3ea50cfd, 0x39403af8, 0x6937016c, 0x00000000}},  //   kalt_, mnis_, rćet,
  { {0x44262fd0, 0xf651026c, 0x3ea5006c, 0x00000000}},  //   rzo_, ائے_, jalt_,
  { {0x8cc1013d, 0x3ea53a77, 0xaad20061, 0x00000000}},  //   _वालो, dalt_, द्यक,
  { {0x39403af9, 0x6d440020, 0x00000000, 0x00000000}},  //   nnis_, _njia,   ,
  { {0x934634b3, 0x93c8026c, 0xbcfb33df, 0x00000000}},  //   _знае, _تازہ_, llég,
  { {0x3940010f, 0x80170025, 0x6d470161, 0x00000000}},  //   hnis_, عزيز_, čkam,
  { {0xd36f0076, 0x39400e48, 0x7d0d0065, 0x00000000}},  //   _اهل_, knis_, _poas,
  { {0x2724000c, 0x213f012d, 0x39520133, 0x00000000}},  //   _hönd_, cnuh_, joys_,
  { {0x3ea5006c, 0x7d0d001a, 0x0b8b005e, 0x00000000}},  //   balt_, _voas, ясни_,
  { {0x39400007, 0x6d560009, 0x628a009d, 0x00000000}},  //   enis_, _ekya, ncfo,
  { {0x39402be7, 0xcf57009b, 0x9967003b, 0x00000000}},  //   fnis_, _רבות_, етал,
  { {0x0e5b00b6, 0x394001a2, 0x6e2e000c, 0x00000000}},  //   _מדוב, gnis_, úbbu,
  { {0xdb1d0210, 0xb909007d, 0x00000000, 0x00000000}},  // [d7b0] ttsä, _यस_,   ,
  { {0x6d5d0073, 0x63ad016c, 0x3940006c, 0x00000000}},  //   llsa, šank, anis_,
  { {0xdb1d0073, 0x3940010f, 0x6d5d0007, 0x00000000}},  //   rtsä, bnis_, olsa,
  { {0xdb060161, 0xdb1d04ce, 0x00000000, 0x00000000}},  //   vské, stsä,   ,
  { {0xdb1d01a2, 0x81d50044, 0x3ea516ec, 0x00000000}},  //   ptsä, িয়া_, yalt_,
  { {0x68ed3afa, 0xdb0601ca, 0x290900b0, 0x00000000}},  //   ldad, tské, ljaa_,
  { {0x3ea50004, 0x9f4b3afb, 0x316d014a, 0x00000000}},  //   valt_, ící_, tmez_,
  { {0x68ed0004, 0x3ea5010f, 0x2bb2013d, 0x00000000}},  //   ndad, walt_, _जिला,
  { {0xa3ae03d7, 0x3ea5122f, 0xf8bf0047, 0x00000000}},  //   _किए_, talt_, _elég_,
  { {0x39400c66, 0xbcfb00b9, 0x68ed0d12, 0x00000000}},  //   znis_, hléd, hdad,
  { {0x68fd0193, 0xa3e9007d, 0x3ea501e3, 0x00000000}},  //   _onsd, यिक_, ralt_,
  { {0x3ea50004, 0x4087005e, 0x7db4007e, 0x00000000}},  //   salt_, _чужб, ысьц,
  { {0x68ed3afc, 0x3ea500f8, 0x00000000, 0x00000000}},  //   ddad, palt_,   ,
  { {0x68ed0181, 0x68fd000a, 0x6d5d129a, 0x00000000}},  //   edad, _ansd, alsa,
  { {0xa2c4006e, 0x39403afd, 0x81cf0044, 0x00000000}},  //   _रास्, tnis_, শিক_,
  { {0x68ed011c, 0xf1b201ce, 0x6d4404cb, 0x00000000}},  //   gdad, יסל_, _ujia,
  { {0x39400007, 0xfc3f0051, 0xf8bf00f6, 0x00000000}},  // [d7c0] rnis_, laín_, _amés_,
  { {0x39401ba5, 0x667600a2, 0x68ed3afe, 0x00000000}},  //   snis_, ندار, adad,
  { {0x6449027b, 0x75890088, 0x6b8407a9, 0x00000000}},  //   _axei, есів_, _huig,
  { {0x6b842d34, 0x63b90016, 0xbcfb0010, 0x00000000}},  //   _kuig, frwn, lmér,
  { {0x0fbc0044, 0x24800091, 0xf8bf00f6, 0x00000000}},  //   _অন্ধ, žimo_, _emés_,
  { {0x65690487, 0x6b84010e, 0x645b00e0, 0x00000000}},  //   _eheh, _muig, _dyui,
  { {0x6b840207, 0xe5a3025f, 0xbcfb00f4, 0x00000000}},  //   _luig, _виси, llée,
  { {0x2fcd001c, 0x656900d9, 0x00000000, 0x00000000}},  //   fteg_, _gheh,   ,
  { {0xa4b70097, 0x42ca00e2, 0x00000000, 0x00000000}},  //   _שלמה_, _оган_,   ,
  { {0x69ce03a9, 0x4d980088, 0x00000000, 0x00000000}},  //   ktbe, нкою_,   ,
  { {0xc0e7025a, 0x68ed006b, 0x79950009, 0x00000000}},  //   رفین_, ydad, xpzw,
  { {0x2002006c, 0x6b840112, 0x65690023, 0x00000000}},  //   äkis_, _buig, _xheh,
  { {0x6d5d01f3, 0x6eb90061, 0x7afe0022, 0x00000000}},  //   rlsa, ऊलखु, _bnpt,
  { {0x81d50044, 0x69ce01a2, 0xdce60089, 0x00000000}},  //   িটর_, ftbe, rmkā,
  { {0x987e011f, 0xaa58003b, 0x765c00ea, 0x00000000}},  //   _açık_, виру_, _nyry,
  { {0xbcfb3aff, 0x68ed3b00, 0xdcf900e5, 0x00000000}},  //   rmés, udad, _duvă,
  { {0x68ed02d5, 0x19580783, 0x6b84009d, 0x00000000}},  // [d7d0] rdad, таты_, _guig,
  { {0xa2c402f4, 0x65690a9e, 0x68ed00c7, 0x00000000}},  //   _राष्, _sheh, sdad,
  { {0x27ff0e00, 0x6b8400b5, 0x69ce00bb, 0x00000000}},  //   _šund_, _zuig, ctbe,
  { {0x99f600b6, 0x2d5900f4, 0x7d1d006c, 0x00000000}},  //   _עזרה_, mées_, nkss,
  { {0xd0060379, 0x63a0018e, 0x2d5900f4, 0x00000000}},  //   _ال_, _cwmn, lées_,
  { {0x56940099, 0xdb1d009d, 0x00000000, 0x00000000}},  //   _варт, fusé,   ,
  { {0x2d59028c, 0x39590022, 0x00000000, 0x00000000}},  //   nées_, _kkss_,   ,
  { {0x00e50264, 0x069700a1, 0x4fe900ed, 0x00000000}},  //   ужин, _ساڑھ, емин_,
  { {0x7ff50380, 0x63a00016, 0x2d59009d, 0x00000000}},  //   اسبا, _gwmn, hées_,
  { {0x6b8400bb, 0x2fcd0093, 0x8e090242, 0x00000000}},  //   _ruig, rteg_, енов_,
  { {0xdca60242, 0x69ce3b01, 0xdb1d009d, 0x00000000}},  //   лани, xtbe, cusé,
  { {0xa3e703d7, 0x2d91001e, 0x6b840129, 0x00000000}},  //   _बना_, īze_, _puig,
  { {0xdcf90089, 0xcee8009e, 0xdb0400fa, 0x00000000}},  //   _atvē, ررین_, _aviá,
  { {0x69ce010f, 0x6fb20879, 0x7d1d01c3, 0x00000000}},  //   ttbe, _اموا, akss,
  { {0x2d5900f4, 0xc332009b, 0x00000000, 0x00000000}},  //   gées_, מוך_,   ,
  { {0x6b840051, 0x7d1d09b0, 0x00000000, 0x00000000}},  //   _tuig, ckss,   ,
  { {0x69ce010f, 0x96960216, 0x628100b4, 0x00000000}},  // [d7e0] stbe, греш, _oglo,
  { {0x613e0089, 0xbcfb0068, 0x69ce3b02, 0x00000000}},  //   rīli, rlée, ptbe,
  { {0x2d5900f4, 0x692c001a, 0x00000000, 0x00000000}},  //   cées_, uşes,   ,
  { {0x62812234, 0x291e0089, 0x142600ed, 0x00000000}},  //   _aglo, ītas_, лдем,
  { {0xbd2d007b, 0x628f001a, 0x98a90036, 0x00000000}},  //   וואָ, _şcoa, wiać_,
  { {0xab5b014a, 0x7cfb0052, 0x00000000, 0x00000000}},  //   ltür, _kärä,   ,
  { {0x154600ed, 0x00000000, 0x00000000, 0x00000000}},  //   _бевм,   ,   ,
  { {0x62810173, 0x60f8005e, 0xab5b3b03, 0x00000000}},  //   _eglo, тния_, ntür,
  { {0x62810009, 0xd3f403e8, 0x00000000, 0x00000000}},  //   _fglo, _мiст,   ,
  { {0x2d59009d, 0x8f340131, 0x00000000, 0x00000000}},  //   yées_, реоц,   ,
  { {0xab5b0808, 0x2d59009d, 0xe29b009b, 0x00000000}},  //   ktür, xées_, _נשאר,
  { {0xac1902d3, 0x2d5900f4, 0x8fa6017f, 0x00000000}},  //   вому_, vées_, _баде,
  { {0xddcb1282, 0xbcfb008e, 0xd12f0439, 0x00000000}},  //   čišt, eléc, _عمه_,
  { {0x7bcf0857, 0x2d5900f4, 0xce94005e, 0x00000000}},  //   rtcu, tées_, _такъ,
  { {0xa3ab03d7, 0x78a60039, 0xaa590a33, 0x00000000}},  //   _कौन_, _bekv, тиву_,
  { {0x2d5900f4, 0x26d80b33, 0x00000000, 0x00000000}},  //   rées_, _abro_,   ,
  { {0x2d5900f4, 0x47350780, 0x78a600d9, 0x00000000}},  // [d7f0] sées_, анас, _dekv,
  { {0x291e008d, 0x2d5900f4, 0xe7330879, 0x00000000}},  //   ëtar_, pées_, حصر_,
  { {0x78a60010, 0xab5b013f, 0x2eee0544, 0x00000000}},  //   _fekv, stüs, _maff_,
  { {0x057402fd, 0x26d80d48, 0x2eee0544, 0x00000000}},  //   ماند, _ebro_, _laff_,
  { {0xab5b006b, 0x00000000, 0x00000000, 0x00000000}},  //   rrüf,   ,   ,
  { {0x41b50175, 0x77ba009b, 0x883a009b, 0x00000000}},  //   асит, _במשח, _יתרו,
  { {0xab5b010f, 0x2249005e, 0x00000000, 0x00000000}},  //   prüf, ъпки_,   ,
  { {0x5eaf0044, 0x00000000, 0x00000000, 0x00000000}},  //   জ্ঞে,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x62810107, 0xe80d007d, 0x00000000, 0x00000000}},  //   _uglo, _सपना_,   ,
  { {0x52840054, 0x60b500e9, 0x3f82000c, 0x00000000}},  //   _المك, _نمائ, íkur_,
  { {0x2d52004a, 0xee36078e, 0xc19a00a0, 0x00000000}},  //   láez_, рню_, _ישעי,
  { {0xa09a007b, 0x8fa53b04, 0x8d55007e, 0x00000000}},  //   _סיסט, _тале, стэч,
  { {0x5e87007e, 0xfaa300ed, 0xeb9702ea, 0x00000000}},  //   _судз, жаро, рир_,
  { {0xc33200b3, 0x83fd0010, 0x2d590068, 0x00000000}},  //   קול_, _szől, réer_,
  { {0x3ea73b05, 0x00000000, 0x00000000, 0x00000000}},  //   _hent_,   ,   ,

  { {0x3ea736c3, 0xb8ee0164, 0xab5b085e, 0x00000000}},  // [d800] _kent_, _रा_, rtür,
  { {0xf7721298, 0x27eb0009, 0xab5b0d85, 0x00000000}},  //   زاء_, _dscn_, stür,
  { {0x2d870038, 0x3ea7121b, 0xc4860264, 0x00000000}},  //   _june_, _ment_, алек,
  { {0x63640129, 0x69de002b, 0x6d46000c, 0x00000000}},  //   tòno, _ippe, nnka,
  { {0x68e43b06, 0x2902255a, 0x44200011, 0x00000000}},  //   meid, _inka_, ái_,
  { {0x8c1b00b6, 0x21ce006b, 0xa59601ab, 0x00000000}},  //   כוני, _məhv_, _вращ,
  { {0x4420001e, 0x1bed013d, 0x2d8701ee, 0x00000000}},  //   ši_, _चैनल_, _nune_,
  { {0x68e400b0, 0x2eee0af2, 0xdb1d00ea, 0x00000000}},  //   neid, _saff_, stsø,
  { {0x8f46007c, 0x42ea012b, 0xff06007e, 0x00000000}},  //   иход, _имао_, аянн,
  { {0x65620065, 0x69de01b5, 0x2d87001a, 0x00000000}},  //   lloh, _oppe, _bune_,
  { {0x68e40128, 0x3ea7009d, 0x171b0049, 0x00000000}},  //   keid, _dent_, דויע,
  { {0xb87b00fa, 0x00000000, 0x00000000, 0x00000000}},  //   _maír,   ,   ,
  { {0x69de028a, 0x3ea71c98, 0xa3c90061, 0x00000000}},  //   _appe, _fent_, लंय_,
  { {0x3ea704bd, 0x2d870026, 0x6d460052, 0x00000000}},  //   _gent_, _fune_, anka,
  { {0x68e4002a, 0x29881662, 0x2d87065c, 0x00000000}},  //   feid, исто_, _gune_,
  { {0x68e40006, 0xdb1d01ca, 0x1d08003b, 0x00000000}},  //   geid, musí, _већи_,
  { {0xbcfb2d2e, 0x69de1b8a, 0xad27009e, 0x00000000}},  // [d810] cléa, _eppe, _مرکو,
  { {0x307700b6, 0x2ca9167c, 0xb87b00fa, 0x00000000}},  //   שתמש_, _head_, _saís,
  { {0xb87b0b76, 0xa3c90183, 0x68e40292, 0x00000000}},  //   _país, लून_, beid,
  { {0x6705007d, 0x45840088, 0x5e790049, 0x00000000}},  //   राहक_, ігів, אָנד,
  { {0xc651026c, 0x37e4007e, 0x61fa00ea, 0x00000000}},  //   _کہاک, _доўг, _artl,
  { {0x97250123, 0x2ca900ab, 0xa3c90164, 0x00000000}},  //   _افسو, _lead_, लंब_,
  { {0x349509b2, 0x3ea73b07, 0x27e90022, 0x00000000}},  //   _габр, _rent_, lwan_,
  { {0x3ea73b08, 0x2d870030, 0x78ad05e0, 0x00000000}},  //   _sent_, _rune_, naav,
  { {0x3ea70173, 0x2d871de0, 0x00000000, 0x00000000}},  //   _pent_, _sune_,   ,
  { {0x2d871d24, 0x27e9011c, 0x68e40171, 0x00000000}},  //   _pune_, iwan_, zeid,
  { {0x6b963b09, 0x78ad00b0, 0x27e9008a, 0x00000000}},  //   _styg, kaav, hwan_,
  { {0xeb9a012b, 0x2ca90051, 0x3ea700ab, 0x00000000}},  //   лим_, _cead_, _went_,
  { {0x68e4001e, 0x2ca900ab, 0x6d4606d3, 0x00000000}},  //   veid, _dead_, rnka,
  { {0x60c9001f, 0x6e950054, 0x27e90739, 0x00000000}},  //   lgem, _الغا, dwan_,
  { {0x68e416a6, 0x3f8d0023, 0xa3c90061, 0x00000000}},  //   teid, lqeu_, लंड_,
  { {0x60c90149, 0x628f001a, 0x6ed30061, 0x00000000}},  //   ngem, _şcol, ब्रु,
  { {0x636401aa, 0x27e90c2d, 0x60c901d6, 0x00000000}},  // [d820] wònm, gwan_, igem,
  { {0x68e40232, 0x78ad041a, 0x7d16004a, 0x00000000}},  //   seid, aaav, _hoys,
  { {0x7bc60dc7, 0x7d04002b, 0x27e90093, 0x00000000}},  //   luku, _knis, awan_,
  { {0xab5b01f6, 0x7d160471, 0xdcf90006, 0x00000000}},  //   crüb, _joys, _buvę,
  { {0x7bc6015e, 0x60c90aba, 0x7d1600fa, 0x00000000}},  //   nuku, dgem, _moys,
  { {0x81e10055, 0x61fa00ee, 0xff470167, 0x00000000}},  //   দিন_, _prtl, _رخ_,
  { {0x7bc632ca, 0xdb1d0181, 0x248904eb, 0x00000000}},  //   huku, lusã, žama_,
  { {0xf8ba02d2, 0xa4910123, 0x7bc609bd, 0x00000000}},  //   ेलिय, _قیمت, kuku,
  { {0x2ca90038, 0x3eac010f, 0x7bc60020, 0x00000000}},  //   _read_, tadt_, juku,
  { {0x75220047, 0x2ca90181, 0x61fa016c, 0x00000000}},  //   lkoz, _sead_, _trtl,
  { {0x2ca9006c, 0x3eac0010, 0x80a60014, 0x00000000}},  //   _pead_, radt_, _همان,
  { {0x7bc60020, 0x30860025, 0x867b00b3, 0x00000000}},  //   fuku, _الإف, טריו,
  { {0x7bc60c4a, 0x78ad0052, 0x2ca9010e, 0x00000000}},  //   guku, vaav, _vead_,
  { {0x7d04049a, 0xab5b010f, 0x00000000, 0x00000000}},  //   _enis, drüc,   ,
  { {0x2ca9006c, 0xdb0f0051, 0xc33900b9, 0x00000000}},  //   _tead_, nscé, _říká,
  { {0x7bc62552, 0x27e9002b, 0xdb1d00c4, 0x00000000}},  //   buku, twan_, fusã,
  { {0xc8671e03, 0x78ad021e, 0x636d09f7, 0x00000000}},  // [d830] стви, raav, núnc,
  { {0x78ad3b0a, 0x27e90093, 0xa2cd0164, 0x00000000}},  //   saav, rwan_, _साध्,
  { {0x27e905ae, 0x60c93b0b, 0x78ad00b0, 0x00000000}},  //   swan_, ygem, paav,
  { {0x7ae73b0c, 0x2ee502ae, 0xab5b010f, 0x00000000}},  //   lejt, zelf_, brüc,
  { {0x69d5022b, 0x69c71414, 0x39493b0d, 0x00000000}},  //   ltze, luje, mnas_,
  { {0xa3aa02d2, 0x39490d90, 0x69d5002d, 0x00000000}},  //   _खबर_, lnas_, otze,
  { {0x69d50756, 0x5ea70044, 0x69c705fd, 0x00000000}},  //   ntze, _খালে, nuje,
  { {0x39490004, 0x69d5022b, 0x7bc6003f, 0x00000000}},  //   nnas_, itze, yuku,
  { {0x60c9028c, 0x69d5010f, 0x39492395, 0x00000000}},  //   rgem, htze, inas_,
  { {0x69c70027, 0x60c93b0e, 0x7d04012d, 0x00000000}},  //   kuje, sgem, _snis,
  { {0xf1dd0183, 0x69c700ee, 0x39493b0f, 0x00000000}},  //   _महिन, juje, knas_,
  { {0xed5a02b8, 0x2ee50b8d, 0x7bc60020, 0x00000000}},  //   ром_, self_, tuku,
  { {0xc178023c, 0x75290020, 0xbcfb076d, 0x00000000}},  //   _اصلا_, _mlez, plén,
  { {0xada508fd, 0x7bc60169, 0x39490d90, 0x00000000}},  //   _дакл, ruku, enas_,
  { {0x69c7045e, 0x6d4700ca, 0x7d160190, 0x00000000}},  //   guje, čkar, _toys,
  { {0x7d04006c, 0x7bc60145, 0x799c0016, 0x00000000}},  //   _unis, puku, rprw,
  { {0x69d5002d, 0x2b8f006b, 0xecb00044, 0x00000000}},  // [d840] atze, _güc_, _কাপড,
  { {0x39490211, 0x69c70b41, 0x753b001a, 0x00000000}},  //   anas_, buje, _amuz,
  { {0x75220047, 0x69c70142, 0x00000000, 0x00000000}},  //   tkoz, cuje,   ,
  { {0xab5b01a2, 0xd5760088, 0x7e6301c3, 0x00000000}},  //   prüc, цузь, _mynp,
  { {0x752200f4, 0x63640129, 0x61e10146, 0x00000000}},  //   rkoz, lòni, _apll,
  { {0x752916df, 0x96fa007e, 0x673e0065, 0x00000000}},  //   _elez, _тэму_, qipj,
  { {0x745400a1, 0xdb1d009d, 0x00000000, 0x00000000}},  //   _کھائ, ursé,   ,
  { {0x61f8001c, 0x68f60036, 0x75290089, 0x00000000}},  //   rvvl, ndyd, _glez,
  { {0xd0070098, 0x68f60016, 0x00000000, 0x00000000}},  //   жење_, idyd,   ,
  { {0xa3df013d, 0x6d4d00bb, 0xb7db0097, 0x00000000}},  //   _तहत_, _sjaa, סקיי,
  { {0x7ae70a9f, 0x39490006, 0xc693009b, 0x00000000}},  //   vejt, ynas_, ואת_,
  { {0xc0c70175, 0x248001ca, 0x69c70142, 0x00000000}},  //   _душе_, žimu_, vuje,
  { {0x7ae700b9, 0x68f60016, 0xdfcf0025, 0x00000000}},  //   tejt, ddyd, _لين_,
  { {0x4f570318, 0x636400d4, 0x7e6301d6, 0x00000000}},  //   _وجود_, fòni, _fynp,
  { {0x7ae73b10, 0x3a25000c, 0x636d0051, 0x00000000}},  //   rejt, álp_, núna,
  { {0x69c7041a, 0x69d50756, 0x2d9e053e, 0x00000000}},  //   ruje, rtze, mpte_,
  { {0x39492593, 0x7ae70065, 0x6d5d076a, 0x00000000}},  // [d850] rnas_, pejt, mosa,
  { {0x6d5d002d, 0x69c70142, 0x75291581, 0x00000000}},  //   losa, puje, _slez,
  { {0xa2c40201, 0x75293b11, 0x6b8d0066, 0x00000000}},  //   _राज्, _plez, _huag,
  { {0x636d0051, 0x6b8d0020, 0x6f18049c, 0x00000000}},  //   dúna, _kuag, _lovc,
  { {0x24891332, 0x3cfc00a3, 0x29191a0b, 0x00000000}},  //   žamo_, ילאנ, _iosa_,
  { {0x6f180091, 0x6d5d19dd, 0x291906ed, 0x00000000}},  //   _novc, hosa, _hosa_,
  { {0x29190020, 0x6d5d0010, 0xf6280088, 0x00000000}},  //   _kosa_, kosa, _діти_,
  { {0x753b3b12, 0x291900d4, 0x6b8d0068, 0x00000000}},  //   _umuz, _josa_, _ouag,
  { {0x6d5d023a, 0x6b8d1fd2, 0x7e630039, 0x00000000}},  //   dosa, _nuag, _synp,
  { {0x29193b13, 0x636d000c, 0x91f70025, 0x00000000}},  //   _losa_, búna, _وأضا,
  { {0xf8bf02d5, 0x68f60016, 0x6d5d00ea, 0x00000000}},  //   _além_, ydyd, fosa,
  { {0x63a91a60, 0xbcfb3ad9, 0x2919049a, 0x00000000}},  //   _kwen, blém, _nosa_,
  { {0x63a90263, 0x60db00e7, 0x7e6301d6, 0x00000000}},  //   _jwen, mfum, _wynp,
  { {0x63a93b14, 0x3b0a007c, 0x699601fb, 0x00000000}},  //   _mwen, щего_, зрах,
  { {0xa3ab0061, 0x6d5d0093, 0x39403b15, 0x00000000}},  //   कीत_, bosa, tiis_,
  { {0x29193b16, 0x636404bd, 0xed57005e, 0x00000000}},  //   _cosa_, ròni, _нощ_,
  { {0x8ca203d7, 0x68f6018e, 0x63a90009, 0x00000000}},  // [d860] _क्यो, rdyd, _nwen,
  { {0x3940006c, 0x4bfb01ce, 0x69c1013e, 0x00000000}},  //   siis_, _פליס, álec,
  { {0xceb2009b, 0x6e21098e, 0x2919004a, 0x00000000}},  //   גיב_, nylb, _fosa_,
  { {0x80db0044, 0x6e3c00c4, 0x63a934ce, 0x00000000}},  //   _মোস্, úrbi, _bwen,
  { {0x78a4129a, 0xb4bc013d, 0xa3e6007d, 0x00000000}},  //   mbiv, _आयी_, यौं_,
  { {0xf1a6013b, 0x2d9e2b60, 0x6d5d00e7, 0x00000000}},  //   прин, ypte_, zosa,
  { {0x64a6008b, 0x7986000b, 0xa2cd02fb, 0x00000000}},  //   _нава, _kikw, _सार्,
  { {0x63a90173, 0x25080167, 0x00000000, 0x00000000}},  //   _fwen, _برسی_,   ,
  { {0x63a9018e, 0x79860ed7, 0x6d5d3316, 0x00000000}},  //   _gwen, _mikw, vosa,
  { {0x539b019b, 0x79862db7, 0xb4bc013d, 0x00000000}},  //   _לימו, _likw, _आयु_,
  { {0x6d5d0010, 0x2baf01f5, 0x63a900bb, 0x00000000}},  //   tosa, जीना, _zwen,
  { {0xab5b010f, 0x2d9e0116, 0xa2cd0061, 0x00000000}},  //   grün, rpte_, _साऱ्,
  { {0x6d5d0127, 0xbcfb0010, 0x6b8d17f4, 0x00000000}},  //   rosa, llék, _quag,
  { {0x2919008e, 0x6d5d0ac2, 0x2d9e09b0, 0x00000000}},  //   _sosa_, sosa, ppte_,
  { {0x29190129, 0x6d5d0238, 0x6edb009b, 0x00000000}},  //   _posa_, posa, _החופ,
  { {0x3eae010f, 0x00000000, 0x00000000, 0x00000000}},  //   _heft_,   ,   ,
  { {0x798607a5, 0x57190930, 0x00000000, 0x00000000}},  // [d870] _dikw, ожая_,   ,
  { {0x9f4d3b17, 0x2d8e0087, 0x00000000, 0x00000000}},  //   rveç_, _kufe_,   ,
  { {0x63a927f5, 0x291900fa, 0x38c80752, 0x00000000}},  //   _swen, _tosa_, _کاپی_,
  { {0xe8eb026c, 0x3eae0866, 0x63a901aa, 0x00000000}},  //   _اردو_, _left_, _pwen,
  { {0xdb060039, 0xbfa30082, 0x00000000, 0x00000000}},  //   rrkö, _chế,   ,
  { {0x3eae005f, 0xa2d20061, 0xc2c40025, 0x00000000}},  //   _neft_, _ठाण्, فيهي,
  { {0x29d73b18, 0x25aa0016, 0xdce40243, 0x00000000}},  //   nça_, _gwbl_, _uhić,
  { {0x212b0036, 0x85050380, 0x29d700fa, 0x00000000}},  //   óch_, _تورن, iça_,
  { {0xab5b006b, 0x00000000, 0x00000000, 0x00000000}},  //   vrün,   ,   ,
  { {0x29d7014a, 0xa29401e1, 0x00000000, 0x00000000}},  //   kça_, _зафі,   ,
  { {0xc33200b6, 0x60db211e, 0x78bd0e3b, 0x00000000}},  //   _שוב_, pfum, _odsv,
  { {0x80db0044, 0x3f9f00b0, 0x00000000, 0x00000000}},  //   _মোর্, ppuu_,   ,
  { {0x7af70436, 0x798601f3, 0x9f4d0007, 0x00000000}},  //   _baxt, _rikw, nweë_,
  { {0x09e609ae, 0x79863b19, 0x78bd0009, 0x00000000}},  //   могн, _sikw, _adsv,
  { {0x79860173, 0x00000000, 0x00000000, 0x00000000}},  //   _pikw,   ,   ,
  { {0xb4bc006e, 0x3f87000c, 0x00000000, 0x00000000}},  //   _आये_, _hinu_,   ,
  { {0x18673b1a, 0x79860d16, 0x29d700c4, 0x00000000}},  // [d880] дати_, _vikw, aça_,
  { {0x8c43010f, 0x917a0082, 0x7af70288, 0x00000000}},  //   ößer, _mấy_, _gaxt,
  { {0x3f870004, 0x3f8f006c, 0x3ea1006c, 0x00000000}},  //   _minu_, _lugu_, _õhtu_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf8b300b3, 0x5eee0061, 0x00000000, 0x00000000}},  //   _בשר_, _असल्_,   ,
  { {0xae0d0164, 0x80db0044, 0x7bc600ea, 0x00000000}},  //   िमान_, _মোল্, irku,
  { {0x3f8f127f, 0x91e3003b, 0x201900b0, 0x00000000}},  //   _augu_, воје, äsin_,
  { {0x92ae0055, 0x66030030, 0x70c80061, 0x00000000}},  //   কলে_, ænke, ळलेल,
  { {0x3f8f0fcd, 0x00000000, 0x00000000, 0x00000000}},  //   _cugu_,   ,   ,
  { {0x3f8f022b, 0x692c014a, 0x8e1406e3, 0x00000000}},  //   _dugu_, rşey, едоц,
  { {0x3f87001a, 0x63a20232, 0xbcfb124d, 0x00000000}},  //   _dinu_, lpon, lléi,
  { {0x3f873b1b, 0xa00a0025, 0x7af7006b, 0x00000000}},  //   _einu_, _وقال_, _saxt,
  { {0x7b67004c, 0x7af70066, 0x63a2002d, 0x00000000}},  //   дтве, _paxt, npon,
  { {0xf047089d, 0x78af0035, 0xbcfb0048, 0x00000000}},  //   _تعمی, _secv, iléi,
  { {0x7af7005f, 0xb34500c4, 0x59f8005e, 0x00000000}},  //   _vaxt, liçã, меря_,
  { {0x29d703d1, 0x63762dfb, 0x3f870089, 0x00000000}},  //   rça_, lând, _zinu_,
  { {0xb8f7006e, 0xb3450181, 0x7af7006b, 0x00000000}},  // [d890] _सा_, niçã, _taxt,
  { {0x63760035, 0x29d73b1c, 0x3f8701f3, 0x00000000}},  //   nând, pça_, _xinu_,
  { {0xfc3f008e, 0x6d4f0026, 0x00000000, 0x00000000}},  //   país_, onca,   ,
  { {0x629a0039, 0x6d4f0d28, 0x672e0146, 0x00000000}},  //   _afto, nnca, _elbj,
  { {0x290b000d, 0x68ed0181, 0xe299007c, 0x00000000}},  //   _inca_, mead, пал_,
  { {0x68ed002a, 0xe299012b, 0xb3450181, 0x00000000}},  //   lead, чак_, diçã,
  { {0x44293b1d, 0xe0d10054, 0x3f8f3b1e, 0x00000000}},  //   ša_, هزة_, _sugu_,
  { {0x3f870004, 0x68ed3b1f, 0x636d008e, 0x00000000}},  //   _sinu_, nead, múnm,
  { {0x3995032e, 0x3f870032, 0x637600c4, 0x00000000}},  //   _lås_, _pinu_, fând,
  { {0x27e40073, 0x68ed30b3, 0x809f007d, 0x00000000}},  //   _ämne_, head, _ग्रे,
  { {0x68ed00ea, 0x3995063b, 0x3f871093, 0x00000000}},  //   kead, _nås_, _vinu_,
  { {0xb3450181, 0x68ed0285, 0x3f8f0091, 0x00000000}},  //   biçã, jead, _tugu_,
  { {0x68ed2582, 0xa11605f3, 0x6376001a, 0x00000000}},  //   dead, _سقوط_, bând,
  { {0x643a007b, 0xab2a008b, 0x290b001a, 0x00000000}},  //   לערנ, чога_, _anca_,
  { {0x63a20010, 0x68ed0051, 0x69c100b9, 0x00000000}},  //   zpon, fead, šlen,
  { {0x6376001a, 0x63bb3b20, 0x68ed2870, 0x00000000}},  //   mâne, _ovun, gead,
  { {0x6d463b21, 0x27e60016, 0x69c733c6, 0x00000000}},  // [d8a0] mika, ïon_, arje,
  { {0x39951c8c, 0xe9da00c0, 0x290b0087, 0x00000000}},  //   _fås_, _еко_, _enca_,
  { {0xfad700bd, 0x63bb00f8, 0x68ed17c9, 0x00000000}},  //   _אויך_, _avun, bead,
  { {0x69dc0fb6, 0x938a025f, 0x6135009f, 0x00000000}},  //   mtre, пска_, _hálf,
  { {0x69dc04bd, 0x63a200e0, 0xe2f80088, 0x00000000}},  //   ltre, upon, делі_,
  { {0x6d46015e, 0x63a20aa3, 0x69dc01d6, 0x00000000}},  //   hika, rpon, otre,
  { {0x69dc0f8e, 0x6d46083a, 0x27f23b22, 0x00000000}},  //   ntre, kika, lwyn_,
  { {0x63a20207, 0x6d4604cb, 0xb3450181, 0x00000000}},  //   ppon, jika, tiçã,
  { {0x6d463b23, 0xb4cc0061, 0x27f20016, 0x00000000}},  //   dika, लली_, nwyn_,
  { {0xb34502d5, 0x44260058, 0x2d890197, 0x00000000}},  //   riçã, myo_, _siae_,
  { {0x6d4601d5, 0xa0a6053c, 0xb34502d5, 0x00000000}},  //   fika, _заед, siçã,
  { {0x6d461330, 0x69dc0109, 0x69ce0032, 0x00000000}},  //   gika, dtre, dube,
  { {0x4426006a, 0x48fb013d, 0x68ed00fa, 0x00000000}},  //   nyo_, _लोगो_, vead,
  { {0x69dc010f, 0x69c70059, 0x6f0a0022, 0x00000000}},  //   ftre, trje, _unfc,
  { {0x68ed006c, 0x6d461158, 0xdb040211, 0x00000000}},  //   tead, bika, _avió,
  { {0x69c7008d, 0x7bda001a, 0x6d48004a, 0x00000000}},  //   rrje, ătur, éjat,
  { {0x68ed038f, 0x69dc00bb, 0x7d0d0020, 0x00000000}},  // [d8b0] read, atre, _inas,
  { {0x68ed0004, 0x44263b24, 0x69c7002b, 0x00000000}},  //   sead, dyo_, prje,
  { {0xceb3061e, 0x69dc0051, 0x7bcf12cb, 0x00000000}},  //   ריע_, ctre, lucu,
  { {0xa5670014, 0x88830014, 0x7bdd006c, 0x00000000}},  //   ردان, _میزن, otsu,
  { {0x7bdd168e, 0x4426011c, 0x7bcf014a, 0x00000000}},  //   ntsu, gyo_, nucu,
  { {0x6d461e86, 0x316601aa, 0x02c20451, 0x00000000}},  //   zika, _akoz_, айшо,
  { {0x95c8012b, 0x1a9c0049, 0x7bdd006c, 0x00000000}},  //   _пута_, ליגע, htsu,
  { {0x25be009f, 0x44260111, 0x600926f0, 0x00000000}},  //   _ætla_, byo_, дним_,
  { {0x442631c8, 0x4395005e, 0x7bcf0107, 0x00000000}},  //   cyo_, _разс, jucu,
  { {0x7d0d27c9, 0xd2f7026c, 0x69dc1291, 0x00000000}},  //   _anas, _سکتا_, ytre,
  { {0x6ea7026c, 0xdca60256, 0xed5a0072, 0x00000000}},  //   ونکہ_, кани, дон_,
  { {0x2cb2005f, 0xd24e007a, 0x63760181, 0x00000000}},  //   _qeyd_, _بچه_, râne,
  { {0x317f011f, 0x69dc00d9, 0x00000000, 0x00000000}},  //   mmuz_, wtre,   ,
  { {0x69dc193b, 0x316d00f4, 0x8ca2006e, 0x00000000}},  //   ttre, llez_, _क्रो,
  { {0x6d462092, 0xf2d201ce, 0x63760181, 0x00000000}},  //   pika, יעם_, lânc,
  { {0x69dc1014, 0xdb0f0051, 0x7d0d1473, 0x00000000}},  //   rtre, rscá, _gnas,
  { {0x63761290, 0x7bdd0e9c, 0x7bcf0145, 0x00000000}},  // [d8c0] nânc, ctsu, cucu,
  { {0x4426000b, 0x9bb7009b, 0x3ce3013d, 0x00000000}},  //   vyo_, _שהיה_, ट्ठे_,
  { {0x44260016, 0x6562012d, 0x14c80014, 0x00000000}},  //   wyo_, tooh, فهای_,
  { {0x44260d3b, 0xb4cc0204, 0x03a6003b, 0x00000000}},  //   tyo_, लले_, видо,
  { {0x32053b25, 0x07a600e2, 0x00000000, 0x00000000}},  //   _arly_, _јагн,   ,
  { {0x4426006a, 0x04430077, 0x316600ca, 0x00000000}},  //   ryo_, шечн, _skoz_,
  { {0x4426006a, 0xf74301fc, 0x39520006, 0x00000000}},  //   syo_, _теро, onys_,
  { {0x63760181, 0x395200b0, 0x6d560009, 0x00000000}},  //   fânc, nnys_, _njya,
  { {0xe80502fb, 0x60f7007e, 0x637600c4, 0x00000000}},  //   रिया_, тныя_, gânc,
  { {0x7d0d3b26, 0x21ce006b, 0xbcfb009d, 0x00000000}},  //   _snas, _məhz_, hlét,
  { {0x7d0d0022, 0xb87b00fa, 0x316d0068, 0x00000000}},  //   _pnas, _abíl, blez_,
  { {0x7bdd00f8, 0x7bcf3b27, 0x00000000, 0x00000000}},  //   ttsu, tucu,   ,
  { {0x60c20006, 0x10130014, 0x637600c4, 0x00000000}},  //   _idom, _نبود, cânc,
  { {0x7bcf22d9, 0x7bdd1e17, 0x752004c4, 0x00000000}},  //   rucu, rtsu, _lomz,
  { {0x27361e14, 0x7bdd010e, 0x7bcf00e5, 0x00000000}},  //   _mænd_, stsu, sucu,
  { {0x7d0d0020, 0xdb060062, 0xb4cc0061, 0x00000000}},  //   _unas, mský, ललो_,
  { {0xdb0601ca, 0x98750794, 0x02d20204, 0x00000000}},  // [d8d0] lský, улац, _सांभ,
  { {0x6d440046, 0x00000000, 0x00000000, 0x00000000}},  //   _zmia,   ,   ,
  { {0xdb0606b8, 0x60c214ba, 0x2baf01f5, 0x00000000}},  //   nský, _odom, जीरा,
  { {0x60c2035e, 0xe7951125, 0x00000000, 0x00000000}},  //   _ndom, _ماسک,   ,
  { {0x3949029d, 0xbcfb01cc, 0x752028e5, 0x00000000}},  //   mias_, llés, _domz,
  { {0x39491325, 0x27f90387, 0x61351365, 0x00000000}},  //   lias_, _issn_, _mále,
  { {0x21690373, 0x6145007c, 0x68fd0006, 0x00000000}},  //   ники_, лека, _kasd,
  { {0x63760181, 0x68fd0022, 0x27f900d9, 0x00000000}},  //   tânc, _jasd, _kssn_,
  { {0x5455005e, 0x68fd3b28, 0x1c07013d, 0x00000000}},  //   _сват, _masd, शिफल_,
  { {0x39493b29, 0x637600c4, 0x60c20052, 0x00000000}},  //   hias_, rânc, _edom,
  { {0x39490006, 0x2006237d, 0xd12e0123, 0x00000000}},  //   kias_, _eroi_, زمی_,
  { {0x40940098, 0x3949004a, 0x00000000, 0x00000000}},  //   _кршт, jias_,   ,
  { {0x39493b2a, 0xeb97046c, 0x81b50044, 0x00000000}},  //   dias_, лия_, _জমি_,
  { {0x2d910181, 0x00000000, 0x00000000, 0x00000000}},  //   ízes_,   ,   ,
  { {0x3949029d, 0xbcfb0129, 0x06b20044, 0x00000000}},  //   fias_, glés, _চালি,
  { {0x3949029d, 0x81b50044, 0x2cb9012d, 0x00000000}},  //   gias_, _জমা_, casd_,
  { {0x7d7b00a3, 0x68fd1b34, 0xa9d10044, 0x00000000}},  // [d8e0] _אנקו, _dasd, াবগঞ,
  { {0x81ea0055, 0x66760014, 0x657b2a10, 0x00000000}},  //   মিত_, هدار, _ahuh,
  { {0x394906d3, 0xf8bf00f4, 0x61350161, 0x00000000}},  //   bias_, _clés_, _zále,
  { {0x39490df9, 0x7afe0065, 0x27e63b2b, 0x00000000}},  //   cias_, _hapt, çons_,
  { {0xbef3001c, 0x7afe121b, 0x9cd7009b, 0x00000000}},  //   _असून_, _kapt, רונה_,
  { {0x08fc0055, 0xf7460057, 0x2900022b, 0x00000000}},  //   _একটু_, _сего, ldia_,
  { {0x27e0002b, 0x41e60025, 0x7afe0203, 0x00000000}},  //   ltin_, استف, _mapt,
  { {0x2900022b, 0xd0100025, 0x7afe0a60, 0x00000000}},  //   ndia_, قلب_, _lapt,
  { {0x29000020, 0x62870010, 0x2b4a00f6, 0x00000000}},  //   idia_, _újon, kibc_,
  { {0x138a0054, 0x27e03b2c, 0xe805006e, 0x00000000}},  //   _أخرى_, itin_, रिता_,
  { {0x22930025, 0x9f4f00f6, 0x27e028a2, 0x00000000}},  //   _المس, _argó_, htin_,
  { {0x27e00065, 0xdb0626a6, 0x39491c9e, 0x00000000}},  //   ktin_, kskó, xias_,
  { {0x7afe00f4, 0x39490489, 0xa2db0067, 0x00000000}},  //   _bapt, vias_, _नाम्,
  { {0x6b96014a, 0x61350802, 0xdb0601dc, 0x00000000}},  //   _duyg, _vále, pský,
  { {0x394900b0, 0x68e40197, 0x7afe0022, 0x00000000}},  //   tias_, ffid, _dapt,
  { {0x27e00a89, 0x29000129, 0x06cc0044, 0x00000000}},  //   ftin_, gdia_, র্মি,
  { {0x39490df9, 0x7afe000d, 0x68fd01d6, 0x00000000}},  // [d8f0] rias_, _fapt, _vasd,
  { {0x3949010a, 0xaadc0061, 0x657b3b2d, 0x00000000}},  //   sias_, _बायक, _shuh,
  { {0x39490489, 0x06cc0044, 0x00000000, 0x00000000}},  //   pias_, র্ভি,   ,
  { {0xc56b0d0b, 0x7afe331a, 0x68e40051, 0x00000000}},  //   رحال_, _zapt, cfid,
  { {0x27e01a86, 0x7afe011f, 0x78ad0bd5, 0x00000000}},  //   ctin_, _yapt, mbav,
  { {0x06cc0044, 0x26c30022, 0x27360190, 0x00000000}},  //   র্বি, _udjo_, _pæne_,
  { {0x657b3b2e, 0xe4a72337, 0x00000000, 0x00000000}},  //   _thuh, _брзо,   ,
  { {0x657b0145, 0x00000000, 0x00000000, 0x00000000}},  //   _uhuh,   ,   ,
  { {0x61fa01e2, 0x2f5502b8, 0x3f8e00e7, 0x00000000}},  //   _estl, итос, _bifu_,
  { {0x80d70061, 0x69cb0089, 0x2fdf3b2f, 0x00000000}},  //   _यावे, _āgen, rtug_,
  { {0xd2510355, 0x6135029d, 0x43840025, 0x00000000}},  //   _بنا_, _cálc, _اللق,
  { {0xeb9a2672, 0xd0110054, 0x7afe000d, 0x00000000}},  //   ким_, _ولا_, _sapt,
  { {0x98a00521, 0xed570121, 0x2d82016c, 0x00000000}},  //   lkić_, роя_, rmke_,
  { {0x2d9500d7, 0x2fcd3b30, 0xa3e8013d, 0x00000000}},  //   _крис, mreg_, _बहस_,
  { {0xc33200b6, 0x98a005fa, 0x20dc0061, 0x00000000}},  //   חום_, nkić_, _यामध,
  { {0x27e0014a, 0x7afe3b31, 0xab5b01a2, 0x00000000}},  //   ttin_, _wapt, gsüb,
  { {0x29000207, 0x7afe3b32, 0x2fcd01d6, 0x00000000}},  // [d900] rdia_, _tapt, nreg_,
  { {0xdb06000c, 0x4a46007c, 0x68e40de2, 0x00000000}},  //   rskó, _внов, sfid,
  { {0x27e0021e, 0xdb24007a, 0x98a00107, 0x00000000}},  //   stin_, _نوکی, jkić_,
  { {0x27e02741, 0x84e601ff, 0x6abc01e5, 0x00000000}},  //   ptin_, родж, larf,
  { {0xa803007e, 0x00000000, 0x00000000, 0x00000000}},  //   _дзял,   ,   ,
  { {0x69ce02ae, 0x31c60242, 0x6abc000c, 0x00000000}},  //   orbe, асив, narf,
  { {0xd24f00b8, 0xe297003b, 0x00000000, 0x00000000}},  //   ونه_, шај_,   ,
  { {0xbcfb00b9, 0x6abc01a2, 0x3f8e0145, 0x00000000}},  //   jlép, harf, _sifu_,
  { {0xd0e202f4, 0x2fcd0022, 0x03a300c0, 0x00000000}},  //   क्षण_, greg_, _мито,
  { {0x80a602d2, 0x25750039, 0x6abc000c, 0x00000000}},  //   _ट्रे, håll_, jarf,
  { {0x06970452, 0x6abc04f2, 0x2fcd0253, 0x00000000}},  //   ידים_, darf, areg_,
  { {0x61350802, 0x00000000, 0x00000000, 0x00000000}},  //   _válc,   ,   ,
  { {0x6abc018e, 0x69ce3b33, 0x00000000, 0x00000000}},  //   farf, erbe,   ,
  { {0xa3ab0061, 0x6d5d009d, 0x98a9050f, 0x00000000}},  //   कीट_, érab, rkač_,
  { {0xff7b0049, 0x98a90087, 0xc178007f, 0x00000000}},  //   _שטומ, skač_, _upės_,
  { {0x3ce9016c, 0x2d5204eb, 0x636d0048, 0x00000000}},  //   _ubav_, všeg_, lúnt,
  { {0x58870783, 0xdb0400c4, 0x69ce010f, 0x00000000}},  // [d910] рыва, _aviõ, arbe,
  { {0x61353b34, 0x399c03df, 0x6abc0203, 0x00000000}},  //   _mála, _fís_, carf,
  { {0xd00606c6, 0x04950025, 0x00000000, 0x00000000}},  //   _کل_, ملاح,   ,
  { {0x69d500d2, 0x7af50232, 0x00000000, 0x00000000}},  //   muze, lezt,   ,
  { {0xfc3f00b9, 0x613513ae, 0x69d5002d, 0x00000000}},  //   nzí_, _nála, luze,
  { {0xf36701fc, 0x7af515ea, 0x00000000, 0x00000000}},  //   штен, nezt,   ,
  { {0x236731e1, 0x27f50276, 0x00000000, 0x00000000}},  //   ronj_, şanı_,   ,
  { {0x06cc0044, 0x2fcd001a, 0x257c0048, 0x00000000}},  //   র্দি, treg_, tíle_,
  { {0xdee508f3, 0x7af50010, 0xc2eb0025, 0x00000000}},  //   бопи, kezt, _لعام_,
  { {0x41e705b8, 0x2fcd1194, 0x636d008e, 0x00000000}},  //   _віда, rreg_, gúnt,
  { {0x4d6602dc, 0x7af50e0c, 0x2fcd01d6, 0x00000000}},  //   йков, dezt, sreg_,
  { {0x69d50091, 0xee360259, 0x40950025, 0x00000000}},  //   duze, сню_, _الإر,
  { {0x6abc000c, 0x30850025, 0x00000000, 0x00000000}},  //   tarf, _الشف,   ,
  { {0xfaa300ed, 0x69d52997, 0x7af53a22, 0x00000000}},  //   заро, fuze, gezt,
  { {0x8e3a00a1, 0xbb4304dd, 0x69ce00bb, 0x00000000}},  //   _مسٹر_, черк, urbe,
  { {0x3a250039, 0x69ce11f0, 0xab5b01a2, 0x00000000}},  //   älpa_, rrbe, früs,
  { {0xc6960025, 0x6abc205b, 0x79843b35, 0x00000000}},  // [d920] مشاع, parf, rmiw,
  { {0xf7720025, 0x69d50704, 0xdb1d009d, 0x00000000}},  //   ساء_, buze, yssé,
  { {0x31950089, 0xd0f90309, 0xa50a026b, 0x00000000}},  //   _kāzu_, ्याण_, лежа_,
  { {0xd91000d3, 0x5a1700b3, 0x93aa0025, 0x00000000}},  //   _تیر_, _הקטן_, هاتف_,
  { {0x2d9200e7, 0xe5050025, 0x68f6349d, 0x00000000}},  //   _miye_, تبلي, meyd,
  { {0xf6d501fb, 0x2902011c, 0x2d920173, 0x00000000}},  //   _міся, _haka_, _liye_,
  { {0x29020244, 0xdb1d009d, 0x1a9b0049, 0x00000000}},  //   _kaka_, ussé, ניקע,
  { {0x29020036, 0xf99300b3, 0x2d92005a, 0x00000000}},  //   _jaka_, הרה_, _niye_,
  { {0x3d1c001c, 0x7454026c, 0x29020149, 0x00000000}},  //   याने_, _بھائ, _maka_,
  { {0x61351bc0, 0x539b0097, 0x11d601ff, 0x00000000}},  //   _vála, _עיבו, _гідр,
  { {0x2d980007, 0x6146007c, 0x68f602d1, 0x00000000}},  //   êre_, _лежа, keyd,
  { {0xd7fe00ad, 0x2902006a, 0xd6de0055, 0x00000000}},  //   _đăng_, _naka_, ড়িয,
  { {0x2d92011f, 0x71650025, 0x7af515ea, 0x00000000}},  //   _diye_, _بالك, tezt,
  { {0x69d50107, 0x637f0181, 0x613c0d4e, 0x00000000}},  //   tuze, cênd, _bélg,
  { {0x29022de7, 0xd6de0044, 0x68f60016, 0x00000000}},  //   _baka_, ড়ায, feyd,
  { {0x69d5003b, 0x4975008b, 0x3ebe0da6, 0x00000000}},  //   ruze, ілас, latt_,
  { {0x6d4f1e91, 0x290700b9, 0x981700a1, 0x00000000}},  // [d930] mica, ěna_, حبزا,
  { {0xec3800b6, 0x06cc0044, 0x613c3b36, 0x00000000}},  //   _לאחר_, র্সি, _héld,
  { {0x2126309b, 0xa3db0061, 0xab5b010f, 0x00000000}},  //   _oooh_, ढून_, srüs,
  { {0x68f6343e, 0x2902000a, 0x3ebe0203, 0x00000000}},  //   ceyd, _gaka_, hatt_,
  { {0x3ebe00f8, 0x320c0aa3, 0x5ed00044, 0x00000000}},  //   katt_, _ardy_, ত্যে,
  { {0x55bb0014, 0x85bb0380, 0xdcb6007d, 0x00000000}},  //   _مطرح_, _مارس_, _अज्ञ,
  { {0x6d4f19e4, 0x7aea010f, 0x613501dc, 0x00000000}},  //   kica, _öfte, _dáln,
  { {0x212602d4, 0x81ea0044, 0x6d4f199a, 0x00000000}},  //   _cooh_, মিং_, jica,
  { {0x200b0428, 0x320c0058, 0x3f990082, 0x00000000}},  //   íci_, _erdy_, êsu_,
  { {0x63a90181, 0x2d92065e, 0x656b0207, 0x00000000}},  //   _iten, _siye_, logh,
  { {0x2d923b37, 0x637f00c4, 0x442f3b38, 0x00000000}},  //   _piye_, gêne, lyg_,
  { {0x6d4f0e3e, 0xdb060039, 0x656b140b, 0x00000000}},  //   gica, nskö, nogh,
  { {0x3ebe05ad, 0xae1701ef, 0x2cad008e, 0x00000000}},  //   batt_, _گذشت, ñeda_,
  { {0x3b0a0057, 0x29020225, 0x6d4f0211, 0x00000000}},  //   шего_, _saka_, ébar,
  { {0x6d4f12cb, 0x290201aa, 0x68f6021e, 0x00000000}},  //   bica, _paka_, teyd,
  { {0x6f0304cb, 0x6d4f00c4, 0x25be000c, 0x00000000}},  //   _hanc, cica, _ætli_,
  { {0x6f03004f, 0x574a0888, 0x394b01ee, 0x00000000}},  // [d940] _kanc, азам_, _dmcs_,
  { {0x6f0301d6, 0x442f1938, 0x68f63b39, 0x00000000}},  //   _janc, dyg_, seyd,
  { {0x6f0308ed, 0x2902009f, 0x3ce10061, 0x00000000}},  //   _manc, _taka_, _कामे_,
  { {0x186a0077, 0x7d04002d, 0xd6b20044, 0x00000000}},  //   _вами_, _jais, _চাওয,
  { {0x7d0418dc, 0x69c10802, 0x06cc0044, 0x00000000}},  //   _mais, šlet, র্ষি,
  { {0x7d043b3a, 0x6d4f001a, 0xf1a60407, 0x00000000}},  //   _lais, zica, орин,
  { {0x63a90315, 0x613c0092, 0xd13a007c, 0x00000000}},  //   _eten, _léle, ихи_,
  { {0x7d040ac2, 0x442f018e, 0x6d4f0781, 0x00000000}},  //   _nais, byg_, xica,
  { {0x3ebe0056, 0x00000000, 0x00000000, 0x00000000}},  //   tatt_,   ,   ,
  { {0x6d4f1fad, 0x7d16175e, 0x212600e0, 0x00000000}},  //   wica, _anys, _wooh_,
  { {0x7d043b3b, 0x3ebe0aca, 0x613c0047, 0x00000000}},  //   _bais, ratt_, _péld,
  { {0x7d041321, 0x3ebe01c9, 0x78a4012d, 0x00000000}},  //   _cais, satt_, jciv,
  { {0xe133008b, 0x64420173, 0x613c0249, 0x00000000}},  //   _іншы, nzoi, _céle,
  { {0x6d4f0df9, 0x60c001a3, 0x613c3b3c, 0x00000000}},  //   sica, lamm, _déle,
  { {0x7d043b3d, 0xd90f007a, 0x9e6601ef, 0x00000000}},  //   _fais, نید_, _باشن,
  { {0x7d04001e, 0x6f030197, 0x60c00883, 0x00000000}},  //   _gais, _zanc, namm,
  { {0x637f00c4, 0x6d4d00e7, 0x00000000, 0x00000000}},  // [d950] nênc, _imaa,   ,
  { {0x7d04016c, 0x1bf4007e, 0x6f0300f6, 0x00000000}},  //   _zais, _ўпэў, _xanc,
  { {0x2d9c16b3, 0x442f0b04, 0x7d160016, 0x00000000}},  //   _juve_, wyg_, _ynys,
  { {0x2fc60119, 0x442f0073, 0x2d9c1aa8, 0x00000000}},  //   _ovog_, tyg_, _muve_,
  { {0x1835007b, 0x656b0420, 0xdb063b3e, 0x00000000}},  //   _זאָל_, rogh, rskö,
  { {0x637f02d5, 0x442f3b3f, 0x2d9c0154, 0x00000000}},  //   dênc, ryg_, _ouve_,
  { {0x6d4d0103, 0x26c100e0, 0x6f030a6b, 0x00000000}},  //   _omaa, maho_, _ranc,
  { {0x60c00232, 0x61350010, 0xda5c009b, 0x00000000}},  //   gamm, _válo, יכול,
  { {0x63a913f0, 0x753b037e, 0x6f0304cb, 0x00000000}},  //   _uten, _iluz, _panc,
  { {0x7d0433fd, 0x26c123fe, 0x6d4d0101, 0x00000000}},  //   _sais, naho_, _amaa,
  { {0xc332012f, 0x613c028c, 0x1d0a10d8, 0x00000000}},  //   _רוב_, _séle, бени_,
  { {0x78bd1322, 0xed5a0b9d, 0xc1040025, 0x00000000}},  //   _nesv, сом_, _يولي,
  { {0x7d04010a, 0x6f0304bd, 0x637f00c4, 0x00000000}},  //   _vais, _tanc, cênc,
  { {0x613c0047, 0x200f010a, 0x68ef0b33, 0x00000000}},  //   _véle, _irgi_, _abcd,
  { {0x7d043b40, 0x78bd04d7, 0xd356009b, 0x00000000}},  //   _tais, _besv, לישי_,
  { {0x613c1152, 0x3f9d0022, 0x7d040048, 0x00000000}},  //   _téle, _kuwu_, _uais,
  { {0x78bd0030, 0xeaaf00a1, 0xaa8a0167, 0x00000000}},  // [d960] _desv, ئٹہ_, _گندم_,
  { {0x869a00ed, 0x753b016c, 0x78a40197, 0x00000000}},  //   стат_, _aluz, sciv,
  { {0x1a9b0476, 0x4a9b007b, 0x7bc60030, 0x00000000}},  //   _לייע, _לייג, lsku,
  { {0x6376000d, 0xdb0d009f, 0xdbf2013e, 0x00000000}},  //   mâni, _hvað, hřív,
  { {0x26c1006a, 0x61350047, 0x7bc6000c, 0x00000000}},  //   baho_, _váll, nsku,
  { {0x637f0181, 0x7bc61081, 0xf4870167, 0x00000000}},  //   vênc, isku, سانی,
  { {0x2fc60119, 0x60c000f4, 0xa50a005e, 0x00000000}},  //   _svog_, tamm, _лева_,
  { {0xd1300054, 0x637f0181, 0x7bc601b6, 0x00000000}},  //   ئمة_, tênc, ksku,
  { {0x60c005b7, 0x2d9c006c, 0xd00700e2, 0x00000000}},  //   ramm, _suve_, зење_,
  { {0x60c0051d, 0x637f02d5, 0x6d4d3b41, 0x00000000}},  //   samm, rênc, _smaa,
  { {0x637f0181, 0xbfa50011, 0x2cad004a, 0x00000000}},  //   sênc, _hiệ, ñedo_,
  { {0x26c10009, 0xc27b00a3, 0x2fc60091, 0x00000000}},  //   zaho_, _פראי, _tvog_,
  { {0x78bd00f8, 0xdfcf0025, 0x00000000, 0x00000000}},  //   _resv, _مين_,   ,
  { {0x2d9c0211, 0x6ffb009b, 0x78bd016e, 0x00000000}},  //   _tuve_, _להדפ, _sesv,
  { {0x26c10009, 0x63760181, 0xde570088, 0x00000000}},  //   vaho_, gâni, _наші_,
  { {0x6d4d11b3, 0x39400051, 0xdff3006e, 0x00000000}},  //   _umaa, ghis_, _अहमद_,
  { {0xb9050201, 0x26c10922, 0x98750a94, 0x00000000}},  // [d970] _ना_, taho_, флац,
  { {0x753b041a, 0x6fcf0061, 0x6abe010f, 0x00000000}},  //   _sluz, _दिसू, _gepf,
  { {0x26c10061, 0x63760181, 0x6d5d0051, 0x00000000}},  //   raho_, câni, onsa,
  { {0x6d5d000c, 0x3940001a, 0xdced0521, 0x00000000}},  //   nnsa, chis_, _okač,
  { {0x2919000d, 0x2d520059, 0xdfc60426, 0x00000000}},  //   _insa_, kšen_, _جي_,
  { {0x27e90058, 0x68ed3b42, 0xe3b001fa, 0x00000000}},  //   mtan_, lfad, ارن_,
  { {0x2eec0009, 0x752900b5, 0x69c70056, 0x00000000}},  //   dfdf_, _toez, nsje,
  { {0x5694005c, 0x29090020, 0x7bc600b0, 0x00000000}},  //   _част, ndaa_, ysku,
  { {0x27e93b43, 0x69d5001f, 0x60060147, 0x00000000}},  //   ntan_, hrze, дным_,
  { {0x02a7003b, 0x333900d3, 0x27e91611, 0x00000000}},  //   _храм, _بزرگ_, itan_,
  { {0x69d50036, 0xbae30044, 0x69c71869, 0x00000000}},  //   jrze, য়াছ, jsje,
  { {0x69c73b44, 0x27e93335, 0x62810091, 0x00000000}},  //   dsje, ktan_, _izlo,
  { {0x68ed002a, 0x7bc600f2, 0x20030089, 0x00000000}},  //   dfad, usku, ājis_,
  { {0x7bc60286, 0x9f8401fb, 0x29193b45, 0x00000000}},  //   rsku, _згід, _ansa_,
  { {0xfc3f1024, 0x27e9022b, 0x68ed00f8, 0x00000000}},  //   rcía_, etan_, ffad,
  { {0x637600c4, 0x27e9014a, 0xdb1d006c, 0x00000000}},  //   râni, ftan_, dusõ,
  { {0xb87b00b9, 0x27e90b5a, 0x69d52eef, 0x00000000}},  // [d980] _sbír, gtan_, arze,
  { {0x613c00f4, 0x62810107, 0x3d1c0061, 0x00000000}},  //   _méla, _ozlo, यावे_,
  { {0x7afc0010, 0xd94600d7, 0x27e90149, 0x00000000}},  //   mert, _жени, atan_,
  { {0x69dc001a, 0x7afc133a, 0x61353b46, 0x00000000}},  //   mure, lert, _dálk,
  { {0x0edd0183, 0x27e933eb, 0x03a30077, 0x00000000}},  //   _मांड, ctan_, вичо,
  { {0x7afc0056, 0xbfa50011, 0x00000000, 0x00000000}},  //   nert, _việ,   ,
  { {0xdced016e, 0x6d5d000c, 0x628100b4, 0x00000000}},  //   _skač, ynsa, _czlo,
  { {0xab5b006b, 0x613c0ee5, 0xbfa50082, 0x00000000}},  //   vsüm, _béla, _tiệ,
  { {0xbcfb028c, 0x69dc00bb, 0x6d5d3b47, 0x00000000}},  //   nnée, hure, éram,
  { {0x613c00f4, 0x69dc0f77, 0x3ce101f5, 0x00000000}},  //   _déla, kure, _काहे_,
  { {0x68ed014a, 0x27e90032, 0x69dc0aa4, 0x00000000}},  //   yfad, ztan_, jure,
  { {0x613c009f, 0x69dc29e7, 0x27e90890, 0x00000000}},  //   _féla, dure, ytan_,
  { {0x7afc0198, 0x2d520521, 0x6d5d0332, 0x00000000}},  //   fert, pšen_, rnsa,
  { {0x69d50046, 0xc4c4026c, 0x7afc002d, 0x00000000}},  //   trze, _ھے_, gert,
  { {0x69dc3b48, 0xda7801e0, 0x613c0253, 0x00000000}},  //   gure, дят_, _zéla,
  { {0x69c700ea, 0x63760035, 0x00000000, 0x00000000}},  //   rsje, mânu,   ,
  { {0x69c73b49, 0xbcfb009d, 0x27e90173, 0x00000000}},  // [d990] ssje, gnée, utan_,
  { {0x27e9022b, 0x69d50046, 0x7bdd006a, 0x00000000}},  //   rtan_, prze, musu,
  { {0x27e93b4a, 0x7bdd006a, 0x69dc3b4b, 0x00000000}},  //   stan_, lusu, cure,
  { {0x27e9014a, 0x2919011c, 0x613501dc, 0x00000000}},  //   ptan_, _unsa_, _válk,
  { {0x7bdd3335, 0x9f9a021e, 0x62810010, 0x00000000}},  //   nusu, nään_, _szlo,
  { {0x63a0000d, 0xc2c50025, 0x61ea0332, 0x00000000}},  //   _dumn, ريبي, ftfl,
  { {0xe1f100a6, 0xa4d501fb, 0xe29606e3, 0x00000000}},  //   است_, _пові, наш_,
  { {0x7afc002d, 0x9f9a021e, 0x7bdd0453, 0x00000000}},  //   zert, kään_, kusu,
  { {0x7ae53b4c, 0x69dc01a2, 0x7afc3b4d, 0x00000000}},  //   _ocht, zure, yert,
  { {0x6135009f, 0x7bdd1aba, 0x200d3553, 0x00000000}},  //   _máli, dusu, rvei_,
  { {0x7afc0f12, 0x06cc0055, 0x06d50055, 0x00000000}},  //   vert, র্কি, স্থি,
  { {0x7afc001f, 0x7ae502ae, 0xc0e90014, 0x00000000}},  //   wert, _acht, _رفتن_,
  { {0x7afc1ddc, 0x7bdd104e, 0xfc3f0048, 0x00000000}},  //   tert, gusu, scín_,
  { {0x06d50044, 0x7afc01a2, 0xdbd2006c, 0x00000000}},  //   স্তি, uert, müüj,
  { {0x637603c7, 0x7afc3120, 0x2cab0051, 0x00000000}},  //   mânt, rert, éidí_,
  { {0x7ae50db5, 0x69dc15a9, 0x63760181, 0x00000000}},  //   _echt, rure, lânt,
  { {0x7afc020c, 0x69dc028a, 0x613500dc, 0x00000000}},  // [d9a0] pert, sure, _cáli,
  { {0xe205001d, 0x386601d5, 0x69dc0778, 0x00000000}},  //   _đóng_, ħor_, pure,
  { {0x63a00091, 0x1f360097, 0x3d150061, 0x00000000}},  //   _sumn, ערער_, धाचे_,
  { {0x80be03d7, 0x63a00035, 0x89360025, 0x00000000}},  //   _एजें, _pumn, _أعدا,
  { {0x289b0104, 0x2d520059, 0x00000000, 0x00000000}},  //   _מיכא, jšem_,   ,
  { {0xae1f0164, 0x61ea2058, 0x98a900b4, 0x00000000}},  //   यमान_, ttfl, tkać_,
  { {0x3ce1013d, 0x61350062, 0x7bdd1a6f, 0x00000000}},  //   _काले_, _záli, zusu,
  { {0x61ea0239, 0x2d52013e, 0x7bdd0276, 0x00000000}},  //   rtfl, ušel_, yusu,
  { {0x98a900b4, 0x00000000, 0x00000000, 0x00000000}},  //   skać_,   ,   ,
  { {0x798d0036, 0x9f9a00b0, 0x3f9801e5, 0x00000000}},  //   zmaw, vään_, öru_,
  { {0xb1e50025, 0x00000000, 0x00000000, 0x00000000}},  //   _لأنه,   ,   ,
  { {0x9f9a021e, 0x3ce10061, 0x8fa6007c, 0x00000000}},  //   tään_, _काळे_, _заде,
  { {0x3c46009d, 0x00000000, 0x00000000, 0x00000000}},  //   _rêvé_,   ,   ,
  { {0xf8b80011, 0x7bdd014a, 0x63761290, 0x00000000}},  //   _đĩa_, rusu, cânt,
  { {0x0a6801e0, 0x7bdd011c, 0x798d0093, 0x00000000}},  //   ерти_, susu, tmaw,
  { {0x9f9a021e, 0x999800ed, 0x613510fa, 0x00000000}},  //   sään_, екст_, _páli,
  { {0x798d0093, 0x671c0309, 0xa775003b, 0x00000000}},  // [d9b0] rmaw, नांक_, влач,
  { {0x61353b4e, 0x65c70047, 0x368b00ed, 0x00000000}},  //   _váli, _néhá, псен_,
  { {0x78a206b8, 0xb6060089, 0x2d520142, 0x00000000}},  //   žova, jušā, dšej_,
  { {0x60c200b9, 0xa4d50088, 0xb4cb0061, 0x00000000}},  //   _neom, тоді, लणे_,
  { {0x290b00e5, 0x00000000, 0x00000000, 0x00000000}},  //   _iaca_,   ,   ,
  { {0x69da008e, 0xd78900a1, 0x6ad30044, 0x00000000}},  //   áteg, _آنسو_, দ্রো,
  { {0x290b0169, 0x6376001a, 0x6135000c, 0x00000000}},  //   _kaca_, vânt, _málv,
  { {0x613c009d, 0x26c300d9, 0x290b04eb, 0x00000000}},  //   _délo, _hejo_, _jaca_,
  { {0x33f40a4f, 0x290b0c56, 0x60c200e0, 0x00000000}},  //   _مسلس, _maca_, _deom,
  { {0xee39012b, 0x2cb91962, 0xddd80006, 0x00000000}},  //   дно_, ebsd_, _gyvū,
  { {0x0d86013b, 0x26c300ca, 0x7bcd00b0, 0x00000000}},  //   клон, _mejo_, _avau,
  { {0xd14b0025, 0x70520167, 0xc0cb007c, 0x00000000}},  //   _عشان_, انیا, _хуже_,
  { {0x06cc0044, 0x27f90093, 0x00000000, 0x00000000}},  //   র্টি, _npsn_,   ,
  { {0xeb970265, 0xbea202dc, 0xfc0302ea, 0x00000000}},  //   кия_, _кашк, јпро,
  { {0x290b04cb, 0x2d5200ca, 0x672e00f6, 0x00000000}},  //   _baca_, nšek_, _robj,
  { {0x23650087, 0x00000000, 0x00000000, 0x00000000}},  //   _ljlj_,   ,   ,
  { {0x290b000d, 0x672e0182, 0x26c30093, 0x00000000}},  // [d9c0] _daca_, _pobj, _bejo_,
  { {0x5fd40061, 0x6fd4013d, 0x249f3b4f, 0x00000000}},  //   _दिसल, _दिसं, _agum_,
  { {0xe7fe02d2, 0x26c31de3, 0x290b001a, 0x00000000}},  //   _उनका_, _dejo_, _faca_,
  { {0x6d460082, 0x00000000, 0x00000000, 0x00000000}},  //   nhka,   ,   ,
  { {0x29001138, 0x6d5d00f4, 0x5ed90044, 0x00000000}},  //   meia_, érai, ব্যে,
  { {0x60c2002a, 0x29002888, 0x6135000c, 0x00000000}},  //   _seom, leia_, _málu,
  { {0x4420000d, 0x5fd40061, 0x27e03b50, 0x00000000}},  //   ţi_, _दिहल, luin_,
  { {0x68e4224a, 0x29001052, 0x613c009d, 0x00000000}},  //   ngid, neia_, _vélo,
  { {0x53a60265, 0x60c2037e, 0xc953019b, 0x00000000}},  //   _разб, _veom, ימה_,
  { {0x777e0009, 0x290000c4, 0x63760035, 0x00000000}},  //   nlpx, heia_, râns,
  { {0x212f0030, 0x27e01ea7, 0xceb80a55, 0x00000000}},  //   _fogh_, huin_, rbę_,
  { {0x09b10044, 0x27e00315, 0x61350b33, 0x00000000}},  //   _ছিলা, kuin_, _sálv,
  { {0x442600d4, 0x29000181, 0x2ca00009, 0x00000000}},  //   nxo_, deia_, _dgid_,
  { {0x44263b51, 0x290b008e, 0x27e00052, 0x00000000}},  //   ixo_, _saca_, duin_,
  { {0x4f9b00b6, 0x39a40098, 0x61350b33, 0x00000000}},  //   _קבוצ, иштв, _válv,
  { {0x6d8700a1, 0x290000c4, 0x68e40026, 0x00000000}},  //   _جمعہ_, geia_, ggid,
  { {0x27e004bd, 0x4815008b, 0x656200b9, 0x00000000}},  // [d9d0] guin_, ымас, dnoh,
  { {0x7d0d00b0, 0x4ab7007d, 0xa6cc0044, 0x00000000}},  //   _haas, _अभिव, র্ঘট,
  { {0x7d0d0cfc, 0x26c33012, 0x290b0048, 0x00000000}},  //   _kaas, _vejo_, _taca_,
  { {0x2d520059, 0xb33c01f3, 0x27e000e0, 0x00000000}},  //   všek_, _jiħf, buin_,
  { {0x7d0d003c, 0x286b00ec, 0x61353b52, 0x00000000}},  //   _maas, _црно_, _mált,
  { {0x7d0d0343, 0x78ad111b, 0x00000000, 0x00000000}},  //   _laas, lcav,   ,
  { {0x799d000b, 0x51f50025, 0x00000000, 0x00000000}},  //   _kisw, استر,   ,
  { {0x7d0d0cf0, 0x78ad0065, 0x60090407, 0x00000000}},  //   _naas, ncav, еним_,
  { {0x3494003b, 0x799d1b87, 0x00000000, 0x00000000}},  //   _ватр, _misw,   ,
  { {0x257c01ca, 0x48160049, 0x5f4503ab, 0x00000000}},  //   víli_, אַטן_, اندل,
  { {0x2ca00009, 0x7d0d017d, 0x3f9c2169, 0x00000000}},  //   _pgid_, _baas, _divu_,
  { {0x799d000a, 0x6d463b53, 0x10150d3a, 0x00000000}},  //   _nisw, uhka, _مبتد,
  { {0x29000ddb, 0xbad6007e, 0x60c9010e, 0x00000000}},  //   veia_, лівы, maem,
  { {0x6d460065, 0x60c908a8, 0xa03a0049, 0x00000000}},  //   shka, laem, _רעספ,
  { {0x29001290, 0x61350048, 0x39420145, 0x00000000}},  //   teia_, _fált, _plks_,
  { {0x7d0d006c, 0x27e02e23, 0x60c9006c, 0x00000000}},  //   _gaas, tuin_, naem,
  { {0x6d560061, 0x6d440020, 0x29000bc0, 0x00000000}},  // [d9e0] _imya, _ilia, reia_,
  { {0x613c0010, 0x27e0067c, 0x68e4046a, 0x00000000}},  //   _célj, ruin_, sgid,
  { {0x290000c4, 0x6d443b54, 0x27e001d6, 0x00000000}},  //   peia_, _klia, suin_,
  { {0x442605b3, 0x6135000c, 0x25b70014, 0x00000000}},  //   txo_, _máls, اهند_,
  { {0x27e000f4, 0x6f010023, 0x00000000, 0x00000000}},  //   quin_, kelc,   ,
  { {0x442600d4, 0x6f01016e, 0x69dc0288, 0x00000000}},  //   rxo_, jelc, orre,
  { {0x6d440006, 0x00000000, 0x00000000, 0x00000000}},  //   _olia,   ,   ,
  { {0x3d0e0754, 0x3f9c021e, 0x69ce0270, 0x00000000}},  //   ियों_, _sivu_, isbe,
  { {0x3f9c016e, 0x7d0d01b1, 0xddcf085c, 0x00000000}},  //   _pivu_, _raas, _češn,
  { {0x6d4400e4, 0x4376005e, 0x69ce0030, 0x00000000}},  //   _alia, _субт, ksbe,
  { {0x6d44002a, 0x3f82001e, 0x7d0d0128, 0x00000000}},  //   _blia, ēku_, _paas,
  { {0x6d44002a, 0x62880089, 0x69ce00eb, 0x00000000}},  //   _clia, _izdo, dsbe,
  { {0x61350047, 0x69dc0032, 0x7d0d00b0, 0x00000000}},  //   _vált, erre, _vaas,
  { {0x799d0390, 0x6d440181, 0x7d0d0020, 0x00000000}},  //   _sisw, _elia, _waas,
  { {0x7d0d06ad, 0x69ce0240, 0x613c0047, 0x00000000}},  //   _taas, gsbe, _nélk,
  { {0xeab0026c, 0x78ad0107, 0x00000000, 0x00000000}},  //   قعہ_, ucav,   ,
  { {0xd6db0265, 0x78ad16b3, 0x799d0066, 0x00000000}},  // [d9f0] ете_, rcav, _visw,
  { {0x78ad00c4, 0x62880ce2, 0x69da013e, 0x00000000}},  //   scav, _ozdo, átec,
  { {0x799d002b, 0x00000000, 0x00000000, 0x00000000}},  //   _tisw,   ,   ,
  { {0xf8b106c6, 0x613c3b55, 0x637f00c4, 0x00000000}},  //   _ذکر_, _délk, mêni,
  { {0xd0061298, 0x7bcf008e, 0x27360030, 0x00000000}},  //   _بل_, nscu, _pænt_,
  { {0x39490181, 0x973204e1, 0x2fcd0107, 0x00000000}},  //   lhas_, _وکلا, vseg_,
  { {0xe12508f3, 0x6f01013f, 0x2002014a, 0x00000000}},  //   имки, velc, çkin_,
  { {0x394902d5, 0xb4f9007b, 0x6f01010f, 0x00000000}},  //   nhas_, _שפּי, welc,
  { {0x60c9023a, 0xbcfb0010, 0x00000000, 0x00000000}},  //   raem, tnén,   ,
  { {0xff5101f7, 0x7777002b, 0x69dc0f03, 0x00000000}},  //   تخب_, noxx, yrre,
  { {0x23ab0030, 0x6d442005, 0x2fcd3b56, 0x00000000}},  //   _høj_, _plia, sseg_,
  { {0xed5a0086, 0x2fcd016c, 0x8d56007c, 0x00000000}},  //   том_, pseg_, рточ,
  { {0x65690209, 0x212d0243, 0x913a0049, 0x00000000}},  //   _mjeh, mjeh_, _שענק,
  { {0x2ee5001c, 0x69ce010f, 0x7c22002b, 0x00000000}},  //   qglf_, tsbe, _ġord,
  { {0x61e3027d, 0x7e79007b, 0x395600ed, 0x00000000}},  //   nunl, _באַז, ањат,
  { {0x98a301e0, 0x6d5d028c, 0x69ce00b5, 0x00000000}},  //   жите, érat, rsbe,
  { {0x69ce01a2, 0xf99f01d6, 0x37a8009e, 0x00000000}},  // [da00] ssbe, _diè_, ائری_,
  { {0x61e3006b, 0xe6c50025, 0x69ce00bb, 0x00000000}},  //   kunl, متمي, psbe,
  { {0xaadb00b3, 0x39490051, 0x00000000, 0x00000000}},  //   _בחיר, bhas_,   ,
  { {0x39493b57, 0x23ab0146, 0x00000000, 0x00000000}},  //   chas_, _bøj_,   ,
  { {0xb6a60088, 0xe3af01d8, 0x212d01ed, 0x00000000}},  //   _вигл, ورو_, djeh_,
  { {0x68f60016, 0x39400a0e, 0x657b0087, 0x00000000}},  //   lfyd, lkis_, _ekuh,
  { {0x613c09af, 0x61e3014a, 0x66840014, 0x00000000}},  //   _héli, gunl, _ایال,
  { {0x23ab0030, 0x394012ca, 0x29120022, 0x00000000}},  //   _føj_, nkis_, ndya_,
  { {0xa2e600a8, 0x27f2018e, 0x29370049, 0x00000000}},  //   _возд, ntyn_, שאפן_,
  { {0x613c009d, 0x00000000, 0x00000000, 0x00000000}},  //   _méli,   ,   ,
  { {0x62883b58, 0x394001c2, 0x3e6100e5, 0x00000000}},  //   _uzdo, kkis_, _cγt_,
  { {0x637f00fa, 0x00000000, 0x00000000, 0x00000000}},  //   vêni,   ,   ,
  { {0xed58007e, 0x2d850089, 0x3940012d, 0x00000000}},  //   роў_, ēle_, dkis_,
  { {0x7bcf0146, 0x00000000, 0x00000000, 0x00000000}},  //   rscu,   ,   ,
  { {0x98c7012d, 0x39491218, 0xf99f15e1, 0x00000000}},  //   исал, thas_, _piè_,
  { {0x613c038e, 0x2d68016c, 0x7c220089, 0x00000000}},  //   _béli, nđel_, _šore,
  { {0x6d5d12ea, 0xf093007b, 0x613c1184, 0x00000000}},  // [da10] misa, ַנע_, _céli,
  { {0x6d5d1ec1, 0x613c00f4, 0xf7700137, 0x00000000}},  //   lisa, _déli, وال_,
  { {0x3d1c001c, 0xab5b006c, 0x2d520059, 0x00000000}},  //   याचे_, ssüs, ršev_,
  { {0x613c2b25, 0x39400ba5, 0x00000000, 0x00000000}},  //   _féli, ckis_,   ,
  { {0x3959008e, 0xdb23000c, 0x270f0044, 0x00000000}},  //   _imss_, _þróa, সাবো_,
  { {0xdb04002a, 0xfbb800b6, 0xd7f8007e, 0x00000000}},  //   _stiú, ספות_, _тую_,
  { {0x3ce8001c, 0xdb040211, 0x45d40256, 0x00000000}},  //   _झाले_, _quié, _морс,
  { {0x61e3011f, 0x6b4b0010, 0x23ab0030, 0x00000000}},  //   runl, _függ, _tøj_,
  { {0x61e30890, 0x6d5d0213, 0x6735199a, 0x00000000}},  //   sunl, disa, _kozj,
  { {0x98a9012d, 0x43850025, 0x61e300e0, 0x00000000}},  //   djač_, _الطق, punl,
  { {0x63a90020, 0x6d5d0020, 0x212d0243, 0x00000000}},  //   _huen, fisa, pjeh_,
  { {0x63a9000b, 0x6d5d0058, 0x200b0030, 0x00000000}},  //   _kuen, gisa, æcis_,
  { {0x814c00bd, 0x51740054, 0x41740025, 0x00000000}},  //   _בעאַ, _بالأ, _بالس,
  { {0x7fb400e9, 0x63a90d65, 0x6d5d009d, 0x00000000}},  //   _بلوچ, _muen, érar,
  { {0x6d5d0760, 0x39403b59, 0x63a900b0, 0x00000000}},  //   bisa, tkis_, _luen,
  { {0x6d5d0181, 0x63a90007, 0x62810082, 0x00000000}},  //   cisa, _ouen, _mylo,
  { {0x7d0600b0, 0x3940006c, 0x63a90032, 0x00000000}},  // [da20] meks, rkis_, _nuen,
  { {0x7d060149, 0xdb0e00b0, 0x3940143d, 0x00000000}},  //   leks, äkär, skis_,
  { {0xb8ee0055, 0x27f21194, 0x2f5a0049, 0x00000000}},  //   _রা_, styn_, נדענ,
  { {0x63a90219, 0x7d0600b0, 0x56930088, 0x00000000}},  //   _buen, neks, чаєт,
  { {0x63a90219, 0xdb040009, 0x63a1004e, 0x00000000}},  //   _cuen, _stiù, _biln,
  { {0x63a9022b, 0x7d06006c, 0x27e00065, 0x00000000}},  //   _duen, heks, mrin_,
  { {0x6d5d3b5a, 0x7d0623b5, 0x63a10065, 0x00000000}},  //   yisa, keks, _diln,
  { {0x7984001c, 0x63a90219, 0x463b007b, 0x00000000}},  //   nliw, _fuen, _געלע,
  { {0x7d060292, 0xe8e00011, 0x26ca0093, 0x00000000}},  //   deks, _ngọt_, _kebo_,
  { {0x9df801f9, 0x6d5d023a, 0x26ca0091, 0x00000000}},  //   анот_, wisa, _jebo_,
  { {0x6d5d005f, 0xa3e4024c, 0x877b061e, 0x00000000}},  //   tisa, पूर_, ראיי,
  { {0x27e0178e, 0x63a1001a, 0x26ca0027, 0x00000000}},  //   krin_, _ziln, _lebo_,
  { {0x40960054, 0x703a004b, 0x79840036, 0x00000000}},  //   _الشر, _حساس_, dliw,
  { {0x26ca101c, 0x6d5d010a, 0x27e021ae, 0x00000000}},  //   _nebo_, sisa, drin_,
  { {0x69da0119, 0x6ce7008b, 0x67353510, 0x00000000}},  //   šten, _ліпе, _rozj,
  { {0x8e830054, 0x7d06014a, 0xbcfb009d, 0x00000000}},  //   _عليه, ceks, fiée,
  { {0x5887007c, 0x26ca0133, 0xe894007c, 0x00000000}},  // [da30] сыва, _bebo_, зать,
  { {0x6b4b01a2, 0x26ca004a, 0x2b5a0087, 0x00000000}},  //   _büge, _cebo_, _gmpc_,
  { {0x25b80056, 0x63a90211, 0x26ca0211, 0x00000000}},  //   _ctrl_, _suen, _debo_,
  { {0x63a12a89, 0x63a90211, 0x27e00065, 0x00000000}},  //   _siln, _puen, brin_,
  { {0x63a13b5b, 0x63a90181, 0xbcfb009d, 0x00000000}},  //   _piln, _quen, ciée,
  { {0x41b50264, 0x62811ee1, 0x443d0016, 0x00000000}},  //   осит, _pylo, ryw_,
  { {0x63a1010a, 0x63bc00ca, 0x7d063b5c, 0x00000000}},  //   _viln, _črne, yeks,
  { {0x13a70014, 0x628101ca, 0x63a93b5d, 0x00000000}},  //   _هنری_, _vylo, _tuen,
  { {0xe81c02d2, 0x63a9006c, 0x2ba50164, 0x00000000}},  //   निया_, _uuen, _गंगा,
  { {0x289c0049, 0x2eee0009, 0xef39003b, 0x00000000}},  //   ניזא, _ccff_, рџић_,
  { {0x2bdc02fb, 0x7d060292, 0x79960036, 0x00000000}},  //   _बिहा, teks, ymyw,
  { {0x6d5d00f4, 0xbcfb0161, 0x2fdf04eb, 0x00000000}},  //   érap, nnéh, prug_,
  { {0x7d062045, 0x613c2ffd, 0x4c36007e, 0x00000000}},  //   reks, _célu, цэнт,
  { {0x7d06021e, 0x613c26f7, 0x27e006e6, 0x00000000}},  //   seks, _délu, vrin_,
  { {0xfaa30888, 0x7d060058, 0x999e00b9, 0x00000000}},  //   даро, peks, átů_,
  { {0x27e0045f, 0xbcfb01ca, 0x26ca00c4, 0x00000000}},  //   trin_, jnéh, _sebo_,
  { {0x60cb0010, 0xbcfb06b8, 0x27e000f2, 0x00000000}},  // [da40] _megm, dnéh, urin_,
  { {0x27e0008d, 0x25aa06d3, 0xbcfb009d, 0x00000000}},  //   rrin_, _publ_, riée,
  { {0x98a60256, 0x248d0023, 0xb87b0051, 0x00000000}},  //   _мине, _azem_, _scít,
  { {0x27e00350, 0x92a600b4, 0x26ca28cd, 0x00000000}},  //   prin_, zyłą, _webo_,
  { {0x613c0010, 0x26ca008a, 0x00000000, 0x00000000}},  //   _mélt, _tebo_,   ,
  { {0x8c1b009b, 0x7afe023a, 0xb33c01f3, 0x00000000}},  //   יוני, _jbpt, _biħa,
  { {0x2d800082, 0xbcfb04bb, 0x00000000, 0x00000000}},  //   _okie_, bnéh,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf99301f8, 0xff0601be, 0x637f00c4, 0x00000000}},  //   ורה_, оянн, tênt,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69da00b9, 0x171b0049, 0x82660014, 0x00000000}},  //   átel, בויע, _بهان,
  { {0x8fa600e3, 0xd24f00a1, 0x21b700a1, 0x00000000}},  //   _даде, _جنم_, _بھوک_,
  { {0xa6d50055, 0x4f65026c, 0x06d50044, 0x00000000}},  //   স্টট, _کانف, স্টি,
  { {0xada50142, 0xbcfb3b5e, 0x23b0009d, 0x00000000}},  //   _skúš, inéi, _màj_,
  { {0xb33c0066, 0x613c0010, 0x00000000, 0x00000000}},  //   _xiħa, _félt,   ,
  { {0xed5807d8, 0x00000000, 0x00000000, 0x00000000}},  //   _мој_,   ,   ,
  { {0xbcfb06b8, 0xfc3f00d4, 0x27140044, 0x00000000}},  // [da50] vnéh, rcís_, ঠানো_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xab980025, 0xbcfb06b8, 0x63760035, 0x00000000}},  //   _بخير_, tnéh, bânz,
  { {0xaae70123, 0xaba80014, 0x69d50010, 0x00000000}},  //   _اسکو, _دهیم_, msze,
  { {0x69d50c59, 0x60cb01d6, 0xbcfb0161, 0x00000000}},  //   lsze, _regm, rnéh,
  { {0x68ed00d6, 0x27e92111, 0x883a009b, 0x00000000}},  //   lgad, muan_, _התשו,
  { {0x69d51297, 0x27e90127, 0x4429000d, 0x00000000}},  //   nsze, luan_, ţa_,
  { {0x68ed04d4, 0x2600013d, 0x2bdc007d, 0x00000000}},  //   ngad, _रहती_, _बिला,
  { {0x27e91511, 0xb4e70164, 0x24840146, 0x00000000}},  //   nuan_, पली_, _gymm_,
  { {0x2ca9006a, 0x69d50010, 0x00000000, 0x00000000}},  //   _agad_, ksze,   ,
  { {0x27e9020c, 0x69d50036, 0x29d7002b, 0x00000000}},  //   huan_, jsze, jħa_,
  { {0x69d50c59, 0x311401e1, 0x656b2088, 0x00000000}},  //   dsze, _офіс, nngh,
  { {0x27e90149, 0x81ad0044, 0x31b10010, 0x00000000}},  //   juan_, _কবি_, _ház_,
  { {0x27e91130, 0xa026009f, 0x2d9900bb, 0x00000000}},  //   duan_, stöð, amse_,
  { {0x6b500073, 0x69d53b5f, 0x29d701d5, 0x00000000}},  //   _lägg, gsze, għa_,
  { {0x68ed0039, 0xc2120049, 0x63bb019a, 0x00000000}},  //   ggad, עהן_, _otun,
  { {0x27e904cb, 0x200d144d, 0x63bb00e5, 0x00000000}},  // [da60] guan_, nwei_, _ntun,
  { {0x6d4600b0, 0x7d16149f, 0x68ed090b, 0x00000000}},  //   lkka, _hays, agad,
  { {0x63bb000d, 0x7d16066b, 0x00000000, 0x00000000}},  //   _atun, _kays,   ,
  { {0x92e80055, 0x6d460ff8, 0x27e904cb, 0x00000000}},  //   _বসে_, nkka, buan_,
  { {0x2937007b, 0x9f4400f4, 0x7d160058, 0x00000000}},  //   _זאכן_, sumé_, _mays,
  { {0x656b002a, 0xd6e30044, 0x7d1600e0, 0x00000000}},  //   angh, ন্বয, _lays,
  { {0xbcfb002a, 0xf107013d, 0x63bb00b0, 0x00000000}},  //   snéi, वजूद_, _etun,
  { {0xb6a30764, 0x7d160b3d, 0x9c8701dc, 0x00000000}},  //   _числ, _nays, _jičí,
  { {0x6f080ba5, 0x69d5108d, 0x00000000, 0x00000000}},  //   tedc, zsze,   ,
  { {0x69d51a53, 0xa857009b, 0x68ed3b60, 0x00000000}},  //   ysze, פייה_, zgad,
  { {0x6d4f09e0, 0x27e90307, 0x6f08245a, 0x00000000}},  //   thca, zuan_, redc,
  { {0x27e909f3, 0xd8430161, 0x613c01e5, 0x00000000}},  //   yuan_, ničí_, _véls,
  { {0x7d160541, 0x69d50036, 0x61ea000c, 0x00000000}},  //   _days, wsze, lufl,
  { {0x69d51297, 0x8fa3007c, 0x6d4f0784, 0x00000000}},  //   tsze, _заче, shca,
  { {0x61ea00f6, 0xd90f0014, 0x656b3b61, 0x00000000}},  //   nufl, هید_, yngh,
  { {0x27e904be, 0x69d509c8, 0x394b0026, 0x00000000}},  //   tuan_, rsze, _qlcs_,
  { {0x68ed3b57, 0x69d50a36, 0x36d5005c, 0x00000000}},  // [da70] rgad, ssze, дозр,
  { {0x27e9022b, 0x68ed3b62, 0x69d5115b, 0x00000000}},  //   ruan_, sgad, psze,
  { {0x63bb3b63, 0xfbaf0055, 0x6d4d046a, 0x00000000}},  //   _stun, _কবিত, _klaa,
  { {0x27e904cb, 0xb4e70204, 0x656b0035, 0x00000000}},  //   puan_, पले_, ungh,
  { {0xe1f10014, 0x27e90082, 0x00000000, 0x00000000}},  //   چسب_, quan_,   ,
  { {0xaabf02fb, 0xd040005f, 0x07a4007e, 0x00000000}},  //   ्रिक, qamə, _паўн,
  { {0x919500ed, 0xe29600d7, 0x6d4600ea, 0x00000000}},  //   мјиш, маш_, ykka,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x944500a1, 0x63bb0020, 0x752900fa, 0x00000000}},  //   _تھان, _utun, _inez,
  { {0xf8aa0164, 0x6d4d011c, 0x7d163b64, 0x00000000}},  //   _कल्प, _alaa, _says,
  { {0x75290107, 0x6d4d00c7, 0x7d1600f4, 0x00000000}},  //   _knez, _blaa, _pays,
  { {0x69da167a, 0x6b50010e, 0x00000000, 0x00000000}},  //   štek, _mäge,   ,
  { {0x6b500039, 0x6d46021e, 0x6b4b006c, 0x00000000}},  //   _läge, rkka, _süga,
  { {0x06e30044, 0x2f18007c, 0x317f0173, 0x00000000}},  //   ন্তি, _ночь_, louz_,
  { {0x6b50050d, 0xbcfb008e, 0x316d0035, 0x00000000}},  //   _näge, mién, onez_,
  { {0x316d00f4, 0x6d4d3b65, 0x753b013e, 0x00000000}},  //   nnez_, _glaa, _nouz,
  { {0xbf8a001d, 0xd7f90088, 0x316d1fcd, 0x00000000}},  // [da80] _đoạn_, зує_, inez_,
  { {0xbcfb008e, 0x64420020, 0xdb0400d4, 0x00000000}},  //   nién, vyoi, _etiò,
  { {0x753b0e6d, 0x6562006c, 0xd5b000a1, 0x00000000}},  //   _bouz, tioh, اہر_,
  { {0x448a0c96, 0x273f001a, 0x998a007f, 0x00000000}},  //   обен_, _sînt_, rybų_,
  { {0x753b023f, 0x320500e0, 0x656201b1, 0x00000000}},  //   _douz, _aply_, rioh,
  { {0x316d002d, 0xa29401e1, 0xdced002b, 0x00000000}},  //   enez_, налі, _pjaċ,
  { {0xbcfb008e, 0xd2500025, 0x24f6226c, 0x00000000}},  //   dién, طنة_, _очар,
  { {0xd1300054, 0x316d00f4, 0x61f800bb, 0x00000000}},  //   امة_, gnez_, rtvl,
  { {0x673c00b0, 0xd00706e3, 0x61ea0035, 0x00000000}},  //   _korj, дење_, sufl,
  { {0x6d4d0100, 0xbcfb167d, 0x753b3b66, 0x00000000}},  //   _slaa, gién, _zouz,
  { {0x6d4d1787, 0x673c0059, 0x753b000a, 0x00000000}},  //   _plaa, _morj, _youz,
  { {0x5066004d, 0xdfcf02fd, 0x50d601b2, 0x00000000}},  //   _отла, _چين_, _آزار,
  { {0x63a82fdb, 0x6d4d00b5, 0xbcfb008e, 0x00000000}},  //   _kidn, _vlaa, bién,
  { {0xbcfb008e, 0x673c00b0, 0x00000000, 0x00000000}},  //   cién, _norj,   ,
  { {0x65600066, 0x00000000, 0x00000000, 0x00000000}},  //   _ommh,   ,   ,
  { {0xbcfb3b67, 0xac95007e, 0x62880052, 0x00000000}},  //   gnét, _пайш, _mydo,
  { {0x6b500073, 0x628806ec, 0x753b1339, 0x00000000}},  // [da90] _säge, _lydo, _rouz,
  { {0x753b0181, 0x7529003b, 0x20060009, 0x00000000}},  //   _souz, _snez, _mpoi_,
  { {0x753b0224, 0x58d5034b, 0x673c0fda, 0x00000000}},  //   _pouz, _понт, _dorj,
  { {0xa835012b, 0x6b500274, 0xdced0f3a, 0x00000000}},  //   _земљ, _väge, _ojač,
  { {0xd40b00f3, 0x29190035, 0x753b0c5e, 0x00000000}},  //   تتام_, _iasa_, _vouz,
  { {0x2919000b, 0x6f18045d, 0x39490dec, 0x00000000}},  //   _hasa_, _navc, lkas_,
  { {0x2006000d, 0x23690091, 0x4b38009b, 0x00000000}},  //   _apoi_, đaj_, ורגל_,
  { {0x3949030b, 0x291904fa, 0x69da0181, 0x00000000}},  //   nkas_, _jasa_, átei,
  { {0x29190127, 0x2d8b377e, 0xbcfb008e, 0x00000000}},  //   _masa_, dlce_, tién,
  { {0x2919001a, 0x8c150044, 0xdced012d, 0x00000000}},  //   _lasa_, ামান_, _djač,
  { {0x8d66004c, 0x3949006c, 0x628810fd, 0x00000000}},  //   евне, kkas_, _gydo,
  { {0x2d8400f4, 0x2919066d, 0x26d10032, 0x00000000}},  //   ôme_, _nasa_, _lezo_,
  { {0x66f0007d, 0x6f180066, 0x39490ebd, 0x00000000}},  //   _चालक_, _favc, dkas_,
  { {0x29190be4, 0x39493b68, 0x00000000, 0x00000000}},  //   _aasa_, ekas_,   ,
  { {0x2919011c, 0xdb0f0051, 0xa3cf0061, 0x00000000}},  //   _basa_, ádái, वीत_,
  { {0x61350047, 0x3949011c, 0x00000000, 0x00000000}},  //   _pály, gkas_,   ,
  { {0x63bc0627, 0x7d040061, 0x25bf0091, 0x00000000}},  // [daa0] _črno, _ibis, _čula_,
  { {0x394900b0, 0x06e30044, 0x2d820943, 0x00000000}},  //   akas_, ন্সি, loke_,
  { {0xd639007e, 0xdd7500a1, 0x63a802e7, 0x00000000}},  //   мяці_, _سپیک, _ridn,
  { {0x39492eb2, 0x3a250030, 0x9695034b, 0x00000000}},  //   ckas_, ælpe_, труш,
  { {0x66150047, 0x673c00b0, 0x7d0423eb, 0x00000000}},  //   _eszk, _torj, _mbis,
  { {0x7c2b000c, 0x00000000, 0x00000000, 0x00000000}},  //   _ágre,   ,   ,
  { {0x7d0401d9, 0x3fac0044, 0x2d820022, 0x00000000}},  //   _obis, _গবেষ, koke_,
  { {0x63a81a79, 0x7afb0091, 0x290006c0, 0x00000000}},  //   _widn, đuti, nfia_,
  { {0x63a80073, 0x62880036, 0x6f180087, 0x00000000}},  //   _tidn, _wydo, _pavc,
  { {0x7d040d49, 0x461300a1, 0xd13000a2, 0x00000000}},  //   _abis, _جوہر, امک_,
  { {0x7c243676, 0x7bcd00e7, 0x00000000, 0x00000000}},  //   _arir, _swau,   ,
  { {0x2d820032, 0x442422ae, 0x7c240023, 0x00000000}},  //   goke_, _krm_, _brir,
  { {0x2919027e, 0x5c04007e, 0x201f0082, 0x00000000}},  //   _rasa_, ляра, cvui_,
  { {0x2919000b, 0x7d040009, 0x7986002b, 0x00000000}},  //   _sasa_, _ebis, _akkw,
  { {0xb9e401fb, 0x29192352, 0x26d101aa, 0x00000000}},  //   літи, _pasa_, _rezo_,
  { {0x4424002a, 0x2d820c0d, 0x69da00f4, 0x00000000}},  //   _orm_, coke_, âtea,
  { {0xb8d902d2, 0x2919016c, 0xf6e7005e, 0x00000000}},  // [dab0] _चल_, _vasa_, ецен,
  { {0x39490a5c, 0x7d1d03fa, 0x2900006c, 0x00000000}},  //   skas_, ldss, afia_,
  { {0x442400fe, 0xb8f70044, 0xdb0400c4, 0x00000000}},  //   _arm_, _সা_, _suiç,
  { {0x59b6024c, 0x7d1d000c, 0xbc68025a, 0x00000000}},  //   _आंतर, ndss, _آمین_,
  { {0x7d1d00bb, 0x798d0258, 0x26d10087, 0x00000000}},  //   idss, mlaw, _tezo_,
  { {0x044200ed, 0x2d680521, 0x27e9013f, 0x00000000}},  //   решн, nđer_, mran_,
  { {0x69da0059, 0x442401a3, 0x66150036, 0x00000000}},  //   štev, _erm_, _uszk,
  { {0x44240061, 0x3f8c3b69, 0x798d00e0, 0x00000000}},  //   _frm_, eldu_, nlaw,
  { {0x2d8201aa, 0x27e90016, 0x4424073a, 0x00000000}},  //   voke_, nran_, _grm_,
  { {0x27e9008a, 0x798d04cb, 0x4f221001, 0x00000000}},  //   iran_, hlaw, адьб,
  { {0x27e93b6a, 0x7c243b6b, 0x64590270, 0x00000000}},  //   hran_, _srir, lzwi,
  { {0x7c240119, 0x27e90010, 0xd00e01b2, 0x00000000}},  //   _prir, kran_, حلی_,
  { {0x2d8201d9, 0x798d0058, 0x118600a1, 0x00000000}},  //   roke_, dlaw, _جھوٹ_,
  { {0x27e93b6c, 0x0056009b, 0x2d821a2d, 0x00000000}},  //   dran_, _בשנת_, soke_,
  { {0x798d018e, 0x27e92352, 0x78af00d9, 0x00000000}},  //   flaw, eran_, _bgcv,
  { {0x7d04003b, 0x27e90016, 0x236700ca, 0x00000000}},  //   _ubis, fran_, hinj_,
  { {0x1867058f, 0x27e93b6d, 0x6843007e, 0x00000000}},  // [dac0] вати_, gran_, анта,
  { {0x998d0091, 0x79860022, 0x7bc606ec, 0x00000000}},  //   ćeš_, _wkkw, mpku,
  { {0xd5b90088, 0x27e901a3, 0x2a36007e, 0x00000000}},  //   есі_, aran_, _рэпр,
  { {0x69dc01c9, 0x27e90213, 0x442412e9, 0x00000000}},  //   msre, bran_, _prm_,
  { {0x3f8c000c, 0x69dc01a2, 0x3f871ab2, 0x00000000}},  //   yldu_, lsre, _oknu_,
  { {0x4424007f, 0x00000000, 0x00000000, 0x00000000}},  //   _vrm_,   ,   ,
  { {0xd24f06f1, 0x69dc0c7a, 0xbebc001e, 0x00000000}},  //   ينه_, nsre, ldīg,
  { {0xdce60006, 0xdef8002b, 0x60f802dc, 0x00000000}},  //   mokė, miċi_, хния_,
  { {0xdef801d5, 0x4fd3007e, 0x6702007d, 0x00000000}},  //   liċi_, ажыт, र्थक_,
  { {0xa2c10309, 0x69dc04d3, 0xbebc0089, 0x00000000}},  //   रुद्, ksre, idīg,
  { {0x13d70055, 0x2bd00061, 0xdef8002b, 0x00000000}},  //   _সময়, तीसा, niċi_,
  { {0xe7e20061, 0x27e9005d, 0xa00a0025, 0x00000000}},  //   _पिंप, yran_, _يقال_,
  { {0x2018001e, 0x7d1d01c9, 0x6b5000f8, 0x00000000}},  //   āris_, rdss, _säga,
  { {0x2bb5013d, 0x69dc1177, 0x27e901ed, 0x00000000}},  //   ंदबा, fsre, vran_,
  { {0x25bf04eb, 0x00000000, 0x00000000, 0x00000000}},  //   _čulo_,   ,   ,
  { {0x2e59008b, 0xdef801d5, 0x6b5003af, 0x00000000}},  //   _яшчэ_, diċi_, _väga,
  { {0x9b4504e8, 0x58870a78, 0x27e90173, 0x00000000}},  // [dad0] _منظو, тыва, uran_,
  { {0x27e9021e, 0x5b150057, 0x69dc0302, 0x00000000}},  //   rran_, _смот, bsre,
  { {0xc6a7007c, 0x798d000a, 0x6b820048, 0x00000000}},  //   траи, plaw, _íoga,
  { {0x27e91a7c, 0x69c73994, 0x45180088, 0x00000000}},  //   pran_, mpje, кція_,
  { {0x69da0bf8, 0xdfc60464, 0xe8e00082, 0x00000000}},  //   štet, _دي_, _ngột_,
  { {0xe2990517, 0x7bdd0cba, 0x64590270, 0x00000000}},  //   нал_, issu, rzwi,
  { {0x45d4007c, 0x23670023, 0xc6a40184, 0x00000000}},  //   _восс, rinj_, _врти,
  { {0x7bdd0190, 0x00000000, 0x00000000, 0x00000000}},  //   kssu,   ,   ,
  { {0xe475012b, 0x23673b6e, 0xfd1f0026, 0x00000000}},  //   _слањ, pinj_, ddì_,
  { {0x69dc1241, 0x60c93b6f, 0x25ad00d9, 0x00000000}},  //   ysre, sbem, _hiel_,
  { {0x7bdf0689, 0x25ad01a2, 0x68070089, 0x00000000}},  //   _avqu, _kiel_, lījā,
  { {0x69dc01e3, 0xab5b01a2, 0xc69200b3, 0x00000000}},  //   vsre, spül, מאי_,
  { {0x25ad038e, 0x7bdd0240, 0x69c700bb, 0x00000000}},  //   _miel_, gssu, epje,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3f8501c5, 0x2b410145, 0xdb0d00c4, 0x00000000}},  //   molu_, _dohc_, _guaí,
  { {0x69dc00b5, 0x25ad0168, 0xfe700014, 0x00000000}},  //   rsre, _niel_, _بده_,
  { {0x69dc00ab, 0x271d0044, 0x23b90173, 0x00000000}},  // [dae0] ssre, নানো_, _nèj_,
  { {0xdef801d5, 0x68070089, 0x69dc00f8, 0x00000000}},  //   tiċi_, dījā, psre,
  { {0x25ad033f, 0x8afb00a3, 0x248d0022, 0x00000000}},  //   _biel_, _אהיי, _ayem_,
  { {0x25ad00f4, 0xa2c10164, 0xd5af03ec, 0x00000000}},  //   _ciel_, रुस्, سفه_,
  { {0x938a01f9, 0x3f8501d5, 0x43460605, 0x00000000}},  //   нска_, kolu_, ледв,
  { {0x2bb7013d, 0x00000000, 0x00000000, 0x00000000}},  //   _इंसा,   ,   ,
  { {0x3f85014a, 0x39420964, 0x25ad24c6, 0x00000000}},  //   dolu_, _koks_, _fiel_,
  { {0x39420e07, 0x25ad00bb, 0x7bdd0fc8, 0x00000000}},  //   _joks_, _giel_, yssu,
  { {0x9f5401fc, 0x2d680010, 0x98ac007f, 0x00000000}},  //   ивич, tően_, ėlės_,
  { {0x25ad059b, 0x3f85002b, 0x3817009b, 0x00000000}},  //   _ziel_, golu_, נקים_,
  { {0x1d350099, 0x7bdd00f6, 0x69da009d, 0x00000000}},  //   ання, wssu, âtel,
  { {0xc27b0476, 0xa3e80061, 0x2b410145, 0x00000000}},  //   _ארבי, _मटा_, _sohc_,
  { {0xfd1f0207, 0x7bdd00f4, 0x26da0020, 0x00000000}},  //   rdì_, ussu, kapo_,
  { {0x90970088, 0x40930025, 0xdb160082, 0x00000000}},  //   _світ_, _الهر, _huyê,
  { {0xf9930123, 0xa1430089, 0x26da254f, 0x00000000}},  //   مبر_, _šķir, dapo_,
  { {0x69c70065, 0x291221a4, 0x2d8900e7, 0x00000000}},  //   rpje, geya_, _ukae_,
  { {0x69c73b70, 0xbebc0089, 0x7d740014, 0x00000000}},  // [daf0] spje, mdīb, _داوط,
  { {0xbebc001e, 0x25ad3b71, 0x6d4f0146, 0x00000000}},  //   ldīb, _siel_, lkca,
  { {0xcf93007b, 0x25ad0211, 0x29123b72, 0x00000000}},  //   צטע_, _piel_, beya_,
  { {0x6d4f0ace, 0x7d1f002b, 0x69c50048, 0x00000000}},  //   nkca, _jaqs, _ithe,
  { {0x25ad001f, 0x26da000b, 0x9fdf0044, 0x00000000}},  //   _viel_, bapo_, _বঙ্গ,
  { {0x69c5008d, 0x25ad0116, 0x26da0026, 0x00000000}},  //   _kthe, _wiel_, capo_,
  { {0x3f853b73, 0x25ad1768, 0x00000000, 0x00000000}},  //   volu_, _tiel_,   ,
  { {0x3fe50aed, 0x6009019d, 0x7d1f002b, 0x00000000}},  //   ажив, вним_, _naqs,
  { {0x3f85002b, 0xdb160011, 0x6702007d, 0x00000000}},  //   tolu_, _duyê, र्वक_,
  { {0x656b0018, 0x69c50038, 0x20d30011, 0x00000000}},  //   ligh, _othe, ải_,
  { {0x644b1203, 0x7bc4001a, 0x63bc00ca, 0x00000000}},  //   lygi, _stiu, _črni,
  { {0xe1f006b4, 0x3f851d61, 0x656b2f16, 0x00000000}},  //   _رسم_, solu_, nigh,
  { {0x69c511d1, 0x60db0020, 0x7d1f002b, 0x00000000}},  //   _athe, maum, _daqs,
  { {0xb3d70044, 0x60db0020, 0xbea51281, 0x00000000}},  //   _সমাজ, laum, _калк,
  { {0xfaa60887, 0x6d9d0051, 0xa96a0893, 0x00000000}},  //   раво, féad, вива_,
  { {0x1c460589, 0x60db0020, 0xdb160011, 0x00000000}},  //   _вним, naum, _xuyê,
  { {0x656b00eb, 0x7f43006b, 0x2912006b, 0x00000000}},  // [db00] digh, _konq, reya_,
  { {0x656b001c, 0x7f433b74, 0x6d44006c, 0x00000000}},  //   eigh, _jonq, _hoia,
  { {0xb8fc0055, 0x3942010a, 0x6702007d, 0x00000000}},  //   _ঠা_, _toks_, र्षक_,
  { {0x14260081, 0x26da2721, 0x6d4428f0, 0x00000000}},  //   идем, sapo_, _joia,
  { {0x6b4b006c, 0x4ada0061, 0x6d4400d4, 0x00000000}},  //   _sügi, _बजाव, _moia,
  { {0x7f4301f3, 0x6d443b75, 0x67020164, 0x00000000}},  //   _nonq, _loia, र्शक_,
  { {0x6d560047, 0x27e00279, 0x656b0058, 0x00000000}},  //   _olya, lsin_, bigh,
  { {0xdb160011, 0xf1260194, 0x644b02d4, 0x00000000}},  //   _quyê, рько, bygi,
  { {0x27e0006a, 0x26d80020, 0xe3aa02e9, 0x00000000}},  //   nsin_, _kero_, _акад_,
  { {0x27e031b2, 0x7f430181, 0x26d80093, 0x00000000}},  //   isin_, _conq, _jero_,
  { {0x4426320b, 0xdb160011, 0x26d8007f, 0x00000000}},  //   lvo_, _tuyê, _mero_,
  { {0x7522147e, 0x27e0006c, 0xa2ca0309, 0x00000000}},  //   ndoz, ksin_, _स्त्,
  { {0xae43007a, 0x6b50010f, 0x442601a3, 0x00000000}},  //   مپیو, _tägl, nvo_,
  { {0x26d80207, 0x656b00b5, 0x442612db, 0x00000000}},  //   _nero_, zigh, ivo_,
  { {0x6d560146, 0x7d1f002b, 0xbcfb009d, 0x00000000}},  //   _flya, _taqs, diév,
  { {0x44260091, 0x26d80142, 0x6d441327, 0x00000000}},  //   kvo_, _aero_, _goia,
  { {0xd6db00ed, 0x26d83b76, 0x656b0035, 0x00000000}},  // [db10] вте_, _bero_, vigh,
  { {0x26d80211, 0x629a002d, 0x69c500e0, 0x00000000}},  //   _cero_, _ozto, _tthe,
  { {0x4b7c0452, 0x656b046a, 0x60db00f4, 0x00000000}},  //   _באזו, tigh, yaum,
  { {0x27e00066, 0x3cf90009, 0x26d801b1, 0x00000000}},  //   bsin_, ngsv_, _eero_,
  { {0x44293b77, 0x656b0038, 0x27e00094, 0x00000000}},  //   ía_, righ, csin_,
  { {0x26d83b78, 0x25b82ed8, 0x850500a1, 0x00000000}},  //   _gero_, _furl_, _گورن,
  { {0x2169102a, 0x25b80058, 0x442605fc, 0x00000000}},  //   лики_, _gurl_, avo_,
  { {0xc692007b, 0xfa7801f8, 0xf8bf008e, 0x00000000}},  //   _זאל_, יעות_, _inés_,
  { {0x60db0635, 0x65691dce, 0x26d80058, 0x00000000}},  //   raum, _imeh, _yero_,
  { {0xf207008b, 0x26c10211, 0x6d440026, 0x00000000}},  //   _вядо, ncho_, _soia,
  { {0x229501b7, 0xb87b00b9, 0x60db0020, 0x00000000}},  //   _الاس, _sdíl, paum,
  { {0x27e000b0, 0x8d56007c, 0x82340025, 0x00000000}},  //   ysin_, сточ, _بركا,
  { {0x7f433b79, 0x6d443b7a, 0x408701fc, 0x00000000}},  //   _tonq, _voia, _тужб,
  { {0xaa462260, 0x213f016c, 0x316d009d, 0x00000000}},  //   бегл, ljuh_, liez_,
  { {0x26d80061, 0xfbd20167, 0xf99f0197, 0x00000000}},  //   _rero_, _کتب_, _bhè_,
  { {0xf99f16c9, 0x27e003b6, 0x26d8005b, 0x00000000}},  //   _chè_, tsin_, _sero_,
  { {0x26d83b7b, 0x98a3025f, 0x25b80009, 0x00000000}},  // [db20] _pero_, зите, _surl_,
  { {0x27e03b7c, 0x25b80050, 0x316d009d, 0x00000000}},  //   rsin_, _purl_, hiez_,
  { {0x26d80207, 0x14c8007a, 0x316d0032, 0x00000000}},  //   _vero_, لهای_, kiez_,
  { {0x44260b4a, 0x95eb00a1, 0x27e00052, 0x00000000}},  //   tvo_, ابلہ_, psin_,
  { {0x75220010, 0x316d0035, 0x629a0c59, 0x00000000}},  //   rdoz, diez_, _szto,
  { {0x8c1b009b, 0x00000000, 0x00000000, 0x00000000}},  //   טוני,   ,   ,
  { {0x316d00f4, 0x9f5f009d, 0x6d9d0051, 0x00000000}},  //   fiez_, ctué_, néac,
  { {0x657b008d, 0x316d0288, 0x39400145, 0x00000000}},  //   _gjuh, giez_, njis_,
  { {0x25bf0091, 0x60dd000c, 0x60d90066, 0x00000000}},  //   _čuli_, ðsma, _dewm,
  { {0xb356025a, 0x25a6103f, 0xdbd4008e, 0x00000000}},  //   _دیتا_, lmol_, _núñe,
  { {0xab5b1396, 0x316d0288, 0x00000000, 0x00000000}},  //   nqüe, biez_,   ,
  { {0x069700b3, 0x316d28eb, 0x25a60016, 0x00000000}},  //   מדים_, ciez_, nmol_,
  { {0x26c100f4, 0xed58007e, 0x06e30044, 0x00000000}},  //   ycho_, соў_, ন্টি,
  { {0x139b0049, 0x0eba0930, 0x00000000, 0x00000000}},  //   ָבלע, _суды_,   ,
  { {0x6d9d00f4, 0x3e57013f, 0x00000000, 0x00000000}},  //   réab, yətə_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26c10173, 0x7d0d1a8d, 0x657b00ca, 0x00000000}},  // [db30] tcho_, _ibas, _rjuh,
  { {0x2d8b0207, 0x65692d13, 0x26c1004a, 0x00000000}},  //   loce_, _smeh, ucho_,
  { {0x26c1157e, 0xf99f0026, 0x0c780123, 0x00000000}},  //   rcho_, _thè_, _نصیب_,
  { {0xbcfb028c, 0x2d8b3b7d, 0x7d0d0066, 0x00000000}},  //   ciét, noce_, _jbas,
  { {0x7d0d0065, 0x316d009d, 0xdce60089, 0x00000000}},  //   _mbas, viez_, nikā,
  { {0xbcfb0344, 0x2329041f, 0x00000000, 0x00000000}},  //   gnéz, роки_,   ,
  { {0x25a60007, 0x7d0d0166, 0x3ce9006c, 0x00000000}},  //   bmol_, _obas, _odav_,
  { {0x7c2d0207, 0xbfc505f6, 0x656900e7, 0x00000000}},  //   _orar, обик, _umeh,
  { {0x316d3b7e, 0xdb0d00c4, 0x2d8b15f7, 0x00000000}},  //   riez_, _guaç, doce_,
  { {0x7d0d0129, 0x8e0900d7, 0x316d3562, 0x00000000}},  //   _abas, анов_, siez_,
  { {0x6e450264, 0x7c2d0181, 0xa15931cd, 0x00000000}},  //   ценз, _arar, _кажу_,
  { {0xdb0d009f, 0x63bb04ff, 0x4ca80044, 0x00000000}},  //   _stað, _kuun, _ক্ষু,
  { {0x63bb0004, 0x1b230044, 0xbcfb3b7f, 0x00000000}},  //   _juun, মানে_, viét,
  { {0x7d0d0004, 0x63bb3937, 0x2fcd3b80, 0x00000000}},  //   _ebas, _muun, mpeg_,
  { {0x6d5d0051, 0x7c2d0f4f, 0x25a60544, 0x00000000}},  //   bhsa, _erar, ymol_,
  { {0x442d139c, 0xae7801e1, 0x2d8b1c37, 0x00000000}},  //   _ore_, _усіх_, coce_,
  { {0xfe4100a1, 0xbcfb00f4, 0x442d0145, 0x00000000}},  // [db40] _رکھی, riét, _nre_,
  { {0x969600ed, 0x7f410045, 0xbcfb004a, 0x00000000}},  //   ореш, njlq, biés,
  { {0x442d0a8a, 0xe61a003b, 0xd9460242, 0x00000000}},  //   _are_, рде_, _дени,
  { {0xa50a3627, 0x442d1264, 0xdb0500b0, 0x00000000}},  //   реда_, _bre_, _eihä,
  { {0x442d3b81, 0x25a6148a, 0x24803b82, 0x00000000}},  //   _cre_, rmol_, çim_,
  { {0x442d0016, 0x69ce00bb, 0x27f2005b, 0x00000000}},  //   _dre_, opbe, mryn_,
  { {0x442d0756, 0x66030726, 0xab5b006b, 0x00000000}},  //   _ere_, _опра, mpüt,
  { {0x442d277c, 0x79961f75, 0x00000000, 0x00000000}},  //   _fre_, nlyw,   ,
  { {0xb4e602d2, 0x442d01d9, 0x2d8b0197, 0x00000000}},  //   पणी_, _gre_, voce_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb4ab009f, 0x20043b83, 0x7d0d0050, 0x00000000}},  //   _íþró, stmi_, _pbas,
  { {0x6ed60061, 0xdce60089, 0xac190a7c, 0x00000000}},  //   _मजकु, tikā, бому_,
  { {0x98b30089, 0x40340143, 0x9f5f00f6, 0x00000000}},  //   ādīt_, _хелс, ctuï_,
  { {0x7c2d2852, 0x70530014, 0x2d8b00b9, 0x00000000}},  //   _vrar, _تنها, soce_,
  { {0x80dd0044, 0x3f8c0032, 0xbcfb009d, 0x00000000}},  //   _যাত্, modu_, théd,
  { {0x98b90098, 0x4cd50044, 0x7c2d1862, 0x00000000}},  //   слат_, _থাকু, _trar,
  { {0x7c2d04f4, 0x1b100044, 0xbcfb004a, 0x00000000}},  // [db50] _urar, ায়ে_, biér,
  { {0x4e1e013d, 0xbcfb004a, 0x00000000, 0x00000000}},  //   _बनाई_, ciér,   ,
  { {0x63bb0368, 0x67251e20, 0x442d0059, 0x00000000}},  //   _suun, rdhj, _sre_,
  { {0x442d13a1, 0x63bb3b84, 0x3f8c0b41, 0x00000000}},  //   _pre_, _puun, hodu_,
  { {0xbcfb00f4, 0xdb04008e, 0x3f8c3b85, 0x00000000}},  //   chée, _guió, kodu_,
  { {0x442d0263, 0x77ba009b, 0x00000000, 0x00000000}},  //   _vre_, _למשח,   ,
  { {0x94d5003b, 0xa4d501ff, 0x56942210, 0x00000000}},  //   _новц, _нові, _жарт,
  { {0x950500a1, 0x6b50006c, 0x63bb212c, 0x00000000}},  //   _رہتے_, _vägi, _tuun,
  { {0x442d3b86, 0x2458007c, 0x63bb00e0, 0x00000000}},  //   _ure_, _дать_, _uuun,
  { {0x9e6534b3, 0xa2ca0061, 0xf8b80309, 0x00000000}},  //   звод, सुद्, _अल्प,
  { {0x22770167, 0xc7b4009b, 0xbcfb0253, 0x00000000}},  //   _بلاگ_, ובץ_, viér,
  { {0x670b007d, 0x070b007d, 0x27e6012d, 0x00000000}},  //   स्तक_, स्तव_, šoni_,
  { {0xbcfb008e, 0xa3cf0204, 0x9f350088, 0x00000000}},  //   tiér, वीच_, _неді,
  { {0xef1801c5, 0x00000000, 0x00000000, 0x00000000}},  //   ceļ_,   ,   ,
  { {0xb87b0211, 0xbcfb06b8, 0xc332009b, 0x00000000}},  //   _leíd, riér, עול_,
  { {0xa9670999, 0x47c600c2, 0x6d9d00f4, 0x00000000}},  //   писа_, збав, léan,
  { {0x27e6009d, 0x69ce0133, 0x00000000, 0x00000000}},  // [db60] éon_, spbe,   ,
  { {0xfaa6013b, 0xf7720a4f, 0xd7ef0054, 0x00000000}},  //   _напо, راء_, اكل_,
  { {0x14ca007c, 0x7abb009b, 0x98a20006, 0x00000000}},  //   были_, _לציו, _tokį_,
  { {0xb4e60061, 0x6d9d1059, 0x35690088, 0x00000000}},  //   पणे_, héan, орін_,
  { {0x999e0006, 0x32070036, 0x00000000, 0x00000000}},  //   štų_, etny_,   ,
  { {0x3a210061, 0x6703006e, 0x6ab00044, 0x00000000}},  //   _yshp_, _लायक_, _জ্যো,
  { {0x3f8c0161, 0x07a3007e, 0xb6cb00a1, 0x00000000}},  //   vodu_, _чарн, _چاہے_,
  { {0x3f8c0036, 0xb034003b, 0xc034003b, 0x00000000}},  //   wodu_, дниш, дниј,
  { {0xb4ca0164, 0x3f8c1f8b, 0x1b230044, 0x00000000}},  //   ोरी_, todu_, মাতে_,
  { {0x3eb801e3, 0xe2920025, 0x2d800022, 0x00000000}},  //   ørt_, _كذا_, _ajie_,
  { {0x3f8c037e, 0x2d920045, 0x00000000, 0x00000000}},  //   rodu_, _bkye_,   ,
  { {0x4fc60478, 0x00000000, 0x00000000, 0x00000000}},  //   _еска,   ,   ,
  { {0x2d80000a, 0x00000000, 0x00000000, 0x00000000}},  //   _djie_,   ,   ,
  { {0x9053007e, 0x00000000, 0x00000000, 0x00000000}},  //   _явіц,   ,   ,
  { {0x6e9301f9, 0x00000000, 0x00000000, 0x00000000}},  //   _пишу,   ,   ,
  { {0x69c83b87, 0x2d8001d6, 0x00000000, 0x00000000}},  //   ídea, _gjie_,   ,
  { {0x57b53b88, 0x81bc0089, 0x61e800f6, 0x00000000}},  // [db70] дбат, _krēs, _lvdl,
  { {0x64d50164, 0xb8f4013d, 0x7bcd3b89, 0x00000000}},  //   दर्श, _स्_, _itau,
  { {0xdb04008e, 0x2d991c9d, 0x2ca00066, 0x00000000}},  //   _guiñ, olse_, _zzid_,
  { {0xceb30452, 0x21260082, 0x00000000, 0x00000000}},  //   גיע_, _naoh_,   ,
  { {0xe454007e, 0x6f1a00d9, 0x6b5000f8, 0x00000000}},  //   нкцы, ketc, _vägv,
  { {0x883a009b, 0x973500a2, 0xe7870794, 0x00000000}},  //   _ותשו, _تکرا, _хумо,
  { {0x6fd5013d, 0xd5670088, 0x22540142, 0x00000000}},  //   _मौजू, _етап, _čaká_,
  { {0x6727002b, 0x394b04bd, 0x65940264, 0x00000000}},  //   _hajj, _jocs_, _засу,
  { {0x394b00f6, 0x67270c33, 0x32070142, 0x00000000}},  //   _mocs_, _kajj, stny_,
  { {0xbebc0089, 0x6727008e, 0x394b00d9, 0x00000000}},  //   ldīj, _jajj, _locs_,
  { {0x67273b8a, 0x7bcd04cb, 0x00000000, 0x00000000}},  //   _majj, _atau,   ,
  { {0xed5703e8, 0x394b0066, 0x00000000, 0x00000000}},  //   дою_, _nocs_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfaa601fb, 0x5eb70044, 0x67271d9b, 0x00000000}},  //   даго, _আজকে, _najj,
  { {0xb0d10164, 0xdb04004a, 0x394b119e, 0x00000000}},  //   _सभाग, _quiñ, _bocs_,
  { {0x6d9d009d, 0x61ee05b7, 0x9f440065, 0x00000000}},  //   néal, _æble, ysmë_,
  { {0x6727002b, 0x60dd000c, 0x394b1e55, 0x00000000}},  // [db80] _bajj, ósmy, _docs_,
  { {0x7c24002b, 0xbcfb0051, 0x3ce000ea, 0x00000000}},  //   _isir, mhéa, _heiv_,
  { {0x5b57009b, 0x394b1e13, 0x67270145, 0x00000000}},  //   _חייב_, _focs_, _dajj,
  { {0x6d4601ae, 0x6e230133, 0x00000000, 0x00000000}},  //   njka, _msnb,   ,
  { {0x68e426fb, 0x5ede0044, 0xbf1d0061, 0x00000000}},  //   maid, _মাসে, _बघून_,
  { {0x68e40a5c, 0xf8bf008e, 0x3ce00288, 0x00000000}},  //   laid, _jaén_, _leiv_,
  { {0x7d040107, 0x65c3007e, 0x6d9d0048, 0x00000000}},  //   _ocis, _абса, féal,
  { {0x2900000b, 0x68e41218, 0x46a30545, 0x00000000}},  //   ngia_, naid, _расв,
  { {0x02cf0164, 0x73063b8b, 0xf993009b, 0x00000000}},  //   _स्वभ, _опаз, כרה_,
  { {0x68e4002a, 0xb356007a, 0x44240232, 0x00000000}},  //   haid, _زیبا_, _ism_,
  { {0x7c240263, 0x36f7009b, 0x7bcd010f, 0x00000000}},  //   _asir, וצים_, _stau,
  { {0xc0a900d3, 0x442402c1, 0x202300b0, 0x00000000}},  //   _کامل_, _ksm_, äriä_,
  { {0xe0430893, 0x68e4002d, 0x7c240010, 0x00000000}},  //   _инци, daid, _csir,
  { {0xfe6f06c6, 0xe1f1026c, 0x442400c4, 0x00000000}},  //   ادی_, _جسے_, _msm_,
  { {0x68e41ab6, 0x44240093, 0x394b0129, 0x00000000}},  //   faid, _lsm_, _pocs_,
  { {0x68e421bc, 0xbcfb002a, 0x29000207, 0x00000000}},  //   gaid, bhéa, ggia_,
  { {0x7d1d021e, 0x672701d5, 0x6d9d0efe, 0x00000000}},  // [db90] mess, _pajj, néam,
  { {0x7d1d1015, 0x70bb007d, 0x67270066, 0x00000000}},  //   less, _उल्ल, _qajj,
  { {0xb90508b7, 0x8aa7081e, 0xfad600b6, 0x00000000}},  //   _না_, _юрид, _אותך_,
  { {0x656200e0, 0x67d50140, 0x00000000, 0x00000000}},  //   ghoh, _пому,   ,
  { {0x44240035, 0x672701d5, 0x94750014, 0x00000000}},  //   _csm_, _tajj, رگرا,
  { {0x7d1d0010, 0x44241575, 0x27e93b8c, 0x00000000}},  //   hess, _dsm_, msan_,
  { {0x07a4008b, 0x7d1d0010, 0x27e91fbc, 0x00000000}},  //   _раён, kess, lsan_,
  { {0x34950265, 0x442412f0, 0x656200e7, 0x00000000}},  //   _забр, _fsm_, choh,
  { {0x7d1d0368, 0x27e9006a, 0xa2ca007d, 0x00000000}},  //   dess, nsan_, _स्क्,
  { {0x6b500039, 0x68e40f0d, 0x6d5f0ede, 0x00000000}},  //   _lägr, zaid, _alqa,
  { {0x27e904be, 0x44240bca, 0x7c240066, 0x00000000}},  //   hsan_, _zsm_, _ssir,
  { {0x27e90155, 0x26070061, 0x7d1d2d75, 0x00000000}},  //   ksan_, _हमनी_, gess,
  { {0x27e90039, 0x68e406aa, 0x75290843, 0x00000000}},  //   jsan_, vaid, _maez,
  { {0xdb1c005f, 0x68e43b8d, 0x60c90197, 0x00000000}},  //   _özün, waid, lcem,
  { {0x29000011, 0x7d1d0010, 0x68e4175e, 0x00000000}},  //   tgia_, bess, taid,
  { {0x60c93b8e, 0x68ef00f6, 0x7c24010e, 0x00000000}},  //   ncem, _cdcd, _tsir,
  { {0x68e4111c, 0x7c2400e7, 0x27e900e0, 0x00000000}},  // [dba0] raid, _usir, gsan_,
  { {0x68e4000b, 0x3a2601e1, 0x6d5d0065, 0x00000000}},  //   said, _змог, ërav,
  { {0xaadb009b, 0x79e800a1, 0x27e90169, 0x00000000}},  //   _מחיר, _توجہ_, asan_,
  { {0x44240ec1, 0x27e93b8f, 0x2ee50133, 0x00000000}},  //   _psm_, bsan_, half_,
  { {0x3d12001c, 0xb87b02d5, 0x88bb034e, 0x00000000}},  //   ध्ये_, _veíc, _מזכי,
  { {0x08770049, 0xf48700a2, 0x7d1d3b90, 0x00000000}},  //   _װעלט_, رانی, zess,
  { {0x44240146, 0x7d1d0b90, 0x317f0045, 0x00000000}},  //   _wsm_, yess, fnuz_,
  { {0x44240284, 0x00000000, 0x00000000, 0x00000000}},  //   _tsm_,   ,   ,
  { {0x7d1d0181, 0x442401a3, 0xd00700ed, 0x00000000}},  //   vess, _usm_, еење_,
  { {0x7d1d01d6, 0x00000000, 0x00000000, 0x00000000}},  //   wess,   ,   ,
  { {0x26c70091, 0x6dba01f3, 0x00000000, 0x00000000}},  //   žnog_, _aċar,   ,
  { {0x63ba3b91, 0x27e90890, 0x61f8016c, 0x00000000}},  //   _hitn, ysan_, mrvl,
  { {0x7c8400e3, 0x61ea02e1, 0x0ca800e2, 0x00000000}},  //   гуре, lsfl, етри_,
  { {0x7d1d021e, 0x63ba002b, 0x68ef107b, 0x00000000}},  //   sess, _jitn, _sdcd,
  { {0x7d1d0010, 0x61ea3b92, 0x63ba01a2, 0x00000000}},  //   pess, nsfl, _mitn,
  { {0x63ba0007, 0x629a1962, 0x27e91136, 0x00000000}},  //   _litn, _myto, tsan_,
  { {0x6b500039, 0x00000000, 0x00000000, 0x00000000}},  // [dbb0] _vägr,   ,   ,
  { {0x27e9049d, 0xb88301dc, 0x61ea0210, 0x00000000}},  //   rsan_, vlíč, ksfl,
  { {0xf7480025, 0x629a3b93, 0x7ae704eb, 0x00000000}},  //   علمي_, _nyto, majt,
  { {0x442f027b, 0x27e90066, 0x7ae70142, 0x00000000}},  //   tvg_, psan_, lajt,
  { {0x63ba0119, 0x2458007e, 0x27e9006b, 0x00000000}},  //   _bitn, наць_, qsan_,
  { {0x629a2dd6, 0x39490dac, 0xe29900a8, 0x00000000}},  //   _byto, ljas_, мал_,
  { {0x38690b32, 0x6352025f, 0x629a1f61, 0x00000000}},  //   lzar_, рвју, _cyto,
  { {0x7ae71db2, 0x56943b94, 0x7777002b, 0x00000000}},  //   hajt, _саст, lixx,
  { {0x7ae70059, 0x38690211, 0x7ed50088, 0x00000000}},  //   kajt, nzar_, кінч,
  { {0x7ae70ed8, 0xdb17009d, 0x63ba011c, 0x00000000}},  //   jajt, _fixé, _gitn,
  { {0x7ae70027, 0xa2ca007d, 0xc3240044, 0x00000000}},  //   dajt, _स्ट्, পাশি_,
  { {0x2ee50c6b, 0xed5a312f, 0x00000000, 0x00000000}},  //   salf_, фом_,   ,
  { {0x0d8302dc, 0x644f00f6, 0x7ae73677, 0x00000000}},  //   рлян, _àcid, fajt,
  { {0x93fa009b, 0x7ae70059, 0xf8bf0068, 0x00000000}},  //   ולשי, gajt, _agé_,
  { {0x200d2522, 0xbcfb009d, 0x49960ab6, 0x00000000}},  //   ltei_, chéo, вшат,
  { {0x6d5d0023, 0x8d76009e, 0x00000000, 0x00000000}},  //   ërat, _جاتا,   ,
  { {0x200d289d, 0x7ae73b95, 0xcc8a0014, 0x00000000}},  // [dbc0] ntei_, bajt, _زنده_,
  { {0x443801c8, 0x7bfb009b, 0xcb6a0014, 0x00000000}},  //   _čr_, _קפיצ, _آمده_,
  { {0xb87b008e, 0x63ba074d, 0xd2450014, 0x00000000}},  //   _veía, _ritn, _اچ_,
  { {0xd9100167, 0x63ba0091, 0x629a0006, 0x00000000}},  //   _دیر_, _sitn, _ryto,
  { {0xa3dd001c, 0x61ea3774, 0x938a0072, 0x00000000}},  //   थील_, wsfl, мска_,
  { {0x61ea22f8, 0x61f8012d, 0x00000000, 0x00000000}},  //   tsfl, trvl,   ,
  { {0xf5060849, 0xd5b20d3a, 0x63ba0d3e, 0x00000000}},  //   _изво, _نفس_, _vitn,
  { {0x2d540181, 0xc05a0088, 0x63ba3177, 0x00000000}},  //   _mães_, діо_, _witn,
  { {0x61ea0109, 0x63ba0066, 0x5f94114a, 0x00000000}},  //   ssfl, _titn, лиит,
  { {0x7d1600b9, 0x63ba01b5, 0x9f53007c, 0x00000000}},  //   _abys, _uitn, ивыч,
  { {0x7ae70209, 0x3869002b, 0x00000000, 0x00000000}},  //   vajt, zzar_,   ,
  { {0xc69300a0, 0xdb16000c, 0x7c360146, 0x00000000}},  //   יאת_, _styð, _bryr,
  { {0x7ae71187, 0x06e80044, 0x6d9d009d, 0x00000000}},  //   tajt, _পানি, néai,
  { {0x69c30010, 0x10a30088, 0x79860022, 0x00000000}},  //   _ének, _тичн, _ajkw,
  { {0x7ae70209, 0xda780ae0, 0xe9190088, 0x00000000}},  //   rajt, вят_, нові_,
  { {0x3f9e0a2d, 0x38693b96, 0x7ae73b97, 0x00000000}},  //   lltu_, tzar_, sajt,
  { {0x7ae7050f, 0x3949006c, 0x971501ee, 0x00000000}},  // [dbd0] pajt, rjas_, лмац,
  { {0xf7700380, 0x6d5d00f8, 0x00000000, 0x00000000}},  //   يال_, lksa,   ,
  { {0x3a840147, 0x5a47007e, 0x7777002b, 0x00000000}},  //   _выяв, _рэпа, rixx,
  { {0x6d5d01a2, 0xa8a7007e, 0xe0df0082, 0x00000000}},  //   nksa, _аргк, ưòi_,
  { {0x7ae50004, 0x24893b98, 0x6d5d00bb, 0x00000000}},  //   _keht, çam_, iksa,
  { {0x42090805, 0x69c50020, 0x2489002b, 0x00000000}},  //   енко_, _kuhe, ħam_,
  { {0x69c5006c, 0x7ae528e3, 0x6d5d0bdc, 0x00000000}},  //   _juhe, _meht, kksa,
  { {0x7ae53b99, 0x69c51158, 0x200d00b0, 0x00000000}},  //   _leht, _muhe, ttei_,
  { {0x69c50023, 0x00000000, 0x00000000, 0x00000000}},  //   _luhe,   ,   ,
  { {0x200d0c75, 0x7ae500b9, 0x6d5d0944, 0x00000000}},  //   rtei_, _neht, eksa,
  { {0x200d03c7, 0xfce60175, 0x1d0a005e, 0x00000000}},  //   stei_, лоно, нени_,
  { {0x200d20c5, 0x7bc40035, 0x657901c3, 0x00000000}},  //   ptei_, _puiu, niwh,
  { {0xff53007a, 0x00000000, 0x00000000, 0x00000000}},  //   _پخش_,   ,   ,
  { {0x60db0027, 0xdfcf0014, 0x2d5400c4, 0x00000000}},  //   lbum, _هيچ_, _pães_,
  { {0x61e100d9, 0x00000000, 0x00000000, 0x00000000}},  //   _jwll,   ,   ,
  { {0x69c5008d, 0x6d5d0002, 0x98a00166, 0x00000000}},  //   _duhe, cksa, ndić_,
  { {0x999e0010, 0x7ae50087, 0x2d83012d, 0x00000000}},  // [dbe0] ítő_, _feht, čket_,
  { {0x64590036, 0x7ae5010f, 0x00000000, 0x00000000}},  //   dywi, _geht,   ,
  { {0x9bb7009b, 0x69c50009, 0x75d30025, 0x00000000}},  //   _תהיה_, _guhe, ميلا,
  { {0x64590016, 0x4a7b00a3, 0x00000000, 0x00000000}},  //   fywi, _טריב,   ,
  { {0x4d7b007b, 0xbebc0089, 0x06e80044, 0x00000000}},  //   ערנע, ldīt, _পাঠি,
  { {0x69c50022, 0x00000000, 0x00000000, 0x00000000}},  //   _yuhe,   ,   ,
  { {0x3d0503d7, 0xed610062, 0xa79b009b, 0x00000000}},  //   _वाले_, ážky_, _נשלח,
  { {0x41542257, 0x41c30025, 0xbcfb00f4, 0x00000000}},  //   рвис, حقيق, thém,
  { {0xa3cb03d7, 0x68e60521, 0x798404c0, 0x00000000}},  //   _रूप_, _mekd, iniw,
  { {0x752200ea, 0x141b0049, 0x66e4007d, 0x00000000}},  //   leoz, _אומב, गरिक_,
  { {0x3eb83b9a, 0x59b40316, 0x7ae50052, 0x00000000}},  //   ärt_, ंगार, _reht,
  { {0x69c52af8, 0x68e618e1, 0x5c073b9b, 0x00000000}},  //   _ruhe, _nekd, ляга,
  { {0x6d5d0073, 0x69c5006c, 0x60c20dfc, 0x00000000}},  //   rksa, _suhe, _igom,
  { {0x69c5021e, 0xdcef001a, 0x0703013d, 0x00000000}},  //   _puhe, fică, _लाइव_,
  { {0x64590046, 0x69c50065, 0xab5b00c4, 0x00000000}},  //   zywi, _quhe, nqüi,
  { {0x2608001c, 0x44262dd5, 0x58d5189f, 0x00000000}},  //   ांनी_, kwo_, роат,
  { {0x7ae53b9c, 0x60c20020, 0xb6060091, 0x00000000}},  // [dbf0] _teht, _mgom, _lišć,
  { {0x2fc600e0, 0xe8740025, 0x368b0517, 0x00000000}},  //   _muog_, حافظ, нсен_,
  { {0x57a4041f, 0x60c2016c, 0x00000000, 0x00000000}},  //   сшта, _ogom,   ,
  { {0x60c23b9d, 0x64590036, 0x89da00a3, 0x00000000}},  //   _ngom, tywi, _שחרי,
  { {0x44263b9e, 0x672e00ca, 0xbcfb009d, 0x00000000}},  //   gwo_, _fabj, ckée,
  { {0x64590b35, 0x1b230044, 0x60c20dfc, 0x00000000}},  //   rywi, মাকে_, _agom,
  { {0x6455006b, 0x44260045, 0x00000000, 0x00000000}},  //   _əziy, awo_,   ,
  { {0x44260061, 0x672e016c, 0x00000000, 0x00000000}},  //   bwo_, _zabj,   ,
  { {0x84670265, 0xdb1700f6, 0x60db189b, 0x00000000}},  //   _съве, _així, rbum,
  { {0x2f5500ed, 0x60c21288, 0x60db28e2, 0x00000000}},  //   ртис, _egom, sbum,
  { {0xc2c40076, 0xbea5012b, 0x2ca9006b, 0x00000000}},  //   _ايمي, ранк, _azad_,
  { {0xa3a902fb, 0x518402be, 0x290b0048, 0x00000000}},  //   _गीत_, _луча, _ncca_,
  { {0x26d100b5, 0x6f0a0045, 0xa3cb007d, 0x00000000}},  //   _ofzo_, _fcfc, _रूम_,
  { {0x68e63b9f, 0x291901d6, 0x98a20036, 0x00000000}},  //   _sekd, _absa_, _jaką_,
  { {0x09e601fb, 0x2d8b00f4, 0xb97600ed, 0x00000000}},  //   робн, ébec_, аѓањ,
  { {0x29190022, 0x3ceb0026, 0x00000000, 0x00000000}},  //   _cbsa_, cacv_,   ,

  { {0x661c012d, 0x7c95007e, 0x00000000, 0x00000000}},  // [dc00] _sprk, _грэц,   ,
  { {0x7c290095, 0x212f0045, 0x00000000, 0x00000000}},  //   çere, _lagh_,   ,
  { {0xa9a6007c, 0x59a70309, 0x7a6a0478, 0x00000000}},  //   _винд, _कीवर, _ринг_,
  { {0x44260046, 0xe45a0057, 0x61fc05fe, 0x00000000}},  //   two_, кже_, _årli,
  { {0x240701fc, 0xd90d0167, 0xa533007e, 0x00000000}},  //   инци_, _سیل_, ўніч,
  { {0x44263ba0, 0x60c20197, 0x2ca00145, 0x00000000}},  //   rwo_, _sgom, _myid_,
  { {0x661c05fa, 0x25bf001a, 0x44260022, 0x00000000}},  //   _uprk, _fiul_, swo_,
  { {0x1fda0044, 0x00000000, 0x00000000, 0x00000000}},  //   _দিবস,   ,   ,
  { {0x7f9d00f4, 0x00000000, 0x00000000, 0x00000000}},  //   hèqu,   ,   ,
  { {0x381700b3, 0x200b0129, 0xc30600f3, 0x00000000}},  //   סקים_, àcia_, _خبرو,
  { {0x201d01aa, 0xdb1700c4, 0x00000000, 0x00000000}},  //   _epwi_, _lixã,   ,
  { {0x61430264, 0x60c214a5, 0x2ca00022, 0x00000000}},  //   _меха, _ugom, _byid_,
  { {0xd0070265, 0x80dd0055, 0x2f180783, 0x00000000}},  //   _вече_, _যাচ্, _боль_,
  { {0x20040089, 0x271700b9, 0x2ee701a2, 0x00000000}},  //   mumi_, _mění_, _genf_,
  { {0x20041a99, 0x00000000, 0x00000000, 0x00000000}},  //   lumi_,   ,   ,
  { {0x644d00b0, 0x00000000, 0x00000000, 0x00000000}},  //   äaik,   ,   ,
  { {0x2004001e, 0x2d990a59, 0x7d0d03d1, 0x00000000}},  // [dc10] numi_, mose_, _icas,
  { {0x2d990007, 0x7c2d011c, 0x25bf1a0b, 0x00000000}},  //   lose_, _isar, _siul_,
  { {0x2004000b, 0xcf9301ce, 0x7c2d0066, 0x00000000}},  //   humi_, קטע_, _hsar,
  { {0x2004001e, 0x2d99037e, 0xe5700379, 0x00000000}},  //   kumi_, nose_, وطن_,
  { {0x20040580, 0x68ed3ba1, 0x7d0d0066, 0x00000000}},  //   jumi_, maad, _mcas,
  { {0xb5c90b03, 0x68ed006c, 0x20043ba2, 0x00000000}},  //   _موسم_, laad, dumi_,
  { {0x7d0d1d66, 0x2d990006, 0xdb1e0065, 0x00000000}},  //   _ocas, kose_, _sipë,
  { {0x29090020, 0xbcfb0051, 0x20040197, 0x00000000}},  //   ngaa_, bhéi, fumi_,
  { {0x2d990211, 0x20040089, 0x656b0051, 0x00000000}},  //   dose_, gumi_, mhgh,
  { {0x442d08a1, 0x7d0d34cd, 0x1f65007c, 0x00000000}},  //   _ise_, _acas, ском,
  { {0x442d1978, 0x7c2d01c5, 0x68ed006c, 0x00000000}},  //   _hse_, _asar, kaad,
  { {0x2004359e, 0x442d0058, 0x01340025, 0x00000000}},  //   bumi_, _kse_, _وعند,
  { {0x442d38a3, 0x68ed006c, 0x672500ea, 0x00000000}},  //   _jse_, daad, kehj,
  { {0x6d4b0263, 0xb47a007b, 0x442d0085, 0x00000000}},  //   _ògan, אָלי, _mse_,
  { {0x2d99007f, 0x442d0bd5, 0x00000000, 0x00000000}},  //   bose_, _lse_,   ,
  { {0x442d008d, 0x68ed3ba3, 0x2d990133, 0x00000000}},  //   _ose_, gaad, cose_,
  { {0x69d7022b, 0x442d007f, 0x6d440058, 0x00000000}},  // [dc20] _etxe, _nse_, _inia,
  { {0x5fdf0067, 0x00000000, 0x00000000, 0x00000000}},  //   पीएल,   ,   ,
  { {0x442d01aa, 0x6d56014a, 0x68ed2c26, 0x00000000}},  //   _ase_, _koya, baad,
  { {0x6d563ba4, 0xdb1e01aa, 0xbcfb0051, 0x00000000}},  //   _joya, _sipè, théi,
  { {0x69dc2a06, 0x6d560145, 0x442d25cf, 0x00000000}},  //   lpre, _moya, _cse_,
  { {0x442d2635, 0xe1d8007e, 0x20040089, 0x00000000}},  //   _dse_, адкі_, vumi_,
  { {0x442d0219, 0x69dc053b, 0x27f23481, 0x00000000}},  //   _ese_, npre, lsyn_,
  { {0xf126103e, 0x4fd40265, 0x6d56005f, 0x00000000}},  //   сько, ожит, _noya,
  { {0xa49400d3, 0x3e4e006b, 0x27f205fe, 0x00000000}},  //   _بیشت, məti_, nsyn_,
  { {0x543b007b, 0x160c01f5, 0x6d44005b, 0x00000000}},  //   _געמא, _हमार_, _ania,
  { {0xeb9f0378, 0x69dc0b9f, 0xa3e4007d, 0x00000000}},  //   ktør_, jpre, भीर_,
  { {0x656200b0, 0x2d990006, 0x69dc0134, 0x00000000}},  //   nkoh, uose_, dpre,
  { {0x2d990207, 0x7d0d3ba5, 0x69dc0270, 0x00000000}},  //   rose_, _vcas, epre,
  { {0x6d4401ee, 0x69dc010f, 0x2d990006, 0x00000000}},  //   _enia, fpre, sose_,
  { {0x2d99032c, 0x68ed0f81, 0x3e4e006b, 0x00000000}},  //   pose_, taad, kəti_,
  { {0x6d9d0051, 0x7c2d1fe8, 0x6d56008a, 0x00000000}},  //   réas, _tsar, _goya,
  { {0xb8d103d7, 0x7c2d3ba6, 0x68ed006c, 0x00000000}},  // [dc30] _ओर_, _usar, raad,
  { {0x68ed06ad, 0x660504fa, 0x7bdd006c, 0x00000000}},  //   saad, tuhk, mpsu,
  { {0x442d010e, 0x3e4e006b, 0x68ed0abf, 0x00000000}},  //   _sse_, fəti_, paad,
  { {0x442d008d, 0xd12604e8, 0x67250190, 0x00000000}},  //   _pse_, _غم_, sehj,
  { {0xe3b1035b, 0x06e80044, 0x442d088a, 0x00000000}},  //   ورت_, _পারি, _qse_,
  { {0x442d17fd, 0x31b301f5, 0x6605006c, 0x00000000}},  //   _vse_, ुद्ध, puhk,
  { {0x3e4e006b, 0x78c80010, 0x00000000, 0x00000000}},  //   bəti_, _ásvá,   ,
  { {0x442d00c4, 0x34951606, 0xd1b900a1, 0x00000000}},  //   _tse_, _дабр, جاتا_,
  { {0x442d0038, 0x1aef0044, 0x6d560549, 0x00000000}},  //   _use_, _জানে_, _roya,
  { {0x2d8b0047, 0x69dc1651, 0x6d56005a, 0x00000000}},  //   ében_, ypre, _soya,
  { {0x69dc0011, 0x6d560c79, 0xd12e01b2, 0x00000000}},  //   xpre, _poya, رمی_,
  { {0x69dc0059, 0x6d56006b, 0x3327004a, 0x00000000}},  //   vpre, _qoya, lenx_,
  { {0x6d56028c, 0x9f350088, 0x6d9d0048, 0x00000000}},  //   _voya, _меді, téar,
  { {0x3b0a003b, 0xf99f000a, 0x00000000, 0x00000000}},  //   јево_, _akè_,   ,
  { {0x3e4e006b, 0xa3cb013d, 0x06e80044, 0x00000000}},  //   yəti_, _रूस_, _পালি,
  { {0xdce40059, 0x6d440016, 0x7aee3ba7, 0x00000000}},  //   _klič, _unia, sabt,
  { {0x69dc0343, 0x3ff90049, 0xf0b60049, 0x00000000}},  // [dc40] spre, יפּע, ַלער_,
  { {0xbf8700ad, 0x81df0055, 0xbcfb0010, 0x00000000}},  //   _điện_, _তিন_, nkén,
  { {0x6b9c06a1, 0x2018001a, 0x316d0010, 0x00000000}},  //   morg, ării_, khez_,
  { {0x96da0164, 0x6b9c00ea, 0x00000000, 0x00000000}},  //   _प्रॉ, lorg,   ,
  { {0xc2f30055, 0x65620065, 0x3e4e006b, 0x00000000}},  //   চ্ছি_, rkoh, rəti_,
  { {0x47c30265, 0x69c300f4, 0x9c8301ca, 0x00000000}},  //   _обяв, _éner, _účel,
  { {0xe1ef0025, 0x416a003b, 0x00000000, 0x00000000}},  //   نسي_, ијим_,   ,
  { {0xdced0521, 0x6b9c0b5e, 0xf99f0197, 0x00000000}},  //   _imać, horg, _xkè_,
  { {0xe5a30242, 0x6b9c0b0b, 0x7f4a0088, 0x00000000}},  //   _цити, korg, аїна_,
  { {0x25a60016, 0x6b9c0023, 0x00000000, 0x00000000}},  //   llol_, jorg,   ,
  { {0xe8a70164, 0x81e40044, 0x6b9c01c5, 0x00000000}},  //   _खर्च, ভূজ_, dorg,
  { {0xd13002fd, 0x316d00f4, 0x3d270088, 0x00000000}},  //   _سمت_, chez_, цьов,
  { {0x6b9c297d, 0xbcfb0010, 0x0cab0f93, 0x00000000}},  //   forg, bkén, ртни_,
  { {0xa3b0062e, 0x99d70025, 0x6b9c009d, 0x00000000}},  //   _टीम_, قترا, gorg,
  { {0x0eba007e, 0x00000000, 0x00000000, 0x00000000}},  //   _туды_,   ,   ,
  { {0x65a3010e, 0x00000000, 0x00000000, 0x00000000}},  //   põhi,   ,   ,
  { {0x6b9c0039, 0x26c71187, 0x00000000, 0x00000000}},  // [dc50] borg, žnom_,   ,
  { {0xd6db0256, 0x5a47008b, 0x6b9c0207, 0x00000000}},  //   рта_, _дэма, corg,
  { {0xcb1200b3, 0x65690065, 0x7bcd00d6, 0x00000000}},  //   _אלי_, _pleh, _huau,
  { {0x8aa4007e, 0xa6e30044, 0xd83e089f, 0x00000000}},  //   _юрыд, _পাওয়, ščad_,
  { {0x7bc53ba8, 0xb4270025, 0x2d8b0051, 0x00000000}},  //   _kihu, تعاو, ince_,
  { {0x2329026b, 0x3959146c, 0x26080061, 0x00000000}},  //   соки_, _hoss_, ांशी_,
  { {0xdce40119, 0x7afa009f, 0x96f800ed, 0x00000000}},  //   _slič, ótti, _фест_,
  { {0x6b9c00b5, 0x657b14a5, 0x645c006b, 0x00000000}},  //   zorg, _umuh, _əriz,
  { {0x44393ba9, 0x229500a6, 0x6b9c00ea, 0x00000000}},  //   _és_, _کلاس, yorg,
  { {0x2d8b030a, 0x39591442, 0x316d0010, 0x00000000}},  //   ence_, _loss_, shez_,
  { {0x80a500a1, 0x443f0161, 0xada6005e, 0x00000000}},  //   _کمشن, _hru_, занл,
  { {0xbcfb1465, 0x443f01a3, 0x39590145, 0x00000000}},  //   skén, _kru_, _noss_,
  { {0x7bc5022b, 0x6b9c0039, 0x7bcd008e, 0x00000000}},  //   _bihu, torg, _cuau,
  { {0x2d8b3baa, 0xd00e0054, 0x7bc50022, 0x00000000}},  //   ance_, _صلى_, _cihu,
  { {0xbcfb00f4, 0x6b9c0056, 0x7bc5003f, 0x00000000}},  //   thét, rorg, _dihu,
  { {0x39460958, 0x88ca003b, 0x443f139b, 0x00000000}},  //   ños_, слав_, _oru_,
  { {0x2d82008d, 0x443f01d5, 0x3b0a003b, 0x00000000}},  // [dc60] mike_, _nru_, _лепо_,
  { {0x2d820343, 0x7bc51bf2, 0x7c2400c4, 0x00000000}},  //   like_, _gihu, _ipir,
  { {0x443f006c, 0x6735002b, 0xbcfb009d, 0x00000000}},  //   _aru_, _dazj, phét,
  { {0x2d820c33, 0xa50a01c0, 0x443f3120, 0x00000000}},  //   nike_, седа_, _bru_,
  { {0xe80303d7, 0xdce6001e, 0x27ee0224, 0x00000000}},  //   _लिया_, dokļ, álně_,
  { {0x8c1b012f, 0x68e4022b, 0x27e004cb, 0x00000000}},  //   מוני, lbid, mpin_,
  { {0x443f0359, 0x69c60010, 0x26ca00ea, 0x00000000}},  //   _eru_, _kike, _igbo_,
  { {0x68e43bab, 0x443f01bf, 0x2d820d61, 0x00000000}},  //   nbid, _fru_, jike_,
  { {0x69c633fa, 0x68e43bac, 0x2d823bad, 0x00000000}},  //   _mike, ibid, dike_,
  { {0x69c624e3, 0x9df800ed, 0x442404be, 0x00000000}},  //   _like, онот_, _ipm_,
  { {0x69c6021e, 0x2d820065, 0x7c24022b, 0x00000000}},  //   _oike, fike_, _apir,
  { {0x160d0164, 0x64400387, 0x442401a3, 0x00000000}},  //   ांतर_, _krmi, _kpm_,
  { {0x442401a3, 0x7bc5006c, 0x2b5a00d4, 0x00000000}},  //   _jpm_, _pihu, _bopc_,
  { {0x7fb8007a, 0xddda0010, 0x69c61241, 0x00000000}},  //   _بهتر_, sztő, _aike,
  { {0x44240690, 0x7c240065, 0x69c63bae, 0x00000000}},  //   _lpm_, _epir, _bike,
  { {0x26d80d69, 0x3f9e1cc7, 0x6da401fc, 0x00000000}},  //   _afro_, lotu_, _пија,
  { {0xa2bc02fb, 0x69c6020c, 0x39590240, 0x00000000}},  // [dc70] षेत्, _dike, _voss_,
  { {0x69c61696, 0x3f9e0089, 0x7d1d2f7b, 0x00000000}},  //   _eike, notu_, lfss,
  { {0x64400065, 0xda670076, 0x6d40009d, 0x00000000}},  //   _armi, _رادي, ômag,
  { {0x44240f2c, 0x443f01a3, 0x68e41995, 0x00000000}},  //   _bpm_, _pru_, cbid,
  { {0x98ab000d, 0x240901fb, 0x444500a1, 0x00000000}},  //   _dacă_, інки_, براہ,
  { {0x2d820213, 0x8c1c01ce, 0x2eee0a3a, 0x00000000}},  //   zike_, צווי, _neff_,
  { {0x6440010f, 0x442400f6, 0x98ab001a, 0x00000000}},  //   _ermi, _epm_, _facă_,
  { {0x636f05df, 0xd179008b, 0x443f3baf, 0x00000000}},  //   _sønd, ўскі_, _tru_,
  { {0x443f3bb0, 0xf2c700d7, 0x4424007f, 0x00000000}},  //   _uru_, _есен, _gpm_,
  { {0x8af7006b, 0xd00e00a6, 0x6e230022, 0x00000000}},  //   _şənb, گلی_, _ppnb,
  { {0x7c24121e, 0x2d82008d, 0x442f018e, 0x00000000}},  //   _spir, tike_, lwg_,
  { {0xd00e00a6, 0xb33c0066, 0x27e00052, 0x00000000}},  //   دلی_, _ikħa, ypin_,
  { {0xef0e0072, 0x2d821a5d, 0x3f9e047c, 0x00000000}},  //   _им_, rike_, botu_,
  { {0x69c60047, 0x8e8509ae, 0x2d821583, 0x00000000}},  //   _sike, _огле, sike_,
  { {0xfaa303e0, 0x69c61583, 0x2d820023, 0x00000000}},  //   варо, _pike, pike_,
  { {0x2d95008b, 0x140d03d7, 0x57ea005e, 0x00000000}},  //   _прыс, _समूह_, ждам_,
  { {0x69c6016e, 0x2fc700ab, 0xbcfb00f4, 0x00000000}},  // [dc80] _vike, _king_, phér,
  { {0x27e00052, 0x69c60f65, 0x68e4002d, 0x00000000}},  //   rpin_, _wike, sbid,
  { {0x442401a3, 0x7afa000c, 0x00000000, 0x00000000}},  //   _spm_, óttu,   ,
  { {0x27e00635, 0x3ea73bb1, 0xdb1e00f6, 0x00000000}},  //   ppin_, _mynt_, _hipà,
  { {0xd24f007a, 0xf4870014, 0x3f8c000c, 0x00000000}},  //   ینه_, واهی, yndu_,
  { {0x2fc706ba, 0x06e80055, 0x00000000, 0x00000000}},  //   _ning_, _পাকি,   ,
  { {0x3f9e0119, 0x2eee008a, 0x2d8032e8, 0x00000000}},  //   votu_, _reff_, _omie_,
  { {0xc034025f, 0x2d920009, 0x44240145, 0x00000000}},  //   ениј, _njye_, _tpm_,
  { {0x442401a3, 0xdce60006, 0x636f00ea, 0x00000000}},  //   _upm_, likė, _søne,
  { {0x69de0107, 0x2fcf0186, 0x2d8000f4, 0x00000000}},  //   _otpe, _dugg_, _amie_,
  { {0xe0da17a4, 0x2fc70343, 0x3f9e09a4, 0x00000000}},  //   _две_, _ding_, rotu_,
  { {0x3f9e3bb2, 0x7d1d01a2, 0x28de0316, 0x00000000}},  //   sotu_, ufss, _फ्लि,
  { {0xb87b0047, 0x3f9e0091, 0x7d1d000c, 0x00000000}},  //   _leír, potu_, rfss,
  { {0x2fc707eb, 0x0a6b05b5, 0x7c3d0190, 0x00000000}},  //   _ging_, орби_, rvsr,
  { {0x8fa3012b, 0x3ea70016, 0x798d01d6, 0x00000000}},  //   _шаље, _gynt_, tnaw,
  { {0x69da002a, 0x2fc7001d, 0x798d3bb3, 0x00000000}},  //   ítea, _zing_, unaw,
  { {0x61f8001c, 0x57b501fc, 0x00000000, 0x00000000}},  // [dc90] hsvl, ебат,   ,
  { {0x2fc70f10, 0x798d3bb4, 0xb87b3007, 0x00000000}},  //   _xing_, snaw, _beír,
  { {0xfc3f008e, 0x06e80044, 0x00000000, 0x00000000}},  //   lví_, _পাখি,   ,
  { {0xceb30097, 0xa4d501fb, 0x46df0309, 0x00000000}},  //   דיע_, ході, _प्रह,
  { {0xd006002c, 0x2458008b, 0xd6db00ed, 0x00000000}},  //   _حل_, маць_, _мтв_,
  { {0x442f068a, 0x00000000, 0x00000000, 0x00000000}},  //   rwg_,   ,   ,
  { {0xd251023c, 0x2fc7066d, 0x7c3a0089, 0x00000000}},  //   انع_, _ring_, ātri,
  { {0x2fc70007, 0x7af5002d, 0x3cfb013d, 0x00000000}},  //   _sing_, hazt, ्लों_,
  { {0x160d001c, 0x7af50032, 0x00000000, 0x00000000}},  //   ांवर_, kazt,   ,
  { {0xa3d4007d, 0xbcfb013e, 0x23790d3a, 0x00000000}},  //   _संत_, lkéh, _عماد_,
  { {0x2fc700f8, 0x00000000, 0x00000000, 0x00000000}},  //   _ving_,   ,   ,
  { {0x20020006, 0x2fc70133, 0xc6920097, 0x00000000}},  //   škia_, _wing_, ראט_,
  { {0x2fc70018, 0xf5390027, 0x3ea7005b, 0x00000000}},  //   _ting_, _mať_, _wynt_,
  { {0x7af5002d, 0x3ea700ea, 0x00000000, 0x00000000}},  //   gazt, _tynt_,   ,
  { {0x3f85023a, 0x200d0032, 0xda6604b1, 0x00000000}},  //   milu_, luei_, راسي,
  { {0x2d8022df, 0x3f850035, 0x2d920009, 0x00000000}},  //   _umie_, lilu_, _ujye_,
  { {0xa3cb02fb, 0x7af5002d, 0xcc360025, 0x00000000}},  // [dca0] _रंग_, bazt, _أربع,
  { {0x212d0058, 0xdce60006, 0x00000000, 0x00000000}},  //   heeh_, tikė,   ,
  { {0x69de02e1, 0x00000000, 0x00000000, 0x00000000}},  //   _utpe,   ,   ,
  { {0xd6e80055, 0xd9100167, 0x200d0032, 0x00000000}},  //   _পাওয, _خیر_, kuei_,
  { {0xd4670f09, 0xd90d0167, 0xdce60006, 0x00000000}},  //   нице_, _ذیل_, sikė,
  { {0xf8af026c, 0x212d00e0, 0x2337007e, 0x00000000}},  //   _چکے_, eeeh_, епшы_,
  { {0x3f8500d0, 0x31c6004c, 0x00000000, 0x00000000}},  //   dilu_, нсив,   ,
  { {0x64a6091b, 0xbcfb004f, 0x29123bb5, 0x00000000}},  //   _заба, ckéh, ngya_,
  { {0x59d203d7, 0x3f8510d9, 0x200d0181, 0x00000000}},  //   _दूसर, filu_, guei_,
  { {0x68f600fa, 0x3f850032, 0x2907007f, 0x00000000}},  //   hayd, gilu_, ėnai_,
  { {0x539b00a0, 0x7c360145, 0x00ca0920, 0x00000000}},  //   _ציבו, _asyr, _елек_,
  { {0xfc3f0224, 0x68f600e7, 0x00000000, 0x00000000}},  //   tví_, jayd,   ,
  { {0x69da0010, 0x3f850387, 0x00000000, 0x00000000}},  //   íten, bilu_,   ,
  { {0xdced0066, 0x00000000, 0x00000000, 0x00000000}},  //   _klaċ,   ,   ,
  { {0x7af5022b, 0x3dc900e0, 0x7ed50088, 0x00000000}},  //   razt, _tiaw_, _річч,
  { {0x29121233, 0x6c850025, 0x00000000, 0x00000000}},  //   ggya_, _للعم,   ,
  { {0x6d4d11ad, 0xa8980b81, 0xfcab009e, 0x00000000}},  // [dcb0] _inaa, екту_, _ڈاکو_,
  { {0x81bc001e, 0x7641000c, 0x00000000, 0x00000000}},  //   _spēl, _ályk,   ,
  { {0x6d4d0116, 0x394b0082, 0x68f6013f, 0x00000000}},  //   _knaa, _tncs_, bayd,
  { {0x3f85199a, 0x00000000, 0x00000000, 0x00000000}},  //   zilu_,   ,   ,
  { {0x5887008b, 0x6d4d1c27, 0x9cd8009b, 0x00000000}},  //   _чына, _mnaa, גודה_,
  { {0xbcfb01ca, 0x00000000, 0x00000000, 0x00000000}},  //   skéh,   ,   ,
  { {0xe29600e3, 0x6d4d01bb, 0x3f850213, 0x00000000}},  //   каш_, _onaa, vilu_,
  { {0x6d4d00e0, 0x200d3bb6, 0x7fd900e2, 0x00000000}},  //   _nnaa, tuei_, мфот_,
  { {0x3f8504a7, 0xa3d50088, 0x637400d4, 0x00000000}},  //   tilu_, _розч, _bànd,
  { {0x20030627, 0x6d4d0020, 0x753b1b2c, 0x00000000}},  //   čji_, _anaa, _hauz,
  { {0x13e608b7, 0xfce601fb, 0x1d0a00ed, 0x00000000}},  //   _নিয়, коно, мени_,
  { {0xd25600b6, 0x3f850c8a, 0x753b002d, 0x00000000}},  //   _בשעה_, silu_, _jauz,
  { {0x200d09f7, 0x753b2d1b, 0x317a0049, 0x00000000}},  //   quei_, _mauz, _קאנד,
  { {0x753b0e07, 0x63a30d0e, 0x68f60190, 0x00000000}},  //   _lauz, nonn, wayd,
  { {0xfaa601fc, 0x60db0009, 0x00000000, 0x00000000}},  //   таво, ocum,   ,
  { {0x1c4604b6, 0x63a30016, 0x753b0032, 0x00000000}},  //   _аним, honn, _nauz,
  { {0x63a30004, 0xf8630131, 0x4c36007e, 0x00000000}},  // [dcc0] konn, авто, _рэйт,
  { {0x63a33bb7, 0x68f6005d, 0x6d4d016c, 0x00000000}},  //   jonn, sayd, _znaa,
  { {0x5a961523, 0x68f60058, 0x753b01a2, 0x00000000}},  //   _шриф, payd, _bauz,
  { {0x753b000d, 0x73e6007e, 0x59830242, 0x00000000}},  //   _cauz, водз, _влюб,
  { {0x753b075c, 0xf48700a2, 0x00000000, 0x00000000}},  //   _dauz, پانی,   ,
  { {0x63a307eb, 0x66e3007e, 0xdced0066, 0x00000000}},  //   gonn, _вора, _plaċ,
  { {0x753b0145, 0x00000000, 0x00000000, 0x00000000}},  //   _fauz,   ,   ,
  { {0x753b022b, 0x673c08b2, 0xd627245d, 0x00000000}},  //   _gauz, _harj, _шосе_,
  { {0xb4250355, 0x34a70256, 0x63a30056, 0x00000000}},  //   _معلو, _авто_, bonn,
  { {0x63a3028c, 0x6d4d07a5, 0x753b0091, 0x00000000}},  //   conn, _snaa, _zauz,
  { {0x673c2a48, 0x3eaa0030, 0x644200b0, 0x00000000}},  //   _marj, æbt_, lvoi,
  { {0x673c0023, 0x629a0288, 0x00000000, 0x00000000}},  //   _larj, _ixto,   ,
  { {0x64420c7e, 0x637400d4, 0x00000000, 0x00000000}},  //   nvoi, _tànd,   ,
  { {0x636f01e3, 0x65600eb6, 0x6d5f0045, 0x00000000}},  //   _lønn, _lomh, _woqa,
  { {0x5fb700b6, 0xdced0627, 0x5ec00055, 0x00000000}},  //   _שהוא_, _hlač, _শ্রে,
  { {0x81bc0089, 0x261c008e, 0x6d4d0020, 0x00000000}},  //   _spēj, dío_, _unaa,
  { {0x69d82b25, 0x63a3023f, 0xeab000a1, 0x00000000}},  // [dcd0] _éven, yonn, معہ_,
  { {0x261c008e, 0xf77313d9, 0xdced050f, 0x00000000}},  //   fío_, جار_, _mlač,
  { {0x673c3bb8, 0x63a30052, 0x636f068f, 0x00000000}},  //   _darj, vonn, _bønn,
  { {0x65600195, 0x63a31440, 0x00000000, 0x00000000}},  //   _comh, wonn,   ,
  { {0x6560002a, 0x63a300f4, 0x44290f57, 0x00000000}},  //   _domh, tonn, ïa_,
  { {0x261c008e, 0x753b00e7, 0x673c0087, 0x00000000}},  //   bío_, _wauz, _garj,
  { {0x63a3028c, 0xb5950f97, 0x261c0211, 0x00000000}},  //   ronn, _бивш, cío_,
  { {0xf2df001d, 0x63a300f4, 0xdce40107, 0x00000000}},  //   _đâu_, sonn, _ilić,
  { {0x60db01a3, 0x38693bb9, 0x63a31339, 0x00000000}},  //   rcum, nyar_, ponn,
  { {0x2608001c, 0x60db3bba, 0x8fa500e2, 0x00000000}},  //   ांची_, scum, ѓане,
  { {0x38690022, 0xa3d9013d, 0xfe710439, 0x00000000}},  //   hyar_, _ठंड_, صدد_,
  { {0xed5a1843, 0x2b460035, 0x645800b4, 0x00000000}},  //   хом_, _şoc_, ścił,
  { {0x644f0b33, 0xe5360049, 0x00000000, 0x00000000}},  //   _ácid, נטשט_,   ,
  { {0x50b80014, 0xdcef0089, 0xdee20b11, 0x00000000}},  //   _شدند_, ficē, _лоши,
  { {0x201f3bbb, 0x00000000, 0x00000000, 0x00000000}},  //   ltui_,   ,   ,
  { {0x261c0211, 0x673c3373, 0xb88600b9, 0x00000000}},  //   vío_, _sarj, hlíž,
  { {0x38690047, 0x81bc001e, 0x65600051, 0x00000000}},  // [dce0] gyar_, _spēk, _romh,
  { {0x636f068f, 0x261c004a, 0x7d040203, 0x00000000}},  //   _sønn, tío_, _hdis,
  { {0x673c0caa, 0x201f00b0, 0xeef60049, 0x00000000}},  //   _varj, htui_, רמער_,
  { {0x261c008e, 0x14c80014, 0x38693bbc, 0x00000000}},  //   río_, نهای_, byar_,
  { {0x673c397d, 0x64421339, 0x752215c7, 0x00000000}},  //   _tarj, uvoi, rfoz,
  { {0x6442110a, 0x39403bbd, 0x3a3a000a, 0x00000000}},  //   rvoi, ldis_, _kspp_,
  { {0x65600051, 0xa2260076, 0x644200b0, 0x00000000}},  //   _tomh, ارته, svoi,
  { {0xdced3bbe, 0x39400004, 0x20020f3a, 0x00000000}},  //   _plač, ndis_, škim_,
  { {0xb88601ca, 0x637400d4, 0x1f74073b, 0x00000000}},  //   blíž, _cànc, илия,
  { {0x7d043bbf, 0xdced0e0d, 0x7ccc01c5, 0x00000000}},  //   _adis, _vlač, _mērī,
  { {0x201f0011, 0x7d040288, 0x00000000, 0x00000000}},  //   atui_, _bdis,   ,
  { {0xdced01ca, 0x7bd60279, 0x7d04009d, 0x00000000}},  //   _tlač, _buyu, _cdis,
  { {0x39400066, 0x7d043416, 0x601809b2, 0x00000000}},  //   ddis_, _ddis, _роля_,
  { {0x25a61cd0, 0x7bd63bc0, 0x200b0027, 0x00000000}},  //   hool_, _duyu, ácie_,
  { {0x25a6196f, 0xb87b00c4, 0x333e00d4, 0x00000000}},  //   kool_, _ofíc, _matx_,
  { {0x79a70478, 0x00000000, 0x00000000, 0x00000000}},  //   урге,   ,   ,
  { {0x2d8b001a, 0x56f500ed, 0x7bd60022, 0x00000000}},  // [dcf0] mice_, ипаѓ, _guyu,
  { {0x2d8b0209, 0x70d1024c, 0x7c2d028d, 0x00000000}},  //   lice_, _हल्ल, _ipar,
  { {0x6dbc0046, 0x386904be, 0x394004a5, 0x00000000}},  //   _właś, syar_, bdis_,
  { {0x2d8b05c5, 0x8af8005f, 0x4a5a009b, 0x00000000}},  //   nice_, _şəxs, _סדרו,
  { {0x78fa00b6, 0xbcfb0010, 0x333e0982, 0x00000000}},  //   _בפרו, lkés, _batx_,
  { {0x27e93bc1, 0x2d8b0035, 0x68ed1968, 0x00000000}},  //   mpan_, hice_, lbad,
  { {0xe4e70099, 0xe0d10054, 0x27e90f18, 0x00000000}},  //   _бізн, يزة_, lpan_,
  { {0x25a60f07, 0x2d8b0213, 0x68ed0173, 0x00000000}},  //   cool_, jice_, nbad,
  { {0x2d8b3bc2, 0x69cf0253, 0x316d3bc3, 0x00000000}},  //   dice_, _mice, rkez_,
  { {0x7af7164f, 0x5f05025f, 0x201f0997, 0x00000000}},  //   _next, јзна, rtui_,
  { {0x6449009f, 0x201f3bc4, 0x7bd6005d, 0x00000000}},  //   _hrei, stui_, _suyu,
  { {0x69cf1237, 0x6da601fb, 0x2d8b001a, 0x00000000}},  //   _nice, рима, gice_,
  { {0x69d7009d, 0x7d040023, 0x7bd6006b, 0x00000000}},  //   _auxe, _vdis, _quyu,
  { {0x442d1a07, 0xdced002b, 0x2d8b00c4, 0x00000000}},  //   _mpe_, _vjaġ, éber_,
  { {0x2d8b091d, 0x7529003b, 0x7c2d009d, 0x00000000}},  //   bice_, _obez, _epar,
  { {0x2d8b037e, 0xf1c6009f, 0x644900f4, 0x00000000}},  //   cice_, _þátt_, _orei,
  { {0x69cf0198, 0x3940143d, 0x1786142c, 0x00000000}},  // [dd00] _dice, rdis_, агам,
  { {0x25a60190, 0x4bfb0049, 0x68ed0145, 0x00000000}},  //   wool_, _שליס, abad,
  { {0x7afc2ac3, 0x25a6267c, 0x442d01a3, 0x00000000}},  //   mart, tool_, _ape_,
  { {0x6449002a, 0x7afc0051, 0x53e6007e, 0x00000000}},  //   _brei, lart, ацка,
  { {0x64493bc5, 0x25a60004, 0x69c4010f, 0x00000000}},  //   _crei, rool_, mmie,
  { {0x200d3bc6, 0x2d8b2443, 0x69c411e8, 0x00000000}},  //   drei_, zice_, lmie,
  { {0x25a60142, 0x442d002d, 0x6449084b, 0x00000000}},  //   pool_, _epe_, _erei,
  { {0x64493bc7, 0x7afc0c35, 0x29dc3bc8, 0x00000000}},  //   _frei, hart, _mía_,
  { {0x64493bc9, 0x7afc3bca, 0x2d8b2256, 0x00000000}},  //   _grei, kart, vice_,
  { {0x2d8b0046, 0x7afc0f18, 0x69c404ca, 0x00000000}},  //   wice_, jart, hmie,
  { {0x2d8b000d, 0x7afc002d, 0x3eb802e1, 0x00000000}},  //   tice_, dart, årt_,
  { {0x7af700fa, 0x7c2d3bcb, 0x200d3285, 0x00000000}},  //   _sext, _ppar, brei_,
  { {0x2d8b06a6, 0x69cf0198, 0x69d7049a, 0x00000000}},  //   rice_, _rice, _suxe,
  { {0x7afc0051, 0x69cf01d9, 0xc90f013d, 0x00000000}},  //   gart, _sice, िल्म_,
  { {0xd90f0167, 0x69cf0197, 0x3f8c002d, 0x00000000}},  //   وید_, _pice, midu_,
  { {0x29dc0819, 0x3f8c002b, 0x69d70039, 0x00000000}},  //   _día_, lidu_, _vuxe,
  { {0x7afc0f0d, 0x68ed033b, 0x69cf0b25, 0x00000000}},  // [dd10] bart, rbad, _vice,
  { {0x7afc0682, 0x69c43bcc, 0x68ed01a2, 0x00000000}},  //   cart, amie, sbad,
  { {0x27e91896, 0x200201ae, 0x69cf0016, 0x00000000}},  //   span_, ških_, _tice,
  { {0x64493bcd, 0x27e90039, 0x1959007e, 0x00000000}},  //   _prei, ppan_, _самы_,
  { {0x798d0093, 0xf956009b, 0x61ea1e28, 0x00000000}},  //   miaw, _הסרת_, epfl,
  { {0x083a0049, 0x200d0207, 0xe299170a, 0x00000000}},  //   _געשל, vrei_, лал_,
  { {0x64490016, 0x3f8c1080, 0x00000000, 0x00000000}},  //   _wrei, didu_,   ,
  { {0x7afc2740, 0x75290036, 0x200d0d87, 0x00000000}},  //   zart, _ubez, trei_,
  { {0x4499008b, 0x25ad01d5, 0x7afc1fb8, 0x00000000}},  //   _сваю_, _ikel_, yart,
  { {0x200d064c, 0x02a70264, 0x69c40af8, 0x00000000}},  //   rrei_, _крем, zmie,
  { {0xbea5013a, 0x69c41ac4, 0x798d008a, 0x00000000}},  //   санк, ymie, kiaw,
  { {0x7afc0046, 0x200d1f95, 0xc692009b, 0x00000000}},  //   wart, prei_, לאי_,
  { {0x7afc07ef, 0x3f8c0032, 0xdd12002b, 0x00000000}},  //   tart, bidu_, _iżżi,
  { {0x3f8c016c, 0x69d80010, 0x79960036, 0x00000000}},  //   cidu_, _évek, wnyw,
  { {0x7afc023a, 0xf2d2007b, 0x5f740076, 0x00000000}},  //   rart, לעם_, _ظاهر,
  { {0x7afc0493, 0x29dc3bce, 0xe803013d, 0x00000000}},  //   sart, _vía_, _लिखा_,
  { {0x69c4001f, 0xab9a03ec, 0x00000000, 0x00000000}},  // [dd20] rmie, _مخدر_,   ,
  { {0x69c41414, 0x29dc316c, 0x7afc0023, 0x00000000}},  //   smie, _tía_, qart,
  { {0x671e006e, 0x7d770123, 0x69c40089, 0x00000000}},  //   _पाठक_, _ضمیر_, pmie,
  { {0x893606b4, 0x3f8c002b, 0x61fc0030, 0x00000000}},  //   _اعدا, zidu_, _ærli,
  { {0xd5af0076, 0x236501d9, 0x938a0a94, 0x00000000}},  //   رفه_, _bolj_, лска_,
  { {0xeb9f0030, 0x98a20006, 0xdb070023, 0x00000000}},  //   rsøg_, _sakė_, vojë,
  { {0x39420004, 0x3f8c01a3, 0x2365001a, 0x00000000}},  //   _kaks_, vidu_, _dolj_,
  { {0xf5960054, 0x7a430047, 0x61ea010f, 0x00000000}},  //   _الرج, lítá, rpfl,
  { {0x61ea010f, 0x3f8c05d2, 0x2cb2010e, 0x00000000}},  //   spfl, tidu_, _nyyd_,
  { {0x200b2b8d, 0x741300f9, 0x39420190, 0x00000000}},  //   ácia_, _روما, _laks_,
  { {0x3f8c002b, 0x2d990325, 0x39a1007f, 0x00000000}},  //   ridu_, éreo_, lėse_,
  { {0x3f8c0066, 0x39420058, 0xdb070023, 0x00000000}},  //   sidu_, _naks_, pojë,
  { {0x39a10006, 0x7a430010, 0x3f8c006c, 0x00000000}},  //   nėse_, kítá, pidu_,
  { {0xa0070025, 0x7a430010, 0x00000000, 0x00000000}},  //   _اقول_, jítá,   ,
  { {0x798d04be, 0x7de60426, 0x42db0049, 0x00000000}},  //   tiaw, _استم, רקלע,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc6f9004c, 0x798d0093, 0xa3d4006e, 0x00000000}},  // [dd30] инах_, riaw, _संग_,
  { {0x798d3bcf, 0xfb150014, 0x63740082, 0x00000000}},  //   siaw, _بودج, _sànn,
  { {0x58d5005e, 0x394201a3, 0x798d0022, 0x00000000}},  //   _монт, _faks_, piaw,
  { {0xdb0701aa, 0x2d990048, 0x39420145, 0x00000000}},  //   wojè, nnse_, _gaks_,
  { {0x68ff006b, 0x2d991946, 0x637400d4, 0x00000000}},  //   maqd, inse_, _càno,
  { {0x63aa0016, 0xc5fb13d9, 0xe87c0276, 0x00000000}},  //   gofn, _معرض_, lüşü,
  { {0xdb1e008d, 0xe3b00025, 0x2365016c, 0x00000000}},  //   _shpë, رره_, _volj_,
  { {0x212b0428, 0x3fe50805, 0x60090407, 0x00000000}},  //   ých_, ожив, аним_,
  { {0x44393bd0, 0x3dc0005b, 0x00000000, 0x00000000}},  //   _ès_, _rhiw_,   ,
  { {0x939701fa, 0x443f0127, 0x2d9900d6, 0x00000000}},  //   _اجرا, _isu_, ense_,
  { {0x3eb90036, 0x7bc703b1, 0x00000000, 0x00000000}},  //   ęsto_, dmju,   ,
  { {0x3cca09ae, 0x69d801e6, 0x443f3bd1, 0x00000000}},  //   илно_, _évei, _ksu_,
  { {0xbcfb0010, 0x7a430010, 0x00000000, 0x00000000}},  //   rkép, yítá,   ,
  { {0x6f1a001c, 0x2d990250, 0x443f3bd2, 0x00000000}},  //   cgtc, anse_, _msu_,
  { {0x09e301ee, 0x7a43140f, 0xaa430245, 0x00000000}},  //   досн, vítá, мерл,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d563bd3, 0xa76600ed, 0xeb9a0364, 0x00000000}},  // [dd40] _inya, окад, _вип_,
  { {0x47c30088, 0xeab20025, 0x39a10006, 0x00000000}},  //   дбув, _يعد_, vėse_,
  { {0x7f4300f4, 0x7c26125b, 0x394201aa, 0x00000000}},  //   _manq, ltkr, _taks_,
  { {0x7a430047, 0x6d44022b, 0x68ff006b, 0x00000000}},  //   sítá, _jaia, caqd,
  { {0x6d44022b, 0x290004f8, 0x6d560020, 0x00000000}},  //   _maia, maia_, _mnya,
  { {0x6d44006c, 0x29000032, 0x443f0146, 0x00000000}},  //   _laia, laia_, _dsu_,
  { {0x443f0006, 0x6d563bd4, 0x26d80059, 0x00000000}},  //   _esu_, _onya, _igro_,
  { {0x68e40919, 0x29003bd5, 0x443f3bd6, 0x00000000}},  //   ncid, naia_, _fsu_,
  { {0x6f1a001c, 0x7f4300f4, 0x316600c4, 0x00000000}},  //   tgtc, _banq, _vooz_,
  { {0x64400f31, 0x543b007b, 0x6d560047, 0x00000000}},  //   _ismi, _דעמא, _anya,
  { {0x44260198, 0x6d4403c7, 0x00e622a7, 0x00000000}},  //   lto_, _baia, _джен,
  { {0x65620efc, 0x44260205, 0x2d990026, 0x00000000}},  //   njoh, oto_, unse_,
  { {0x2900002d, 0x6d4400c4, 0x98b9001a, 0x00000000}},  //   daia_, _daia, _masă_,
  { {0x442602d5, 0xf413009b, 0x98b9001a, 0x00000000}},  //   ito_, ופש_, _lasă_,
  { {0x442607e2, 0x6d443af3, 0x195907d0, 0x00000000}},  //   hto_, _faia, бавы_,
  { {0x26d8027b, 0x44260480, 0x6d44002d, 0x00000000}},  //   _agro_, kto_, _gaia,
  { {0xd6db00c0, 0x47d50054, 0xe87c0180, 0x00000000}},  // [dd50] ате_, سيار, rüşü,
  { {0x442626f9, 0x443f08b3, 0x27e60051, 0x00000000}},  //   dto_, _rsu_, íona_,
  { {0x69da0047, 0xbb3a009b, 0xf99000a1, 0x00000000}},  //   ítet, _העתי, ربہ_,
  { {0xdcef0089, 0x20040089, 0x98b9001a, 0x00000000}},  //   dicī, ksmi_, _casă_,
  { {0x764e018e, 0x4426011c, 0x78bd0089, 0x00000000}},  //   _erby, gto_, _uzsv,
  { {0x93422e00, 0x83880088, 0xa3570379, 0x00000000}},  //   енше, обів_, تخصص,
  { {0x44260198, 0x443f0606, 0x6440007f, 0x00000000}},  //   ato_, _wsu_, _esmi,
  { {0xf65200b6, 0x200b00c4, 0x44263bd7, 0x00000000}},  //   _אצל_, ácio_, bto_,
  { {0x44263bd8, 0xf8b90309, 0x68fd3bd9, 0x00000000}},  //   cto_, _आरोप, _mesd,
  { {0x6d44002d, 0x657b018d, 0x7f74007e, 0x00000000}},  //   _saia, _hluh, дуюц,
  { {0x2f5401fb, 0x66050065, 0x65693bda, 0x00000000}},  //   єтьс, nshk, _koeh,
  { {0xb2ba00b6, 0xd00e00d3, 0x27e00023, 0x00000000}},  //   _המער, خلی_, yqin_,
  { {0x7f4310af, 0xe6b8007d, 0x65690277, 0x00000000}},  //   _tanq, _अर्ज, _moeh,
  { {0x7c2601d6, 0x6d440258, 0x62830c1e, 0x00000000}},  //   rtkr, _waia, ozno,
  { {0xa3d40316, 0x637d2560, 0x6f010059, 0x00000000}},  //   _संघ_, _gène, malc,
  { {0xb87b0b32, 0x6d560020, 0x6f013bdb, 0x00000000}},  //   _efím, _unya, lalc,
  { {0x68fd08ec, 0x442600d6, 0x68e422e4, 0x00000000}},  // [dd60] _desd, xto_, rcid,
  { {0x6f0100ca, 0x68e42838, 0x2900002d, 0x00000000}},  //   nalc, scid, saia_,
  { {0x44260066, 0x657b3bdc, 0x68e4012d, 0x00000000}},  //   wto_, _bluh, pcid,
  { {0x4426051b, 0xe45a0088, 0x0566005e, 0x00000000}},  //   tto_, йже_, явен,
  { {0x44263bdd, 0x6f010059, 0x69de0020, 0x00000000}},  //   uto_, kalc, _hupe,
  { {0x69de000b, 0x6f0101d9, 0x7afe0065, 0x00000000}},  //   _kupe, jalc, _jept,
  { {0x442605d3, 0x877b007b, 0xdb1e029d, 0x00000000}},  //   sto_, _פאלי, _hipó,
  { {0x44260211, 0x1543012b, 0x7afe0091, 0x00000000}},  //   pto_, _песм, _lept,
  { {0x69de016c, 0x60f7008b, 0x6f01005b, 0x00000000}},  //   _lupe, чныя_, falc,
  { {0x43860188, 0x7afe01aa, 0x32460072, 0x00000000}},  //   _علاق, _nept, _незг,
  { {0x62830046, 0x69de02eb, 0x00000000, 0x00000000}},  //   czno, _nupe,   ,
  { {0x069700b6, 0x00000000, 0x00000000, 0x00000000}},  //   לדים_,   ,   ,
  { {0x0cab005e, 0x6f010d48, 0x7c3d00bb, 0x00000000}},  //   стни_, balc, uwsr,
  { {0x9a87092b, 0x6f010375, 0x7f580920, 0x00000000}},  //   публ, calc, _факс_,
  { {0x27e6002a, 0x69de3bde, 0x7afe00ab, 0x00000000}},  //   íonn_, _cupe, _dept,
  { {0x3197001a, 0x3da4007e, 0x69de016e, 0x00000000}},  //   tăzi_, _прыб, _dupe,
  { {0x52d00044, 0x65691607, 0x69de0270, 0x00000000}},  // [dd70] _স্মৃ, _roeh, _eupe,
  { {0x6569023a, 0x31970035, 0x657b049c, 0x00000000}},  //   _soeh, răzi_, _sluh,
  { {0xcb12019b, 0x6569000a, 0x636f0030, 0x00000000}},  //   _בלי_, _poeh, _mønt,
  { {0x66050065, 0x7afe00b9, 0x6f0100ca, 0x00000000}},  //   rshk, _zept, zalc,
  { {0xd006039d, 0x395900c4, 0xf8b10167, 0x00000000}},  //   _جل_, _inss_, _شکر_,
  { {0x3949143d, 0x8c1c019b, 0xdb1e00d4, 0x00000000}},  //   ldas_, מודי, _hipò,
  { {0x6f0101d9, 0x7d0d014a, 0x394910fd, 0x00000000}},  //   valc, _odas, odas_,
  { {0x7d0d0023, 0x6f010036, 0xc69200a0, 0x00000000}},  //   _ndas, walc, _סאן_,
  { {0x62830047, 0x3949183d, 0x7bdf0068, 0x00000000}},  //   szno, idas_, _nuqu,
  { {0x8e09022a, 0x7d0d019a, 0xdb1c080a, 0x00000000}},  //   онов_, _adas, områ,
  { {0x7afe0129, 0x6da603f3, 0x6f010059, 0x00000000}},  //   _rept, дина, ralc,
  { {0xcb0900b6, 0x69de00b0, 0xed5a012d, 0x00000000}},  //   _כל_, _rupe, цом_,
  { {0x7bdf06c2, 0x394907c3, 0x671e0164, 0x00000000}},  //   _cuqu, ddas_, _पालक_,
  { {0x7d0d0004, 0x39490211, 0x7bdf088a, 0x00000000}},  //   _edas, edas_, _duqu,
  { {0x636f0190, 0x00000000, 0x00000000, 0x00000000}},  //   _høns,   ,   ,
  { {0x636f0030, 0x7bd700d4, 0x00000000, 0x00000000}},  //   _køns, _eixu,   ,
  { {0xdb1e0129, 0x7bd73bdf, 0xb95b0082, 0x00000000}},  // [dd80] _dipò, _fixu, _thìn,
  { {0xdced0091, 0x39493be0, 0x636f01e3, 0x00000000}},  //   _plać, adas_, _møns,
  { {0x636f0190, 0xeb9f0374, 0x2b5a00fa, 0x00000000}},  //   _løns, prør_, _inpc_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xeaaf00a1, 0xd467003b, 0x00000000, 0x00000000}},  //   _مٹی_, мице_,   ,
  { {0x533301fc, 0x68f60030, 0x00000000, 0x00000000}},  //   вешт, lbyd,   ,
  { {0xd2500426, 0x69d80010, 0x00000000, 0x00000000}},  //   انب_, _éves,   ,
  { {0x637400d4, 0x636f0146, 0xe97b0049, 0x00000000}},  //   _màni, _bøns, ַניש,
  { {0x637400d4, 0x03260545, 0x00000000, 0x00000000}},  //   _làni, _одан,   ,
  { {0x3e4c00b9, 0x39490006, 0x637d00d4, 0x00000000}},  //   _pět_, zdas_, _vènc,
  { {0x7bdf00f6, 0x4e8a007c, 0x7c36007f, 0x00000000}},  //   _suqu, ющим_, _apyr,
  { {0xdb0701dc, 0x2b5a0035, 0x636f0146, 0x00000000}},  //   rojí, _anpc_, _føns,
  { {0x3da4008b, 0x403400c0, 0x68f62dd7, 0x00000000}},  //   трэб, _челс, dbyd,
  { {0xdb1e01aa, 0x2b5a00fa, 0x60c20232, 0x00000000}},  //   _sipò, _cnpc_, _izom,
  { {0x7e86013e, 0xdb1e000a, 0x00000000, 0x00000000}},  //   úspě, _pipò,   ,
  { {0xf770007a, 0xbda70025, 0x7d0d0dfc, 0x00000000}},  //   یال_, _تحتو, _udas,
  { {0xe8940057, 0x39491b18, 0x2486016c, 0x00000000}},  // [dd90] вать, rdas_, jzom_,
  { {0x394900e7, 0x2a6e0023, 0xbc380380, 0x00000000}},  //   sdas_, ëmbë_, _آسيا_,
  { {0xb6070082, 0x68f600d9, 0x261a013d, 0x00000000}},  //   _giớ, bbyd, मूली_,
  { {0xcdd90049, 0x2a76009b, 0x00000000, 0x00000000}},  //   פֿער, _נערך_,   ,
  { {0xc91600b6, 0xb60701d5, 0x69cd0190, 0x00000000}},  //   _אחרת_, _suġġ, mmae,
  { {0x637d000a, 0x8c1c0097, 0xcc78009b, 0x00000000}},  //   _bèna, קווי, ועדה_,
  { {0xd66901b7, 0xf5270849, 0x60c20258, 0x00000000}},  //   _عمرو_, _офан, _azom,
  { {0x3f9e0089, 0x7dde0089, 0x69cd005b, 0x00000000}},  //   entu_, _mūsd, nmae,
  { {0x4f952cf1, 0x659402be, 0xd00e006d, 0x00000000}},  //   ерну, _рату, ملي_,
  { {0x9e65017f, 0xd3d80014, 0x69cd1575, 0x00000000}},  //   евод, _قبلا_, hmae,
  { {0x7c36000c, 0xc7b2009b, 0x03d600a0, 0x00000000}},  //   _spyr, רבי_, _נועם_,
  { {0xf2df001d, 0xf67a0049, 0x636f0056, 0x00000000}},  //   _đây_, פארמ, _tøns,
  { {0x61e11273, 0x636f06ec, 0x00000000, 0x00000000}},  //   _hull, _uøns,   ,
  { {0x61e11355, 0x69c6008d, 0x2d820065, 0x00000000}},  //   _kull, _shke, shke_,
  { {0x61e106b2, 0xfaa3007e, 0xfbc300e2, 0x00000000}},  //   _jull, гаро, убро,
  { {0x61e108b2, 0xe9d700d7, 0xa967017f, 0x00000000}},  //   _mull, екс_, ниса_,
  { {0x7d061cf7, 0x61e100bb, 0x68f6022c, 0x00000000}},  // [dda0] maks, _lull, rbyd,
  { {0x7d060149, 0x4a460088, 0x68f60abb, 0x00000000}},  //   laks, _знов, sbyd,
  { {0x61e10207, 0x00000000, 0x00000000, 0x00000000}},  //   _null,   ,   ,
  { {0x84e601e1, 0xee490011, 0x7d060052, 0x00000000}},  //   ходж, _mẽ_, naks,
  { {0xee490011, 0xf9f20044, 0x61e1004a, 0x00000000}},  //   _lẽ_, _জটিল_, _aull,
  { {0x61e123e9, 0x7d063be1, 0xa2940245, 0x00000000}},  //   _bull, haks, калі,
  { {0x61e122d8, 0x60c20047, 0x2d803be2, 0x00000000}},  //   _cull, _szom, _olie_,
  { {0x61e10016, 0x7d063be3, 0x657931e9, 0x00000000}},  //   _dull, jaks, ckwh,
  { {0x7d0610f8, 0x290204eb, 0x41c30025, 0x00000000}},  //   daks, _meka_, دقيق,
  { {0x61e103fa, 0x75220047, 0x2fd8000c, 0x00000000}},  //   _full, lgoz, örg_,
  { {0x61e1000c, 0x3eb8137b, 0xe0da00ed, 0x00000000}},  //   _gull, ært_, _еве_,
  { {0x7522000b, 0x29020119, 0x2d800026, 0x00000000}},  //   ngoz, _neka_, _clie_,
  { {0x61e102ae, 0x79840020, 0xdcbb005e, 0x00000000}},  //   _zull, dhiw, ящо_,
  { {0x2d80097e, 0x661e3be4, 0x00000000, 0x00000000}},  //   _elie_, kupk,   ,
  { {0x61e1049a, 0x6d96001e, 0xf9c70ae0, 0x00000000}},  //   _xull, mšan, ещан,
  { {0xdd9101ef, 0x2902016c, 0xf773007a, 0x00000000}},  //   _خوب_, _ceka_, گار_,
  { {0x69cd0030, 0x3dc90058, 0x00000000, 0x00000000}},  // [ddb0] rmae, _ihaw_,   ,
  { {0xf773002c, 0x6da40107, 0x200b0142, 0x00000000}},  //   دار_, nđan, ácii_,
  { {0xcf93007b, 0x57a401fc, 0x00000000, 0x00000000}},  //   נטע_, ушта,   ,
  { {0x79841bbd, 0x00000000, 0x00000000, 0x00000000}},  //   chiw,   ,   ,
  { {0x61e10198, 0x04453be5, 0x6d9618c5, 0x00000000}},  //   _sull, телн, kšan,
  { {0x6d960059, 0x2902014a, 0x7d06277c, 0x00000000}},  //   jšan, _zeka_, zaks,
  { {0x85bb05f3, 0x7d0601aa, 0x61e1006b, 0x00000000}},  //   _فارس_, yaks, _qull,
  { {0x205501f9, 0x61e10f7b, 0xee490011, 0x00000000}},  //   втор, _vull, _rẽ_,
  { {0xee4900ad, 0x7d0600b0, 0x61e10270, 0x00000000}},  //   _sẽ_, vaks, _wull,
  { {0x61e1021e, 0x76550046, 0x6d960089, 0x00000000}},  //   _tull, _krzy, gšan,
  { {0x7d060004, 0xbea5003b, 0x9f0400a1, 0x00000000}},  //   taks, танк, دوپو,
  { {0xed5703e8, 0xee490011, 0x82340025, 0x00000000}},  //   вою_, _vẽ_, _حركا,
  { {0x7d06001e, 0x290226bd, 0xfebb00a6, 0x00000000}},  //   raks, _reka_, _کاشت_,
  { {0x29020205, 0xfaa6279d, 0x00000000, 0x00000000}},  //   _seka_, ваго,   ,
  { {0x7bce0065, 0x79843be6, 0x290201a3, 0x00000000}},  //   rmbu, thiw, _peka_,
  { {0x6f0300ab, 0x00000000, 0x00000000, 0x00000000}},  //   _henc,   ,   ,
  { {0x1b170055, 0x6f0304cb, 0xe8be0061, 0x00000000}},  // [ddc0] দ্ধে_, _kenc, ्धेच,
  { {0x7d04010f, 0x79840020, 0x29020020, 0x00000000}},  //   _heis, shiw, _weka_,
  { {0x6f03020c, 0x7d04010a, 0x2902011c, 0x00000000}},  //   _menc, _keis, _teka_,
  { {0x7de10089, 0x7d040032, 0x00000000, 0x00000000}},  //   _cēsi, _jeis,   ,
  { {0x7d04001f, 0x394000f6, 0xa82300a1, 0x00000000}},  //   _meis, meis_, _نکلن,
  { {0x66e6098c, 0xf65100a1, 0x93b3007e, 0x00000000}},  //   _јова, جئے_, абіц,
  { {0xcb13009b, 0x76550036, 0x00000000, 0x00000000}},  //   בלו_, _grzy,   ,
  { {0x3940004a, 0x3253005e, 0xd259007e, 0x00000000}},  //   neis_, рвър, эці_,
  { {0xf993019b, 0x6f031c57, 0x637d00f6, 0x00000000}},  //   ירה_, _benc, _gèno,
  { {0xd378037e, 0x7f4a006b, 0x39400145, 0x00000000}},  //   _biće_, _qafq, heis_,
  { {0x7d04001f, 0x8266007a, 0x6d960089, 0x00000000}},  //   _beis, _جهان, ršan,
  { {0xac190805, 0x7d04016d, 0x6146012b, 0x00000000}},  //   ному_, _ceis, _једа,
  { {0x6d960089, 0x7d040051, 0x3940008e, 0x00000000}},  //   pšan, _deis, deis_,
  { {0x6f033be7, 0x394b00f4, 0xd378016c, 0x00000000}},  //   _genc, _sacs_, _fiće_,
  { {0x9e340057, 0x2e4a005e, 0x2d99009d, 0x00000000}},  //   _сейч, _цяло_, éres_,
  { {0x7d040090, 0x6f030095, 0x3dc90058, 0x00000000}},  //   _geis, _zenc, _uhaw_,
  { {0x2d99061f, 0x08550a78, 0x6d5f01d5, 0x00000000}},  // [ddd0] mise_, ываю, _inqa,
  { {0x76550df0, 0x6d4d011c, 0x7d0400bb, 0x00000000}},  //   _przy, _haaa, _zeis,
  { {0x3940008e, 0x2d99009d, 0x394b0bb4, 0x00000000}},  //   beis_, oise_, _tacs_,
  { {0x2d990051, 0xa9790049, 0x6d4f3b8c, 0x00000000}},  //   nise_, _נאָכ, ndca,
  { {0x6d4d006a, 0x7c2d0066, 0xd91a00b3, 0x00000000}},  //   _maaa, _jqar, _אורל,
  { {0x76550036, 0x69dd0129, 0x6d4d3756, 0x00000000}},  //   _trzy, _hise, _laaa,
  { {0x69dd11b7, 0x6f033be8, 0xdb07000c, 0x00000000}},  //   _kise, _renc, lljó,
  { {0x6f030211, 0x68ed0181, 0x6d4d011c, 0x00000000}},  //   _senc, ncad, _naaa,
  { {0x2d99006c, 0x6f03020c, 0x3f850016, 0x00000000}},  //   dise_, _penc, thlu_,
  { {0x7d040004, 0x69dd0563, 0x6d4d3be9, 0x00000000}},  //   _seis, _lise, _aaaa,
  { {0x6f030181, 0x69dd3bea, 0x7d04001a, 0x00000000}},  //   _venc, _oise, _peis,
  { {0x69dd01d9, 0x63ad002a, 0x7de800b9, 0x00000000}},  //   _nise, éanf, _těsn,
  { {0x394002d5, 0x7d0406e8, 0x2eee3beb, 0x00000000}},  //   veis_, _veis, _ffff_,
  { {0xa09a012f, 0x7d04001f, 0x69dd0051, 0x00000000}},  //   _אינט, _weis, _aise,
  { {0x7d0422a6, 0x69dd0e7d, 0x81e50044, 0x00000000}},  //   _teis, _bise, বীর_,
  { {0x2d991c28, 0xd24f007e, 0x69dd1059, 0x00000000}},  //   cise_, сцi_, _cise,
  { {0x69dd033b, 0x39400dcc, 0x200d0181, 0x00000000}},  // [dde0] _dise, reis_, nsei_,
  { {0x69dd0270, 0x3940006c, 0x2909016e, 0x00000000}},  //   _eise, seis_, aaaa_,
  { {0x4b7b0049, 0x69dd0023, 0xd245025a, 0x00000000}},  //   _נאטו, _fise, _بچ_,
  { {0xc486007c, 0x05ba0879, 0x1a9b0049, 0x00000000}},  //   ллек, ردات_, _טייע,
  { {0x7bde0ac2, 0x7f410065, 0x6e213bec, 0x00000000}},  //   _kipu, kelq, hulb,
  { {0x66e3008b, 0x987b0049, 0x2d990023, 0x00000000}},  //   _гора, _טאכט, zise_,
  { {0x200f00ea, 0xfe6701af, 0x64492005, 0x00000000}},  //   _avgi_, _اد_, _esei,
  { {0x7bde011c, 0x63a300e0, 0xeb9f0056, 0x00000000}},  //   _lipu, annn, tsøk_,
  { {0x6d961322, 0x2eee1de2, 0x65600051, 0x00000000}},  //   ršal, _pfff_, _inmh,
  { {0x1e34007e, 0xdb0e000c, 0x6d4d34d6, 0x00000000}},  //   аноў, albú, _saaa,
  { {0x2d99006c, 0x6d4d1a7e, 0x7c2d0065, 0x00000000}},  //   tise_, _paaa, _sqar,
  { {0x2d99018d, 0x7bde0032, 0xf04400a1, 0x00000000}},  //   uise_, _aipu, _نعتی,
  { {0x2d99008d, 0x69dd0198, 0x7bde0032, 0x00000000}},  //   rise_, _rise, _bipu,
  { {0x69dd0004, 0x2d990065, 0x6d4d011c, 0x00000000}},  //   _sise, sise_, _waaa,
  { {0xf0b0026c, 0x69dd037e, 0x7bde3553, 0x00000000}},  //   _دیکھ, _pise, _dipu,
  { {0xd5a4026c, 0x6d4d3bed, 0x2d990065, 0x00000000}},  //   _رہ_, _uaaa, qise_,
  { {0x68ed0977, 0x69dd0292, 0xdb070052, 0x00000000}},  // [ddf0] rcad, _vise, tojä,
  { {0x68ed0219, 0xe8ff028c, 0x7bde022b, 0x00000000}},  //   scad, _août_, _gipu,
  { {0x78bd01c3, 0xdced04eb, 0x00000000, 0x00000000}},  //   _wysv, _hlađ,   ,
  { {0xe8ff00f4, 0x54553bee, 0x39a10006, 0x00000000}},  //   _coût_, ивет, kėsi_,
  { {0x23290331, 0x88990049, 0x2458007e, 0x00000000}},  //   воли_, _סבֿי, лаць_,
  { {0xe2990517, 0xdced0091, 0x2215034b, 0x00000000}},  //   кал_, _mlađ, афир,
  { {0x442f06be, 0x45d5007c, 0x00000000, 0x00000000}},  //   stg_, _вовс,   ,
  { {0x200d0004, 0x644931f0, 0xe8ff00f4, 0x00000000}},  //   tsei_, _tsei, _goût_,
  { {0x6449021e, 0x6006007e, 0x39a10006, 0x00000000}},  //   _usei, аным_, gėsi_,
  { {0x38691052, 0x200d0035, 0xcf5929a1, 0x00000000}},  //   ixar_, rsei_, трич_,
  { {0x02a71123, 0x8d662e54, 0x200d0181, 0x00000000}},  //   _срам, авне, ssei_,
  { {0x7bde0329, 0x200d0035, 0x00000000, 0x00000000}},  //   _sipu, psei_,   ,
  { {0x0c230ae0, 0xd378016c, 0x26050061, 0x00000000}},  //   омян, _hića_, हीती_,
  { {0xc3320049, 0x7df30035, 0x00000000, 0x00000000}},  //   ֿון_, _răsf,   ,
  { {0x7bde0883, 0xaa46007c, 0xa928013e, 0x00000000}},  //   _vipu, шевл, _nežá,
  { {0xd3780521, 0x316d11e1, 0x00000000, 0x00000000}},  //   _mića_, njez_,   ,
  { {0x8c4607ca, 0x7bde0a07, 0x00000000, 0x00000000}},  // [de00] _тепе, _tipu,   ,
  { {0xf77f00f6, 0x6abe00d9, 0x00000000, 0x00000000}},  //   _puça_, _typf,   ,
  { {0xdd8f007a, 0xe9df13f3, 0x81ab0044, 0x00000000}},  //   _روی_, _fiú_, _গঠন_,
  { {0x2bb403d7, 0x14c80014, 0x637400d4, 0x00000000}},  //   ंकवा, ههای_, _rànq,
  { {0xd4030242, 0x934600ed, 0x00000000, 0x00000000}},  //   оящи, инде,   ,
  { {0xd3780091, 0xd3b70088, 0x00000000, 0x00000000}},  //   _bića_, алії_,   ,
  { {0xe81e013d, 0x6da4012d, 0x75d60379, 0x00000000}},  //   यंका_, rđaj, _نيسا,
  { {0x3952125e, 0x1259009e, 0x59b60061, 0x00000000}},  //   ndys_, اثوں_, ंविर,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x1be10316, 0xd378012d, 0x39520052, 0x00000000}},  //   _गूगल_, _fića_, hdys_,
  { {0x63b80062, 0x4f67007e, 0xdced04eb, 0x00000000}},  //   movn, ршым_, _slađ,
  { {0x63b801d9, 0x25a6018e, 0xed65006b, 0x00000000}},  //   lovn, nnol_, _şöbə_,
  { {0x7d160016, 0x61e8032e, 0x38690066, 0x00000000}},  //   _ddys, _hudl, xxar_,
  { {0x63b800ee, 0x2cad01d5, 0x00000000, 0x00000000}},  //   novn, ħed_,   ,
  { {0xb34502d5, 0x224c281f, 0x09071aca, 0x00000000}},  //   leçã, _jsdk_, ичам,
  { {0x7de1001e, 0x0b270044, 0x61e80066, 0x00000000}},  //   _vēst, য়েল_, _mudl,
  { {0x63b801d9, 0x26c52086, 0x6b9c0218, 0x00000000}},  // [de10] kovn, _šlo_, birg,
  { {0x25a60016, 0x38690129, 0x63b80161, 0x00000000}},  //   enol_, rxar_, jovn,
  { {0x63b809fc, 0xd6db0265, 0x61e8013e, 0x00000000}},  //   dovn, тта_, _nudl,
  { {0xe945007a, 0x25a600f4, 0x3ed90049, 0x00000000}},  //   _اردی, gnol_, אַנא,
  { {0xb3450181, 0x00000000, 0x00000000, 0x00000000}},  //   jeçã,   ,   ,
  { {0x63b807a0, 0x61e800e0, 0xd3780091, 0x00000000}},  //   govn, _budl, _pića_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x016501f9, 0x61e83bef, 0x25a606c0, 0x00000000}},  //   скио, _dudl, cnol_,
  { {0x637d00f6, 0xdb0e0010, 0x68fb010e, 0x00000000}},  //   _lèni, őkés, _õudu,
  { {0x23740054, 0x63b80428, 0x443f01d1, 0x00000000}},  //   _والح, covn, _ipu_,
  { {0x1d0a00e3, 0x61e818bb, 0x69cf0087, 0x00000000}},  //   лени_, _gudl, _ohce,
  { {0x645b0100, 0x443f023a, 0xf77f00c4, 0x00000000}},  //   _krui, _kpu_, _ouço_,
  { {0xb34500c4, 0x753b0020, 0x443f0093, 0x00000000}},  //   ceçã, _mbuz, _jpu_,
  { {0x443f00fa, 0x005600b3, 0x7f850014, 0x00000000}},  //   _mpu_, _לשנת_, _دلتن,
  { {0x25a6018e, 0x7df3001a, 0xed5a3bf0, 0x00000000}},  //   ynol_, _băse, _бой_,
  { {0x69cf3bf1, 0xfaa3007e, 0x6b9c0006, 0x00000000}},  //   _chce, часо, sirg,
  { {0x6d4614d2, 0x8d7600e9, 0x25a60082, 0x00000000}},  // [de20] meka, _ناکا, vnol_,
  { {0x4b260106, 0x6d461aae, 0x753b3bf2, 0x00000000}},  //   _умов, leka, _abuz,
  { {0xd946007c, 0xe61a1ab7, 0x443f0052, 0x00000000}},  //   _лени, уде_, _apu_,
  { {0x645b046a, 0x7df3001a, 0x443f0085, 0x00000000}},  //   _brui, _găse, _bpu_,
  { {0x29002ca2, 0x443f0011, 0x63b80cce, 0x00000000}},  //   mbia_, _cpu_, tovn,
  { {0x645b07a9, 0x26050061, 0x443f3bf3, 0x00000000}},  //   _drui, हीही_, _dpu_,
  { {0x63b80428, 0x645b00b5, 0x443f0085, 0x00000000}},  //   rovn, _erui, _epu_,
  { {0x6d46037e, 0x63b80a0f, 0xb3450181, 0x00000000}},  //   jeka, sovn, teçã,
  { {0x6d460056, 0x645b00d4, 0xc953009b, 0x00000000}},  //   deka, _grui, למה_,
  { {0x69c4001f, 0xb3450181, 0x44262301, 0x00000000}},  //   hlie, reçã, muo_,
  { {0xdceb0627, 0x69c40f81, 0xc106006d, 0x00000000}},  //   žičn, klie, _هواي,
  { {0x6d46006c, 0xd00a0cb3, 0x00000000, 0x00000000}},  //   geka, _беде_,   ,
  { {0x44260119, 0x69c41354, 0x637d00d4, 0x00000000}},  //   nuo_, dlie, _sèni,
  { {0x69c40ebd, 0x2d8b012d, 0x3e5700e5, 0x00000000}},  //   elie, shce_, _făt_,
  { {0x3f9e002b, 0x98b001d5, 0x6d463bf4, 0x00000000}},  //   mitu_, _ħaġa_, beka,
  { {0x69c40198, 0x6d4632a2, 0xada40098, 0x00000000}},  //   glie, ceka, _најл,
  { {0x61e200c4, 0x44260045, 0x00000000, 0x00000000}},  // [de30] _miol, juo_,   ,
  { {0x60c200d9, 0x443f0460, 0x61e2185c, 0x00000000}},  //   _myom, _rpu_, _liol,
  { {0x69c40168, 0x29000207, 0x443f12dd, 0x00000000}},  //   blie, bbia_, _spu_,
  { {0xd6d8058f, 0x3f9e022b, 0x645b3bf5, 0x00000000}},  //   сту_, hitu_, _prui,
  { {0x60c20047, 0x44263bf6, 0x3f9e002d, 0x00000000}},  //   _nyom, guo_, kitu_,
  { {0x6d46195b, 0xe81e00e8, 0xcec300b9, 0x00000000}},  //   zeka, _पिता_, _jiří_,
  { {0x3f9e36ee, 0x2d8205b7, 0x1dc90061, 0x00000000}},  //   ditu_, ykke_, रतात,
  { {0x753b0061, 0xa2d501f5, 0x290b2178, 0x00000000}},  //   _ubuz, येष्, _jeca_,
  { {0x61e20016, 0x44261862, 0xf1b90142, 0x00000000}},  //   _diol, cuo_, roš_,
  { {0xee390265, 0x3f9e3bf7, 0x69c43bf8, 0x00000000}},  //   ано_, gitu_, zlie,
  { {0x27e30662, 0x6d46022b, 0xa1190380, 0x00000000}},  //   _mijn_, teka, _نقاط_,
  { {0x68e2010a, 0x27e300b5, 0x61e20048, 0x00000000}},  //   žodi, _lijn_, _giol,
  { {0x6d46000b, 0x3f9e08f0, 0xef0e0175, 0x00000000}},  //   reka, bitu_, _ом_,
  { {0x6d4603f2, 0x61e23bf9, 0x29190066, 0x00000000}},  //   seka, _ziol, _adsa_,
  { {0x290b0b32, 0x69c401c5, 0x25bf014a, 0x00000000}},  //   _beca_, tlie, _okul_,
  { {0xddc301e0, 0x69c404a5, 0x798d26c3, 0x00000000}},  //   _общи, ulie, ghaw,
  { {0x29000065, 0x290b012b, 0x92c50044, 0x00000000}},  // [de40] rbia_, _deca_, _এলো_,
  { {0x69c427dc, 0x29002048, 0x29190058, 0x00000000}},  //   slie, sbia_, _edsa_,
  { {0x69c40038, 0xfa6a0930, 0x00000000, 0x00000000}},  //   plie, _танк_,   ,
  { {0x2e3a007b, 0x4426000b, 0xe45a0175, 0x00000000}},  //   יגענ, tuo_, иже_,
  { {0x27e300b5, 0x61e200bb, 0x00000000, 0x00000000}},  //   _fijn_, _riol,   ,
  { {0x44260afb, 0xd7c50061, 0x925a0025, 0x00000000}},  //   ruo_, वतःच, لشعر_,
  { {0x63ad0195, 0x61e20058, 0x4426007f, 0x00000000}},  //   éana, _piol, suo_,
  { {0x27e30662, 0x44263bfa, 0xeb9f0056, 0x00000000}},  //   _zijn_, puo_, nsør_,
  { {0x442600d4, 0x3f9e002d, 0x232a0893, 0x00000000}},  //   quo_, titu_, _вози_,
  { {0x60c2000b, 0xdfd00379, 0x2d8901d6, 0x00000000}},  //   _vyom, عيد_, _slae_,
  { {0x0dcb00ed, 0xddc90006, 0x798d04d2, 0x00000000}},  //   иуми_, rydž, yhaw,
  { {0x3f9e16f0, 0xc05a03e8, 0x200600b4, 0x00000000}},  //   situ_, _вік_, _twoi_,
  { {0x290b0724, 0x160a0061, 0x2d8901d6, 0x00000000}},  //   _reca_, हीतर_, _vlae_,
  { {0x33f000d4, 0x00000000, 0x00000000, 0x00000000}},  //   _màx_,   ,   ,
  { {0xd3780091, 0x3f9c3bfb, 0x27e300bb, 0x00000000}},  //   _moć_, _imvu_, _rijn_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x290b3bfc, 0x27e300b5, 0x798d0145, 0x00000000}},  // [de50] _veca_, _pijn_, rhaw,
  { {0xd3780091, 0x798d0020, 0x25bf0058, 0x00000000}},  //   _noć_, shaw, _skul_,
  { {0x6e2801d9, 0x7d0d04be, 0x6d96016e, 0x00000000}},  //   nudb, _keas, ršav,
  { {0xb8d10044, 0x7bc70203, 0xa927006d, 0x00000000}},  //   _ওর_, llju, _بعده,
  { {0x7d0d21f3, 0xdb1500b9, 0x39492870, 0x00000000}},  //   _meas, hozí, meas_,
  { {0x7d0d21f3, 0xceb8010a, 0x394916b8, 0x00000000}},  //   _leas, ngęs_, leas_,
  { {0xa91b000c, 0xb5a70242, 0x170800a1, 0x00000000}},  //   _alþi, _драй, _ذہنی_,
  { {0x39490211, 0x7d0d0035, 0x60090931, 0x00000000}},  //   neas_, _neas, бним_,
  { {0x7bc70295, 0x3dd2018e, 0x00000000, 0x00000000}},  //   klju, _rhyw_,   ,
  { {0x3949002a, 0x7bc70e0f, 0x637d00d4, 0x00000000}},  //   heas_, jlju, _cènt,
  { {0x7d0d0f54, 0x39493bfd, 0xed5a0517, 0x00000000}},  //   _beas, keas_, бон_,
  { {0x7d0d189d, 0x523a0049, 0x00000000, 0x00000000}},  //   _ceas, _לײענ,   ,
  { {0xd1b800a2, 0x7d0d094e, 0x39490051, 0x00000000}},  //   _بالا_, _deas, deas_,
  { {0xff5106c6, 0x70520025, 0xdb1c0023, 0x00000000}},  //   _سخت_, _أنوا, morë,
  { {0xa96a0893, 0x672100b0, 0x3ced016e, 0x00000000}},  //   бива_, _öljy, ževa_,
  { {0x7d0d0168, 0xfe700025, 0xda1d0061, 0x00000000}},  //   _geas, _جده_, _फिरत_,
  { {0xa2a202d2, 0xdb1c0065, 0x6d560022, 0x00000000}},  // [de60] _केन्, norë, _iaya,
  { {0x6d5612d9, 0x7af70197, 0x47c310d6, 0x00000000}},  //   _haya, _gfxt, ебув,
  { {0x394900c4, 0xf62305a5, 0x6d563bfe, 0x00000000}},  //   beas_, едхо, _kaya,
  { {0x6d560169, 0x63ad0051, 0x39490325, 0x00000000}},  //   _jaya, éann, ceas_,
  { {0x6d560760, 0x2912011f, 0xe4e301ff, 0x00000000}},  //   _maya, maya_, нішн,
  { {0x2912000b, 0x6d56020c, 0xcc3b0049, 0x00000000}},  //   laya_, _laya, מענט,
  { {0xe1d8007e, 0xe6430256, 0xed61013e, 0x00000000}},  //   одкі_, _перп, ížky_,
  { {0x7de80224, 0x6d561ebf, 0x29120890, 0x00000000}},  //   _měst, _naya, naya_,
  { {0x7d0d0038, 0x00000000, 0x00000000, 0x00000000}},  //   _reas,   ,   ,
  { {0x7d0d0531, 0x291204cb, 0xe7be0164, 0x00000000}},  //   _seas, haya_, ्तिप,
  { {0x6d5603b0, 0x29120453, 0x7bc70091, 0x00000000}},  //   _baya, kaya_, vlju,
  { {0x291204cb, 0x6e282311, 0x6d560145, 0x00000000}},  //   jaya_, rudb, _caya,
  { {0x6d56038c, 0x29120149, 0x515b00a0, 0x00000000}},  //   _daya, daya_, _לכאו,
  { {0x629c000c, 0x7d0d14f9, 0x00000000, 0x00000000}},  //   _þros, _weas,   ,
  { {0x7d0d0051, 0x39490051, 0x29120276, 0x00000000}},  //   _teas, teas_, faya_,
  { {0x2912011c, 0x6d560058, 0x7bc700f8, 0x00000000}},  //   gaya_, _gaya, slju,
  { {0x394910c9, 0x7bc70091, 0x210000d0, 0x00000000}},  // [de70] reas_, plju, mčič_,
  { {0x39493bff, 0x04fe0044, 0x00000000, 0x00000000}},  //   seas_, ুলোর_,   ,
  { {0x29120390, 0x6d560169, 0x3949008e, 0x00000000}},  //   baya_, _yaya, peas_,
  { {0x7ddf008f, 0x2100221d, 0x29123667, 0x00000000}},  //   _būsi, nčič_, caya_,
  { {0x63ad2656, 0xf99f0173, 0x00000000, 0x00000000}},  //   éano, _imè_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x91fc0089, 0x00000000, 0x00000000, 0x00000000}},  //   _arāb,   ,   ,
  { {0x806501e0, 0xdb1c008d, 0x26d10026, 0x00000000}},  //   движ, torë, _izzo_,
  { {0x3494008b, 0x6d56004a, 0xdb1c00f6, 0x00000000}},  //   _затр, _raya, borè,
  { {0x6d560127, 0x29120279, 0xdb1c0065, 0x00000000}},  //   _saya, zaya_, rorë,
  { {0x2912005f, 0x63a33c00, 0xdb1c0023, 0x00000000}},  //   yaya_, minn, sorë,
  { {0x63a30004, 0x865a0049, 0x656901f3, 0x00000000}},  //   linn, קדרי, _jneh,
  { {0x62832da3, 0x6d563c01, 0x29120279, 0x00000000}},  //   lyno, _vaya, vaya_,
  { {0xa3cd02d2, 0x63a3000c, 0x6d5601a3, 0x00000000}},  //   रति_, ninn, _waya,
  { {0x6d5616c3, 0x29123c02, 0x656900d2, 0x00000000}},  //   _taya, taya_, _oneh,
  { {0x63a303b6, 0xb33c0066, 0x2c170061, 0x00000000}},  //   hinn, _imħe, _तिचं_,
  { {0xb9060365, 0x63a303fa, 0x29122b16, 0x00000000}},  // [de80] _पण_, kinn, raya_,
  { {0x29123c03, 0x65692224, 0x7de8013e, 0x00000000}},  //   saya_, _aneh, _těst,
  { {0x63a31415, 0x6f1c0181, 0x657b0068, 0x00000000}},  //   dinn, órci, _bouh,
  { {0x186a3c04, 0xdb150010, 0x00000000, 0x00000000}},  //   _дами_, mozá,   ,
  { {0x63a33696, 0x00000000, 0x00000000, 0x00000000}},  //   finn,   ,   ,
  { {0xf6263c05, 0x63a314d6, 0xb33c01f3, 0x00000000}},  //   _одго, ginn, _omħe,
  { {0xe5a6012d, 0x133900a1, 0x6283060a, 0x00000000}},  //   _живи, ستوں_, gyno,
  { {0xdb1c0039, 0x22450022, 0x90541984, 0x00000000}},  //   llrä, _dplk_, евиц,
  { {0xd6b00044, 0xdb1513a5, 0xcf2603ec, 0x00000000}},  //   _করিয, hozá, وردي,
  { {0xdb150010, 0x44260016, 0xdb1c3c06, 0x00000000}},  //   kozá, mro_, boré,
  { {0xd12f01fe, 0xdb1c009d, 0x657b0068, 0x00000000}},  //   _их_, coré, _youh,
  { {0x44260032, 0x7de801aa, 0xd6b00044, 0x00000000}},  //   oro_, vèsè, _করায,
  { {0x5c74041f, 0x3ced050f, 0x00000000, 0x00000000}},  //   влят, ževo_,   ,
  { {0x44260917, 0xcf26007a, 0xdfa6023c, 0x00000000}},  //   iro_, _آرشي, _تحصي,
  { {0x44260016, 0x7c260007, 0x00000000, 0x00000000}},  //   hro_, arkr,   ,
  { {0xea000011, 0x63a300b5, 0x26d1012d, 0x00000000}},  //   _giật_, zinn, _rzzo_,
  { {0x777c0065, 0x62830036, 0x44263c07, 0x00000000}},  // [de90] _borx, zyno, jro_,
  { {0x44260df9, 0x657b3c08, 0x65690142, 0x00000000}},  //   dro_, _souh, _sneh,
  { {0x63a33514, 0x44263c09, 0xe81b0204, 0x00000000}},  //   vinn, ero_, _फटका_,
  { {0x63a30a70, 0x4426133c, 0x00000000, 0x00000000}},  //   winn, fro_,   ,
  { {0x44262d24, 0x63a3000c, 0x62830016, 0x00000000}},  //   gro_, tinn, wyno,
  { {0x4255025f, 0x395905de, 0x62830a3d, 0x00000000}},  //   етит, _hass_, tyno,
  { {0x63a3009f, 0xdb0e0b32, 0x44260207, 0x00000000}},  //   rinn, tobú, aro_,
  { {0x63a30056, 0x3f8e00e7, 0x3cf9013d, 0x00000000}},  //   sinn, _alfu_, ंडों_,
  { {0x20190047, 0x395900ab, 0x63a303b6, 0x00000000}},  //   ési_, _mass_, pinn,
  { {0x39590bea, 0x82f80014, 0x00000000, 0x00000000}},  //   _lass_, _قرمز_,   ,
  { {0xd1310025, 0xed5a01c0, 0x398e000c, 0x00000000}},  //   _مما_, пон_, _lýsa_,
  { {0x3f8e0020, 0xdb0a0161, 0x9f470023, 0x00000000}},  //   _elfu_, čník, _kinë_,
  { {0xa28300a1, 0x637400f6, 0x0d830c89, 0x00000000}},  //   _سیکو, _pànx, улян,
  { {0x207a0049, 0xdce40059, 0xdb150a50, 0x00000000}},  //   _מאנא, _unič, tozá,
  { {0xfb85008b, 0x6da601e0, 0xada616b6, 0x00000000}},  //   тыўн, _пика, _пакл,
  { {0x39590197, 0x442617c1, 0xdb15313d, 0x00000000}},  //   _cass_, yro_, rozá,
  { {0x3959001f, 0xfc320025, 0x777c00d4, 0x00000000}},  // [dea0] _dass_, _صحة_, _porx,
  { {0x442602d5, 0x777c006b, 0xdc3b009b, 0x00000000}},  //   vro_, _qorx, _צעיר,
  { {0x39590210, 0x98c0006b, 0x4426005b, 0x00000000}},  //   _fass_, ırıq_, wro_,
  { {0x442616d5, 0xf651026c, 0x39592fac, 0x00000000}},  //   tro_, گئے_, _gass_,
  { {0x442608eb, 0x69c600ea, 0x777c00d4, 0x00000000}},  //   uro_, _ikke, _torx,
  { {0x44262522, 0x779100a6, 0x9f470065, 0x00000000}},  //   rro_, _پیما, _dinë_,
  { {0x60e5006b, 0x4426007f, 0x6d440036, 0x00000000}},  //   ərmə, sro_, _obia,
  { {0xd259008b, 0x00000000, 0x00000000, 0x00000000}},  //   ьці_,   ,   ,
  { {0xf99300b6, 0xcfa60242, 0x3860004a, 0x00000000}},  //   טרה_, ешни, nvir_,
  { {0x25a63c0a, 0x6d44022b, 0x0fce0044, 0x00000000}},  //   liol_, _abia, রদ্ধ,
  { {0xdd95008b, 0xbcfb0010, 0x9f4701aa, 0x00000000}},  //   ваны, ndég, _minè_,
  { {0x25a63c0b, 0xac190259, 0x7bc50022, 0x00000000}},  //   niol_, мому_, _skhu,
  { {0xdb1c0016, 0x395901e5, 0x00000000, 0x00000000}},  //   gorï, _rass_,   ,
  { {0x63a1001c, 0x25a6018e, 0x69c600c7, 0x00000000}},  //   _xmln, hiol_, _akke,
  { {0x395905d8, 0x2d99028c, 0x7ddf0006, 0x00000000}},  //   _pass_, ères_, _būst,
  { {0x62980f3a, 0x2b5a00f6, 0x00000000, 0x00000000}},  //   izvo, _eapc_,   ,
  { {0x25a6018e, 0x2bd203d7, 0x6d4f04cb, 0x00000000}},  // [deb0] diol_, _दीवा, meca,
  { {0x69c6009f, 0x6d4f0046, 0x6d5d0039, 0x00000000}},  //   _ekke, leca, ldsa,
  { {0x7c2f050a, 0xf77005d4, 0x6d5d109a, 0x00000000}},  //   lucr, حاق_, odsa,
  { {0x6d5d068f, 0x6d4f0adb, 0x2d8b00b9, 0x00000000}},  //   ndsa, neca, nkce_,
  { {0x76550df0, 0x29090020, 0x6d5d0116, 0x00000000}},  //   _wszy, mbaa_, idsa,
  { {0x69cd004e, 0x6d4f00d9, 0x7c3d01a2, 0x00000000}},  //   llae, heca, itsr,
  { {0x69cd018e, 0x41b5005e, 0x25a60133, 0x00000000}},  //   olae, ксит, biol_,
  { {0x6d4f0182, 0x6d5d1e2e, 0xe2a80025, 0x00000000}},  //   jeca, jdsa, عاون_,
  { {0x6d4f1ab5, 0xdc3c0089, 0x6e2801c3, 0x00000000}},  //   deca, ršīg, erdb,
  { {0xd3780107, 0xf07600a1, 0xa2a20061, 0x00000000}},  //   _biću_, ئیوں_, _केव्,
  { {0x9f470224, 0x442f0125, 0x2b50006b, 0x00000000}},  //   _jiné_, lug_, _öncə_,
  { {0xb33c01d5, 0x6d4f1588, 0x7c3d254d, 0x00000000}},  //   _imħa, geca, ftsr,
  { {0x69cd018e, 0x1fb5003b, 0x5576007b, 0x00000000}},  //   dlae, _искр, דערן_,
  { {0x6d5d00e0, 0x00000000, 0x00000000, 0x00000000}},  //   adsa,   ,   ,
  { {0xc332019b, 0x442f16e7, 0x00000000, 0x00000000}},  //   יום_, hug_,   ,
  { {0x3a25000c, 0x644917e3, 0x6d440022, 0x00000000}},  //   álpa_, _opei, _ubia,
  { {0x61eb0198, 0x39403c0c, 0xdb1c11c4, 0x00000000}},  // [dec0] _migl, rfis_, lorí,
  { {0x38600129, 0x442f0093, 0x25a60016, 0x00000000}},  //   rvir_, dug_, wiol_,
  { {0xe9da012b, 0x443d0061, 0x9f470547, 0x00000000}},  //   _око_, etw_, _ciné_,
  { {0x2d8000f4, 0x8ab7009b, 0x75890088, 0x00000000}},  //   _joie_, _יהיו_, нсів_,
  { {0x25a60016, 0x442f0022, 0x69c40c79, 0x00000000}},  //   riol_, gug_, moie,
  { {0xdceb0243, 0x61eb009d, 0x25a6005b, 0x00000000}},  //   žićn, _aigl, siol_,
  { {0x61eb1921, 0x2d9201aa, 0x82330025, 0x00000000}},  //   _bigl, _olye_, لريا,
  { {0x6d4f0129, 0xdb1c1429, 0x2fc70058, 0x00000000}},  //   xeca, norâ, _akng_,
  { {0x6d4f037e, 0xbcfb009d, 0x61eb0166, 0x00000000}},  //   veca, ndée, _digl,
  { {0x836a0257, 0x2d920173, 0x31ba0089, 0x00000000}},  //   _تصرف_, _alye_, dīze_,
  { {0xdb1c0819, 0x61eb0198, 0x6d4f0211, 0x00000000}},  //   gorí, _figl, teca,
  { {0x6026007e, 0x61eb0197, 0xa1831001, 0x00000000}},  //   _адда, _gigl, _вышл,
  { {0x20190224, 0x6d5d0056, 0xada4007e, 0x00000000}},  //   ásit_, rdsa, раўл,
  { {0x8fa301be, 0xdb070065, 0x6d4f003b, 0x00000000}},  //   _каче, mijë, seca,
  { {0x442f010f, 0x7c2f0efe, 0x2d80009d, 0x00000000}},  //   zug_, sucr, _foie_,
  { {0xa806014a, 0x69c4002d, 0x7bce0142, 0x00000000}},  //   ktığ, goie, albu,
  { {0x98a2005f, 0x3dc9006a, 0x69cd010e, 0x00000000}},  // [ded0] _bakı_, _ikaw_, rlae,
  { {0x3b550069, 0x69cd0755, 0x7f8400f6, 0x00000000}},  //   _скор, slae, _tòqu,
  { {0x64493bc7, 0xa2a2001c, 0xd00601ef, 0x00000000}},  //   _spei, _केल्, _گل_,
  { {0xceb300a0, 0x442f01e5, 0xc8840276, 0x00000000}},  //   ביע_, tug_, _bağı_,
  { {0xd0060151, 0xfc3f002a, 0xef18001e, 0x00000000}},  //   _دل_, ntí_, kaļ_,
  { {0x442f1b7e, 0x61eb0e7f, 0xdb1c0211, 0x00000000}},  //   rug_, _sigl, yorí,
  { {0x05bb0070, 0x61eb0197, 0x442f0828, 0x00000000}},  //   _قدرت_, _pigl, sug_,
  { {0x798d2b5e, 0x61fe0161, 0x2fc70145, 0x00000000}},  //   nkaw, ípla, _skng_,
  { {0x61eb225f, 0xf94a0049, 0x69da01bb, 0x00000000}},  //   _vigl, געפֿ, ïtei,
  { {0x2d9900b5, 0xdb1c3c0d, 0x2d80009d, 0x00000000}},  //   ëren_, torí, _soie_,
  { {0x798d002b, 0x61eb3c0e, 0x2d92000a, 0x00000000}},  //   kkaw, _tigl, _plye_,
  { {0xed570088, 0xc1050025, 0xd00e00a1, 0x00000000}},  //   гою_, _صوتي, _کلو_,
  { {0x711a00b6, 0x2d8010ff, 0xdb1c073f, 0x00000000}},  //   _נוספ, _voie_, sorí,
  { {0xe0d00123, 0x798d00b4, 0x00000000, 0x00000000}},  //   _بزم_, ekaw,   ,
  { {0x69c42f69, 0xdb1c00fa, 0x00000000, 0x00000000}},  //   toie, torâ,   ,
  { {0x798d011c, 0x00000000, 0x00000000, 0x00000000}},  //   gkaw,   ,   ,
  { {0x38660048, 0x69c41a19, 0x79960016, 0x00000000}},  // [dee0] íor_, roie, rhyw,
  { {0xbcfb009d, 0x79960009, 0x91fc0089, 0x00000000}},  //   rdée, shyw, _brāl,
  { {0x452a0849, 0x7d160133, 0x69c40585, 0x00000000}},  //   ежен_, _keys, poie,
  { {0xa806014a, 0xc5160076, 0x49ba01d8, 0x00000000}},  //   ttığ, ابات, _ساجد_,
  { {0xd87605d4, 0x7d160016, 0xd4670e75, 0x00000000}},  //   _صاحب, _meys, лице_,
  { {0x39521440, 0x9326007a, 0x7d161ea9, 0x00000000}},  //   leys_, ارشن, _leys,
  { {0x7dd60010, 0xa8061d83, 0x00000000, 0x00000000}},  //   zása, stığ,   ,
  { {0xa806011f, 0x7d161402, 0x7df3001a, 0x00000000}},  //   ptığ, _neys, _găsi,
  { {0x2fc5010f, 0xbfaa025f, 0x351b009b, 0x00000000}},  //   folg_, етне_, _רומנ,
  { {0xa857009b, 0xa2bf013d, 0x2d8406d3, 0x00000000}},  //   נייה_, _लुक्, ömen_,
  { {0x39520085, 0x00000000, 0x00000000, 0x00000000}},  //   keys_,   ,   ,
  { {0x7dd60010, 0x00000000, 0x00000000, 0x00000000}},  //   tása,   ,   ,
  { {0x5b27132a, 0xdced0066, 0x00000000, 0x00000000}},  //   льва, _inaċ,   ,
  { {0xfc3f3c0f, 0xbe86035b, 0x7dd63c10, 0x00000000}},  //   rtí_, _مجبو, rása,
  { {0xfc3f05d2, 0x6f1a05ad, 0xe9190088, 0x00000000}},  //   stí_, matc, кові_,
  { {0x7d1601e5, 0x39520146, 0x195807d0, 0x00000000}},  //   _geys, geys_, ласы_,
  { {0x971501e0, 0x2d990051, 0x5efb0061, 0x00000000}},  // [def0] имац, mhse_, लुक्_,
  { {0x6f1a0095, 0x798d1c2e, 0x00000000, 0x00000000}},  //   natc, skaw,   ,
  { {0xb8cc02d2, 0x941f006b, 0xb87b0ddb, 0x00000000}},  //   _के_, ərək_, _egíp,
  { {0x7bc71eca, 0x9542006b, 0x6f1a009d, 0x00000000}},  //   loju, əşkə, hatc,
  { {0x1b180044, 0x6d5f013f, 0x399e013e, 0x00000000}},  //   _তাতে_, _maqa, růst_,
  { {0x7bc70089, 0x14a40061, 0x6d5f002b, 0x00000000}},  //   noju, _खेळण, _laqa,
  { {0x2fc500c7, 0xa806014a, 0xdb1c0321, 0x00000000}},  //   volg_, rtış, norá,
  { {0x91fc12d1, 0x22ae006b, 0x6d5f3c11, 0x00000000}},  //   _grām, _dək_, _naqa,
  { {0x7bc70089, 0xd347007a, 0x9f470026, 0x00000000}},  //   koju, _میشه_, _finì_,
  { {0x6f1a001c, 0xff2500ed, 0x2054005e, 0x00000000}},  //   gatc, јмно, стър,
  { {0x7bc71a2f, 0x6d5f1347, 0x7d1601e5, 0x00000000}},  //   doju, _baqa, _peys,
  { {0xfce63c12, 0xc27a08cd, 0x00000000, 0x00000000}},  //   ионо, _ברעי,   ,
  { {0x7bc70d3d, 0x645b009d, 0x39520052, 0x00000000}},  //   foju, _jsui, veys_,
  { {0xdee5012b, 0x6f1a001c, 0xdb1c07da, 0x00000000}},  //   _коли, catc, forá,
  { {0xbea200ed, 0x6d5f0066, 0x395200b0, 0x00000000}},  //   _машк, _faqa, teys_,
  { {0x667600a6, 0x2d99010f, 0x7dd60010, 0x00000000}},  //   یدار, chse_, máso,
  { {0x7dd60047, 0x201f1f54, 0x7bc71b05, 0x00000000}},  // [df00] láso, nsui_, boju,
  { {0x753b001a, 0x27ee000c, 0x661b0036, 0x00000000}},  //   _acuz, öfn_, _łuka,
  { {0x443f0b32, 0x91fc0089, 0x645b00b0, 0x00000000}},  //   _aqu_, _prām, _asui,
  { {0x7ddd00d4, 0x00000000, 0x00000000, 0x00000000}},  //   césd,   ,   ,
  { {0x63aa3c13, 0x290014a6, 0x00000000, 0x00000000}},  //   tifn, mcia_,   ,
  { {0xb4d603d7, 0xbcfb0051, 0x7dd60010, 0x00000000}},  //   _हरी_, idéa, káso,
  { {0x2b47011f, 0xd2500025, 0x7ddd0047, 0x00000000}},  //   _önce_, سنة_, lése,
  { {0x7dd60010, 0xd1300025, 0x7bc73c14, 0x00000000}},  //   dáso, أمة_, zoju,
  { {0x7df3001a, 0x2900008e, 0xd00700ed, 0x00000000}},  //   _măsu, icia_, аење_,
  { {0x63ad0ea5, 0x244001aa, 0x65600051, 0x00000000}},  //   éant, mòm_, _hamh,
  { {0xa3e30316, 0x24400263, 0x29000027, 0x00000000}},  //   नगर_, lòm_, kcia_,
  { {0x6562008d, 0x65600020, 0xdb1c00c4, 0x00000000}},  //   ndoh, _jamh, vorá,
  { {0x64423c15, 0x7bc73c16, 0x244001aa, 0x00000000}},  //   ntoi, toju, nòm_,
  { {0xc0a901f7, 0x6d5f3c17, 0x7ddd0010, 0x00000000}},  //   _حامل_, _waqa, dése,
  { {0xdced0091, 0x7bc70089, 0x69c0041a, 0x00000000}},  //   _inač, roju, čmen,
  { {0x637d0263, 0x65600e93, 0x6f1801f3, 0x00000000}},  //   _dèny, _namh, _hevc,
  { {0x7d1d021e, 0x7bc73c18, 0x673c0085, 0x00000000}},  // [df10] mass, poju, _bcrj,
  { {0xe7190025, 0xe73301f7, 0xa7740264, 0x00000000}},  //   ايات_, تصر_, олуч,
  { {0x2126037e, 0xc6a4003b, 0x6f18014a, 0x00000000}},  //   _odoh_, орци, _mevc,
  { {0x29000198, 0x7d1d00b0, 0x244001aa, 0x00000000}},  //   ccia_, nass, fòm_,
  { {0x7dd60047, 0x65603c19, 0x29190145, 0x00000000}},  //   záso, _damh, _iesa_,
  { {0x7d1d00b0, 0xb3c801ff, 0xb4c70061, 0x00000000}},  //   hass, аліз_, _उडी_,
  { {0xd6e50055, 0x06e50055, 0xe6950054, 0x00000000}},  //   _প্রয, _প্রি, _الأد,
  { {0x201f0052, 0x753b0279, 0x7d1d0103, 0x00000000}},  //   tsui_, _ucuz, jass,
  { {0x29190576, 0x644200f4, 0x7d1d00b0, 0x00000000}},  //   _mesa_, ctoi, dass,
  { {0x7dd60047, 0x2919009f, 0xf2c7013b, 0x00000000}},  //   táso, _lesa_, _ксен,
  { {0x7d1d010f, 0x201f0181, 0x7ddd0047, 0x00000000}},  //   fass, ssui_, zése,
  { {0x7d1d0010, 0x29190016, 0x7dd60010, 0x00000000}},  //   gass, _nesa_, ráso,
  { {0x515a009b, 0x7c2900ca, 0x6d460546, 0x00000000}},  //   _תכנו, šern, rfka,
  { {0x3b95025f, 0x394b0386, 0x442f0048, 0x00000000}},  //   ојст, _abcs_, irg_,
  { {0x244001aa, 0x29190065, 0xf8bf13f6, 0x00000000}},  //   zòm_, _besa_, _axé_,
  { {0xe9df001d, 0x7ddd0047, 0x2919097c, 0x00000000}},  //   _chú_, tése, _cesa_,
  { {0x29000027, 0x291904fa, 0x4ca60055, 0x00000000}},  // [df20] rcia_, _desa_, _গুরু,
  { {0x65603c1a, 0x29000198, 0x869a0ceb, 0x00000000}},  //   _samh, scia_, лтет_,
  { {0x2e23014a, 0x244001aa, 0xd7ef0025, 0x00000000}},  //   nıf_, wòm_, ركم_,
  { {0xdb1c09f7, 0x63140044, 0x6442089e, 0x00000000}},  //   forç, _সাইট_, ttoi,
  { {0xfe67007a, 0xf3f10082, 0x6fc701f5, 0x00000000}},  //   _کد_, _bị_, रकां,
  { {0x6442089e, 0x7d1d2c3e, 0x7c2400e7, 0x00000000}},  //   rtoi, zass, _mvir,
  { {0x64423c1b, 0x7d0438fc, 0x442f3284, 0x00000000}},  //   stoi, _ofis, arg_,
  { {0x15430cee, 0x7c240059, 0x60f8005e, 0x00000000}},  //   _несм, _ovir, шния_,
  { {0x7d1d0943, 0x6f1800ca, 0x6e230146, 0x00000000}},  //   vass, _pevc, _avnb,
  { {0x7d041111, 0x7d1d31c1, 0x442400bb, 0x00000000}},  //   _afis, wass, _ivm_,
  { {0x7d1d0010, 0x7ddd0010, 0x8266023c, 0x00000000}},  //   tass, vésb, _دهان,
  { {0x44240193, 0xc69301ce, 0x7c2401f3, 0x00000000}},  //   _kvm_, פאר_, _bvir,
  { {0x7d1d00f2, 0x29193c1c, 0x442400f8, 0x00000000}},  //   rass, _resa_, _jvm_,
  { {0x7d040169, 0x29190065, 0x7c240006, 0x00000000}},  //   _efis, _sesa_, _dvir,
  { {0x7d1d02ae, 0xe9df001d, 0x29190020, 0x00000000}},  //   pass, _phú_, _pesa_,
  { {0x61fa011f, 0x00000000, 0x00000000, 0x00000000}},  //   _mutl,   ,   ,
  { {0x29190052, 0x6d4d027f, 0x7c2401ee, 0x00000000}},  // [df30] _vesa_, _ibaa, _gvir,
  { {0xba55025f, 0x61fa00ab, 0x6fdd00f4, 0x00000000}},  //   _двој, _outl, pèce,
  { {0xd6db003b, 0xe9df3c1d, 0x29190197, 0x00000000}},  //   ута_, _thú_, _tesa_,
  { {0x9b4500a1, 0x2e3b0049, 0x442f211e, 0x00000000}},  //   _انھو, רגאנ, trg_,
  { {0x442f00f4, 0x29d72c6f, 0x442400c4, 0x00000000}},  //   urg_, nçam_, _cvm_,
  { {0x61fa04bd, 0x4424012d, 0x420900ed, 0x00000000}},  //   _butl, _dvm_, анко_,
  { {0xe2990265, 0x38693c1e, 0xdb1c00c4, 0x00000000}},  //   рай_, lvar_, sorç,
  { {0x80dd01f5, 0xdb1c00c4, 0x3949005b, 0x00000000}},  //   _परदे, porç, nfas_,
  { {0x3869005f, 0x76450e42, 0x00000000, 0x00000000}},  //   nvar_, lthy,   ,
  { {0x6d4d0061, 0xd00e00a2, 0xf8aa0049, 0x00000000}},  //   _abaa, کلی_, יספֿ,
  { {0x7c240091, 0x7645018e, 0x6d4d0045, 0x00000000}},  //   _svir, nthy, _bbaa,
  { {0xe2940049, 0x7645005b, 0x00000000, 0x00000000}},  //   _צװײ_, ithy,   ,
  { {0x29d71052, 0x06b00044, 0x7dd60a50, 0x00000000}},  //   rçal_, _করছি, lásk,
  { {0x69cf0046, 0x200d237d, 0x76450065, 0x00000000}},  //   _akce, mpei_, kthy,
  { {0x75290667, 0x79862bcd, 0x7d04002b, 0x00000000}},  //   _odez, _pokw, _tfis,
  { {0x3946008b, 0x7d040020, 0x7c240006, 0x00000000}},  //   ўнаг, _ufis, _tvir,
  { {0x3f87011f, 0x66093a59, 0x76450016, 0x00000000}},  // [df40] _konu_, _čeka, ethy,
  { {0x2d820ce4, 0x69cf3c1f, 0x75290035, 0x00000000}},  //   ljke_, _ekce, _adez,
  { {0x2b583c20, 0x4c0500a2, 0x3f870087, 0x00000000}},  //   merc_, _وظیف, _monu_,
  { {0x61fa1fdb, 0x44240997, 0x8936004b, 0x00000000}},  //   _rutl, _pvm_, _بعدا,
  { {0x29120dfc, 0x1957009b, 0x00000000, 0x00000000}},  //   mbya_, _ובכל_,   ,
  { {0x69d60010, 0x366a007e, 0x44240146, 0x00000000}},  //   llye, _каго_, _vvm_,
  { {0xd627005e, 0xe297003b, 0x1dca0061, 0x00000000}},  //   _море_, жај_, रवात,
  { {0xfbc20044, 0x399c0051, 0x00000000, 0x00000000}},  //   োগিত, _físe_,   ,
  { {0x3f87012d, 0xdced0066, 0x44240b77, 0x00000000}},  //   _bonu_, _ilaħ, _uvm_,
  { {0x7dd60010, 0xff98012b, 0x3f98000c, 0x00000000}},  //   lásh, ској_, óru_,
  { {0xb7db007b, 0x614601e1, 0x4106007e, 0x00000000}},  //   שקיי, _межа, _дзев,
  { {0xdced0066, 0xbcfb009d, 0x00000000, 0x00000000}},  //   _jlaħ, rdéo,   ,
  { {0x7b670589, 0x6eca0183, 0xed58007e, 0x00000000}},  //   отве, _सुरु, цоў_,
  { {0x7645018e, 0xa00701d8, 0x29d707c2, 0x00000000}},  //   ythy, _بقول_, rçam_,
  { {0x69d60302, 0x61e20c35, 0x8f9b009b, 0x00000000}},  //   flye, _khol, _דיגי,
  { {0x6fd400f6, 0x38690095, 0x00000000, 0x00000000}},  //   dàci, tvar_,   ,
  { {0xbcfb049a, 0x61e20051, 0x39490904, 0x00000000}},  // [df50] ndém, _mhol, rfas_,
  { {0x386906c2, 0xe94500e9, 0x2b58001a, 0x00000000}},  //   rvar_, _کردی, cerc_,
  { {0xd5750373, 0x3869004e, 0x61e237b2, 0x00000000}},  //   зуль, svar_, _ohol,
  { {0x7645018e, 0xbc6800a6, 0x61e201f3, 0x00000000}},  //   rthy, _امین_, _nhol,
  { {0xa8790049, 0xa3d60061, 0x00000000, 0x00000000}},  //   _האָר, सतं_,   ,
  { {0x61e2002d, 0x57f4007c, 0x7dd60010, 0x00000000}},  //   _ahol, _опят, tásk,
  { {0x61e20048, 0xdb150010, 0x9608007e, 0x00000000}},  //   _bhol, lozó, _мэта_,
  { {0xd24e0380, 0x3f87005d, 0x98ab0279, 0x00000000}},  //   اني_, _sonu_, _hacı_,
  { {0x25ad3c21, 0x00000000, 0x00000000, 0x00000000}},  //   _imel_,   ,   ,
  { {0xee39017a, 0x3f9e0846, 0x25bf032e, 0x00000000}},  //   бно_, ghtu_, _hjul_,
  { {0x59bd0164, 0x61e20051, 0x25bf00ea, 0x00000000}},  //   ्कार, _fhol, _kjul_,
  { {0x61e23c22, 0xdb150010, 0x00000000, 0x00000000}},  //   _ghol, kozó,   ,
  { {0xea00001d, 0x61e9365c, 0x7dd600c4, 0x00000000}},  //   _biết_, mmel, nási,
  { {0x61e93c23, 0x398e000c, 0x2d82012d, 0x00000000}},  //   lmel, _lýst_, sjke_,
  { {0x09e602e9, 0xeab200a1, 0xea000082, 0x00000000}},  //   зовн, رٹر_, _diết_,
  { {0x61e902ae, 0xf2d20049, 0x3dd60044, 0x00000000}},  //   nmel, געל_, _সংকল,
  { {0x61e93396, 0x29120058, 0x98ab28fc, 0x00000000}},  // [df60] imel, rbya_, _bacı_,
  { {0x7c2602d8, 0xea000011, 0x61e908e8, 0x00000000}},  //   mskr, _giết_, hmel,
  { {0xd90d026c, 0xeab20647, 0xbafb009b, 0x00000000}},  //   _چیف_, _سعد_, _להיש,
  { {0x6f1c0036, 0x7dd60325, 0x00000000, 0x00000000}},  //   órcz, fási,   ,
  { {0x7c2605d1, 0x61e90030, 0x938a2473, 0x00000000}},  //   nskr, dmel, йска_,
  { {0x61e23c24, 0x5334007c, 0x78a40107, 0x00000000}},  //   _shol, фект, mziv,
  { {0x61e23c25, 0x9f47021e, 0x2365050f, 0x00000000}},  //   _phol, _minä_, _dalj_,
  { {0xb6bb009b, 0x7c2600f8, 0x61e9149f, 0x00000000}},  //   _הצלי, kskr, gmel,
  { {0x7df4000d, 0x7bce01d6, 0x7dd6004a, 0x00000000}},  //   _răsp, kobu, cási,
  { {0x08e90055, 0x61e200ab, 0x7bc1016c, 0x00000000}},  //   টুকু_, _whol, čluk,
  { {0x44260576, 0x61e20016, 0xa3c90164, 0x00000000}},  //   lso_, _thol, ईवर_,
  { {0x3f9e008d, 0x44260cdd, 0x7c26021f, 0x00000000}},  //   shtu_, oso_, fskr,
  { {0x44260555, 0x7c26000c, 0x29f801ee, 0x00000000}},  //   nso_, gskr, _očas_,
  { {0x442601c5, 0x200b3c26, 0x78a41ae3, 0x00000000}},  //   iso_, ície_, dziv,
  { {0xea0000ad, 0x7ac40517, 0xbef701b7, 0x00000000}},  //   _viết_, есте, _عروض_,
  { {0x44260006, 0x7c260036, 0xb33c0066, 0x00000000}},  //   kso_, bskr, _imħu,
  { {0xea00001d, 0x91fc001e, 0x00000000, 0x00000000}},  // [df70] _tiết_, _krās,   ,
  { {0x4c9c009b, 0x7bce0116, 0x442600d9, 0x00000000}},  //   _לבחו, cobu, dso_,
  { {0x44263c27, 0xcf930049, 0x6e3a00f8, 0x00000000}},  //   eso_, עטע_, nutb,
  { {0x3ea1006c, 0xfa5600a1, 0x00000000, 0x00000000}},  //   _ühte_, _کریگ,   ,
  { {0xf8c1013d, 0x44260058, 0xe4cb0167, 0x00000000}},  //   _एशिय, gso_, حبان_,
  { {0x7dd63c28, 0xf41000a1, 0xc79900a1, 0x00000000}},  //   rási, اؤن_, _بھرا_,
  { {0x61e9014a, 0x7d060039, 0x44263c29, 0x00000000}},  //   tmel, ycks, aso_,
  { {0xd9e3013d, 0xdb0e0115, 0x6009007c, 0x00000000}},  //   _कीमत_, ribé, оним_,
  { {0x7ddd0010, 0x8fa50887, 0x31660288, 0x00000000}},  //   tésn, дапе, _daoz_,
  { {0x61e93c2a, 0x91fc0089, 0x7c260056, 0x00000000}},  //   smel, _prāt, vskr,
  { {0xdb1c0027, 0x9f5f009d, 0x00000000, 0x00000000}},  //   porú, nqué_,   ,
  { {0x61360279, 0x9f4700b0, 0x50b501ee, 0x00000000}},  //   rülü, _sinä_, _ослу,
  { {0x91aa00a1, 0x4c83005e, 0xd7bf0061, 0x00000000}},  //   _بننے_, вляв, ्वाच,
  { {0x9fb5005f, 0x6d410010, 0x799d00d9, 0x00000000}},  //   dəçi_, őlap, _alsw,
  { {0x7c260056, 0x00000000, 0x00000000, 0x00000000}},  //   sskr,   ,   ,
  { {0xe9da0822, 0x7c26000c, 0x44260016, 0x00000000}},  //   іка_, pskr, yso_,
  { {0x7bce012d, 0x798405cd, 0x6d440288, 0x00000000}},  // [df80] pobu, rjiw, _icia,
  { {0x1b180055, 0x799d00d9, 0x799601c3, 0x00000000}},  //   _তাকে_, _elsw, skyw,
  { {0xe8fa0920, 0x9f5f04bd, 0x29f80062, 0x00000000}},  //   _млн_, rquè_, _včas_,
  { {0x4426021e, 0xe57a0930, 0x6fd400f6, 0x00000000}},  //   tso_, юзе_, làct,
  { {0x44261395, 0x045a0025, 0xea000082, 0x00000000}},  //   uso_, تجات_, _khắt_,
  { {0x4426081d, 0xa3a803d7, 0x9a2500a1, 0x00000000}},  //   rso_, खों_, _تعین,
  { {0x4426024e, 0x6fdd0129, 0x38600016, 0x00000000}},  //   sso_, tècn, lwir_,
  { {0x6d440061, 0x32530265, 0x6143003b, 0x00000000}},  //   _ncia, твър, већа,
  { {0x3940006c, 0xcfaa0025, 0x27f800ca, 0x00000000}},  //   igis_, قادم_, _kirn_,
  { {0x83fd0047, 0x187b009b, 0xada40036, 0x00000000}},  //   _erős, קטיב, óźni,
  { {0x6fd40129, 0x0737009b, 0xa3cb0061, 0x00000000}},  //   dàct, ואים_, ळकर_,
  { {0x6d440197, 0x6e3a00d8, 0x00000000, 0x00000000}},  //   _ccia, rutb,   ,
  { {0xdb05002a, 0x50e202f4, 0x6e3a1d43, 0x00000000}},  //   _amhá, _परिष, sutb,
  { {0x2124002a, 0x6e3a0009, 0xbcfb0051, 0x00000000}},  //   lamh_, putb, idéi,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x21240195, 0x75200047, 0x6f0d016c, 0x00000000}},  //   namh_, _nemz, _đaci,
  { {0x6d5d023a, 0xa3ce01f5, 0x00000000, 0x00000000}},  // [df90] mesa, रवा_,   ,
  { {0x6d5d033b, 0xd6db17da, 0x399c000c, 0x00000000}},  //   lesa, оте_, _vísa_,
  { {0x19950878, 0xa53500ed, 0xfbdf00c4, 0x00000000}},  //   _заня, енеч, ntêm_,
  { {0x6d5d01aa, 0x9f5f3c2b, 0x39400bd3, 0x00000000}},  //   nesa, rqué_, cgis_,
  { {0x92bb0044, 0x6f0a00ea, 0x9f5f009d, 0x00000000}},  //   _ঘরে_, _offc, squé_,
  { {0x6d5d0020, 0xd7c90014, 0x7dd604e7, 0x00000000}},  //   hesa, _روزه_, lást,
  { {0xf99f01aa, 0x6d5d01a3, 0x26d81238, 0x00000000}},  //   _klè_, kesa, _gyro_,
  { {0x2d9900b5, 0x6d5d3762, 0x7dd63c2c, 0x00000000}},  //   jkse_, jesa, nást,
  { {0x6d5d023a, 0x00000000, 0x00000000, 0x00000000}},  //   desa,   ,   ,
  { {0x6d442820, 0x2d9900c7, 0x1e850140, 0x00000000}},  //   _scia, ekse_, елом,
  { {0x6d5d00c4, 0xf99f0026, 0x65690146, 0x00000000}},  //   fesa, _olè_, _kaeh,
  { {0x6d5d010f, 0x38600016, 0x00000000, 0x00000000}},  //   gesa, ywir_,   ,
  { {0xbdf9026c, 0x7c3d006c, 0xdb0700b0, 0x00000000}},  //   _کرتا_, gusr, kijä,
  { {0x2d99095a, 0x12d10044, 0xf99f3c2d, 0x00000000}},  //   akse_, াধীদ, _alè_,
  { {0x6d5d0169, 0x6fd40129, 0xc3320097, 0x00000000}},  //   besa, ràct, טום_,
  { {0x6d5d3c2e, 0x2d9901c3, 0x7dd60010, 0x00000000}},  //   cesa, ckse_, tásu,
  { {0x26de0119, 0x394006aa, 0xea000011, 0x00000000}},  // [dfa0] _što_, rgis_, _thắt_,
  { {0x290b0066, 0x443d00bb, 0x1a550026, 0x00000000}},  //   _efca_, duw_, ìììì,
  { {0xf99f01aa, 0x443d00b5, 0xbb3b0049, 0x00000000}},  //   _flè_, euw_, _צעטי,
  { {0x2909001c, 0xdce40bf8, 0x7bdc00f8, 0x00000000}},  //   ccaa_, _laič, llru,
  { {0x7dd60010, 0xc95300b3, 0x00000000, 0x00000000}},  //   láss, _גמר_,   ,
  { {0xdb1c000c, 0x6d5d1858, 0x326601ee, 0x00000000}},  //   fnré, zesa, етив,
  { {0x3afb007b, 0x66e3003b, 0x9f4e0026, 0x00000000}},  //   פּגע, _бора, _rifà_,
  { {0xea00001d, 0x2449000c, 0xdcf6000a, 0x00000000}},  //   _nhật_, búm_, _anyč,
  { {0x6d5d339c, 0xd5ad00a1, 0x82fa00a6, 0x00000000}},  //   vesa, _بہن_, _فراز_,
  { {0x200b3c2f, 0x6e980fc0, 0x21240051, 0x00000000}},  //   ícia_, двор_, samh_,
  { {0x6d5d00d6, 0xdd9105f3, 0x70540014, 0x00000000}},  //   tesa, لود_, رنگا,
  { {0x29d70129, 0x7c3d017b, 0xea000082, 0x00000000}},  //   nçat_, tusr, _chật_,
  { {0x2d9900bb, 0x6d4f1595, 0x48c40044, 0x00000000}},  //   rkse_, rfca, ্ধুর,
  { {0xcf260025, 0x6d5d01a3, 0x09d90061, 0x00000000}},  //   _أرشي, sesa, ढत्य,
  { {0x7dd63c30, 0x6d5d033b, 0xdb0e008e, 0x00000000}},  //   tást, pesa, cibí,
  { {0x3f8e0020, 0x67250022, 0x5c7519a2, 0x00000000}},  //   _hofu_, wahj, _алит,
  { {0xdb150023, 0x7d0d3c31, 0x7dd60142, 0x00000000}},  // [dfb0] nizë, _ifas, rást,
  { {0x7c2d1263, 0xd12600a1, 0x00000000, 0x00000000}},  //   _ivar, _ھم_,   ,
  { {0x7c2d3c32, 0xc7c402b8, 0x67250065, 0x00000000}},  //   _hvar, усти, rahj,
  { {0x7c2d0292, 0x7dd60010, 0x7d0d0066, 0x00000000}},  //   _kvar, lásr, _jfas,
  { {0x7d0d002b, 0x7c2d002b, 0x7f410009, 0x00000000}},  //   _mfas, _jvar, yglq,
  { {0x644b0bc7, 0x7c2d0023, 0x00000000, 0x00000000}},  //   rtgi, _mvar,   ,
  { {0x644b00f8, 0xfc3f0051, 0xdce402c3, 0x00000000}},  //   stgi, huí_, _raič,
  { {0x96f80893, 0x7c2d0838, 0x00000000, 0x00000000}},  //   _чест_, _ovar,   ,
  { {0xa156003b, 0x29d700c4, 0x7dd60010, 0x00000000}},  //   тању_, lças_, záss,
  { {0x02a70216, 0x7d0d0181, 0x442d0133, 0x00000000}},  //   _прем, _afas, _ive_,
  { {0x6da6017f, 0x29d702d5, 0xa3c0001c, 0x00000000}},  //   вина, nças_, ीवर_,
  { {0x80d30044, 0xdb0e004a, 0x7bdc00ea, 0x00000000}},  //   দেষ্, ribí, wlru,
  { {0xb87b0047, 0xfc3f3c33, 0xdb0500f8, 0x00000000}},  //   _szín, guí_, _omhä,
  { {0x316d0d48, 0x4fe80088, 0x7dd60010, 0x00000000}},  //   ldez_, _змін_, táss,
  { {0xea00001d, 0x7d0d0016, 0x7f5600e2, 0x00000000}},  //   _thật_, _ffas, _рајс_,
  { {0x442d0119, 0x316d00f4, 0x7d1b009f, 0x00000000}},  //   _ove_, ndez_, ðust,
  { {0x6d560061, 0x39460089, 0x316d0325, 0x00000000}},  // [dfc0] _ibya, ļos_, idez_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4b370049, 0xfaa602e9, 0x442d2172, 0x00000000}},  //   _בריל_, _рано, _ave_,
  { {0xf8bf0129, 0x63a101e5, 0x25a00048, 0x00000000}},  //   _adéu_, _alln, óil_,
  { {0x29d71052, 0x69c600d9, 0x24540025, 0x00000000}},  //   rçat_, _ijke, انتس,
  { {0x442d0cce, 0x57250025, 0x61e4002b, 0x00000000}},  //   _dve_, _مرفق, ċilm,
  { {0x63a10009, 0x442d114e, 0xdb1c29b3, 0x00000000}},  //   _dlln, _eve_, loró,
  { {0xd1300025, 0x7dd60010, 0xdb150023, 0x00000000}},  //   حمة_, zásr, tizë,
  { {0x0326008b, 0x660904a5, 0x4fd400e3, 0x00000000}},  //   _адзн, _čeki, лжит,
  { {0x29d70d42, 0x6d560173, 0x7d0d237d, 0x00000000}},  //   nçar_, _abya, _sfas,
  { {0xc7b3009b, 0xb14602dc, 0x7ddd0d95, 0x00000000}},  //   שבת_, _анел, lési,
  { {0x25a61665, 0x63b800b9, 0xfc3f0ddb, 0x00000000}},  //   nhol_, livn, tuí_,
  { {0x4fc60265, 0x3f8e17cf, 0x403405f6, 0x00000000}},  //   _иска, _tofu_, _селс,
  { {0xc0e30001, 0x6d560a5f, 0x09bd0204, 0x00000000}},  //   _точк, _ebya, ्क्य,
  { {0x75fa0224, 0x7ddd00f4, 0x6fdd0bf2, 0x00000000}},  //   _různ, hési, dèch,
  { {0x7c2d0a76, 0x39a4072b, 0x7d0d3c34, 0x00000000}},  //   _tvar, ашув, _ufas,
  { {0xfc3f029a, 0xdb1c0c56, 0x8b0800b4, 0x00000000}},  // [dfd0] quí_, goró, _stęż,
  { {0x7ddd009d, 0x995c07e4, 0x7c290079, 0x00000000}},  //   dési, _víš_, šers,
  { {0x442d0119, 0xd6db00ed, 0x63b80091, 0x00000000}},  //   _sve_, фта_, divn,
  { {0x2d8b0e00, 0x29d700c4, 0xceb300b3, 0x00000000}},  //   njce_, rças_, סיף_,
  { {0x7ddd0285, 0x236c000a, 0x43950f62, 0x00000000}},  //   gési, _badj_, ладс,
  { {0x63b80945, 0xe6130137, 0xbcfb0010, 0x00000000}},  //   givn, _نشر_, ldés,
  { {0x42520025, 0x00000000, 0x00000000, 0x00000000}},  //   منور,   ,   ,
  { {0x45d50001, 0x200b02d5, 0x25a63c35, 0x00000000}},  //   _собс, ício_, chol_,
  { {0x316d00f4, 0x659401e0, 0x7bd5199f, 0x00000000}},  //   rdez_, _тату, kozu,
  { {0xea000011, 0x645b002d, 0x9f8501ee, 0x00000000}},  //   _giặt_, _ipui, угод,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xea000011, 0x399c0161, 0x00000000, 0x00000000}},  //   _nhạt_, _písm_,   ,
  { {0xa3c701f5, 0x6e3a00d9, 0x645b00f6, 0x00000000}},  //   _उदा_, artb, _jpui,
  { {0xd00e06ea, 0xf1b90213, 0xfc03007c, 0x00000000}},  //   _على_, liš_, спро,
  { {0x32053c36, 0xfaa3007e, 0x15f5007d, 0x00000000}},  //   _july_, баро, ेदार_,
  { {0xdb1c0036, 0x63b8016e, 0xf1b90091, 0x00000000}},  //   toró, zivn, niš_,
  { {0xa2da001c, 0x57ea00c0, 0xfc320025, 0x00000000}},  // [dfe0] _पुन्, едам_, _احب_,
  { {0xf8bf00f6, 0x6d460190, 0x00000000, 0x00000000}},  //   _adés_, lgka,   ,
  { {0x25a60016, 0x29d71396, 0x7c223c37, 0x00000000}},  //   thol_, rçar_, _çorb,
  { {0x6d461451, 0xb5da01b7, 0xf1b90213, 0x00000000}},  //   ngka, رباء_, jiš_,
  { {0x2d800046, 0x69c43221, 0xf1b90c1e, 0x00000000}},  //   _mnie_, mnie, diš_,
  { {0x69c409a4, 0x62983c38, 0x7ddd009d, 0x00000000}},  //   lnie, tyvo, rési,
  { {0x63b80039, 0x25a6063f, 0x645b3c39, 0x00000000}},  //   rivn, phol_, _epui,
  { {0xc03400e1, 0x69c4101a, 0xe5a3003b, 0x00000000}},  //   аниј, nnie, _лиси,
  { {0x80dc0044, 0xf993009b, 0x69c401a2, 0x00000000}},  //   মেন্, מרה_, inie,
  { {0xbcfb0010, 0x69c418d5, 0x6562010e, 0x00000000}},  //   zdés, hnie, leoh,
  { {0xf1b90059, 0x69c4000c, 0x9d19007e, 0x00000000}},  //   biš_, knie, конт_,
  { {0x69c406ed, 0x69d60133, 0xe7eb013d, 0x00000000}},  //   jnie, joye, _जीना_,
  { {0x69c409a0, 0x2d921de0, 0x00000000, 0x00000000}},  //   dnie, _doye_,   ,
  { {0x765c1ea2, 0x69c41031, 0x7f96009d, 0x00000000}},  //   _opry, enie, _pâqu,
  { {0xea000011, 0x9f4700b9, 0x7bd50ce2, 0x00000000}},  //   _phạt_, _jiný_, rozu,
  { {0x69c40a77, 0x89a7026c, 0x3915005e, 0x00000000}},  //   gnie, اھدہ_, рмар,
  { {0xbcfb0047, 0x7bd53c3a, 0xa3e4006e, 0x00000000}},  // [dff0] rdés, pozu, नता_,
  { {0x3f9e3c3b, 0x7c2f0e98, 0xf1b90825, 0x00000000}},  //   nktu_, mscr, ziš_,
  { {0x69c43221, 0x645b0250, 0x6da400a2, 0x00000000}},  //   bnie, _spui, _ضمیم,
  { {0x9967005c, 0x7e6a0061, 0xd6d80088, 0x00000000}},  //   _стол, _msfp, уту_,
  { {0xf1b90c1e, 0x7c2f0b25, 0xd46900ec, 0x00000000}},  //   viš_, nscr, тиле_,
  { {0x6fdd0129, 0x7c2f0026, 0x386b0026, 0x00000000}},  //   pèci, iscr, _iscr_,
  { {0xfe09001d, 0xf1b90091, 0x7c3d01a2, 0x00000000}},  //   _mắc_, tiš_, hrsr,
  { {0x798d027e, 0xfe090011, 0x349500d7, 0x00000000}},  //   njaw, _lắc_, _кабр,
  { {0x20060011, 0x78ad15e1, 0xb33c0066, 0x00000000}},  //   _cuoi_, nzav, _ilħn,
  { {0x69c43c3c, 0x81bc001e, 0x442f0009, 0x00000000}},  //   znie, _svēt, msg_,
  { {0xf1b9003b, 0x672701d5, 0x69c40036, 0x00000000}},  //   piš_, _mejj, ynie,
  { {0x81bc0089, 0x9f5c000a, 0x00000000, 0x00000000}},  //   _dvēs, _livè_,   ,
  { {0x69d6028c, 0x2d920263, 0xfe09001d, 0x00000000}},  //   voye, _voye_, _bắc_,
  { {0x69c40046, 0xb92b0011, 0x442f0544, 0x00000000}},  //   wnie, _thuỷ_, isg_,
  { {0x69c409a2, 0x69d600f4, 0xc9b601fc, 0x00000000}},  //   tnie, toye, асањ,
  { {0x7c2f1e53, 0x2d80013e, 0x394b0544, 0x00000000}},  //   bscr, _unie_, _cccs_,

  { {0x69c4028c, 0xe8fa005e, 0x7d041bf2, 0x00000000}},  // [e000] rnie, тла_, _igis,
  { {0x69c4001e, 0x998d0bf8, 0x61e4002b, 0x00000000}},  //   snie, češ_, ċili,
  { {0x672701d5, 0x443d0036, 0x69c421bf, 0x00000000}},  //   _dejj, erw_, pnie,
  { {0x1e56007b, 0x7c240009, 0x6607012d, 0x00000000}},  //   ישער_, _kwir, _dujk,
  { {0x7ddd3c3d, 0x9f4f008e, 0x99980006, 0x00000000}},  //   mést, _jugó_, strų_,
  { {0xd25a06e1, 0x6727002b, 0x7c2421a4, 0x00000000}},  //   вци_, _gejj, _mwir,
  { {0x20060198, 0xfe67004b, 0x7d04012d, 0x00000000}},  //   _suoi_, _بد_, _ogis,
  { {0x20060198, 0xa2da0201, 0x74160445, 0x00000000}},  //   _puoi_, _पुण्, _نورا,
  { {0x2006028c, 0x64a30887, 0x7e780009, 0x00000000}},  //   _quoi_, _дата, _srvp,
  { {0x20060207, 0x7d0411c6, 0x66000cfd, 0x00000000}},  //   _vuoi_, _agis, _himk,
  { {0x78ad0197, 0x7c2f0050, 0xfe090011, 0x00000000}},  //   zzav, wscr, _rắc_,
  { {0x20063c3e, 0xfe09001d, 0x7c2f0270, 0x00000000}},  //   _tuoi_, _sắc_, tscr,
  { {0xa2da007d, 0x98a2000a, 0x29de0016, 0x00000000}},  //   _पुत्, _bekč_, nïau_,
  { {0x09b1001c, 0x69c800f4, 0x7c2f0051, 0x00000000}},  //   ीच्य, éden, rscr,
  { {0xff1700b6, 0x9f3700b3, 0x7c2f0a89, 0x00000000}},  //   _דקות_, _כנגד_, sscr,
  { {0x4efb009b, 0x442f0016, 0x78ad00d4, 0x00000000}},  //   _בלוג, ysg_, tzav,
  { {0x7c24018e, 0xfe090011, 0x225e0093, 0x00000000}},  // [e010] _gwir, _tắc_, _lptk_,
  { {0x78ad0091, 0x7c223b1c, 0x7dc80095, 0x00000000}},  //   rzav, _çora, hısl,
  { {0x17f80025, 0x41d6013d, 0x995c093f, 0x00000000}},  //   شركة_, डकास, _síť_,
  { {0xeef70104, 0x7bc70059, 0x6607012d, 0x00000000}},  //   במבר_, lnju, _vujk,
  { {0x44240016, 0x55520123, 0x7bc70168, 0x00000000}},  //   _cwm_, سپور, onju,
  { {0xfc3f002a, 0x9cd800b6, 0x3949006c, 0x00000000}},  //   irí_, בודה_, lgas_,
  { {0x356b0153, 0x92640025, 0x38693c3f, 0x00000000}},  //   _иран_, قديم, lwar_,
  { {0x3949010a, 0xe7eb013d, 0x00000000, 0x00000000}},  //   ngas_, _जीता_,   ,
  { {0x394901c5, 0x44243c40, 0x00000000, 0x00000000}},  //   igas_, _gwm_,   ,
  { {0xf8b2009b, 0x399c000c, 0x225e0022, 0x00000000}},  //   פשי_, _vísi_, _fptk_,
  { {0x9f470129, 0x69dd23b5, 0x59c70164, 0x00000000}},  //   _sinó_, _okse, रचार,
  { {0xcb09009b, 0xfc3f01e5, 0x2b5a00c4, 0x00000000}},  //   _טל_, frí_, _sbpc_,
  { {0xfc3f0129, 0x9f4701aa, 0x752900d9, 0x00000000}},  //   grí_, _dinò_, _meez,
  { {0x386909e2, 0xdb1c0065, 0x39490d94, 0x00000000}},  //   dwar_, mirë, egas_,
  { {0x68e3005f, 0xfaa300ed, 0x3a990088, 0x00000000}},  //   əndi, паро, аттю_,
  { {0x39490039, 0x0906007e, 0xf2d20049, 0x00000000}},  //   ggas_, спан, פען_,
  { {0xea0000ad, 0x660028bc, 0x25bd005b, 0x00000000}},  // [e020] _nhất_, _rimk, diwl_,
  { {0x69dd0292, 0xe8f70175, 0x3949007f, 0x00000000}},  //   _ekse, слу_, agas_,
  { {0x44240016, 0x44d4001a, 0x7ddd009d, 0x00000000}},  //   _swm_, _sπ_, céss,
  { {0x99860054, 0x7ddd0010, 0x00000000, 0x00000000}},  //   _الحو, lésr,   ,
  { {0xea00001d, 0x75290068, 0x00000000, 0x00000000}},  //   _chất_, _deez,   ,
  { {0x29de0016, 0xd5b20123, 0x69c1009d, 0x00000000}},  //   rïau_, _کفر_, élev,
  { {0x3164001c, 0xa7a70088, 0x29de0016, 0x00000000}},  //   temz_, _укра_, sïau_,
  { {0xdb1c0065, 0x914a01ee, 0x7529297d, 0x00000000}},  //   firë, учка_, _geez,
  { {0x7ddd0010, 0xd0071e8a, 0x00000000, 0x00000000}},  //   zéss, бење_,   ,
  { {0xc3220055, 0x752900bb, 0x9f4700f6, 0x00000000}},  //   _নাকি_, _zeez, _sinò_,
  { {0x8c000044, 0x11d6041f, 0x39490006, 0x00000000}},  //   ্ঠান_, _людя, ygas_,
  { {0x69c80047, 0xc693009b, 0xdb0500c4, 0x00000000}},  //   édel, לאת_, _ilhé,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ddd0010, 0xfc3f1ad4, 0x00000000, 0x00000000}},  //   téss, rrí_,   ,
  { {0x0f57012e, 0xfe090011, 0x3d950242, 0x00000000}},  //   _היום_, _hắn_, _микр,
  { {0x39490006, 0x3869000a, 0x7ddd1152, 0x00000000}},  //   ugas_, twar_, réss,
  { {0xa2da02f4, 0x39490211, 0x23ab0030, 0x00000000}},  // [e030] _पुस्, rgas_, _høje_,
  { {0x386901d6, 0xfe090011, 0x39490058, 0x00000000}},  //   rwar_, _mắn_, sgas_,
  { {0x38691575, 0x00000000, 0x00000000, 0x00000000}},  //   swar_,   ,   ,
  { {0x69dd3c41, 0xea000082, 0x76450022, 0x00000000}},  //   _ukse, _phất_, ruhy,
  { {0xf1c90082, 0xfe090082, 0x00000000, 0x00000000}},  //   hạc_, _nắn_,   ,
  { {0x752902c2, 0xe29901e0, 0x80dc013d, 0x00000000}},  //   _weez, иал_, _पड़े,
  { {0xa189007c, 0x25600173, 0x23ab0190, 0x00000000}},  //   ибка_, _bčlč_, _nøje_,
  { {0xea00001d, 0xfe090011, 0xdb1c0065, 0x00000000}},  //   _thất_, _bắn_, tirë,
  { {0xfe090011, 0xae03013d, 0x249200ea, 0x00000000}},  //   _cắn_, _रंजन_, øymt_,
  { {0x5334005e, 0x23ab0190, 0x00000000, 0x00000000}},  //   _неут, _bøje_,   ,
  { {0x93880175, 0x236731f8, 0xdb1c0065, 0x00000000}},  //   _уста_, menj_, sirë,
  { {0x82d6007b, 0x7d090006, 0x6e3c0010, 0x00000000}},  //   _וועג_, žesn, árba,
  { {0x22470047, 0xfe090011, 0x399c01dc, 0x00000000}},  //   lunk_, _gắn_, _míst_,
  { {0xbea503dc, 0x98a2001e, 0xf1c90082, 0x00000000}},  //   _малк, _nekā_, bạc_,
  { {0x22470010, 0x23ab0146, 0x00000000, 0x00000000}},  //   nunk_, _gøje_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe9d70245, 0xfe090082, 0x08c60228, 0x00000000}},  // [e040] іку_, _xắn_, цбан,
  { {0x9b461880, 0x236731f8, 0x7ddd1f1f, 0x00000000}},  //   _بندو, jenj_, lésp,
  { {0xa6ca0054, 0x22473c42, 0x7bdc3122, 0x00000000}},  //   جوال_, junk_, moru,
  { {0xae5a0049, 0xa2da007d, 0x22470010, 0x00000000}},  //   יכער, _पुष्, dunk_,
  { {0x7986002b, 0xb87b0047, 0x938a00a8, 0x00000000}},  //   _inkw, _szív, иска_,
  { {0x7bdc0f04, 0xfe090011, 0x7a150036, 0x00000000}},  //   noru, _rắn_, _wąte,
  { {0xe5a6019d, 0xdb153c43, 0x22470010, 0x00000000}},  //   _диви, nizá, gunk_,
  { {0xf1260099, 0x7bdc3c44, 0x00000000, 0x00000000}},  //   цько, horu,   ,
  { {0xa2da0164, 0xd5b9008b, 0x75220020, 0x00000000}},  //   _पुर्, _усё_, mboz,
  { {0x644201f3, 0x6d40000c, 0xfe090082, 0x00000000}},  //   mroi, óman, _vắn_,
  { {0x7bdc179c, 0x00000000, 0x00000000, 0x00000000}},  //   doru,   ,   ,
  { {0xfe090082, 0x00000000, 0x00000000, 0x00000000}},  //   _tắn_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbebc001e, 0x7bdc0066, 0x7986000a, 0x00000000}},  //   rbīb, goru, _ankw,
  { {0xda7801e0, 0x64421c7e, 0x7e2a0088, 0x00000000}},  //   оят_, hroi, _тіла_,
  { {0x752211e4, 0x23670087, 0x64422c69, 0x00000000}},  //   jboz, zenj_, kroi,
  { {0x22470010, 0x7bdc0232, 0x7dd60010, 0x00000000}},  // [e050] zunk_, boru, yász,
  { {0x644200f4, 0x81c20044, 0x7bdc0035, 0x00000000}},  //   droi, ৃতি_, coru,
  { {0x23670059, 0x69c10010, 0x320c1d48, 0x00000000}},  //   venj_, éles, _nudy_,
  { {0x6442009d, 0x48c90044, 0x671b0164, 0x00000000}},  //   froi, _শরীর, _प्रक_,
  { {0x63850081, 0x399c000c, 0x64420052, 0x00000000}},  //   згла, _víst_, groi,
  { {0x22470047, 0x78fa009b, 0xdb1c009d, 0x00000000}},  //   tunk_, _לפרו, tiré,
  { {0x3f89001d, 0x23670087, 0x00000000, 0x00000000}},  //   _đau_, renj_,   ,
  { {0x7bdc3c45, 0x22470010, 0x9f5c3c46, 0x00000000}},  //   zoru, runk_, _diví_,
  { {0x7bdc011f, 0x2019008d, 0x644200f4, 0x00000000}},  //   yoru, ësi_, croi,
  { {0x22470010, 0xdb1c009d, 0x00000000, 0x00000000}},  //   punk_, piré,   ,
  { {0x7bdc0208, 0x3cfe0204, 0x00000000, 0x00000000}},  //   voru, रेने_,   ,
  { {0x7bdc0022, 0x00000000, 0x00000000, 0x00000000}},  //   woru,   ,   ,
  { {0x7bdc000d, 0x06e20044, 0x00000000, 0x00000000}},  //   toru, _বলছি,   ,
  { {0xdb152b92, 0xe1f90006, 0x00000000, 0x00000000}},  //   tizá, lmų_,   ,
  { {0x6da6012b, 0xdee21534, 0x7bdc1131, 0x00000000}},  //   _ника, _поши, roru,
  { {0x7d76002c, 0x7bdc001a, 0x64420133, 0x00000000}},  //   _رابط, soru, yroi,
  { {0x7bdc045e, 0x661b0521, 0xfe090011, 0x00000000}},  // [e060] poru, _čuka, _mắm_,
  { {0xfe09001d, 0x6c7b00a0, 0x46f6026b, 0x00000000}},  //   _lắm_, _פריד, пчет,
  { {0xfe050163, 0x8b9b034e, 0xdd8f0014, 0x00000000}},  //   _üçün_, _הבית, _شوی_,
  { {0xfe090011, 0x80dc0061, 0xb33c01f3, 0x00000000}},  //   _nắm_, _पडले, _ilħi,
  { {0x845a003b, 0x7522065a, 0x397b009b, 0x00000000}},  //   срет_, rboz, _הטכנ,
  { {0x64423c47, 0x00000000, 0x00000000, 0x00000000}},  //   rroi,   ,   ,
  { {0x27f700b9, 0x3f98000c, 0x93cb009e, 0x00000000}},  //   řené_, örum_, حانہ_,
  { {0xfe090011, 0x6442065d, 0x7ae101a2, 0x00000000}},  //   _cắm_, proi, ülti,
  { {0x04430b11, 0xb87b0010, 0xb4aa02be, 0x00000000}},  //   _петн, _nyíl, _указ_,
  { {0x995c01dc, 0x672e0146, 0x00000000, 0x00000000}},  //   _níž_, _jebj,   ,
  { {0x1df9007c, 0x68e601c3, 0x00000000, 0x00000000}},  //   жены_, _lykd,   ,
  { {0xfe090082, 0x25a61163, 0x7ae500b0, 0x00000000}},  //   _gắm_, nkol_, _ryht,
  { {0x61e201d5, 0xf1b3009b, 0xed58007e, 0x00000000}},  //   _ikol, _אסף_, чоў_,
  { {0x661c01c5, 0x9f5c00fa, 0x00000000, 0x00000000}},  //   _otrk, _divã_,   ,
  { {0x25a63c48, 0xaf5b009b, 0x1f5b009b, 0x00000000}},  //   kkol_, _הכוכ, _הדוא,
  { {0xf773089d, 0x61e201d5, 0x1994005e, 0x00000000}},  //   کار_, _jkol, нася,
  { {0xa2be0316, 0xa3dc0204, 0xe70b09b9, 0x00000000}},  // [e070] _वेस्, ठवा_, متان_,
  { {0x61e2002b, 0x00000000, 0x00000000, 0x00000000}},  //   _lkol,   ,   ,
  { {0x61e20cce, 0xfbd00076, 0x363401b7, 0x00000000}},  //   _okol, _حتي_, فرنس,
  { {0x6d4f0011, 0x29350049, 0xa5f81076, 0x00000000}},  //   ngca, _קאָן_, пеху_,
  { {0x76430010, 0x69cd0091, 0x00000000, 0x00000000}},  //   ányb, mnae,   ,
  { {0xfe090011, 0x61e20173, 0x00000000, 0x00000000}},  //   _sắm_, _akol,   ,
  { {0xa1f50143, 0x00000000, 0x00000000, 0x00000000}},  //   мџиј,   ,   ,
  { {0x69cd3c49, 0x23600107, 0x6d5d00bb, 0x00000000}},  //   nnae, đija_, jfsa,
  { {0xbf050201, 0xe1f90006, 0xbcfb009d, 0x00000000}},  //   रश्न_, rmų_, nféd,
  { {0x644b015e, 0xdb1e00f4, 0x2d893c4a, 0x00000000}},  //   mugi, _empê, _anae_,
  { {0x9d460259, 0xdb0800f4, 0x644b1f72, 0x00000000}},  //   менд, _élém, lugi,
  { {0x6d4f001c, 0x9f45146b, 0x656b08eb, 0x00000000}},  //   ggca, illé_, negh,
  { {0x64590e42, 0x644b0058, 0x61fb010e, 0x00000000}},  //   ntwi, nugi, mmul,
  { {0x61e90004, 0x61fb001a, 0x645901a0, 0x00000000}},  //   llel, lmul, itwi,
  { {0xea00001d, 0x09e60072, 0x25bf001a, 0x00000000}},  //   _chết_, довн, _omul_,
  { {0xfe090082, 0x644b0009, 0xf2d20049, 0x00000000}},  //   _lắk_, kugi, דעל_,
  { {0x20071532, 0x09e30245, 0x644b2645, 0x00000000}},  // [e080] _kini_, тотн, jugi,
  { {0x62810fdf, 0x68e60006, 0x200f2248, 0x00000000}},  //   _orlo, _vykd, _mugi_,
  { {0x61e91322, 0x200f0058, 0xdb1c004a, 0x00000000}},  //   klel, _lugi_, nirí,
  { {0xea00001d, 0x29d701d5, 0x20070020, 0x00000000}},  //   _đặc_, għad_, _lini_,
  { {0x62813c4b, 0x644b0026, 0x25a60a3b, 0x00000000}},  //   _arlo, gugi, rkol_,
  { {0x61e23c4c, 0x2007000b, 0xdb07000c, 0x00000000}},  //   _skol, _nini_, lhjá,
  { {0x661c016e, 0x644b0006, 0x6d5d01d6, 0x00000000}},  //   _utrk, augi, yfsa,
  { {0x30a60088, 0x644b3c4d, 0x61fb011c, 0x00000000}},  //   дров, bugi, gmul,
  { {0xc05a01fb, 0x20073c4e, 0x628109ce, 0x00000000}},  //   цій_, _bini_, _erlo,
  { {0x2007037e, 0x61e201d5, 0x61e90035, 0x00000000}},  //   _cini_, _wkol, alel,
  { {0x6d4f001c, 0x20073c4f, 0x61e9007f, 0x00000000}},  //   tgca, _dini_, blel,
  { {0x61e23c50, 0x61e9121e, 0x56370049, 0x00000000}},  //   _ukol, clel, ואטע_,
  { {0x20073c51, 0xd90f0014, 0x6d5d000c, 0x00000000}},  //   _fini_, یید_, rfsa,
  { {0x09c7001c, 0x200704be, 0x9f5800b0, 0x00000000}},  //   रच्य, _gini_, örä_,
  { {0x69cd0091, 0x644b01ee, 0xdb1c008e, 0x00000000}},  //   tnae, zugi, cirí,
  { {0x20073c52, 0xdb0700b0, 0x200f02d4, 0x00000000}},  //   _zini_, kijö, _yugi_,
  { {0x7d0d006c, 0x64590009, 0x656b001a, 0x00000000}},  // [e090] _igas, xtwi, vegh,
  { {0x644b0061, 0x7c2d01f3, 0x3f9c012d, 0x00000000}},  //   vugi, _iwar, _jovu_,
  { {0x61e003ed, 0x7c2d00e0, 0x61e90095, 0x00000000}},  //   koml, _hwar, ylel,
  { {0x91fc0089, 0x3f9c0091, 0x4efb0049, 0x00000000}},  //   _spān, _lovu_, קלאג,
  { {0x321e103f, 0x656b3c53, 0xe3650aed, 0x00000000}},  //   _atty_, regh, екли,
  { {0x644b04cb, 0xe6670ae0, 0x3f9c0ec4, 0x00000000}},  //   rugi, _отбо, _novu_,
  { {0xc2e70055, 0x645900b4, 0x644b0058, 0x00000000}},  //   গেনি_, stwi, sugi,
  { {0x7d0d3340, 0x2007027e, 0x7dc8006b, 0x00000000}},  //   _ngas, _sini_, nıst,
  { {0x200701aa, 0x321e1372, 0x61e90145, 0x00000000}},  //   _pini_, _etty_, rlel,
  { {0x61fb001a, 0x7d0d281b, 0x442d0020, 0x00000000}},  //   smul, _agas, _iwe_,
  { {0x20073c54, 0x6609010a, 0xddc60256, 0x00000000}},  //   _vini_, _kiek, ебни,
  { {0x442d01aa, 0xdb1e0f07, 0x7c2d2c0b, 0x00000000}},  //   _kwe_, _impé, _bwar,
  { {0x442d0263, 0x5e5600a2, 0x660920bd, 0x00000000}},  //   _jwe_, ولیس_, _miek,
  { {0x7c2d01d5, 0x442d0202, 0x6609082e, 0x00000000}},  //   _dwar, _mwe_, _liek,
  { {0x442d0f5b, 0x00000000, 0x00000000, 0x00000000}},  //   _lwe_,   ,   ,
  { {0x66093c55, 0x442d0075, 0x3f9c0091, 0x00000000}},  //   _niek, _owe_, _zovu_,
  { {0x7c2d30de, 0x186701f9, 0x6d560061, 0x00000000}},  // [e0a0] _gwar, нати_, _icya,
  { {0x5c5b00a3, 0xdb070030, 0x7d0d2a7b, 0x00000000}},  //   _צדיק, dhjæ, _zgas,
  { {0x7c2d3c56, 0x660913d1, 0x442d03ef, 0x00000000}},  //   _zwar, _biek, _awe_,
  { {0x66090046, 0x442d3c57, 0x799d0319, 0x00000000}},  //   _ciek, _bwe_, _gosw,
  { {0xb4aa03d7, 0x442d0093, 0x6609008a, 0x00000000}},  //   खने_, _cwe_, _diek,
  { {0x442d0263, 0xd2500025, 0x00000000, 0x00000000}},  //   _dwe_, لنت_,   ,
  { {0x442d3c58, 0x3872018e, 0x9294007e, 0x00000000}},  //   _ewe_, lwyr_, тайц,
  { {0xd1300025, 0x39520016, 0x00000000, 0x00000000}},  //   جمة_, ngys_,   ,
  { {0x442d0016, 0x3872018e, 0x6b9e0007, 0x00000000}},  //   _gwe_, nwyr_, _oopg,
  { {0x660900b5, 0x7c2d0009, 0x7d0d0026, 0x00000000}},  //   _ziek, _rwar, _sgas,
  { {0x7c2d0343, 0x3872018e, 0x316d0144, 0x00000000}},  //   _swar, hwyr_, beez_,
  { {0x717303ec, 0x7dc8006b, 0xdd12005d, 0x00000000}},  //   _مهما, xıst, rüşm,
  { {0x69c1009d, 0x799d0f10, 0x8fa614df, 0x00000000}},  //   èlem, _rosw, _паде,
  { {0x3872018e, 0xf4120044, 0x3f9c0d16, 0x00000000}},  //   dwyr_, _হবার_, _uovu_,
  { {0x6b9e3c59, 0xf99f000a, 0x00000000, 0x00000000}},  //   _dopg, _fièl_,   ,
  { {0x7c2d0036, 0x7d0d0213, 0xdb1c00c4, 0x00000000}},  //   _twar, _ugas, tirã,
  { {0x3872018e, 0x7ddd0010, 0x7dc80477, 0x00000000}},  // [e0b0] gwyr_, kész, rıst,
  { {0x66091404, 0x2cb3005a, 0x442d122a, 0x00000000}},  //   _siek, ındı_, _rwe_,
  { {0x6609001e, 0x6e3a054e, 0x442d00b4, 0x00000000}},  //   _piek, nstb, _swe_,
  { {0x7bc70209, 0x27e10066, 0x442d0156, 0x00000000}},  //   liju, sohn_, _pwe_,
  { {0x3872005b, 0x7524004a, 0x66090d8f, 0x00000000}},  //   cwyr_, ñiza, _viek,
  { {0x7bc73126, 0x66090036, 0x7ddd0010, 0x00000000}},  //   niju, _wiek, gész,
  { {0x22560a90, 0x442d18c3, 0x66090995, 0x00000000}},  //   نلود_, _wwe_, _tiek,
  { {0xceb80036, 0x201900c4, 0x442d00b4, 0x00000000}},  //   dzę_, ísio_, _twe_,
  { {0x442d1af8, 0x7bc72134, 0x6e3a09d0, 0x00000000}},  //   _uwe_, kiju, estb,
  { {0xa283007a, 0x645b206d, 0x657b3c5a, 0x00000000}},  //   _میتو, _iqui, _hauh,
  { {0x273c0224, 0x7bc70006, 0x657b00b0, 0x00000000}},  //   lání_, diju, _kauh,
  { {0x657b3c5b, 0xdb1c12c5, 0xf99f0026, 0x00000000}},  //   _jauh, dirá, _noè_,
  { {0x273c00b9, 0x853a009b, 0x6b9e2cdc, 0x00000000}},  //   nání_, וגרי, _popg,
  { {0x6f1a001c, 0x8fa20057, 0x2d990065, 0x00000000}},  //   cctc, _ваше, ajse_,
  { {0xceb80036, 0x273c00b9, 0x8db601e1, 0x00000000}},  //   czę_, hání_, _аспі,
  { {0x273c00b9, 0x657b00b0, 0x9f450051, 0x00000000}},  //   kání_, _nauh, illí_,
  { {0x26170181, 0x2d5a0059, 0x6b9e0471, 0x00000000}},  // [e0c0] _aço_, _všeč_, _topg,
  { {0x273c0224, 0x3872018e, 0xdb1c008e, 0x00000000}},  //   dání_, rwyr_, birá,
  { {0x645b0181, 0x1dc6013d, 0x7ddd0010, 0x00000000}},  //   _aqui, _लगात, vész,
  { {0xe9a60478, 0x3872005b, 0x00000000, 0x00000000}},  //   _рамп, pwyr_,   ,
  { {0x77910167, 0x00000000, 0x00000000, 0x00000000}},  //   _گیلا,   ,   ,
  { {0x7c22014a, 0x00000000, 0x00000000, 0x00000000}},  //   _çoru,   ,   ,
  { {0x133900a1, 0x877b071c, 0x7ddd0010, 0x00000000}},  //   رتوں_, _קאלי, rész,
  { {0x80e00055, 0x167700b6, 0x28c7006e, 0x00000000}},  //   _পৃষ্, _בגלל_, _रेडि,
  { {0xb4650014, 0x39420145, 0x00000000, 0x00000000}},  //   _مدله, _mdks_,   ,
  { {0x44260555, 0x39420022, 0xdce404eb, 0x00000000}},  //   mpo_, _ldks_, _naiđ,
  { {0xdd9105d4, 0x777c04bd, 0x03a3012b, 0x00000000}},  //   مود_, _marx, _њихо,
  { {0x6e3a054e, 0x75f800b9, 0x2b410471, 0x00000000}},  //   rstb, bíze, _sdhc_,
  { {0xceb80046, 0x4426002d, 0x5c740121, 0x00000000}},  //   szę_, npo_, алят,
  { {0x44260219, 0x8f340726, 0xdb1c077b, 0x00000000}},  //   ipo_, _секц, tirá,
  { {0x273c00b9, 0x7bc73c5c, 0xcb3402dc, 0x00000000}},  //   zání_, riju, ресъ,
  { {0x1e9700b6, 0x7bc7010a, 0x5d550745, 0x00000000}},  //   _יכול_, siju, _скит,
  { {0x657b00b0, 0x7bc70006, 0xb33c002b, 0x00000000}},  // [e0d0] _rauh, piju, _moħb,
  { {0x273c0224, 0x76430047, 0x777c00d4, 0x00000000}},  //   vání_, ányo, _carx,
  { {0x645b085d, 0xdced012d, 0xdce401f3, 0x00000000}},  //   _squi, _baać, _iniġ,
  { {0xe66402dc, 0x273c01dc, 0x7d090089, 0x00000000}},  //   ртфо, tání_, _tīrī,
  { {0x798f0016, 0xc7cb007e, 0x657b00b0, 0x00000000}},  //   _incw, _жыве_, _vauh,
  { {0x273c00b9, 0xfe0a0082, 0xb444007e, 0x00000000}},  //   rání_, _hắt_, рэцк,
  { {0x56940069, 0x657b170b, 0x44260dd7, 0x00000000}},  //   _карт, _tauh, apo_,
  { {0x273c00b9, 0x38790085, 0x00000000, 0x00000000}},  //   pání_, _kssr_,   ,
  { {0xfe0a001d, 0x600902d3, 0x6717013d, 0x00000000}},  //   _mắt_, нним_, _तलाक_,
  { {0x777c04bd, 0x53b70204, 0x237700a1, 0x00000000}},  //   _xarx, _अतिश, _جارح,
  { {0x6da600ed, 0xdb1c000c, 0xed5a007e, 0x00000000}},  //   гина, gnrý, нон_,
  { {0x644b0197, 0x63a10010, 0x40351d84, 0x00000000}},  //   orgi, _holn, _бедс,
  { {0xd7b30061, 0x00000000, 0x00000000, 0x00000000}},  //   ंघाच,   ,   ,
  { {0x317f002d, 0x105200a1, 0x903a0049, 0x00000000}},  //   lduz_, _اکٹھ, _טענה,
  { {0xd94600d7, 0xfe0a001d, 0x63a13c5d, 0x00000000}},  //   леви, _bắt_, _moln,
  { {0x443f0363, 0xfe0a0011, 0x317f002d, 0x00000000}},  //   _ovu_, _cắt_, nduz_,
  { {0xe9d7005e, 0x6735129d, 0xfe0a0011, 0x00000000}},  // [e0e0] укт_, _bezj, _dắt_,
  { {0x7c240279, 0x6b56007c, 0x26180164, 0x00000000}},  //   _itir, _стих, _बंदी_,
  { {0x443f3c5e, 0x46f6007c, 0x98ab0089, 0x00000000}},  //   _avu_, учат, _vecā_,
  { {0x35e50cf2, 0xfe0a0082, 0x1e560049, 0x00000000}},  //   аців, _gắt_, טשער_,
  { {0x63a100ee, 0x69c62998, 0x6615002d, 0x00000000}},  //   _boln, _imke, _euzk,
  { {0x442608d3, 0x63a10142, 0x7c2400e7, 0x00000000}},  //   rpo_, _coln, _mtir,
  { {0x63a11124, 0x644b36c5, 0x6d4408d3, 0x00000000}},  //   _doln, argi, _odia,
  { {0x44260198, 0x6d440051, 0x443f0146, 0x00000000}},  //   ppo_, _ndia, _fvu_,
  { {0x7c240009, 0x443f0146, 0x00000000, 0x00000000}},  //   _ntir, _gvu_,   ,
  { {0x6d440181, 0x63a1251a, 0x00000000, 0x00000000}},  //   _adia, _goln,   ,
  { {0x4424001c, 0x7d1d001c, 0x7c24185b, 0x00000000}},  //   _htm_, tcss, _atir,
  { {0xac190373, 0x38603261, 0x7a150036, 0x00000000}},  //   кому_, ktir_, _wątk,
  { {0x6d440016, 0x2a7a00f6, 0xa3c80316, 0x00000000}},  //   _ddia, _aspb_, _उषा_,
  { {0xfe0a0011, 0x46b40061, 0x442424e7, 0x00000000}},  //   _sắt_, ंनाह, _mtm_,
  { {0x7c24005f, 0x44240022, 0x386b0009, 0x00000000}},  //   _etir, _ltm_, _spcr_,
  { {0x38603c5f, 0x8e470025, 0xbebc0089, 0x00000000}},  //   ftir_, _إليك_, ecīg,
  { {0x9817023c, 0xb6c900a1, 0xfe0a0082, 0x00000000}},  // [e0f0] ابرا, ھائے_, _vắt_,
  { {0x628802a4, 0xfc3f0051, 0xd6db0679, 0x00000000}},  //   _ordo, msí_, нте_,
  { {0x4424033b, 0xfe0a001d, 0x63a10036, 0x00000000}},  //   _atm_, _tắt_, _roln,
  { {0x63a1093b, 0x4424018c, 0x00000000, 0x00000000}},  //   _soln, _btm_,   ,
  { {0x63a12dec, 0x6288002d, 0x2283014a, 0x00000000}},  //   _poln, _ardo, _sık_,
  { {0x8c1c0049, 0x443f0020, 0xfc3f0051, 0x00000000}},  //   עווי, _vvu_, isí_,
  { {0xe299008b, 0x5b5800b6, 0x63a13302, 0x00000000}},  //   тай_, אשון_, _voln,
  { {0x63a10046, 0x628310b1, 0xe045026b, 0x00000000}},  //   _woln, rvno, ании,
  { {0x6288014a, 0x442406ed, 0x63a10010, 0x00000000}},  //   _erdo, _gtm_, _toln,
  { {0xb0680025, 0x9e65007e, 0xdee50216, 0x00000000}},  //   اصيل_, авод, иопи,
  { {0xf77200b6, 0x60ce006b, 0x42990188, 0x00000000}},  //   חקי_, _əhmə, _جناح_,
  { {0x2a7a1ad0, 0xee3616e8, 0x3860000c, 0x00000000}},  //   _rspb_, шню_, ytir_,
  { {0xd1b8007a, 0x55760049, 0x68ef000a, 0x00000000}},  //   _حالا_, בערן_, _nycd,
  { {0xbcfb009f, 0x61e407ac, 0x00000000, 0x00000000}},  //   mfél, čile,   ,
  { {0xdb250010, 0xeb970216, 0xdb1c010e, 0x00000000}},  //   ásár, шир_, virä,
  { {0x38603c60, 0xe206000c, 0xe9d700ed, 0x00000000}},  //   ttir_, _þótt_, акс_,
  { {0xfbdf0181, 0x47c6008b, 0x38603a04, 0x00000000}},  // [e100] guês_, абав, utir_,
  { {0x442401a3, 0xdb1c0051, 0x2d80068d, 0x00000000}},  //   _rtm_, rnró, _haie_,
  { {0x3860009f, 0x44240061, 0x66022224, 0x00000000}},  //   stir_, _stm_, tmok,
  { {0x38601402, 0xb8cc0044, 0xbcfb0092, 0x00000000}},  //   ptir_, _কই_, kfél,
  { {0xdce40825, 0x66021b8e, 0x2d80010e, 0x00000000}},  //   _obič, rmok, _maie_,
  { {0x05160055, 0x66020032, 0x026a0077, 0x00000000}},  //   ারের_, smok, вший_,
  { {0x69d60020, 0xa5960088, 0x9596012b, 0x00000000}},  //   onye, _кращ, _краљ,
  { {0x69d60047, 0x23690091, 0x200e0173, 0x00000000}},  //   nnye, đaja_, _sifi_,
  { {0x442401a3, 0xe5d9025f, 0xbcfb05ee, 0x00000000}},  //   _utm_, _сфрј_, gfél,
  { {0x81460167, 0x2d920173, 0x65693c61, 0x00000000}},  //   _چنان, _anye_, _zbeh,
  { {0x2d801273, 0x24860030, 0xc22400a1, 0x00000000}},  //   _baie_, lvom_, _اکتو,
  { {0x2fc70022, 0xd08601ab, 0x00000000, 0x00000000}},  //   _emng_, _выки,   ,
  { {0xa3ca03d7, 0x200e3c62, 0x9f4501aa, 0x00000000}},  //   _लगा_, _tifi_, kolè_,
  { {0x2cab0009, 0xfd1f0197, 0x2d850036, 0x00000000}},  //   rycd_, scì_, śle_,
  { {0xfb84008b, 0xf9c7005e, 0x1995005e, 0x00000000}},  //   цыян, ащан, бавя,
  { {0x24860091, 0xdb1e00f6, 0x3915013b, 0x00000000}},  //   kvom_, _empà, смар,
  { {0xa3d6001c, 0x3dc90058, 0xcbc700a2, 0x00000000}},  // [e110] ाचा_, _imaw_, _نزدي,
  { {0x2d80002d, 0xe70b023c, 0x00000000, 0x00000000}},  //   _zaie_, نتان_,   ,
  { {0x75150054, 0x00000000, 0x00000000, 0x00000000}},  //   مواض,   ,   ,
  { {0xb9950025, 0x24190147, 0xbcfb0010, 0x00000000}},  //   _الحب, годы_, yfél,
  { {0xb8cc0055, 0x661b0925, 0x248900c4, 0x00000000}},  //   _কে_, _čuku, íam_,
  { {0xfe0a0011, 0x69cd0016, 0x6a140014, 0x00000000}},  //   _lắp_, liae, _دبیر,
  { {0x0bb8009b, 0x3875014a, 0xdd2c0006, 0x00000000}},  //   שלום_, şarı_, _lėšo,
  { {0x69cd018e, 0x22490119, 0xfe0a0011, 0x00000000}},  //   niae, čak_, _nắp_,
  { {0x78ad00d4, 0xf0a602dc, 0x2d800f69, 0x00000000}},  //   nyav, йкъл_, _raie_,
  { {0xbcfb009f, 0x3fb70055, 0x67f000b0, 0x00000000}},  //   rfél, ীক্ষ, täji,
  { {0xbebc001e, 0xfe0a0011, 0x2d803c63, 0x00000000}},  //   ecīb, _bắp_, _paie_,
  { {0xed571969, 0xea000011, 0xfe0a0011, 0x00000000}},  //   бою_, _đắc_, _cắp_,
  { {0x3f690a94, 0x69cd018e, 0x61e93c64, 0x00000000}},  //   _било_, diae, moel,
  { {0x09d00061, 0x61e90554, 0x00000000, 0x00000000}},  //   सच्य, loel,   ,
  { {0x2d80001a, 0x69cd0bd8, 0x24860142, 0x00000000}},  //   _taie_, fiae, zvom_,
  { {0xfd12004b, 0x69cd0016, 0x2ef801a2, 0x00000000}},  //   _عجب_, giae, ürfe_,
  { {0x69d6121b, 0xb7160025, 0x00000000, 0x00000000}},  // [e120] rnye, مباش,   ,
  { {0x61e91703, 0x00000000, 0x00000000, 0x00000000}},  //   hoel,   ,   ,
  { {0x6b7b061e, 0x61e93a16, 0x7c360016, 0x00000000}},  //   _גרינ, koel, _hwyr,
  { {0x24860027, 0x844601b7, 0x61e9323a, 0x00000000}},  //   tvom_, مختل, joel,
  { {0x61e90250, 0x00000000, 0x00000000, 0x00000000}},  //   doel,   ,   ,
  { {0xf99f0263, 0x7bce31d9, 0x9f58014a, 0x00000000}},  //   _chèf_, nibu, örü_,
  { {0x7d16018e, 0xb2860783, 0x9f453c65, 0x00000000}},  //   _ogys, сылк, illä_,
  { {0x75d60431, 0x61e9022b, 0x7984011c, 0x00000000}},  //   _ايرا, goel, ndiw,
  { {0xf48400d3, 0x79843c66, 0x7bce0095, 0x00000000}},  //   _بازی, idiw, kibu,
  { {0xfe0a001d, 0x7bce3c67, 0x673e0010, 0x00000000}},  //   _sắp_, jibu, napj,
  { {0x7c360016, 0xe21601b7, 0xbcfb0161, 0x00000000}},  //   _awyr, _طباع, rfém,
  { {0x8cb503d7, 0x644200b0, 0xd24f0025, 0x00000000}},  //   उनलो, osoi, _سنه_,
  { {0x644216c6, 0xac190888, 0x79840016, 0x00000000}},  //   nsoi, рогу_, ddiw,
  { {0x7d160047, 0x69da00f4, 0x69cd018e, 0x00000000}},  //   _egys, éten, wiae,
  { {0x7f3b00bd, 0x5e260d3a, 0x69cd0016, 0x00000000}},  //   _געוו, _اعتق, tiae,
  { {0x38350099, 0x23ab0030, 0x644200b0, 0x00000000}},  //   жнар, _højt_, ksoi,
  { {0x69cd018e, 0xdb05008d, 0x9f470051, 0x00000000}},  // [e130] riae, _kohë, _ghnó_,
  { {0x61e900e7, 0x69cd3c68, 0x7bce2bfe, 0x00000000}},  //   zoel, siae, cibu,
  { {0x163b0054, 0xb8f003d7, 0x61e900e7, 0x00000000}},  //   اسطة_, _वे_, yoel,
  { {0x7afa3c69, 0x00000000, 0x00000000, 0x00000000}},  //   ütte,   ,   ,
  { {0x04670264, 0x61e901b5, 0x9f4500f4, 0x00000000}},  //   стем, voel, solé_,
  { {0xd2a9003b, 0xc7b8007e, 0x75220026, 0x00000000}},  //   икле_, _лёс_, acoz,
  { {0x61e900bb, 0x7777002b, 0x00000000, 0x00000000}},  //   toel, mexx,   ,
  { {0xd9fb02fb, 0x77770066, 0x7bce0232, 0x00000000}},  //   ्षित_, lexx, zibu,
  { {0x61e90197, 0x9f4500b0, 0x7bce0009, 0x00000000}},  //   roel, yllä_, yibu,
  { {0x3e7a1a2f, 0x20110010, 0x7777002b, 0x00000000}},  //   _būt_, özi_, nexx,
  { {0xd9fb001c, 0x753b00b5, 0x61e93c6a, 0x00000000}},  //   ्षात_, _keuz, poel,
  { {0xed5a0175, 0x1d0a15c4, 0x248d3c6b, 0x00000000}},  //   шом_, иени_, _krem_,
  { {0x7bce0bb2, 0xccfa01e1, 0x00000000, 0x00000000}},  //   tibu, рхні_,   ,
  { {0xb33c01f3, 0x00000000, 0x00000000, 0x00000000}},  //   _noħl,   ,   ,
  { {0x7bce049a, 0x9c870428, 0x3b0a20e6, 0x00000000}},  //   ribu, _počí, рево_,
  { {0x753b0089, 0x7bce033b, 0x224500d9, 0x00000000}},  //   _neuz, sibu, _mvlk_,
  { {0x201f0b32, 0x673e15aa, 0x00000000, 0x00000000}},  // [e140] nqui_, tapj,   ,
  { {0x46f60265, 0xdb07000c, 0x3f853c6c, 0x00000000}},  //   очет, skjá, ndlu_,
  { {0xa96a00ed, 0x869a2798, 0x00000000, 0x00000000}},  //   _кина_, штат_,   ,
  { {0x213f04cb, 0x644200b0, 0x00000000, 0x00000000}},  //   jauh_, tsoi,   ,
  { {0x248d07c8, 0x439401ab, 0x240a030d, 0x00000000}},  //   _crem_, залс, анди_,
  { {0x64420dd9, 0xdb050bdb, 0x00000000, 0x00000000}},  //   rsoi, _bohè,   ,
  { {0x6442028c, 0x966319f1, 0x3f85103c, 0x00000000}},  //   ssoi, _окре, ddlu_,
  { {0x248d02cc, 0x753b08ff, 0xe476007e, 0x00000000}},  //   _frem_, _geuz, _музэ,
  { {0x673c0149, 0x248d0059, 0xcf9a0143, 0x00000000}},  //   _kerj, _grem_, ајн_,
  { {0x39400051, 0x661c00b0, 0xd00700ed, 0x00000000}},  //   hais_, _kurk, оење_,
  { {0x39401104, 0x673c0059, 0x6e94300e, 0x00000000}},  //   kais_, _merj, чину,
  { {0x63a8004f, 0x69da0047, 0x39400ebc, 0x00000000}},  //   _hodn, étel, jais_,
  { {0x661c20bb, 0x39400006, 0x0ca80cee, 0x00000000}},  //   _lurk, dais_, отри_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63a80627, 0x661c301a, 0xaff90049, 0x00000000}},  //   _modn, _nurk, _פּני,
  { {0x3940049a, 0x2d85001e, 0x63a80062, 0x00000000}},  //   gais_, ēles_, _lodn,
  { {0x661c022b, 0x673c3210, 0x753b00bb, 0x00000000}},  // [e150] _aurk, _berj, _reuz,
  { {0xf773031d, 0x661c1422, 0x65600051, 0x00000000}},  //   بار_, _burk, _acmh,
  { {0x39403c6d, 0x248d01ee, 0x661c016e, 0x00000000}},  //   bais_, _srem_, _curk,
  { {0x39400917, 0x248d00d4, 0xe6180088, 0x00000000}},  //   cais_, _prem_, іді_,
  { {0xc8640aef, 0xa3d60061, 0x673c0635, 0x00000000}},  //   _отри, ाचं_, _ferj,
  { {0x248d001a, 0x661c0095, 0x1a6800a1, 0x00000000}},  //   _vrem_, _furk, _دیہی_,
  { {0x661c0210, 0x05770070, 0x61e40059, 0x00000000}},  //   _gurk, _وارد, čiln,
  { {0x248d00c4, 0xdb05009d, 0x673c012d, 0x00000000}},  //   _trem_, _cohé, _zerj,
  { {0xdb1e021e, 0x661c01ee, 0xb367005e, 0x00000000}},  //   _ympä, _zurk, _мъжк,
  { {0xd9c30044, 0x201f0d62, 0x394008ad, 0x00000000}},  //   ্কিম, rqui_, zais_,
  { {0x6d5d001c, 0x201f0efe, 0x764504b3, 0x00000000}},  //   fgsa, squi_, nshy,
  { {0xdb1c0051, 0x6281002b, 0x247d01aa, 0x00000000}},  //   mhré, _islo, _kňm_,
  { {0x69da027b, 0x394000f4, 0x1c4301e1, 0x00000000}},  //   étem, vais_, нням,
  { {0x7e630061, 0xe81f013d, 0x201d00e0, 0x00000000}},  //   _tqnp, _बढ़ा_, _iuwi_,
  { {0x6459112f, 0x3af5007c, 0x29190145, 0x00000000}},  //   huwi, дятс, _bgsa_,
  { {0x673c01d5, 0x64590007, 0x442f1721, 0x00000000}},  //   _serj, kuwi, kpg_,
  { {0x39400917, 0x661c00b0, 0x2e2101e5, 0x00000000}},  // [e160] rais_, _surk, _hóf_,
  { {0x39403b3b, 0x62810466, 0x661c00b0, 0x00000000}},  //   sais_, _oslo, _purk,
  { {0x39400a0a, 0x673c01d9, 0x63a80466, 0x00000000}},  //   pais_, _verj, _rodn,
  { {0x63a80059, 0x271900b9, 0x6e3c0035, 0x00000000}},  //   _sodn, třní_, ârbi,
  { {0x63a80428, 0x673c0149, 0xc953019b, 0x00000000}},  //   _podn, _terj, _אמר_,
  { {0x60d60006, 0x79860ea6, 0x00000000, 0x00000000}},  //   _žymo, _hakw,   ,
  { {0x66e30216, 0x63a80b41, 0x79860058, 0x00000000}},  //   _зора, _vodn, _kakw,
  { {0xcb1300b6, 0x63a80036, 0x61e40059, 0x00000000}},  //   עלה_, _wodn, čilo,
  { {0x5ea90055, 0x69c1013d, 0x798600e7, 0x00000000}},  //   _ছেলে, रोटी, _makw,
  { {0x79863c6e, 0xbcfb009d, 0x00000000, 0x00000000}},  //   _lakw, ngée,   ,
  { {0x79860319, 0xdd910439, 0x00000000, 0x00000000}},  //   _oakw, نود_,   ,
  { {0xa0a60081, 0x79860eb0, 0x00000000, 0x00000000}},  //   _наед, _nakw,   ,
  { {0x5c0709b2, 0xdcef001a, 0x77b3013f, 0x00000000}},  //   зява, decă, _yıxı,
  { {0xea000082, 0x7f41088a, 0x628100ea, 0x00000000}},  //   _đạc_, calq, _yslo,
  { {0x798621a4, 0x2cb300b9, 0x64593c6f, 0x00000000}},  //   _bakw, _řadě_, zuwi,
  { {0x6d5d001c, 0x79860093, 0x2fce0009, 0x00000000}},  //   qgsa, _cakw, _hmfg_,
  { {0x798604cb, 0x321e0036, 0x6d4d0058, 0x00000000}},  // [e170] _dakw, _luty_, _idaa,
  { {0x7c2d3c70, 0x9cd800a3, 0x37070867, 0x00000000}},  //   _itar, _מוחה_, пчев,
  { {0x1a6500a1, 0xf7700379, 0x65790045, 0x00000000}},  //   _تیزی_, طال_, tewh,
  { {0xf6500355, 0x25a9009f, 0x6459011c, 0x00000000}},  //   ائل_, ðal_, tuwi,
  { {0xfc4600b9, 0x00000000, 0x00000000, 0x00000000}},  //   říve_,   ,   ,
  { {0x386900ce, 0x321e0036, 0xe2990816, 0x00000000}},  //   mtar_, _buty_, жак_,
  { {0xf77200b6, 0x64590022, 0x798621a4, 0x00000000}},  //   _שקל_, suwi, _yakw,
  { {0x321e00ab, 0x645900e0, 0x00000000, 0x00000000}},  //   _duty_, puwi,   ,
  { {0x7c2d0061, 0x00000000, 0x00000000, 0x00000000}},  //   _ntar,   ,   ,
  { {0x442d00b0, 0x386909f7, 0x6d4d3c71, 0x00000000}},  //   _ite_, itar_, _adaa,
  { {0x7c2d002d, 0x628105fa, 0x90e702fd, 0x00000000}},  //   _atar, _uslo, _کسان,
  { {0x7a1c016c, 0x442d0065, 0x64490fdc, 0x00000000}},  //   _učti, _kte_, _kvei,
  { {0xa158007e, 0xdc13006b, 0xdb1e00f6, 0x00000000}},  //   _хачу_, _ağıl, _impú,
  { {0x38693c72, 0x442d00c4, 0x7c2d0051, 0x00000000}},  //   dtar_, _mte_, _dtar,
  { {0x7c2d0347, 0xca750783, 0x38690035, 0x00000000}},  //   _etar, нуты, etar_,
  { {0x3869020c, 0x442d002d, 0xcee702fd, 0x00000000}},  //   ftar_, _ote_, _ورژن_,
  { {0x3869002a, 0x18670088, 0xe7aa007c, 0x00000000}},  // [e180] gtar_, мати_, овал_,
  { {0x0903012b, 0x69cf0145, 0x7a150036, 0x00000000}},  //   тпун, _emce, _wątp,
  { {0x442d008d, 0x3f870089, 0x7986015d, 0x00000000}},  //   _ate_, _manu_, _takw,
  { {0x893600a6, 0x38693c73, 0xd91002fd, 0x00000000}},  //   _تعدا, btar_, _میز_,
  { {0x3869095e, 0x442d0023, 0x7c2d0066, 0x00000000}},  //   ctar_, _cte_, _xtar,
  { {0x75290173, 0x28c7007d, 0x3f873c74, 0x00000000}},  //   _efez, _रेटि, _nanu_,
  { {0xe29702a8, 0xfd650011, 0xf623007e, 0x00000000}},  //   дај_, _chuố, _адсо,
  { {0xd1300025, 0x442d00d9, 0xe1f90006, 0x00000000}},  //   دمة_, _fte_, glų_,
  { {0x442d2635, 0x67230825, 0x3f872ebd, 0x00000000}},  //   _gte_, žnje, _banu_,
  { {0xdb1e0129, 0x3f870016, 0xdefa007e, 0x00000000}},  //   _empú, _canu_, жым_,
  { {0x442d3c75, 0x1df9007e, 0x3eb83c76, 0x00000000}},  //   _zte_, зены_, árt_,
  { {0x25a61b28, 0x7c2d00f6, 0x386928e0, 0x00000000}},  //   njol_, _ptar, ytar_,
  { {0x4fc60088, 0x3869006b, 0x3f8708ad, 0x00000000}},  //   _оска, xtar_, _fanu_,
  { {0xb34502d5, 0x3f873c77, 0x9f4500f6, 0x00000000}},  //   maçã, _ganu_, colà_,
  { {0xb34502d5, 0xa0070025, 0x61e238d4, 0x00000000}},  //   laçã, _تقول_, _kjol,
  { {0x38693c78, 0x2369037e, 0x3f871aef, 0x00000000}},  //   ttar_, đaji_, _zanu_,
  { {0xb34502d5, 0x28f8007c, 0x61e20203, 0x00000000}},  // [e190] naçã, деть_, _mjol,
  { {0x442d07c9, 0xe1f90006, 0x7d001a4a, 0x00000000}},  //   _rte_, zlų_, ümse,
  { {0x64493c79, 0x442d0cce, 0x06b20044, 0x00000000}},  //   _svei, _ste_, _টেবি,
  { {0x3869008d, 0x29d701d5, 0x61e20023, 0x00000000}},  //   ptar_, għat_, _njol,
  { {0x442d3c7a, 0x2329017a, 0x00000000, 0x00000000}},  //   _qte_, поли_,   ,
  { {0xb3450181, 0xe7301095, 0x32060fd5, 0x00000000}},  //   daçã, _نصف_, _ahoy_,
  { {0x3f870466, 0x00000000, 0x00000000, 0x00000000}},  //   _ranu_,   ,   ,
  { {0x64490635, 0x3f870107, 0x32060145, 0x00000000}},  //   _tvei, _sanu_, _choy_,
  { {0xe0d93c7b, 0x442d093b, 0xb34502d5, 0x00000000}},  //   яви_, _ute_, gaçã,
  { {0x60061036, 0xfd65001d, 0x3fcd0044, 0x00000000}},  //   нным_, _thuố, রক্ষ,
  { {0xf7720476, 0x25ad0116, 0x61e202e7, 0x00000000}},  //   נקט_, _koel_, _fjol,
  { {0xb34500c4, 0x00000000, 0x00000000, 0x00000000}},  //   baçã,   ,   ,
  { {0xb34502d5, 0x61fb014a, 0x7bd50065, 0x00000000}},  //   caçã, mlul, fizu,
  { {0xdee501f9, 0x61fb0207, 0x7bd50032, 0x00000000}},  //   _поли, llul, gizu,
  { {0x63730279, 0x6e950025, 0xdce411af, 0x00000000}},  //   mını, _ألعا, _obić,
  { {0x63730279, 0x25ad1cbb, 0x3eb801e3, 0x00000000}},  //   lını, _noel_, ørte_,
  { {0x6d460281, 0xa8060140, 0x7bd50032, 0x00000000}},  // [e1a0] maka, езал, bizu,
  { {0x6d46027c, 0x6373005d, 0x7bd50023, 0x00000000}},  //   laka, nını, cizu,
  { {0xb34502d5, 0x25ad00bb, 0xbb3b034e, 0x00000000}},  //   zaçã, _boel_, _מעיי,
  { {0x6d46033b, 0xb9060044, 0x1c0400e8, 0x00000000}},  //   naka, _ফর_, _शीतल_,
  { {0x25ad3c7c, 0x63730279, 0xb34500c4, 0x00000000}},  //   _doel_, kını, xaçã,
  { {0x6d4606fe, 0xb34502d5, 0x69d601f6, 0x00000000}},  //   haka, vaçã, liye,
  { {0x6d461084, 0xbcfb00f4, 0x6373005d, 0x00000000}},  //   kaka, nfér, dını,
  { {0xb34502d5, 0x6d460390, 0x30a6003b, 0x00000000}},  //   taçã, jaka, еров,
  { {0x6d46020c, 0xe45300a1, 0x61e20ca2, 0x00000000}},  //   daka, _مہنگ, _vjol,
  { {0xb34502d5, 0x50b70025, 0x201800b0, 0x00000000}},  //   raçã, عديد_, öri_,
  { {0xd33700b6, 0x7bd50314, 0x6d460020, 0x00000000}},  //   _נראה_, vizu, faka,
  { {0xb3450181, 0x6d4604cb, 0xa3cc006e, 0x00000000}},  //   paçã, gaka, शोर_,
  { {0x69d601df, 0x63730279, 0x7bd50142, 0x00000000}},  //   diye, bını, tizu,
  { {0xbcfb028c, 0xf99f2ef4, 0x7d040046, 0x00000000}},  //   ffér, _chèn_, _dzis,
  { {0xda780ae0, 0x7bd50c55, 0x69d6026d, 0x00000000}},  //   нят_, rizu, fiye,
  { {0x69c40207, 0x6d46033b, 0x4efb009b, 0x00000000}},  //   ghie, caka, _מהוו,
  { {0x25ad00bb, 0x00000000, 0x00000000, 0x00000000}},  // [e1b0] _roel_,   ,   ,
  { {0x29d7002b, 0x25ad01c3, 0x3f8c005b, 0x00000000}},  //   għar_, _soel_, nddu_,
  { {0x25ad0116, 0x69d60284, 0x39420190, 0x00000000}},  //   _poel_, biye, _feks_,
  { {0x6373005d, 0x94790c27, 0x394200d9, 0x00000000}},  //   zını, дску_, _geks_,
  { {0x25ad1f4b, 0x6373047f, 0xc8670088, 0x00000000}},  //   _voel_, yını, _ятни,
  { {0x6d460010, 0x798d01d6, 0x394201ee, 0x00000000}},  //   zaka, ldaw, _zeks_,
  { {0x6d46033b, 0x61fb3c7d, 0x25ad010e, 0x00000000}},  //   yaka, tlul, _toel_,
  { {0x798d2c60, 0xdce40521, 0xa2240014, 0x00000000}},  //   ndaw, _ubić, دروه,
  { {0x6373027d, 0x6d46006c, 0x61fb01a3, 0x00000000}},  //   tını, vaka, rlul,
  { {0x6d4603b0, 0x69d63c7e, 0xddc90521, 0x00000000}},  //   waka, ziye, _ćošk,
  { {0x6373038c, 0x6d46020c, 0xeadc0055, 0x00000000}},  //   rını, taka, _ধর্ম,
  { {0x6373038c, 0x23690091, 0x645901c3, 0x00000000}},  //   sını, đaju_, orwi,
  { {0x6d46020c, 0xdb1c000c, 0x69d6014a, 0x00000000}},  //   raka, firð, viye,
  { {0x799d0038, 0x6d460127, 0x661b042c, 0x00000000}},  //   _answ, saka, _liuk,
  { {0x6d460149, 0x69c41eb6, 0x60c9014a, 0x00000000}},  //   paka, thie, lzem,
  { {0x60d60006, 0xdc14005d, 0x798d00e0, 0x00000000}},  //   _žymi, rşıy, gdaw,
  { {0x69d6047f, 0x60c9016e, 0x69c40de1, 0x00000000}},  // [e1c0] riye, nzem, rhie,
  { {0x69d6014a, 0x644b05d5, 0x7c3b0035, 0x00000000}},  //   siye, dsgi, ţurc,
  { {0x69c408ea, 0x394201a3, 0x64590546, 0x00000000}},  //   phie, _teks_, erwi,
  { {0x660900e7, 0x7c2400e7, 0x00000000, 0x00000000}},  //   _chek, _kuir,   ,
  { {0x65620065, 0x67230825, 0x6d443884, 0x00000000}},  //   rgoh, žnja, _meia,
  { {0x60c91478, 0xa3cc03d7, 0x6d443c7f, 0x00000000}},  //   dzem, शों_, _leia,
  { {0x386000f7, 0x64590ace, 0x6e231165, 0x00000000}},  //   luir_, arwi, _nunb,
  { {0xe1ef0076, 0x68ed0065, 0x00000000, 0x00000000}},  //   يسي_, _ëndë,   ,
  { {0x386029a6, 0x443f0066, 0x7c24009d, 0x00000000}},  //   nuir_, _gwu_, _nuir,
  { {0x44242a04, 0x6e23004a, 0xdb0700ea, 0x00000000}},  //   _ium_, _bunb, pkjø,
  { {0xa75b0049, 0x3d150061, 0x38600048, 0x00000000}},  //   ודיר, नेने_, huir_,
  { {0x3f8a040d, 0x44240362, 0x7c240048, 0x00000000}},  //   žbu_, _kum_, _buir,
  { {0x7c24002a, 0x6d44022b, 0x44241300, 0x00000000}},  //   _cuir, _deia, _jum_,
  { {0x38600129, 0x45280044, 0x6e2300f8, 0x00000000}},  //   duir_, মরিক_, _funb,
  { {0x4424002b, 0xac18007c, 0x6e230e08, 0x00000000}},  //   _lum_, тору_, _gunb,
  { {0x201c0020, 0x628800e0, 0x7c243c80, 0x00000000}},  //   _hivi_, _msdo, _fuir,
  { {0x44240181, 0x7c2400d4, 0x798d1576, 0x00000000}},  // [e1d0] _num_, _guir, rdaw,
  { {0x6609008d, 0x26e70044, 0xf7700426, 0x00000000}},  //   _shek, _করবো_, قام_,
  { {0x60c90197, 0x98140025, 0x442401e5, 0x00000000}},  //   zzem, شبكا, _aum_,
  { {0x38602c97, 0x644b0039, 0x44243c81, 0x00000000}},  //   buir_, tsgi, _bum_,
  { {0x4424000d, 0x3949011c, 0x64590506, 0x00000000}},  //   _cum_, maas_, urwi,
  { {0x39490250, 0x4424062c, 0x60c93947, 0x00000000}},  //   laas_, _dum_, vzem,
  { {0x66090065, 0xb364005e, 0x44241a40, 0x00000000}},  //   _thek, ръчк, _eum_,
  { {0x60c90948, 0x44243c82, 0x39493c83, 0x00000000}},  //   tzem, _fum_, naas_,
  { {0x6e230051, 0x6d440129, 0xf3670867, 0x00000000}},  //   _sunb, _reia, _атен,
  { {0xee391523, 0x60c90089, 0x6d443c84, 0x00000000}},  //   нно_, rzem, _seia,
  { {0x442408ba, 0x60c93c85, 0x201c0089, 0x00000000}},  //   _zum_, szem, _divi_,
  { {0xb2ba007b, 0x9b9602fd, 0x865a01ce, 0x00000000}},  //   _אמער, گلست, עדרי,
  { {0x7c240efe, 0x6d4400d6, 0x2a7a0022, 0x00000000}},  //   _quir, _veia, _sppb_,
  { {0x7052023c, 0xa066003b, 0x7bc7032e, 0x00000000}},  //   _انوا, _саша_, ghju,
  { {0xdb050d7f, 0x2d84009d, 0x65690022, 0x00000000}},  //   _pohá, ômes_, _oceh,
  { {0x201c037e, 0x3b0701f9, 0xf2d20049, 0x00000000}},  //   _zivi_, ѓето_, צען_,
  { {0xbcfb00fd, 0x98a3007c, 0x2d820020, 0x00000000}},  // [e1e0] ngél, бите, meke_,
  { {0x44240039, 0x2d8200d0, 0x3b860216, 0x00000000}},  //   _rum_, leke_, _слог,
  { {0x39490160, 0xdb1c0051, 0x4fba0049, 0x00000000}},  //   baas_, bhrá, עזעצ,
  { {0x44240016, 0x3935007e, 0x7ae1004a, 0x00000000}},  //   _pum_, _вэрс, últe,
  { {0x7e613c86, 0x386000d4, 0x7afe000a, 0x00000000}},  //   hulp, quir_, _hypt,
  { {0x2d8236b1, 0x00000000, 0x00000000, 0x00000000}},  //   heke_,   ,   ,
  { {0x66840123, 0x2d820145, 0x61ed0087, 0x00000000}},  //   _خیال, keke_, čaln,
  { {0x2d820243, 0x44243c87, 0x7e610240, 0x00000000}},  //   jeke_, _tum_, dulp,
  { {0x2d820232, 0x44240145, 0x00000000, 0x00000000}},  //   deke_, _uum_,   ,
  { {0x30770025, 0xdcf6006b, 0x212f03b2, 0x00000000}},  //   احية_, _sayğ, _efgh_,
  { {0x2002001e, 0x201c0197, 0x741301f7, 0x00000000}},  //   ēki_, _vivi_, _اولا,
  { {0xdcf6006b, 0x2b530203, 0x00000000, 0x00000000}},  //   _qayğ, _sdxc_,   ,
  { {0xdfda0265, 0x201c0011, 0x5c7402d3, 0x00000000}},  //   _пък_, _tivi_, блят,
  { {0x6e9404ac, 0xaedc0088, 0x00000000, 0x00000000}},  //   _вику, _облi,   ,
  { {0x2d82064a, 0x3949006a, 0x7e610035, 0x00000000}},  //   beke_, taas_, culp,
  { {0xf99f0011, 0xb33c01f3, 0x00000000, 0x00000000}},  //   _thèm_, _moħq,   ,
  { {0x3f8e05fa, 0x06b20044, 0x39492b48, 0x00000000}},  // [e1f0] _kafu_, _টেলি, raas_,
  { {0xb8cd006e, 0x3f8e002b, 0x394900ea, 0x00000000}},  //   _कप_, _jafu_, saas_,
  { {0x37073c88, 0x672304eb, 0xfc300bb6, 0x00000000}},  //   учав, žnjo, _وحی_,
  { {0x645d0039, 0xdb1e00c4, 0x68fd00ea, 0x00000000}},  //   _åsik, _empó, _tysd,
  { {0x64a5003b, 0xdcfd010a, 0x7e61002d, 0x00000000}},  //   рала, kesč, zulp,
  { {0x3f8e002b, 0x2d820032, 0xdb1e000a, 0x00000000}},  //   _nafu_, zeke_, _impò,
  { {0xfbb8009b, 0x00000000, 0x00000000, 0x00000000}},  //   רפות_,   ,   ,
  { {0x020501f9, 0x00000000, 0x00000000, 0x00000000}},  //   јзин,   ,   ,
  { {0x798f0090, 0x3f8e0258, 0x00000000, 0x00000000}},  //   _macw, _bafu_,   ,
  { {0xd00e0426, 0x2d8236a6, 0x1fb50216, 0x00000000}},  //   ولي_, weke_, рсир,
  { {0x2d82022b, 0x539a00a0, 0xd5b90309, 0x00000000}},  //   teke_, _שיעו, _आवाज,
  { {0x41e4007e, 0x7bc50085, 0x00000000, 0x00000000}},  //   _ліча, _alhu,   ,
  { {0x7e6112b5, 0x814c0049, 0x8afb013f, 0x00000000}},  //   sulp, _טעאַ, yyəç,
  { {0x09de0061, 0x2d8238fc, 0x7a1c0173, 0x00000000}},  //   नच्य, seke_, _pōto,
  { {0x7ff40879, 0xaa46007c, 0x09d6007e, 0x00000000}},  //   _اسنا, ребл, ацаў,
  { {0x7bc50dd6, 0xdb1c08aa, 0x00000000, 0x00000000}},  //   _elhu, nkré,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [e200]   ,   ,   ,
  { {0xeb9a0478, 0xe73a0072, 0x7afe00d9, 0x00000000}},  //   _рио_, теж_, _typt,
  { {0x39ea007e, 0xfaa60256, 0xdb1c00fa, 0x00000000}},  //   _адно_, _тано, tirõ,
  { {0x7bdc01a3, 0x25a0008e, 0x00000000, 0x00000000}},  //   liru, ñil_,   ,
  { {0x69c6396f, 0x00000000, 0x00000000, 0x00000000}},  //   _ilke,   ,   ,
  { {0x7bdc0006, 0x06661125, 0x7d010048, 0x00000000}},  //   niru, _پاسپ, lárú,
  { {0x6d560173, 0x3f8e39c6, 0x31c6003b, 0x00000000}},  //   _odya, _rafu_, исив,
  { {0x3f8e0020, 0x00000000, 0x00000000, 0x00000000}},  //   _safu_,   ,   ,
  { {0x3872004e, 0xcfa600ed, 0xdfa60098, 0x00000000}},  //   ntyr_, ашни, ајно,
  { {0x6602317c, 0x6d56004a, 0x7bdc00e7, 0x00000000}},  //   llok, _adya, jiru,
  { {0x7c36008d, 0x7bdc2399, 0x6e630194, 0x00000000}},  //   _atyr, diru, отяж,
  { {0x3f8e1475, 0x629a3c89, 0x00000000, 0x00000000}},  //   _wafu_, _irto,   ,
  { {0x76430047, 0x3f8e0418, 0x99890036, 0x00000000}},  //   ányz, _tafu_, ymał_,
  { {0x69c61c79, 0x7bdc0032, 0x7ff30f8b, 0x00000000}},  //   _alke, giru, _وسوا,
  { {0xe0e80044, 0x66020032, 0xf96b005e, 0x00000000}},  //   _পরিভ, klok, край_,
  { {0x39a40457, 0x89370025, 0x00000000, 0x00000000}},  //   ошув, شعرا,   ,
  { {0xdb5b007c, 0x6602013e, 0x00000000, 0x00000000}},  // [e210] _июн_, dlok,   ,
  { {0x629a0632, 0x69c63c8a, 0xc60f02f4, 0x00000000}},  //   _orto, _elke, िष्य_,
  { {0xb8fe03d7, 0x6602009f, 0x00000000, 0x00000000}},  //   _थे_, flok,   ,
  { {0x66023c8b, 0x00000000, 0x00000000, 0x00000000}},  //   glok,   ,   ,
  { {0x629a184d, 0xa8790049, 0x24f80147, 0x00000000}},  //   _arto, _גאָר, анцы_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb5a701e0, 0x9567005e, 0xdb1c010f, 0x00000000}},  //   _край, _възд, chrä,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7dc60051, 0x629a00bb, 0x657b0058, 0x00000000}},  //   _nósa, _erto, _ibuh,
  { {0x248d01d5, 0x724200a1, 0xdb1c209e, 0x00000000}},  //   _isem_, _کھول, skré,
  { {0x7bdc0006, 0xb4e7013d, 0x00000000, 0x00000000}},  //   viru, _पशु_,   ,
  { {0xb33c002b, 0xc0a8009e, 0x51842742, 0x00000000}},  //   _inħa, _چاول_, _муча,
  { {0x248d0224, 0x213f0169, 0x7bdc0035, 0x00000000}},  //   _jsem_, mbuh_, tiru,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4e3503ab, 0xdd110161, 0x657b0091, 0x00000000}},  //   _اعتز, _výšk, _obuh,
  { {0x7bdc0006, 0x7ae10a87, 0x3e710010, 0x00000000}},  //   siru, últa, mát_,
  { {0x7bdc0056, 0x98a300da, 0x3e7113ae, 0x00000000}},  // [e220] piru, пите, lát_,
  { {0xbb860054, 0x387205ad, 0x2d920068, 0x00000000}},  //   _الدي, rtyr_, _haye_,
  { {0x2d9209e0, 0x38723c8c, 0x248d0007, 0x00000000}},  //   _kaye_, styr_, _asem_,
  { {0x5efa0049, 0x00000000, 0x00000000, 0x00000000}},  //   אפעד,   ,   ,
  { {0x3e710047, 0x6ba5000c, 0x66020093, 0x00000000}},  //   hát_, _útgá, rlok,
  { {0x3f850243, 0x3e71139d, 0x39400dec, 0x00000000}},  //   jelu_, kát_, lbis_,
  { {0x3e710047, 0x3f851712, 0x66021487, 0x00000000}},  //   ját_, delu_, plok,
  { {0x2d9236e3, 0x4a9b0049, 0xc034025f, 0x00000000}},  //   _naye_, ריקג, ониј,
  { {0x39400051, 0x38600fd1, 0x600601e5, 0x00000000}},  //   ibis_, nrir_, uðmo,
  { {0x3f850016, 0xb7fa007d, 0x6e5402dc, 0x00000000}},  //   gelu_, ्तिम_, овоф,
  { {0xd33700b6, 0x3e710047, 0x2d922efe, 0x00000000}},  //   _הרבה_, gát_, _baye_,
  { {0x7dc60051, 0x00000000, 0x00000000, 0x00000000}},  //   _pósa,   ,   ,
  { {0x3f8510b0, 0x2d920173, 0x50ba0257, 0x00000000}},  //   belu_, _daye_, _حداد_,
  { {0x2f1807d0, 0x3e7128e4, 0x38603c8d, 0x00000000}},  //   _коль_, bát_, drir_,
  { {0x38600115, 0x6d5a0023, 0x00000000, 0x00000000}},  //   erir_, ėtar,   ,
  { {0x2d9201aa, 0x386012a3, 0x26e70044, 0x00000000}},  //   _gaye_, frir_, _করলো_,
  { {0xbbeb007a, 0x6d4f0169, 0xa3e80061, 0x00000000}},  // [e230] _مردم_, maca, मचा_,
  { {0x6d4f049d, 0x7d0d3c8e, 0x2a980173, 0x00000000}},  //   laca, _izas, _fčb_,
  { {0x39402f08, 0x21260093, 0x3ebe0039, 0x00000000}},  //   bbis_, _ogoh_, nytt_,
  { {0x6d4f038c, 0x3860045b, 0x3f85016c, 0x00000000}},  //   naca, brir_, zelu_,
  { {0x9980038c, 0x69df0023, 0x00000000, 0x00000000}},  //   lmiş_, miqe,   ,
  { {0x248d0059, 0x3dc90016, 0x36d53c8f, 0x00000000}},  //   _vsem_, _llaw_, _догр,
  { {0xd5ae026c, 0x9980005a, 0x6d4f0dd2, 0x00000000}},  //   رہے_, nmiş_, kaca,
  { {0x3e710a50, 0x657b0061, 0x69cd005b, 0x00000000}},  //   vát_, _ubuh, nhae,
  { {0x6e2a010f, 0x6d4f006b, 0x394b00f4, 0x00000000}},  //   _aufb, daca, _mecs_,
  { {0x3e7128e4, 0x2d9201a3, 0x9980005a, 0x00000000}},  //   tát_, _saye_, kmiş_,
  { {0x59c90309, 0x2d923c90, 0x6d4f3c91, 0x00000000}},  //   रसार, _paye_, faca,
  { {0x6d4f001c, 0x3e710d7f, 0x3860000c, 0x00000000}},  //   gaca, rát_, yrir_,
  { {0x7d0d0046, 0x00e5026c, 0x3e710047, 0x00000000}},  //   _czas, _بتای, sát_,
  { {0x3860028c, 0xcb6a003b, 0x2480005a, 0x00000000}},  //   vrir_, јаве_, çimi_,
  { {0xdde9007a, 0x2d9201aa, 0xdcfd0089, 0x00000000}},  //   _گروه_, _taye_, resā,
  { {0x61e90018, 0x6d4f0ab2, 0x3e550089, 0x00000000}},  //   nnel, caca, māt_,
  { {0x20c90201, 0x394036f9, 0x574a0867, 0x00000000}},  // [e240] िनिध, rbis_, изам_,
  { {0x61e93c92, 0x628102ae, 0x38600249, 0x00000000}},  //   hnel, _oplo, rrir_,
  { {0x3e55001e, 0x61fb00b0, 0x61e90006, 0x00000000}},  //   nāt_, koul, knel,
  { {0x98a601fc, 0x656b00e0, 0x386000c4, 0x00000000}},  //   _диме, gggh, prir_,
  { {0x69c401d5, 0x61e901ee, 0x62813c52, 0x00000000}},  //   mkie, dnel, _aplo,
  { {0x69c40036, 0xd25a0331, 0x3e550089, 0x00000000}},  //   lkie, аци_, kāt_,
  { {0x04fc0055, 0x6d4f01f6, 0x69c40009, 0x00000000}},  //   েশের_, yaca, okie,
  { {0x69c4270b, 0x799600e0, 0x61e901e3, 0x00000000}},  //   nkie, ndyw, gnel,
  { {0xbfaa0407, 0xdb1e00c4, 0x6d4f01ed, 0x00000000}},  //   атне_, _impõ, vaca,
  { {0x7dc6027b, 0x61e9001a, 0x3dc90606, 0x00000000}},  //   _bóso, anel, _slaw_,
  { {0x7d040263, 0x6d4f03fe, 0x69c429be, 0x00000000}},  //   _ayis, taca, kkie,
  { {0x61fb009d, 0x7d040045, 0xdb1c0048, 0x00000000}},  //   coul, _byis, bhrú,
  { {0x6d4f014a, 0x394b1a86, 0x48cc0044, 0x00000000}},  //   raca, _recs_, লপুর,
  { {0x6d4f0c2b, 0x62810061, 0x60cc005d, 0x00000000}},  //   saca, _yplo, ılmı,
  { {0x69cd01d6, 0x2e4a005e, 0x656b0039, 0x00000000}},  //   thae, _тяло_, yggh,
  { {0x61e00119, 0x9980005d, 0x3c2f010f, 0x00000000}},  //   niml, rmiş_, _tüv_,
  { {0x69cd2801, 0xef180089, 0xfb270014, 0x00000000}},  // [e250] rhae, deļi_, _وردپ,
  { {0x61ed003b, 0x7bce01a2, 0x7de40010, 0x00000000}},  //   čali, chbu, rőse,
  { {0x61e00279, 0x61e9004e, 0x7c2d3c93, 0x00000000}},  //   kiml, ynel, _huar,
  { {0x69c4114b, 0x7c2d04be, 0x8afa009b, 0x00000000}},  //   ckie, _kuar, _להתי,
  { {0x1835007b, 0x69dd002b, 0x628101d9, 0x00000000}},  //   _מאָל_, _imse, _splo,
  { {0x61fb01aa, 0x38690065, 0x7c2d3c94, 0x00000000}},  //   woul, muar_, _muar,
  { {0x386930ea, 0xc5f30044, 0x7c2d2c5f, 0x00000000}},  //   luar_, জতবা_, _luar,
  { {0xdb1e1ffa, 0x61e90035, 0x7c2d009d, 0x00000000}},  //   _impô, unel, _ouar,
  { {0x3869008d, 0xa3b8026c, 0x61fb3c95, 0x00000000}},  //   nuar_, _ڈالر_, roul,
  { {0x69c43c96, 0x6f030016, 0x20050026, 0x00000000}},  //   zkie, _pync, ulli_,
  { {0x62811f9c, 0x61fb36a5, 0x69dd15c8, 0x00000000}},  //   _uplo, poul, _omse,
  { {0x3869008d, 0x4425002d, 0x442d023a, 0x00000000}},  //   kuar_, _hil_, _kue_,
  { {0x7c2d3c97, 0x3869008d, 0x442d3c98, 0x00000000}},  //   _cuar, juar_, _jue_,
  { {0x38693c99, 0x69dd018e, 0x7c2d0065, 0x00000000}},  //   duar_, _amse, _duar,
  { {0xfaa303f3, 0xa3ac0183, 0x442d021e, 0x00000000}},  //   наро, गात_, _lue_,
  { {0x442501d5, 0x7c2d2d82, 0x316d009d, 0x00000000}},  //   _lil_, _fuar, ngez_,
  { {0x69c40125, 0x442500ab, 0x442d00f4, 0x00000000}},  // [e260] rkie, _oil_, _nue_,
  { {0x69c43c9a, 0xdc9b00b3, 0x61e00279, 0x00000000}},  //   skie, _פסיכ, ziml,
  { {0x3bbb009b, 0x249f0093, 0x3a0602fd, 0x00000000}},  //   _המיד, _arum_, _فکری_,
  { {0x4425018e, 0x38691e20, 0x442d3c9b, 0x00000000}},  //   _ail_, buar_, _bue_,
  { {0x44250233, 0x61e00279, 0x299b0104, 0x00000000}},  //   _bil_, viml, _הסכמ,
  { {0x442d3c9c, 0x395200ab, 0x44252ca6, 0x00000000}},  //   _due_, lays_, _cil_,
  { {0x44250279, 0x249f009f, 0x61e0014a, 0x00000000}},  //   _dil_, _erum_, timl,
  { {0x442d0219, 0x11d80054, 0x44252238, 0x00000000}},  //   _fue_, توبة_, _eil_,
  { {0x64490bc4, 0x442502c0, 0x442d0169, 0x00000000}},  //   _gwei, _fil_, _gue_,
  { {0x61e0011f, 0x93c800a1, 0xe3a40167, 0x00000000}},  //   siml, _بارہ_, _تشری,
  { {0x3869008d, 0x6449001f, 0x7c2d0149, 0x00000000}},  //   zuar_, _zwei, _suar,
  { {0x7bde3be3, 0x442d05e6, 0x63ba001a, 0x00000000}},  //   _ampu, _yue_, _hotn,
  { {0x8fa6313f, 0xf1a90204, 0x38690065, 0x00000000}},  //   _наде, कारन, xuar_,
  { {0xe10b007b, 0x38690065, 0xbcfb009d, 0x00000000}},  //   _פּאָ, vuar_, dgét,
  { {0xfc3f3c9d, 0x63ba0059, 0x7c2500b0, 0x00000000}},  //   spí_, _motn, _vihr,
  { {0x3869008d, 0x7c2d002a, 0x7bde1902, 0x00000000}},  //   tuar_, _tuar, _empu,
  { {0x290f0073, 0x2d8b00c4, 0x2ca000ab, 0x00000000}},  // [e270] åga_, mece_, _grid_,
  { {0x3869008d, 0x442d028c, 0x2d8b3af4, 0x00000000}},  //   ruar_, _rue_, lece_,
  { {0x38690a0d, 0xf559036d, 0x26c700b9, 0x00000000}},  //   suar_, قلاب_, áno_,
  { {0x44251baf, 0x2d9901b5, 0x2d8b0b76, 0x00000000}},  //   _sil_, ndse_, nece_,
  { {0x442d0919, 0x26c7092f, 0x44250272, 0x00000000}},  //   _que_, šno_, _pil_,
  { {0x442d028c, 0xfe780006, 0x63ba3c9e, 0x00000000}},  //   _vue_, ktį_, _cotn,
  { {0x44250374, 0x994d0027, 0x221500e2, 0x00000000}},  //   _vil_, _môžu_, мфир,
  { {0x44250100, 0x63a83c9f, 0xbcfb0010, 0x00000000}},  //   _wil_, _endn, ngés,
  { {0x4425137b, 0x2d8b011f, 0x932704e8, 0x00000000}},  //   _til_, dece_, _فران,
  { {0x442502e4, 0x2d990116, 0x60060783, 0x00000000}},  //   _uil_, edse_, мным_,
  { {0xaf09006d, 0x00000000, 0x00000000, 0x00000000}},  //   تقدم_,   ,   ,
  { {0xfce602d3, 0x9f450026, 0x63ba108f, 0x00000000}},  //   домо, golò_, _zotn,
  { {0x68e904eb, 0xef1801c5, 0x7bde0085, 0x00000000}},  //   _žedn, deļu_, _pmpu,
  { {0x39520038, 0x2d9901d6, 0xe9df0048, 0x00000000}},  //   ways_, adse_, _amú_,
  { {0x2d8b012d, 0x8a06007e, 0x00000000, 0x00000000}},  //   bece_, дзве,   ,
  { {0x2ca001d5, 0x2d8b3ca0, 0x9f453ca1, 0x00000000}},  //   _trid_, cece_, colò_,
  { {0x39520133, 0x48e3003b, 0x00000000, 0x00000000}},  // [e280] rays_, вотв,   ,
  { {0xbcfb1055, 0x395200ab, 0x2cad0190, 0x00000000}},  //   rgét, says_, åede_,
  { {0x39520f36, 0x63a80009, 0x63ba3ca2, 0x00000000}},  //   pays_, _rndn, _rotn,
  { {0x80d40044, 0xe5c50088, 0x63ba3237, 0x00000000}},  //   দপত্, нсіо, _sotn,
  { {0x63ba0059, 0xc9530104, 0x00000000, 0x00000000}},  //   _potn, _שמש_,   ,
  { {0x2d8b0035, 0x9cd70104, 0x00000000, 0x00000000}},  //   zece_, וונה_,   ,
  { {0xf1a9001c, 0x2d993ca3, 0x41a90061, 0x00000000}},  //   कांन, ydse_, कांस,
  { {0xcb1300b6, 0x3d0f0061, 0xa3ac006e, 0x00000000}},  //   כלו_, _ठरले_, गाह_,
  { {0x2d8b0198, 0x63ba00d9, 0x00000000, 0x00000000}},  //   vece_, _totn,   ,
  { {0xdfd00076, 0x9ed800ed, 0x64423ca4, 0x00000000}},  //   ايد_, змот_, mpoi,
  { {0x644200b0, 0xdd91006d, 0x9f450026, 0x00000000}},  //   lpoi, هود_, tolò_,
  { {0xa3ac0183, 0xfe780006, 0x00000000, 0x00000000}},  //   गाव_, rtį_,   ,
  { {0x2d8b3ca5, 0x644200b0, 0x2d991eda, 0x00000000}},  //   rece_, npoi, rdse_,
  { {0x2d8b0059, 0xab84005e, 0x00000000, 0x00000000}},  //   sece_, куск,   ,
  { {0x7bc7009f, 0xbcfb00f4, 0x2d8b038e, 0x00000000}},  //   rkju, ggér, pece_,
  { {0x3f8c2da3, 0x3e780047, 0x68290107, 0x00000000}},  //   ledu_, mét_, _ažda,
  { {0xb81507d8, 0x2aff007d, 0xc4c400a1, 0x00000000}},  // [e290] едај, _शुरु_, _ئے_,
  { {0xdb1c000c, 0x64420aa4, 0x3f8c1703, 0x00000000}},  //   skrá, dpoi, nedu_,
  { {0x3e7807fd, 0x6fcd004a, 0x00000000, 0x00000000}},  //   nét_, _júca,   ,
  { {0x25a90211, 0x6fc400f6, 0x00000000, 0x00000000}},  //   ñal_, _dòci,   ,
  { {0x63850216, 0x7c38012d, 0xa928013e, 0x00000000}},  //   егла, _čvrk, _vyžá,
  { {0xe299003b, 0x3e780010, 0x3f8c3ca6, 0x00000000}},  //   зак_, két_, jedu_,
  { {0x3e780010, 0xdd32006b, 0x45d50088, 0x00000000}},  //   jét_, _nəşr, _зовс,
  { {0x69da009d, 0x00000000, 0x00000000, 0x00000000}},  //   étex,   ,   ,
  { {0x60250401, 0x00000000, 0x00000000, 0x00000000}},  //   ндиа,   ,   ,
  { {0x443f0149, 0xf2c7007c, 0x9f5e01aa, 0x00000000}},  //   _itu_, _осен, notè_,
  { {0x3e780010, 0x5de61deb, 0xa3ac0309, 0x00000000}},  //   gét_, ежна, गार_,
  { {0x443f3ca7, 0x00000000, 0x00000000, 0x00000000}},  //   _ktu_,   ,   ,
  { {0xe0ce0216, 0x64590270, 0x2d9e0224, 0x00000000}},  //   _св_, nswi, ěte_,
  { {0x443f000b, 0x69cf00c4, 0x645900bb, 0x00000000}},  //   _mtu_, _alce, iswi,
  { {0x443f3ca8, 0x00000000, 0x00000000, 0x00000000}},  //   _ltu_,   ,   ,
  { {0x644200bb, 0x6926003b, 0x317f031a, 0x00000000}},  //   ypoi, емба, nfuz_,
  { {0x443f0093, 0x64420026, 0x645900bb, 0x00000000}},  // [e2a0] _ntu_, xpoi, jswi,
  { {0x64593ca9, 0x46f6014c, 0x69cf1ad6, 0x00000000}},  //   dswi, нчет, _elce,
  { {0xd91006c6, 0x443f0035, 0x0566017a, 0x00000000}},  //   _چیز_, _atu_, евен,
  { {0xd9100cd9, 0x443f0082, 0x64420253, 0x00000000}},  //   _نیز_, _btu_, tpoi,
  { {0xa3ac006e, 0x3e780010, 0x00000000, 0x00000000}},  //   गाल_, zét_,   ,
  { {0x443f0190, 0x3e780010, 0x00000000, 0x00000000}},  //   _dtu_, yét_,   ,
  { {0xfe6706b4, 0x6829010a, 0x443f0052, 0x00000000}},  //   _حد_, _užda, _etu_,
  { {0x3e780010, 0x7dc6008e, 0x64420e2d, 0x00000000}},  //   vét_, _fósi, ppoi,
  { {0x63ab0224, 0x443f0093, 0xdb1c0210, 0x00000000}},  //   ální, _gtu_, lkrä,
  { {0x3e780047, 0x6602164e, 0x629c01dc, 0x00000000}},  //   tét_, look, _šrou,
  { {0x3f8c13f7, 0xe0cf0014, 0x66023caa, 0x00000000}},  //   redu_, لزی_, oook,
  { {0x66020107, 0x3e780f11, 0x00000000, 0x00000000}},  //   nook, rét_,   ,
  { {0x3e780047, 0x61e20197, 0x0ca8072b, 0x00000000}},  //   sét_, _imol, нтри_,
  { {0x6fe600f4, 0x66020ace, 0xd9c90316, 0x00000000}},  //   _décè, hook, रस्ट,
  { {0x660200bb, 0x5fa6013d, 0x39a7007e, 0x00000000}},  //   kook, _कोयल, ншав,
  { {0x6602006c, 0x645901c3, 0x644004eb, 0x00000000}},  //   jook, yswi, _otmi,
  { {0x8dfc009b, 0x00000000, 0x00000000, 0x00000000}},  // [e2b0] _מההת,   ,   ,
  { {0x65600051, 0x443f0089, 0x62880112, 0x00000000}},  //   _admh, _rtu_, _opdo,
  { {0x6444000d, 0x659500ed, 0x64590784, 0x00000000}},  //   ţiil, кажу, wswi,
  { {0x69cf0951, 0xcb12019b, 0x37043cab, 0x00000000}},  //   _ulce, _כלי_, учув,
  { {0x62880964, 0x3d150061, 0xe22f0011, 0x00000000}},  //   _apdo, नेचे_, ợđiệ,
  { {0x6459054e, 0x39492059, 0x61e20232, 0x00000000}},  //   rswi, lbas_, _amol,
  { {0x66020428, 0x6440038c, 0x64593cac, 0x00000000}},  //   book, _etmi, sswi,
  { {0x66020045, 0x56941662, 0x1b1e0044, 0x00000000}},  //   cook, _щаст, বুকে_,
  { {0x443f0020, 0x629c0c8a, 0x25ad0035, 0x00000000}},  //   _utu_, _šrot, _inel_,
  { {0x61e20052, 0x386908da, 0x62880045, 0x00000000}},  //   _emol, irar_, _fpdo,
  { {0x9d460849, 0x25bf3cad, 0x7e7e00f8, 0x00000000}},  //   кенд, _koul_, _äppl,
  { {0x38693cae, 0x200c002d, 0xdced012d, 0x00000000}},  //   krar_, aldi_, _abađ,
  { {0x7de40010, 0x25bf0173, 0x5cf6007c, 0x00000000}},  //   sőso, _moul_, тяну,
  { {0x38691d43, 0x39490211, 0x5f05003b, 0x00000000}},  //   drar_, ebas_, _изла,
  { {0x2d9b008d, 0x25ad00f6, 0xa6ec0044, 0x00000000}},  //   _faqe_, _onel_, _কর্ম_,
  { {0x25bf001a, 0xb222000c, 0x386901e5, 0x00000000}},  //   _noul_, _þætt, frar_,
  { {0x386911c3, 0xdb1c0051, 0x00000000, 0x00000000}},  // [e2c0] grar_, thró,   ,
  { {0x46a61963, 0x320d0857, 0x7bd5010f, 0x00000000}},  //   казв, hley_, chzu,
  { {0xe57a0551, 0x25bf01aa, 0x64402224, 0x00000000}},  //   дзе_, _boul_, _stmi,
  { {0xceb2012f, 0x0446008b, 0x38690df5, 0x00000000}},  //   ייב_, ведн, brar_,
  { {0x660200bb, 0x200c000c, 0xdb1c09b0, 0x00000000}},  //   rook, yldi_, skrä,
  { {0xf743012b, 0x61e20871, 0x25ad0197, 0x00000000}},  //   _веро, _smol, _enel_,
  { {0x37e30373, 0x25bf01aa, 0x66e63caf, 0x00000000}},  //   _торг, _foul_, _рова,
  { {0x320d0675, 0x2b580a87, 0x30a600ed, 0x00000000}},  //   gley_, harc_, вров,
  { {0xa06702a8, 0x1426007e, 0xf99f000a, 0x00000000}},  //   вања_, _адам, _okèn_,
  { {0xb4ce006e, 0x0eea041f, 0x78a60733, 0x00000000}},  //   शनी_, дьми_, _mrkv,
  { {0x442c0cfe, 0x320d2f33, 0x2d9b0065, 0x00000000}},  //   _iid_, bley_, _paqe_,
  { {0x38693cb0, 0x320600e0, 0x3dd2005b, 0x00000000}},  //   yrar_, _ukoy_, _clyw_,
  { {0x7d160036, 0x442c00ab, 0x4cb80194, 0x00000000}},  //   _czys, _kid_, вляю_,
  { {0x442c0173, 0x1ae40044, 0x386900c4, 0x00000000}},  //   _jid_, _গড়ে_, vrar_,
  { {0x442c18a9, 0xa3b30061, 0x1ae60055, 0x00000000}},  //   _mid_, टात_, _খুবই_,
  { {0x442c02ae, 0x3869029d, 0x320400ab, 0x00000000}},  //   _lid_, trar_, nomy_,
  { {0x78a60119, 0x3949010a, 0x442c0061, 0x00000000}},  // [e2d0] _crkv, rbas_, _oid_,
  { {0x442c018e, 0x38690219, 0x25ad02ae, 0x00000000}},  //   _nid_, rrar_, _snel_,
  { {0x25bf3cb1, 0x320d0ca4, 0x6e2d0232, 0x00000000}},  //   _poul_, yley_, _kiab,
  { {0x320d00ea, 0x386900d4, 0x76450403, 0x00000000}},  //   xley_, prar_, rphy,
  { {0x442c11ce, 0x320d01c3, 0xd83807d0, 0x00000000}},  //   _bid_, vley_, _аэс_,
  { {0x442c0061, 0x6e2d2f94, 0x799d0020, 0x00000000}},  //   _cid_, _liab, _hasw,
  { {0x442c0038, 0x36d50f40, 0x799d0058, 0x00000000}},  //   _did_, _совр, _kasw,
  { {0x442c0019, 0x6e2d0e1a, 0x600f068f, 0x00000000}},  //   _eid_, _niab, rømm,
  { {0x44f504af, 0x442c01d5, 0xe4e701fb, 0x00000000}},  //   _спас, _fid_, _рівн,
  { {0x442c01aa, 0x6ed3006b, 0x799d3242, 0x00000000}},  //   _gid_, ləbə, _lasw,
  { {0xc7d6009b, 0x02d90188, 0x80240025, 0x00000000}},  //   רותי_, _ثواب_, جريم,
  { {0x8c46003b, 0x7d0d2c0b, 0x442c0091, 0x00000000}},  //   леме, _byas, _zid_,
  { {0x4079007b, 0x61e90639, 0x1ae10044, 0x00000000}},  //   _נאַװ, miel, _খুলে_,
  { {0x61e9001e, 0x7d0d01aa, 0x799d00e0, 0x00000000}},  //   liel, _dyas, _aasw,
  { {0x09cc0044, 0x6e2d00f4, 0x69d60065, 0x00000000}},  //   রোফা, _fiab, thye,
  { {0x61e90027, 0xa2a4006e, 0x09cc0044, 0x00000000}},  //   niel, कित्, রোনা,
  { {0x7d160036, 0x60c904cb, 0x18670088, 0x00000000}},  // [e2e0] _uzys, nyem, лати_,
  { {0x61e9010f, 0x20050016, 0x661b0020, 0x00000000}},  //   hiel, noli_, _ahuk,
  { {0x61e900b0, 0x5b7b00b3, 0x7dc6000c, 0x00000000}},  //   kiel, _אריא, _fóst,
  { {0x442c0600, 0x661b0020, 0x2005006c, 0x00000000}},  //   _sid_, _chuk, holi_,
  { {0x442c0061, 0x20053cb2, 0x100302fb, 0x00000000}},  //   _pid_, koli_, रकाश_,
  { {0xa3de03d7, 0x7bce3cb3, 0x60db0089, 0x00000000}},  //   दों_, nkbu, dzum,
  { {0x61e92ea8, 0x442c0073, 0x20050016, 0x00000000}},  //   fiel, _vid_, doli_,
  { {0x3f9c001e, 0x61e90036, 0x442c01a3, 0x00000000}},  //   _savu_, giel, _wid_,
  { {0x442c05fe, 0x6e2d0197, 0x20050c42, 0x00000000}},  //   _tid_, _riab, foli_,
  { {0x200501d5, 0x987b007b, 0x442c01a3, 0x00000000}},  //   goli_, עריק, _uid_,
  { {0x61e900b5, 0x6d56011f, 0x3df53cb4, 0x00000000}},  //   biel, _beya, изос,
  { {0x60c9011c, 0xad67023c, 0x57c10061, 0x00000000}},  //   byem, داده, _एव्ह,
  { {0x6e2d027b, 0x20050142, 0x3f9c0089, 0x00000000}},  //   _viab, boli_, _tavu_,
  { {0x20050198, 0x6b9e0129, 0x7d0d0258, 0x00000000}},  //   coli_, _capg, _vyas,
  { {0x7dc62363, 0x799d00bb, 0x2f3b00a0, 0x00000000}},  //   _póst, _pasw, _אגוד,
  { {0x6e430439, 0x6d560288, 0x00000000, 0x00000000}},  //   _انيم, _geya,   ,
  { {0x799d01c3, 0x69cd2dbb, 0x00000000, 0x00000000}},  // [e2f0] _vasw, rkae,   ,
  { {0x61e928f5, 0x661b3cb5, 0x629a00b0, 0x00000000}},  //   ziel, _shuk, _osto,
  { {0xa3d8007d, 0x0555004d, 0x799d3cb6, 0x00000000}},  //   ासन_, атля, _tasw,
  { {0x78870089, 0x00000000, 0x00000000, 0x00000000}},  //   tīvā,   ,   ,
  { {0x61e9125b, 0x629a191c, 0x2ca90087, 0x00000000}},  //   viel, _asto, _jrad_,
  { {0x61e90036, 0xa4e50061, 0x6ed3006b, 0x00000000}},  //   wiel, _कधीच_, səbə,
  { {0x200501bc, 0x61e900b0, 0x00000000, 0x00000000}},  //   voli_, tiel,   ,
  { {0x60db0b7c, 0x60c93cb7, 0x200509db, 0x00000000}},  //   tzum, tyem, woli_,
  { {0x61e900f4, 0x6d560263, 0x2005086f, 0x00000000}},  //   riel, _reya, toli_,
  { {0x61e93cb8, 0x09d2007d, 0x629a0009, 0x00000000}},  //   siel, _सत्य, _fsto,
  { {0x612b0676, 0x2005001e, 0x61e90f48, 0x00000000}},  //   _bölü, roli_, piel,
  { {0xb2ba009b, 0x20050442, 0x724200a1, 0x00000000}},  //   _במער, soli_, _بھول,
  { {0x4b230055, 0x200507c5, 0x7c3810ec, 0x00000000}},  //   _ব্লগ_, poli_, _čvrs,
  { {0x629a018e, 0x78a40197, 0x00000000, 0x00000000}},  //   _ysto, vviv,   ,
  { {0x6d5601aa, 0x395600ec, 0x3946008e, 0x00000000}},  //   _teya, ињат, ñoso_,
  { {0xf2d2007b, 0x3946007e, 0x78a43cb9, 0x00000000}},  //   קען_, рнаг, tviv,
  { {0xe73a003b, 0x6b9e00e0, 0x7984005b, 0x00000000}},  // [e300] вез_, _tapg, rfiw,
  { {0x78a400ab, 0x076a0379, 0x3cf10161, 0x00000000}},  //   rviv, ئماً_, šová_,
  { {0xdb050190, 0x00000000, 0x00000000, 0x00000000}},  //   _anhæ,   ,   ,
  { {0xa2a402fb, 0x32ee006b, 0xfc3f1ad4, 0x00000000}},  //   किस्, _rəy_, lvía_,
  { {0x998c007f, 0x27f800fa, 0x00000000, 0x00000000}},  //   ūdų_, _tjrn_,   ,
  { {0x38603cba, 0xfc3f008e, 0x629a00d9, 0x00000000}},  //   msir_, nvía_, _psto,
  { {0xd257008b, 0xfe060164, 0x4e060309, 0x00000000}},  //   ацы_, रवास_, रवाई_,
  { {0x39403cbb, 0x629a18e1, 0x00000000, 0x00000000}},  //   ncis_, _vsto,   ,
  { {0xdfda005e, 0x38600093, 0x39400051, 0x00000000}},  //   вън_, nsir_, icis_,
  { {0x3860028c, 0x09b30061, 0x4ea6007e, 0x00000000}},  //   isir_, _ंच्य, арма,
  { {0xa3b3007d, 0x073700b3, 0x2ca90851, 0x00000000}},  //   टार_, יאים_, _srad_,
  { {0xb33c01d5, 0x38600897, 0x7de70088, 0x00000000}},  //   _waħd, ksir_, ріод,
  { {0xed58007e, 0xb33c002b, 0x5c740131, 0x00000000}},  //   шоў_, _taħd, олят,
  { {0xdb1e0016, 0x5fad0061, 0x00000000, 0x00000000}},  //   _copï, _झोपल,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3860008a, 0xb33c0066, 0x00000000, 0x00000000}},  //   fsir_, _jaħb,   ,
  { {0x2ca91aab, 0x7afe2b63, 0x89380679, 0x00000000}},  // [e310] _urad_, _expt, рпус_,
  { {0xd759031d, 0xf77306dd, 0xcb990088, 0x00000000}},  //   الات_, تار_, _свої_,
  { {0x6fcd0051, 0x29070036, 0xdd1f013e, 0x00000000}},  //   _dúch, łna_, vířo,
  { {0x6d5d006a, 0x39400203, 0x00000000, 0x00000000}},  //   nasa, ccis_,   ,
  { {0x7bc50004, 0xdff8006e, 0x3959004a, 0x00000000}},  //   _kohu, ुवाद_, _iess_,
  { {0x42550401, 0xf6770014, 0x395901a2, 0x00000000}},  //   бтит, _پاسخ, _hess_,
  { {0x6d5d006a, 0x7bc50dc1, 0x395909d8, 0x00000000}},  //   kasa, _mohu, _kess_,
  { {0x39590860, 0x7bc5010e, 0xdb1c00ea, 0x00000000}},  //   _jess_, _lohu, rkrø,
  { {0x39590951, 0x6d5d04d4, 0x6009003b, 0x00000000}},  //   _mess_, dasa, лним_,
  { {0x395900ab, 0xe81d013d, 0x9f5e16a3, 0x00000000}},  //   _less_, _बीमा_, gotà_,
  { {0xd1310025, 0x6d5d0145, 0x81d60044, 0x00000000}},  //   _فما_, fasa, _সদর_,
  { {0xfbc900b6, 0x63a13cbc, 0x657900e0, 0x00000000}},  //   _את_, _haln, ngwh,
  { {0x8fa50200, 0x63a10dec, 0x22810047, 0x00000000}},  //   _гале, _kaln, lók_,
  { {0x63a13cbd, 0x8fa40025, 0x3940005b, 0x00000000}},  //   _jaln, _ومنه, wcis_,
  { {0xc332019b, 0x6d5d3cbe, 0x628309fc, 0x00000000}},  //   לום_, basa, ntno,
  { {0x6d5d106f, 0x1a2a3cbf, 0x38600093, 0x00000000}},  //   casa, ужби_, tsir_,
  { {0x39590039, 0x6c860025, 0xdb050788, 0x00000000}},  // [e320] _dess_, _الخم, _anhä,
  { {0x6283041a, 0x3940008e, 0x63a10058, 0x00000000}},  //   ktno, scis_, _naln,
  { {0x38600fd1, 0x3e63014a, 0xdb1e0161, 0x00000000}},  //   ssir_, nıt_, _kopí,
  { {0x250b00a2, 0x22810010, 0x00000000, 0x00000000}},  //   گرمی_, dók_,   ,
  { {0x779400d3, 0x00000000, 0x00000000, 0x00000000}},  //   _ویرا,   ,   ,
  { {0x69c6082e, 0x25a03cc0, 0xd3700025, 0x00000000}},  //   _hoke, žil_, ذهب_,
  { {0x69c6021e, 0x6d5d3cc1, 0x6d440036, 0x00000000}},  //   _koke, yasa, _ofia,
  { {0x66f7009b, 0x69c63cc2, 0x79960133, 0x00000000}},  //   _המלא_, _joke, neyw,
  { {0x6d5d0d90, 0x69c6010a, 0xa3d804da, 0x00000000}},  //   vasa, _moke, ासद_,
  { {0x6d5d020c, 0x2281009f, 0x389b00b6, 0x00000000}},  //   wasa, bók_, ניינ,
  { {0x6d5d014a, 0x66fa0309, 0x9f5e0211, 0x00000000}},  //   tasa, ्थिक_, gotá_,
  { {0x7bc8006c, 0x7bc501cf, 0x2bd10316, 0x00000000}},  //   ödun, _sohu, हस्थ,
  { {0x63a1038c, 0x6d5d020c, 0x7bc50023, 0x00000000}},  //   _yaln, rasa, _pohu,
  { {0x3959002b, 0x6d5d006a, 0x8fa3003b, 0x00000000}},  //   _sess_, sasa, _наче,
  { {0x69c601c9, 0xcf260379, 0x68290006, 0x00000000}},  //   _boke, _ارشي, _uždi,
  { {0x69c604be, 0x5c75007c, 0x601d1339, 0x00000000}},  //   _coke, _длит, rème,
  { {0x22810010, 0x7bc508a7, 0xdc550167, 0x00000000}},  // [e330] zók_, _tohu, _برعک,
  { {0x67eb01d5, 0x62830802, 0x7bdc1b74, 0x00000000}},  //   rżjo, ytno, chru,
  { {0xa93501e1, 0x62830009, 0x00000000, 0x00000000}},  //   _менш, xtno,   ,
  { {0x63a1027b, 0x69c60ace, 0xd56b0088, 0x00000000}},  //   _saln, _goke, рiал,
  { {0xa879007b, 0xd7fb01fb, 0xa5bd010a, 0x00000000}},  //   _דאָר, _був_, _siųs,
  { {0x3e6301f6, 0x22810047, 0x224900ed, 0x00000000}},  //   yıt_, tók_, апки_,
  { {0x657a002a, 0x62810061, 0x6eca006b, 0x00000000}},  //   úchá, _qqlo, həbb,
  { {0x644b0039, 0x62830091, 0x63a13cc3, 0x00000000}},  //   ppgi, rtno, _waln,
  { {0x62830428, 0x63a13cc4, 0x4f95078e, 0x00000000}},  //   stno, _taln, орну,
  { {0x9e650373, 0x6d440026, 0x4fe90256, 0x00000000}},  //   овод, _sfia, рмон_,
  { {0xd12e00a1, 0x44270058, 0xf77200b3, 0x00000000}},  //   ٹمی_, mmn_, וקי_,
  { {0x2b5a00d4, 0x00000000, 0x00000000, 0x00000000}},  //   _sepc_,   ,   ,
  { {0x69c63cc5, 0x3a3a10c5, 0x7bdc0051, 0x00000000}},  //   _roke, _supp_, thru,
  { {0x69c600b0, 0x44272dd5, 0xe1f90006, 0x00000000}},  //   _soke, nmn_, lnų_,
  { {0x69c608d0, 0xfaa31abd, 0xd00e0014, 0x00000000}},  //   _poke, маро, _جلو_,
  { {0x69d80006, 0xe9d7004d, 0x64490032, 0x00000000}},  //   _įves, окс_, _otei,
  { {0x2fc7006a, 0x47c602e9, 0x57ea007e, 0x00000000}},  // [e340] _kong_, обав, адам_,
  { {0x2fc700c7, 0x95f4006e, 0x9f4c0023, 0x00000000}},  //   _jong_, ेक्ट_, vidë_,
  { {0x2fc73cc6, 0x6449010a, 0x69c63cc7, 0x00000000}},  //   _mong_, _atei, _toke,
  { {0x2fc7190f, 0x68fb012d, 0x291c006b, 0x00000000}},  //   _long_, _žude, əvan_,
  { {0x649a00d7, 0x7de40010, 0x6569005b, 0x00000000}},  //   ртер_, lőss, _ddeh,
  { {0x66e6012b, 0x2fc73cc8, 0x64490051, 0x00000000}},  //   _дога, _nong_, _dtei,
  { {0x9f450197, 0x64490c67, 0x00000000, 0x00000000}},  //   dilà_, _etei,   ,
  { {0xa3d80061, 0xb33c002b, 0xe5770245, 0x00000000}},  //   ासह_, _daħa, _мзс_,
  { {0xdfd00054, 0x2fc71f36, 0x9f4c009d, 0x00000000}},  //   فية_, _bong_, lidé_,
  { {0x2fc70011, 0x388e0089, 0xb33c0066, 0x00000000}},  //   _cong_, mērā_, _faħa,
  { {0x2fc70011, 0x25a60016, 0x60140129, 0x00000000}},  //   _dong_, odol_, nàmi,
  { {0x25a60129, 0x2d80016b, 0xd0eb0061, 0x00000000}},  //   ndol_, _ccie_, _जेवण_,
  { {0xd7da0061, 0x2fc70145, 0x248608d0, 0x00000000}},  //   णसाच, _fong_, ntom_,
  { {0x2fc70056, 0xfc3f004a, 0x2a780068, 0x00000000}},  //   _gong_, svío_, furb_,
  { {0x69d8010a, 0x200c09f9, 0x6fcd004a, 0x00000000}},  //   _įver, modi_, _cúcu,
  { {0x24860142, 0x2fc73cc9, 0x2ca00045, 0x00000000}},  //   ktom_, _zong_, _fsid_,
  { {0x25a6018e, 0x2d993cca, 0x2fc73ccb, 0x00000000}},  // [e350] ddol_, mese_, _yong_,
  { {0x2fc7001d, 0x200c0016, 0x249f012d, 0x00000000}},  //   _xong_, nodi_, _rsum_,
  { {0x644905de, 0x395224c6, 0xe1f9007f, 0x00000000}},  //   _stei, bbys_, ynų_,
  { {0x1a9a0049, 0xb33c002b, 0xa7140088, 0x00000000}},  //   _פירע, _raħa, ємці,
  { {0x200c0020, 0x2d990026, 0xb33c002b, 0x00000000}},  //   kodi_, iese_, _saħa,
  { {0x25a63ccc, 0xe019013d, 0xf1a3013d, 0x00000000}},  //   adol_, _नींद_, _खोजन,
  { {0x2d99006c, 0x9f4c00f4, 0x2fc73ccd, 0x00000000}},  //   kese_, cidé_, _rong_,
  { {0x2fc713ec, 0x016500ed, 0x2d990c33, 0x00000000}},  //   _song_, чкио, jese_,
  { {0x2fc7011c, 0x2d993cce, 0x1015007e, 0x00000000}},  //   _pong_, dese_, зьня,
  { {0xb4d702fb, 0x200c0209, 0x2d80117e, 0x00000000}},  //   ानी_, godi_, _scie_,
  { {0xf772007b, 0x2d8005d2, 0x2fc70011, 0x00000000}},  //   עקט_, _pcie_, _vong_,
  { {0x2d9901d6, 0xa3e70204, 0xdb16013e, 0x00000000}},  //   gese_, मोर_, ícíc,
  { {0x2fc7011c, 0x621a061e, 0x61fb001a, 0x00000000}},  //   _tong_, _פונק, mnul,
  { {0x8fa5007e, 0x200c00f6, 0x69cb09b0, 0x00000000}},  //   _хаке, codi_, ögen,
  { {0x25a63ccf, 0x61fb11e1, 0x6fcd00f6, 0x00000000}},  //   ydol_, onul, _dúct,
  { {0x61fb000c, 0x9f4c008e, 0x684600e2, 0x00000000}},  //   nnul, vidé_, знаа,
  { {0x09e3005e, 0x61fb00ea, 0x3952074e, 0x00000000}},  // [e360] хотн, inul, rbys_,
  { {0x7bd5010f, 0x25a400eb, 0x7b070010, 0x00000000}},  //   ckzu, _saml_, érté,
  { {0x61fb0166, 0xd9460a85, 0x00000000, 0x00000000}},  //   knul, _нени,   ,
  { {0x24860339, 0x60140129, 0x00000000, 0x00000000}},  //   ttom_, ràmi,   ,
  { {0x2937007b, 0x00000000, 0x00000000, 0x00000000}},  //   _מאכן_,   ,   ,
  { {0x5497007e, 0x2d991089, 0x69c41275, 0x00000000}},  //   явіў_, zese_, ljie,
  { {0x200c0825, 0x2d99152b, 0x00000000, 0x00000000}},  //   vodi_, yese_,   ,
  { {0x24860209, 0x69c40891, 0x69d60173, 0x00000000}},  //   ptom_, njie, nkye,
  { {0x200c01bc, 0x2d9921de, 0x74160d0b, 0x00000000}},  //   todi_, vese_, _فورا,
  { {0x2d990007, 0x61fb02a6, 0x00000000, 0x00000000}},  //   wese_, anul,   ,
  { {0x2d990d69, 0x200c0213, 0x3a290203, 0x00000000}},  //   tese_, rodi_, ymap_,
  { {0x200c0207, 0x67e00039, 0x69c4002b, 0x00000000}},  //   sodi_, _höjd, jjie,
  { {0x69c41a33, 0x200c0026, 0x00000000, 0x00000000}},  //   djie, podi_,   ,
  { {0x2d9910fb, 0x3a290b19, 0x00000000, 0x00000000}},  //   sese_, wmap_,   ,
  { {0x7d040bc0, 0x2d9900b5, 0x3a2901d0, 0x00000000}},  //   _exis, pese_, tmap_,
  { {0x5a340517, 0x64be0061, 0x6e240145, 0x00000000}},  //   енст, ्हाळ, _ghib,
  { {0x6d5f0066, 0x00000000, 0x00000000, 0x00000000}},  // [e370] _ieqa,   ,   ,
  { {0x67e00039, 0x6143000c, 0x27210044, 0x00000000}},  //   _nöjd, _kíló, _বলবো_,
  { {0x6d5f0023, 0x3a290023, 0x6b8a000c, 0x00000000}},  //   _keqa, pmap_, _öfga,
  { {0x7e9b0049, 0xe81d0204, 0xdb1e0030, 0x00000000}},  //   מסבו, _बीरा_, _bopæ,
  { {0xb4d702f4, 0x03a50131, 0xdb050146, 0x00000000}},  //   ाने_, дило, _anhø,
  { {0xa3e703d7, 0x9c8701ca, 0x7c370066, 0x00000000}},  //   मों_, _začí, _jixr,
  { {0x78ad006c, 0x6d460039, 0xa2291d84, 0x00000000}},  //   lvav, ycka, ожка_,
  { {0x200302aa, 0x00000000, 0x00000000, 0x00000000}},  //   čjim_,   ,   ,
  { {0x8f750822, 0x61fb001a, 0x6d4100b9, 0x00000000}},  //   муні, rnul, ělal,
  { {0x2628001a, 0x798d0016, 0x443f0066, 0x00000000}},  //   _uşor_, hfaw, _iuu_,
  { {0x69dd04b3, 0x443f000b, 0x7d1600b0, 0x00000000}},  //   _olse, _huu_, _syys,
  { {0x443f1a0c, 0x9f470051, 0x645b000a, 0x00000000}},  //   _kuu_, _imní_, _kwui,
  { {0x443f000b, 0x67e00039, 0x7c370066, 0x00000000}},  //   _juu_, _höje, _bixr,
  { {0x443f03b6, 0xb33c0066, 0xf99f000a, 0x00000000}},  //   _muu_, _naħl, _okès_,
  { {0x160d02d2, 0x69c43cd0, 0xfebb007a, 0x00000000}},  //   िकार_, tjie, _داشت_,
  { {0x7d04002d, 0x753b0020, 0x68e40032, 0x00000000}},  //   _txis, _nguz, tzid,
  { {0x6b930039, 0x3cff0061, 0x2d920045, 0x00000000}},  // [e380] ädgå, रपणे_, _ibye_,
  { {0x44250142, 0x46f605f6, 0x69c40007, 0x00000000}},  //   _nhl_, мчет, sjie,
  { {0x6b9c1ec2, 0x67e00039, 0x3a26012b, 0x00000000}},  //   merg, _nöje, _омог,
  { {0x93bc0011, 0x601d0026, 0x00000000, 0x00000000}},  //   _chăn, kèmo,   ,
  { {0x249a02fd, 0xfbd20164, 0x443f0082, 0x00000000}},  //   تخاب_, _हवाम, _cuu_,
  { {0xe73a1e4d, 0x44250190, 0x443f00d4, 0x00000000}},  //   _фев_, _chl_, _duu_,
  { {0x442504fb, 0x645d002b, 0xfe6700f9, 0x00000000}},  //   _dhl_, _ħsie, _جد_,
  { {0x6b9c3cd1, 0x68290006, 0x69dd004a, 0x00000000}},  //   herg, _uždr, _xlse,
  { {0x60f801e0, 0x6b9c00ea, 0xfc3f000c, 0x00000000}},  //   яния_, kerg, rvík_,
  { {0x60f7008b, 0x2d92000a, 0x6b9c0190, 0x00000000}},  //   ьныя_, _abye_, jerg,
  { {0x6440006a, 0x7d1a006b, 0x600f0030, 0x00000000}},  //   _humi, ətsi, rømp,
  { {0xc3330452, 0x644003ea, 0x2cb2018e, 0x00000000}},  //   _סוף_, _kumi, _bryd_,
  { {0x628a0066, 0x7c840893, 0x64400ef7, 0x00000000}},  //   ltfo, куре, _jumi,
  { {0x64400006, 0x6b9c0190, 0x63a80091, 0x00000000}},  //   _mumi, gerg, _jadn,
  { {0x628a0030, 0x64403cd2, 0x9e0705f6, 0x00000000}},  //   ntfo, _lumi, _очил,
  { {0x7bde12c2, 0x63a800b4, 0x2cb21506, 0x00000000}},  //   _elpu, _ladn, _fryd_,
  { {0x6440001a, 0x9be70088, 0x63ba01bb, 0x00000000}},  // [e390] _numi, _жінк, _ontn,
  { {0xf7701095, 0xa77401f9, 0x78ad0a0e, 0x00000000}},  //   لام_, клуч, rvav,
  { {0x443f03b6, 0x44250022, 0x78ad03b6, 0x00000000}},  //   _suu_, _rhl_, svav,
  { {0x644017ca, 0x443f2440, 0x00000000, 0x00000000}},  //   _bumi, _puu_,   ,
  { {0xf99200b3, 0x64400035, 0x63a804eb, 0x00000000}},  //   _ערך_, _cumi, _badn,
  { {0x64403cd3, 0x386900f8, 0x628a0056, 0x00000000}},  //   _dumi, msar_, ftfo,
  { {0x93bc0011, 0x765c0016, 0x59d3006e, 0x00000000}},  //   _thăn, _gwry, _सवार,
  { {0x39490325, 0x2055003b, 0x443f16c3, 0x00000000}},  //   ncas_, нтор, _tuu_,
  { {0x64402175, 0x39493cd4, 0xdff5007e, 0x00000000}},  //   _gumi, icas_, еянь,
  { {0x38690181, 0x6b9c00c4, 0x3a3901d0, 0x00000000}},  //   isar_, xerg, _lisp_,
  { {0x6b9c010f, 0x6440010f, 0xef190077, 0x00000000}},  //   verg, _zumi, ямо_,
  { {0x63a818e1, 0xed570088, 0x2cb2018e, 0x00000000}},  //   _zadn, ною_, _pryd_,
  { {0x522c007b, 0x6b9c0125, 0x6eca006b, 0x00000000}},  //   _וואַ, terg, ləbl,
  { {0xc05802fd, 0x39490089, 0xfaa601e1, 0x00000000}},  //   _آشنا_, ecas_, наго,
  { {0x6b9c0112, 0x501a0049, 0x00000000, 0x00000000}},  //   rerg, _צוצו,   ,
  { {0xe9df0051, 0x6b9c1d93, 0x00000000, 0x00000000}},  //   _clú_, serg,   ,
  { {0x6b9c0169, 0x3a390494, 0x48e300e3, 0x00000000}},  // [e3a0] perg, _disp_, готв,
  { {0x66e6004d, 0x3949004a, 0x628a0374, 0x00000000}},  //   ноза, acas_, ytfo,
  { {0x63a806a6, 0x20030746, 0x38690058, 0x00000000}},  //   _radn, čjih_, asar_,
  { {0x7ddf008d, 0x63a80b4a, 0x6440011c, 0x00000000}},  //   _kësa, _sadn, _pumi,
  { {0x63a80091, 0x6fd6009d, 0x00000000, 0x00000000}},  //   _padn, _fâch,   ,
  { {0x02a60088, 0x628a3cd5, 0xa5200061, 0x00000000}},  //   ерим, ttfo, _बरीच_,
  { {0x764e093b, 0xfbd3009b, 0x628a00ea, 0x00000000}},  //   _utby, רתו_, utfo,
  { {0x6440006a, 0x64a6007e, 0x00000000, 0x00000000}},  //   _tumi, _паба,   ,
  { {0x628a004e, 0x98a9002b, 0x7a05007f, 0x00000000}},  //   stfo, rbaħ_, nėta,
  { {0x628a0240, 0xddc90036, 0x6eca006b, 0x00000000}},  //   ptfo, łożo, bəbl,
  { {0x11d601fb, 0x00000000, 0x00000000, 0x00000000}},  //   _підр,   ,   ,
  { {0x7c2e1632, 0x7a050006, 0x00000000, 0x00000000}},  //   embr, kėta,   ,
  { {0x20d30070, 0x6aa500f6, 0x3a390197, 0x00000000}},  //   _متوج, _sshf, _risp_,
  { {0x7a050006, 0x29190bde, 0x00000000, 0x00000000}},  //   dėta, _rysa_,   ,
  { {0x3f9e0627, 0xbea30184, 0x00000000, 0x00000000}},  //   metu_, _бајк,   ,
  { {0x3f9e0059, 0x38690039, 0x7c2e0026, 0x00000000}},  //   letu_, tsar_, ambr,
  { {0xc4c4026c, 0x39490489, 0xa89800c2, 0x00000000}},  // [e3b0] _اے_, rcas_, нкту_,
  { {0x39490489, 0x38693cd6, 0x37070072, 0x00000000}},  //   scas_, rsar_, нчев,
  { {0xf7700379, 0x98140076, 0x34d90963, 0x00000000}},  //   صال_, ابقا, भन्द,
  { {0x38693cd7, 0x3a390197, 0x0708006d, 0x00000000}},  //   psar_, _uisp_, ريني_,
  { {0x6fd600f4, 0x58d43cd8, 0x00000000, 0x00000000}},  //   _tâch, _боят,   ,
  { {0x69cf037e, 0x3f9e0243, 0x0454026c, 0x00000000}},  //   _hoce, jetu_, ائند,
  { {0x69cf144f, 0x3f9e002d, 0xfbb800b3, 0x00000000}},  //   _koce, detu_, תפות_,
  { {0x69cf3cd9, 0xf48500a1, 0x80ca0044, 0x00000000}},  //   _joce, _لائی, িনন্,
  { {0x3c240039, 0x3f9e16d0, 0xd5ac00a1, 0x00000000}},  //   höva_, fetu_, _رہو_,
  { {0xd00e006d, 0x44f40679, 0x69cf0089, 0x00000000}},  //   يلي_, _спус, _loce,
  { {0xfe550025, 0x23670087, 0xdcfd0089, 0x00000000}},  //   خخخخ, manj_, besī,
  { {0x11f9007a, 0x23670173, 0x91a700a1, 0x00000000}},  //   _کوچک_, lanj_, _سنتے_,
  { {0xe0ce0072, 0x3f9e119a, 0xddc93cda, 0x00000000}},  //   _тв_, betu_, budž,
  { {0x2eb50216, 0x3f9e016c, 0xab2a007e, 0x00000000}},  //   _асис, cetu_, дога_,
  { {0x69cf148a, 0x7c2e0ce3, 0xaf760049, 0x00000000}},  //   _boce, rmbr, _סעקס_,
  { {0x236701aa, 0x3ea70133, 0x00000000, 0x00000000}},  //   hanj_, _isnt_,   ,
  { {0x18670088, 0xa5200061, 0xdddb00b9, 0x00000000}},  // [e3c0] кати_, _बरेच_, jstř,
  { {0x4a46044b, 0xd7f90088, 0x23670059, 0x00000000}},  //   _инов, нує_, janj_,
  { {0x69cf3cdb, 0x26dc01ca, 0xa2a1013d, 0x00000000}},  //   _foce, ávo_, _कैल्,
  { {0x69cf0023, 0xb33c01f3, 0x00000000, 0x00000000}},  //   _goce, _taħk,   ,
  { {0x26dc00ee, 0x3f9e00e7, 0x00000000, 0x00000000}},  //   švo_, yetu_,   ,
  { {0xdb0e009f, 0x23670618, 0x9cd7009b, 0x00000000}},  //   _þjón, ganj_, כונה_,
  { {0xe29700ec, 0x3f9e0091, 0x81ab0044, 0x00000000}},  //   вај_, vetu_, খান_,
  { {0x7bdc0715, 0x79840020, 0x442e0145, 0x00000000}},  //   hkru, ngiw, smf_,
  { {0x2367016e, 0x7bdc000c, 0x3f9e0091, 0x00000000}},  //   banj_, kkru, tetu_,
  { {0xa3e6013d, 0xdefa0147, 0x00000000, 0x00000000}},  //   _पति_, дым_,   ,
  { {0xdef404af, 0x3f9e0006, 0xddc90166, 0x00000000}},  //   упны, retu_, rudž,
  { {0xe0da012b, 0x92e4014a, 0x660216af, 0x00000000}},  //   _ове_, ışıl, nnok,
  { {0xa3e6062e, 0xc0e3025f, 0x5f9402ea, 0x00000000}},  //   _पता_, _коцк, _билт,
  { {0x3d120061, 0x7bdc01d6, 0x69cf2ddd, 0x00000000}},  //   _धुळे_, gkru, _soce,
  { {0x69cf01cd, 0x66022722, 0x00000000, 0x00000000}},  //   _poce, knok,   ,
  { {0x1f37009b, 0x66020010, 0x23671827, 0x00000000}},  //   _ברור_, jnok, zanj_,
  { {0x69cf0f6a, 0x201e0197, 0x9f5e009d, 0x00000000}},  // [e3d0] _voce, olti_, enté_,
  { {0xb8cb03d7, 0x7bdc01a2, 0x00000000, 0x00000000}},  //   _कई_, ckru,   ,
  { {0x2367085c, 0xd5753cdc, 0x00000000, 0x00000000}},  //   vanj_, гуль,   ,
  { {0x9865026c, 0x7ddf0065, 0x2ca90022, 0x00000000}},  //   _میرے_, _mëso, _ksad_,
  { {0x629a00d6, 0x7a050006, 0x15140088, 0x00000000}},  //   _apto, lėto, адця,
  { {0xa3b3006e, 0x00000000, 0x00000000, 0x00000000}},  //   _जोश_,   ,   ,
  { {0x23670209, 0xe2990245, 0x7a050006, 0x00000000}},  //   ranj_, хай_, nėto,
  { {0xa3b3007d, 0x236712ac, 0x629a0d62, 0x00000000}},  //   _जोर_, sanj_, _dpto,
  { {0x23670209, 0xe4a4025f, 0x601d0129, 0x00000000}},  //   panj_, _врхо, lèmi,
  { {0xbfc5007c, 0x61e20010, 0x7a050006, 0x00000000}},  //   убок, _elol, kėto,
  { {0xa2d50054, 0xe3b003ec, 0x3255007c, 0x00000000}},  //   _حيات, _برق_, _свер,
  { {0x2d8900d4, 0x8d760d75, 0x00000000, 0x00000000}},  //   _ccae_, دادا,   ,
  { {0x224509e7, 0xe1f90006, 0x7bdc01d6, 0x00000000}},  //   _hulk_, mių_, tkru,
  { {0xe1f9010a, 0x8c430088, 0x66020036, 0x00000000}},  //   lių_, сере, znok,
  { {0x7bdc0168, 0x00000000, 0x00000000, 0x00000000}},  //   rkru,   ,   ,
  { {0xe1f90736, 0x601d0129, 0x3eb8043e, 0x00000000}},  //   nių_, dèmi, ærte_,
  { {0x660200ca, 0xa9260545, 0x00000000, 0x00000000}},  // [e3e0] vnok, удал,   ,
  { {0x25bf0eed, 0x3f850066, 0x3dd2005b, 0x00000000}},  //   _anul_, nglu_, _hoyw_,
  { {0xe1f9010a, 0xe57a0072, 0xb8cb0164, 0x00000000}},  //   kių_, езе_, _कै_,
  { {0x25ad0bc4, 0x7c3e14ad, 0x00000000, 0x00000000}},  //   _cael_, _hipr,   ,
  { {0x7c3e3278, 0x66020010, 0x3ae800a1, 0x00000000}},  //   _kipr, rnok, _سبھی_,
  { {0x22450133, 0x7c3e0066, 0x61e2010e, 0x00000000}},  //   _bulk_, _jipr, _slol,
  { {0xdef8002b, 0x00000000, 0x00000000, 0x00000000}},  //   paċi_,   ,   ,
  { {0x25ad018e, 0xe1f90006, 0x85b5003b, 0x00000000}},  //   _gael_, gių_, _кључ,
  { {0xdfd00054, 0x5506007e, 0x26da0006, 0x00000000}},  //   قية_, _спаб, lypo_,
  { {0x749b0097, 0x7ddf0023, 0x224501c3, 0x00000000}},  //   _אימפ, _pëso, _fulk_,
  { {0x3a200030, 0xe1f90006, 0x629a3cdd, 0x00000000}},  //   klip_, bių_, _upto,
  { {0x6146003b, 0x443e039f, 0x442c0146, 0x00000000}},  //   _седа, _hit_, _hhd_,
  { {0x443e060b, 0x3a2000e0, 0x00000000, 0x00000000}},  //   _kit_, dlip_,   ,
  { {0x7c3e001a, 0xe7bf0055, 0x443e013e, 0x00000000}},  //   _cipr, _ইত্য, _jit_,
  { {0x443e08ba, 0xda78005e, 0x7c3e3cde, 0x00000000}},  //   _mit_, лят_, _dipr,
  { {0x443e023f, 0x442c3cdf, 0x9955091b, 0x00000000}},  //   _lit_, _lhd_, ркац,
  { {0x57f509e6, 0x6e2d0569, 0x6eca013f, 0x00000000}},  // [e3f0] апат, _ihab, dəbi,
  { {0x443e04bd, 0x601d01aa, 0x442c00d9, 0x00000000}},  //   _nit_, tèmi, _nhd_,
  { {0x6d5d0061, 0x6e2d01a3, 0xdb050016, 0x00000000}},  //   obsa, _khab, _wahâ,
  { {0x443e3ce0, 0x3a20001a, 0x6595007e, 0x00000000}},  //   _ait_, clip_, раду,
  { {0xe1f9010a, 0x443e00ab, 0x442c01a3, 0x00000000}},  //   vių_, _bit_, _bhd_,
  { {0x443e001a, 0x987a007b, 0xa87a0049, 0x00000000}},  //   _cit_, _באשט, _באשר,
  { {0x443e0100, 0x67e00073, 0x68ed3ce1, 0x00000000}},  //   _dit_, _möjl, lzad,
  { {0x25bf000d, 0x443e0c64, 0x40953ce2, 0x00000000}},  //   _unul_, _eit_, арот,
  { {0x68ed0841, 0xe1f9010a, 0xe45001f7, 0x00000000}},  //   nzad, rių_, _فضل_,
  { {0xe1f9010a, 0x443e011f, 0x442c0875, 0x00000000}},  //   sių_, _git_, _ghd_,
  { {0xed5a012b, 0x7c3e3ce3, 0x63a33ce4, 0x00000000}},  //   кон_, _ripr, menn,
  { {0x6e2d027b, 0x63a3018e, 0x443e02ae, 0x00000000}},  //   _chab, lenn, _zit_,
  { {0x66090065, 0x61e90016, 0x6283011c, 0x00000000}},  //   _mjek, mhel, luno,
  { {0x61fb3ce5, 0x61e90304, 0x66090243, 0x00000000}},  //   liul, lhel, _ljek,
  { {0x661b0061, 0xa96a0265, 0x7d0d0a86, 0x00000000}},  //   _okuk, кива_, _exas,
  { {0x6d4f001c, 0x6e2d002a, 0x61e90016, 0x00000000}},  //   ccca, _ghab, nhel,

  { {0x63a3021e, 0x60db37d8, 0x656b0058, 0x00000000}},  // [e400] kenn, nyum, dagh,
  { {0x63a33ce6, 0x3a200bbc, 0x60c90129, 0x00000000}},  //   jenn, slip_, ixem,
  { {0x63a300b0, 0x5b7b00b6, 0x442c00e0, 0x00000000}},  //   denn, _בריא, _rhd_,
  { {0xdcf6014a, 0x61fb0020, 0x69960245, 0x00000000}},  //   _hayı, jiul, _трох,
  { {0xdcf6011f, 0x63a3018e, 0x442c09b8, 0x00000000}},  //   _kayı, fenn, _phd_,
  { {0x62833711, 0x661b00e0, 0x7529016c, 0x00000000}},  //   funo, _ekuk, _dzez,
  { {0x62830219, 0x443e0065, 0xdcf601f6, 0x00000000}},  //   guno, _vit_, _mayı,
  { {0x68fb366d, 0x98b201df, 0x66090056, 0x00000000}},  //   _žudi, layı_, _gjek,
  { {0x443e09e0, 0x63a3018e, 0x4fc6007e, 0x00000000}},  //   _tit_, benn, асна,
  { {0x443e049b, 0x63a30207, 0x6e2d1b1c, 0x00000000}},  //   _uit_, cenn, _shab,
  { {0x6d4f0365, 0x76402d8b, 0x6283001a, 0x00000000}},  //   tcca, _kimy, cuno,
  { {0x5183003b, 0x61fb3ce7, 0x60db0009, 0x00000000}},  //   _душа, ciul, byum,
  { {0xe7c901f5, 0x3eb90089, 0xdcf6005a, 0x00000000}},  //   रामप, āsta_, _bayı,
  { {0x76400263, 0x6d44002d, 0x8fa301fc, 0x00000000}},  //   _limy, _egia, _маче,
  { {0x6e2d002a, 0x9967007c, 0x9f5e0051, 0x00000000}},  //   _thab, итал, nntí_,
  { {0x68ed3ce8, 0x8277007b, 0x6e2d0020, 0x00000000}},  //   tzad, יעלע_, _uhab,
  { {0x63a300f4, 0x7c950025, 0x656b02e5, 0x00000000}},  // [e410] yenn, _الخص, vagh,
  { {0x68ed2c69, 0x66093ce9, 0xd6db0cee, 0x00000000}},  //   rzad, _sjek, кте_,
  { {0x95cb0057, 0xdb050002, 0x63a30ef1, 0x00000000}},  //   куда_, _anhö, venn,
  { {0x361801fb, 0xdcf6014a, 0x261c008e, 0x00000000}},  //   ацію_, _zayı, díos_,
  { {0xdcf601f6, 0x656b1dec, 0x645902c2, 0x00000000}},  //   _yayı, ragh, upwi,
  { {0x6283025e, 0xdb050802, 0x261c008e, 0x00000000}},  //   tuno, _zahá, fíos_,
  { {0x61e91775, 0x66090030, 0x656b011c, 0x00000000}},  //   thel, _tjek, pagh,
  { {0xc692007b, 0x63a3018e, 0x6283011c, 0x00000000}},  //   _מאל_, senn, runo,
  { {0x61e90010, 0x20d50099, 0x6283006a, 0x00000000}},  //   rhel, сійс, suno,
  { {0x61e90010, 0x628319e4, 0x61fb0006, 0x00000000}},  //   shel, puno, siul,
  { {0xee3a1281, 0x7ddf008d, 0x61e918cf, 0x00000000}},  //   лно_, _kësh, phel,
  { {0xdcf6047f, 0x682901dc, 0xd12e00a6, 0x00000000}},  //   _sayı, _vždy, ظمی_,
  { {0x64411ace, 0xdea1026c, 0x60c401d5, 0x00000000}},  //   _kili, _کیجی, _ġimg,
  { {0xdcf6005f, 0x7ddf0065, 0x66190036, 0x00000000}},  //   _qayı, _lësh, howk,
  { {0x98b20279, 0x00000000, 0x00000000, 0x00000000}},  //   vayı_,   ,   ,
  { {0x6441000b, 0x7f3a0049, 0x394605b8, 0x00000000}},  //   _lili, _געצו, снаг,
  { {0x6441002a, 0xdce40006, 0x64490006, 0x00000000}},  // [e420] _oili, _keič, _nuei,
  { {0x64411a60, 0x3b8601fc, 0x76400ee4, 0x00000000}},  //   _nili, _улог, _simy,
  { {0x3cfc013d, 0x98b2005a, 0xa9a60081, 0x00000000}},  //   _लेते_, rayı_, _линд,
  { {0x261c0211, 0x64410048, 0x2ca00093, 0x00000000}},  //   víos_, _aili, _kpid_,
  { {0x644114d7, 0x7ddf008d, 0x6449009d, 0x00000000}},  //   _bili, _dësh, _cuei,
  { {0x6441008d, 0x00000000, 0x00000000, 0x00000000}},  //   _cili,   ,   ,
  { {0x644100ef, 0xd7e70867, 0xddc9016c, 0x00000000}},  //   _dili, _умре_, vrdž,
  { {0x64411189, 0x9054003b, 0x656901a2, 0x00000000}},  //   _eili, овиц, _geeh,
  { {0xc1b70783, 0xc05700a1, 0x644900fa, 0x00000000}},  //   слых_, یشیا_, _guei,
  { {0x6441011c, 0x6fb4025a, 0x656900bb, 0x00000000}},  //   _gili, آمدا, _zeeh,
  { {0x200b00c4, 0x079b00a0, 0xa3ad013d, 0x00000000}},  //   écia_, נסטל, _औसत_,
  { {0x6441000b, 0x25a6004a, 0xddeb0439, 0x00000000}},  //   _zili, neol_, ارده_,
  { {0xb33c002b, 0x2ca00009, 0x00000000, 0x00000000}},  //   _taħs, _cpid_,   ,
  { {0x7ddf0065, 0x6441009d, 0x2ca00087, 0x00000000}},  //   _mësi, _xili, _dpid_,
  { {0x81ab0055, 0x7a05007f, 0x00000000, 0x00000000}},  //   খার_, lėti,   ,
  { {0xd257009b, 0x2ca00009, 0x7de70014, 0x00000000}},  //   משלה_, _fpid_, _دستم,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [e430]   ,   ,   ,
  { {0xdd310036, 0xe9df0051, 0x8af9005e, 0x00000000}},  //   _mężc, _siúd_, _внос_,
  { {0x7bc5002b, 0x64413cea, 0x7ddf0023, 0x00000000}},  //   _inhu, _rili, _pësh,
  { {0x64411aa0, 0x7a050006, 0x9567005e, 0x00000000}},  //   _sili, kėti, съжд,
  { {0x6441170b, 0x64493ceb, 0x7ddf0065, 0x00000000}},  //   _pili, _quei, _vësh,
  { {0x7a050006, 0x4255005e, 0x00000000, 0x00000000}},  //   dėti, отит,   ,
  { {0x64413cec, 0x316d0032, 0x7bdc01ce, 0x00000000}},  //   _vili, taez_, רקוו,
  { {0x939700a1, 0x6441005b, 0x6594132e, 0x00000000}},  //   _گجرا, _wili, _насу,
  { {0x644100b0, 0x9f5e0181, 0x63c400b9, 0x00000000}},  //   _tili, mitê_, átní,
  { {0xcf390088, 0xdb1e014a, 0x64410051, 0x00000000}},  //   ичні_, _popü, _uili,
  { {0x8e0a0242, 0x63c400b9, 0x9f450026, 0x00000000}},  //   инов_, štní, filò_,
  { {0xfbc9019b, 0x7bc51a07, 0xcdf6008b, 0x00000000}},  //   _בת_, _anhu, ічны,
  { {0x683003a2, 0x7bd7175b, 0x00000000, 0x00000000}},  //   läde, _boxu,   ,
  { {0xdee5012b, 0x8af7006b, 0x653a0049, 0x00000000}},  //   _моли, ğənn, יערד,
  { {0xed5a0265, 0xe7ff013d, 0x78bd0026, 0x00000000}},  //   _кой_, ोचना_, _arsv,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6fdf00f4, 0x6830010f, 0x00000000, 0x00000000}},  // [e440] _pêch, häde,   ,
  { {0xfc320025, 0x7bd70288, 0x00000000, 0x00000000}},  //   _تحب_, _goxu,   ,
  { {0xd946005e, 0xba760464, 0x387200f8, 0x00000000}},  //   _мени, _باخت, ssyr_,
  { {0xa526005e, 0xad9b0051, 0x64a6007e, 0x00000000}},  //   омед, miúc, жада,
  { {0xad9b002a, 0x69c6345a, 0x25a61506, 0x00000000}},  //   liúc, _inke, reol_,
  { {0xb33c0066, 0x00000000, 0x00000000, 0x00000000}},  //   _saħq,   ,   ,
  { {0x26cc008d, 0xf1c50061, 0xad9b0051, 0x00000000}},  //   _çdo_, वांन, niúc,
  { {0x672e0243, 0xd5ad00a1, 0xe617005e, 0x00000000}},  //   _izbj, _مہم_, _ддс_,
  { {0xdfa6025f, 0xc05a0088, 0x6562008a, 0x00000000}},  //   ојно, шій_, mboh,
  { {0x33d50245, 0x9f5e0023, 0x65620668, 0x00000000}},  //   _ніхт, mitë_, lboh,
  { {0x69c63409, 0x24500011, 0x9f5e0023, 0x00000000}},  //   _onke, _hàm_, litë_,
  { {0x7bda01e5, 0x29dc004a, 0x00000000, 0x00000000}},  //   ötun, _mías_,   ,
  { {0x8cf4007e, 0x9f5e0065, 0xceb8007f, 0x00000000}},  //   дзяц, nitë_, svę_,
  { {0x212b010f, 0x6b9b016e, 0x00000000, 0x00000000}},  //   üche_, đugo,   ,
  { {0x245000ad, 0xf96b005e, 0x236c0521, 0x00000000}},  //   _làm_, ирай_, _medj_,
  { {0x5c750954, 0xdce60089, 0x5fe00061, 0x00000000}},  //   _елит, sakā, _पकडल,
  { {0x7bd7006b, 0xe894007c, 0x68fb0142, 0x00000000}},  // [e450] _toxu, мать, _ľuds,
  { {0x3f8c01e5, 0xcd340379, 0x4e9500a1, 0x00000000}},  //   ngdu_, _غريب, _بھیج_,
  { {0xac380025, 0x6d48013e, 0x00000000, 0x00000000}},  //   _بسيط_, ědav,   ,
  { {0x29dc0958, 0x9f5e0065, 0x683000f8, 0x00000000}},  //   _días_, fitë_, väde,
  { {0x24f807d0, 0xf1b9013e, 0x6fbc0061, 0x00000000}},  //   онцы_, noše_, ्ञां,
  { {0x493a009b, 0xf8bf008e, 0xf8da009b, 0x00000000}},  //   _לגרו, _iré_, _החשמ,
  { {0x81b40055, 0x5b7c0097, 0x9f5e00d4, 0x00000000}},  //   ঞান_, ברוא, mitè_,
  { {0x68300002, 0x798d0169, 0x9f5e3ced, 0x00000000}},  //   räde, ngaw, litè_,
  { {0x2458007c, 0x78ad0146, 0x200b00c4, 0x00000000}},  //   _мать_, nwav, écio_,
  { {0x1e8500ed, 0x7ddf0065, 0x9f5e01aa, 0x00000000}},  //   плом, _mësu, nitè_,
  { {0x7a050006, 0xa3b809b9, 0x37bd0044, 0x00000000}},  //   lėtu, _باقر_, _আকার,
  { {0xd1b81941, 0xcfe9007a, 0x236c016c, 0x00000000}},  //   _وانا_, _گفته_, _zedj_,
  { {0x6e92025a, 0x00000000, 0x00000000, 0x00000000}},  //   ولیا,   ,   ,
  { {0x6283321f, 0x00000000, 0x00000000, 0x00000000}},  //   orno,   ,   ,
  { {0xab2a012b, 0x9f5e0065, 0xee490082, 0x00000000}},  //   сова_, zitë_, _kẽm_,
  { {0xad9b002a, 0x798d011c, 0x8b6601b2, 0x00000000}},  //   riúc, ggaw, _کاظم,
  { {0x98a30081, 0xad9b0051, 0xf8bf31bf, 0x00000000}},  // [e460] ните, siúc, _cré_,
  { {0xf99f0173, 0x798d00e0, 0x657b0145, 0x00000000}},  //   _ebè_, agaw, _aduh,
  { {0x44270022, 0x236c01c3, 0x24500082, 0x00000000}},  //   dln_, _redj_, _sàm_,
  { {0x29dc008e, 0x9f5e0023, 0x00000000, 0x00000000}},  //   _vías_, titë_,   ,
  { {0x649a00da, 0x656201a3, 0x62830116, 0x00000000}},  //   стер_, rboh, erno,
  { {0x386004cb, 0xa5330106, 0x9f5e0065, 0x00000000}},  //   mpir_, хніч, ritë_,
  { {0x9f5e0065, 0x386000f6, 0x645b2a48, 0x00000000}},  //   sitë_, lpir_, _etui,
  { {0x9f5e040a, 0x2fc700e0, 0x3a220085, 0x00000000}},  //   mité_, _anng_, _jkkp_,
  { {0x9f5e31cb, 0xb034034b, 0xdb070023, 0x00000000}},  //   lité_, мниш, tejë,
  { {0xb4d80201, 0x66023cee, 0x628310b1, 0x00000000}},  //   ाही_, liok, brno,
  { {0x9f5e3cef, 0x81460a4f, 0x6283016c, 0x00000000}},  //   nité_, _فنان, crno,
  { {0x63aa009f, 0x764e0009, 0x9f5e0173, 0x00000000}},  //   lefn, _muby, zitè_,
  { {0x6298388f, 0x628a00b0, 0xdb1e000a, 0x00000000}},  //   ltvo, lufo, _anpà,
  { {0x764e0263, 0x63aa009f, 0x62983cf0, 0x00000000}},  //   _ouby, nefn, otvo,
  { {0x201e007f, 0x798d0007, 0x62980168, 0x00000000}},  //   moti_, tgaw, ntvo,
  { {0xf8bf1ca5, 0x201e0059, 0x9f5e00f4, 0x00000000}},  //   _pré_, loti_, dité_,
  { {0x798d0007, 0x2c270088, 0x6d400142, 0x00000000}},  // [e470] rgaw, _ньог, žmar,
  { {0x201e008f, 0x9f4701ca, 0x9f5e009d, 0x00000000}},  //   noti_, _plné_, fité_,
  { {0x3dc902c2, 0xd6db005e, 0x645b3cf1, 0x00000000}},  //   _knaw_, щта_, _stui,
  { {0xf8bf1801, 0x764e0542, 0x660211fe, 0x00000000}},  //   _tré_, _duby, giok,
  { {0x6283018e, 0x3e4c0224, 0x201e0ecb, 0x00000000}},  //   wrno, _děti_, koti_,
  { {0x0fe70044, 0x201e0006, 0x7a050006, 0x00000000}},  //   _পদ্ধ, joti_, rėtu,
  { {0x9f5e3cf2, 0x201e008f, 0x4e1d013d, 0x00000000}},  //   cité_, doti_, नवाई_,
  { {0x3a290010, 0x200c006c, 0x24800091, 0x00000000}},  //   nlap_, endi_, šima_,
  { {0x6b9c018e, 0x200c000c, 0x22460288, 0x00000000}},  //   yfrg, fndi_, _diok_,
  { {0x201e0006, 0x00000000, 0x00000000, 0x00000000}},  //   goti_,   ,   ,
  { {0xe7f5013d, 0x3a290336, 0x6830006c, 0x00000000}},  //   _इतना_, klap_, näda,
  { {0xed570088, 0x200c0197, 0x22460022, 0x00000000}},  //   мою_, andi_, _giok_,
  { {0x201e0995, 0x417402fd, 0xee371734, 0x00000000}},  //   boti_, _سانس, ьню_,
  { {0x6602002d, 0x320d00fa, 0x201e0420, 0x00000000}},  //   ziok, lney_, coti_,
  { {0xef1f006b, 0x9f5e009d, 0x3a2901c3, 0x00000000}},  //   şüb_, xité_, flap_,
  { {0x320d278f, 0x9f5e3cf3, 0xad9b0051, 0x00000000}},  //   nney_, vité_, liún,
  { {0x765c29bf, 0xd7c90183, 0x6e2401dd, 0x00000000}},  // [e480] _stry, रांच, _ikib,
  { {0x66e6030d, 0x9f5e009d, 0xad9b0048, 0x00000000}},  //   моза, tité_, niún,
  { {0x86c60054, 0x38600a16, 0x321f01aa, 0x00000000}},  //   بيان, spir_, kouy_,
  { {0x9f5e028c, 0x452a01e0, 0xad9b0051, 0x00000000}},  //   rité_, ожен_, hiún,
  { {0x9f5e00f4, 0x63aa000c, 0x320d00ab, 0x00000000}},  //   sité_, tefn, dney_,
  { {0xd25a09ae, 0x684601e1, 0x66020416, 0x00000000}},  //   оци_, _інва, siok,
  { {0x201e0006, 0xf743072b, 0x63aa06d6, 0x00000000}},  //   voti_, _аеро, refn,
  { {0x321f01aa, 0x6298010f, 0x63aa000c, 0x00000000}},  //   gouy_, rtvo, sefn,
  { {0x6298037e, 0x68e4023a, 0x201e0089, 0x00000000}},  //   stvo, nyid, toti_,
  { {0x6e24020c, 0xad9b0051, 0x733601fa, 0x00000000}},  //   _akib, giún, _قرائ,
  { {0x3c240039, 0x201e0161, 0xdef7007e, 0x00000000}},  //   hövs_, roti_, дыя_,
  { {0x6e3613a6, 0x00e6005e, 0x64480122, 0x00000000}},  //   _chyb, _ожен, _hidi,
  { {0x201e000b, 0x64481475, 0xdb0e1f7d, 0x00000000}},  //   poti_, _kidi, ndbæ,
  { {0x644801aa, 0x6e243cf4, 0x7fb80014, 0x00000000}},  //   _jidi, _ekib, _رهبر_,
  { {0x6448008d, 0x60c201ca, 0x3a290010, 0x00000000}},  //   _midi, _hrom, tlap_,
  { {0x60c200b9, 0x1de3007d, 0x248616d0, 0x00000000}},  //   _krom, _पवित, krom_,
  { {0x3a29031e, 0x7b6701e0, 0xf1b906ed, 0x00000000}},  // [e490] rlap_, _отне, noša_,
  { {0x248629de, 0x64480197, 0x6e3d3cf5, 0x00000000}},  //   drom_, _nidi, lmsb,
  { {0xf4140044, 0x9f4c004a, 0x00000000, 0x00000000}},  //   িতার_, lidó_,   ,
  { {0x2486016c, 0x64480e71, 0x683000f8, 0x00000000}},  //   from_, _aidi, räda,
  { {0xb4e90164, 0x64481ff1, 0xf1b901c5, 0x00000000}},  //   मने_, _bidi, joša_,
  { {0x69dd01a2, 0x320d0c78, 0xc6a70256, 0x00000000}},  //   _hose, wney_, _орби,
  { {0x320d077d, 0x644804d4, 0x387e0089, 0x00000000}},  //   tney_, _didi, _ātri_,
  { {0x69dd04bd, 0x60c20039, 0xf770026c, 0x00000000}},  //   _jose, _brom, _ماہ_,
  { {0x69dd0007, 0x320d00ab, 0x6e360016, 0x00000000}},  //   _mose, rney_, _rhyb,
  { {0x60c20007, 0x6e240030, 0x6448011f, 0x00000000}},  //   _drom, _skib, _gidi,
  { {0xa2c00061, 0xad9b102e, 0x60c20599, 0x00000000}},  //   विण्, riún, _erom,
  { {0xad9b002a, 0x69dd01d9, 0x60c2084d, 0x00000000}},  //   siún, _nose, _from,
  { {0x2e32000c, 0xad9b0051, 0x60c208c5, 0x00000000}},  //   gáfa_, miúl, _grom,
  { {0x6e3d3cf6, 0xad9b0051, 0x61e91484, 0x00000000}},  //   amsb, liúl, lkel,
  { {0x2005006a, 0x69dd011c, 0xf1d30309, 0x00000000}},  //   mili_, _bose, थापन,
  { {0xf2d200bd, 0x61e902ae, 0x69dd3cf7, 0x00000000}},  //   נען_, nkel, _cose,
  { {0x69dd3cf8, 0xa84a0355, 0x61e900b5, 0x00000000}},  // [e4a0] _dose, سلام_, ikel,
  { {0x61e9006c, 0xdc9b0049, 0xad9b0051, 0x00000000}},  //   hkel, _צייל, hiúl,
  { {0x64480585, 0x69dd3cf9, 0x7bde0026, 0x00000000}},  //   _ridi, _fose, _iopu,
  { {0x248609fc, 0x7ae117ed, 0x200503ef, 0x00000000}},  //   trom_, älte, hili_,
  { {0x2005187c, 0x64480c1b, 0x7bde3cfa, 0x00000000}},  //   kili_, _pidi, _kopu,
  { {0x24800006, 0x2005000b, 0x61e90328, 0x00000000}},  //   šimo_, jili_, ekel,
  { {0x2d800058, 0x44250146, 0x7bde0035, 0x00000000}},  //   _odie_, _dkl_, _mopu,
  { {0xe6430057, 0x7bde021e, 0x64481300, 0x00000000}},  //   _бесп, _lopu, _widi,
  { {0x64480073, 0x20050065, 0x09c50044, 0x00000000}},  //   _tidi, fili_, _একমা,
  { {0x2005011f, 0x32040036, 0x9f4c008e, 0x00000000}},  //   gili_, simy_, vidó_,
  { {0x211a01ef, 0x1b050044, 0x9f5e0051, 0x00000000}},  //   _کتاب_, _শুনে_, ontú_,
  { {0x60c20292, 0x61e903a9, 0xad9b0051, 0x00000000}},  //   _trom, ckel, ciúl,
  { {0x20051ff6, 0x9ccb007e, 0x7bde01c3, 0x00000000}},  //   bili_, чына_, _bopu,
  { {0x69dd0059, 0x2d8000d2, 0x9f4c00fa, 0x00000000}},  //   _sose, _edie_, ridó_,
  { {0x69dd0a0f, 0x6d4d001c, 0x7bde0209, 0x00000000}},  //   _pose, _tgaa, _dopu,
  { {0x8e830025, 0x99cf0044, 0x63ba3cfb, 0x00000000}},  //   _إليه, রস্ক, _latn,
  { {0x69dd0087, 0x00000000, 0x00000000, 0x00000000}},  // [e4b0] _vose,   ,   ,
  { {0xf7700137, 0xd7c90014, 0x7bde01f3, 0x00000000}},  //   مام_, بوطه_, _gopu,
  { {0x56950a1e, 0xfd1000a1, 0x99800295, 0x00000000}},  //   тает, _نجی_, sliš_,
  { {0x2a610022, 0x2ca90022, 0x7e7a00ea, 0x00000000}},  //   _ithb_, _kpad_, istp,
  { {0x44250093, 0x63ba000c, 0x00000000, 0x00000000}},  //   _pkl_, _batn,   ,
  { {0x2005006b, 0x63ba0bec, 0xec720049, 0x00000000}},  //   xili_, _catn, בֿה_,
  { {0xb5a7008b, 0x61e9182c, 0xad9b0051, 0x00000000}},  //   _прай, tkel, tiúl,
  { {0x2005195b, 0x1635007c, 0x7777002b, 0x00000000}},  //   wili_, _ребя, laxx,
  { {0x20050213, 0x63ba01e5, 0x44253cfc, 0x00000000}},  //   tili_, _fatn, _tkl_,
  { {0x61e92334, 0xe9df0051, 0xad9b0051, 0x00000000}},  //   skel, _siúl_, siúl,
  { {0x2005006a, 0x2bd50061, 0x2d8000f6, 0x00000000}},  //   rili_, दाना, _pdie_,
  { {0x7bde0052, 0x00000000, 0x00000000, 0x00000000}},  //   _sopu,   ,   ,
  { {0x7bde07d4, 0xad9b00c4, 0x63ba0022, 0x00000000}},  //   _popu, ciúm, _yatn,
  { {0xafe2007c, 0x00000000, 0x00000000, 0x00000000}},  //   _вошл,   ,   ,
  { {0xab27017f, 0x00000000, 0x00000000, 0x00000000}},  //   вора_,   ,   ,
  { {0x2a36007e, 0x00000000, 0x00000000, 0x00000000}},  //   тэгр,   ,   ,
  { {0x25bd018e, 0x7bde149f, 0x673501d5, 0x00000000}},  // [e4c0] ddwl_, _topu, _azzj,
  { {0xdb1c0065, 0xf1b901c5, 0x00000000, 0x00000000}},  //   ndrë, košo_,   ,
  { {0x63ba037e, 0xc81501fb, 0xf1b90089, 0x00000000}},  //   _ratn, уєть, jošo_,
  { {0x7c2e0210, 0x63ba016e, 0xf1b90089, 0x00000000}},  //   llbr, _satn, došo_,
  { {0x2b06013d, 0x00000000, 0x00000000, 0x00000000}},  //   _हेतु_,   ,   ,
  { {0xdb0701dc, 0x77770026, 0x82a601ab, 0x00000000}},  //   zejí, caxx, вшие,
  { {0xfba402fb, 0x63ba021a, 0x2ba40309, 0x00000000}},  //   ख्यम, _vatn, ख्या,
  { {0xcb130452, 0xbbdf0183, 0x63ba00e0, 0x00000000}},  //   ילו_, _नक्क, _watn,
  { {0x5edf0044, 0x63ba0066, 0x00000000, 0x00000000}},  //   _ফেলে, _tatn,   ,
  { {0x9ed800ed, 0xef1f014a, 0x00000000, 0x00000000}},  //   емот_, ğün_,   ,
  { {0xd36f0014, 0x2ca90145, 0xef1f005d, 0x00000000}},  //   _ذهن_, _spad_, şün_,
  { {0x7e7a0c46, 0x442e00f6, 0xdb1c0023, 0x00000000}},  //   rstp, llf_, adrë,
  { {0x5c07005e, 0x6fb60025, 0xa3b60204, 0x00000000}},  //   вява, _لمشا, _जसा_,
  { {0xdb0700b9, 0x2f180604, 0x00000000, 0x00000000}},  //   sejí, _поль_,   ,
  { {0x9f5e3cfd, 0x3ced00ca, 0x201900f4, 0x00000000}},  //   mità_, šev_, ésie_,
  { {0x9f5e0282, 0x7c2e00ea, 0x996416e8, 0x00000000}},  //   lità_, albr, итул,
  { {0x101700a1, 0x6d5d0010, 0xa8150140, 0x00000000}},  // [e4d0] _سکیں_, mcsa, гдаш,
  { {0x9f5e13f0, 0x00000000, 0x00000000, 0x00000000}},  //   nità_,   ,   ,
  { {0x77770066, 0xf7700380, 0x00000000, 0x00000000}},  //   raxx, زال_,   ,
  { {0x6d5d0010, 0x80b7006e, 0x00000000, 0x00000000}},  //   ncsa, ्टमे,   ,
  { {0x69cf3cfe, 0x45840088, 0x65943cff, 0x00000000}},  //   _ince, ргів, рачу,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f5e0282, 0x36d40194, 0x00000000, 0x00000000}},  //   dità_, _корр,   ,
  { {0x442e00c7, 0xf48500a1, 0x85040061, 0x00000000}},  //   alf_, _مائی, _शेवट_,
  { {0xc61f0061, 0xbcfb16ff, 0x9f5e00f6, 0x00000000}},  //   यकीय_, ncéd, fità_,
  { {0xa2c00164, 0x9f450051, 0x9f5e0026, 0x00000000}},  //   विश्, mhlú_, gità_,
  { {0x69cf0095, 0x5f05034b, 0x00000000, 0x00000000}},  //   _once, узна,   ,
  { {0x76550046, 0x2459001d, 0x00000000, 0x00000000}},  //   _muzy, _kèm_,   ,
  { {0x2d9e0036, 0x245901aa, 0x1fdf0044, 0x00000000}},  //   ęte_, _jèm_, যোগস,
  { {0x9f5e0198, 0x2d9e00b9, 0x24591e60, 0x00000000}},  //   cità_, řte_, _mèm_,
  { {0xf8bf0047, 0x2459135a, 0x3eb90089, 0x00000000}},  //   _szép_, _lèm_, āsts_,
  { {0xdb1c3d00, 0x7ae100f8, 0x00000000, 0x00000000}},  //   ndré, älta,   ,
  { {0xdb0e000c, 0x6e260010, 0xc7a61b15, 0x00000000}},  // [e4e0] ndbú, mokb, лиак,
  { {0x67f2009f, 0x998900b4, 0x46f61b15, 0x00000000}},  //   _bæja, gnał_, лчет,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd5b901ff, 0x657900e0, 0x00000000, 0x00000000}},  //   ксі_, gawh,   ,
  { {0xbcfb009d, 0xa4d40088, 0x00000000, 0x00000000}},  //   ccéd, ролі,   ,
  { {0xd7f20025, 0x00000000, 0x00000000, 0x00000000}},  //   _اكس_,   ,   ,
  { {0x9f5e0409, 0x66e3030d, 0x628a01c3, 0x00000000}},  //   vità_, _лора, urfo,
  { {0x245901aa, 0x00000000, 0x00000000, 0x00000000}},  //   _fèm_,   ,   ,
  { {0x463b007b, 0x9f5e17f4, 0xe45f014a, 0x00000000}},  //   _טעלע, tità_, _çöp_,
  { {0x527604af, 0x09e1001c, 0xad9b0051, 0x00000000}},  //   _буду, _नव्य, miúi,
  { {0x9f5e13f0, 0xad9b0051, 0x29dc02a0, 0x00000000}},  //   rità_, liúi, _díaz_,
  { {0x9f5e0207, 0x245901aa, 0x867b009b, 0x00000000}},  //   sità_, _yèm_, ערכו,
  { {0xcd070216, 0xad9b0051, 0x63a8012d, 0x00000000}},  //   учни, niúi, _kbdn,
  { {0x61e20004, 0xab95012b, 0x30830025, 0x00000000}},  //   _hool, јављ, _الوف,
  { {0xc4c4024a, 0xad9b0051, 0x61e20114, 0x00000000}},  //   _کے_, hiúi, _kool,
  { {0x61e201d6, 0x82770049, 0x7655013e, 0x00000000}},  //   _jool, טעלע_, _ruzy,
  { {0xcfb70055, 0x61e201d6, 0x26e20044, 0x00000000}},  // [e4f0] জারন, _mool, _গেলো_,
  { {0xad9b0051, 0x24590082, 0x61e2010e, 0x00000000}},  //   diúi, _rèm_, _lool,
  { {0x26c70285, 0x65793d01, 0xf77003d6, 0x00000000}},  //   íno_, tawh, ثاق_,
  { {0x69cf0133, 0x61e2010e, 0x9f450048, 0x00000000}},  //   _unce, _nool, thlú_,
  { {0xad9b0051, 0xa8790049, 0x65790066, 0x00000000}},  //   giúi, _באָר, rawh,
  { {0x3206011c, 0x00000000, 0x00000000, 0x00000000}},  //   _amoy_,   ,   ,
  { {0x38690332, 0x00000000, 0x00000000, 0x00000000}},  //   lpar_,   ,   ,
  { {0x245901aa, 0x61e200ab, 0x11e5007c, 0x00000000}},  //   _tèm_, _cool, ржим,
  { {0x61e201d6, 0xad9b0051, 0xe5340088, 0x00000000}},  //   _dool, ciúi, _геть,
  { {0x25bf3d02, 0x660b0302, 0x249f01f3, 0x00000000}},  //   _haul_, ligk, _iqum_,
  { {0x02d91847, 0x3255004c, 0x3ea500ed, 0x00000000}},  //   _جواب_, _твер, шинг,
  { {0x61e20197, 0x720700a1, 0x3f8b0c4f, 0x00000000}},  //   _gool, _حفصہ_, şcu_,
  { {0x44270004, 0x7ae1010f, 0x200b00f4, 0x00000000}},  //   oon_, ältn, écis_,
  { {0x1ef90054, 0x64430051, 0x660b010f, 0x00000000}},  //   _لعبة_, nmni, higk,
  { {0xab2a0265, 0x64433d03, 0x4427186c, 0x00000000}},  //   това_, imni, ion_,
  { {0x44273d04, 0xdb1e0065, 0x60c4016e, 0x00000000}},  //   hon_, _hapë, _šimi,
  { {0x44270209, 0xa8061561, 0x9756012b, 0x00000000}},  // [e500] kon_, азал, атељ,
  { {0x44270292, 0x64430036, 0xdb071748, 0x00000000}},  //   jon_, jmni, sejá,
  { {0x25bf1ebf, 0x09c50044, 0x20070022, 0x00000000}},  //   _baul_, _একরা, _mmni_,
  { {0xad9b002a, 0xe5a6142c, 0x4427005b, 0x00000000}},  //   tiúi, риди, eon_,
  { {0x44272c60, 0x2480002a, 0x20071b27, 0x00000000}},  //   fon_, éim_, _omni_,
  { {0x44270aa4, 0x61e2006c, 0xad9b0051, 0x00000000}},  //   gon_, _sool, riúi,
  { {0x66e60373, 0xad9b002a, 0x660b0548, 0x00000000}},  //   _това, siúi, bigk,
  { {0x24890ade, 0x30a602be, 0x25bf023a, 0x00000000}},  //   šama_, аров, _gaul_,
  { {0x44271987, 0xdfd00054, 0x61e2006c, 0x00000000}},  //   bon_, كية_, _vool,
  { {0x44270498, 0x61e20133, 0x20070145, 0x00000000}},  //   con_, _wool, _cmni_,
  { {0x3fc802fd, 0x20190129, 0x443e1506, 0x00000000}},  //   ندگی_, ésia_, _iht_,
  { {0x442c0093, 0x10a6007c, 0x443e0082, 0x00000000}},  //   _hkd_, _видн, _hht_,
  { {0x442c0022, 0x00d70167, 0x13aa0044, 0x00000000}},  //   _kkd_, _نبوت_, _গোয়,
  { {0x26fc0055, 0x99890036, 0x20070022, 0x00000000}},  //   _এখনো_, znań_, _gmni_,
  { {0x7ac40373, 0x200c1097, 0x443e0030, 0x00000000}},  //   осте, midi_, _mht_,
  { {0x4427060b, 0x443e0058, 0x5d850025, 0x00000000}},  //   zon_, _lht_, _الظل,
  { {0x44272f00, 0xe7d2001c, 0xa3b602d2, 0x00000000}},  // [e510] yon_, सांप, ज़ा_,
  { {0x44273d05, 0x25bf01d6, 0x38690016, 0x00000000}},  //   xon_, _saul_, rpar_,
  { {0x44271744, 0x660b010f, 0xe9450014, 0x00000000}},  //   von_, tigk, _گردی,
  { {0x200c000b, 0x44273d06, 0x38693d07, 0x00000000}},  //   hidi_, won_, ppar_,
  { {0xd49b00e3, 0x442c3d08, 0x660b01a2, 0x00000000}},  //   тре_, _bkd_, rigk,
  { {0x660b010f, 0x6443016c, 0x212f0056, 0x00000000}},  //   sigk, umni, _rygh_,
  { {0x442702e2, 0x68ed1892, 0x64430193, 0x00000000}},  //   ron_, lyad, rmni,
  { {0x40950726, 0x6e2d0009, 0xef1f014a, 0x00000000}},  //   брот, _nkab, şük_,
  { {0x68ed0890, 0x6609000b, 0x4427066d, 0x00000000}},  //   nyad, _imek, pon_,
  { {0x753b037e, 0x6e2d1786, 0x200c0197, 0x00000000}},  //   _izuz, _akab, gidi_,
  { {0x68ed0022, 0x00000000, 0x00000000, 0x00000000}},  //   hyad,   ,   ,
  { {0x7c3e008d, 0xc692007b, 0xa159003b, 0x00000000}},  //   _shpr, האט_, _саду_,
  { {0x661b3d09, 0x200c0020, 0x66091519, 0x00000000}},  //   _mjuk, bidi_, _mmek,
  { {0x3c19008b, 0x200c0197, 0x6830010f, 0x00000000}},  //   аўся_, cidi_, pädi,
  { {0x6e950379, 0xa3a902f4, 0x5e950025, 0x00000000}},  //   _العا, ग्य_, _العط,
  { {0x661b012d, 0x00000000, 0x00000000, 0x00000000}},  //   _njuk,   ,   ,
  { {0x81cc0044, 0x26ca016c, 0xf99f0173, 0x00000000}},  // [e520] _রকম_, _srbo_, _imèl_,
  { {0x6609000b, 0xdb1c158b, 0x661b14f0, 0x00000000}},  //   _amek, ldrí, _ajuk,
  { {0x2bd5001c, 0x5b5701ce, 0xd378016e, 0x00000000}},  //   दारा, _לייב_, _reć_,
  { {0x200c0020, 0xdb1c0211, 0x442c0059, 0x00000000}},  //   zidi_, ndrí, _skd_,
  { {0x661b0107, 0x61fb0020, 0xceb80036, 0x00000000}},  //   _djuk, dhul, zwę_,
  { {0x29000020, 0x6609014a, 0x443e006b, 0x00000000}},  //   mzia_, _emek, _qht_,
  { {0xd3780119, 0x200c0207, 0xf1d30061, 0x00000000}},  //   _već_, vidi_, थांन,
  { {0x61fb000b, 0x443e3d0a, 0xda7b0049, 0x00000000}},  //   ghul, _wht_, אנקר,
  { {0x78a4049a, 0x29003d0b, 0x442c23c4, 0x00000000}},  //   ntiv, nzia_, _tkd_,
  { {0x6e2d0018, 0x6ee60025, 0x656200d9, 0x00000000}},  //   _skab, مسجل, lcoh,
  { {0xdd910076, 0x200c0020, 0x78a401c2, 0x00000000}},  //   وود_, ridi_, htiv,
  { {0x61fb010f, 0x65620023, 0x633b0049, 0x00000000}},  //   chul, ncoh, _געבױ,
  { {0x69c401d5, 0x200c1d79, 0x2d99046a, 0x00000000}},  //   ddie, pidi_, rgse_,
  { {0x69c40089, 0x29003d0c, 0x6d560010, 0x00000000}},  //   edie, dzia_, _egya,
  { {0xec3401fb, 0xcfa9007a, 0x76403d0d, 0x00000000}},  //   їнсь, _خانم_, _ohmy,
  { {0xf1b90089, 0x69c40116, 0x6e2d3d0e, 0x00000000}},  //   toši_, gdie, _ukab,
  { {0x7c97004b, 0x2d8900f6, 0x00000000, 0x00000000}},  // [e530] _اشعا, _idae_,   ,
  { {0x661b01c9, 0x6609074d, 0x68ed0093, 0x00000000}},  //   _sjuk, _smek, ryad,
  { {0x78a40209, 0x68ed006a, 0x29000197, 0x00000000}},  //   ativ, syad, azia_,
  { {0xd2460014, 0x99990006, 0xe7f50061, 0x00000000}},  //   _زن_, _visų_, _इतका_,
  { {0x78a41294, 0x039501c5, 0x00000000, 0x00000000}},  //   ctiv, žīmā_,   ,
  { {0x248913cf, 0x00000000, 0x00000000, 0x00000000}},  //   šamo_,   ,   ,
  { {0xdb1e0181, 0x61fb08a5, 0x661b00ea, 0x00000000}},  //   _papé, thul, _tjuk,
  { {0x66090020, 0xa5f80930, 0x60db0032, 0x00000000}},  //   _umek, _лесу_, txum,
  { {0x201900c4, 0x00000000, 0x00000000, 0x00000000}},  //   ésio_,   ,   ,
  { {0x60090175, 0x61fb0041, 0x657b0433, 0x00000000}},  //   рном_, shul, _heuh,
  { {0xe4480025, 0x29000197, 0x60c40006, 0x00000000}},  //   _اللى_, zzia_, _šimt,
  { {0x9f4501dc, 0xf8bf009d, 0x645b00e7, 0x00000000}},  //   chlý_, _osé_, _kuui,
  { {0xc0e51281, 0x628300bb, 0x00000000, 0x00000000}},  //   _фолк, lsno,   ,
  { {0x317f0232, 0x6d560009, 0x645b00fa, 0x00000000}},  //   lauz_, _wgya, _muui,
  { {0x60c9049a, 0x69c4125b, 0x1ea80014, 0x00000000}},  //   lvem, tdie, _هايي_,
  { {0x78a43d0f, 0x6d560047, 0x2900022b, 0x00000000}},  //   ttiv, _ugya, tzia_,
  { {0x98a300a8, 0xf1b200a3, 0x29002ecb, 0x00000000}},  // [e540] мите, וסן_, uzia_,
  { {0xda0b0061, 0x29000142, 0x9cb30014, 0x00000000}},  //   सोबत_, rzia_, _کمیت,
  { {0x56930088, 0x69c412ec, 0xdb0e01a2, 0x00000000}},  //   даєт, pdie, ndbü,
  { {0x78a400ab, 0xad9b0051, 0x628300d9, 0x00000000}},  //   ptiv, liúr, dsno,
  { {0x6441002a, 0x21f80010, 0x65620023, 0x00000000}},  //   _bhli, _néha_, rcoh,
  { {0x20190ff6, 0x64413d10, 0x25ad00ca, 0x00000000}},  //   ésil_, _chli, _ebel_,
  { {0xfc3f1526, 0xa2bd01f5, 0xa3a9006e, 0x00000000}},  //   ntía_, _वैद्, ग्ध_,
  { {0xd3780091, 0x6441014a, 0x317f0334, 0x00000000}},  //   _moći_, _ehli, gauz_,
  { {0xef180089, 0x64a60216, 0x41a601f5, 0x00000000}},  //   daļa_, _фаза, क्षस,
  { {0x765c011c, 0x4ea60d68, 0x244001aa, 0x00000000}},  //   _kury, орма, fòme_,
  { {0xd3780091, 0x2bde0067, 0x765c02e1, 0x00000000}},  //   _noći_, माना, _jury,
  { {0x765c0ef9, 0x00000000, 0x00000000, 0x00000000}},  //   _mury,   ,   ,
  { {0x5c74060e, 0x202901e5, 0x00000000, 0x00000000}},  //   млят, ótið_,   ,
  { {0x63b800bf, 0xc04f01e1, 0xdb150010, 0x00000000}},  //   nevn, _іі_, lezé,
  { {0xc1ee013d, 0x3950006b, 0x765c0f42, 0x00000000}},  //   _जवाब_, ənsə_, _nury,
  { {0xd3780363, 0x91fc0089, 0xee0800ed, 0x00000000}},  //   _doći_, _stāj, _мејл_,
  { {0x2e32000c, 0xbd8800a1, 0x62550066, 0x00000000}},  // [e550] gáfu_, _بچپن_, _jġor,
  { {0x765c0061, 0xf77006b4, 0xdb17006b, 0x00000000}},  //   _bury, نام_, _naxç,
  { {0xd6db0269, 0xdb150047, 0x35b5005e, 0x00000000}},  //   шта_, kezé, збер,
  { {0xdb150010, 0x765c0006, 0x64410051, 0x00000000}},  //   jezé, _dury, _shli,
  { {0x7bc5006a, 0x9f4c0051, 0x765c00ea, 0x00000000}},  //   _kahu, ghdú_, _eury,
  { {0x628300bb, 0x7bc70010, 0x7bc5006c, 0x00000000}},  //   tsno, ndju, _jahu,
  { {0x7bc51312, 0x61f90009, 0x657b0023, 0x00000000}},  //   _mahu, _plwl, _teuh,
  { {0x4095013b, 0xdb1c004a, 0x628301d6, 0x00000000}},  //   прот, ndrá, rsno,
  { {0x628302e1, 0x60090088, 0xe0d6007e, 0x00000000}},  //   ssno, йним_, звы_,
  { {0x7bc5011c, 0xaf050265, 0x60c901b1, 0x00000000}},  //   _nahu, зпол, rvem,
  { {0xed5a0c74, 0x7bc707c4, 0x00000000, 0x00000000}},  //   йон_, ddju,   ,
  { {0xd1310054, 0xf1b90089, 0x00000000, 0x00000000}},  //   _كما_, tošu_,   ,
  { {0xf1b90059, 0x7bc524be, 0x00000000, 0x00000000}},  //   meš_, _bahu,   ,
  { {0x9f470065, 0x7bc50035, 0xf1b90089, 0x00000000}},  //   _jonë_, _cahu, rošu_,
  { {0x7bc5027e, 0x0f7a009b, 0x39590022, 0x00000000}},  //   _dahu, _הרצל, _bgss_,
  { {0x09e30113, 0x63b805fa, 0x78660e85, 0x00000000}},  //   носн, zevn, зказ,
  { {0x2d820d2a, 0x765c023a, 0xfc3f008e, 0x00000000}},  // [e560] make_, _sury, stía_,
  { {0x2d82011c, 0x9ce7026c, 0xfc3f002a, 0x00000000}},  //   lake_, _روپے_, ltín_,
  { {0xf1bd024c, 0x41bd001c, 0xdb1e0263, 0x00000000}},  //   ्यान, ्यास, _enpò,
  { {0x2d820059, 0x7c2e0ade, 0xf1b90091, 0x00000000}},  //   nake_, lobr, ješ_,
  { {0x63b801ca, 0x7bc50996, 0xf1b90161, 0x00000000}},  //   tevn, _yahu, deš_,
  { {0x62980736, 0x69c6021e, 0x765c0046, 0x00000000}},  //   tuvo, _hake, _tury,
  { {0x69c63d11, 0x63b83d12, 0xa2b300a1, 0x00000000}},  //   _kake, revn, ٹینڈ,
  { {0x2d8209fc, 0x69c60297, 0x64a601fc, 0x00000000}},  //   jake_, _jake, _наба,
  { {0x69c60f12, 0x2d82006c, 0xdb23000c, 0x00000000}},  //   _make, dake_, _þrön,
  { {0xe9df0011, 0x2ef40175, 0x69c600ab, 0x00000000}},  //   _khúc_, дзор, _lake,
  { {0x7bc50004, 0x24863d13, 0x7c2e016e, 0x00000000}},  //   _rahu, lsom_, dobr,
  { {0xdb1e045b, 0x442e01d6, 0x69c60472, 0x00000000}},  //   _capí, lof_, _nake,
  { {0x24860145, 0xdb1c000c, 0x1154007e, 0x00000000}},  //   nsom_, ndræ, _ўклю,
  { {0x60c200b0, 0xc5fa0044, 0xf1da013d, 0x00000000}},  //   _isom, েকটা_, भावन,
  { {0x69c61624, 0x2d8238d5, 0x7bc70864, 0x00000000}},  //   _bake, bake_, rdju,
  { {0x24860039, 0x69c601a3, 0x442e0125, 0x00000000}},  //   ksom_, _cake, hof_,
  { {0x7bc50149, 0x442e1c44, 0xbd450464, 0x00000000}},  // [e570] _tahu, kof_, _تنظي,
  { {0xd6db1523, 0x9f4701aa, 0x60c20020, 0x00000000}},  //   йте_, _bonè_, _msom,
  { {0xe9df001d, 0xa7fb0553, 0x3e610011, 0x00000000}},  //   _chúc_, _nuñe, _xót_,
  { {0xe9df001d, 0x9f470065, 0x69c60045, 0x00000000}},  //   _giúp_, _sonë_, _gake,
  { {0x8cd0013d, 0x60c201f3, 0x6288012d, 0x00000000}},  //   दियो, _nsom, _avdo,
  { {0x69c602ae, 0x2d82210c, 0x63ad0107, 0x00000000}},  //   _zake, zake_, đano,
  { {0xea00001d, 0xddcd0046, 0x9f470065, 0x00000000}},  //   _hoạt_, _miał, _vonë_,
  { {0x3e6103a3, 0x644a24d9, 0xe5730257, 0x00000000}},  //   _rót_, amfi, _سطر_,
  { {0x3494008b, 0xf1b901d9, 0x9f47008d, 0x00000000}},  //   _патр, reš_, _tonë_,
  { {0x2d82000b, 0xdb1e0181, 0xf1b900ee, 0x00000000}},  //   wake_, _japã, seš_,
  { {0xdb1e3d14, 0xea000011, 0xf1b9144f, 0x00000000}},  //   _papí, _loạt_, peš_,
  { {0x7c2e026e, 0x00000000, 0x00000000, 0x00000000}},  //   wobr,   ,   ,
  { {0x69c61c79, 0x7c2e03e2, 0x522a007b, 0x00000000}},  //   _rake, tobr, _ווײַ,
  { {0x69c63d15, 0xfc3f000c, 0x2d821ec2, 0x00000000}},  //   _sake, stín_, sake_,
  { {0x69c60b53, 0x2d823d16, 0xfaa30081, 0x00000000}},  //   _pake, pake_, каро,
  { {0x2fc71d57, 0x7c2e1346, 0x61eb3d17, 0x00000000}},  //   _hang_, sobr, _jogl,
  { {0x61eb2b24, 0x2fc70b9a, 0x69c600b5, 0x00000000}},  // [e580] _mogl, _kang_, _vake,
  { {0x442e0061, 0x26d10e45, 0xe9df001d, 0x00000000}},  //   xof_, _brzo_, _phúc_,
  { {0x2fc73d18, 0x69c60038, 0x99800006, 0x00000000}},  //   _mang_, _take, ulių_,
  { {0x2fc72b1c, 0x61eb0018, 0x9f5e0065, 0x00000000}},  //   _lang_, _nogl, thtë_,
  { {0x2d800004, 0x99800006, 0x2fc70085, 0x00000000}},  //   _meie_, slių_, _oang_,
  { {0x2fc73d19, 0x2486067e, 0xe9df0011, 0x00000000}},  //   _nang_, rsom_, _thúc_,
  { {0x9f5e008d, 0x96630256, 0x61eb0d22, 0x00000000}},  //   shtë_, _аксе, _bogl,
  { {0x61eb0207, 0xf743025f, 0x442e2d65, 0x00000000}},  //   _cogl, _ресо, sof_,
  { {0x2fc73d1a, 0x442e01c3, 0x00000000, 0x00000000}},  //   _bang_, pof_,   ,
  { {0x44380051, 0x2fc70082, 0x00000000, 0x00000000}},  //   _ór_, _cang_,   ,
  { {0x61eb3d1b, 0xdb0e0039, 0x2fc70011, 0x00000000}},  //   _fogl, nebä, _dang_,
  { {0x61eb018e, 0x2fc7018e, 0x99890036, 0x00000000}},  //   _gogl, _eang_, ział_,
  { {0x2fc70191, 0x79840020, 0x60c23d1c, 0x00000000}},  //   _fang_, daiw, _usom,
  { {0x2fc71d1b, 0x00000000, 0x00000000, 0x00000000}},  //   _gang_,   ,   ,
  { {0xef1f0180, 0xa3b001f5, 0x62a20161, 0x00000000}},  //   şür_, ट्य_, _útoč,
  { {0x2fc700bb, 0x20140036, 0x60cd12db, 0x00000000}},  //   _zang_, ścić_, _šami,
  { {0x2fc70149, 0xe9df0011, 0x66020023, 0x00000000}},  // [e590] _yang_, _chúa_, dhok,
  { {0x201e000c, 0x1ddd007d, 0x22460022, 0x00000000}},  //   nnti_, यावत, _lhok_,
  { {0xa3e20309, 0x201e00b0, 0xf4140044, 0x00000000}},  //   धान_, inti_, াকার_,
  { {0x22460082, 0x99890036, 0x00000000, 0x00000000}},  //   _nhok_, siał_,   ,
  { {0x61eb0087, 0x00000000, 0x00000000, 0x00000000}},  //   _rogl,   ,   ,
  { {0x61eb3d1d, 0x00000000, 0x00000000, 0x00000000}},  //   _sogl,   ,   ,
  { {0x61eb0340, 0x6b7c00b6, 0x2fc70bf5, 0x00000000}},  //   _pogl, חרונ, _rang_,
  { {0x2fc7001d, 0xdb1c02d5, 0x201e0207, 0x00000000}},  //   _sang_, ferê, enti_,
  { {0x61eb3d1e, 0x2fc7006a, 0xdb1e3008, 0x00000000}},  //   _vogl, _pang_, _mapá,
  { {0xe3b0007a, 0x2d800056, 0x3dc900e0, 0x00000000}},  //   _نرم_, _seie_, _aaaw_,
  { {0x61eb0207, 0x2fc73d1f, 0x6da600ed, 0x00000000}},  //   _togl, _vang_, нина,
  { {0x2fc70127, 0x91fc001e, 0x201e06bd, 0x00000000}},  //   _wang_, _stāv, anti_,
  { {0x2fc70011, 0x51840451, 0xdb0e0538, 0x00000000}},  //   _tang_, _руха, ndbö,
  { {0x2fc70390, 0x224d3d20, 0x3ced006c, 0x00000000}},  //   _uang_, lmek_, äeva_,
  { {0x2d800004, 0x3f8500b9, 0x2bd50061, 0x00000000}},  //   _teie_, malu_, दाजा,
  { {0xe1f9010a, 0x3f85020c, 0x224d014a, 0x00000000}},  //   nkų_, lalu_, nmek_,
  { {0x63ad0363, 0xdb05010f, 0xcc8a0025, 0x00000000}},  // [e5a0] đanj, _abhä, _عنده_,
  { {0xfd471001, 0x3f850340, 0xdb1c0065, 0x00000000}},  //   _язык_, nalu_, nerë,
  { {0xc0490082, 0x869a005e, 0x224d014a, 0x00000000}},  //   _sườn_, ятат_, kmek_,
  { {0xf5390027, 0x14ca007c, 0x3f85315e, 0x00000000}},  //   _byť_, зыки_, halu_,
  { {0xc955008b, 0x3f850089, 0x201e00b0, 0x00000000}},  //   _атры, kalu_, ynti_,
  { {0xc0490011, 0x22460065, 0xf2c6004d, 0x00000000}},  //   _vườn_, _shok_, есин,
  { {0xf74300e3, 0xdb1c0023, 0x3f850213, 0x00000000}},  //   _беро, derë, dalu_,
  { {0x68e400f8, 0xdb1c0dce, 0xf99f000a, 0x00000000}},  //   oxid, terê, _elèf_,
  { {0xdfd00054, 0xbddb00f4, 0x3f850016, 0x00000000}},  //   لية_, llèg, falu_,
  { {0xa2e6012b, 0x201e3d21, 0x3f85007f, 0x00000000}},  //   _позд, unti_, galu_,
  { {0x6d443d22, 0x22460022, 0x00000000, 0x00000000}},  //   _azia, _thok_,   ,
  { {0x628a004e, 0x645a0020, 0x443c06d3, 0x00000000}},  //   msfo, _hiti, llv_,
  { {0x645a0006, 0x6f0600f4, 0x3f85154c, 0x00000000}},  //   _kiti, _bébé, balu_,
  { {0x6d440046, 0x645a06a9, 0xbcfb0048, 0x00000000}},  //   _dzia, _jiti, ncéi,
  { {0x645a006b, 0x03d7009b, 0xe9df0051, 0x00000000}},  //   _miti, עולם_, _dhún_,
  { {0x62980190, 0x645a124c, 0x00000000, 0x00000000}},  //   irvo, _liti,   ,
  { {0xab8702be, 0xb955005e, 0x645a2522, 0x00000000}},  // [e5b0] _пунк, тващ, _oiti,
  { {0x6e3d06a1, 0x628a0944, 0x6298016c, 0x00000000}},  //   llsb, ksfo, krvo,
  { {0x2bde0204, 0xa7fb008e, 0x9f5e004a, 0x00000000}},  //   मारा, _cuña, litó_,
  { {0x628a0b09, 0xf650004b, 0x7afa01e3, 0x00000000}},  //   dsfo, مئن_, øtte,
  { {0x69dd0198, 0x645a005d, 0x629800bb, 0x00000000}},  //   _inse, _biti, ervo,
  { {0x7415004b, 0x3fcb0055, 0xdb1c04bd, 0x00000000}},  //   ضوعا, _লক্ষ, ferè,
  { {0x9f4d0279, 0x78ad00b0, 0x645a04cb, 0x00000000}},  //   ünün_, ltav, _diti,
  { {0xe4e70088, 0xe1f90006, 0x645a0051, 0x00000000}},  //   _пізн, ukų_, _eiti,
  { {0x78ad0ef7, 0x224d011f, 0x645a0065, 0x00000000}},  //   ntav, rmek_, _fiti,
  { {0x24550cd9, 0x628a0296, 0x645a1c39, 0x00000000}},  //   _شناس, bsfo, _giti,
  { {0x69dd3d23, 0x78ad003c, 0x248d01e3, 0x00000000}},  //   _onse, htav, _hvem_,
  { {0x78ad0dec, 0x645a010f, 0x3f85006c, 0x00000000}},  //   ktav, _ziti, salu_,
  { {0x6448021e, 0xf6520049, 0x78ad0065, 0x00000000}},  //   _yhdi, יצט_, jtav,
  { {0x69dd3bc7, 0x61e93d24, 0x78ad016c, 0x00000000}},  //   _anse, ljel, dtav,
  { {0xa3e2001c, 0xbddb02d0, 0x47ca0044, 0x00000000}},  //   धात_, tmèt, রামী,
  { {0xba23012b, 0x61e9020c, 0x3eaa01c8, 0x00000000}},  //   адск, njel, žití_,
  { {0x9f5e3d25, 0x753b00e7, 0x248d0087, 0x00000000}},  // [e5c0] citó_, _nyuz, _nvem_,
  { {0x480300ed, 0x61e93d26, 0x69dd2fc4, 0x00000000}},  //   апув, hjel, _ense,
  { {0x7bde001c, 0x645a0207, 0x248d000d, 0x00000000}},  //   _inpu, _riti, _avem_,
  { {0x645a3d27, 0xa2d503d7, 0xc1bd007d, 0x00000000}},  //   _siti, भिन्, ्योग,
  { {0x61e90182, 0x645a0607, 0x78ad00d4, 0x00000000}},  //   djel, _piti, ctav,
  { {0xdb1c25b8, 0x7bce059b, 0xdb1e00d4, 0x00000000}},  //   terè, ndbu, _capç,
  { {0x645a008d, 0x66e3013b, 0x61e90056, 0x00000000}},  //   _viti, _кора, fjel,
  { {0x61e93d28, 0x61fb0058, 0x645a0145, 0x00000000}},  //   gjel, gkul, _witi,
  { {0x91fc001e, 0x673c0065, 0xdb050173, 0x00000000}},  //   _stās, _hyrj, _echè,
  { {0x645a0112, 0x2d920173, 0x628a00ea, 0x00000000}},  //   _uiti, _adye_, psfo,
  { {0x7e6401c5, 0x29091081, 0x00000000, 0x00000000}},  //   _čips, zzaa_,   ,
  { {0xe9df0051, 0x61e9016e, 0x61fb3c61, 0x00000000}},  //   _chúl_, cjel, ckul,
  { {0x6e3d032e, 0xa3e6013d, 0x78ad0ddd, 0x00000000}},  //   rlsb, _बचा_, xtav,
  { {0xdfcf0025, 0x7e630270, 0xac240216, 0x00000000}},  //   _وين_, _funp, афск,
  { {0xdeef03c8, 0x199509b2, 0x9f5e12c5, 0x00000000}},  //   _ты_, лавя, sitó_,
  { {0x78ad021e, 0x63ad037e, 0x0f5700b6, 0x00000000}},  //   ttav, đani, _ביום_,
  { {0xc4c4026c, 0x69cd0b32, 0x57b51f24, 0x00000000}},  // [e5d0] _بے_, rdae, лбат,
  { {0x78ad09fb, 0x673c021a, 0x76490da4, 0x00000000}},  //   rtav, _byrj, _shey,
  { {0xcf93007b, 0xa3d60316, 0xd838007e, 0x00000000}},  //   שטע_, ियन_, тэт_,
  { {0x69dd001f, 0xa3b002d2, 0xceb30097, 0x00000000}},  //   _unse, ट्स_, ייע_,
  { {0x61e93d29, 0xdb1c0a50, 0x58840147, 0x00000000}},  //   vjel, veré, _выса,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb1c0211, 0x61e93d2a, 0xad9b0051, 0x00000000}},  //   teré, tjel, thúl,
  { {0x3a39012d, 0x7ae801a2, 0x47ca0044, 0x00000000}},  //   _jksp_, ädti, রাণী,
  { {0x61e9006c, 0x7e630c51, 0x28c9007d, 0x00000000}},  //   rjel, _sunp, रिटि,
  { {0x61e90d00, 0x24890089, 0xa7fb0553, 0x00000000}},  //   sjel, šams_, _muño,
  { {0x61e90243, 0x61fb01c5, 0x7c350142, 0x00000000}},  //   pjel, pkul, dozr,
  { {0x2005184a, 0x02fa0049, 0xfbc900b3, 0x00000000}},  //   shli_, _אלעמ, _מת_,
  { {0xed570088, 0xdb0e08c8, 0x3e68009d, 0x00000000}},  //   лою_, lebø, _eût_,
  { {0x40920054, 0x75160049, 0x3e68009d, 0x00000000}},  //   _الور, אַלע_, _fût_,
  { {0xab27005e, 0x7bce068f, 0x9f5e0026, 0x00000000}},  //   гора_, rdbu, pitò_,
  { {0x316d3d2b, 0x00000000, 0x00000000, 0x00000000}},  //   ncez_,   ,   ,
  { {0xa3d6013d, 0x48e3005e, 0x673c00b0, 0x00000000}},  // [e5e0] ियम_, ботв, _syrj,
  { {0x7bde0133, 0x3a390146, 0x00000000, 0x00000000}},  //   _unpu, _eksp_,   ,
  { {0x09b90044, 0x00000000, 0x00000000, 0x00000000}},  //   ঁয়া,   ,   ,
  { {0x94aa00e3, 0xc976035b, 0x09e600a8, 0x00000000}},  //   етка_, _حادث, _сомн,
  { {0x4e370049, 0x00000000, 0x00000000, 0x00000000}},  //   אָגן_,   ,   ,
  { {0xdb053d2c, 0x9f4e000a, 0x7986046a, 0x00000000}},  //   _sché, _fofè_, _hekw,
  { {0xd25a092b, 0x1daa0061, 0x798601a3, 0x00000000}},  //   нци_, _काढत, _kekw,
  { {0xa78500a1, 0x66190036, 0x98a70036, 0x00000000}},  //   _مشہو, ciwk, łną_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x25a60058, 0x5f940143, 0x67db0089, 0x00000000}},  //   lgol_, јинт, _gājē,
  { {0x6d40014a, 0xdb05009d, 0xf837009b, 0x00000000}},  //   üman, _tché, רנית_,
  { {0x25a63d2d, 0xa3b0007d, 0x9f473d2e, 0x00000000}},  //   ngol_, ट्र_, _donà_,
  { {0xbddb00d4, 0x00000000, 0x00000000, 0x00000000}},  //   elèc,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3ffb007b, 0xfc3f10fa, 0x79860116, 0x00000000}},  //   _אפגע, ktív_, _bekw,
  { {0x13cd0044, 0xa7fb004a, 0x7afa00ea, 0x00000000}},  //   লায়, _puño, øtta,
  { {0x2d8b00b9, 0xd7e00067, 0x798601aa, 0x00000000}},  // [e5f0] mace_, नांच, _dekw,
  { {0x2d8b3d2f, 0x64460006, 0x37070478, 0x00000000}},  //   lace_, _ūkin, лчев,
  { {0xf770031d, 0x00000000, 0x00000000, 0x00000000}},  //   سال_,   ,   ,
  { {0x8f3701ce, 0x798600c7, 0x069800a1, 0x00000000}},  //   נטאג_, _gekw, اخلت_,
  { {0x26d80917, 0xa2bd006e, 0x638501ee, 0x00000000}},  //   _erro_, _वैज्, агла,
  { {0x69cf0219, 0xe299007e, 0xe944025a, 0x00000000}},  //   _hace, вак_, _درپی,
  { {0x2d8b0224, 0x38af005d, 0x69cf0471, 0x00000000}},  //   kace_, lür_, _kace,
  { {0x2d8b3d30, 0xa3a90061, 0x016500ed, 0x00000000}},  //   jace_, ग्ज_, шкио,
  { {0x2d8b00b9, 0x38af0279, 0x316d3d31, 0x00000000}},  //   dace_, nür_, rcez_,
  { {0xf07600a1, 0x00000000, 0x00000000, 0x00000000}},  //   جیوں_,   ,   ,
  { {0xa3e20309, 0x3fc700a1, 0xdced0066, 0x00000000}},  //   धार_, ندھی_, _ffaċ,
  { {0x2d8b00b9, 0x69cf008e, 0x38af005d, 0x00000000}},  //   gace_, _nace, kür_,
  { {0x7986002b, 0xef180089, 0x8c4602dc, 0x00000000}},  //   _rekw, daļu_, иеме,
  { {0x38af038c, 0x798603b2, 0xef67005e, 0x00000000}},  //   dür_, _sekw, _съдо,
  { {0x2d8b0107, 0x78bd08ad, 0x25a60016, 0x00000000}},  //   bace_, _apsv, ygol_,
  { {0x38af072f, 0x2d8b11c6, 0x69cf0325, 0x00000000}},  //   für_, cace_, _cace,
  { {0xdb1c076b, 0x38c800a2, 0x1786003b, 0x00000000}},  // [e600] merí, دازی_, игам,
  { {0x60040263, 0xdb1c0211, 0x8b960594, 0x00000000}},  //   _kòma, lerí, _трич,
  { {0x056600d7, 0xa3e902fb, 0x3f873d32, 0x00000000}},  //   авен, यान_, _menu_,
  { {0xdb1c0211, 0x69cf008e, 0xe61a005e, 0x00000000}},  //   nerí, _gace, ъде_,
  { {0xa3e20061, 0x25a600d4, 0x8cd9013d, 0x00000000}},  //   धाल_, rgol_, मियो,
  { {0x2d8b0224, 0x69c4063c, 0x69cf0059, 0x00000000}},  //   zace_, leie, _zace,
  { {0x60cd0142, 0x60042964, 0x3f9805ee, 0x00000000}},  //   _šamp, _nòma, órum_,
  { {0xe5a30b86, 0xdb1c0211, 0x1a9b0049, 0x00000000}},  //   _миси, jerí, דיקע,
  { {0x2d8b00b9, 0xdb1c3d33, 0x78a40026, 0x00000000}},  //   vace_, derí, nuiv,
  { {0xdefa04af, 0x3f873d34, 0x6abe0292, 0x00000000}},  //   вым_, _cenu_, _oppf,
  { {0x2d8b00b9, 0xdb1c00dc, 0x3f870016, 0x00000000}},  //   tace_, ferí, _denu_,
  { {0xdb1c1ad4, 0xfe780006, 0xf1a90014, 0x00000000}},  //   gerí, rpį_, _ماهه_,
  { {0x69cf022d, 0x2d8b0224, 0x61e23d35, 0x00000000}},  //   _race, race_, _inol,
  { {0x69cf0089, 0x2d8b00f4, 0x600401aa, 0x00000000}},  //   _sace, sace_, _fòma,
  { {0x2d8b3d36, 0x69cf0089, 0x6e940025, 0x00000000}},  //   pace_, _pace, _البا,
  { {0x3f87168d, 0xdb1c0211, 0xb5fd2c1b, 0x00000000}},  //   _zenu_, cerí, _kiše,
  { {0xa3d60201, 0x478b0242, 0x3f870d16, 0x00000000}},  // [e610] िया_, всем_, _yenu_,
  { {0x38af0279, 0xf1b9016c, 0xb5fd0733, 0x00000000}},  //   rür_, miše_, _miše,
  { {0x61e2037e, 0xf1b90107, 0xe7190025, 0x00000000}},  //   _onol, liše_, ديات_,
  { {0xd6d831cd, 0xb7c60089, 0x78a40026, 0x00000000}},  //   шту_, _apģē, buiv,
  { {0x81d50055, 0xf1b90107, 0x798d00e0, 0x00000000}},  //   _সকল_, niše_, maaw,
  { {0x61e20085, 0x32060085, 0x00000000, 0x00000000}},  //   _anol, _aloy_,   ,
  { {0x5694007c, 0xdb1c008e, 0xe2a80014, 0x00000000}},  //   _март, yerí, لاين_,
  { {0x1634041f, 0x0085007c, 0x83fc012d, 0x00000000}},  //   _деся, блио, _riđe,
  { {0x03c7007c, 0xfc3f06c2, 0x25ad0009, 0x00000000}},  //   _всем, ntís_, _icel_,
  { {0xa3ae001c, 0x61e200ca, 0x63ad0091, 0x00000000}},  //   _काय_, _enol, đans,
  { {0xdb1c0211, 0x3f8700f4, 0x798d011c, 0x00000000}},  //   terí, _venu_, kaaw,
  { {0x64430039, 0x32550679, 0x3f870020, 0x00000000}},  //   llni, _увер, _wenu_,
  { {0xa3ae02f4, 0x3f8700f4, 0x44273d37, 0x00000000}},  //   _काम_, _tenu_, onn_,
  { {0x2d9e3d38, 0xdb1c3d39, 0x69c401d6, 0x00000000}},  //   şte_, serí, weie,
  { {0x44271573, 0x09e60256, 0xdb1c3d3a, 0x00000000}},  //   inn_, бовн, derã,
  { {0xc33200b6, 0xf1b90521, 0x89663d3b, 0x00000000}},  //   פון_, biše_, скаж,
  { {0xc0440011, 0x69c4010f, 0x7c9604b1, 0x00000000}},  // [e620] _đoạt_, reie, _اشبا,
  { {0x25ad001a, 0x69c414d3, 0x78a40026, 0x00000000}},  //   _acel_, seie, ruiv,
  { {0x3ea53d3c, 0x6abe091a, 0x7afc0065, 0x00000000}},  //   nult_, _uppf, qyrt,
  { {0xad9b002a, 0x64430036, 0x60c90045, 0x00000000}},  //   thúi, elni, kwem,
  { {0x78a41160, 0x044600ed, 0x3ea50210, 0x00000000}},  //   quiv, бедн, hult_,
  { {0x3ea50004, 0xdb1c00c4, 0xb5fd0618, 0x00000000}},  //   kult_, cerã, _riše,
  { {0x7642030a, 0xd2501019, 0x3f8c0089, 0x00000000}},  //   ploy, ونت_, vadu_,
  { {0x4427002a, 0x30a601c0, 0xa0740242, 0x00000000}},  //   ann_, бров, огич,
  { {0x3f8c0032, 0x00000000, 0x00000000, 0x00000000}},  //   tadu_,   ,   ,
  { {0xf1b90119, 0xb5fd0091, 0xdb1c0321, 0x00000000}},  //   više_, _više, ndró,
  { {0x50d601ef, 0x3f8c0466, 0xdb0e010f, 0x00000000}},  //   _گزار, radu_, gebü,
  { {0x660200b0, 0x7c3e0022, 0x443e0082, 0x00000000}},  //   nkok, _akpr, _hkt_,
  { {0x7c3e0283, 0xdddb0d90, 0x3ea53d3d, 0x00000000}},  //   _bkpr, lptū, ault_,
  { {0x443e1799, 0xf1b90ce4, 0x7bd80b33, 0x00000000}},  //   _jkt_, riše_, _óvul,
  { {0xa3e9024c, 0x443e0039, 0x201e016e, 0x00000000}},  //   यात_, _mkt_, miti_,
  { {0x201e0127, 0x26df0091, 0xddc40036, 0x00000000}},  //   liti_, _čuo_, _chiń,
  { {0x44270ca4, 0x442c2580, 0x57f50256, 0x00000000}},  // [e630] ynn_, _ojd_, опат,
  { {0x443e3d3e, 0xb767005e, 0x798d0045, 0x00000000}},  //   _nkt_, стай, saaw,
  { {0xb87b0b32, 0x44270011, 0xd6db0783, 0x00000000}},  //   _oríg, vnn_, ыта_,
  { {0x7afa06d3, 0x443e0c01, 0xa9c70014, 0x00000000}},  //   ätte, _akt_, _ازدو,
  { {0xd49b0aed, 0x201e2379, 0xdb1c07fd, 0x00000000}},  //   уре_, kiti_, merá,
  { {0x201e1adc, 0xc7c7005e, 0x88ba0049, 0x00000000}},  //   jiti_, _усми, _דזשי,
  { {0x201e0213, 0x443e06fe, 0xdb07006c, 0x00000000}},  //   diti_, _dkt_, pejõ,
  { {0x40950088, 0xdb1c1238, 0x1dd90309, 0x00000000}},  //   орот, nerá, _बोलत,
  { {0x201e0020, 0x600902e9, 0x7e6a01a2, 0x00000000}},  //   fiti_, иним_, _aufp,
  { {0x3ea50004, 0x6e2d0020, 0x3a2900e0, 0x00000000}},  //   tult_, _ajab, hnap_,
  { {0xa3d6013d, 0xddc6019d, 0x7bc7007f, 0x00000000}},  //   ियर_, обни, deju,
  { {0xed5a0517, 0x3ea51bd5, 0xdb1c01a2, 0x00000000}},  //   ион_, rult_, rdrü,
  { {0x6609037a, 0x3ea500ab, 0x3a293d3f, 0x00000000}},  //   _mlek, sult_, dnap_,
  { {0x3ea50209, 0x201e0091, 0x3ad801aa, 0x00000000}},  //   pult_, citi_, _pčp_,
  { {0xdd92026c, 0x66090004, 0x8c4300ed, 0x00000000}},  //   _ہوں_, _olek, фере,
  { {0xf2d201f8, 0xceb200a0, 0x3a290010, 0x00000000}},  //   ועל_, _חיה_, gnap_,
  { {0x2bb2013d, 0xa7fb004a, 0x00000000, 0x00000000}},  // [e640] _जापा, _zuñi,   ,
  { {0x6609037e, 0x7f8c0049, 0x39420006, 0x00000000}},  //   _alek, ָנאַ, _vyks_,
  { {0x06ca2546, 0x66090039, 0xdb1c3d40, 0x00000000}},  //   ргей_, _blek, berá,
  { {0x201e0213, 0xd0120044, 0xdb1c3d41, 0x00000000}},  //   ziti_, িচয়_, cerá,
  { {0x201e3d42, 0xb1240055, 0x443e0036, 0x00000000}},  //   yiti_, _পর্ব_, _pkt_,
  { {0x660200b0, 0x00000000, 0x00000000, 0x00000000}},  //   skok,   ,   ,
  { {0x201e3d43, 0x6609068f, 0x38b40a5d, 0x00000000}},  //   viti_, _flek, lär_,
  { {0x7c3c002d, 0x443e0022, 0x69d63d44, 0x00000000}},  //   horr, _wkt_, ndye,
  { {0x201e0119, 0x7c3c168e, 0x27f80190, 0x00000000}},  //   titi_, korr, _korn_,
  { {0xdb1c06b8, 0x6e2d01bb, 0x27f80bbc, 0x00000000}},  //   zerá, _sjab, _jorn_,
  { {0x201e0209, 0x443c0cce, 0x7c3c0129, 0x00000000}},  //   riti_, mov_, dorr,
  { {0x443c0027, 0x201e0091, 0x69da001c, 0x00000000}},  //   lov_, siti_, _पोली,
  { {0x201e0209, 0x7c3c06a5, 0x7bc7010e, 0x00000000}},  //   piti_, forr, teju,
  { {0x443c0c30, 0x7c3c022b, 0x60c2000a, 0x00000000}},  //   nov_, gorr, _ipom,
  { {0xdb1c0161, 0x6ab50146, 0x298b003b, 0x00000000}},  //   terá, utzf, исао_,
  { {0x38b40039, 0x68ed05b3, 0xee770025, 0x00000000}},  //   fär_, txad, _بصوت_,
  { {0x443c0cce, 0x7c3c02f5, 0xb5fd0107, 0x00000000}},  // [e650] kov_, borr, _niša,
  { {0xd6db0113, 0x661b3d45, 0x443c0027, 0x00000000}},  //   ите_, _smuk, jov_,
  { {0xa3e90201, 0x443c0cce, 0x66090168, 0x00000000}},  //   यास_, dov_, _plek,
  { {0xd2460151, 0x60c200ee, 0x38b40039, 0x00000000}},  //   _سن_, _opom, bär_,
  { {0xd1260054, 0x27f83d46, 0x600d008e, 0x00000000}},  //   _أم_, _forn_, _húme,
  { {0x443c0235, 0xb5fd11a5, 0x27f80544, 0x00000000}},  //   gov_, _diša, _gorn_,
  { {0x66b4013b, 0x60c200e5, 0x00000000, 0x00000000}},  //   _обру, _apom,   ,
  { {0x661b0061, 0x7c3c3d47, 0xddc4001a, 0x00000000}},  //   _umuk, zorr, _munţ,
  { {0x7e6400b0, 0x92ab0044, 0x443c1caa, 0x00000000}},  //   _riip, গবে_, bov_,
  { {0x443c0027, 0x60090175, 0x320d0058, 0x00000000}},  //   cov_, сном_, shey_,
  { {0x600d0c2e, 0xee3a178d, 0x26150027, 0x00000000}},  //   _núme, йно_, sťou_,
  { {0xbddb028c, 0xb2ba009b, 0xf1b911e4, 0x00000000}},  //   blèm, _למער, biša_,
  { {0x7c3c022b, 0x7e640103, 0x64410066, 0x00000000}},  //   torr, _viip, _kkli,
  { {0xdb050062, 0x61f90133, 0xda660025, 0x00000000}},  //   _schá, _howl, كاري,
  { {0x63bc011f, 0x09e601fb, 0xdb1c0180, 0x00000000}},  //   _örne, повн, _üzün,
  { {0x443c0027, 0x78b6021e, 0xfc3f02a0, 0x00000000}},  //   zov_, ttyv, quín_,
  { {0x27f80365, 0x7c3c0207, 0x443c3d48, 0x00000000}},  // [e660] _porn_, porr, yov_,
  { {0x61f9020f, 0x2005014a, 0x9d1b01ce, 0x00000000}},  //   _lowl, nkli_, _לופט,
  { {0xe9df001d, 0x443c0465, 0x78b600b0, 0x00000000}},  //   _phút_, vov_, styv,
  { {0x3ce00213, 0x61f900d9, 0x27f80133, 0x00000000}},  //   _kriv_, _nowl, _worn_,
  { {0x443c0cce, 0x79840020, 0xd4e3007c, 0x00000000}},  //   tov_, mbiw, еющи,
  { {0xf1b90e00, 0xb5fd0ecc, 0xa7fb04f3, 0x00000000}},  //   viša_, _viša, _buñu,
  { {0x443c0c30, 0x6458016e, 0x78a401c3, 0x00000000}},  //   rov_, rmvi, lriv,
  { {0x443c0cce, 0x30a6004c, 0xc181026c, 0x00000000}},  //   sov_, пров, پیوٹ,
  { {0x443c0465, 0x78a401d6, 0x61f90082, 0x00000000}},  //   pov_, nriv, _dowl,
  { {0x6e98003b, 0xdb1e0211, 0xf1b9016c, 0x00000000}},  //   овор_, _japó, riša_,
  { {0xa3e902d2, 0x6f01018e, 0xdcf6005f, 0x00000000}},  //   यार_, gylc, _peyğ,
  { {0x78a41dea, 0x61f901d5, 0x600401aa, 0x00000000}},  //   kriv, _gowl, _kòmk,
  { {0xc05a007e, 0x6e3d0010, 0x60c200b4, 0x00000000}},  //   _лік_, rosb, _upom,
  { {0x78a405ad, 0x2bb2001c, 0x2005014a, 0x00000000}},  //   driv, _जाणा, ckli_,
  { {0x81cf0044, 0x78a4006c, 0x76590016, 0x00000000}},  //   শার_, eriv, ymwy,
  { {0x7afa0039, 0xad9b000c, 0x78a40026, 0x00000000}},  //   ätta, rhús, friv,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [e670]   ,   ,   ,
  { {0xf7700076, 0x39470089, 0xb87b0027, 0x00000000}},  //   هام_, āns_, _príb,
  { {0x2bb2001c, 0x6d4101f6, 0xdb1c010f, 0x00000000}},  //   _जाता, şlad, gerä,
  { {0x78a43d49, 0xb87b0051, 0x60db0006, 0x00000000}},  //   briv, _críc, yvum,
  { {0x78a40207, 0x99f600b6, 0x61f93d4a, 0x00000000}},  //   criv, _חזרה_, _rowl,
  { {0xb4ad0201, 0xe9df0051, 0xdb1c00f8, 0x00000000}},  //   _कमी_, _thús_, berä,
  { {0xa3ae02d2, 0x62630047, 0xe5f300e5, 0x00000000}},  //   _कार_, _főol, _căţă,
  { {0xdb1c00c4, 0x60db006c, 0x9f5e0048, 0x00000000}},  //   serç, tvum, bhtú_,
  { {0x9f5e002a, 0x81cf0044, 0xdb1c3d4b, 0x00000000}},  //   chtú_, শাল_, perç,
  { {0x9f4e0285, 0x6441013e, 0xb5fd0091, 0x00000000}},  //   _sofá_, _ukli, _kišo,
  { {0x6da60081, 0x60c4001e, 0xada600ec, 0x00000000}},  //   мина, _ģime, манл,
  { {0x3ce0211e, 0x28e00061, 0x38720023, 0x00000000}},  //   _priv_, निमि, yqyr_,
  { {0x6ff50025, 0x7bd7002d, 0xdea1025a, 0x00000000}},  //   _يستط, _baxu, ریکی,
  { {0x3f8e0026, 0x00000000, 0x00000000, 0x00000000}},  //   _gefu_,   ,   ,
  { {0x81b40055, 0x3f850035, 0xcb673d4c, 0x00000000}},  //   _ছোট_, mblu_, даре_,
  { {0x78a4000d, 0xa3e903d7, 0xc332019b, 0x00000000}},  //   triv, याँ_, דול_,
  { {0xa3ae0164, 0x6b990048, 0x7bd700e5, 0x00000000}},  // [e680] _काल_, éagó, _faxu,
  { {0x60040009, 0x07a3007c, 0xdb1c0052, 0x00000000}},  //   _còmh, каун, terä,
  { {0xa96a00e3, 0x78a400ea, 0xb5fd0091, 0x00000000}},  //   _мина_, sriv, _višn,
  { {0x78a40091, 0xeef60049, 0x68e9013e, 0x00000000}},  //   priv, ומער_, _šede,
  { {0xa3e903d7, 0x7bd7006b, 0xdb1e004a, 0x00000000}},  //   यां_, _yaxu, _tapó,
  { {0xdb1c021e, 0xa3ae0061, 0x7c2e3086, 0x00000000}},  //   perä, _काळ_, nnbr,
  { {0x07a302a8, 0xb87b3d4d, 0x7c2e01a2, 0x00000000}},  //   _јасн, _tríc, inbr,
  { {0x3f8e1140, 0xfc3f004a, 0x00000000, 0x00000000}},  //   _sefu_, iría_,   ,
  { {0xb5fd0ce4, 0xfa1c0082, 0x00000000, 0x00000000}},  //   _mišl, _đất_,   ,
  { {0xf957009b, 0x6004000a, 0x33f6007e, 0x00000000}},  //   וספת_, _kòmi, _ўчас,
  { {0x63061289, 0x00000000, 0x00000000, 0x00000000}},  //   _توال,   ,   ,
  { {0xfc3f0211, 0xceb80fed, 0x7c2e01c3, 0x00000000}},  //   dría_, rtę_, enbr,
  { {0x7afa0073, 0x11690123, 0xdfd20025, 0x00000000}},  //   ättn, _علوی_, _ليش_,
  { {0xdb1e01aa, 0xfc3f008e, 0xce94005e, 0x00000000}},  //   _rapò, fría_, _закъ,
  { {0x27ed001d, 0x20193175, 0xfc3f0211, 0x00000000}},  //   _đen_, ësie_, gría_,
  { {0x7c2e037f, 0x629801a2, 0xdb1e0173, 0x00000000}},  //   anbr, isvo, _papò,
  { {0xa3ae0316, 0xdb050788, 0xfc3f008e, 0x00000000}},  // [e690] कला_, _schä, aría_,
  { {0xfc3f0211, 0xb87b004a, 0x88580c96, 0x00000000}},  //   bría_, _cría, диус_,
  { {0xdb1c0193, 0x629e1748, 0x1995007e, 0x00000000}},  //   terå, ápol, _паня,
  { {0x62980c46, 0x600400f6, 0x78a20161, 0x00000000}},  //   dsvo, _dòmi, šova,
  { {0xe00e001c, 0x629a3d4e, 0xa8790049, 0x00000000}},  //   िसाद_, _avto, _מאָר,
  { {0x600401aa, 0x62983d4f, 0xdb1c00f8, 0x00000000}},  //   _fòmi, fsvo, rdrö,
  { {0x44290091, 0x78ad00b0, 0x09040044, 0x00000000}},  //   đa_, luav, _রেপু_,
  { {0x644a1a4a, 0x69cd010e, 0x00000000, 0x00000000}},  //   alfi, neae,   ,
  { {0x9f470051, 0x78ad16a3, 0x84350088, 0x00000000}},  //   _inné_, nuav, _знає,
  { {0xb5fd0087, 0x764b005b, 0x00000000, 0x00000000}},  //   _mišm, llgy,   ,
  { {0x47ca0044, 0xf99f0173, 0x00000000, 0x00000000}},  //   রাচী, _odè_,   ,
  { {0x200e0197, 0x6619014a, 0xa3b50061, 0x00000000}},  //   _elfi_, _çakı, _झाड_,
  { {0x8fa501e1, 0x78ad07a4, 0x00000000, 0x00000000}},  //   _зале, juav,   ,
  { {0x09a80061, 0xfc3f008e, 0x6b950010, 0x00000000}},  //   गल्य, tría_, gazg,
  { {0x7c2e06d3, 0xca56003b, 0x48bf0044, 0x00000000}},  //   rnbr, етањ, উটোর,
  { {0xfc3f008e, 0xdb1c009d, 0x00000000, 0x00000000}},  //   rría_, nfré,   ,
  { {0x98a308d6, 0x3f81010e, 0x78ad00f6, 0x00000000}},  // [e6a0] лите, _õhus_, guav,
  { {0x7d06021e, 0x6e260b5a, 0xf99f000a, 0x00000000}},  //   myks, likb, _edè_,
  { {0x39ea0200, 0x61eb00f4, 0x7bdc0190, 0x00000000}},  //   _едно_, _ongl, mdru,
  { {0x186a004c, 0x7bdc000c, 0x7bce0095, 0x00000000}},  //   _нами_, ldru, lebu,
  { {0x2d92042a, 0xb87b00d6, 0xa50702dc, 0x00000000}},  //   _meye_, _tría, неца_,
  { {0x7bdc0006, 0x6e2602ae, 0x229a0089, 0x00000000}},  //   ndru, hikb, tīk_,
  { {0x5334007c, 0xe8050061, 0x7869007f, 0x00000000}},  //   ъект, _शकता_, _užva,
  { {0x20bd0754, 0xd25700a5, 0xb6bb0104, 0x00000000}},  //   ्बंध, нцы_, _מצלי,
  { {0xe3b202fd, 0x63b70065, 0x629804f2, 0x00000000}},  //   _مرا_, çanë, ssvo,
  { {0x629a00d9, 0x00000000, 0x00000000, 0x00000000}},  //   _tvto,   ,   ,
  { {0xd36f006d, 0x2f1901f3, 0x6e260203, 0x00000000}},  //   _اهم_, _nżgħ_, fikb,
  { {0x7bdc189b, 0x3eac0190, 0xd6e20044, 0x00000000}},  //   edru, rudt_, _যথায,
  { {0x2d923d50, 0x7bdc0270, 0xb87b00d4, 0x00000000}},  //   _deye_, fdru, _arín,
  { {0x7bce010f, 0xb87b00f6, 0x7bdc00bb, 0x00000000}},  //   gebu, _brín, gdru,
  { {0x8ff704e8, 0x61eb3d51, 0xc987003b, 0x00000000}},  //   _سرور_, _yngl, еузи,
  { {0x78ad00d4, 0x799600e0, 0x00000000, 0x00000000}},  //   tuav, gayw,   ,
  { {0x9c390b49, 0x97a70088, 0x7bce3d52, 0x00000000}},  // [e6b0] _опит_, ерел, bebu,
  { {0xc02e0011, 0x7bce0be9, 0x00000000, 0x00000000}},  //   _điệu_, cebu,   ,
  { {0x8c1c0452, 0x2d92000b, 0x69cd001c, 0x00000000}},  //   _מוזי, _yeye_, peae,
  { {0xa64700a2, 0x78ad2f47, 0xb5fd016c, 0x00000000}},  //   رخان, puav, _tišm,
  { {0x78ad0197, 0xb5fd00ca, 0x00000000, 0x00000000}},  //   quav, _hišk,   ,
  { {0x22460145, 0x61eb01f3, 0x00000000, 0x00000000}},  //   _akok_, _sngl,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb5fd0006, 0xf99f0263, 0x7bce0036, 0x00000000}},  //   _mišk, _elèv_, zebu,
  { {0x2d920173, 0x27210316, 0x7bdc0022, 0x00000000}},  //   _reye_, _मधुर_, ydru,
  { {0xa2a903d7, 0x2d9218ae, 0x7d061b1b, 0x00000000}},  //   _टिप्, _seye_, vyks,
  { {0x4427048a, 0x2d920263, 0xf7720097, 0x00000000}},  //   min_, _peye_, יקי_,
  { {0x64430209, 0x61eb00db, 0x7d06021e, 0x00000000}},  //   loni, _ungl, tyks,
  { {0x64430004, 0xed570088, 0x7bdc0506, 0x00000000}},  //   ooni, кою_, tdru,
  { {0x4427038c, 0xb5fd2649, 0x6e260190, 0x00000000}},  //   nin_, _bišk, sikb,
  { {0x7bdc037f, 0x7bce033b, 0xae1f006e, 0x00000000}},  //   rdru, rebu, मोहन_,
  { {0x44270811, 0xb87b002a, 0x7bce04cb, 0x00000000}},  //   hin_, _crío, sebu,
  { {0x44273d53, 0x6e240061, 0x6abc0016, 0x00000000}},  // [e6c0] kin_, _imib, strf,
  { {0x64430f68, 0x44273be4, 0xb87b0051, 0x00000000}},  //   joni, jin_, _trín,
  { {0x6443008d, 0xb87b0b51, 0x09b90044, 0x00000000}},  //   doni, _frío, ুয়া,
  { {0xf743004d, 0x44270051, 0x80b70044, 0x00000000}},  //   шехо, ein_, _অনন্,
  { {0x442703a4, 0x224d002b, 0xcd770049, 0x00000000}},  //   fin_, dlek_, דענק_,
  { {0xe1f90006, 0x9d1b00b3, 0x224d0066, 0x00000000}},  //   ejų_, וונט, elek_,
  { {0xd25a2476, 0x92b30025, 0xdb1c06ec, 0x00000000}},  //   мци_, لحيا, gerø,
  { {0x4427002a, 0x26d80022, 0x224d0032, 0x00000000}},  //   ain_, _isro_, glek_,
  { {0xdfd00054, 0x64430016, 0xe3ba007c, 0x00000000}},  //   مية_, boni, _оба_,
  { {0x4427012b, 0x64430035, 0x212b1690, 0x00000000}},  //   cin_, coni, úcha_,
  { {0xdef7008b, 0x645a011f, 0x20190065, 0x00000000}},  //   выя_, _ihti, ësia_,
  { {0xd3780521, 0x9f5c00d4, 0x600400d4, 0x00000000}},  //   _daće_, _jové_, _ròmu,
  { {0xf1b300b6, 0x66000091, 0x24860022, 0x00000000}},  //   _כסף_, _momk, npom_,
  { {0xb5fd0059, 0xd01001fa, 0x600400f6, 0x00000000}},  //   _pišk, _دلت_, _pòmu,
  { {0xb87b002a, 0xdb23011f, 0xbddb009d, 0x00000000}},  //   _prío, _ürün, flèt,
  { {0x442701f6, 0x5a341447, 0xb5fd037e, 0x00000000}},  //   zin_, анст, _višk,
  { {0x44270890, 0x99551efa, 0x2d99006c, 0x00000000}},  // [e6d0] yin_, укац, mase_,
  { {0x44270129, 0x2d99006c, 0xf99f0173, 0x00000000}},  //   xin_, lase_, _alèt_,
  { {0x44273d54, 0x2d99001a, 0x6443016e, 0x00000000}},  //   vin_, oase_, voni,
  { {0x44270b9a, 0x645a0850, 0xe3b8005a, 0x00000000}},  //   win_, _ahti, _acı_,
  { {0x4427150f, 0x2bc002f4, 0x224d01d6, 0x00000000}},  //   tin_, श्वा, vlek_,
  { {0x69dd002d, 0x2d9900ab, 0xb5fd016e, 0x00000000}},  //   _hase, hase_, _miši,
  { {0xb5fd013e, 0x2d9915d6, 0x00000000, 0x00000000}},  //   _liši, kase_,   ,
  { {0x69dd037e, 0x645a3d55, 0x44270e2d, 0x00000000}},  //   _jase, _ehti, sin_,
  { {0x44270a1f, 0x64432f69, 0x224d3d56, 0x00000000}},  //   pin_, poni, rlek_,
  { {0x442724e5, 0xf07600a1, 0x224d014a, 0x00000000}},  //   qin_, دیوں_, slek_,
  { {0x765b001d, 0xa347008b, 0x224d0168, 0x00000000}},  //   _khuy, _рэал, plek_,
  { {0x69dd016c, 0x7c253d57, 0x6d41047f, 0x00000000}},  //   _nase, _amhr, ğlan,
  { {0x6d4101f6, 0x10a50751, 0x44250089, 0x00000000}},  //   şlan, _силн, _kml_,
  { {0x44250093, 0xb87b008e, 0xb5fd00ee, 0x00000000}},  //   _jml_, _crím, _diši,
  { {0x2d9924e3, 0x2fc700e0, 0x61fb00e7, 0x00000000}},  //   base_, _ibng_, ojul,
  { {0xceb200b6, 0x61fb000c, 0x7e6d0207, 0x00000000}},  //   _היה_, njul, _giap,
  { {0x69dd0de1, 0x660023b1, 0x6a8901aa, 0x00000000}},  // [e6e0] _dase, _romk, _pèfò,
  { {0x764901aa, 0xb87b000c, 0x61fb3d58, 0x00000000}},  //   _akey, _grím, hjul,
  { {0x2c6f01d5, 0x69dd1d47, 0x55e60794, 0x00000000}},  //   _iżda_, _fase, ложб,
  { {0x765b00ad, 0x69dd001a, 0x7bde008d, 0x00000000}},  //   _chuy, _gase, _hapu,
  { {0x69c400bb, 0x44250009, 0x61fb016c, 0x00000000}},  //   mfie, _bml_, djul,
  { {0x69dd01d9, 0x69c401d6, 0x44250145, 0x00000000}},  //   _zase, lfie, _cml_,
  { {0x7bde036b, 0x68e40181, 0x0cb1007d, 0x00000000}},  //   _mapu, lvid, _जम्म,
  { {0x2d99049a, 0x69c4038e, 0x7bde002d, 0x00000000}},  //   xase_, nfie, _lapu,
  { {0x7e6d0ec0, 0x13b60431, 0x2d992c9b, 0x00000000}},  //   _riap, _مصاح, vase_,
  { {0x7bde3d59, 0x7e6d0149, 0x3ebe0058, 0x00000000}},  //   _napu, _siap, tttt_,
  { {0x63060447, 0x69c400bb, 0x320d0009, 0x00000000}},  //   _حوال, kfie, bkey_,
  { {0x68e40142, 0x90e601fa, 0xb5fd0059, 0x00000000}},  //   kvid, _مستن, _piši,
  { {0x2d99027b, 0xa3e9001c, 0x69dd0cfd, 0x00000000}},  //   rase_, याच_, _rase,
  { {0x442504d2, 0x68e40059, 0x7bde001a, 0x00000000}},  //   _xml_, dvid, _capu,
  { {0x69c400c7, 0x2d9915d8, 0x3a290149, 0x00000000}},  //   ffie, pase_, tiap_,
  { {0xb5fd0295, 0x8e830025, 0x69c400d9, 0x00000000}},  //   _tiši, _اليه, gfie,
  { {0x69dd00b0, 0x37ab026b, 0x290f0010, 0x00000000}},  // [e6f0] _vase, етен_, ága_,
  { {0xf1b9016e, 0x69dd0020, 0x7bde0093, 0x00000000}},  //   riši_, _wase, _gapu,
  { {0x69dd006c, 0x76b900e2, 0x44250022, 0x00000000}},  //   _tase, тлер_, _rml_,
  { {0x7bde00ee, 0x3ce924fd, 0xc64b0025, 0x00000000}},  //   _zapu, _krav_, رجال_,
  { {0x798d0fe7, 0x68e406ed, 0x442500fa, 0x00000000}},  //   mbaw, cvid, _pml_,
  { {0x3ce9057c, 0x23290088, 0x78ad1f7c, 0x00000000}},  //   _mrav_, коли_, mrav,
  { {0x765b001d, 0x320d0082, 0x44250009, 0x00000000}},  //   _thuy, tkey_, _vml_,
  { {0x44250066, 0x212b0181, 0x78ad08a6, 0x00000000}},  //   _wml_, úcho_, orav,
  { {0x44250089, 0x944200a1, 0x320d26d6, 0x00000000}},  //   _tml_, _ڈھون, rkey_,
  { {0x60090175, 0xb87b0027, 0x6b9701f3, 0x00000000}},  //   тном_, _príj, _nexg,
  { {0x99890bf8, 0x69c40de7, 0x68e400ca, 0x00000000}},  //   znaš_, yfie, zvid,
  { {0x68e40009, 0x78ad0056, 0x7bde1922, 0x00000000}},  //   yvid, krav, _sapu,
  { {0x68e400f4, 0x3eac00bb, 0xee372063, 0x00000000}},  //   xvid, ardt_, рня_,
  { {0x92d70055, 0xa1360049, 0x78ad016e, 0x00000000}},  //   ামী_, _דאנק_, drav,
  { {0xeb970216, 0x7bde002b, 0x19960098, 0x00000000}},  //   рис_, _vapu, ијар,
  { {0x78ad027b, 0x68e400ea, 0x7bde00e7, 0x00000000}},  //   frav, tvid, _wapu,
  { {0x69c4002b, 0x3ce93d5a, 0x7bde011c, 0x00000000}},  // [e700] rfie, _grav_, _tapu,
  { {0x68e43d5b, 0x07a601e0, 0xa3e5007d, 0x00000000}},  //   rvid, ражн, _बोल_,
  { {0x6b9c29d0, 0x78ad0197, 0x69c401a2, 0x00000000}},  //   marg, arav, pfie,
  { {0x78ad0626, 0x1a9b0049, 0x38710b18, 0x00000000}},  //   brav, _ביטע, _žorž_,
  { {0xf1b90107, 0x78ad0181, 0x5d7b0049, 0x00000000}},  //   nišu_, crav, דאנק,
  { {0x66e60265, 0xdb1c0047, 0x6b9c3d5c, 0x00000000}},  //   _кога, kerü, narg,
  { {0xc7a3025f, 0xe7c60061, 0xdb1500fa, 0x00000000}},  //   _фиск, र्णप, bezõ,
  { {0x6b9c0169, 0xc48600e3, 0xdb1c3d5d, 0x00000000}},  //   harg, _влак, derü,
  { {0x6b9c002d, 0x00000000, 0x00000000, 0x00000000}},  //   karg,   ,   ,
  { {0x6016001a, 0x2bb20061, 0x238900b9, 0x00000000}},  //   _sâmb, _जागा, čují_,
  { {0x085700b6, 0x6d41005d, 0xb33c01d5, 0x00000000}},  //   שבים_, ğlam, _idħo,
  { {0x3ce901d9, 0x6d41005d, 0x628a0b4a, 0x00000000}},  //   _prav_, şlam, mpfo,
  { {0x6b9c00ea, 0xc5f300a0, 0x628a00bb, 0x00000000}},  //   farg, קדש_, lpfo,
  { {0x7f840025, 0x09af0061, 0x26c10016, 0x00000000}},  //   _الغن, टल्य, ytho_,
  { {0xda780265, 0xbebc001e, 0xb5fd11e2, 0x00000000}},  //   ият_, dzīg, _kišt,
  { {0x78ad05d2, 0x3ce900f8, 0x9dab005e, 0x00000000}},  //   trav, _trav_, _ръка_,
  { {0x6b9c0211, 0x32d80082, 0x9f47000c, 0x00000000}},  // [e710] barg, _lũy_, _inná_,
  { {0x6b9c0211, 0x78ad0065, 0xdd910014, 0x00000000}},  //   carg, rrav, _بوک_,
  { {0x8ae401fb, 0xdc3c009b, 0x78ad006c, 0x00000000}},  //   _діял, _בעזר, srav,
  { {0xb5fd0119, 0x26c13d5e, 0x3ce63d5f, 0x00000000}},  //   _ništ, rtho_, _šovi_,
  { {0xbb48025a, 0xfc3f0d62, 0xd378016c, 0x00000000}},  //   _ملین_, quís_, _saća_,
  { {0x7bd50211, 0x87e701ab, 0x00000000, 0x00000000}},  //   nezu, _тюме,   ,
  { {0x9f5c00f6, 0xd298007e, 0x20190023, 0x00000000}},  //   _boví_, атыі_, ësim_,
  { {0xcb38009b, 0x6b9c0288, 0x7bd50efd, 0x00000000}},  //   ינוק_, zarg, hezu,
  { {0x7a33002b, 0x7bd5002d, 0x317f016c, 0x00000000}},  //   għti, kezu, rcuz_,
  { {0xaffe0011, 0x04590025, 0xf1b93d60, 0x00000000}},  //   _phướ, _صلاة_, višu_,
  { {0x6b9c0a0e, 0x2eb6006e, 0x5f450025, 0x00000000}},  //   varg, _अमृत, إنجل,
  { {0x78a218a2, 0x6b9c10ed, 0xe9df0011, 0x00000000}},  //   šovi, warg, _thúy_,
  { {0x30850054, 0x6b9c0036, 0xafe5041f, 0x00000000}},  //   _التف, targ, _голл,
  { {0xf1b90107, 0xaffe0011, 0x1c39007c, 0x00000000}},  //   rišu_, _thướ, аясь_,
  { {0x6b9c006b, 0xe4560049, 0xead60044, 0x00000000}},  //   rarg, מישט_, হম্ম,
  { {0x6b9c0d90, 0x00000000, 0x00000000, 0x00000000}},  //   sarg,   ,   ,
  { {0xfc3f027b, 0x1b200044, 0xdb1c1ac3, 0x00000000}},  // [e720] ruír_, _মুখে_, teró,
  { {0x3cfb00b3, 0x6b9c0009, 0x00000000, 0x00000000}},  //   _עלינ, qarg,   ,
  { {0x20560049, 0x00000000, 0x00000000, 0x00000000}},  //   ציעל_,   ,   ,
  { {0x7c2e0219, 0xe5a30081, 0xceb2007b, 0x00000000}},  //   libr, зици, ליב_,
  { {0x69d6014a, 0xdb05009d, 0x6aa101e5, 0x00000000}},  //   meye, _adhè, álfv,
  { {0x69d6011f, 0x0443007e, 0x9f5c00f6, 0x00000000}},  //   leye, печн, _soví_,
  { {0x81e10044, 0x00000000, 0x00000000, 0x00000000}},  //   দান_,   ,   ,
  { {0x69d6014a, 0x00000000, 0x00000000, 0x00000000}},  //   neye,   ,   ,
  { {0xdb05001f, 0xb5fd0006, 0x99800006, 0x00000000}},  //   _schü, _višt, lnių_,
  { {0xa208005d, 0x3f9809ed, 0x9980007f, 0x00000000}},  //   ılış_, úru_, onių_,
  { {0x601602d5, 0xb5fd0b46, 0xdb1c000c, 0x00000000}},  //   _câma, _tišt, lfræ,
  { {0x442e038c, 0x644a3ae0, 0x62883d61, 0x00000000}},  //   lif_, lofi, _itdo,
  { {0x7bd50035, 0x00000000, 0x00000000, 0x00000000}},  //   tezu,   ,   ,
  { {0xdb05008d, 0x4e93007a, 0x9f5e0065, 0x00000000}},  //   _udhë, _کشور, njtë_,
  { {0x3f9e1c0b, 0x61e21844, 0xdb0700ea, 0x00000000}},  //   matu_, _kaol, ngjø,
  { {0x3f9e022b, 0x644a0020, 0x600d000c, 0x00000000}},  //   latu_, hofi, _rúmi,
  { {0x61e20051, 0x779900e2, 0x00000000, 0x00000000}},  // [e730] _maol, икар_,   ,
  { {0x3f9e002d, 0x61e22a87, 0xf77305f3, 0x00000000}},  //   natu_, _laol, ساط_,
  { {0x442e002b, 0x2d9b0065, 0x69d60173, 0x00000000}},  //   dif_, _keqe_, beye,
  { {0x6aa1009f, 0xdebb00a3, 0x3f9e118e, 0x00000000}},  //   álfu, רמאל, hatu_,
  { {0x3f9e022b, 0xcc34026c, 0x789300a2, 0x00000000}},  //   katu_, _ذریع, _ریاض,
  { {0xd7fb01f9, 0xdb0500f4, 0x1b0c0044, 0x00000000}},  //   _сум_, _adhé, _হইতে_,
  { {0xdc38007b, 0x3f9e022b, 0x6265005e, 0x00000000}},  //   זאגט_, datu_, овка,
  { {0x20c2009f, 0x80a93d62, 0x61e20048, 0x00000000}},  //   fði_, авив_, _caol,
  { {0x20c2009f, 0x3494005e, 0x644a058b, 0x00000000}},  //   gði_, _натр, bofi,
  { {0xbebc001e, 0x3f9e002d, 0x644a1b3e, 0x00000000}},  //   dzīb, gatu_, cofi,
  { {0xee3a013b, 0x02d906c6, 0xc7b2009b, 0x00000000}},  //   ино_, _خواب_, ובי_,
  { {0x61e20051, 0x92b4035b, 0x6e2f00d2, 0x00000000}},  //   _gaol, _رحما, gicb,
  { {0x8fa50b7a, 0x3f9e002d, 0x69d6004a, 0x00000000}},  //   _дале, batu_, veye,
  { {0xdb1c009f, 0x3f9e00c4, 0x3f690c96, 0x00000000}},  //   ferð, catu_, _кило_,
  { {0xcb6a00c0, 0xdb1c009f, 0x69d6014a, 0x00000000}},  //   раве_, gerð, teye,
  { {0x2007022b, 0xe9da00ec, 0x442e003b, 0x00000000}},  //   _honi_, јка_, zif_,
  { {0x69d601aa, 0xd9100167, 0x644a00e7, 0x00000000}},  // [e740] reye, ریس_, yofi,
  { {0x69d60173, 0x3b83041f, 0xe7320d3a, 0x00000000}},  //   seye, _ольг, وصا_,
  { {0xe57a2239, 0x69d601aa, 0x200700b0, 0x00000000}},  //   азе_, peye, _moni_,
  { {0x3f9e2eee, 0x200700b9, 0xdce60180, 0x00000000}},  //   zatu_, _loni_, lakı,
  { {0x92e60044, 0x99800006, 0x64a3007e, 0x00000000}},  //   _পথে_, snių_, дача,
  { {0xdb1c000c, 0x628816b1, 0x2007016e, 0x00000000}},  //   rfræ, _ptdo, _noni_,
  { {0x442e24a5, 0x644a0129, 0x61e20207, 0x00000000}},  //   rif_, rofi, _paol,
  { {0x30a608d6, 0x9f5c0428, 0x27e3012d, 0x00000000}},  //   оров, _nová_, _zajn_,
  { {0x3f9e09c5, 0x78a400ab, 0x200700ca, 0x00000000}},  //   tatu_, nsiv, _boni_,
  { {0x20c2009f, 0x2018000c, 0x93cb00a1, 0x00000000}},  //   rði_, óri_, _نامہ_,
  { {0x3f9e022b, 0x20070065, 0x61e2006c, 0x00000000}},  //   ratu_, _doni_, _taol,
  { {0x3f9e022b, 0xdb1c000c, 0x78a4044e, 0x00000000}},  //   satu_, verð, ksiv,
  { {0x3f9e3d63, 0x442c0190, 0x913600a1, 0x00000000}},  //   patu_, _kmd_, _براؤ,
  { {0xdfcf0025, 0x68fb0129, 0x6e2f0253, 0x00000000}},  //   _ليه_, _àudi, sicb,
  { {0x5fb700b6, 0x600d10af, 0x764b0f4c, 0x00000000}},  //   _והוא_, _cúmu, yogy,
  { {0x7bda009d, 0x7bc8006c, 0x442c0068, 0x00000000}},  //   ôtur, õdur, _lmd_,
  { {0x7afa0039, 0x20070146, 0x3f9c0521, 0x00000000}},  // [e750] ättr, _yoni_, _kevu_,
  { {0x6aa1009f, 0xc7f80088, 0x7986000a, 0x00000000}},  //   álfs, онує_, _efkw,
  { {0x3a2b0082, 0x81e10044, 0x00000000, 0x00000000}},  //   _tmcp_, দাত_,   ,
  { {0x94793d64, 0x3f9c0d0a, 0x7afa0cb2, 0x00000000}},  //   бску_, _levu_, åtte,
  { {0xb87b1195, 0x442c10c5, 0x25a0000c, 0x00000000}},  //   _crít, _bmd_, ðila_,
  { {0x2eee06b9, 0x442c00ab, 0x764b3d65, 0x00000000}},  //   _orff_, _cmd_, sogy,
  { {0x6595008b, 0x442c04d2, 0x8c1c0097, 0x00000000}},  //   _наву, _dmd_, שווי,
  { {0x442c00d4, 0x20070023, 0xb87b000c, 0x00000000}},  //   _emd_, _soni_, _frít,
  { {0x442c02a9, 0x661b3d66, 0x00000000, 0x00000000}},  //   _fmd_, _iluk,   ,
  { {0x66091f4b, 0x6e2d0211, 0x201e002b, 0x00000000}},  //   _hoek, _amab, ghti_,
  { {0x661b009f, 0x660916db, 0x8e8501e1, 0x00000000}},  //   _kluk, _koek, ягне,
  { {0x8237026c, 0x44dd0173, 0x00000000, 0x00000000}},  //   _برطا, _kň_,   ,
  { {0x20070129, 0x317a00a3, 0xa3df0061, 0x00000000}},  //   _toni_, _האנד, _तसा_,
  { {0x201e0c10, 0x6e2d0600, 0x224d37e7, 0x00000000}},  //   chti_, _emab, loek_,
  { {0x6b630242, 0x661b006c, 0xdce6005d, 0x00000000}},  //   екра, _oluk, rakı,
  { {0x224d3d67, 0x78a40933, 0x321f0082, 0x00000000}},  //   noek_, tsiv, nhuy_,
  { {0x799d010f, 0xfbd10044, 0x6aa1000c, 0x00000000}},  // [e760] _desw, ায়ত, álfr,
  { {0x78a400b0, 0x224d00c7, 0xb8e40309, 0x00000000}},  //   rsiv, hoek_, _एम_,
  { {0x78a40198, 0x66090100, 0x224d3d68, 0x00000000}},  //   ssiv, _boek, koek_,
  { {0x442c0048, 0x44dd01aa, 0x799d0007, 0x00000000}},  //   _smd_, _bň_, _gesw,
  { {0x01c30055, 0x443e0a44, 0x66090116, 0x00000000}},  //   ্যাদ, _pjt_, _doek,
  { {0x3fe60055, 0x661b006c, 0x78a20f6c, 0x00000000}},  //   _পক্ষ, _eluk, šovs,
  { {0x661b00ea, 0xe2970098, 0xf48700a1, 0x00000000}},  //   _fluk, пај_, _ہالی,
  { {0x44dd0173, 0x8cad013d, 0xb87b135c, 0x00000000}},  //   _fň_, _जिलो, _trít,
  { {0xdfd00054, 0x76430047, 0x0ef4007d, 0x00000000}},  //   نية_, énye, इम्स_,
  { {0x66090662, 0xe0cf0076, 0x251b0097, 0x00000000}},  //   _zoek, ازي_, _הומא,
  { {0x224d3d69, 0xa3e501f5, 0x6d440133, 0x00000000}},  //   boek_, _बोट_, _axia,
  { {0xf27b00b6, 0xa3cd02fb, 0x201e0065, 0x00000000}},  //   _הראש, ष्ठ_, shti_,
  { {0xfc3f008e, 0x799d0016, 0x63bc0039, 0x00000000}},  //   esía_, _resw, _örns,
  { {0x7e640058, 0x27f80087, 0x799d0085, 0x00000000}},  //   _ehip, _nnrn_, _sesw,
  { {0xdb1c009d, 0xe4570049, 0x00000000, 0x00000000}},  //   ngrè, פילט_,   ,
  { {0x6e2d011c, 0x7f3b00a3, 0x0f57009b, 0x00000000}},  //   _umab, _לעוו, _מיום_,
  { {0x660901d6, 0x00000000, 0x00000000, 0x00000000}},  // [e770] _roek,   ,   ,
  { {0x66093d6a, 0x224d02ae, 0x661b0030, 0x00000000}},  //   _soek, zoek_, _sluk,
  { {0x2ca90018, 0xb87b13a1, 0x6e3d06d3, 0x00000000}},  //   _hvad_, _prís, onsb,
  { {0x3a201d08, 0x6e3d030e, 0x80d30044, 0x00000000}},  //   chip_, nnsb, তিত্,
  { {0x629a3d6b, 0xdb1c0039, 0xe8eb0025, 0x00000000}},  //   _awto, rfrå, _ارجو_,
  { {0xe3b8006b, 0x69cd0016, 0x76430010, 0x00000000}},  //   _alıb_, lfae, ényb,
  { {0x68ed00d6, 0x66090100, 0x321f0082, 0x00000000}},  //   lvad, _toek, thuy_,
  { {0x601f00f4, 0xf99f01aa, 0x661b0772, 0x00000000}},  //   _même, _alèz_, _uluk,
  { {0x224d11fe, 0x68200039, 0x68ed3d6c, 0x00000000}},  //   roek_, _född, nvad,
  { {0x443102b9, 0x224d3d6d, 0x248d1f9c, 0x00000000}},  //   _öz_, soek_, _item_,
  { {0x63a3009f, 0xa3cd0316, 0x1f650088, 0x00000000}},  //   mann, ष्ण_, ьком,
  { {0xd12e06c6, 0x1b0c0044, 0xed5a3520, 0x00000000}},  //   امی_, _হইলে_, жом_,
  { {0x61e90056, 0x25ad0022, 0x69cd0544, 0x00000000}},  //   mdel, _mdel_, dfae,
  { {0x61e93d6e, 0x63a33b29, 0xddcd001a, 0x00000000}},  //   ldel, nann, _piaţ,
  { {0x60c90007, 0x69cd133c, 0x63a305cd, 0x00000000}},  //   ltem, ffae, iann,
  { {0xdb1c2560, 0xddcd001a, 0x2900002d, 0x00000000}},  //   ngré, _viaţ, txia_,
  { {0x63a3293e, 0x61e90007, 0x6ea10204, 0x00000000}},  // [e780] kann, idel, _कौतु,
  { {0x60c900f4, 0xc963007c, 0xb87b0027, 0x00000000}},  //   item, твуй, _prír,
  { {0x63a30378, 0xdb05001f, 0x7bdc0006, 0x00000000}},  //   dann, _schö, meru,
  { {0x61e900b5, 0x60c93d6f, 0x6b670047, 0x00000000}},  //   jdel, ktem, ségé,
  { {0x63a30016, 0xfc3f0051, 0x186a29ef, 0x00000000}},  //   fann, isín_, _мами_,
  { {0x63a3000c, 0x7bdc0127, 0x61e900bb, 0x00000000}},  //   gann, neru, edel,
  { {0x61e921cb, 0x7bdc001a, 0xe61a00e2, 0x00000000}},  //   fdel, ieru, _ддв_,
  { {0xd2570147, 0xdb250010, 0x60c90146, 0x00000000}},  //   мцы_, ésér, ftem,
  { {0x63a30051, 0x30140242, 0x7bdc00ea, 0x00000000}},  //   bann, едпр, keru,
  { {0x68200039, 0x7bdc0020, 0x63a30051, 0x00000000}},  //   _föde, jeru, cann,
  { {0x7bdc001f, 0x74130084, 0x80bd0044, 0x00000000}},  //   deru, _جولا, ্টগ্,
  { {0xd3780091, 0x61e9004a, 0x6abc3d70, 0x00000000}},  //   _naći_, cdel, durf,
  { {0x60c900f4, 0x7bdc1c94, 0x6e3d1fbc, 0x00000000}},  //   ctem, feru, rnsb,
  { {0x20190065, 0x7bdc010f, 0x09a70061, 0x00000000}},  //   ësit_, geru, गण्य,
  { {0x81e10055, 0xd5a4026c, 0x76590016, 0x00000000}},  //   দার_, _پہ_, ylwy,
  { {0x799601d6, 0x25a0000c, 0x387800fa, 0x00000000}},  //   gbyw, ðill_, _airr_,
  { {0x30bc0055, 0x63a30890, 0xc984005e, 0x00000000}},  // [e790] _অনুস, yann, туси,
  { {0x68ed0df9, 0xee3f0428, 0x9c38007c, 0x00000000}},  //   rvad, lný_, _опыт_,
  { {0x248d0343, 0x61e931d5, 0x68ed0142, 0x00000000}},  //   _stem_, ydel, svad,
  { {0x7ae5008d, 0x63a3293e, 0xee3f3d71, 0x00000000}},  //   _isht, wann, nný_,
  { {0x68200039, 0x61e915b3, 0xb87b000c, 0x00000000}},  //   _söde, vdel, _gríp,
  { {0x61e900d9, 0x02c51c31, 0x7ae50023, 0x00000000}},  //   wdel, ейко, _ksht,
  { {0x63a30198, 0x7bc50020, 0x61e900f8, 0x00000000}},  //   rann, _mchu, tdel,
  { {0x63a3002a, 0x60c90198, 0xee3f01ca, 0x00000000}},  //   sann, ttem, jný_,
  { {0x61e90376, 0xee3f01ca, 0x63a301a3, 0x00000000}},  //   rdel, dný_, pann,
  { {0x60c91ec1, 0x61e90056, 0x93bc001a, 0x00000000}},  //   rtem, sdel, _clăd,
  { {0x7bdc0b30, 0x61e90129, 0xdb1c004a, 0x00000000}},  //   veru, pdel, sfrú,
  { {0x7bc50016, 0xfbc9009b, 0x63a1032e, 0x00000000}},  //   _achu, _לת_, _heln,
  { {0x9f47008d, 0x7bdc0127, 0x63a10006, 0x00000000}},  //   _kanë_, teru, _keln,
  { {0x9f47008d, 0x62810c5d, 0x7bdc010f, 0x00000000}},  //   _janë_, _kulo, ueru,
  { {0xdbdd009f, 0x7bdc0190, 0x63a10089, 0x00000000}},  //   ráðu, reru, _meln,
  { {0x09e300ed, 0xb87b0027, 0xbca60025, 0x00000000}},  //   лосн, _príp, _كمبي,
  { {0x7ae5048a, 0x39460ca7, 0x6d4101f6, 0x00000000}},  // [e7a0] _esht, ços_, şlar,
  { {0x57e700ed, 0x7bdc0065, 0x1ae610dc, 0x00000000}},  //   ндум_, qeru, _зоом,
  { {0x28ac013d, 0xdb9b0104, 0x62810471, 0x00000000}},  //   _चिकि, _מסיר, _nulo,
  { {0x25a0002a, 0xb87b06c2, 0x5ab70049, 0x00000000}},  //   úil_, _tríp, _אלטע_,
  { {0xb97b009b, 0x69c6035f, 0x62813d72, 0x00000000}},  //   _מרכז, _icke, _aulo,
  { {0x62811314, 0x63a1137e, 0x93bc0035, 0x00000000}},  //   _bulo, _celn, _amăr,
  { {0x2bd20201, 0x6281001a, 0x63a10059, 0x00000000}},  //   द्या, _culo, _deln,
  { {0x63a10004, 0xc7af00a1, 0x6281011c, 0x00000000}},  //   _eeln, _پڑے_, _dulo,
  { {0xc05a008b, 0xee3f06b8, 0x63a10010, 0x00000000}},  //   зін_, vný_, _feln,
  { {0x20d30025, 0x25a600e0, 0x9f470173, 0x00000000}},  //   اتيج, laol_, _kanè_,
  { {0xee3f06b8, 0x6281382e, 0x69c600f8, 0x00000000}},  //   tný_, _gulo, _ocke,
  { {0x7bc5001f, 0x63a105d2, 0x00000000, 0x00000000}},  //   _schu, _zeln,   ,
  { {0xee3f01ca, 0x6281002d, 0xdb15000c, 0x00000000}},  //   rný_, _zulo, _íbúa,
  { {0x7a23006c, 0x79e700a1, 0xee3f0161, 0x00000000}},  //   _mõte, کورہ_, sný_,
  { {0x005700a0, 0x22ac00b9, 0x27ff0082, 0x00000000}},  //   _רשות_, něk_, _đun_,
  { {0x9b580088, 0xa2d80204, 0x00000000, 0x00000000}},  //   хист_, _महन्,   ,
  { {0x26d83d73, 0x200e00e7, 0x3ebe0056, 0x00000000}},  // [e7b0] _apro_, _kofi_, lutt_,
  { {0xb90902fb, 0x7bc5000b, 0x66190093, 0x00000000}},  //   _मन_, _uchu, wkwk,
  { {0xf3ff00ad, 0x7ae5008d, 0x3ebe0056, 0x00000000}},  //   _đã_, _usht, nutt_,
  { {0x62810035, 0x25a60022, 0xceb300a0, 0x00000000}},  //   _rulo, gaol_, ריף_,
  { {0x63a13d74, 0x628100e0, 0xb22b00e2, 0x00000000}},  //   _peln, _sulo, _наjн,
  { {0xe3b300a2, 0x628103dd, 0x2936007b, 0x00000000}},  //   ارش_, _pulo, _יארן_,
  { {0x81ea0055, 0x92e80025, 0x63a10d90, 0x00000000}},  //   মান_, فريق_, _veln,
  { {0x75e7007e, 0x62813d75, 0x25a6005b, 0x00000000}},  //   _яўге, _vulo, caol_,
  { {0x63a106d4, 0x9f470065, 0xe3b30644, 0x00000000}},  //   _teln, _tanë_, _مرض_,
  { {0x6281272e, 0x69df0023, 0x3e7b05a0, 0x00000000}},  //   _tulo, heqe, _rūta_,
  { {0x62810058, 0x00000000, 0x00000000, 0x00000000}},  //   _uulo,   ,   ,
  { {0x2374031d, 0xd05f006b, 0x9f470062, 0x00000000}},  //   _صالح, _əvəz, _jané_,
  { {0xd378016c, 0x200e0026, 0x9f4700c4, 0x00000000}},  //   _daću_, _fofi_, _mané_,
  { {0x320f1bc0, 0x3ebe02c0, 0x0c79007c, 0x00000000}},  //   _hogy_, butt_, ессы_,
  { {0xe805006e, 0xf1a501f5, 0x00000000, 0x00000000}},  //   राना_, _गजान,   ,
  { {0x61eb00ea, 0x00000000, 0x00000000, 0x00000000}},  //   _jagl,   ,   ,
  { {0x61eb006a, 0x00000000, 0x00000000, 0x00000000}},  // [e7c0] _magl,   ,   ,
  { {0x61eb0039, 0xe3b8005a, 0x395c0089, 0x00000000}},  //   _lagl, _alın_, āvs_,
  { {0xf719007e, 0x3d6500a6, 0x25a6005b, 0x00000000}},  //   ніцы_, _لطیف, taol_,
  { {0x61eb1a7e, 0x22ac00b9, 0x68200039, 0x00000000}},  //   _nagl, věk_, _döda,
  { {0x9f473d76, 0x7a3b00b0, 0x00000000, 0x00000000}},  //   _dané_, sätä,   ,
  { {0xa7da007a, 0x93bc001a, 0xa507003b, 0x00000000}},  //   _توسط_, _slăb, теља_,
  { {0x6234026b, 0x68e43d77, 0x2d803d78, 0x00000000}},  //   леку, lwid, _ogie_,
  { {0xe3b2007a, 0x69c40142, 0x61eb0207, 0x00000000}},  //   _چرا_, ngie, _cagl,
  { {0x68e40857, 0x61eb2a8f, 0xad9b000c, 0x00000000}},  //   nwid, _dagl, sjúk,
  { {0xa3ba0025, 0x69df0065, 0xd378016c, 0x00000000}},  //   _زائر_, zeqe, _saću_,
  { {0x81d708b7, 0x61eb2165, 0xd7bb0049, 0x00000000}},  //   ায়_, _fagl, וציר,
  { {0x61eb28a7, 0x24843d79, 0x3ebe3d7a, 0x00000000}},  //   _gagl, _kumm_, rutt_,
  { {0x69c400bb, 0x23c90309, 0x00000000, 0x00000000}},  //   dgie, _रामद,   ,
  { {0x61e0011f, 0xdfd00025, 0x68e400ab, 0x00000000}},  //   leml, _طيب_, dwid,
  { {0x2bd2007d, 0x307b00a3, 0x60c000b0, 0x00000000}},  //   द्धा, _קאונ, lumm,
  { {0x69c40007, 0x61e0014a, 0x00000000, 0x00000000}},  //   ggie, neml,   ,
  { {0x60c00056, 0x68e4077e, 0x69df0023, 0x00000000}},  // [e7d0] numm, gwid, reqe,
  { {0x2bd20164, 0x7d58009b, 0x00000000, 0x00000000}},  //   द्दा, _ביחד_,   ,
  { {0x12bd0055, 0x25ff0061, 0x60c00145, 0x00000000}},  //   _আন্দ, ळाली_, humm,
  { {0x60c0002b, 0x61e000ca, 0xe6100426, 0x00000000}},  //   kumm, jeml, يشن_,
  { {0xe8df001d, 0xa8a401f9, 0x61eb0016, 0x00000000}},  //   _thực_, _врск, _ragl,
  { {0x61eb2353, 0x78ad0479, 0x248401a2, 0x00000000}},  //   _sagl, msav, _dumm_,
  { {0x61eb006a, 0x78ad0006, 0x9f4700f6, 0x00000000}},  //   _pagl, lsav, _tané_,
  { {0x93bc001a, 0x80be0044, 0x26c10058, 0x00000000}},  //   _plăc, ্বন্, muho_,
  { {0x78ad1395, 0x61eb0197, 0x26c10058, 0x00000000}},  //   nsav, _vagl, luho_,
  { {0x1dc60061, 0x603901aa, 0x61eb3d7b, 0x00000000}},  //   _वाहत, fňma, _wagl,
  { {0x61eb0207, 0x6da60256, 0x61e0016c, 0x00000000}},  //   _tagl, лина, beml,
  { {0xa2d802f4, 0x60c03d7c, 0x00000000, 0x00000000}},  //   _महत्, bumm,   ,
  { {0x78ad0107, 0x64433d7d, 0xb87b0010, 0x00000000}},  //   jsav, onni, _csík,
  { {0x78ad0056, 0x81ea0044, 0x64430fd1, 0x00000000}},  //   dsav, মাণ_, nnni,
  { {0x644331b2, 0xab2a003b, 0x69c401d6, 0x00000000}},  //   inni, хова_, tgie,
  { {0x69c4001e, 0x6e92067a, 0x68e4278b, 0x00000000}},  //   ugie, _اليا, twid,
  { {0x69c4010f, 0x6e2409bd, 0x78ad01c4, 0x00000000}},  // [e7e0] rgie, _ilib, gsav,
  { {0xebe601f9, 0x68e40d4d, 0x69c4054e, 0x00000000}},  //   _сооп, rwid, sgie,
  { {0x09b00044, 0x7d090065, 0x225f083a, 0x00000000}},  //   ঙ্গা, _tërë, kluk_,
  { {0x64430046, 0x00000000, 0x00000000, 0x00000000}},  //   enni,   ,   ,
  { {0xe3b20014, 0xb4ae0061, 0x00000000, 0x00000000}},  //   مرغ_, कळे_,   ,
  { {0x6e2404bd, 0x2a60006c, 0xdb07000c, 0x00000000}},  //   _llib, llib_, rgjö,
  { {0x61e0393a, 0x6e242e51, 0xd62a003b, 0x00000000}},  //   teml, _olib, _зове_,
  { {0x7afa00b0, 0x64433d7e, 0x28c80316, 0x00000000}},  //   ätty, anni, िंपि,
  { {0x61e03d7f, 0x463b007b, 0xf99300a0, 0x00000000}},  //   reml, _נעמע, זרח_,
  { {0x60c00193, 0x442701a2, 0x44382c50, 0x00000000}},  //   rumm, chn_, _ör_,
  { {0x93cb00a1, 0xb33c01d5, 0x60c0006c, 0x00000000}},  //   _سالہ_, _ieħo, summ,
  { {0x78ad3d80, 0x6e240051, 0x62983d81, 0x00000000}},  //   ysav, _clib, mpvo,
  { {0x81ea0044, 0x409601fc, 0x00000000, 0x00000000}},  //   মাদ_, _срет,   ,
  { {0x6e24001a, 0xa2ab0061, 0xb33c01f3, 0x00000000}},  //   _elib, ींच्, _jeħo,
  { {0x501b0104, 0xdcef0276, 0xfe7001b2, 0x00000000}},  //   _אוגו, racı, تدی_,
  { {0x63aa000c, 0x78ad010e, 0x00000000, 0x00000000}},  //   hafn, tsav,   ,
  { {0x644337a9, 0x38350216, 0xe3b801df, 0x00000000}},  // [e7f0] ynni, анар, _alım_,
  { {0x78ad0066, 0x201e06aa, 0x225f3d82, 0x00000000}},  //   rsav, nkti_, zluk_,
  { {0x78ad06c0, 0xd6db00a5, 0x2a600058, 0x00000000}},  //   ssav, эта_, blib_,
  { {0x7afa0030, 0xeef70104, 0x45d5007c, 0x00000000}},  //   ætte, טמבר_, родс,
  { {0x2bd2007d, 0x44270146, 0x7e6d0fcc, 0x00000000}},  //   द्वा, thn_, _mhap,
  { {0x7bc7000c, 0x644300b0, 0x00000000, 0x00000000}},  //   ngju, unni,   ,
  { {0xa3490265, 0xdb1c1f1e, 0x225f3d83, 0x00000000}},  //   ъзка_, ográ, tluk_,
  { {0xe1ff008e, 0xdb1c3d84, 0x5b7c0049, 0x00000000}},  //   ñó_, ngrá, ערהא,
  { {0x1b0c0044, 0x225f3d85, 0x61450069, 0x00000000}},  //   _হইছে_, rluk_, репа,
  { {0x225f0334, 0x6e2400b9, 0xe8df0082, 0x00000000}},  //   sluk_, _slib, _giục_,
  { {0x44251775, 0x43840025, 0xb87b12b2, 0x00000000}},  //   _ill_, _المق, _epíg,
  { {0x3eb807da, 0x4155007c, 0x6e240026, 0x00000000}},  //   árta_, _квес, _qlib,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x55760049, 0x7bc7000c, 0x6d5f0065, 0x00000000}},  //   יערן_, ggju, _dyqa,
  { {0xfaa60081, 0x765b014a, 0x26c70129, 0x00000000}},  //   рабо, _okuy, ànol_,
  { {0xceb80036, 0x6e241126, 0x442514ea, 0x00000000}},  //   rzęt_, _ulib, _lll_,

  { {0x44250016, 0x2a600f00, 0xe9d70184, 0x00000000}},  // [e800] _oll_, rlib_, јку_,
  { {0x7a230004, 0x48032798, 0x00000000, 0x00000000}},  //   _võta, опув,   ,
  { {0x3bbb009b, 0x93bc00e5, 0xf99f000a, 0x00000000}},  //   _במיד, _blăn, _poèt_,
  { {0x4425130f, 0x9f5c004f, 0x3a2902ae, 0x00000000}},  //   _all_, _nový_, chap_,
  { {0x44250190, 0x261700fa, 0x00000000, 0x00000000}},  //   _bll_, _aços_,   ,
  { {0x18a3007e, 0x92f60025, 0x14180025, 0x00000000}},  //   _фарм, لأعض, طيبة_,
  { {0x44253d86, 0x63aa0016, 0xb7db00b3, 0x00000000}},  //   _dll_, rafn, _שקלי,
  { {0x442504bd, 0x63aa000c, 0x7c3c01a2, 0x00000000}},  //   _ell_, safn, hirr,
  { {0xdfd401ab, 0x7c3c0145, 0xb33c0066, 0x00000000}},  //   бопы, kirr, _teħo,
  { {0x7e6d3d87, 0x201e008f, 0x16040061, 0x00000000}},  //   _shap, ukti_, ळावर_,
  { {0x64580a14, 0x201e0006, 0x443c3d88, 0x00000000}},  //   movi, rkti_, miv_,
  { {0x443c0224, 0x63a80cf5, 0x00000000, 0x00000000}},  //   liv_, _hedn,   ,
  { {0x40940054, 0x0ca8005e, 0x62880027, 0x00000000}},  //   _التر, итри_, _hudo,
  { {0x645801cd, 0x62881ea7, 0xbebc001e, 0x00000000}},  //   novi, _kudo, dzīv,
  { {0x63a8115c, 0x7e6d0051, 0x62881d9c, 0x00000000}},  //   _medn, _thap, _judo,
  { {0x443c01d9, 0x7e6d05fa, 0x64580119, 0x00000000}},  //   hiv_, _uhap, hovi,
  { {0x64580466, 0x443c063b, 0xc4c400a1, 0x00000000}},  // [e810] kovi, kiv_, _تے_,
  { {0x645800d2, 0x6e3d2a22, 0x443c0213, 0x00000000}},  //   jovi, lisb, jiv_,
  { {0x64580340, 0xcfe10044, 0x443c0142, 0x00000000}},  //   dovi, বাচন, div_,
  { {0x3f790049, 0xdb050010, 0xd24601d8, 0x00000000}},  //   אָנע, _nehé, _رن_,
  { {0x44253d89, 0x24e70098, 0x65600016, 0x00000000}},  //   _pll_, рцег, _cymh,
  { {0x645800ee, 0x62881124, 0xb4e700e8, 0x00000000}},  //   govi, _budo, _बनी_,
  { {0x9f4700b9, 0x62880036, 0x63a83859, 0x00000000}},  //   _paní_, _cudo, _dedn,
  { {0xddc40059, 0xe8050061, 0x00000000, 0x00000000}},  //   _ohiš, रावा_,   ,
  { {0x443c3d8a, 0x65600016, 0x76590036, 0x00000000}},  //   biv_, _gymh, mowy,
  { {0x44250129, 0x64580387, 0x76590036, 0x00000000}},  //   _ull_, covi, lowy,
  { {0xdb050010, 0x26d33d8b, 0x628800f8, 0x00000000}},  //   _fehé, ntxo_, _gudo,
  { {0x81b10044, 0x63a8013e, 0x76590036, 0x00000000}},  //   ঞ্জ_, _zedn, nowy,
  { {0xee37060e, 0x30750751, 0x7c3c0fd1, 0x00000000}},  //   сня_, _лукс, tirr,
  { {0x62880022, 0x00000000, 0x00000000, 0x00000000}},  //   _yudo,   ,   ,
  { {0xff5300d3, 0x81ea0055, 0x4e95031d, 0x00000000}},  //   _بخش_, মার_, _اشتر,
  { {0xbb430680, 0x5986005e, 0x64580340, 0x00000000}},  //   ческ, слаб, zovi,
  { {0x76590036, 0xe8fa00a5, 0x443c01aa, 0x00000000}},  // [e820] dowy, ыла_, yiv_,
  { {0x443c006b, 0x3a2003e3, 0x81b10044, 0x00000000}},  //   xiv_, skip_, ঞ্চ_,
  { {0x6458037e, 0x63a80059, 0x443c19c5, 0x00000000}},  //   vovi, _redn, viv_,
  { {0x62882727, 0x452a19c9, 0x63a8003b, 0x00000000}},  //   _rudo, лжен_, _sedn,
  { {0x443c3d8c, 0x98a00046, 0x7a230004, 0x00000000}},  //   tiv_, dzić_, _mõtl,
  { {0x9cd700b6, 0x628800b0, 0x9f4e0023, 0x00000000}},  //   מונה_, _pudo, _qafë_,
  { {0x443c00eb, 0x63a801d9, 0x8bf20044, 0x00000000}},  //   riv_, _vedn, ঞাপন_,
  { {0x443c000d, 0x64580091, 0x76590036, 0x00000000}},  //   siv_, sovi, cowy,
  { {0x64580213, 0x9f4e0263, 0x63a801d9, 0x00000000}},  //   povi, _zafè_, _tedn,
  { {0x62883d8d, 0x6016001a, 0x6e3d01d6, 0x00000000}},  //   _tudo, _câmp, wisb,
  { {0xe0cf00a6, 0xdb1c0210, 0x6e3d1fbc, 0x00000000}},  //   وزی_, ngrä, tisb,
  { {0xde590451, 0xbebc0089, 0x7d1d3d8e, 0x00000000}},  //   рамі_, dzīt, tyss,
  { {0x463b0049, 0x5c07005e, 0x25d70049, 0x00000000}},  //   רעכע, бява, זוכן_,
  { {0x6e3d00bb, 0x7d1d00f8, 0x76590036, 0x00000000}},  //   sisb, ryss, zowy,
  { {0xa3cd02fb, 0x9f5c00c4, 0x7d1d3d8f, 0x00000000}},  //   ष्ट_, _vovó_, syss,
  { {0x6e4401f9, 0x7d0900b0, 0xb9c50025, 0x00000000}},  //   _нејз, äess, تقري,
  { {0xe805024c, 0xb4e703d7, 0xb815003b, 0x00000000}},  // [e830] राला_, _बने_, одај,
  { {0x2cb400b9, 0x2baa0061, 0x9f4e01aa, 0x00000000}},  //   řadí_, करणा, _pafè_,
  { {0x76590eeb, 0x67b80025, 0xb87b0325, 0x00000000}},  //   towy, صالح_, _apíc,
  { {0x9f4e088a, 0x3e7b010a, 0xe3b801f6, 0x00000000}},  //   _café_, _būti_, _adı_,
  { {0x6385025f, 0x76590036, 0x69dd0056, 0x00000000}},  //   огла, rowy, _ibse,
  { {0x76590036, 0xe8940194, 0xdb07013e, 0x00000000}},  //   sowy, _харь, hají,
  { {0x8c1c061e, 0xe299008b, 0x2bdb04da, 0x00000000}},  //   רווי, шай_, म्या,
  { {0x6d41038c, 0x20183d90, 0x00000000, 0x00000000}},  //   şlay, örin_,   ,
  { {0x98a00107, 0xdb0700b9, 0x41050088, 0x00000000}},  //   rzić_, dají, ізов,
  { {0x225d0022, 0x00000000, 0x00000000, 0x00000000}},  //   _wkwk_,   ,   ,
  { {0x3f6900e2, 0x5e4a2436, 0x69cf000a, 0x00000000}},  //   рино_, ипом_, _occe,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x60160035, 0xd0090fd8, 0x00000000, 0x00000000}},  //   _tâmp, _веле_,   ,
  { {0x69cf0b63, 0x80dc0044, 0x00000000, 0x00000000}},  //   _acce, বিশ্,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xbebc0089, 0x69cf00e5, 0x00000000, 0x00000000}},  //   rzīt, _ccce,   ,
  { {0xe7aa0081, 0x3ea70016, 0x69dd0087, 0x00000000}},  // [e840] ивал_, _hwnt_, _dbse,
  { {0x69cf0207, 0x7d1b010f, 0x201300f6, 0x00000000}},  //   _ecce, äuse, _òxid_,
  { {0x46ea026b, 0x3e7b0089, 0xf986007c, 0x00000000}},  //   рден_, _sūti_, _мгно,
  { {0xe5a30256, 0x05661074, 0x090601f9, 0x00000000}},  //   дици, овен, _дпмн,
  { {0xe8f72329, 0x62820116, 0xdb1c04ce, 0x00000000}},  //   _для_, _rioo, sgrä,
  { {0xdb07013e, 0x00000000, 0x00000000, 0x00000000}},  //   zají,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb114003b, 0xb33c01f3, 0x00000000, 0x00000000}},  //   змиш, _jeħi,   ,
  { {0xdb0700b9, 0x628201d6, 0x00000000, 0x00000000}},  //   vají, _vioo,   ,
  { {0xf3ca0439, 0xb33c0066, 0xd01a1663, 0x00000000}},  //   _خبره_, _leħi, рфи_,
  { {0x25ff0061, 0x00000000, 0x00000000, 0x00000000}},  //   ळाची_,   ,   ,
  { {0x629a0288, 0xddab00e2, 0x7bde384f, 0x00000000}},  //   _itto, штол_, _abpu,
  { {0x867b00a0, 0x00000000, 0x00000000, 0x00000000}},  //   ירטו,   ,   ,
  { {0x7a23006c, 0x644a0048, 0xdb07339c, 0x00000000}},  //   _võtm, nnfi, sají,
  { {0xb0240011, 0x644a0051, 0x00000000, 0x00000000}},  //   _giườ, infi,   ,
  { {0xddeb03ec, 0xe70b0014, 0x00000000, 0x00000000}},  //   _ضربه_, یتان_,   ,
  { {0x69dd0051, 0xfbd3007d, 0x00000000, 0x00000000}},  // [e850] _vbse, _तापम,   ,
  { {0x629a0198, 0xe6160059, 0x7c2e01a2, 0x00000000}},  //   _otto, _čišč, chbr,
  { {0x98ac0089, 0x7afe0009, 0x9f4e0010, 0x00000000}},  //   ālās_, _grpt, _infó_,
  { {0x69cf0197, 0xcff30044, 0x3afa0049, 0x00000000}},  //   _ucce, জায়_, _פּיע,
  { {0x629a19eb, 0x64a50888, 0xa3e7013d, 0x00000000}},  //   _atto, чала, यजल_,
  { {0xdb0e1c88, 0x3e720161, 0xe8df0082, 0x00000000}},  //   fabè, máte_, _nhức_,
  { {0x68ed018e, 0x20090011, 0x170700a1, 0x00000000}},  //   lwad, _đai_, _ظفری_,
  { {0x69cd03e3, 0xd4e72bda, 0x682004ce, 0x00000000}},  //   ngae, _мюзи, _rödi,
  { {0x629a0197, 0x68ed0016, 0xd5fb0082, 0x00000000}},  //   _etto, nwad, _giú,
  { {0x25ad015c, 0xe8df001d, 0xb87b0010, 0x00000000}},  //   _heel_, _chức_, _zsír,
  { {0x961d001e, 0x25ad3d91, 0x764b0016, 0x00000000}},  //   _ziņa, _keel_, ongy,
  { {0xfce601fb, 0xfe7201f7, 0x3e720062, 0x00000000}},  //   помо, عدد_, káte_,
  { {0xc1040054, 0x61e9006c, 0x9f5c00f6, 0x00000000}},  //   _يومي, meel, _envà_,
  { {0xa09a012f, 0x5eda0055, 0x68ed0016, 0x00000000}},  //   _היסט, _বছরে, dwad,
  { {0x2007349c, 0xab27003b, 0x60c90ede, 0x00000000}},  //   _inni_, пора_, luem,
  { {0x1dc6001c, 0x3e7b001e, 0x61e900b0, 0x00000000}},  //   _वाटत, _būtu_, neel,
  { {0x2edb141c, 0x60c90ede, 0x9ac30066, 0x00000000}},  // [e860] _बहुत, nuem, _ċċek,
  { {0x61e91ea7, 0x7e930035, 0xb33c0066, 0x00000000}},  //   heel, _zăpa, _weħi,
  { {0x61e93d92, 0x69cd0009, 0x9f450010, 0x00000000}},  //   keel, bgae, felé_,
  { {0xd6cf0558, 0x68200039, 0xa2ca01f5, 0x00000000}},  //   طقه_, _nödv, संस्,
  { {0x25ad0100, 0xd5af06f1, 0x61e901b5, 0x00000000}},  //   _deel_, افه_, deel,
  { {0x02a601be, 0x961d001e, 0x7bce0058, 0x00000000}},  //   прим, _viņa, ngbu,
  { {0x66e301b3, 0x25ad00ab, 0xd36f0025, 0x00000000}},  //   _пора, _feel_, ههه_,
  { {0x20070198, 0x25ad0ee3, 0xc1ea0088, 0x00000000}},  //   _anni_, _geel_, ське_,
  { {0x1dc60061, 0xe8df0011, 0x60c9038e, 0x00000000}},  //   _वाजत, _phức_, guem,
  { {0x2018000c, 0xb033007c, 0x2d893d93, 0x00000000}},  //   ðri_, еньш, _sgae_,
  { {0x61e9017c, 0x75220010, 0x442c0190, 0x00000000}},  //   beel, lyoz, _ild_,
  { {0x443e16d4, 0x7c3e0035, 0x99820173, 0x00000000}},  //   _hmt_, _ampr, _ankō_,
  { {0xe8df001d, 0xdb050211, 0x5c070c4e, 0x00000000}},  //   _thức_, _vehí, пява,
  { {0x68fb0181, 0x717b009b, 0x68ed01aa, 0x00000000}},  //   _áudi, _הנדס, vwad,
  { {0x7e860224, 0x442c0142, 0x443e0724, 0x00000000}},  //   íspě, _mld_, _mmt_,
  { {0x7c3e081d, 0x442c01f3, 0x443e0089, 0x00000000}},  //   _empr, _lld_, _lmt_,
  { {0x442c0038, 0xa3d20061, 0x20070016, 0x00000000}},  // [e870] _old_, _वाढ_, _ynni_,
  { {0x68ed1f0f, 0xb87b1505, 0x442c0082, 0x00000000}},  //   rwad, _psíq, _nld_,
  { {0x6e2d1ac6, 0x25ad0e9e, 0x9f450224, 0x00000000}},  //   _klab, _peel_, telé_,
  { {0x443e3d94, 0x442c0032, 0xd774004b, 0x00000000}},  //   _amt_, _ald_, رالع,
  { {0x25ad2e34, 0x248d02d5, 0x443e006b, 0x00000000}},  //   _veel_, _quem_, _bmt_,
  { {0x443e0095, 0x2a69010e, 0x25ad0bc7, 0x00000000}},  //   _cmt_, llab_, _weel_,
  { {0xe3b000b8, 0x6e2d011f, 0x35b500ed, 0x00000000}},  //   اره_, _olab, _обвр,
  { {0x02dd03d7, 0x442c0332, 0x443e006c, 0x00000000}},  //   _महीन, _eld_, _emt_,
  { {0x61e92a1d, 0xdb0e0181, 0x443e2b33, 0x00000000}},  //   reel, rabé, _fmt_,
  { {0x443e001d, 0xa3d40140, 0x61e90c75, 0x00000000}},  //   _gmt_, _поуч, seel,
  { {0x6e2d00f4, 0x661b24b0, 0x61e9046a, 0x00000000}},  //   _blab, _kouk, peel,
  { {0x6443010a, 0x661b021e, 0x7c3e00f6, 0x00000000}},  //   lini, _jouk, _smpr,
  { {0x60c9028c, 0x64430051, 0x661b098a, 0x00000000}},  //   quem, oini, _mouk,
  { {0x64432b61, 0x7afc0119, 0x3b0a007c, 0x00000000}},  //   nini, tvrt, оего_,
  { {0x7bdc0146, 0x66092309, 0x442700ea, 0x00000000}},  //   rfru, _onek, ikn_,
  { {0x7bdc0f2a, 0x224d0010, 0x6443014a, 0x00000000}},  //   sfru, nnek_, hini,
  { {0x6443010a, 0xd9430057, 0x2bdb02f4, 0x00000000}},  // [e880] kini, вети, म्हा,
  { {0x66092017, 0x64430006, 0xcb6a003b, 0x00000000}},  //   _anek, jini, _мапе_,
  { {0x6443010a, 0x224d0047, 0x661b01aa, 0x00000000}},  //   dini, knek_, _bouk,
  { {0x81e20044, 0xb33c01d5, 0x443e0145, 0x00000000}},  //   _ফোন_, _meħt, _smt_,
  { {0x6443096e, 0xa3d20164, 0x443e0009, 0x00000000}},  //   fini, _वाद_, _pmt_,
  { {0x6443010a, 0xe3b8005d, 0x6609002d, 0x00000000}},  //   gini, _alır_, _enek,
  { {0x7e640263, 0xbddb0129, 0x442c1768, 0x00000000}},  //   _okip, dièn, _vld_,
  { {0x290200ca, 0x224d0010, 0x64433d95, 0x00000000}},  //   _krka_, gnek_, aini,
  { {0x6443010a, 0x961d001e, 0x442c0300, 0x00000000}},  //   bini, _ziņo, _tld_,
  { {0x3f140242, 0x7e640020, 0x442c0190, 0x00000000}},  //   едос, _akip, _uld_,
  { {0x3eb80047, 0x27f80016, 0x629e3d96, 0x00000000}},  //   ért_, _marn_, ípod,
  { {0x26c70091, 0x2902074d, 0x25a63d97, 0x00000000}},  //   šnog_, _orka_, nbol_,
  { {0x03f10044, 0xe0d40049, 0x7ff300a2, 0x00000000}},  //   চারী_, _נײַ_, رسیا,
  { {0x7e640340, 0xbddb0129, 0x7a310056, 0x00000000}},  //   _ekip, cièn, _måte,
  { {0x2a6900ea, 0x7a310039, 0x2902014a, 0x00000000}},  //   tlab_, _låte, _arka_,
  { {0x64430006, 0x3e56001e, 0xb87b12b2, 0x00000000}},  //   zini, tāte_, _epíl,
  { {0x6443027d, 0x2a6901ee, 0x61e200e7, 0x00000000}},  // [e890] yini, rlab_, _mbol,
  { {0x661b00b9, 0x47c70044, 0x27f83d98, 0x00000000}},  //   _souk, র্নী, _carn_,
  { {0x6443010a, 0x661b000a, 0x201c0061, 0x00000000}},  //   vini, _pouk, _movi_,
  { {0x64430036, 0x7a3100d8, 0x27f83d99, 0x00000000}},  //   wini, _båte, _earn_,
  { {0x6443010a, 0x27f80016, 0x78f90049, 0x00000000}},  //   tini, _farn_, _צפֿו,
  { {0x61e20129, 0x201c01d9, 0x68200039, 0x00000000}},  //   _abol, _novi_, _döds,
  { {0x6443049d, 0x224d0047, 0x661b00b0, 0x00000000}},  //   rini, tnek_, _touk,
  { {0x64430890, 0x2d9f04f3, 0xdb1c00ea, 0x00000000}},  //   sini, ñuel_, rgrø,
  { {0x64430006, 0x224d0cca, 0x25bf023a, 0x00000000}},  //   pini, rnek_, _idul_,
  { {0x7e64009f, 0x224d0010, 0x61e2002d, 0x00000000}},  //   _skip, snek_, _ebol,
  { {0xfe460741, 0xbddb0129, 0xd24e0123, 0x00000000}},  //   енно, rièn, شنی_,
  { {0xed5a0a33, 0x6ec0007d, 0x00000000, 0x00000000}},  //   зом_, _विरु,   ,
  { {0x61fb003f, 0xdb07006c, 0x00000000, 0x00000000}},  //   mdul, hajä,   ,
  { {0x09ba001c, 0x61f9018e, 0x60db0416, 0x00000000}},  //   ेल्य, _hawl, mtum,
  { {0x60db3d9a, 0xa3d20164, 0x25a60279, 0x00000000}},  //   ltum, _वास_, ybol_,
  { {0x3a29023a, 0x60db1b50, 0xbddb1339, 0x00000000}},  //   gkap_, otum, nièl,
  { {0x60db0ae4, 0x68320030, 0x64410c46, 0x00000000}},  // [e8a0] ntum, _læde, _omli,
  { {0x25bf0061, 0x6c3400a1, 0x60db0883, 0x00000000}},  //   _adul_, _شہزا, itum,
  { {0x60db0368, 0x7d041ab0, 0xdb050047, 0x00000000}},  //   htum, _hris, _tehá,
  { {0x321d0046, 0x4a9b007b, 0x29020107, 0x00000000}},  //   _nowy_, _מיטג, _trka_,
  { {0x25a61346, 0x27f8009d, 0x61fb0016, 0x00000000}},  //   rbol_, _tarn_, ddul,
  { {0x7d040020, 0x25a6008e, 0x29003d9b, 0x00000000}},  //   _mris, sbol_, mvia_,
  { {0x2bd3001c, 0x61f900e0, 0x201c0026, 0x00000000}},  //   _तासा, _bawl, _rovi_,
  { {0x28c7013d, 0x93bc001a, 0x30a602dc, 0x00000000}},  //   _लिमि, _alăt, нров,
  { {0x29000129, 0xe8050061, 0x61f900ea, 0x00000000}},  //   nvia_, राचा_, _dawl,
  { {0x93bc0035, 0x61fb3d9c, 0xd575030d, 0x00000000}},  //   _clăt, adul, _русь,
  { {0x7d043d9d, 0x61f901c3, 0x61fb1fec, 0x00000000}},  //   _aris, _fawl, bdul,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7e7d01c5, 0x7a230004, 0x2ca00009, 0x00000000}},  //   rmsp, _mõtt, _ctid_,
  { {0x7d042ddd, 0x00f7009b, 0x3e720062, 0x00000000}},  //   _dris, _נמוך_, ráta_,
  { {0x7d040ac2, 0xdb58007c, 0x2ca001aa, 0x00000000}},  //   _eris, еют_, _etid_,
  { {0x7d040e69, 0x00000000, 0x00000000, 0x00000000}},  //   _fris,   ,   ,
  { {0x7d040016, 0x3a290397, 0x6f030ecc, 0x00000000}},  // [e8b0] _gris, rkap_, _zrnc,
  { {0x3a29351f, 0x68200039, 0x61fb0010, 0x00000000}},  //   skap_, _södr, zdul,
  { {0xdcfd01f6, 0xc5d501ff, 0x290000b0, 0x00000000}},  //   ması, віль, avia_,
  { {0xdcfd0279, 0xd6d8007e, 0x2c760190, 0x00000000}},  //   lası, эту_, ræde_,
  { {0x61f9020f, 0x3e560089, 0x7d04006b, 0x00000000}},  //   _rawl, nāta_, _xris,
  { {0xdcfd027d, 0x00000000, 0x00000000, 0x00000000}},  //   nası,   ,   ,
  { {0xdce40046, 0x61f91a79, 0xb3d20061, 0x00000000}},  //   _dzię, _pawl, _सारख,
  { {0x60db3d9e, 0x7afa000c, 0x3e5601c5, 0x00000000}},  //   ttum, ætti, kāta_,
  { {0x212b0dea, 0x34950069, 0xdcfd027d, 0x00000000}},  //   ách_, _разр, kası,
  { {0x601e00b9, 0x7d0426a1, 0x3e560089, 0x00000000}},  //   _námě, _rris, dāta_,
  { {0x60db021e, 0x34d102fb, 0x47c70044, 0x00000000}},  //   stum, _समुद, র্থী,
  { {0x7d04102f, 0x27010006, 0x98a90036, 0x00000000}},  //   _pris, _mėn_, czać_,
  { {0xee371969, 0xdcfd005a, 0x3e560089, 0x00000000}},  //   тня_, fası, gāta_,
  { {0x628b00e0, 0xa1360049, 0x29000197, 0x00000000}},  //   _higo, _באנק_, vvia_,
  { {0x628b0020, 0x0b590a78, 0xeb970072, 0x00000000}},  //   _kigo, ерты_, тис_,
  { {0x29000089, 0xc3320104, 0x628b2e8a, 0x00000000}},  //   tvia_, בול_, _jigo,
  { {0xf1b2052f, 0xa3c302f4, 0x60c90207, 0x00000000}},  // [e8c0] יסן_, ्ला_, nrem,
  { {0x628b010a, 0x60c900f4, 0x29002522, 0x00000000}},  //   _ligo, irem, rvia_,
  { {0x99990047, 0xfaa60245, 0xbddb147f, 0x00000000}},  //   _első_, _шано, zièm,
  { {0x64a600ed, 0x601e00b9, 0x44e900fa, 0x00000000}},  //   вада, _zámě, fº_,
  { {0x7a230004, 0xbddb00f4, 0x34d10309, 0x00000000}},  //   _võtt, xièm, _समृद,
  { {0x07a30265, 0x07ba0025, 0xfc3f008e, 0x00000000}},  //   _варн, _زهرة_, opía_,
  { {0x628b027b, 0x77910167, 0x7a230004, 0x00000000}},  //   _bigo, _ایما, _tõtt,
  { {0x60f801be, 0xf506092b, 0x5186007c, 0x00000000}},  //   ения_, _избо, купа,
  { {0xdcfd005f, 0x60c90173, 0xfbb80055, 0x00000000}},  //   yası, grem, _জানত,
  { {0xdcfd006b, 0x98a90036, 0x7a310056, 0x00000000}},  //   xası, szać_, _måta,
  { {0x7a3138c6, 0x3fc800a6, 0x60c9004a, 0x00000000}},  //   _låta, ودگی_, arem,
  { {0x63b80213, 0xd36f0076, 0x71a6007e, 0x00000000}},  //   lavn, _بهم_, _радз,
  { {0x60c9027b, 0xdcfd005d, 0xecc7005e, 0x00000000}},  //   crem, tası, ъщно,
  { {0x09cb001c, 0x628b002d, 0x63b81565, 0x00000000}},  //   िल्य, _zigo, navn,
  { {0xdcfd038c, 0x628000d9, 0x00000000, 0x00000000}},  //   rası, ommo,   ,
  { {0x79a4007c, 0x39a400ed, 0x7a3102e1, 0x00000000}},  //   ируе, ишув, _båta,
  { {0x497501a4, 0xa3d20309, 0x63b8089f, 0x00000000}},  // [e8d0] улас, वला_, kavn,
  { {0x63b801d9, 0xc6a70098, 0xdcfd006b, 0x00000000}},  //   javn, врди, qası,
  { {0x63b80091, 0xdb050afc, 0x588400a5, 0x00000000}},  //   davn, _behå, рыта,
  { {0x7a23006c, 0x80b80044, 0xa535007c, 0x00000000}},  //   _võts, _আমন্, лнеч,
  { {0xc9870143, 0x00000000, 0x00000000, 0x00000000}},  //   _јуни,   ,   ,
  { {0x60c90119, 0x628b014a, 0xf77300a6, 0x00000000}},  //   vrem, _sigo, _ناز_,
  { {0xe1f10025, 0x8c1c009b, 0x00000000, 0x00000000}},  //   مسة_, ווגי,   ,
  { {0xc1b90054, 0x628b3d9f, 0x63b8016c, 0x00000000}},  //   رابط_, _qigo, aavn,
  { {0x63b80209, 0x60c90666, 0x3114007e, 0x00000000}},  //   bavn, urem, афэс,
  { {0x60c9022b, 0xef19012b, 0x6fd80061, 0x00000000}},  //   rrem, емо_, _माणू,
  { {0xe7f603d7, 0x5f450025, 0x628b224b, 0x00000000}},  //   ीयता_, انجل, _tigo,
  { {0xe80a03d7, 0x60c93a03, 0xe29a0049, 0x00000000}},  //   _होना_, prem, _טשער,
  { {0xb4f90049, 0xf1b90213, 0x518706f3, 0x00000000}},  //   עפֿי, maš_, _ружа,
  { {0xd040005f, 0x9f050558, 0xf1b90059, 0x00000000}},  //   kumə, _موتو, laš_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63b812d6, 0x7a310d2b, 0x00000000, 0x00000000}},  //   zavn, _påta,   ,
  { {0x2bdc0061, 0x00000000, 0x00000000, 0x00000000}},  // [e8e0] _बापा,   ,   ,
  { {0xf99f01aa, 0xe73a09e6, 0xf1b900ca, 0x00000000}},  //   _efè_, нез_, haš_,
  { {0xa3ba006e, 0xf1b90213, 0x3e560089, 0x00000000}},  //   _अजब_, kaš_, nāto_,
  { {0xf1b9092f, 0x7afa000c, 0x7c2e00f8, 0x00000000}},  //   jaš_, ættu, lkbr,
  { {0x63b80059, 0xa3b4008b, 0xf1b90340, 0x00000000}},  //   tavn, аблі, daš_,
  { {0x7c2e0112, 0x320f00e5, 0xdb070142, 0x00000000}},  //   nkbr, _angy_, vajú,
  { {0x63b80340, 0x68f6018e, 0x5334041f, 0x00000000}},  //   ravn, lwyd, рейт,
  { {0x69d60010, 0xf753023c, 0xddcf0035, 0x00000000}},  //   ngye, _انفج, docş,
  { {0x2611001c, 0xc034025f, 0x68f60016, 0x00000000}},  //   णारी_, иниј, nwyd,
  { {0xdb0e0010, 0x00000000, 0x00000000, 0x00000000}},  //   zabá,   ,   ,
  { {0x33930054, 0x81e90044, 0x7413067a, 0x00000000}},  //   _المز, ময়_, _دولا,
  { {0x2cb2018e, 0x644a0b25, 0xdd910025, 0x00000000}},  //   _bwyd_, lifi, توح_,
  { {0x302a004d, 0x00000000, 0x00000000, 0x00000000}},  //   _подп_,   ,   ,
  { {0x961d0089, 0x9f5c0065, 0x68f60016, 0x00000000}},  //   _viņi, _javë_, dwyd,
  { {0x28c7001c, 0xf8bf0224, 0xdb0e015f, 0x00000000}},  //   _लिहि, _své_, tabá,
  { {0x2cb20016, 0xf9930025, 0x644a01b1, 0x00000000}},  //   _fwyd_, صبر_, hifi,
  { {0x68f6018e, 0x644a16fa, 0x00000000, 0x00000000}},  // [e8f0] gwyd, kifi,   ,
  { {0x25fd0183, 0x68320030, 0x644a0a13, 0x00000000}},  //   _रोजी_, _pæda, jifi,
  { {0x81cc0055, 0xf1b90059, 0xc6a708f3, 0x00000000}},  //   শ্য_, ljše_, урзи,
  { {0xf8bf013e, 0x00000000, 0x00000000, 0x00000000}},  //   _tvé_,   ,   ,
  { {0xf1b90295, 0x99820173, 0x644a2dbf, 0x00000000}},  //   vaš_, _ankņ_, fifi,
  { {0xd90e026c, 0x644a3da0, 0x22460190, 0x00000000}},  //   _کیے_, gifi, _amok_,
  { {0xf1b90091, 0x00000000, 0x00000000, 0x00000000}},  //   taš_,   ,   ,
  { {0x3e5601c5, 0x00000000, 0x00000000, 0x00000000}},  //   vāto_,   ,   ,
  { {0x2055007c, 0xf1b90e3b, 0xdcee0089, 0x00000000}},  //   итор, raš_, ājīb,
  { {0xe3b00014, 0x09b2013d, 0x8467005e, 0x00000000}},  //   _فرم_, _ज़्य, _събе,
  { {0x2bdc01f5, 0x3ea30023, 0x00000000, 0x00000000}},  //   _बाबा, ëjt_,   ,
  { {0x7bc50a9e, 0x81cc0044, 0x68f60016, 0x00000000}},  //   _adhu, শ্ব_, ywyd,
  { {0x9f4c0207, 0x6aa50048, 0x7c660025, 0x00000000}},  //   ledì_, _athf, لاسل,
  { {0x69cb00dc, 0x4fa50a94, 0x913a0049, 0x00000000}},  //   ógen, _тикв, _בענק,
  { {0x9f4c0207, 0x290f0039, 0x7ae30039, 0x00000000}},  //   nedì_, ågan_, _äntl,
  { {0xc33200b3, 0x644a03ae, 0x2d920010, 0x00000000}},  //   קון_, zifi, _ugye_,
  { {0x87ba007c, 0xada90025, 0x644a0173, 0x00000000}},  // [e900] вует_, _صديق_, yifi,
  { {0x68f61acd, 0x644a0035, 0x6e240051, 0x00000000}},  //   rwyd, xifi, _hoib,
  { {0x1036007b, 0x5fdd0061, 0x68f60016, 0x00000000}},  //   סטעם_, _मानल, swyd,
  { {0x81ab0044, 0x25a00009, 0x644a005b, 0x00000000}},  //   কৃত_, ùil_, wifi,
  { {0xb903008b, 0x25a9008e, 0x00000000, 0x00000000}},  //   _дзяк, ñala_,   ,
  { {0x9f5c01aa, 0x0ec5006e, 0xf2c60216, 0x00000000}},  //   _favè_, _विंड, асин,
  { {0x764b011c, 0xc5d60088, 0x00000000, 0x00000000}},  //   bigy, _візь,   ,
  { {0xe80a02f4, 0x6e240048, 0x75d60379, 0x00000000}},  //   _होता_, _noib, _خيرا,
  { {0xd0100025, 0x100a0025, 0x1da7006e, 0x00000000}},  //   كلة_, نتدى_, _क्षत,
  { {0x66001f0f, 0x91a6013d, 0x660207ef, 0x00000000}},  //   _hamk, _ट्रै, ldok,
  { {0x44e20011, 0x645a30ad, 0x44e00197, 0x00000000}},  //   _hư_, _ijti, lò_,
  { {0x66022367, 0x3e720051, 0x6e360016, 0x00000000}},  //   ndok, náth_, _clyb,
  { {0x44e03da1, 0x00000000, 0x00000000, 0x00000000}},  //   nò_,   ,   ,
  { {0x78a9005d, 0x660027e4, 0x6fb40439, 0x00000000}},  //   _çevi, _lamk, _امثا,
  { {0x6e360030, 0x8ff7026c, 0xdddd0036, 0x00000000}},  //   _flyb, _ضرور_, rosł,
  { {0x0dcb041f, 0xbdb50098, 0x6e243da2, 0x00000000}},  //   _руки_, _убиј, _goib,
  { {0x5fdd03d7, 0x7e6d0199, 0x644805fe, 0x00000000}},  // [e910] _मामल, _ikap, _omdi,
  { {0x9f47008e, 0x44e015e1, 0xe8df0082, 0x00000000}},  //   _ganó_, dò_, _nhục_,
  { {0xfbdc001c, 0xf7700188, 0xda67006d, 0x00000000}},  //   _बातम, وام_, _ناحي,
  { {0x9f4c0207, 0x60c20091, 0x645a0087, 0x00000000}},  //   vedì_, _ovom, _ajti,
  { {0x44e2001d, 0x7e6d0020, 0xa3d20061, 0x00000000}},  //   _cư_, _mkap, वलं_,
  { {0x44e20011, 0xe8df0011, 0xdb050637, 0x00000000}},  //   _dư_, _chục_, _behø,
  { {0x972500d3, 0x7a2a0161, 0x00000000, 0x00000000}},  //   _افزو, _výtv,   ,
  { {0xe1f900d7, 0x7c2506be, 0x660001d6, 0x00000000}},  //   уги_, _lohr, _gamk,
  { {0x44e00197, 0x7649323a, 0xe5340194, 0x00000000}},  //   cò_, _imey, _деть,
  { {0x66000036, 0x12e70088, 0x7e6d0020, 0x00000000}},  //   _zamk, _відг, _akap,
  { {0x6e24002a, 0xfeb9007a, 0x4425013e, 0x00000000}},  //   _poib, داخت_, _iol_,
  { {0x44250010, 0x290b01ee, 0xdb150161, 0x00000000}},  //   _hol_, _orca_, gazí,
  { {0x4425010a, 0x7c25010f, 0x865a01ce, 0x00000000}},  //   _kol_, _bohr, רדרי,
  { {0x224d27dc, 0x69dd0093, 0x44250cc1, 0x00000000}},  //   liek_, _acse, _jol_,
  { {0x09a90055, 0x9f95006c, 0x7c250062, 0x00000000}},  //   _ওয়া, _müük_, _dohr,
  { {0x4425006a, 0x224d1c71, 0xdb1c0023, 0x00000000}},  //   _lol_, niek_, larë,
  { {0x19b9007e, 0x69dd0009, 0x660000b4, 0x00000000}},  // [e920] русь_, _dcse, _ramk,
  { {0x6600009f, 0x80cf0164, 0x44252f06, 0x00000000}},  //   _samk, _दिने, _nol_,
  { {0x44e2001d, 0x66020030, 0x224d312a, 0x00000000}},  //   _sư_, tdok, kiek_,
  { {0x05ba1095, 0x69dd0050, 0x44e00197, 0x00000000}},  //   ادات_, _gcse, tò_,
  { {0xe8df001d, 0x44250027, 0x6fd8006e, 0x00000000}},  //   _phục_, _bol_, _मालू,
  { {0x44252800, 0x68e41861, 0x44e00207, 0x00000000}},  //   _col_, mtid, rò_,
  { {0xc5ed0055, 0x68e40004, 0x44250059, 0x00000000}},  //   ওয়া_, ltid, _dol_,
  { {0x44e2001d, 0x644d00f4, 0x44250d28, 0x00000000}},  //   _tư_, éair, _eol_,
  { {0x5554026c, 0x44250c55, 0xa5070888, 0x00000000}},  //   _بھار, _fol_, _лета_,
  { {0x7e6d01e2, 0xa3d20204, 0x16160061, 0x00000000}},  //   _skap, _वाट_, णावर_,
  { {0xc7b3009b, 0x68e4006c, 0x2d9e00b9, 0x00000000}},  //   הבת_, htid, ěten_,
  { {0x90e6007a, 0x68e4006c, 0x44250009, 0x00000000}},  //   _هستن, ktid, _zol_,
  { {0x4425038c, 0x412a01fb, 0x62650379, 0x00000000}},  //   _yol_, _щодо_, _بالق,
  { {0x629a0be3, 0x80a4007a, 0x39400089, 0x00000000}},  //   _kuto, _همچن, dzis_,
  { {0x63ba1402, 0x290b0746, 0xf1b90059, 0x00000000}},  //   _metn, _srca_, ljša_,
  { {0x7e6d01ee, 0x68e40009, 0x31790036, 0x00000000}},  //   _ukap, ftid, ższe_,
  { {0x7c250066, 0xe9180088, 0xf1b90059, 0x00000000}},  // [e930] _tohr, боті_, njša_,
  { {0x629a3da3, 0x26c71c61, 0x224d3da4, 0x00000000}},  //   _outo, šnom_, ziek_,
  { {0x2baf0164, 0x7d0d0340, 0x629a007f, 0x00000000}},  //   _ज्या, _hras, _nuto,
  { {0x442504bd, 0x68e40146, 0xa3ab0061, 0x00000000}},  //   _sol_, btid, कुन_,
  { {0x4425086e, 0x68e400d4, 0x25bd3da5, 0x00000000}},  //   _pol_, ctid, rawl_,
  { {0x63ba01a8, 0x629a12fc, 0xdb1c010f, 0x00000000}},  //   _cetn, _buto, rgrö,
  { {0x44253da6, 0x224d001e, 0xdb1c3da7, 0x00000000}},  //   _vol_, tiek_, varë,
  { {0x7d0d001a, 0x44253da8, 0xd7d9013d, 0x00000000}},  //   _oras, _wol_, _ढाँच,
  { {0xdb1c008d, 0x224d022b, 0x545500e3, 0x00000000}},  //   tarë, riek_, _дват,
  { {0x224d0343, 0x44250181, 0x629a0232, 0x00000000}},  //   siek_, _uol_, _futo,
  { {0x7d0d01f6, 0x629a011c, 0x68e40032, 0x00000000}},  //   _aras, _guto, ztid,
  { {0x7d0d0fb3, 0x7659018e, 0x7afe001c, 0x00000000}},  //   _bras, nnwy, _rspt,
  { {0x1ddb02f4, 0x3e560089, 0x7d0d00ab, 0x00000000}},  //   _भारत, nāti_, _cras,
  { {0x61e90292, 0xdd06006b, 0x00000000, 0x00000000}},  //   lfel, çqın,   ,
  { {0x7d0d0d49, 0xa3d20061, 0x61e90026, 0x00000000}},  //   _eras, _वाघ_, ofel,
  { {0x61e905b4, 0x68e4225c, 0xdb1700c4, 0x00000000}},  //   nfel, ttid, _xexé,
  { {0x602500b9, 0xe9d7007e, 0x61e901a2, 0x00000000}},  // [e940] _témě, ўку_, ifel,
  { {0x20050d82, 0x39400035, 0x3e560089, 0x00000000}},  //   ndli_, rzis_, dāti_,
  { {0xbddb028c, 0x63ba05ba, 0x76590016, 0x00000000}},  //   mièr, _retn, fnwy,
  { {0xac97089d, 0xbddb028c, 0x94aa003b, 0x00000000}},  //   _دنیا_, lièr, атка_,
  { {0x61e900ea, 0xdb153da9, 0x63ba0213, 0x00000000}},  //   dfel, mazá, _petn,
  { {0x48f9007b, 0xbddb00f4, 0x629a0119, 0x00000000}},  //   _פּרא, nièr, _puto,
  { {0x645800f8, 0x00000000, 0x00000000, 0x00000000}},  //   rnvi,   ,   ,
  { {0x61e90047, 0x4444026c, 0xaa370049, 0x00000000}},  //   gfel, _کررہ, ַטיק_,
  { {0x7bdc01d2, 0x32020142, 0x3e720062, 0x00000000}},  //   kgru, ľky_, nátu_,
  { {0x32020428, 0xdb1c1d81, 0x7d0d0023, 0x00000000}},  //   žky_, parè, _rras,
  { {0x91e60069, 0x7bdc1502, 0x59ca0061, 0x00000000}},  //   _може, dgru, िणार,
  { {0x7d0d0ebc, 0x98b20046, 0xde59007e, 0x00000000}},  //   _pras, czyć_, самі_,
  { {0x7bdc010f, 0x5c070e85, 0x00000000, 0x00000000}},  //   fgru, оява,   ,
  { {0x7bdc0030, 0x7d0d0065, 0x212b010f, 0x00000000}},  //   ggru, _vras, äche_,
  { {0x0dcb00e3, 0x76590016, 0x2bdc0309, 0x00000000}},  //   _купи_, ynwy, _बारा,
  { {0x7d0d07c5, 0x9999005e, 0x00000000, 0x00000000}},  //   _tras, скат_,   ,
  { {0xc4c400a1, 0xbddb009d, 0x00000000, 0x00000000}},  // [e950] _جے_, bièr,   ,
  { {0xbddb009d, 0x57f4007e, 0x62820022, 0x00000000}},  //   cièr, мпут, _lhoo,
  { {0x78ad037e, 0x5695007c, 0xf77000a1, 0x00000000}},  //   spav, чает, پال_,
  { {0x3e56001e, 0xfad6009b, 0x78ad0052, 0x00000000}},  //   tāti_, _צורך_, ppav,
  { {0x0608007e, 0xa5090517, 0x03a5004d, 0x00000000}},  //   ўнік_, села_, пило,
  { {0xe2990147, 0x03a50194, 0x3e560089, 0x00000000}},  //   бак_, чико, rāti_,
  { {0x61e90010, 0x68f9005d, 0xf48500a1, 0x00000000}},  //   tfel, şadı, _ہائی,
  { {0x628200ab, 0xa3ab0316, 0xbddb009d, 0x00000000}},  //   _choo, _क्र_, zièr,
  { {0xc3cb002c, 0x98b20036, 0x61e9010f, 0x00000000}},  //   _نظام_, rzyć_, rfel,
  { {0x61e90f11, 0x98b20036, 0x2d9e00b9, 0x00000000}},  //   sfel, szyć_, ětem_,
  { {0xfd4d001d, 0x61e902fa, 0xbddb00f4, 0x00000000}},  //   _triệ, pfel, vièr,
  { {0x20032794, 0x244900b4, 0x00000000, 0x00000000}},  //   žji_, dźmi_,   ,
  { {0xbddb028c, 0xc19a00b6, 0xdb150010, 0x00000000}},  //   tièr, _השני, vazá,
  { {0x2bdc0061, 0xb068039d, 0xc0040088, 0x00000000}},  //   _बाळा, _وصول_, _опік,
  { {0x7bdc010f, 0xbddb00f4, 0x6833014a, 0x00000000}},  //   rgru, rièr, _mıdı,
  { {0x7bdc0056, 0xba230517, 0x28c7006e, 0x00000000}},  //   sgru, ндск, _लिखि,
  { {0x3946008b, 0xbddb009d, 0x00000000, 0x00000000}},  // [e960] чнаг, pièr,   ,
  { {0x3e720428, 0xb7da0076, 0xa8030143, 0x00000000}},  //   rátu_, صوصا_, нзул,
  { {0x04040044, 0xa9a6004d, 0xbf790082, 0x00000000}},  //   লামী_, _нинд, _đuốc_,
  { {0x6aa3008e, 0x63820048, 0x00000000, 0x00000000}},  //   _énfa, _líní,   ,
  { {0x628200d9, 0x00000000, 0x00000000, 0x00000000}},  //   _rhoo,   ,   ,
  { {0x04432763, 0x628200ab, 0xd4990088, 0x00000000}},  //   нечн, _shoo, ірі_,
  { {0x78a901f6, 0x62820066, 0xb0240082, 0x00000000}},  //   _çevr, _phoo, _nhườ,
  { {0x75840123, 0x714602dc, 0x85e702dc, 0x00000000}},  //   _قیام, зхож, _ндсв_,
  { {0x3e560089, 0x26da3daa, 0x00000000, 0x00000000}},  //   nātu_, lupo_,   ,
  { {0xdefa0147, 0x00000000, 0x00000000, 0x00000000}},  //   бым_,   ,   ,
  { {0x5fdd0061, 0x26110061, 0x833a18ea, 0x00000000}},  //   _मारल, णाची_, _учат_,
  { {0xd37b0049, 0x2902006c, 0x31790036, 0x00000000}},  //   _פראט, _oska_, ższa_,
  { {0xa3c2001c, 0x9405006b, 0x69d8007f, 0x00000000}},  //   _्या_, _ailə_, ėvel,
  { {0x26da0058, 0x3e560089, 0x00000000, 0x00000000}},  //   kupo_, dātu_,   ,
  { {0x7a380051, 0x290213ee, 0x00000000, 0x00000000}},  //   _vítn, _aska_,   ,
  { {0xb606012d, 0xdb1e01c3, 0x9405013f, 0x00000000}},  //   _ješć, _kepê, _dilə_,
  { {0x3206011c, 0x290f01e5, 0x00000000, 0x00000000}},  // [e970] _maoy_, íga_,   ,
  { {0x80cf0061, 0xf99013d9, 0x00000000, 0x00000000}},  //   _दिसे, طبق_,   ,
  { {0xf1dc0365, 0xfbd2019b, 0x26c70224, 0x00000000}},  //   _यांन, _בתי_, éno_,
  { {0xb8d308b7, 0xcf930049, 0x00000000, 0x00000000}},  //   _টি_, גטע_,   ,
  { {0xe5340088, 0xd5fb0082, 0x3a2b000a, 0x00000000}},  //   нець, _chú, _iocp_,
  { {0x61e23a56, 0x3e480010, 0x6fd80061, 0x00000000}},  //   _acol, lőtt_, _मागू,
  { {0x753c005f, 0x26da0197, 0x94740014, 0x00000000}},  //   _ərzi, cupo_, ردها,
  { {0x394d009f, 0xfbe30044, 0x61e20009, 0x00000000}},  //   _þess_, য়িত, _ccol,
  { {0x7fd50099, 0xa4d40088, 0x62890add, 0x00000000}},  //   міні, _поті, rmeo,
  { {0xb0240011, 0x2c760190, 0x60250088, 0x00000000}},  //   _phườ, pædi_, єдна,
  { {0x73c4023c, 0xfbe30044, 0xe7ef0061, 0x00000000}},  //   _سينم, য়াত, घ्या_,
  { {0x200b0df0, 0x61e20051, 0x249f006c, 0x00000000}},  //   ści_, _gcol, _kuum_,
  { {0x61fb0557, 0x9405013f, 0x37d50044, 0x00000000}},  //   meul, _silə_, স্যর,
  { {0xb024001d, 0x8c9505b8, 0x3c3400b0, 0x00000000}},  //   _thườ, ерсі, _kävi_,
  { {0x09e60088, 0x9f5c0129, 0xeb9701fc, 0x00000000}},  //   мовн, _gavà_, дир_,
  { {0x68ff001c, 0xed5a0865, 0x200715df, 0x00000000}},  //   fwqd, _мой_, _hani_,
  { {0x2007011c, 0xdb1c3dab, 0x2baf007d, 0x00000000}},  // [e980] _kani_, marí, _ज्वा,
  { {0x7a3804bd, 0x7d040058, 0x20071d9c, 0x00000000}},  //   _títo, _isis, _jani_,
  { {0x8c1b007b, 0x20072e43, 0x49ba0d3a, 0x00000000}},  //   _וויי, _mani_, _واحد_,
  { {0x2ca00004, 0x200707a0, 0xb8e40055, 0x00000000}},  //   _kuid_, _lani_, _এম_,
  { {0x6e3d0065, 0x61fb00e0, 0x64a30451, 0x00000000}},  //   ërbi, deul, вача,
  { {0x2ca0244d, 0x2007000b, 0x25a63dac, 0x00000000}},  //   _muid_, _nani_, scol_,
  { {0x38a403a2, 0x3e56001e, 0x4e0e013d, 0x00000000}},  //   _hör_, nāts_, ियाई_,
  { {0x38a418c2, 0x80cf0061, 0x69c40f90, 0x00000000}},  //   _kör_, _दिशे, naie,
  { {0x2007000d, 0xdb1c11c4, 0x7d0401f3, 0x00000000}},  //   _bani_, darí, _nsis,
  { {0xdfd00380, 0x20070207, 0x69c43dad, 0x00000000}},  //   ديد_, _cani_, haie,
  { {0x93430256, 0x2007049c, 0x443e2370, 0x00000000}},  //   _инфе, _dani_, _ilt_,
  { {0x442c0161, 0xdb1c11c4, 0x99800006, 0x00000000}},  //   _hod_, garí, nkių_,
  { {0x442c0119, 0x2ca0002a, 0x7a31080a, 0x00000000}},  //   _kod_, _cuid_, _mått,
  { {0x2007000b, 0x20560088, 0x7a3102e1, 0x00000000}},  //   _gani_, _ютер, _lått,
  { {0x442c3dae, 0xc108001d, 0x7d040198, 0x00000000}},  //   _mod_, _hỗ_, _esis,
  { {0x38a40073, 0x442c07f4, 0xdb1c00dc, 0x00000000}},  //   _bör_, _lod_, carí,
  { {0x2007011f, 0x2ca00922, 0x7642023a, 0x00000000}},  // [e990] _yani_, _guid_, dhoy,
  { {0xe61000e9, 0x25bf00f4, 0x38a40039, 0x00000000}},  //   یشن_, _seul_, _dör_,
  { {0x2ca000b5, 0xc1080011, 0x249f000a, 0x00000000}},  //   _zuid_, _lỗ_, _suum_,
  { {0x38a40901, 0x443e28a0, 0x80cf001c, 0x00000000}},  //   _för_, _alt_, _दिले,
  { {0x442c0bc4, 0x38a43daf, 0x443e274a, 0x00000000}},  //   _bod_, _gör_, _blt_,
  { {0xd3780046, 0x442c1567, 0xe29901f9, 0x00000000}},  //   _być_, _cod_, пак_,
  { {0x442c0e87, 0x61fb3db0, 0x45d53db1, 0x00000000}},  //   _dod_, teul, _повс,
  { {0x20073db2, 0x442c05d2, 0xdb1e0129, 0x00000000}},  //   _sani_, _eod_, _depè,
  { {0x442c0bc4, 0x200718d5, 0xf07600a1, 0x00000000}},  //   _fod_, _pani_, کیوں_,
  { {0x442c0aba, 0x7a3810af, 0x60db006c, 0x00000000}},  //   _god_, _rítm, ruum,
  { {0x2ca00343, 0xdb1c1068, 0x64430051, 0x00000000}},  //   _suid_, tarí, mhni,
  { {0xa3ab0309, 0x442c358f, 0x6e2d060c, 0x00000000}},  //   कुर_, _zod_, _coab,
  { {0x2007008d, 0xdb1e008d, 0x443e0061, 0x00000000}},  //   _tani_, _tepë, _ylt_,
  { {0x38a4072d, 0xdb1c008e, 0x3e560089, 0x00000000}},  //   _rör_, sarí, tāts_,
  { {0xe80a03d7, 0x6d460046, 0x60c93db3, 0x00000000}},  //   _होगा_, szka, lsem,
  { {0xdb260047, 0xdd9200a1, 0x2ca00009, 0x00000000}},  //   _épít, _یوں_, _tuid_,
  { {0x69c41cc3, 0xd9430088, 0x60c93c2a, 0x00000000}},  // [e9a0] raie, гети, nsem,
  { {0x60c900b0, 0x1aff0044, 0x44e929de, 0x00000000}},  //   isem, _উপরে_, dú_,
  { {0x9f450d62, 0x64430065, 0x69c41ec5, 0x00000000}},  //   meló_, dhni, paie,
  { {0x442c002b, 0xdb1e03eb, 0x667600d3, 0x00000000}},  //   _sod_, _repè, ردار,
  { {0x443e0093, 0xdb1c2c6f, 0x60c90030, 0x00000000}},  //   _plt_, barã, jsem,
  { {0x66e60088, 0xa2a40309, 0xa3ab007d, 0x00000000}},  //   _пога, _चंद्, कुल_,
  { {0x81e90055, 0x442c0f8e, 0x62990173, 0x00000000}},  //   য়ন_, _vod_, _biwo,
  { {0x877b0049, 0x2a60006c, 0xe29702ea, 0x00000000}},  //   _זאלי, nnib_, нај_,
  { {0xe2130025, 0x60f7007e, 0x442c010f, 0x00000000}},  //   طبيع, еныя_, _tod_,
  { {0x443e00d4, 0xc1080082, 0x3944000c, 0x00000000}},  //   _ult_, _vỗ_, _ýmsu_,
  { {0x60c9003c, 0x0857009b, 0x00000000, 0x00000000}},  //   asem, תבים_,   ,
  { {0x11e9006d, 0x60c90035, 0xdb1c03d1, 0x00000000}},  //   _يعني_, bsem, zarã,
  { {0xe0d40049, 0x7e64000a, 0x0cab02dc, 0x00000000}},  //   _סײַ_, _djip, ятни_,
  { {0x7e640173, 0xdb1c00fa, 0x00000000, 0x00000000}},  //   _ejip, xarã,   ,
  { {0xdb1c1396, 0x3e64014a, 0x201c004a, 0x00000000}},  //   varã, sıta_, _invi_,
  { {0xa8a7007c, 0x6443012d, 0x9f7b00a0, 0x00000000}},  //   ержк, zhni, _מנוח,
  { {0x23e00204, 0xdb1c0181, 0x6609006c, 0x00000000}},  // [e9b0] _नांद, tarã, _raek,
  { {0x7e7d0365, 0xdb1c0129, 0x2a60006c, 0x00000000}},  //   llsp, barà, anib_,
  { {0xd6db0265, 0x7bc704cb, 0xd6d000a1, 0x00000000}},  //   ята_, maju, یقے_,
  { {0xdb053db4, 0x60c900ea, 0x7bc701a3, 0x00000000}},  //   _behö, ysem, laju,
  { {0xdb1c1f18, 0xdb1e009d, 0x64430051, 0x00000000}},  //   mará, _repé, thni,
  { {0xdb1c000c, 0x7bc70020, 0x44e93db5, 0x00000000}},  //   lará, naju, rú_,
  { {0x68ed0f19, 0x44e93db6, 0xf1b90059, 0x00000000}},  //   ltad, sú_, ljši_,
  { {0x60c908b2, 0xb8030055, 0xdb1c1ad4, 0x00000000}},  //   tsem, _উচিত_, nará,
  { {0x68ed3db7, 0xe66401be, 0x39490211, 0x00000000}},  //   ntad, _стро, nzas_,
  { {0x7e7603c9, 0x68ed1ce5, 0x60c90127, 0x00000000}},  //   _skyp, itad, rsem,
  { {0x60c9028c, 0x7bc70091, 0x68ed1e85, 0x00000000}},  //   ssem, daju, htad,
  { {0xed5a013b, 0x68ed011f, 0x2fc50030, 0x00000000}},  //   дом_, ktad, salg_,
  { {0xdb1c0051, 0x321d01c3, 0xc69208cd, 0x00000000}},  //   dará, _inwy_, יאט_,
  { {0x320d0061, 0x09ca001c, 0xd011025a, 0x00000000}},  //   ldey_, िण्य, _ضلع_,
  { {0xbad5008b, 0x20560049, 0x629c009d, 0x00000000}},  //   літы, _ביסל_, _érot,
  { {0x3b0701f9, 0xf2d201ce, 0x68ed3db8, 0x00000000}},  //   њето_, יעל_, ftad,
  { {0x64410052, 0x65690065, 0xdb0e00d6, 0x00000000}},  // [e9c0] _olli, _nxeh, tabó,
  { {0x7a382c39, 0x7bc704eb, 0x00000000, 0x00000000}},  //   _míti, caju,   ,
  { {0x7a38009f, 0xdb1c3db9, 0x290f0039, 0x00000000}},  //   _líti, bará, ågar_,
  { {0x75d30054, 0xe9a6026b, 0x9473089d, 0x00000000}},  //   ليما, _шамп, یدوا,
  { {0x68ed3dba, 0x200c018e, 0xd4e30057, 0x00000000}},  //   ctad, yddi_, ающи,
  { {0x07a603f3, 0x00000000, 0x00000000, 0x00000000}},  //   _јавн,   ,   ,
  { {0x683208c8, 0x00000000, 0x00000000, 0x00000000}},  //   _fædr,   ,   ,
  { {0x2281000c, 0x64413dbb, 0x00000000, 0x00000000}},  //   sókn_, _elli,   ,
  { {0x64a6008b, 0x7bc700e7, 0x7a3804bb, 0x00000000}},  //   _раза, yaju, _cíti,
  { {0xdb1c008e, 0xd575007e, 0x9f450026, 0x00000000}},  //   zará, _сусь, velò_,
  { {0x2bdc02fb, 0x4815007b, 0x7bc70091, 0x00000000}},  //   _बाजा, אַרן_, vaju,
  { {0x200a01ae, 0x7d160030, 0xf773009b, 0x00000000}},  //   žbi_, _brys, יקת_,
  { {0x7bc7037e, 0x7d1600ab, 0xdb1c04e7, 0x00000000}},  //   taju, _crys, vará,
  { {0x645809a3, 0x7d160016, 0xd00f0025, 0x00000000}},  //   nivi, _drys, _ولن_,
  { {0x7bc73dbc, 0xdb1c1d59, 0x79a700ed, 0x00000000}},  //   raju, tará, врзе,
  { {0xcbe30055, 0x68ed129e, 0x7bc7001a, 0x00000000}},  //   য়েছ, ttad, saju,
  { {0xdb1c0f26, 0x6458003c, 0x7d160007, 0x00000000}},  // [e9d0] rará, kivi, _grys,
  { {0x6e3d0007, 0x64580ecc, 0x39490211, 0x00000000}},  //   lksb, jivi, rzas_,
  { {0xdb1c0161, 0x3dd20016, 0x657b3dbd, 0x00000000}},  //   pará, _ydyw_, _syuh,
  { {0xb9090055, 0x68ed0325, 0xe7ff03d7, 0x00000000}},  //   _মন_, ptad, _उसका_,
  { {0xd1260774, 0x89da019b, 0x58d40265, 0x00000000}},  //   _ام_, _אחרי, _коят,
  { {0x64580052, 0x7bc50023, 0x00000000, 0x00000000}},  //   givi, _jehu,   ,
  { {0x7a380181, 0x7bc51d9c, 0xdb0700ea, 0x00000000}},  //   _síti, _mehu, gbjø,
  { {0x96f80893, 0x65950121, 0xad9b00c4, 0x00000000}},  //   _шест_, _бабу, ndús,
  { {0xe4d900a1, 0x6458006c, 0xd0590088, 0x00000000}},  //   _سوات_, bivi, ерні_,
  { {0x64580e77, 0x7a383451, 0x7bc5041a, 0x00000000}},  //   civi, _víti, _nehu,
  { {0x8eb20014, 0x00000000, 0x00000000, 0x00000000}},  //   یمیش,   ,   ,
  { {0x7d163dbe, 0x76590696, 0x00000000, 0x00000000}},  //   _prys, niwy,   ,
  { {0x7bc50250, 0x463a0049, 0x81e90044, 0x00000000}},  //   _behu, גערע, য়দ_,
  { {0xd0060113, 0x7d160007, 0x3b0a007c, 0x00000000}},  //   _беше_, _vrys, него_,
  { {0xdea100a6, 0x7bc50023, 0xbb43030d, 0x00000000}},  //   _دیجی, _dehu, берк,
  { {0x7d163dbf, 0x64580091, 0x9f5e0023, 0x00000000}},  //   _trys, zivi, zetë_,
  { {0x76590016, 0x7aee0009, 0x3e79000c, 0x00000000}},  // [e9e0] diwy, stbt, rétt_,
  { {0x7bc500c7, 0x6458006b, 0x9cbb00a3, 0x00000000}},  //   _gehu, xivi, _רציח,
  { {0x64580211, 0x60db194f, 0x44220011, 0x00000000}},  //   vivi, hrum, _đk_,
  { {0x64a6132a, 0x44220010, 0x60db007f, 0x00000000}},  //   гада, _ők_, krum,
  { {0x6458081d, 0x81e908b7, 0xe5e700a1, 0x00000000}},  //   tivi, য়া_, ازمی,
  { {0x07a30088, 0x83f800e3, 0x69c63dc0, 0x00000000}},  //   _гарн, текс_, _heke,
  { {0x69c604cb, 0x81b50044, 0x60db010e, 0x00000000}},  //   _keke, _জয়_, erum,
  { {0x60f8005e, 0x60db3116, 0xdb07068f, 0x00000000}},  //   вния_, frum, rbjø,
  { {0xc5660269, 0x64582426, 0x69c618e6, 0x00000000}},  //   _скак, pivi, _meke,
  { {0x9f5e3dc1, 0x00000000, 0x00000000, 0x00000000}},  //   leté_,   ,   ,
  { {0x04930025, 0xb7db0049, 0x7bc53dc2, 0x00000000}},  //   _اللح, עקטי, _rehu,
  { {0x69c60047, 0xde59007e, 0x60db00ea, 0x00000000}},  //   _neke, тамі_, brum,
  { {0xd24f0054, 0x60db0061, 0x6e3d0c7a, 0x00000000}},  //   _عنه_, crum, rksb,
  { {0x9f5e023f, 0x69c60288, 0x765900b4, 0x00000000}},  //   heté_, _aeke, ziwy,
  { {0xab95012b, 0x7a38000c, 0xa3e701f5, 0x00000000}},  //   рављ, _lítu, _भास_,
  { {0x200e009f, 0x78a6037e, 0x69c60095, 0x00000000}},  //   _hafi_, _bukv, _ceke,
  { {0x69c61ad9, 0x2bcb003b, 0x200e3046, 0x00000000}},  // [e9f0] _deke, _пуно_, _kafi_,
  { {0xee3f01dc, 0x2bc60061, 0x60c200e7, 0x00000000}},  //   lký_, वरणा, _mwom,
  { {0x69c60010, 0x200e0173, 0xdb0f00b0, 0x00000000}},  //   _feke, _mafi_, öjär,
  { {0x69c60b72, 0x79820036, 0x00000000, 0x00000000}},  //   _geke, żowa,   ,
  { {0xa50904b6, 0x76590016, 0x00000000, 0x00000000}},  //   тела_, riwy,   ,
  { {0x69c602ae, 0x7659005b, 0x32d500ed, 0x00000000}},  //   _zeke, siwy, ацис,
  { {0x249e000a, 0x00000000, 0x00000000, 0x00000000}},  //   _ditm_,   ,   ,
  { {0xa3e70201, 0xd5f9007b, 0x2919012d, 0x00000000}},  //   _भाव_, _שפּר, _krsa_,
  { {0x681b0089, 0xd24e0025, 0xe8df0082, 0x00000000}},  //   _tādē, بني_, _diệc_,
  { {0x29190271, 0x60db008e, 0x628000d9, 0x00000000}},  //   _mrsa_, rrum, almo,
  { {0x9e66041f, 0x3f690517, 0x0e660364, 0x00000000}},  //   ивод, тино_, икон,
  { {0x60db3dc3, 0x290b00d4, 0x29193dc4, 0x00000000}},  //   prum, _osca_, _orsa_,
  { {0x69c6049b, 0x60c20173, 0x32ee013f, 0x00000000}},  //   _reke, _gwom, _rəyi_,
  { {0x69c63dc5, 0xafe2012b, 0x200e00f6, 0x00000000}},  //   _seke, _дошл, _gafi_,
  { {0x69c6020c, 0x29193dc6, 0x290b0026, 0x00000000}},  //   _peke, _arsa_, _asca_,
  { {0xee3f0428, 0xb33c002b, 0x2fc700ea, 0x00000000}},  //   cký_, _jgħa, _heng_,
  { {0x47c60256, 0x69c60056, 0xb33c002b, 0x00000000}},  // [ea00] ибав, _veke, _mgħa,
  { {0x3ea702ae, 0x69c602ae, 0x9f473dc7, 0x00000000}},  //   _kunt_, _weke, _acné_,
  { {0x69c60dde, 0x2fc704d4, 0xf719007e, 0x00000000}},  //   _teke, _meng_, ліцы_,
  { {0x320f0047, 0x3ea70129, 0xeef60049, 0x00000000}},  //   _nagy_, _munt_, ימער_,
  { {0x9f5e009d, 0x3ea72555, 0x66021382, 0x00000000}},  //   reté_, _lunt_, reok,
  { {0x2baf02fb, 0x3ea034b4, 0xb6c800a1, 0x00000000}},  //   _ज्ञा, _liit_, _مارے_,
  { {0x68e4178a, 0xb33c0066, 0x9f5e0026, 0x00000000}},  //   luid, _bgħa, peté_,
  { {0x7a381cca, 0x60c20263, 0x200e0020, 0x00000000}},  //   _títu, _pwom, _safi_,
  { {0xe8df00ad, 0x68e40b33, 0x2d800020, 0x00000000}},  //   _việc_, nuid, _nyie_,
  { {0x7afe0056, 0x249e01a3, 0x3ea701a2, 0x00000000}},  //   _oppt, _uitm_, _bunt_,
  { {0xe8df0011, 0x2fc7005b, 0x2d800145, 0x00000000}},  //   _tiệc_, _deng_, _ayie_,
  { {0x68e40e2f, 0x60c23dc8, 0xd6d80044, 0x00000000}},  //   kuid, _twom, _সহায,
  { {0x2fc73dc9, 0x7afe016b, 0x00000000, 0x00000000}},  //   _feng_, _appt,   ,
  { {0xee3f004f, 0xe0fb009b, 0x68e401b5, 0x00000000}},  //   ský_, _סלול, duid,
  { {0x2246046a, 0x81e90044, 0x3ea700d9, 0x00000000}},  //   _klok_, য়র_, _gunt_,
  { {0x9f9b009b, 0x3ea000e0, 0x291932e0, 0x00000000}},  //   _בסופ, _giit_, _prsa_,
  { {0x2fc70085, 0x00000000, 0x00000000, 0x00000000}},  // [ea10] _yeng_,   ,   ,
  { {0x7d0d011c, 0x00000000, 0x00000000, 0x00000000}},  //   _isas,   ,   ,
  { {0x81de0044, 0x78ba013e, 0x2246033b, 0x00000000}},  //   দ্য_, _čtve, _olok_,
  { {0x32040046, 0x68e40489, 0x291900d0, 0x00000000}},  //   jemy_, buid, _trsa_,
  { {0x320400ab, 0x38c90167, 0x888200a1, 0x00000000}},  //   demy_, _حاجی_, _کیلن,
  { {0x644a0697, 0x2246011c, 0xdb1e0b33, 0x00000000}},  //   ghfi, _alok_, _hepá,
  { {0x224604cb, 0x683300b9, 0xdb15004a, 0x00000000}},  //   _blok_, _výdě, mazó,
  { {0x3ea70073, 0x7d0d0234, 0x2fc70030, 0x00000000}},  //   _runt_, _osas, _seng_,
  { {0x320f1bc0, 0x3ea71305, 0x2fc70b97, 0x00000000}},  //   _vagy_, _sunt_, _peng_,
  { {0x3ea704bd, 0x3ea00004, 0x644a01a2, 0x00000000}},  //   _punt_, _siit_, chfi,
  { {0xa3ac00e8, 0xb33c002b, 0x22460646, 0x00000000}},  //   _गलत_, _tgħa, _flok_,
  { {0x7bd7027b, 0x29090020, 0x2fc70145, 0x00000000}},  //   _adxu, kwaa_, _weng_,
  { {0x30a70c96, 0x2fc70058, 0xdb1c3a04, 0x00000000}},  //   _трев, _teng_, mbré,
  { {0x61e93dca, 0x3dd801d5, 0x81ae0044, 0x00000000}},  //   lgel, _żewġ_, করণ_,
  { {0x2005014a, 0x61e90016, 0x7d0d3dcb, 0x00000000}},  //   meli_, ogel, _esas,
  { {0x20050229, 0x68e400dc, 0x2ca90a89, 0x00000000}},  //   leli_, tuid, _fuad_,
  { {0x6e240851, 0x00000000, 0x00000000, 0x00000000}},  // [ea20] _inib,   ,   ,
  { {0xdb151906, 0x2005014a, 0x68e4008e, 0x00000000}},  //   gazó, neli_, ruid,
  { {0x1779008b, 0x7afe03ed, 0x7bce0a42, 0x00000000}},  //   асць_, _uppt, mabu,
  { {0x80d803d7, 0x7bce0127, 0x20050016, 0x00000000}},  //   _मिले, labu, heli_,
  { {0x644a0051, 0x61e90116, 0x2005014a, 0x00000000}},  //   thfi, dgel, keli_,
  { {0x20050209, 0x3e7201ca, 0x7bce011c, 0x00000000}},  //   jeli_, ráty_, nabu,
  { {0x61e92e94, 0x6e24268c, 0x386f0010, 0x00000000}},  //   fgel, _onib, égre_,
  { {0x61e937b0, 0x7bce1af8, 0x7a3800b9, 0x00000000}},  //   ggel, habu, _zítr,
  { {0x7bce0b9a, 0x80d80061, 0x200515dc, 0x00000000}},  //   kabu, _मिळे, feli_,
  { {0x20053dcc, 0x6e240058, 0x00000000, 0x00000000}},  //   geli_, _anib,   ,
  { {0x43863dcd, 0x645a006b, 0x64483dce, 0x00000000}},  //   _الاق, _imti, _ildi,
  { {0x3f820089, 0x479b01ce, 0x00000000, 0x00000000}},  //   āku_, טייס,   ,
  { {0x91e30e09, 0x2ca900f4, 0x9f5e004a, 0x00000000}},  //   _хоче, _quad_, metí_,
  { {0x9f5e3dcf, 0x20050142, 0x7bce04cb, 0x00000000}},  //   letí_, celi_, gabu,
  { {0x9f4c06c2, 0xa3d0007d, 0x7ff7009b, 0x00000000}},  //   redó_, _वजन_, _הזוג_,
  { {0x2aa8007c, 0x7f830025, 0x29090d16, 0x00000000}},  //   стро_, _علين, twaa_,
  { {0x38350175, 0x7d0d05e0, 0x7bce1844, 0x00000000}},  // [ea30] онар, _usas, babu,
  { {0x81ae0044, 0xb33c0066, 0x00000000, 0x00000000}},  //   করি_, _ngħo,   ,
  { {0xdb153dd0, 0xdc380049, 0x61e91ec2, 0x00000000}},  //   razó, _לאזט_, ygel,
  { {0x6448022b, 0xceb30049, 0x9f5e00b9, 0x00000000}},  //   _aldi, ליע_, jetí_,
  { {0xf8b100a1, 0x81ae0044, 0x2005014a, 0x00000000}},  //   _آکر_, করা_, yeli_,
  { {0x98790049, 0x42d90242, 0x20052034, 0x00000000}},  //   _כאָט, афия_, xeli_,
  { {0x61e903cd, 0x20050091, 0xa229213f, 0x00000000}},  //   tgel, veli_, ижка_,
  { {0xe0d90200, 0x2005000b, 0x64481402, 0x00000000}},  //   ави_, weli_, _eldi,
  { {0x61e93dd1, 0xa3e70061, 0x2ee50253, 0x00000000}},  //   rgel, _भाऊ_, wulf_,
  { {0xd766026c, 0x61e90125, 0x81e90044, 0x00000000}},  //   _انہی, sgel, য়ই_,
  { {0x81de0055, 0x64430036, 0x2005014a, 0x00000000}},  //   দ্ধ_, mkni, reli_,
  { {0x64430b16, 0x4425016e, 0x7ae70161, 0x00000000}},  //   lkni, _hnl_, dujt,
  { {0x200500b0, 0x7bce0145, 0x7c370203, 0x00000000}},  //   peli_, tabu, _boxr,
  { {0x644301bf, 0xb33c002b, 0x76493118, 0x00000000}},  //   nkni, _ogħl, _lley,
  { {0xa3e702fb, 0xeb9a0088, 0x64433dd2, 0x00000000}},  //   _भाई_, рив_, ikni,
  { {0x6e24022b, 0x7bce1794, 0x225f3dd3, 0x00000000}},  //   _unib, sabu, niuk_,
  { {0x7bce011c, 0xb33c002b, 0x44250082, 0x00000000}},  // [ea40] pabu, _agħl, _onl_,
  { {0x7649005d, 0x673e0023, 0x765b0058, 0x00000000}},  //   _aley, typj, _amuy,
  { {0xdb050011, 0xab2a142c, 0x76493dd4, 0x00000000}},  //   _nghè, _тона_, _bley,
  { {0x5efa007b, 0xd5b006dd, 0x4425002d, 0x00000000}},  //   יפעד, رفت_, _anl_,
  { {0x2c0f0061, 0x44252de5, 0xb33c01f3, 0x00000000}},  //   ायचं_, _bnl_, _egħl,
  { {0x442500f6, 0xd3720014, 0x68f601d6, 0x00000000}},  //   _cnl_, وهش_, mtyd,
  { {0x68f60007, 0x76493dd4, 0xdc9b0049, 0x00000000}},  //   ltyd, _fley, ביסל,
  { {0x7649009f, 0x224d002b, 0x442500f8, 0x00000000}},  //   _gley, ghek_, _enl_,
  { {0x2bbf001c, 0x661d000c, 0x321800b9, 0x00000000}},  //   ्रमा, _óska, ěry_,
  { {0x64430039, 0xdced005d, 0x64480089, 0x00000000}},  //   ckni, _ayağ, _uldi,
  { {0xc7b3019b, 0x3eb80065, 0x62470288, 0x00000000}},  //   ובת_, ërt_, _iñon,
  { {0x4126026c, 0x13cf0044, 0x68f60c6b, 0x00000000}},  //   _وفاق, _রায়, ktyd,
  { {0xa06a012b, 0x225700a6, 0x00000000, 0x00000000}},  //   _када_, _بلند_,   ,
  { {0x7ae71238, 0x2d850089, 0x7c37002b, 0x00000000}},  //   tujt, āle_, _qoxr,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ae70161, 0x42db0049, 0x7e6d00e7, 0x00000000}},  //   rujt, יקלע, _ujap,
  { {0x37ab026b, 0x64433dd5, 0x7e7d08d0, 0x00000000}},  // [ea50] атен_, ykni, mosp,
  { {0x7e7d1cd8, 0x7ae704bb, 0xb33c002b, 0x00000000}},  //   losp, pujt, _agħm,
  { {0x76492f1f, 0x00000000, 0x00000000, 0x00000000}},  //   _pley,   ,   ,
  { {0x44253dd6, 0x7e7d009d, 0x4efb0049, 0x00000000}},  //   _snl_, nosp, שלאג,
  { {0x4425001a, 0xe53403e8, 0xc984142c, 0x00000000}},  //   _pnl_, мець, _жури,
  { {0x7e7d0142, 0xb33c01f3, 0x3a390253, 0x00000000}},  //   hosp, _egħm, _hosp_,
  { {0x64430193, 0x9f5e002b, 0x224d01a2, 0x00000000}},  //   rkni, jetà_, thek_,
  { {0x765b0c2b, 0x64433dd7, 0x00c9005e, 0x00000000}},  //   _umuy, skni, блик_,
  { {0xf487003b, 0x7e7d3dd8, 0x00000000, 0x00000000}},  //   _дужн, dosp,   ,
  { {0x8f750088, 0x224d2828, 0x9f5c00f6, 0x00000000}},  //   зумі, shek_, _navó_,
  { {0x7e7d008e, 0x2019013e, 0x00000000, 0x00000000}},  //   fosp, ěsi_,   ,
  { {0x3ea40039, 0x7e7d00b4, 0x12fa009b, 0x00000000}},  //   ömt_, gosp, _להעב,
  { {0xe1670025, 0x68f60009, 0x61fb1473, 0x00000000}},  //   _بداي, xtyd, mful,
  { {0xd4790049, 0x61fb08e0, 0x9f5e00f6, 0x00000000}},  //   מאָל, lful, betà_,
  { {0xd00e06ea, 0x8b2302ea, 0x00000000, 0x00000000}},  //   _إلى_, ндре,   ,
  { {0x81e90044, 0x9f960097, 0x29020022, 0x00000000}},  //   য়ক_, _צדקה_, _ppka_,
  { {0xdb1c004a, 0x61fb0022, 0x00000000, 0x00000000}},  // [ea60] mbrí, iful,   ,
  { {0xa3e702f4, 0x68f601c3, 0x9f5e0861, 0x00000000}},  //   _भाग_, rtyd, letá_,
  { {0x394608ad, 0x68f60007, 0xd7ef0025, 0x00000000}},  //   šos_, styd, اكم_,
  { {0x986600a1, 0x3a3904eb, 0xbddb00f6, 0x00000000}},  //   _کیئے_, _gosp_, lhèr,
  { {0x69c42318, 0xdb1c002a, 0x1a9b007b, 0x00000000}},  //   mbie, ibrí, _ליטע,
  { {0x69c4002b, 0xf8bf000c, 0x68e40b28, 0x00000000}},  //   lbie, _bréf_, mrid,
  { {0x68e407c4, 0xd25a005e, 0x00000000, 0x00000000}},  //   lrid, йци_,   ,
  { {0x69c402ae, 0x68e4029d, 0x07a3003b, 0x00000000}},  //   nbie, orid, _часн,
  { {0x62470288, 0x00000000, 0x00000000, 0x00000000}},  //   _iñol,   ,   ,
  { {0x9989089f, 0x645d0006, 0xb603002b, 0x00000000}},  //   njaš_, _įsig, ġġer,
  { {0x7e7d25fa, 0x68e40051, 0x6d4006ec, 0x00000000}},  //   tosp, hrid, øman,
  { {0x648d002a, 0x68e4004e, 0x69c403b2, 0x00000000}},  //   núin, krid, jbie,
  { {0x7e7d0161, 0xed58007e, 0x69c410d9, 0x00000000}},  //   rosp, зоў_, dbie,
  { {0x2ca53dd9, 0x2bbf0204, 0x7e7d0197, 0x00000000}},  //   öld_, ्रधा, sosp,
  { {0x68e4006c, 0x3ffb009b, 0xd5cc01f5, 0x00000000}},  //   erid, _הפוע, ाराज,
  { {0x81de0055, 0x68e438ea, 0xaa580407, 0x00000000}},  //   দ্র_, frid, пису_,
  { {0x26d8006b, 0xdbd700b0, 0xed58003b, 0x00000000}},  // [ea70] _avro_, tääk, _ноћ_,
  { {0x37ab00ed, 0xbddb00f4, 0x69c4004a, 0x00000000}},  //   стан_, chèr, abie,
  { {0x69c40337, 0x442b001d, 0x68e4006c, 0x00000000}},  //   bbie, _đc_, arid,
  { {0xd24601fa, 0x00000000, 0x00000000, 0x00000000}},  //   _شن_,   ,   ,
  { {0x69cf0089, 0x69dd0022, 0x26d800ca, 0x00000000}},  //   _iece, _idse, _evro_,
  { {0x057402fd, 0x62820058, 0x69cf2aaa, 0x00000000}},  //   راند, _akoo, _hece,
  { {0x61fb0186, 0x69cf020c, 0x645d0006, 0x00000000}},  //   tful, _kece, _įsid,
  { {0x2fce000a, 0x26c1009d, 0x244b00ea, 0x00000000}},  //   _aefg_, mpho_, _døma_,
  { {0x61fb000c, 0xd3a700e2, 0x26c100fa, 0x00000000}},  //   rful, _ереп, lpho_,
  { {0x69cf01ee, 0x09aa0309, 0x69c405fd, 0x00000000}},  //   _lece, _कल्य, zbie,
  { {0x69dd0142, 0x2d8c0036, 0x69c41d16, 0x00000000}},  //   _odse, ędem_, ybie,
  { {0x68e40142, 0x3eae3dda, 0x78a700d9, 0x00000000}},  //   yrid, _duft_, _lijv,
  { {0x205501be, 0xcc2600a1, 0xd1b800a1, 0x00000000}},  //   _откр, ورسٹ, _رانا_,
  { {0x7d040059, 0x68e40a9d, 0x62890051, 0x00000000}},  //   _vpis, vrid, lleo,
  { {0xdca30057, 0x7d040046, 0xddcb037e, 0x00000000}},  //   тари, _wpis, žišn,
  { {0x7ae10047, 0x68e400ea, 0x69dd0009, 0x00000000}},  //   álta, trid, _cdse,
  { {0x69c41275, 0x78a702ae, 0x7d040091, 0x00000000}},  // [ea80] rbie, _bijv, _upis,
  { {0xb8f602fb, 0x69c42430, 0x69dd3ddb, 0x00000000}},  //   _सब_, sbie, _edse,
  { {0x69cf0197, 0x62891293, 0x68e40146, 0x00000000}},  //   _fece, kleo, srid,
  { {0xa3d003d7, 0x69cf014a, 0x68e40253, 0x00000000}},  //   _वजह_, _gece, prid,
  { {0xb33c0066, 0xe5a30478, 0x00000000, 0x00000000}},  //   _igħi, вици,   ,
  { {0x62820343, 0x69cf0587, 0xdb0706a1, 0x00000000}},  //   _skoo, _zece, rbjö,
  { {0x6289018e, 0xdb050011, 0xdb1c3ddc, 0x00000000}},  //   fleo, _nghì, maró,
  { {0xc1140098, 0xb33c01d5, 0x37e30055, 0x00000000}},  //   емиј, _jgħi, ন্দর,
  { {0x958305a5, 0x7bde0465, 0x12770025, 0x00000000}},  //   _алте, _odpu, بحوث_,
  { {0xdb1c0051, 0x00000000, 0x00000000, 0x00000000}},  //   naró,   ,   ,
  { {0x60cd002b, 0x6148000c, 0x62890d28, 0x00000000}},  //   _ħame, félö, bleo,
  { {0xbddb00f4, 0xb33c002b, 0x628900ab, 0x00000000}},  //   thèq, _ngħi, cleo,
  { {0xdc3a01f6, 0x628000ca, 0x00000000, 0x00000000}},  //   _açıl, momo,   ,
  { {0x628001aa, 0xddcd10b1, 0x7d1d0030, 0x00000000}},  //   lomo, _ukaž, rvss,
  { {0x69cf029a, 0x200c1ec0, 0x78a700bb, 0x00000000}},  //   _pece, medi_, _rijv,
  { {0x200c3ddd, 0xdb120051, 0x1da701f5, 0x00000000}},  //   ledi_, ógái, _गणपत,
  { {0x69cf0219, 0xb33c01f3, 0x00000000, 0x00000000}},  // [ea90] _vece, _dgħi,   ,
  { {0x628000b9, 0x200c378b, 0x9cd80104, 0x00000000}},  //   homo, nedi_, _חוזה_,
  { {0x62803dde, 0x3ea904be, 0x69cf065a, 0x00000000}},  //   komo, _kiat_, _tece,
  { {0xb93501f9, 0xd0170044, 0x69dd0030, 0x00000000}},  //   _земј, ়ায়_, _udse,
  { {0x62800046, 0x200c1bac, 0x2ab50190, 0x00000000}},  //   domo, kedi_, _håb_,
  { {0x200c0209, 0xdb1e029d, 0x3ea90169, 0x00000000}},  //   jedi_, _repú, _liat_,
  { {0xe784012b, 0x27f806b8, 0x68ed3ddf, 0x00000000}},  //   _ауто, žený_, luad,
  { {0x62800006, 0x3ea9003f, 0xdb050082, 0x00000000}},  //   gomo, _niat_, _nghí,
  { {0x68ed1b0f, 0x7bd50213, 0x9f5e021e, 0x00000000}},  //   nuad, kazu, hetä_,
  { {0x6289002d, 0x200c2c13, 0x629b2d72, 0x00000000}},  //   sleo, gedi_, smuo,
  { {0x62890211, 0x62803de0, 0x7bd50032, 0x00000000}},  //   pleo, bomo, dazu,
  { {0xf7720097, 0x531a009b, 0x76590279, 0x00000000}},  //   רקט_, _מועצ, _çayı,
  { {0x61d600b6, 0x200c003b, 0x3ea90032, 0x00000000}},  //   _נוסף_, bedi_, _diat_,
  { {0x200c0207, 0x68ed0285, 0x7bd5144c, 0x00000000}},  //   cedi_, duad, gazu,
  { {0xf8bf02d5, 0x3ea90207, 0xa3c203d7, 0x00000000}},  //   _até_, _fiat_, ूरत_,
  { {0xc332019b, 0xf2d20049, 0x3ea93de1, 0x00000000}},  //   נון_, טעל_, _giat_,
  { {0x68ed008e, 0x7bd53de2, 0x4c8601fc, 0x00000000}},  // [eaa0] guad, bazu, _плив,
  { {0x7e66023a, 0x7d57009b, 0x25ad2d51, 0x00000000}},  //   likp, _נייד_, _agel_,
  { {0x6d460006, 0xb33c01d5, 0xd7760025, 0x00000000}},  //   lyka, _tgħi, رائع,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x68ed0211, 0x7c3e02db, 0x628004c8, 0x00000000}},  //   cuad, _kopr, vomo,
  { {0x28b5007d, 0x69d600ab, 0x7c3e0089, 0x00000000}},  //   _अंति, laye, _jopr,
  { {0x200c0627, 0x6fd6006e, 0x1bee0061, 0x00000000}},  //   vedi_, _मजबू, _जाईल_,
  { {0xd25701e1, 0x69d63de3, 0x7c3e3de4, 0x00000000}},  //   ець_, naye, _lopr,
  { {0x50661deb, 0x998001d5, 0x3ea90022, 0x00000000}},  //   етна, jjiż_, _riat_,
  { {0x7c3e200a, 0x628000e7, 0x289b0049, 0x00000000}},  //   _nopr, somo, ּיטא,
  { {0x442c0018, 0x200c028c, 0x69d63de5, 0x00000000}},  //   _ind_, redi_, kaye,
  { {0x443e001d, 0x200c258f, 0x442c00e0, 0x00000000}},  //   _hot_, sedi_, _hnd_,
  { {0x443e17fd, 0x5c070265, 0x7bd50173, 0x00000000}},  //   _kot_, нява, tazu,
  { {0x3157007b, 0x7c3e1017, 0x7ae10010, 0x00000000}},  //   _אידן_, _copr, álto,
  { {0x443e05ad, 0xc4c4009c, 0x7c3e004f, 0x00000000}},  //   _mot_, _گے_, _dopr,
  { {0x443e1743, 0x68ed0325, 0x38b63de6, 0x00000000}},  //   _lot_, tuad, _bær_,
  { {0x442c0bc4, 0xc4c4026c, 0x6e2d036b, 0x00000000}},  // [eab0] _ond_, _دے_, _inab,
  { {0x443e0a8a, 0x2bee013d, 0x00000000, 0x00000000}},  //   _not_, _जाएं_,   ,
  { {0x69d6006b, 0xbbbf006e, 0xe8020061, 0x00000000}},  //   baye, ्रीक, _रउरा_,
  { {0x442c2735, 0x38b6000c, 0x443e0203, 0x00000000}},  //   _and_, _fær_, _aot_,
  { {0x38b6009f, 0x68ed3de7, 0xcc3400a6, 0x00000000}},  //   _gær_, quad, _شریع,
  { {0x443e1a50, 0xdddd0036, 0x442c00fa, 0x00000000}},  //   _cot_, nisł, _cnd_,
  { {0x6d460036, 0x6e2d00fa, 0x00000000, 0x00000000}},  //   zyka, _onab,   ,
  { {0x442c0b65, 0xd36e0025, 0x6e2d0009, 0x00000000}},  //   _end_, تهى_, _nnab,
  { {0x03f9012b, 0x442c0009, 0x443e3de8, 0x00000000}},  //   _онај_, _fnd_, _fot_,
  { {0x6e2d018e, 0x661b250b, 0x443e0038, 0x00000000}},  //   _anab, _hauk, _got_,
  { {0xc7b200b3, 0x661b2e23, 0xdb1c000c, 0x00000000}},  //   יבי_, _kauk, jarð,
  { {0x7c3e0198, 0x2f540e09, 0x661b0dec, 0x00000000}},  //   _sopr, утьс, _jauk,
  { {0x7c3e1191, 0xb33c01f3, 0x6e2d0022, 0x00000000}},  //   _popr, _dgħu, _dnab,
  { {0x661b0ebc, 0x6e2d00ab, 0x2d8c0089, 0x00000000}},  //   _lauk, _enab, āde_,
  { {0x69d60173, 0xdb1c000c, 0x60db007f, 0x00000000}},  //   taye, garð, lsum,
  { {0x661b0046, 0xbb431663, 0x44fb00c4, 0x00000000}},  //   _nauk, шеск, kê_,
  { {0x69d6006b, 0x7c3e014a, 0xa967003b, 0x00000000}},  // [eac0] raye, _topr, вита_,
  { {0x0b460256, 0x69d600f4, 0x38b601e3, 0x00000000}},  //   _анон, saye, _vær_,
  { {0x443e010f, 0x442c04e2, 0x661b01a2, 0x00000000}},  //   _rot_, _rnd_, _bauk,
  { {0x443e2d3f, 0x60db01c2, 0x442c1238, 0x00000000}},  //   _sot_, ksum, _snd_,
  { {0x661b022b, 0x443e1954, 0x00000000, 0x00000000}},  //   _dauk, _pot_,   ,
  { {0x8d5b009b, 0x442c08eb, 0x60db0036, 0x00000000}},  //   וכני, _qnd_, dsum,
  { {0x443e1825, 0x442c0011, 0xdbcd000c, 0x00000000}},  //   _vot_, _vnd_, _móðu,
  { {0x661b0542, 0x52140679, 0x2a7201c3, 0x00000000}},  //   _gauk, удит, nnyb_,
  { {0xd0100054, 0xb5050151, 0x6fd6006e, 0x00000000}},  //   ملة_, _مظلو, _मजदू,
  { {0x442c08ba, 0x6e2d0073, 0x7054004b, 0x00000000}},  //   _und_, _snab, اندا,
  { {0x1df900a5, 0x7640011c, 0xd3450014, 0x00000000}},  //   нены_, _komy, _میوه_,
  { {0xe802062e, 0xdb1c000c, 0xdd0e006e, 0x00000000}},  //   र्ता_, varð, िबंध_,
  { {0xb88400b9, 0x3f820036, 0x60db01ee, 0x00000000}},  //   _zvíř, łku_, csum,
  { {0x60cd014a, 0x60c20288, 0xfc6702dc, 0x00000000}},  //   _çama, _itom, тъмн,
  { {0x7e640093, 0x6e3f0066, 0x00000000, 0x00000000}},  //   _fmip, _toqb,   ,
  { {0x6e2d3de9, 0xba740025, 0x201c0010, 0x00000000}},  //   _unab, لاقت, _havi_,
  { {0x661b0205, 0x201c00ca, 0x661d000c, 0x00000000}},  // [ead0] _rauk, _kavi_, _óski,
  { {0xdbcd000c, 0x201c097c, 0x44fb0181, 0x00000000}},  //   _góðu, _javi_, vê_,
  { {0x661b0006, 0x201c005a, 0x97a71deb, 0x00000000}},  //   _pauk, _mavi_, трал,
  { {0x60c205fb, 0x201c0263, 0x44fb00c4, 0x00000000}},  //   _otom, _lavi_, tê_,
  { {0x76400036, 0x60c20146, 0x752201ed, 0x00000000}},  //   _domy, _ntom, gvoz,
  { {0x61e21e1e, 0x291901d5, 0x201c0d46, 0x00000000}},  //   _adol, _issa_, _navi_,
  { {0x394907b1, 0x661b11e8, 0x32060082, 0x00000000}},  //   lyas_, _tauk, _bboy_,
  { {0x60db03b6, 0x7640000a, 0x44fb00fa, 0x00000000}},  //   tsum, _gomy, pê_,
  { {0x201c037e, 0x0085007c, 0x39490b5a, 0x00000000}},  //   _bavi_, ллио, nyas_,
  { {0xf48401e0, 0x049505d4, 0x201c0197, 0x00000000}},  //   _кухн, _صلاح, _cavi_,
  { {0x60db002b, 0x201c00c4, 0x2efe0009, 0x00000000}},  //   ssum, _davi_, gttf_,
  { {0x64410388, 0x29190026, 0x39492dd5, 0x00000000}},  //   _holi, _ossa_, kyas_,
  { {0x644111e6, 0x60db002b, 0x60c20022, 0x00000000}},  //   _koli, qsum, _gtom,
  { {0x644100f4, 0x61e20871, 0x201c0026, 0x00000000}},  //   _joli, _zdol, _gavi_,
  { {0x6441021d, 0x09e601fb, 0x291900f8, 0x00000000}},  //   _moli, ловн, _assa_,
  { {0x224d0010, 0x00000000, 0x00000000, 0x00000000}},  //   nkek_,   ,   ,
  { {0x0e9b009b, 0x9e6500a1, 0x60c20ab4, 0x00000000}},  // [eae0] _אשקל, _خاون, _xtom,
  { {0x6441001e, 0x201c0129, 0x69cb000c, 0x00000000}},  //   _noli, _xavi_, ðger,
  { {0x2919251d, 0x764015b1, 0x224d0047, 0x00000000}},  //   _essa_, _pomy, kkek_,
  { {0xd01c0055, 0xdb1c0a2f, 0x31790036, 0x00000000}},  //   তায়_, rbrä, ższy_,
  { {0x64410018, 0x04460216, 0x660204be, 0x00000000}},  //   _boli, ледн, rfok,
  { {0x64413dea, 0x75220091, 0x29000020, 0x00000000}},  //   _coli, rvoz, mtia_,
  { {0x3d160309, 0x29000129, 0x201c006c, 0x00000000}},  //   _पैसे_, ltia_, _ravi_,
  { {0x779101ef, 0x99890180, 0x3a2001f3, 0x00000000}},  //   _بیما, ndaş_, ndip_,
  { {0x29003deb, 0x3014008b, 0xdb1c00c4, 0x00000000}},  //   ntia_, адпр, marõ,
  { {0x6441037e, 0x29000d53, 0xb4e00061, 0x00000000}},  //   _goli, itia_, थळी_,
  { {0xde590088, 0xa3c1006e, 0x290000b0, 0x00000000}},  //   вані_, ंडर_, htia_,
  { {0x78ae00d2, 0x64411422, 0x00000000, 0x00000000}},  //   _libv, _zoli,   ,
  { {0x60c20039, 0x201c01c5, 0x6441004a, 0x00000000}},  //   _utom, _tavi_, _yoli,
  { {0x64580011, 0x13d80044, 0x29191b61, 0x00000000}},  //   nhvi, _সাড়, _rssa_,
  { {0xce95005e, 0x2d84010f, 0xdb1c009d, 0x00000000}},  //   _какъ, ümer_, ncrè,
  { {0x39491e36, 0x00000000, 0x00000000, 0x00000000}},  //   tyas_,   ,   ,
  { {0x195827f9, 0x00000000, 0x00000000, 0x00000000}},  // [eaf0] гаты_,   ,   ,
  { {0x7d0d3dec, 0x39490173, 0x00000000, 0x00000000}},  //   _ipas, ryas_,   ,
  { {0x64410039, 0xdb1e029d, 0x29000cde, 0x00000000}},  //   _roli, _depó, atia_,
  { {0x2bbf02fb, 0x7d0d0022, 0x39490058, 0x00000000}},  //   ्रका, _kpas, pyas_,
  { {0x2900001a, 0xa3c1013d, 0x81da0044, 0x00000000}},  //   ctia_, ंडल_, ়লা_,
  { {0x80c30055, 0x68ed0b28, 0x7d0d00e7, 0x00000000}},  //   _শিল্, mrad, _mpas,
  { {0x64410868, 0x4255005e, 0xd3d80380, 0x00000000}},  //   _voli, итит, ابها_,
  { {0x7bd7164d, 0xc245003b, 0x7d0d0213, 0x00000000}},  //   _lexu, рник, _opas,
  { {0x644124f2, 0xe0d6045a, 0x68ed1218, 0x00000000}},  //   _toli, авы_, nrad,
  { {0x68ed00fa, 0x224d3ded, 0x3e6f00b0, 0x00000000}},  //   irad, skek_, yötä_,
  { {0x68ed004f, 0xd3710054, 0x7d0d2662, 0x00000000}},  //   hrad, _بها_, _apas,
  { {0xd1310054, 0x7529000a, 0x76590016, 0x00000000}},  //   _وما_, _krez, nhwy,
  { {0x66090007, 0x68ed0142, 0x463a0049, 0x00000000}},  //   _mbek, jrad, דערע,
  { {0x68ed1596, 0x60c922d7, 0x752904eb, 0x00000000}},  //   drad, mpem, _mrez,
  { {0x68ed00f8, 0xdb1e0181, 0x7d0d0d90, 0x00000000}},  //   erad, _repó, _epas,
  { {0x29000625, 0x68ed0016, 0xdb1c1059, 0x00000000}},  //   ttia_, frad, ncré,
  { {0x68ed0490, 0x98e60025, 0x99890477, 0x00000000}},  // [eb00] grad, شكاو, rdaş_,
  { {0x60c900f4, 0x29001a5d, 0xdb1e01aa, 0x00000000}},  //   ipem, rtia_, _depò,
  { {0x2900184d, 0x7bdc000d, 0x75290207, 0x00000000}},  //   stia_, maru, _arez,
  { {0x752901d9, 0x68ed029d, 0xa5260b11, 0x00000000}},  //   _brez, brad, имед,
  { {0x6891026c, 0x75293dee, 0x68ed0b33, 0x00000000}},  //   _کیلئ, _crez, crad,
  { {0x7bdc001a, 0x3ce9013d, 0xd90d0014, 0x00000000}},  //   naru, _जिसे_, _سیم_,
  { {0x66e3012b, 0x7529096e, 0xdb1e01aa, 0x00000000}},  //   _мора, _erez, _zepò,
  { {0x76590610, 0x7bdc04cb, 0x75291507, 0x00000000}},  //   chwy, haru, _frez,
  { {0x752915f8, 0xdb1c2902, 0x7aee0059, 0x00000000}},  //   _grez, scrè, hrbt,
  { {0xa2e60175, 0xcfa600e3, 0x7bdc1254, 0x00000000}},  //   _вожд, ишни, jaru,
  { {0x7d0d0119, 0x68ed0161, 0xb7db0049, 0x00000000}},  //   _spas, zrad, כקיי,
  { {0xe4db0224, 0xdceb0e0d, 0x6d22006e, 0x00000000}},  //   zšíř, šičn, मिंग_,
  { {0x7bdc3def, 0x224b01a2, 0x00000000, 0x00000000}},  //   faru, öcke_,   ,
  { {0x7c870364, 0x7bdc2c3c, 0x68ed00c4, 0x00000000}},  //   руме, garu, vrad,
  { {0xc5d70044, 0xaa67007e, 0x62470032, 0x00000000}},  //   _হাসপ, атак, _iñor,
  { {0x68ed0919, 0x0f57009b, 0x645d0006, 0x00000000}},  //   trad, _כיום_, _įsim,
  { {0x7d0d004e, 0x68ed06c0, 0x7bdc00e7, 0x00000000}},  // [eb10] _upas, urad, baru,
  { {0x7529008d, 0x7bdc001a, 0x6ab700ea, 0x00000000}},  //   _rrez, caru, _tuxf,
  { {0xd126089d, 0x68ed00f8, 0xfbd2009b, 0x00000000}},  //   _کم_, srad, _מתי_,
  { {0x68ed2a8c, 0x5695007c, 0x24590068, 0x00000000}},  //   prad, щает, _mème_,
  { {0xe570023c, 0x7af52431, 0xf8bf0d7f, 0x00000000}},  //   وطه_, luzt, _krém_,
  { {0x58d40131, 0x75290dd0, 0x00000000, 0x00000000}},  //   _форт, _vrez,   ,
  { {0x03a50194, 0x7af50032, 0x00000000, 0x00000000}},  //   щико, nuzt,   ,
  { {0x7529001a, 0x07d800a1, 0x7bdc064f, 0x00000000}},  //   _trez, _مذہب_, zaru,
  { {0x0fd9045a, 0x60c92a41, 0x7bdc00a9, 0x00000000}},  //   льны_, upem, yaru,
  { {0xdb1c009d, 0x60c9188a, 0x00000000, 0x00000000}},  //   scré, rpem,   ,
  { {0x7bdc001a, 0x339501b7, 0x0eaa01ab, 0x00000000}},  //   varu, _الاز, лкой_,
  { {0x60c9028c, 0x7bdc0020, 0x6284016c, 0x00000000}},  //   ppem, waru, čioc,
  { {0x7bdc1c68, 0x645d007f, 0x00000000, 0x00000000}},  //   taru, _įsij,   ,
  { {0x9f5e0861, 0x2459000a, 0x0c7901ab, 0x00000000}},  //   letý_, _fème_, ассы_,
  { {0x2002005f, 0x7bdc33c8, 0x00000000, 0x00000000}},  //   əki_, raru,   ,
  { {0x7bdc001a, 0xc33200b6, 0xe8e00011, 0x00000000}},  //   saru, הול_, _suốt_,
  { {0x7bdc01a3, 0x6aa43df0, 0x00000000, 0x00000000}},  // [eb20] paru, rmif,   ,
  { {0xe73a00da, 0x00000000, 0x00000000, 0x00000000}},  //   лез_,   ,   ,
  { {0xbc68026c, 0xfa6a004c, 0x648d0051, 0x00000000}},  //   _مجھے_, _банк_, húis,
  { {0x54e60025, 0x00000000, 0x00000000, 0x00000000}},  //   مستق,   ,   ,
  { {0xd6250054, 0xe8e00082, 0x00000000, 0x00000000}},  //   تعلي, _tuốt_,   ,
  { {0x6846026b, 0xe8560188, 0x53342bda, 0x00000000}},  //   _унга, _انسد, жект,
  { {0xe3b200a1, 0x8c1b0104, 0x00000000, 0x00000000}},  //   _ہرا_, רוצי,   ,
  { {0x3ce903d7, 0xd2570147, 0x00000000, 0x00000000}},  //   _जिले_, йцы_,   ,
  { {0xdfd00054, 0x6fe20224, 0xb6a32d6f, 0x00000000}},  //   وية_, jící, _хитл,
  { {0xdce40089, 0x50b70025, 0xe1f90006, 0x00000000}},  //   _dziļ, حديد_, agų_,
  { {0xe2ca0265, 0x20020046, 0x9e1501ff, 0x00000000}},  //   _след_, ęki_, одні,
  { {0x3ea00082, 0x539b00b3, 0x877b0097, 0x00000000}},  //   _chit_, _גיבו, ראטי,
  { {0xbd6b003b, 0x00000000, 0x00000000, 0x00000000}},  //   урне_,   ,   ,
  { {0x7af5022b, 0x645d0006, 0x99890059, 0x00000000}},  //   tuzt, _įsik, tjaž_,
  { {0x22460007, 0x00000000, 0x00000000, 0x00000000}},  //   _kook_,   ,   ,
  { {0x78ba00b9, 0x2246010e, 0x00000000, 0x00000000}},  //   _čtvr, _jook_,   ,
  { {0x224600d9, 0x290f0115, 0x00000000, 0x00000000}},  // [eb30] _mook_, ïga_,   ,
  { {0x22460038, 0x26130011, 0x44d60036, 0x00000000}},  //   _look_, _ảo_, dł_,
  { {0x6d4f103b, 0x625c00f4, 0xb09b009b, 0x00000000}},  //   lyca, _géog, ניבר,
  { {0x3e7201a8, 0x9f5e0325, 0x7e6f0068, 0x00000000}},  //   pšte_, letó_, nicp,
  { {0x26c70964, 0x6d4f02d4, 0x2d800068, 0x00000000}},  //   ūno_, nyca, _xxie_,
  { {0x386a0145, 0x00000000, 0x00000000, 0x00000000}},  //   _gmbr_,   ,   ,
  { {0x44d60046, 0x22460038, 0x2a6b0022, 0x00000000}},  //   ał_, _book_, _kmcb_,
  { {0xe1f9010a, 0x69df0065, 0x2246235a, 0x00000000}},  //   ugų_, naqe, _cook_,
  { {0x212b3df1, 0xe1f90006, 0x22460bca, 0x00000000}},  //   ích_, rgų_, _dook_,
  { {0x3ea01d32, 0x9477004b, 0x648d0051, 0x00000000}},  //   _shit_, _ادرا, rúis,
  { {0xe80b007d, 0x5334022a, 0x69df0065, 0x00000000}},  //   स्या_, _нефт, kaqe,
  { {0xa6e2000c, 0x7bc50bc7, 0x00000000, 0x00000000}},  //   æðil, _afhu,   ,
  { {0x80c30055, 0xafe5007c, 0x625c009d, 0x00000000}},  //   _শিক্, _долл, _déod,
  { {0xf1b20097, 0xdb0a0062, 0x7ae50082, 0x00000000}},  //   _חסד_, žník, _bvht,
  { {0x69df0065, 0x3ea03df2, 0x6fe200b9, 0x00000000}},  //   faqe, _thit_, sící,
  { {0x31af0279, 0x3ced04eb, 0x6d4f013f, 0x00000000}},  //   _gözü_, ševa_, byca,
  { {0x2d8000d9, 0x00000000, 0x00000000, 0x00000000}},  // [eb40] _uxie_,   ,   ,
  { {0x6e2400e7, 0x7d040066, 0x00000000, 0x00000000}},  //   _haib, _iqis,   ,
  { {0x2bd0001c, 0x6e24006a, 0x7794025a, 0x00000000}},  //   _त्या, _kaib, سیرا,
  { {0xb87b000c, 0x452a0478, 0xd378012d, 0x00000000}},  //   _hvíl, ижен_, _jeće_,
  { {0x22460007, 0x6e24011c, 0xe4a60140, 0x00000000}},  //   _rook_, _maib, орко,
  { {0xd4d9008b, 0x68e40073, 0xc1d20204, 0x00000000}},  //   сьці_, msid, सर्ग,
  { {0xd25a10d8, 0x68e40056, 0x2246011c, 0x00000000}},  //   ици_, lsid, _pook_,
  { {0xd3780119, 0x61fb023a, 0x69c401cb, 0x00000000}},  //   _neće_, ggul, ncie,
  { {0x733600a1, 0x22b50089, 0x601f007f, 0x00000000}},  //   _ڈرائ, _sākt_, kšmė,
  { {0x31af005d, 0x6e360133, 0x61fb00e5, 0x00000000}},  //   _sözü_, _anyb, agul,
  { {0x381700b6, 0x68e40146, 0x22462f94, 0x00000000}},  //   חקים_, hsid, _took_,
  { {0x644829e4, 0x6e240051, 0x69c40036, 0x00000000}},  //   _hodi, _caib, jcie,
  { {0x61e0014a, 0x7e6f00f6, 0x6448086a, 0x00000000}},  //   maml, ricp, _kodi,
  { {0x64480520, 0x68e40292, 0xd00f0025, 0x00000000}},  //   _jodi, dsid, _لله_,
  { {0x6e2400f4, 0x9f5e02a0, 0x26d800d9, 0x00000000}},  //   _faib, retó_, _nwro_,
  { {0xddc4011f, 0xfbd000a1, 0x6d4f098e, 0x00000000}},  //   _iliş, فتہ_, pyca,
  { {0x69df0065, 0x68e40030, 0x7bc50009, 0x00000000}},  // [eb50] raqe, gsid, _tfhu,
  { {0x6448049b, 0x61e0006b, 0x6e243df3, 0x00000000}},  //   _nodi, haml, _zaib,
  { {0x87e40057, 0xe3d80044, 0x501b009b, 0x00000000}},  //   ьюте, _সাংব, שובו,
  { {0x68e43df4, 0x69c416df, 0x645a3df5, 0x00000000}},  //   bsid, ccie, _alti,
  { {0x672e0073, 0x26d81d34, 0x7c25014a, 0x00000000}},  //   _erbj, _ewro_, _kahr,
  { {0x7c25001f, 0x64480198, 0xe787003b, 0x00000000}},  //   _jahr, _codi, _дубо,
  { {0x69dd020c, 0xd6c301ef, 0x62840b4d, 0x00000000}},  //   _kese, _آمری, čion,
  { {0x6b7c0097, 0x645a1ae2, 0xe0d9007c, 0x00000000}},  //   ירונ, _elti, бви_,
  { {0x69dd1b83, 0x6e24002a, 0x41b5026c, 0x00000000}},  //   _mese, _raib, _ہمار,
  { {0x64480119, 0x69dd001f, 0x7c250161, 0x00000000}},  //   _godi, _lese, _nahr,
  { {0x69c40036, 0xa207005d, 0x6e240058, 0x00000000}},  //   ycie, şmış_, _paib,
  { {0x69dd0263, 0x44250149, 0x644824b7, 0x00000000}},  //   _nese, _hal_, _zodi,
  { {0x44250f99, 0x7c2501a3, 0xd3780091, 0x00000000}},  //   _kal_, _bahr, _veće_,
  { {0xdb1c3df6, 0xb042001d, 0x44253b6d, 0x00000000}},  //   scrí, _thưở, _jal_,
  { {0x69dd3df7, 0x765b011f, 0x09b40164, 0x00000000}},  //   _bese, _oluy, ंख्य,
  { {0x78b5001e, 0x69dd2b75, 0x68e406d7, 0x00000000}},  //   _aizv, _cese, tsid,
  { {0x69dd0576, 0x7c25001f, 0x69c400f4, 0x00000000}},  // [eb60] _dese, _fahr, rcie,
  { {0x68e4068f, 0x69c40207, 0x397901fb, 0x00000000}},  //   rsid, scie, істю_,
  { {0x64480428, 0x68e4003a, 0x61eb0107, 0x00000000}},  //   _rodi, ssid, _odgl,
  { {0x644801d9, 0x69dd12e3, 0x7c25004f, 0x00000000}},  //   _sodi, _gese, _zahr,
  { {0x442501aa, 0x64480466, 0x7bde020c, 0x00000000}},  //   _bal_, _podi, _kepu,
  { {0x442504bd, 0x66e60175, 0x6abe01a2, 0x00000000}},  //   _cal_, _нога, _kupf,
  { {0x44250198, 0x765b008e, 0x61e00095, 0x00000000}},  //   _dal_, _fluy, taml,
  { {0x7bde3df8, 0xcb1300b3, 0x4427004a, 0x00000000}},  //   _lepu, גלה_, adn_,
  { {0x44250065, 0x644800b0, 0x61e01fe3, 0x00000000}},  //   _fal_, _todi, raml,
  { {0x4425010a, 0x645a1d28, 0x61e0030e, 0x00000000}},  //   _gal_, _ulti, saml,
  { {0x3de10044, 0x00000000, 0x00000000, 0x00000000}},  //   _ভাবল,   ,   ,
  { {0x44253df9, 0x7c25037e, 0x61e0006b, 0x00000000}},  //   _zal_, _sahr, qaml,
  { {0x44250173, 0x7c250022, 0x7bde01c3, 0x00000000}},  //   _yal_, _pahr, _bepu,
  { {0x69dd027e, 0x7bde0089, 0x78bd3dfa, 0x00000000}},  //   _sese, _cepu, _rusv,
  { {0x7bde028c, 0x69dd0149, 0x9f6200b0, 0x00000000}},  //   _depu, _pese, ävän_,
  { {0x7c25010f, 0x7e6d0058, 0x58d90a1e, 0x00000000}},  //   _wahr, _umap, ждая_,
  { {0x69dd001e, 0x44271014, 0xf4d70044, 0x00000000}},  // [eb70] _vese, ydn_, _সম্ব,
  { {0x69dd3dfb, 0x7bde15bd, 0x6abe0146, 0x00000000}},  //   _wese, _gepu, _fupf,
  { {0x442500d4, 0x7e7d2201, 0xe7190025, 0x00000000}},  //   _ral_, onsp, تيات_,
  { {0x44251273, 0x7e7d1b7b, 0xa3cf0061, 0x00000000}},  //   _sal_, nnsp, वुन_,
  { {0x3a393dfc, 0x78b501f3, 0x00000000, 0x00000000}},  //   _insp_, _tizv,   ,
  { {0x442501d5, 0xa493025a, 0x3a290058, 0x00000000}},  //   _qal_, ریات, ldap_,
  { {0x4425010a, 0x290900b0, 0x225f0022, 0x00000000}},  //   _val_, ltaa_, thuk_,
  { {0x56940099, 0x44250016, 0x44273dfd, 0x00000000}},  //   _заст, _wal_, sdn_,
  { {0x442502c0, 0x2909021e, 0x0019007e, 0x00000000}},  //   _tal_, ntaa_, оўны_,
  { {0xaec5025f, 0x7860005a, 0x8ee901ab, 0x00000000}},  //   мбол, _gövd, омов_,
  { {0x2909021e, 0xddc43dfe, 0x3ce9000a, 0x00000000}},  //   htaa_, _amiš, _avav_,
  { {0x1ee7026c, 0x7bde0169, 0xdb1c01a2, 0x00000000}},  //   _ہوتی_, _sepu, rbrü,
  { {0x2d840189, 0x212f0544, 0x7bde17f6, 0x00000000}},  //   çme_, _urgh_, _pepu,
  { {0x78600047, 0x7e7d3dff, 0x395200b0, 0x00000000}},  //   _köve, ansp, vyys_,
  { {0x41d10183, 0xab27025f, 0x78600010, 0x00000000}},  //   _सभास, мора_, _jöve,
  { {0xe80b006e, 0x00000000, 0x00000000, 0x00000000}},  //   स्सा_,   ,   ,
  { {0x4c86034b, 0x7bde04cb, 0x2a600022, 0x00000000}},  // [eb80] _олив, _tepu, rhib_,
  { {0x39403e00, 0x3a3900fa, 0x00000000, 0x00000000}},  //   rxis_, _ensp_,   ,
  { {0xb6c50106, 0x78600047, 0xdb1c03df, 0x00000000}},  //   есій, _növe, rbró,
  { {0x7afc014a, 0xf8bf008e, 0x00000000, 0x00000000}},  //   murt, _fué_,   ,
  { {0x1fe30044, 0x94aa0069, 0x69d62a2b, 0x00000000}},  //   _মানস, отка_, mbye,
  { {0xa6e2000c, 0x3e720006, 0xd5fb0082, 0x00000000}},  //   æðsl, kšto_, _phụ,
  { {0xe2c70025, 0x645d0006, 0x7afc0288, 0x00000000}},  //   وووو_, _įsit, nurt,
  { {0xc7a301e0, 0x69d601aa, 0x7217005e, 0x00000000}},  //   _риск, nbye, джър_,
  { {0xf5030265, 0x7afc3e01, 0x00000000, 0x00000000}},  //   _изто, hurt,   ,
  { {0x7afc3e02, 0xc0570088, 0xe802007d, 0x00000000}},  //   kurt, дію_, र्चा_,
  { {0xe810001c, 0xddc404eb, 0x645802e7, 0x00000000}},  //   ठ्या_, _smiš, mkvi,
  { {0x7afc3e03, 0x645800f8, 0xc7b3009b, 0x00000000}},  //   durt, lkvi, כבת_,
  { {0x50660517, 0xed58008b, 0x7e7d0210, 0x00000000}},  //   _отка, доў_, rnsp,
  { {0xe5710049, 0x7afc01a2, 0xd6df0036, 0x00000000}},  //   אַל_, furt, ółka_,
  { {0x7afc1692, 0xa2d20061, 0x9e67006d, 0x00000000}},  //   gurt, णीच्, _يابن,
  { {0x29090f3c, 0x7860005f, 0x68f60016, 0x00000000}},  //   ttaa_, _növb, fryd,
  { {0xf8bf0219, 0xa3cf03d7, 0xddc40243, 0x00000000}},  // [eb90] _qué_, वुड_, _umiš,
  { {0x7afc010f, 0x2909021e, 0x7ac7003b, 0x00000000}},  //   burt, rtaa_, _осме,
  { {0x8bd600b6, 0x0c740b59, 0x2909021e, 0x00000000}},  //   _אותו_, _جديد, staa_,
  { {0xfe100011, 0x68f63e04, 0xf8bf009d, 0x00000000}},  //   _lắng_, bryd, _tué_,
  { {0xe5040025, 0x6aad00f8, 0xceb4009b, 0x00000000}},  //   نبوي, mmaf, דיף_,
  { {0xfe100011, 0xd3780521, 0x03a5007c, 0x00000000}},  //   _nắng_, _seća_, нило,
  { {0xc6060044, 0x00000000, 0x00000000, 0x00000000}},  //   োয়া_,   ,   ,
  { {0x65950088, 0xfbb8009b, 0x628201c3, 0x00000000}},  //   _забу, ופות_, _cjoo,
  { {0xd3780091, 0x60cd002b, 0x7afc0032, 0x00000000}},  //   _veća_, _ħams, zurt,
  { {0x6458098e, 0x60090175, 0xf1b9016c, 0x00000000}},  //   ckvi, чном_, deše_,
  { {0xbcfb0047, 0xe3b3002c, 0x7d1601d6, 0x00000000}},  //   szél, _شرط_, _spys,
  { {0x3f990089, 0x3e72007f, 0x00000000, 0x00000000}},  //   āsu_, ršto_,   ,
  { {0xee37005e, 0x00000000, 0x00000000, 0x00000000}},  //   хня_,   ,   ,
  { {0x7afc0089, 0xe00603d7, 0x7860006b, 0x00000000}},  //   turt, _शायद_, _mövc,
  { {0x6fd500e8, 0x3f790049, 0xf99f00f6, 0x00000000}},  //   _म्यू, _מאַס, _obès_,
  { {0x3dda0055, 0x2bd00164, 0x68f63e05, 0x00000000}},  //   _থাকল, _त्रा, tryd,
  { {0xe8fa007e, 0x65b60477, 0x6a8305f6, 0x00000000}},  // [eba0] яла_, _mühü, улта,
  { {0x7afc36ee, 0xb8820428, 0x68f602e7, 0x00000000}},  //   purt, _čísl, rryd,
  { {0xe61a0cee, 0x00000000, 0x00000000, 0x00000000}},  //   зде_,   ,   ,
  { {0x550600e2, 0xcf920049, 0x00000000, 0x00000000}},  //   ечка, נטא_,   ,
  { {0xd5e700a1, 0xad9b004a, 0xbebc0089, 0x00000000}},  //   رٹون_, lfúr, lvīt,
  { {0x04430517, 0xd467017f, 0xdceb11af, 0x00000000}},  //   лечн, ниче_, šićn,
  { {0xc795008b, 0x6458037d, 0x625c009d, 0x00000000}},  //   _арты, rkvi, _déon,
  { {0xa50a0816, 0x179b0097, 0xf8bf0082, 0x00000000}},  //   _неба_, _זילב, _trét_,
  { {0xe0cf0167, 0x00000000, 0x00000000, 0x00000000}},  //   یزی_,   ,   ,
  { {0x66020010, 0x00000000, 0x00000000, 0x00000000}},  //   lgok,   ,   ,
  { {0x81df08b7, 0x1df90147, 0xfe100011, 0x00000000}},  //   _তার_, мены_, _vắng_,
  { {0x66022092, 0x628d012d, 0x00000000, 0x00000000}},  //   ngok, čaoc,   ,
  { {0xfe6e089d, 0xf1b9016c, 0xc05a0451, 0x00000000}},  //   تگو_, teše_, _нік_,
  { {0x61e231f0, 0x00000000, 0x00000000, 0x00000000}},  //   _heol,   ,   ,
  { {0x60c2021e, 0x0b88007c, 0xab95019d, 0x00000000}},  //   _huom, ести_, тиві,
  { {0x201e0047, 0x60c20020, 0x66e701dc, 0x00000000}},  //   leti_, _kuom, _léká,
  { {0x60c200b0, 0xf1b9016c, 0x62800145, 0x00000000}},  // [ebb0] _juom, peše_, inmo,
  { {0x61e20016, 0x628001a2, 0x60c200e7, 0x00000000}},  //   _leol, hnmo, _muom,
  { {0x998010c1, 0x60c200b0, 0xf8bf009d, 0x00000000}},  //   rdiš_, _luom, _prés_,
  { {0xfb1a009c, 0xd57509b5, 0x201e0010, 0x00000000}},  //   _کریں_, куль, heti_,
  { {0x201e3e06, 0x60c2010a, 0x5a34007c, 0x00000000}},  //   keti_, _nuom, _снят,
  { {0x201e0209, 0x3ea90058, 0x628000d9, 0x00000000}},  //   jeti_, _lhat_, enmo,
  { {0xf8bf00f4, 0xe784005e, 0x5c38009b, 0x00000000}},  //   _trés_, _буто, תרון_,
  { {0x3ea90011, 0x61e20051, 0x629b3e07, 0x00000000}},  //   _nhat_, _ceol, uluo,
  { {0xd24e006d, 0x60c20912, 0x201e02ba, 0x00000000}},  //   تني_, _cuom, feti_,
  { {0x8574008b, 0x60c23e08, 0x201e1403, 0x00000000}},  //   _слух, _duom, geti_,
  { {0x3ea901f3, 0x200b0036, 0xd4360049, 0x00000000}},  //   _bhat_, ęci_, _שרעק_,
  { {0x27e301d5, 0x26c3016e, 0x325500ec, 0x00000000}},  //   _lejn_, _mujo_, _швер,
  { {0x26c30211, 0x26fe013d, 0x201e333e, 0x00000000}},  //   _lujo_, _उम्र_, beti_,
  { {0x201e001a, 0x68ff006b, 0x224f01c3, 0x00000000}},  //   ceti_, duqd, _hogk_,
  { {0x09e6025f, 0xfe0a03d7, 0xeb9701ee, 0x00000000}},  //   ковн, _वापस_, вир_,
  { {0xc332009b, 0x3ea9002b, 0xc0b900b9, 0x00000000}},  //   סון_, _ghat_, řádá,
  { {0x27e301d5, 0x26d1002d, 0x81b30044, 0x00000000}},  // [ebc0] _bejn_, _atzo_, জুর_,
  { {0x3cfb00a0, 0xbc6a02fd, 0xed57009b, 0x00000000}},  //   _קלינ, _آمدن_, _סביר_,
  { {0x7c3e002d, 0x26c30181, 0x645d0006, 0x00000000}},  //   _inpr, _cujo_, _įsip,
  { {0x201e0924, 0x3ce001aa, 0x7c2e01a2, 0x00000000}},  //   zeti_, _kwiv_, ldbr,
  { {0x27e301d5, 0x61e233a1, 0x201e014a, 0x00000000}},  //   _fejn_, _reol, yeti_,
  { {0x61e23e09, 0x29000020, 0x26c30020, 0x00000000}},  //   _seol, muia_, _fujo_,
  { {0x60c2021e, 0x201e0229, 0x290020c2, 0x00000000}},  //   _suom, veti_, luia_,
  { {0x78bc00b0, 0x625c009d, 0x3ced0ecc, 0x00000000}},  //   _hirv, _géol, ševi_,
  { {0x201e1d24, 0x628000f8, 0x78bc0052, 0x00000000}},  //   teti_, rnmo, _kirv,
  { {0xb42500a6, 0x27e301d5, 0x3ea92a2b, 0x00000000}},  //   _معمو, _xejn_, _shat_,
  { {0x443e01d5, 0x442c002a, 0x6f0a0061, 0x00000000}},  //   _int_, _iad_, _qqfc,
  { {0x442c0f44, 0x60c22334, 0x201e3e0a, 0x00000000}},  //   _had_, _tuom, seti_,
  { {0x442c0b53, 0xc693009b, 0x443e0146, 0x00000000}},  //   _kad_, שאר_, _knt_,
  { {0x3ea90038, 0x442c0d6b, 0xd0100355, 0x00000000}},  //   _what_, _jad_, _طلب_,
  { {0x3ea90a8a, 0xefb00014, 0x443e006c, 0x00000000}},  //   _that_, _دیدگ, _mnt_,
  { {0x442c0030, 0x7c3e3e0b, 0x32041c66, 0x00000000}},  //   _lad_, _enpr, ngmy_,
  { {0x443e3e0c, 0x2d8f00f4, 0x2900050b, 0x00000000}},  // [ebd0] _ont_, _âge_, guia_,
  { {0xf1b908ad, 0x443e01a3, 0x7d0d0066, 0x00000000}},  //   neša_, _nnt_, _iqas,
  { {0x442e018e, 0x6e2d17f6, 0x78bc0419, 0x00000000}},  //   ddf_, _kaab, _dirv,
  { {0x443e33bb, 0x442c00bb, 0x79a700ed, 0x00000000}},  //   _ant_, _aad_, _арге,
  { {0x6e2d036b, 0x442c192b, 0x443e14ad, 0x00000000}},  //   _maab, _bad_, _bnt_,
  { {0x442c002a, 0x81df0055, 0x443e15e0, 0x00000000}},  //   _cad_, _তাই_, _cnt_,
  { {0xe2993e0d, 0x68ed21e9, 0x442c0787, 0x00000000}},  //   нак_, lsad, _dad_,
  { {0x443e006c, 0x6e2d3e0e, 0x78bc0279, 0x00000000}},  //   _ent_, _naab, _zirv,
  { {0x6abd004e, 0x442c002a, 0x26080061, 0x00000000}},  //   _misf, _fad_, _हाती_,
  { {0x442c01aa, 0x68ed0181, 0x799d0022, 0x00000000}},  //   _gad_, isad, _mysw,
  { {0x5f05008b, 0x3ce00263, 0x29000020, 0x00000000}},  //   ызна, _swiv_, zuia_,
  { {0x68ed0039, 0x442c0baf, 0x6abd3e0f, 0x00000000}},  //   ksad, _zad_, _nisf,
  { {0x443e014a, 0x442c006b, 0x3e620048, 0x00000000}},  //   _ynt_, _yad_, _cóta_,
  { {0xab2a06f3, 0x69cf00d9, 0x7e660023, 0x00000000}},  //   нога_, _afce, shkp,
  { {0x6609037e, 0x6eca02fb, 0x7c2e01c9, 0x00000000}},  //   _ocek, _संयु, rdbr,
  { {0x78bc0211, 0x61e90020, 0x8f9a00a0, 0x00000000}},  //   _sirv, nael, _איצי,
  { {0x6abd0211, 0x7e640e1a, 0x799d0016, 0x00000000}},  // [ebe0] _disf, _ilip, _cysw,
  { {0x61e9001a, 0x20053886, 0x20c90011, 0x00000000}},  //   hael, ngli_, _múi_,
  { {0x442c17cf, 0x7bdc1dd4, 0x7529001a, 0x00000000}},  //   _rad_, mbru, _asez,
  { {0x7bdc00ea, 0xb87b00b9, 0x6b7b01ce, 0x00000000}},  //   lbru, _svít, _טרינ,
  { {0x442c0343, 0x29000325, 0x20c90011, 0x00000000}},  //   _pad_, quia_, _núi_,
  { {0x7bdc0c53, 0x443e0026, 0x6299000a, 0x00000000}},  //   nbru, _qnt_, _akwo,
  { {0x442c0073, 0x443e0006, 0x628d016c, 0x00000000}},  //   _vad_, _vnt_, čaon,
  { {0x3254017a, 0x442c22df, 0x82a6007c, 0x00000000}},  //   рвир, _wad_, ышле,
  { {0x442c2e42, 0x443e05f2, 0x6e2d0240, 0x00000000}},  //   _tad_, _tnt_, _raab,
  { {0xdefa04af, 0x7e64000b, 0x443e18be, 0x00000000}},  //   ным_, _alip, _unt_,
  { {0x7bdc068f, 0x4ab40061, 0x7e6400b4, 0x00000000}},  //   dbru, ंगाव, _blip,
  { {0x7e64001c, 0x6e950088, 0x61e9014a, 0x00000000}},  //   _clip, риму, cael,
  { {0x22930054, 0xf1b9016c, 0x00000000, 0x00000000}},  //   _النس, peša_,   ,
  { {0x3e620051, 0x7e640253, 0x7bdc0056, 0x00000000}},  //   _vóta_, _elip, gbru,
  { {0x309b00b6, 0x6f01058b, 0x6e2d0020, 0x00000000}},  //   _רשומ, culc, _taab,
  { {0x7e6401d6, 0x68ed29f9, 0x5bb8007c, 0x00000000}},  //   _glip, tsad, улся_,
  { {0x987500c0, 0x7afc0051, 0x9f4501ca, 0x00000000}},  // [ebf0] алац, arrt, valé_,
  { {0x68ed0010, 0x660901ee, 0x2c663c2c, 0x00000000}},  //   rsad, _scek, _pôde_,
  { {0x68ed02d5, 0x97a70269, 0x7e6400b0, 0x00000000}},  //   ssad, урал, _ylip,
  { {0x68ed00f8, 0xa53506e3, 0x5695007c, 0x00000000}},  //   psad, инеч, шает,
  { {0xd126039d, 0x58870783, 0x3e72016c, 0x00000000}},  //   _بم_, _быва, ušti_,
  { {0xa879007b, 0xc48401e1, 0x61e90020, 0x00000000}},  //   _יאָר, блік, wael,
  { {0x61e93e10, 0x9f51005d, 0x7860013f, 0x00000000}},  //   tael, üzü_, _mövl,
  { {0x3e7201ee, 0x2ce5006e, 0x00000000, 0x00000000}},  //   pšti_, _कबूल_,   ,
  { {0x7bdc00eb, 0xe66402b8, 0x00000000, 0x00000000}},  //   ybru, _утро,   ,
  { {0x39492e19, 0x205501e0, 0x2a690022, 0x00000000}},  //   ixas_, ртир, hhab_,
  { {0x8fa50081, 0xfe46007c, 0x20050207, 0x00000000}},  //   ране, анно, rgli_,
  { {0xed5a0437, 0x20c9001d, 0x00000000, 0x00000000}},  //   вом_, _túi_,   ,
  { {0xc0e505b5, 0xa696009b, 0x7bdc0190, 0x00000000}},  //   _толк, שכרה_, tbru,
  { {0x6f013000, 0x224d3e11, 0xdde50089, 0x00000000}},  //   pulc, ljek_, āpša,
  { {0x7860005f, 0xddcd011f, 0xf99f0173, 0x00000000}},  //   _dövl, _ulaş, _ayè_,
  { {0x7bdc05a6, 0x7e640020, 0x3b0700ed, 0x00000000}},  //   sbru, _ulip, јето_,

  { {0x7bdc043e, 0x00000000, 0x00000000, 0x00000000}},  // [ec00] pbru,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x75e6008b, 0xbb460545, 0x8d8502fd, 0x00000000}},  //   аўле, _тенк, _نشین,
  { {0xeabf0207, 0x644105b4, 0x2a69000a, 0x00000000}},  //   _giù_, _anli, chab_,
  { {0x9633008b, 0xe5340b52, 0xf9920688, 0x00000000}},  //   ўніц, сель, _ذبح_,
  { {0xb60200b9, 0x5497007e, 0xddcd01ee, 0x00000000}},  //   _řádk, авіў_, _mmaš,
  { {0x24800091, 0x00000000, 0x00000000, 0x00000000}},  //   đim_,   ,   ,
  { {0xd257007c, 0xddcd016c, 0x64410aa4, 0x00000000}},  //   ицы_, _omaš, _enli,
  { {0x81e80044, 0x26da00b0, 0x291208e3, 0x00000000}},  //   _বাদ_, lppo_, ntya_,
  { {0x32ca0011, 0x2018000c, 0x200a12b6, 0x00000000}},  //   _tùy_, ýri_, übi_,
  { {0x50b70054, 0x224d003f, 0xb80b013d, 0x00000000}},  //   جديد_, bjek_, स्टम_,
  { {0x6284007f, 0x00000000, 0x00000000, 0x00000000}},  //   čios,   ,   ,
  { {0x39490860, 0x00000000, 0x00000000, 0x00000000}},  //   xxas_,   ,   ,
  { {0xa067003b, 0x00000000, 0x00000000, 0x00000000}},  //   _ваља_,   ,   ,
  { {0xeabf05d3, 0xdb580057, 0xee87007c, 0x00000000}},  //   _più_, ают_, _выпо,
  { {0xf99f01aa, 0x8f9b009b, 0x59f8007c, 0x00000000}},  //   _pyè_, _שיהי, иеся_,
  { {0x7e7d03b6, 0x9f4700fa, 0x00000000, 0x00000000}},  // [ec10] misp, _nenê_,   ,
  { {0x1c160061, 0x7e7d006c, 0x2a691856, 0x00000000}},  //   द्दल_, lisp, shab_,
  { {0x6d5d0056, 0xc5d501e1, 0x00000000, 0x00000000}},  //   lysa, біль,   ,
  { {0x7e7d0020, 0x00000000, 0x00000000, 0x00000000}},  //   nisp,   ,   ,
  { {0x224d0363, 0xbcfb0010, 0x6d5d060a, 0x00000000}},  //   vjek_, mzés, nysa,
  { {0x7e7d3b5d, 0xbcfb0010, 0x24090088, 0x00000000}},  //   hisp, lzés, унки_,
  { {0x7e7d0052, 0x7ebf0089, 0xf8b200a0, 0x00000000}},  //   kisp, _rūpn, _משך_,
  { {0xc245012b, 0x5694008b, 0xcfe30044, 0x00000000}},  //   сник, _даст, _মাইন,
  { {0x7e7d1017, 0x661b023a, 0xa1120025, 0x00000000}},  //   disp, _ibuk, كويت,
  { {0x44230047, 0x753b022b, 0xf0650888, 0x00000000}},  //   _új_, _iruz, скоп,
  { {0x54340167, 0xe8190309, 0x2054005e, 0x00000000}},  //   _برقر, न्या_, ютър,
  { {0x753b041a, 0x6ed30035, 0x00000000, 0x00000000}},  //   _kruz, _răbd,   ,
  { {0xd3780119, 0x9f470065, 0xd24e009e, 0x00000000}},  //   _reći_, _kenë_, _سنو_,
  { {0x9f470065, 0xc0b20011, 0x63a12096, 0x00000000}},  //   _jenë_, _mười_, _kyln,
  { {0xcaa60025, 0x7e7d0b33, 0x661b3e12, 0x00000000}},  //   مصري, bisp, _obuk,
  { {0x753b0107, 0x6d5d0190, 0x6aaf0009, 0x00000000}},  //   _oruz, bysa, _chcf,
  { {0x2f110047, 0xd3780091, 0x39460181, 0x00000000}},  // [ec20] lág_, _veći_, ãos_,
  { {0x7d06021e, 0x29120010, 0x2a6027ac, 0x00000000}},  //   muks, rtya_, skib_,
  { {0x29123e13, 0x81e80044, 0x7d0600b0, 0x00000000}},  //   stya_, _বাস_, luks,
  { {0x69da001a, 0x753b1669, 0x00000000, 0x00000000}},  //   _ştef, _bruz,   ,
  { {0xc0b2001d, 0x753b029d, 0x893601d8, 0x00000000}},  //   _cười_, _cruz, _اعجا,
  { {0x753b016c, 0xf7460081, 0x00000000, 0x00000000}},  //   _druz, _лего,   ,
  { {0x753b0197, 0xf48700a6, 0x7d060961, 0x00000000}},  //   _eruz, حانی, huks,
  { {0x60f801be, 0x29000181, 0xd251026c, 0x00000000}},  //   ания_, oria_, ِنٹ_,
  { {0x26ca0211, 0xc05a01e1, 0x05663e14, 0x00000000}},  //   _hubo_, гін_, _уван,
  { {0x7d060d4b, 0x26ca0178, 0x661b15e7, 0x00000000}},  //   duks, _kubo_, _zbuk,
  { {0x6aa40279, 0x389b0097, 0x889b0097, 0x00000000}},  //   klif, ריינ, רביי,
  { {0x6e670265, 0x6d5d00b0, 0x9f47000a, 0x00000000}},  //   стож, tysa, _menè_,
  { {0x7e7d1529, 0xa3cf01f5, 0x09e70044, 0x00000000}},  //   risp, वुक_, _ফালা,
  { {0x26d80b2f, 0x29003e15, 0x6d5d04dc, 0x00000000}},  //   _otro_, dria_, rysa,
  { {0xf3f10011, 0x307b009b, 0x00000000, 0x00000000}},  //   _học_, _תאונ,   ,
  { {0x2bd902d2, 0x38c904e1, 0x29003e16, 0x00000000}},  //   _ब्रा, لائی_, fria_,
  { {0x290009f7, 0xbcfb0010, 0xdd9103ec, 0x00000000}},  // [ec30] gria_, rzés, _زود_,
  { {0x753b0023, 0x9f470173, 0x00000000, 0x00000000}},  //   _rruz, _benè_,   ,
  { {0x29000207, 0xbcfb0010, 0x8a19005c, 0x00000000}},  //   aria_, pzés, _конс_,
  { {0x753b057c, 0x29003e17, 0x7c270190, 0x00000000}},  //   _pruz, bria_, lejr,
  { {0x2f110047, 0x672e0030, 0x81c30044, 0x00000000}},  //   zág_, _esbj, ্রম_,
  { {0x9f47008d, 0xf7730076, 0xf99f000a, 0x00000000}},  //   _qenë_, _فاز_, _obèz_,
  { {0x9f470023, 0x0ab81125, 0x00000000, 0x00000000}},  //   _venë_, _خطیب_,   ,
  { {0xd3780119, 0x661b0061, 0x6b7c0104, 0x00000000}},  //   _neću_, _ubuk, טרונ,
  { {0x753b0d4d, 0x7e8b0036, 0xfe7f00f6, 0x00000000}},  //   _uruz, tępn, diï_,
  { {0x2bd902d2, 0xef19012b, 0xe3b30151, 0x00000000}},  //   _ब्ला, амо_, _فرض_,
  { {0x81e80055, 0x6aa40061, 0x6e260010, 0x00000000}},  //   _বার_, ylif, tekb,
  { {0x7d06021e, 0x60db00b0, 0x60cd0051, 0x00000000}},  //   tuks, ppum, _éamo,
  { {0x2f110047, 0x442711fe, 0x9f47009d, 0x00000000}},  //   ság_, oen_, _mené_,
  { {0x44270e53, 0x7d060056, 0x6aa40544, 0x00000000}},  //   nen_, ruks, wlif,
  { {0x60cb009f, 0x44272680, 0x7d0616fe, 0x00000000}},  //   _hugm, ien_, suks,
  { {0x442708ba, 0x29000142, 0x628934d4, 0x00000000}},  //   hen_, tria_, nneo,
  { {0x44270662, 0x61eb3e18, 0xbcfb0010, 0x00000000}},  // [ec40] ken_, _megl, szér,
  { {0x4427021e, 0x29000756, 0x61eb01aa, 0x00000000}},  //   jen_, rria_, _legl,
  { {0xbc6a06c6, 0xe5c6003b, 0xd6cf0025, 0x00000000}},  //   _ممکن_, осло, نقل_,
  { {0x44273e19, 0x2900303d, 0xd94600ed, 0x00000000}},  //   een_, pria_, _деми,
  { {0x4427001f, 0x1fa60316, 0x00000000, 0x00000000}},  //   fen_, _ऑर्ड,   ,
  { {0x44271440, 0x66e61447, 0x26ca0555, 0x00000000}},  //   gen_, _мога, _tubo_,
  { {0x26d823bd, 0x61eb010f, 0x60cb2a66, 0x00000000}},  //   _utro_, _begl, _augm,
  { {0x60c3002a, 0x41e60245, 0xa7a70088, 0x00000000}},  //   _ainm, ціка, _єкта_,
  { {0x4427196d, 0x61eb0198, 0xf8af026c, 0x00000000}},  //   ben_, _degl, _سکے_,
  { {0x44270219, 0x3ea02175, 0x60cb0091, 0x00000000}},  //   cen_, _akit_, _dugm,
  { {0x3ea00058, 0x3eb20082, 0x26c400e7, 0x00000000}},  //   _bkit_, _bhyt_, _kimo_,
  { {0x60c326cf, 0x61eb3e1a, 0x62890051, 0x00000000}},  //   _einm, _gegl, cneo,
  { {0x60c300ea, 0xd3780091, 0x5d8501b7, 0x00000000}},  //   _finm, _veću_, سلسل,
  { {0x628013b1, 0xed4e00a1, 0x26c40253, 0x00000000}},  //   limo, چھی_, _limo_,
  { {0x9f4500f6, 0x7c2718bc, 0x00000000, 0x00000000}},  //   calà_, rejr,   ,
  { {0x44270756, 0x26c40058, 0x63a70030, 0x00000000}},  //   zen_, _nimo_, _øjne,
  { {0x44270f99, 0x3eb905e9, 0x9f4706f0, 0x00000000}},  // [ec50] yen_, mmst_, _rené_,
  { {0x442704bd, 0x6280006b, 0x200c000c, 0x00000000}},  //   xen_, himo, ngdi_,
  { {0x44270662, 0x6280007f, 0x26c41c2b, 0x00000000}},  //   ven_, kimo, _bimo_,
  { {0x442702ae, 0x62800006, 0x1daf0061, 0x00000000}},  //   wen_, jimo, _घरात,
  { {0x44270270, 0x62800211, 0x9f4c01aa, 0x00000000}},  //   ten_, dimo, sadè_,
  { {0x44273e1b, 0x61eb3e1c, 0x25ad0059, 0x00000000}},  //   uen_, _segl, _vzel_,
  { {0x44270599, 0x60c301aa, 0x290900b0, 0x00000000}},  //   ren_, _rinm, luaa_,
  { {0x44270e53, 0x78600010, 0x6280008e, 0x00000000}},  //   sen_, _rövi, gimo,
  { {0x442702ae, 0x6289008e, 0x61eb2b84, 0x00000000}},  //   pen_, rneo, _vegl,
  { {0xe5c40cf2, 0x9f4504bd, 0x4427008d, 0x00000000}},  //   _істо, talà_, qen_,
  { {0x6280008e, 0x3ea6030d, 0x60c30190, 0x00000000}},  //   bimo, зинг, _vinm,
  { {0x62800211, 0x26c40b32, 0x60cb2274, 0x00000000}},  //   cimo, _ximo_, _tugm,
  { {0x80de0044, 0x60c30082, 0x0d9a01ab, 0x00000000}},  //   _মিথ্, _tinm, стны_,
  { {0xc17200b6, 0x6ab402fb, 0x3e62009f, 0x00000000}},  //   _אחד_, ंग्र, _móti_,
  { {0xe9df000c, 0x09e631c7, 0x00000000, 0x00000000}},  //   _snúa_, зобн,   ,
  { {0x32d100ad, 0xc3320104, 0x9f45008e, 0x00000000}},  //   _máy_, עון_, calá_,
  { {0x7af50010, 0x3ce90173, 0x00000000, 0x00000000}},  // [ec60] aszt, _gwav_,   ,
  { {0x44e90046, 0x6280002d, 0x26c420b0, 0x00000000}},  //   dź_, zimo, _simo_,
  { {0x6e36011f, 0x212d3e1d, 0x25a40016, 0x00000000}},  //   _kayb, hweh_, _syml_,
  { {0x6280008e, 0x6e360ace, 0x4efa0049, 0x00000000}},  //   ximo, _jayb, מלעג,
  { {0xe819024c, 0x62800b7f, 0x6e360edd, 0x00000000}},  //   न्हा_, vimo, _mayb,
  { {0x81c30055, 0x81e80044, 0x00000000, 0x00000000}},  //   ্রা_, _বাই_,   ,
  { {0x62800489, 0x26c400b0, 0x9f5801df, 0x00000000}},  //   timo, _timo_, ürü_,
  { {0x46a30cb7, 0x1dbe0061, 0xe61701ab, 0x00000000}},  //   _засв, ोशात, _ндс_,
  { {0x62800056, 0x68f61810, 0x00000000, 0x00000000}},  //   rimo, nsyd,   ,
  { {0x62802154, 0x29370049, 0x00000000, 0x00000000}},  //   simo, לאפן_,   ,
  { {0x6e363e1e, 0x32d10082, 0x6280004a, 0x00000000}},  //   _bayb, _gáy_, pimo,
  { {0x645a031a, 0x2002014a, 0x2c6f01a2, 0x00000000}},  //   _hoti, şki_, _müde_,
  { {0x645a3e1f, 0xfd47008b, 0x6e360912, 0x00000000}},  //   _koti, чэнн, _dayb,
  { {0x91bb00b6, 0x645a1aa3, 0x625c009d, 0x00000000}},  //   _המדי, _joti, _géor,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x645a0059, 0x7af51072, 0x3ce91e5a, 0x00000000}},  //   _loti, rszt, _twav_,
  { {0x644809ac, 0xa3cc01f5, 0x7e6d0058, 0x00000000}},  // [ec70] _ondi, रखा_, _ilap,
  { {0x645a3e20, 0x00000000, 0x00000000, 0x00000000}},  //   _noti,   ,   ,
  { {0xc3240044, 0x00000000, 0x00000000, 0x00000000}},  //   ভিডি_,   ,   ,
  { {0x64483e21, 0x645a0288, 0x00000000, 0x00000000}},  //   _andi, _aoti,   ,
  { {0x645a145d, 0x2bb50061, 0x7e6d00e0, 0x00000000}},  //   _boti, ंधका, _mlap,
  { {0x645a0682, 0xdfc60054, 0x7e6d3e22, 0x00000000}},  //   _coti, _لي_, _llap,
  { {0xf794008b, 0x625c009d, 0x81de0044, 0x00000000}},  //   _зарэ, _réor, _তয়_,
  { {0xe0d901f9, 0x32d10011, 0x64483e23, 0x00000000}},  //   ови_, _váy_, _endi,
  { {0x645a0142, 0x320d3e24, 0x6e3602d4, 0x00000000}},  //   _foti, rgey_, _rayb,
  { {0x7e6d0047, 0x7649000c, 0x00000000, 0x00000000}},  //   _alap, _hney,   ,
  { {0x765b1259, 0x6e3600b4, 0x7e6d01c3, 0x00000000}},  //   _kouy, _payb, _blap,
  { {0x7e6d002b, 0x645a008d, 0x68f60016, 0x00000000}},  //   _clap, _zoti, ysyd,
  { {0x20180129, 0x6448000c, 0x81c30044, 0x00000000}},  //   òric_, _yndi, ্রহ_,
  { {0x3f690545, 0x00000000, 0x00000000, 0x00000000}},  //   _мило_,   ,   ,
  { {0xfaa6007e, 0x38b401a2, 0xda660439, 0x00000000}},  //   даво, näre_, واري,
  { {0x4cdd0055, 0x765b01aa, 0x1e95007e, 0x00000000}},  //   _বিরু, _nouy, _прыр,
  { {0xfaa3007c, 0x38b4010f, 0x69d60023, 0x00000000}},  // [ec80] тато, häre_, rcye,
  { {0x69a20061, 0x68f60007, 0x65620020, 0x00000000}},  //   _कुणी, rsyd, vyoh,
  { {0x765b03eb, 0x645a0181, 0xdb2400b0, 0x00000000}},  //   _bouy, _roti, äräs,
  { {0x9f470224, 0x645a16c7, 0x26dc0089, 0x00000000}},  //   _není_, _soti, īvo_,
  { {0x645a3e25, 0xb9030044, 0x6aa300c4, 0x00000000}},  //   _poti, _নয়_, _ênfa,
  { {0x65620009, 0xd467011e, 0xf1b90089, 0x00000000}},  //   ryoh, миче_, nešu_,
  { {0x645a0065, 0x765b01aa, 0xb87b000c, 0x00000000}},  //   _voti, _fouy, _stíg,
  { {0x32b70054, 0xd2500054, 0x765b0173, 0x00000000}},  //   ودية_, انة_, _gouy,
  { {0x645a01ca, 0x902a00e2, 0x00000000, 0x00000000}},  //   _toti, оцна_,   ,
  { {0x7e6d010a, 0x644820e9, 0x15f8007d, 0x00000000}},  //   _slap, _undi, ुलकर_,
  { {0xd9ee00e8, 0x7e6d0035, 0xa06700ed, 0x00000000}},  //   जरात_, _plap, фаќа_,
  { {0x78720190, 0x625c009d, 0x81e80044, 0x00000000}},  //   _hævd, _géop, _বাক_,
  { {0x859b0049, 0x7e6d01c3, 0x00000000, 0x00000000}},  //   ַשלו, _vlap,   ,
  { {0x80d50044, 0x7860006b, 0x212601a3, 0x00000000}},  //   _দিচ্, _mövs, _ipoh_,
  { {0x20190163, 0x260f013d, 0x00000000, 0x00000000}},  //   əsi_, _डाली_,   ,
  { {0x63a800f6, 0x2d9e0035, 0x00000000, 0x00000000}},  //   _mydn, ştea_,   ,
  { {0x63a826d7, 0xdff2013d, 0x00000000, 0x00000000}},  // [ec90] _lydn, _आजाद_,   ,
  { {0x37ab026b, 0x00000000, 0x00000000, 0x00000000}},  //   отен_,   ,   ,
  { {0x765b0e6d, 0x00000000, 0x00000000, 0x00000000}},  //   _pouy,   ,   ,
  { {0x645e0039, 0xd7df02f4, 0x3942016c, 0x00000000}},  //   öpin, _प्रच, _frks_,
  { {0x2a69023a, 0x9425004c, 0x5887007e, 0x00000000}},  //   mkab_, емле, _жыва,
  { {0x344b004d, 0x94750014, 0x81e80044, 0x00000000}},  //   ючен_, رگذا, _বাগ_,
  { {0x765b0263, 0x63a80016, 0x80de0044, 0x00000000}},  //   _touy, _cydn, _মিষ্,
  { {0x3a39000a, 0x00000000, 0x00000000, 0x00000000}},  //   _jasp_,   ,   ,
  { {0x1015008b, 0x3a3900fa, 0x9f47004a, 0x00000000}},  //   ньня, _masp_, _vení_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x201804bd, 0x2a69006c, 0x63a80016, 0x00000000}},  //   òria_, kkab_, _gydn,
  { {0x3e62000c, 0x00000000, 0x00000000, 0x00000000}},  //   _nótt_,   ,   ,
  { {0x6f1a001c, 0x78720030, 0xddc40087, 0x00000000}},  //   attc, _hæve, _bliš,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1a001c, 0xd00e0054, 0xf1b90089, 0x00000000}},  //   cttc, _الى_, rešu_,
  { {0x3a3900d4, 0xddc40861, 0x00000000, 0x00000000}},  //   _casp_, _eliš,   ,
  { {0x6e241db1, 0x26d1002d, 0x00000000, 0x00000000}},  // [eca0] _ibib, _auzo_,   ,
  { {0x6d44023a, 0xddc40107, 0x3a390009, 0x00000000}},  //   _iria, _gliš, _easp_,
  { {0xdbc7010e, 0x225d00d9, 0x00000000, 0x00000000}},  //   _söök, _oowk_,   ,
  { {0x7c2e0c8f, 0xb8f60055, 0x38af01a2, 0x00000000}},  //   lebr, _সব_, büro_,
  { {0xe53405c7, 0x7860005f, 0x63a800ab, 0x00000000}},  //   тель, _dövr, _sydn,
  { {0x7c2e0919, 0x7c3c0023, 0xf71a007e, 0x00000000}},  //   nebr, ndrr, _нібы_,
  { {0x39400039, 0xe7e00061, 0x68e4010e, 0x00000000}},  //   lvis_, खुणा_, lpid,
  { {0x6d44018e, 0xdbc7006c, 0x7860006b, 0x00000000}},  //   _oria, _töök, _tövs,
  { {0x39403e26, 0x7c2e0479, 0x68e41622, 0x00000000}},  //   nvis_, kebr, npid,
  { {0x6f1a001c, 0x6e240009, 0xd2500123, 0x00000000}},  //   tttc, _abib, انک_,
  { {0x6d443e27, 0xdef70551, 0x201e000c, 0x00000000}},  //   _aria, ныя_, rfti_,
  { {0x442e0066, 0x63a4011f, 0x7860005f, 0x00000000}},  //   lef_, ğind, _mövq,
  { {0x6d4402d5, 0x2f180047, 0x7c2e0b32, 0x00000000}},  //   _cria, ség_, febr,
  { {0x7c2e0270, 0x6e240009, 0x394004d3, 0x00000000}},  //   gebr, _ebib, dvis_,
  { {0x6d44006c, 0x2a692919, 0xa6e70082, 0x00000000}},  //   _eria, tkab_, _chứ,
  { {0x442e0193, 0x6d4400f8, 0x5d850025, 0x00000000}},  //   hef_, _fria, _للعل,
  { {0xf80701fb, 0x6d44002a, 0x394005b7, 0x00000000}},  // [ecb0] ечен, _gria, gvis_,
  { {0x2a693e28, 0x6e3d00ea, 0x442e00ea, 0x00000000}},  //   skab_, ldsb, jef_,
  { {0x442e04db, 0x39400190, 0x7d1d2156, 0x00000000}},  //   def_, avis_, ltss,
  { {0x6e3d000c, 0x68f2000c, 0x7872068f, 0x00000000}},  //   ndsb, úkdó, _ræve,
  { {0x442e3e29, 0xddec0049, 0x6e3d0116, 0x00000000}},  //   fef_, פֿאָ, idsb,
  { {0x6aad0ce3, 0x26d10020, 0x62823e2a, 0x00000000}},  //   llaf, _tuzo_, _amoo,
  { {0xe2990c27, 0x00000000, 0x00000000, 0x00000000}},  //   мак_,   ,   ,
  { {0xc24501fe, 0x6aad0fcf, 0x6e3d0bbc, 0x00000000}},  //   тник, nlaf, jdsb,
  { {0x38b40039, 0x29090030, 0x9f45263c, 0x00000000}},  //   lära_, nraa_, mblé_,
  { {0x6aad010f, 0x78720190, 0xa4d403e8, 0x00000000}},  //   hlaf, _tæve, _софі,
  { {0x68e4002d, 0x44250460, 0x6d440051, 0x00000000}},  //   zpid, _ibl_, _sria,
  { {0x6d440027, 0x7d1d010f, 0x442500f8, 0x00000000}},  //   _pria, ftss, _hbl_,
  { {0x61e930ad, 0x7c2e0146, 0x427a0049, 0x00000000}},  //   mbel, tebr, _קאנג,
  { {0xab2a2210, 0x44250253, 0x69dd0190, 0x00000000}},  //   мога_, _jbl_, _afse,
  { {0x4425009f, 0x7d1d054e, 0x2c740039, 0x00000000}},  //   _mbl_, atss, _rädd_,
  { {0xf2d2007b, 0x61e90270, 0x6d44038f, 0x00000000}},  //   שען_, nbel, _tria,
  { {0x6d4404f8, 0x61e90058, 0x0c9400a1, 0x00000000}},  // [ecc0] _uria, ibel, _مددگ,
  { {0x68e4022b, 0x44250022, 0xa6e70082, 0x00000000}},  //   rpid, _nbl_, _thứ,
  { {0x8a060b86, 0x68e42c9b, 0x39401a96, 0x00000000}},  //   _изне, spid, svis_,
  { {0x9f4c0b33, 0x2f5a0049, 0x68e4006c, 0x00000000}},  //   nadá_, ודענ, ppid,
  { {0xceb300b3, 0x442e012d, 0x442501a3, 0x00000000}},  //   ביא_, tef_, _bbl_,
  { {0x628200ab, 0x44250048, 0x61e90c4c, 0x00000000}},  //   _smoo, _cbl_, ebel,
  { {0x442e018e, 0x44250093, 0x9f4e00c4, 0x00000000}},  //   ref_, _dbl_, _tefé_,
  { {0x442e0343, 0x3263007c, 0x44252a46, 0x00000000}},  //   sef_, итыв, _ebl_,
  { {0x28d802f4, 0x442e0197, 0x361b009b, 0x00000000}},  //   _भूमि, pef_, _קומד,
  { {0xdefa0783, 0x9f4c0129, 0xb35600a1, 0x00000000}},  //   мым_, tadà_, _لیتا_,
  { {0x7bdc0009, 0xbebd01c5, 0x00000000, 0x00000000}},  //   dcru, ntīg,   ,
  { {0x91e600e3, 0x7d1d01c9, 0x83fc0091, 0x00000000}},  //   _роде, ttss, _dođe,
  { {0x6e3d0479, 0x00000000, 0x00000000, 0x00000000}},  //   rdsb,   ,   ,
  { {0x7d1d101b, 0x00000000, 0x00000000, 0x00000000}},  //   rtss,   ,   ,
  { {0x7b640088, 0x00000000, 0x00000000, 0x00000000}},  //   атте,   ,   ,
  { {0xb5fd0626, 0x6a78000c, 0x29090052, 0x00000000}},  //   _koše, _líff, traa_,
  { {0xd75901ef, 0x3ea90169, 0x2c1b00e8, 0x00000000}},  // [ecd0] کلات_, _ikat_, _बापू_,
  { {0xb76704dd, 0x38b400f8, 0x00000000, 0x00000000}},  //   ктей, tära_,   ,
  { {0x75293e2b, 0x61e9007f, 0x9f450197, 0x00000000}},  //   _spez, ybel, falù_,
  { {0x44250061, 0x24f901ab, 0xb9e40088, 0x00000000}},  //   _sbl_, енды_, _віри,
  { {0x44253b0d, 0xfd1f0197, 0x248701ee, 0x00000000}},  //   _pbl_, ntì_, tinm_,
  { {0x61e91661, 0xa8790049, 0x38b4010e, 0x00000000}},  //   wbel, _טאָר, pära_,
  { {0x82f4008b, 0x61e9165e, 0xe7300464, 0x00000000}},  //   ачыц, tbel, _وصف_,
  { {0x83fc0119, 0x6d410089, 0x61e900bb, 0x00000000}},  //   _rođe, ālaj, ubel,
  { {0x61e90127, 0x7bdc0203, 0x00000000, 0x00000000}},  //   rbel, ycru,   ,
  { {0x61e6011f, 0x61e90056, 0x5f040164, 0x00000000}},  //   ıkla, sbel, _विश्_,
  { {0x6aa400e7, 0x82151298, 0x61e900d9, 0x00000000}},  //   yoif, _مواص, pbel,
  { {0x83fc0091, 0xcee800a6, 0x2d9e0c4f, 0x00000000}},  //   _vođe, کرین_, ştem_,
  { {0x78a5182d, 0x7bdc00d9, 0xd0090745, 0x00000000}},  //   kohv, tcru, _зеле_,
  { {0x7f41001c, 0x6abe007d, 0x7ae70009, 0x00000000}},  //   pvlq, ्द्र, fpjt,
  { {0x9f4c0802, 0x00000000, 0x00000000, 0x00000000}},  //   padá_,   ,   ,
  { {0x7bdc106f, 0x7afc0009, 0x6a710ccc, 0x00000000}},  //   scru, rsrt, _påfa,
  { {0x394605f4, 0x00000000, 0x00000000, 0x00000000}},  // [ece0] íos_,   ,   ,
  { {0xb86600a1, 0x6aa40068, 0x00000000, 0x00000000}},  //   دارو, soif,   ,
  { {0x5c370097, 0xbc1b0049, 0xf3f10082, 0x00000000}},  //   _גרין_, _אויש, _gọi_,
  { {0xbebd0089, 0x00000000, 0x00000000, 0x00000000}},  //   rtīg,   ,   ,
  { {0x7c3e0471, 0x628908e0, 0xbebd0089, 0x00000000}},  //   _kapr, dieo, stīg,
  { {0x9f47014a, 0x64a33e2c, 0x81f00044, 0x00000000}},  //   _genç_, бача, _টাইপ_,
  { {0x7c3e015e, 0x29120ee4, 0x9326023c, 0x00000000}},  //   _mapr, luya_, ارتن,
  { {0x7c3e0263, 0x26cd0082, 0x25ad0173, 0x00000000}},  //   _lapr, _gieo_, _fyel_,
  { {0x2912014a, 0x9237003b, 0x00000000, 0x00000000}},  //   nuya_, учју_,   ,
  { {0x3ea93e2d, 0x6ed80061, 0x2018010e, 0x00000000}},  //   _skat_, _नंदु, üri_,
  { {0xa2e616c4, 0x2ba4007d, 0x0857009b, 0x00000000}},  //   _соед, _खुला, אבים_,
  { {0x443e03a1, 0x38af1e00, 0xfd1f0197, 0x00000000}},  //   _hat_, türk_, ttì_,
  { {0x5c072b26, 0x443e0127, 0xa06a3e2e, 0x00000000}},  //   лява, _kat_, _пада_,
  { {0x7c3e0412, 0xdfcf0054, 0xfd1f0026, 0x00000000}},  //   _capr, _فيه_, rtì_,
  { {0x7c3e0263, 0x8cd5013d, 0xfd1f0026, 0x00000000}},  //   _dapr, _यूरो, stì_,
  { {0x443e0046, 0x5a3500ed, 0x00000000, 0x00000000}},  //   _lat_, јнат,   ,
  { {0x57f500ec, 0x443e0145, 0x787201e5, 0x00000000}},  // [ecf0] ипат, _oat_, _sæva,
  { {0x29071032, 0x443e3e2f, 0x13cc0055, 0x00000000}},  //   čna_, _nat_, রুয়,
  { {0x9f4700f6, 0x9994012d, 0x00000000, 0x00000000}},  //   _venç_, đešu_,   ,
  { {0x29121ebf, 0x6e3f002b, 0x7ae50023, 0x00000000}},  //   buya_, _jaqb, _itht,
  { {0x443e0238, 0x7c3e014a, 0xe3b80477, 0x00000000}},  //   _bat_, _yapr, _azı_,
  { {0x443e3e30, 0x044501ee, 0x00000000, 0x00000000}},  //   _cat_, рекн,   ,
  { {0x443e3e31, 0xc3040025, 0x628900bb, 0x00000000}},  //   _dat_, مبيو, tieo,
  { {0x443e00ab, 0x4105003b, 0x78720030, 0x00000000}},  //   _eat_, азив, _jævn,
  { {0x5455007e, 0x62890179, 0x00000000, 0x00000000}},  //   _кват, rieo,   ,
  { {0x753b0007, 0x443e375b, 0xe4a7003b, 0x00000000}},  //   _isuz, _gat_, _србо,
  { {0x7c3e0066, 0x2912013f, 0x00000000, 0x00000000}},  //   _rapr, zuya_,   ,
  { {0x7c3e2e43, 0x78720030, 0x443e00b5, 0x00000000}},  //   _sapr, _nævn, _zat_,
  { {0x7c3e010a, 0x61fb008e, 0xa075007e, 0x00000000}},  //   _papr, maul, _выйш,
  { {0x443e0129, 0xb87b3e32, 0x61fb17f6, 0x00000000}},  //   _xat_, _stín, laul,
  { {0x6b630517, 0x6a78000c, 0x1a660014, 0x00000000}},  //   окра, _lífe, لیدی_,
  { {0x7c3e12eb, 0x8f9a00b3, 0x29123e33, 0x00000000}},  //   _wapr, _ביצי, tuya_,
  { {0xe9d72cb4, 0x7c3e0381, 0x9f450051, 0x00000000}},  // [ed00] рку_, _tapr, iblí_,
  { {0x61fb1a91, 0xb87b0051, 0x29120095, 0x00000000}},  //   haul, _dtío, ruya_,
  { {0x7eb61748, 0x7e640d17, 0xb87b004a, 0x00000000}},  //   nápo, _koip, _etío,
  { {0x0bb7019b, 0xe9a60242, 0x291211f3, 0x00000000}},  //   _כלים_, _вамп, puya_,
  { {0x443e0995, 0x09b00044, 0xceb300b3, 0x00000000}},  //   _pat_, _কলকা, קיד_,
  { {0x443e006b, 0x290216d0, 0xddc400b4, 0x00000000}},  //   _qat_, _ivka_, _bliź,
  { {0x443e3e34, 0x61fb0866, 0xd467012b, 0x00000000}},  //   _vat_, faul, рије_,
  { {0x443e06b2, 0x442000b9, 0x83fc016c, 0x00000000}},  //   _wat_, ři_, _dođa,
  { {0x443e01d5, 0x60f7008b, 0x27f80168, 0x00000000}},  //   _tat_, аныя_, _kern_,
  { {0x2900021e, 0x69b90061, 0x26d82301, 0x00000000}},  //   isia_, ्धती, _kuro_,
  { {0x75220047, 0x1df90147, 0x26d825c0, 0x00000000}},  //   ltoz, лены_, _juro_,
  { {0xb5fd02aa, 0x2900021e, 0x26d80555, 0x00000000}},  //   _koša, ksia_, _muro_,
  { {0xf27b0104, 0x76400006, 0x75220232, 0x00000000}},  //   _בראש, _mamy, ntoz,
  { {0x7ebd00f4, 0x26d80181, 0x764000e0, 0x00000000}},  //   dépe, _ouro_, _lamy,
  { {0xbebd001e, 0x26d800e0, 0x2900010e, 0x00000000}},  //   rtīb, _nuro_, esia_,
  { {0xbebd001e, 0xb87b00d6, 0x00000000, 0x00000000}},  //   stīb, _etíl,   ,
  { {0xdebc00b6, 0x27f801a2, 0x7ebd0010, 0x00000000}},  // [ed10] _במהל, _bern_, gépe,
  { {0x085401fb, 0x26d80112, 0x06de0044, 0x00000000}},  //   овую, _buro_, _ডিজি,
  { {0xec3600b6, 0x26d83e35, 0x6a78000c, 0x00000000}},  //   _האתר_, _curo_, _sífe,
  { {0x26d8004a, 0x83fc0091, 0x36180088, 0x00000000}},  //   _duro_, _rođa, ицію_,
  { {0x7640000a, 0x27f801a2, 0x61fb0068, 0x00000000}},  //   _damy, _fern_, vaul,
  { {0xb5fd3e36, 0x27f8010f, 0xe81e006e, 0x00000000}},  //   _doša, _gern_, _पाया_,
  { {0xe7ed001c, 0x96f801f9, 0xf794007e, 0x00000000}},  //   _च्या_, _вест_, _дарэ,
  { {0x76400006, 0xeb98009b, 0x05870072, 0x00000000}},  //   _gamy, ידור_, _кузм,
  { {0x61fb04bd, 0x75220035, 0x00000000, 0x00000000}},  //   raul, ctoz,   ,
  { {0x205503f3, 0xcea9007b, 0xd3a7022a, 0x00000000}},  //   стир, _װי_, _креп,
  { {0x61fb0e30, 0x5058007e, 0x644100e0, 0x00000000}},  //   paul, ршыя_, _iali,
  { {0x64430239, 0xed5a2672, 0x2900117c, 0x00000000}},  //   ldni, гом_, ysia_,
  { {0x6441006a, 0xdd920084, 0x3f8b0036, 0x00000000}},  //   _kali, سوس_, ńcu_,
  { {0x64430a5d, 0x9f473e37, 0x64413e38, 0x00000000}},  //   ndni, _menú_, _jali,
  { {0x64413e39, 0x394b3e3a, 0x00000000, 0x00000000}},  //   _mali, _arcs_,   ,
  { {0x64410e6a, 0x225f3604, 0x29001e17, 0x00000000}},  //   _lali, njuk_, tsia_,
  { {0x29003e3b, 0x27f80251, 0x76400006, 0x00000000}},  // [ed20] usia_, _pern_, _ramy,
  { {0x644103dd, 0x26d8011c, 0x29000065, 0x00000000}},  //   _nali, _puro_, rsia_,
  { {0x64430039, 0x27f80056, 0xf3f80089, 0x00000000}},  //   ddni, _vern_, _reģ_,
  { {0xb5fd021d, 0x64413e3c, 0x29000ac1, 0x00000000}},  //   _poša, _aali, psia_,
  { {0x64413e3d, 0x7860005f, 0x27f80190, 0x00000000}},  //   _bali, _mövz, _tern_,
  { {0x64412731, 0x75220047, 0x26d8011c, 0x00000000}},  //   _cali, rtoz, _turo_,
  { {0x6441010a, 0x08770049, 0x672e0022, 0x00000000}},  //   _dali, _פעלט_, _upbj,
  { {0xe6960054, 0x7d040209, 0x20073e3e, 0x00000000}},  //   _الرد, _ovis, _adni_,
  { {0xb5fd0e00, 0x315a0025, 0x00000000, 0x00000000}},  //   _košn, اجعة_,   ,
  { {0x64413e3f, 0x0eea0088, 0x00000000, 0x00000000}},  //   _gali, льми_,   ,
  { {0x7d0419fa, 0x442c3e40, 0xb5fd21e8, 0x00000000}},  //   _avis, _ibd_, _mošn,
  { {0xc3b70049, 0x644139e2, 0x00000000, 0x00000000}},  //   _פלאץ_, _zali,   ,
  { {0x6441000b, 0x9f470207, 0xddcd1288, 0x00000000}},  //   _yali, _menù_, _blaš,
  { {0x6441006b, 0x7d041288, 0x9f45004a, 0x00000000}},  //   _xali, _dvis, galó_,
  { {0x5f9302a8, 0xeabf001d, 0x7d04008e, 0x00000000}},  //   _ништ, _phù_, _evis,
  { {0x64430059, 0x00000000, 0x00000000, 0x00000000}},  //   zdni,   ,   ,
  { {0xb5fd037e, 0xddcd041a, 0x6e2d006a, 0x00000000}},  // [ed30] _bošn, _flaš, _ibab,
  { {0x81bd0044, 0x6d4d006c, 0x442c200a, 0x00000000}},  //   _আলম_, _iraa, _nbd_,
  { {0x64410006, 0xeabf0011, 0x442700fa, 0x00000000}},  //   _rali, _thù_, vfn_,
  { {0x442c3851, 0x6d4d095c, 0x3a2b0009, 0x00000000}},  //   _abd_, _kraa, _ubcp_,
  { {0xa3cb02d2, 0x442c3e41, 0x6e2d0c97, 0x00000000}},  //   रेन_, _bbd_, _mbab,
  { {0x442c0875, 0x68ed322e, 0x64410312, 0x00000000}},  //   _cbd_, mpad, _qali,
  { {0x64413e42, 0x39490089, 0x68ed0d3f, 0x00000000}},  //   _vali, lvas_, lpad,
  { {0x64410be3, 0x6d4d0abf, 0x68ed3e43, 0x00000000}},  //   _wali, _oraa, opad,
  { {0x64413e44, 0xe0d6008b, 0x68ed1eca, 0x00000000}},  //   _tali, овы_, npad,
  { {0xaf050364, 0x6e2d0061, 0x68ed1261, 0x00000000}},  //   опол, _abab, ipad,
  { {0x7d043250, 0x3949006c, 0x6d4d010e, 0x00000000}},  //   _svis, hvas_, _araa,
  { {0x6d4d0007, 0xddcd00ca, 0x7e7d05af, 0x00000000}},  //   _braa, _slaš, ghsp,
  { {0xddcd06ed, 0x763a007b, 0x628b0009, 0x00000000}},  //   _plaš, בערג, _imgo,
  { {0x6d4d049b, 0xdfdb005e, 0x00000000, 0x00000000}},  //   _draa, _съд_,   ,
  { {0xbb4300a5, 0x6d4d3e45, 0x2a60002b, 0x00000000}},  //   мерк, _eraa, tjib_,
  { {0x7e7d010f, 0x6d4d00bb, 0x7d04141a, 0x00000000}},  //   chsp, _fraa, _tvis,
  { {0x6d4d049b, 0x68ed011c, 0x7d04068f, 0x00000000}},  // [ed40] _graa, gpad, _uvis,
  { {0x6609041a, 0xbebd0089, 0x00000000, 0x00000000}},  //   _adek, ntīn,   ,
  { {0x442c0939, 0xa3cb0309, 0x68ed3e46, 0x00000000}},  //   _rbd_, रेम_, apad,
  { {0xd62a0cee, 0x442c0f02, 0x8f9a009b, 0x00000000}},  //   роде_, _sbd_, ביעי,
  { {0x44f3008b, 0x14f3007e, 0xbcfb0010, 0x00000000}},  //   дпіс, дзіў, lyér,
  { {0x3d120061, 0xddc4012d, 0x38b400b0, 0x00000000}},  //   _तिने_, _oliž, käri_,
  { {0xbcfb0010, 0x00000000, 0x00000000, 0x00000000}},  //   nyér,   ,   ,
  { {0xfbd300b6, 0xf48402fd, 0x442c0022, 0x00000000}},  //   ותו_, _کاری, _wbd_,
  { {0xa2da0164, 0x93bc001a, 0xc05a007e, 0x00000000}},  //   _पूर्, _scăd, аін_,
  { {0xddc405e8, 0xa3560025, 0x1957009b, 0x00000000}},  //   _bliž, _وخاص, קביל_,
  { {0xb7db00a3, 0x3ce90161, 0x7e7d0275, 0x00000000}},  //   יקיי, _stav_, thsp,
  { {0x6d4d0343, 0x3949010a, 0xe29202fd, 0x00000000}},  //   _praa, yvas_, _غذا_,
  { {0x2eec004a, 0x6ab63e47, 0x00000000, 0x00000000}},  //   spdf_, dlyf,   ,
  { {0x6d4d015c, 0x9f5e0023, 0x00000000, 0x00000000}},  //   _vraa, natë_,   ,
  { {0x6d4d040f, 0x628b005b, 0x00000000, 0x00000000}},  //   _wraa, _ymgo,   ,
  { {0x6d4d109a, 0x68ed00ca, 0x6e2d00e7, 0x00000000}},  //   _traa, tpad, _ubab,
  { {0xb5fd057a, 0xdd9104e8, 0x38c90123, 0x00000000}},  // [ed50] _došl, _سود_, مائی_,
  { {0x68ed04be, 0x3949071d, 0xa3cb0316, 0x00000000}},  //   rpad, rvas_, रेड_,
  { {0x3707007e, 0x3949127b, 0x9f5e0023, 0x00000000}},  //   ючав, svas_, datë_,
  { {0x68ed0039, 0xcb120049, 0x67253e48, 0x00000000}},  //   ppad, _אלט_, rthj,
  { {0xd1260054, 0x6609008d, 0x73e50265, 0x00000000}},  //   _ثم_, _vdek, полз,
  { {0x81c20044, 0x9f5e25f6, 0x00000000, 0x00000000}},  //   ্ডা_, ratê_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f5e01aa, 0xb5fd1878, 0x66091ea2, 0x00000000}},  //   matè_, _košm, _udek,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe3b30151, 0x032b0088, 0x9f8518bf, 0x00000000}},  //   _قرض_, _відп_, згод,
  { {0x9f5e0263, 0x00000000, 0x00000000, 0x00000000}},  //   natè_,   ,   ,
  { {0xbebd0089, 0x6da6003b, 0x2d820a3a, 0x00000000}},  //   stīn, зима, tzke_,
  { {0x31580025, 0xee370088, 0x1c20013d, 0x00000000}},  //   _وجهة_, чня_, _बादल_,
  { {0x9f5e01aa, 0x9f05006d, 0x629b0419, 0x00000000}},  //   katè_, _فوتو, lnuo,
  { {0xb5fd086e, 0x2d820f88, 0xfbc3044b, 0x00000000}},  //   _pošl, szke_, ебро,
  { {0xe9da01b3, 0xada63e49, 0xe81e0061, 0x00000000}},  //   ска_, _найл, _पाहा_,
  { {0x7afb0521, 0x6ab608e6, 0xa3cb01f5, 0x00000000}},  // [ed60] ćuta, rlyf, रेत_,
  { {0x49990088, 0x29123e4a, 0xb904007d, 0x00000000}},  //   іття_, rrya_, _पं_,
  { {0x25bf0489, 0xbb4a0025, 0xc2f00044, 0x00000000}},  //   _azul_, _الجن_, _টিভি_,
  { {0x3e7b0065, 0xb6cb00a1, 0x38b4010e, 0x00000000}},  //   _këta_, مانے_, järv_,
  { {0x48e32e54, 0x9f5e0065, 0xb8080044, 0x00000000}},  //   _появ, tatë_, র্গত_,
  { {0xb87b004a, 0xd7f20025, 0x798400e7, 0x00000000}},  //   _cuíd, _سكر_, mziw,
  { {0x9f5e0065, 0x4367300e, 0xddc401f3, 0x00000000}},  //   ratë_, зајн_, _aliż,
  { {0x394201ee, 0x3ea000d9, 0x629b05fc, 0x00000000}},  //   _ksks_, _njit_, gnuo,
  { {0x79841519, 0x93bc00e5, 0x9f5e0023, 0x00000000}},  //   nziw, _abăt, patë_,
  { {0x443811ea, 0x2fd80637, 0x43463e4b, 0x00000000}},  //   _úr_, ørg_, _незв,
  { {0xdfd00380, 0x00000000, 0x00000000, 0x00000000}},  //   ضيح_,   ,   ,
  { {0x66020020, 0xde59007e, 0x00000000, 0x00000000}},  //   naok, цамі_,   ,
  { {0x9f5e01aa, 0x6aa3052a, 0x39420087, 0x00000000}},  //   zatè_, _ínfi, _nsks_,
  { {0x6ab502fb, 0x386a001c, 0x79840036, 0x00000000}},  //   ंत्र, _nobr_, dziw,
  { {0x3d12001c, 0x160c0061, 0x6602087c, 0x00000000}},  //   _तिथे_, हणार_, kaok,
  { {0xfd4700a1, 0x9f5e01aa, 0x69da001a, 0x00000000}},  //   _ٹیسٹ_, vatè_, _şter,
  { {0xf993007a, 0xdd9200a1, 0x6aad3e4c, 0x00000000}},  // [ed70] ربر_, _لوٹ_, roaf,
  { {0x201e010a, 0x3eb93e4d, 0x00000000, 0x00000000}},  //   ngti_, llst_,   ,
  { {0x44e23e4e, 0xb87b00c4, 0x386a00ca, 0x00000000}},  //   _að_, _ruíd, _dobr_,
  { {0x9f5e01aa, 0x19590147, 0x660204e7, 0x00000000}},  //   ratè_, _дамы_, gaok,
  { {0x04450200, 0xd46902ea, 0x00000000, 0x00000000}},  //   делн, жиле_,   ,
  { {0x7eb62678, 0x3eb901a2, 0x629e009d, 0x00000000}},  //   rápi, hlst_, épon,
  { {0xb5fd050f, 0x9f5e1396, 0xe695007c, 0x00000000}},  //   _jošk, baté_, _живы,
  { {0xb5fd01d9, 0xd5ae00a1, 0x9f5c00c4, 0x00000000}},  //   _mošk, اہے_, _tevê_,
  { {0x81b508b7, 0xf4f700a1, 0xb5fd00ca, 0x00000000}},  //   ছেন_, _رواں_, _lošk,
  { {0x3ea001c3, 0x3eb201c3, 0x00000000, 0x00000000}},  //   _sjit_, _skyt_,   ,
  { {0x4abf0061, 0x629b007f, 0x00000000, 0x00000000}},  //   ्षाव, pnuo,   ,
  { {0x38b400f8, 0x628027a4, 0x00000000, 0x00000000}},  //   lärt_, chmo,   ,
  { {0x61450e05, 0xd009007c, 0x00000000, 0x00000000}},  //   _цела, _деле_,   ,
  { {0x7afb0107, 0x7d060635, 0xb5fd0340, 0x00000000}},  //   ćutn, rsks, _bošk,
  { {0x09e63bf0, 0xebe3005c, 0x9f5c000a, 0x00000000}},  //   добн, тосп, _nevè_,
  { {0xc332019b, 0x9f473e4f, 0x3ea00065, 0x00000000}},  //   כול_, _menü_, _ujit_,
  { {0x63a4011f, 0x6e243c70, 0x00000000, 0x00000000}},  // [ed80] ğini, _icib,   ,
  { {0x63a43e50, 0x6d4404be, 0x660200e7, 0x00000000}},  //   şini, _isia, waok,
  { {0x7c3c0023, 0x9f5e009d, 0x66020095, 0x00000000}},  //   merr, taté_, taok,
  { {0x7c3c022b, 0x386a0016, 0x7c2e00d9, 0x00000000}},  //   lerr, _wobr_, lfbr,
  { {0x66020011, 0xa3cb02d2, 0x321f098e, 0x00000000}},  //   raok, रेस_, dguy_,
  { {0x7c3c0968, 0x6d4400e7, 0x00000000, 0x00000000}},  //   nerr, _msia,   ,
  { {0x6280008d, 0x224600d9, 0x00000000, 0x00000000}},  //   thmo, _paok_,   ,
  { {0x7c3c00db, 0x00000000, 0x00000000, 0x00000000}},  //   herr,   ,   ,
  { {0x7c3c002d, 0x142600ed, 0x68e4006b, 0x00000000}},  //   kerr, _одам, nqid,
  { {0x62800065, 0x7c3c0065, 0x81c20044, 0x00000000}},  //   shmo, jerr, ্ডল_,
  { {0x3817019b, 0x7c3c0dcc, 0x6d440e2d, 0x00000000}},  //   וקים_, derr, _asia,
  { {0x64482c9d, 0x442e0090, 0x443c269f, 0x00000000}},  //   _hadi, lff_, lev_,
  { {0x7c3c00ab, 0xdbc7006b, 0x442e0009, 0x00000000}},  //   ferr, _köçk, off_,
  { {0xb5fd3692, 0x7c3c0239, 0x6448003f, 0x00000000}},  //   _pošk, gerr, _jadi,
  { {0x6448000b, 0xe2070036, 0x6d443e51, 0x00000000}},  //   _madi, spół_, _esia,
  { {0x443c013e, 0x644807ff, 0x320409b6, 0x00000000}},  //   hev_, _ladi, namy_,
  { {0x7c3c3e52, 0x645a00d4, 0x5cc719c9, 0x00000000}},  // [ed90] berr, _onti, _осоз,
  { {0x443c3d7f, 0x7c3c3e53, 0x3e7b008d, 0x00000000}},  //   jev_, cerr, _këto_,
  { {0x7d1d021e, 0xd148001d, 0x443c3e54, 0x00000000}},  //   luss, _lễ_, dev_,
  { {0xb5fd0027, 0x442e0007, 0x6e3d000c, 0x00000000}},  //   _koši, eff_, nesb,
  { {0x6448022b, 0x442e0061, 0xe3b80279, 0x00000000}},  //   _badi, fff_, _ayı_,
  { {0xdfc6007a, 0x6448029a, 0x443c006c, 0x00000000}},  //   _مي_, _cadi, gev_,
  { {0xb5fd0209, 0x6448002d, 0x66003e55, 0x00000000}},  //   _loši, _dadi, _femk,
  { {0xb1450175, 0x645a3e56, 0x7c3c3e57, 0x00000000}},  //   енил, _enti, zerr,
  { {0x7c2523d9, 0x81d70055, 0x644801a3, 0x00000000}},  //   _ochr, ়ুন_, _fadi,
  { {0x64482291, 0x7d1d11ef, 0xd148001d, 0x00000000}},  //   _gadi, duss, _dễ_,
  { {0x7c3c0d3e, 0x3ce01e83, 0x44250f5d, 0x00000000}},  //   verr, _suiv_, _icl_,
  { {0x32040036, 0x2909290f, 0x7c250fcc, 0x00000000}},  //   camy_, ksaa_, _achr,
  { {0x64480b1e, 0x7d1d006c, 0x61e9013f, 0x00000000}},  //   _yadi, guss, mcel,
  { {0x8fa51deb, 0x6448006b, 0x61e930c7, 0x00000000}},  //   _пале, _xadi, lcel,
  { {0x7c3c0032, 0x44251575, 0x7d1d01a2, 0x00000000}},  //   rerr, _mcl_, auss,
  { {0x61e92004, 0x7c3c0948, 0x443c00b9, 0x00000000}},  //   ncel, serr, zev_,
  { {0x443c005f, 0x442e00d4, 0x7c3c1103, 0x00000000}},  // [eda0] yev_, yff_, perr,
  { {0x20053e58, 0x39400046, 0x290b0146, 0x00000000}},  //   nali_, rwis_, _dvca_,
  { {0x64480119, 0xabfb00b6, 0xf77201b7, 0x00000000}},  //   _radi, _מהיר, داء_,
  { {0x6448122b, 0x2005000b, 0xf5063bee, 0x00000000}},  //   _sadi, hali_, ездо,
  { {0x20053193, 0x64480006, 0x443c01d9, 0x00000000}},  //   kali_, _padi, tev_,
  { {0x2005049e, 0x64480312, 0xd1480082, 0x00000000}},  //   jali_, _qadi, _rễ_,
  { {0x20051634, 0x64481a9d, 0x443c0239, 0x00000000}},  //   dali_, _vadi, rev_,
  { {0xcb1300b6, 0x443c010e, 0x2166003b, 0x00000000}},  //   אלה_, sev_, етог,
  { {0x64483e59, 0x44250009, 0x20050095, 0x00000000}},  //   _tadi, _fcl_, fali_,
  { {0x200501d5, 0x645a3e5a, 0x64480020, 0x00000000}},  //   gali_, _unti, _uadi,
  { {0x7d1d2e94, 0xe9df008e, 0x6e3d23c5, 0x00000000}},  //   wuss, _baúl_, tesb,
  { {0x7c2504e5, 0xb5fd0059, 0x7d1d0ac2, 0x00000000}},  //   _schr, _poši, tuss,
  { {0x2005181e, 0x6e3d00bb, 0xa1130076, 0x00000000}},  //   bali_, resb, _مونت,
  { {0x20050198, 0x7d1d00b0, 0x6e3d1aff, 0x00000000}},  //   cali_, russ, sesb,
  { {0x4abf0061, 0x7d1d0052, 0x9f4c0010, 0x00000000}},  //   ्षलव, suss, radó_,
  { {0x7d1d00b0, 0xb5fd016e, 0x00000000, 0x00000000}},  //   puss, _toši,   ,
  { {0x38b40039, 0x04060044, 0x00000000, 0x00000000}},  // [edb0] värr_, _রানী_,   ,
  { {0xd6d90036, 0x61e901c5, 0x00000000, 0x00000000}},  //   _sił_, zcel,   ,
  { {0x290900b0, 0x7d0d01e5, 0x61e9005b, 0x00000000}},  //   ssaa_, _hvas, ycel,
  { {0x7d0d040d, 0x00000000, 0x00000000, 0x00000000}},  //   _kvas,   ,   ,
  { {0x61e923f6, 0x20050095, 0x44250253, 0x00000000}},  //   vcel, yali_, _pcl_,
  { {0x61e91a8f, 0x9f45009d, 0x00000000, 0x00000000}},  //   wcel, sclé_,   ,
  { {0xa3cb03d7, 0xb87b0211, 0x61e901c5, 0x00000000}},  //   रें_, _guía, tcel,
  { {0x20053e5b, 0xa562007a, 0x2a692fe4, 0x00000000}},  //   wali_, _چگون, njab_,
  { {0x4102007c, 0x61e901cb, 0xe9df0211, 0x00000000}},  //   азыв, rcel, _raúl_,
  { {0x7ebd028c, 0x442510c5, 0xe9df004a, 0x00000000}},  //   léph, _ucl_, _saúl_,
  { {0x200501d5, 0x201805e2, 0x63ba0061, 0x00000000}},  //   rali_, ória_, _gytn,
  { {0x2c7401a2, 0xc7d6009b, 0x7ebd0068, 0x00000000}},  //   _lädt_, כותי_, néph,
  { {0x200501d5, 0xfd1f0197, 0x66e50006, 0x00000000}},  //   pali_, guì_, _sėkl,
  { {0x7d0d0006, 0x224d0032, 0xe1f90006, 0x00000000}},  //   _dvas, ldek_, lbų_,
  { {0x7d0d0197, 0x2b150259, 0x09d90044, 0x00000000}},  //   _evas, льтр, ধুমা,
  { {0x224d2a26, 0xb5fd0166, 0x6a710030, 0x00000000}},  //   ndek_, _košu, _såfr,
  { {0x6e360009, 0x2d95007e, 0x290c0089, 0x00000000}},  // [edc0] _ibyb, _брэс, _ādas_,
  { {0x92dc0044, 0x6d560045, 0x394d01f3, 0x00000000}},  //   তীয়_, _irya, _ġest_,
  { {0x6a78009f, 0x394d018b, 0xc5fe0089, 0x00000000}},  //   _lífi, _šest_, ņēma_,
  { {0x9407006b, 0x63ad019a, 0x00000000, 0x00000000}},  //   minə_, ğanl,   ,
  { {0x63ad005d, 0x9407006b, 0x00000000, 0x00000000}},  //   şanl, linə_,   ,
  { {0x44b3007e, 0xc44801b2, 0x69c60032, 0x00000000}},  //   абіс, عیان_, _izke,
  { {0x9407006b, 0x00000000, 0x00000000, 0x00000000}},  //   ninə_,   ,   ,
  { {0x6d561338, 0x225d0009, 0x6a7800f6, 0x00000000}},  //   _orya, _cnwk_, _bífi,
  { {0x6a7800f6, 0x00000000, 0x00000000, 0x00000000}},  //   _cífi,   ,   ,
  { {0x6a7800f6, 0x84450439, 0x63ba00d9, 0x00000000}},  //   _dífi, _مخمل, _tytn,
  { {0x7d0d037e, 0x50d30025, 0x6d56008a, 0x00000000}},  //   _svas, جزير, _arya,
  { {0xc7b3019b, 0xddd600b9, 0xfd1f0026, 0x00000000}},  //   יבת_, _slyš, tuì_,
  { {0xbebd001e, 0xddc40059, 0xc27b009b, 0x00000000}},  //   ktīv, _poiš, _קרדי,
  { {0x8f540070, 0x66e50006, 0x9407006b, 0x00000000}},  //   _منتش, _sėkm, finə_,
  { {0x69c6022b, 0xdee3012b, 0xb5fd0091, 0x00000000}},  //   _azke, _који, _košt,
  { {0xb87b0325, 0x00000000, 0x00000000, 0x00000000}},  //   _atíp,   ,   ,
  { {0xf80701fb, 0xead402d3, 0xb5fd00ca, 0x00000000}},  // [edd0] вчен, роть, _mošt,
  { {0x7e7d021f, 0x9407006b, 0x224d3e5c, 0x00000000}},  //   lksp, binə_, zdek_,
  { {0x69c6002d, 0xe1f90006, 0x9715007e, 0x00000000}},  //   _ezke, ybų_, умец,
  { {0xf7700380, 0x7e7d01a2, 0x9f5c013e, 0x00000000}},  //   غال_, nksp, _neví_,
  { {0xa82502fd, 0x7ae500b0, 0x25a9101d, 0x00000000}},  //   _مکان, _huht, çal_,
  { {0x63ad005a, 0x25a9002b, 0xd7f4007c, 0x00000000}},  //   şanm, ħal_, _взры,
  { {0x7ae50004, 0x628200fe, 0xf8b200a0, 0x00000000}},  //   _juht, _bloo, _השם_,
  { {0x7ae5014a, 0x23690091, 0xb5fd0c76, 0x00000000}},  //   _muht, ćaj_, _pošu,
  { {0x20c2000c, 0xe1f90006, 0x224d0095, 0x00000000}},  //   rðin_, rbų_, rdek_,
  { {0x9407005f, 0xddcd016e, 0x25a00051, 0x00000000}},  //   yinə_, _blaž, úile_,
  { {0x628200ab, 0xa2f5005e, 0xb87b0051, 0x00000000}},  //   _floo, _спеч, _luío,
  { {0xf38c0049, 0xddcd0161, 0x9407006b, 0x00000000}},  //   _קראָ, _dlaž, vinə_,
  { {0x61fb1b20, 0x61fd000c, 0xb87b00c4, 0x00000000}},  //   mbul, ðslu, _ruín,
  { {0x753b0061, 0x9407006b, 0x7e7d0c7c, 0x00000000}},  //   _mpuz, tinə_, ërpr,
  { {0x30da0049, 0xddcd0087, 0x7ebd0010, 0x00000000}},  //   _אַהע, _glaž, zépi,
  { {0x9407005f, 0xb87b002a, 0x61fb005d, 0x00000000}},  //   rinə_, _buío, nbul,
  { {0x9407005f, 0xa81a04e1, 0x98a0037e, 0x00000000}},  // [ede0] sinə_, فتار_, ntić_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xe61a003b, 0xeb9a00ed, 0x61fb12d9, 0x00000000}},  //   еде_, _чин_, kbul,
  { {0xa96a017f, 0x95ca06b6, 0x84e60088, 0x00000000}},  //   _зима_, нула_, годж,
  { {0x6aa4001a, 0xe5a300aa, 0x98a00521, 0x00000000}},  //   mnif, бици, jtić_,
  { {0x628200b5, 0xbebd0089, 0x00000000, 0x00000000}},  //   _sloo, ltīt,   ,
  { {0x6282109a, 0xe61a3e5d, 0xf48700a2, 0x00000000}},  //   _ploo, _пдв_, دانی,
  { {0x75d60076, 0x98a0016c, 0x2cba0022, 0x00000000}},  //   _ميزا, ftić_, _lkpd_,
  { {0xddcd037e, 0x81dc0055, 0x83fc0363, 0x00000000}},  //   _slaž, তুন_, _anđe,
  { {0xddcd073a, 0x83fc0521, 0x63a4006b, 0x00000000}},  //   _plaž, _vođs, şinq,
  { {0x6aa401e5, 0x2fd800f8, 0xe475007e, 0x00000000}},  //   knif, ärg_, _тутэ,
  { {0x91e60057, 0xddcd02db, 0xb5fd012d, 0x00000000}},  //   _соде, _vlaž, _uošt,
  { {0x7ae508b2, 0x7e7d00ea, 0xd041006b, 0x00000000}},  //   _suht, rksp, hmlə,
  { {0x7ae503b6, 0xa3cb0309, 0x7e7d0203, 0x00000000}},  //   _puht, रेक_, sksp,
  { {0x8aa703f3, 0xb87b002a, 0xddcd037e, 0x00000000}},  //   град, _suío, _ulaž,
  { {0x68e60d22, 0x00000000, 0x00000000, 0x00000000}},  //   _bukd,   ,   ,
  { {0x38c90167, 0x764201df, 0x290f3e5e, 0x00000000}},  // [edf0] نائی_, deoy, éga_,
  { {0x61fb013f, 0x37ab0478, 0x68e600e0, 0x00000000}},  //   zbul, нтен_, _dukd,
  { {0x61fb3e5f, 0x61e21091, 0x00000000, 0x00000000}},  //   ybul, _ogol,   ,
  { {0x6aa40d62, 0x635c001a, 0x61e2005b, 0x00000000}},  //   cnif, _mănă, _ngol,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4d7c0049, 0x98a0016c, 0x61e23e60, 0x00000000}},  //   ערגע, vtić_, _agol,
  { {0x9f5c00f6, 0x6265034b, 0x7d1d3230, 0x00000000}},  //   _nevà_, ивка, hrss,
  { {0xbb3c0049, 0x00000000, 0x00000000, 0x00000000}},  //   געהי,   ,   ,
  { {0xb42704e8, 0xd538031d, 0x6a78000c, 0x00000000}},  //   _معاو, _مثلا_, _gífu,
  { {0x25bf005f, 0x61e201d6, 0x3ea900b0, 0x00000000}},  //   _iyul_, _egol, _ajat_,
  { {0x20540147, 0x98a00091, 0xa3cb0061, 0x00000000}},  //   стыр, stić_, रेख_,
  { {0x64430620, 0x3a3900ca, 0x2cba023a, 0x00000000}},  //   leni, _nbsp_, _skpd_,
  { {0x6cc60088, 0xfce6041f, 0xa3e90061, 0x00000000}},  //   ийма, рого, _यला_,
  { {0x629b010a, 0x64433e61, 0xceb90036, 0x00000000}},  //   liuo, neni, stęp_,
  { {0xdca318ea, 0xa09a00a3, 0x442700ab, 0x00000000}},  //   цари, _ביסט, ign_,
  { {0x6443002d, 0x629b0006, 0x3ea90023, 0x00000000}},  //   heni, niuo, _gjat_,
  { {0x6443049b, 0x2007008d, 0x6aa4254e, 0x00000000}},  // [ee00] keni, _keni_, rnif,
  { {0x644304a9, 0x2007008d, 0xbebd001e, 0x00000000}},  //   jeni, _jeni_, stīt,
  { {0x64430027, 0x20073e62, 0x2cb80190, 0x00000000}},  //   deni, _meni_, mord_,
  { {0x7d0401d5, 0x2cb80039, 0x1f360049, 0x00000000}},  //   _kwis, lord_, ירער_,
  { {0x644300c7, 0x9f4e01aa, 0xd627007c, 0x00000000}},  //   feni, _jefò_, роче_,
  { {0x7d04000b, 0x20073e63, 0xd7f20025, 0x00000000}},  //   _mwis, _neni_, _ذكر_,
  { {0xd4090025, 0x25ad0fab, 0x00000000, 0x00000000}},  //   اتهم_, _exel_,   ,
  { {0xd257008b, 0x66e3008b, 0xddcd3e64, 0x00000000}},  //   аць_, _фота, _plaż,
  { {0x64433e65, 0x30a620f2, 0x2cb8039e, 0x00000000}},  //   beni, иров, kord_,
  { {0x64430821, 0x20070059, 0x2cb805d5, 0x00000000}},  //   ceni, _ceni_, jord_,
  { {0x9ed900ed, 0x20070020, 0x7d04002b, 0x00000000}},  //   лмот_, _deni_, _awis,
  { {0x7d040058, 0x61e20026, 0xefcc014a, 0x00000000}},  //   _bwis, _ugol, _ışığ,
  { {0x6a78000c, 0xb87b0051, 0x2cb800ab, 0x00000000}},  //   _lífs, _suím, ford_,
  { {0x20070016, 0x2cb8009d, 0x3a2b00fa, 0x00000000}},  //   _geni_, gord_, _sccp_,
  { {0xb87b1383, 0x200c0583, 0x442c0145, 0x00000000}},  //   _quím, madi_, _mcd_,
  { {0x64431191, 0x200c3e66, 0x20070107, 0x00000000}},  //   zeni, ladi_, _zeni_,
  { {0x200701f6, 0x2cb801bf, 0x6443014a, 0x00000000}},  // [ee10] _yeni_, bord_, yeni,
  { {0x3eb9037b, 0x6d4d011c, 0x2cb8030a, 0x00000000}},  //   lost_, _isaa, cord_,
  { {0x7d04001f, 0x64432256, 0xac9900a1, 0x00000000}},  //   _zwis, veni, _لنکا_,
  { {0x64433e67, 0x4fd90049, 0xc6a43e68, 0x00000000}},  //   weni, אַנד, орчи,
  { {0x64430027, 0x442c0190, 0x200c0020, 0x00000000}},  //   teni, _bcd_, kadi_,
  { {0x6d4d000b, 0x200c01a3, 0x39490022, 0x00000000}},  //   _msaa, jadi_, mwas_,
  { {0x64433178, 0x26cd00ad, 0x6289002a, 0x00000000}},  //   reni, _theo_, theo,
  { {0x3e7b008d, 0x20073e69, 0x6d4d00b0, 0x00000000}},  //   _këtu_, _seni_, _osaa,
  { {0x3eb9037b, 0x64430142, 0x629b010a, 0x00000000}},  //   dost_, peni, riuo,
  { {0x6e2d06c0, 0x14740054, 0x442c096b, 0x00000000}},  //   _acab, _والج, _gcd_,
  { {0x160b02f4, 0x2007001a, 0x187800a0, 0x00000000}},  //   _हजार_, _veni_, יעזר_,
  { {0x7d0401aa, 0x5c270044, 0x39493e6a, 0x00000000}},  //   _pwis, য়োগ_, kwas_,
  { {0x200c04cb, 0x66093e6b, 0x200706af, 0x00000000}},  //   badi_, _meek, _teni_,
  { {0xab2a06b6, 0x200c00d4, 0x644e00c4, 0x00000000}},  //   лога_, cadi_, _óbit,
  { {0x8fa201fe, 0x3eb9002d, 0x9ef50379, 0x00000000}},  //   _наше, bost_, _استش,
  { {0x4f1600bd, 0x2cb800eb, 0x3eb90ca4, 0x00000000}},  //   _פֿון_, sord_, cost_,
  { {0x7e641d4b, 0x7d040009, 0xfd1f0026, 0x00000000}},  // [ee20] _inip, _uwis, crì_,
  { {0xe9d705a4, 0x81ac0044, 0xb80a0025, 0x00000000}},  //   ску_, _গরম_, ايام_,
  { {0x442c00d4, 0x660900bb, 0x7e6400b5, 0x00000000}},  //   _rcd_, _beek, _knip,
  { {0x5fba007b, 0x200c01ee, 0x6b810637, 0x00000000}},  //   אצענ, zadi_, ølge,
  { {0x200c0093, 0x442c0810, 0x00000000, 0x00000000}},  //   yadi_, _pcd_,   ,
  { {0x7aed0010, 0x62991519, 0x00000000, 0x00000000}},  //   _öltö, _amwo,   ,
  { {0x33170054, 0x200c0059, 0xd467003b, 0x00000000}},  //   مزيد_, vadi_, сије_,
  { {0x66090ace, 0x9695098c, 0x200c0020, 0x00000000}},  //   _geek, _друш, wadi_,
  { {0xe1ef023c, 0x200c1b43, 0x2912011c, 0x00000000}},  //   رسي_, tadi_, nsya_,
  { {0xdefa00a5, 0x6e2d048c, 0xf48400a6, 0x00000000}},  //   лым_, _scab, _باری,
  { {0x200c01d9, 0xea000082, 0x6d4d0009, 0x00000000}},  //   radi_, _ngắt_, _ssaa,
  { {0x200c3e6c, 0xb7db0049, 0xf773009b, 0x00000000}},  //   sadi_, טקיי, לקת_,
  { {0xa133007a, 0x3eb905c9, 0x7e6401f3, 0x00000000}},  //   _فروش, rost_, _dnip,
  { {0x68fb0065, 0x3eb900d2, 0x00000000, 0x00000000}},  //   _çudi, sost_,   ,
  { {0x3eb92df6, 0x00000000, 0x00000000, 0x00000000}},  //   post_,   ,   ,
  { {0x139b007b, 0xbea4025f, 0x3d120061, 0x00000000}},  //   אבלע, _најк, _तिचे_,
  { {0x660900c7, 0x66e50006, 0x98750751, 0x00000000}},  // [ee30] _reek, _lėkt, олац,
  { {0x66093e6d, 0x3b130082, 0x394901d6, 0x00000000}},  //   _seek, _tvxq_, rwas_,
  { {0x39490300, 0x00000000, 0x00000000, 0x00000000}},  //   swas_,   ,   ,
  { {0x80ac0061, 0x00000000, 0x00000000, 0x00000000}},  //   ीकडे,   ,   ,
  { {0xd1261095, 0x660901c2, 0x0608007e, 0x00000000}},  //   _تم_, _veek, снік_,
  { {0x66090038, 0x1bfb0164, 0x22ac00b9, 0x00000000}},  //   _week, ्रिल_, věka_,
  { {0x6609006c, 0xa3d40164, 0x00000000, 0x00000000}},  //   _teek, सेल_,   ,
  { {0xc7b2009b, 0x12b90044, 0x00000000, 0x00000000}},  //   _חבל_, ুদ্দ,   ,
  { {0x940e005f, 0xc42b0151, 0xe573023c, 0x00000000}},  //   hifə_, _مثال_, _عطر_,
  { {0x60090cb3, 0x00000000, 0x00000000, 0x00000000}},  //   шном_,   ,   ,
  { {0xbebd001e, 0xcdc9061e, 0xfe460764, 0x00000000}},  //   drīb, _סך_, онно,
  { {0x3f8b0036, 0x62993e6e, 0x00000000, 0x00000000}},  //   ącu_, _umwo,   ,
  { {0x2d840161, 0xa2c60061, 0x3f831032, 0x00000000}},  //   áme_, ातर्, šju_,
  { {0x2b41000a, 0x00000000, 0x00000000, 0x00000000}},  //   _bphc_,   ,   ,
  { {0x4a9a007e, 0x7ebd1f1f, 0x00000000, 0x00000000}},  //   атаў_, répr,   ,
  { {0x2912000a, 0xada6004d, 0x394600c4, 0x00000000}},  //   tsya_, _майл, çoso_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [ee40]   ,   ,   ,
  { {0x7d16013e, 0x291200e0, 0x00000000, 0x00000000}},  //   _ivys, rsya_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7c3e00fa, 0x00000000, 0x00000000, 0x00000000}},  //   _kbpr,   ,   ,
  { {0x7ae3004a, 0x00000000, 0x00000000, 0x00000000}},  //   _éntr,   ,   ,
  { {0x4420011f, 0xa2c60061, 0xe8000061, 0x00000000}},  //   ği_, ातल्, _ल्या_,
  { {0x1fcf0044, 0x44203e6f, 0x260b0204, 0x00000000}},  //   রশাস, şi_, ारणी_,
  { {0xe5a3003b, 0xdcea00b9, 0x940e006b, 0x00000000}},  //   _жити, čněj, zifə_,
  { {0x6602002d, 0x44380009, 0x26c601b1, 0x00000000}},  //   lbok, _ùr_, lloo_,
  { {0x44f000ad, 0x38780ea9, 0x443e0082, 0x00000000}},  //   _hà_, _morr_, _ibt_,
  { {0xd2501847, 0x443e3e70, 0x26c618bd, 0x00000000}},  //   _سنت_, _hbt_, nloo_,
  { {0xd12f0025, 0x7c3e3e71, 0x61a5007d, 0x00000000}},  //   _لمن_, _bbpr, खपृष,
  { {0x44f03e72, 0x443e0973, 0xbf14007a, 0x00000000}},  //   _mà_, _jbt_, _فوتب,
  { {0x44f02811, 0x443e26ec, 0x040f0044, 0x00000000}},  //   _là_, _mbt_, _সামী_,
  { {0x7c3e0061, 0x443e0066, 0x940e006b, 0x00000000}},  //   _ebpr, _lbt_, rifə_,
  { {0x44f00011, 0x66020056, 0x81dc0044, 0x00000000}},  // [ee50] _nà_, dbok, তুর_,
  { {0x38780048, 0x6d5f002b, 0x752214a6, 0x00000000}},  //   _corr_, _irqa, droz,
  { {0x63bc0374, 0x00000000, 0x00000000, 0x00000000}},  //   _ørnh,   ,   ,
  { {0x44f0001d, 0x443e0d78, 0x66020c73, 0x00000000}},  //   _bà_, _abt_, gbok,
  { {0x44f00011, 0x75220089, 0x443e0785, 0x00000000}},  //   _cà_, groz, _bbt_,
  { {0x44f00207, 0x69cf198c, 0xb97a009b, 0x00000000}},  //   _dà_, _izce, _הנשי,
  { {0x8c44005f, 0x660201c3, 0x00000000, 0x00000000}},  //   əşdi, bbok,   ,
  { {0x6d5f005f, 0x44f00197, 0x443e000a, 0x00000000}},  //   _orqa, _fà_, _ebt_,
  { {0x44f00011, 0x27351a95, 0x75220035, 0x00000000}},  //   _gà_, lån_, croz,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x81dc0044, 0x00000000, 0x00000000, 0x00000000}},  //   তুল_,   ,   ,
  { {0xe3b20049, 0xee3f04bb, 0x00000000, 0x00000000}},  //   _אױב_, bným_,   ,
  { {0x81a700f3, 0x44f00011, 0x0d83005e, 0x00000000}},  //   _بحال, _xà_, елян,
  { {0x7bc50146, 0x00000000, 0x00000000, 0x00000000}},  //   _byhu,   ,   ,
  { {0x7bc50016, 0x00000000, 0x00000000, 0x00000000}},  //   _cyhu,   ,   ,
  { {0x6486009f, 0x2a790016, 0x6b8100ea, 0x00000000}},  //   _aðil, _cosb_, ølga,
  { {0xa96701c0, 0x387800f8, 0xad9b000c, 0x00000000}},  // [ee60] пита_, _porr_, lbún,
  { {0x13e30055, 0x3ea2138f, 0x44f00082, 0x00000000}},  //   নুয়, likt_, _rà_,
  { {0xb8f302fb, 0x2d820007, 0x44f02de5, 0x00000000}},  //   _ही_, lyke_, _sà_,
  { {0x443e0181, 0xe7b30014, 0x44f00082, 0x00000000}},  //   _sbt_, رمند, _pà_,
  { {0x387800f8, 0x26c606fa, 0x6602063d, 0x00000000}},  //   _torr_, rloo_, rbok,
  { {0x44f000ad, 0x661b022b, 0x290000b0, 0x00000000}},  //   _và_, _eduk, mpia_,
  { {0xf74301ee, 0x6602012d, 0x6ac700c4, 0x00000000}},  //   _перо, pbok, _órfã,
  { {0x60f801e0, 0x44f00011, 0xdb23009d, 0x00000000}},  //   ония_, _tà_, érée,
  { {0x850600a6, 0x7ae63e73, 0xf1a3007e, 0x00000000}},  //   _روان, _mikt, ерэн,
  { {0x67230825, 0x628b028d, 0xf8be013d, 0x00000000}},  //   šnje, _elgo, ्तिय,
  { {0x3d0f001c, 0x644a0020, 0x6d4400c4, 0x00000000}},  //   तीने_, mefi, _apia,
  { {0x64582313, 0xd24f0014, 0x7ae60142, 0x00000000}},  //   ldvi, _منم_, _nikt,
  { {0x601809b5, 0x00000000, 0x00000000, 0x00000000}},  //   _доля_,   ,   ,
  { {0x32e70082, 0x9ce402be, 0x00000000, 0x00000000}},  //   _tđyt_, ецсл,   ,
  { {0x7ae6149a, 0x00000000, 0x00000000, 0x00000000}},  //   _bikt,   ,   ,
  { {0x644a0016, 0x27350039, 0x69c60146, 0x00000000}},  //   hefi, vån_, _byke,
  { {0x69c60193, 0x78be01d6, 0x00000000, 0x00000000}},  // [ee70] _cyke, fopv,   ,
  { {0x69c60039, 0xed600006, 0x6e3d01a2, 0x00000000}},  //   _dyke, įžti_, lfsb,
  { {0x644a049a, 0x6d5d22d6, 0x65603e74, 0x00000000}},  //   defi, lvsa, _armh,
  { {0x27350039, 0x1a65025a, 0x395200b0, 0x00000000}},  //   rån_, _تیری_, änsä_,
  { {0x69cf0089, 0x00000000, 0x00000000, 0x00000000}},  //   _uzce,   ,   ,
  { {0x644a000c, 0x260b0061, 0x201c0288, 0x00000000}},  //   gefi, ारही_, _ndvi_,
  { {0x2eee1a90, 0xe738007c, 0xe299007e, 0x00000000}},  //   _nuff_, _неё_, жай_,
  { {0x6aad000c, 0x6458222b, 0x6e3d00bb, 0x00000000}},  //   nnaf, advi, jfsb,
  { {0xd12e0379, 0xc4f80380, 0x644a01a2, 0x00000000}},  //   لمي_, _فعلا_, befi,
  { {0x76591915, 0xef190364, 0x644a3e75, 0x00000000}},  //   ldwy, омо_, cefi,
  { {0x6d443e76, 0x200e01aa, 0x3ea20089, 0x00000000}},  //   _spia, _defi_, tikt_,
  { {0xada6008b, 0x6da6003b, 0xad9b000c, 0x00000000}},  //   дамл, дима, rbún,
  { {0x7ae61e82, 0x3ea20056, 0x61eb2ab8, 0x00000000}},  //   _rikt, rikt_, _iggl,
  { {0x61420081, 0x7ae60039, 0x69c601c3, 0x00000000}},  //   _реша, _sikt, _ryke,
  { {0xfce33e77, 0x7ae60993, 0x6441314b, 0x00000000}},  //   торо, _pikt, _mbli,
  { {0x764b0010, 0x644a0023, 0x6aad01e5, 0x00000000}},  //   jegy, zefi, gnaf,
  { {0x7ae6067e, 0x7659018e, 0x68e700b5, 0x00000000}},  // [ee80] _vikt, ddwy, _bijd,
  { {0x7ae6049a, 0x9f4700f6, 0xc9d500a1, 0x00000000}},  //   _wikt, _agné_, رملک,
  { {0x7ae60485, 0x644a01e5, 0x78be0328, 0x00000000}},  //   _tikt, vefi, ropv,
  { {0x29001c89, 0xd9100123, 0xb87b00c4, 0x00000000}},  //   ppia_, _میر_, _suít,
  { {0x6aa40020, 0x1fba0164, 0x20c2000c, 0x00000000}},  //   miif, _उड्ड, iðir_,
  { {0x741401d8, 0x61eb009d, 0xe1ff008e, 0x00000000}},  //   روبا, _aggl, ñón_,
  { {0x17790057, 0x644a0036, 0x645802e1, 0x00000000}},  //   _есть_, refi, rdvi,
  { {0x644a00f8, 0x2eee01d6, 0x68e700b5, 0x00000000}},  //   sefi, _ruff_, _zijd,
  { {0x321d0016, 0x79840020, 0x644a0035, 0x00000000}},  //   _ddwy_, nyiw, pefi,
  { {0x3ea00047, 0x61eb0635, 0x200e0023, 0x00000000}},  //   _amit_, _eggl, _qefi_,
  { {0x98a90036, 0x93460088, 0x20c2000c, 0x00000000}},  //   stać_, _інде, fðir_,
  { {0x64410036, 0x2ca300bb, 0x20c2000c, 0x00000000}},  //   _zbli, wijd_, gðir_,
  { {0x2ca302ae, 0x200501d5, 0xbebd0089, 0x00000000}},  //   tijd_, bbli_, brīn,
  { {0x3ea03e78, 0x2eee00f8, 0x6d5d0190, 0x00000000}},  //   _emit_, _tuff_, rvsa,
  { {0x68e700b5, 0x2ca300b5, 0x8ff703e6, 0x00000000}},  //   _rijd, rijd_, _غرور_,
  { {0xbcfb0047, 0x63bc00ea, 0x68e73e79, 0x00000000}},  //   tvéd, _ørnu, _sijd,
  { {0x5ea40025, 0x6aad000c, 0x127b0049, 0x00000000}},  // [ee90] _جميل, rnaf, קאמע,
  { {0x7d0d03ea, 0xd795005e, 0x98a4003b, 0x00000000}},  //   _iwas, низъ, виђе,
  { {0x764b1cbc, 0x00000000, 0x00000000, 0x00000000}},  //   tegy,   ,   ,
  { {0x7d0d10b4, 0x3dc900e0, 0x68e700bb, 0x00000000}},  //   _kwas, _kyaw_, _wijd,
  { {0x68e702ae, 0x79960036, 0x76591ffe, 0x00000000}},  //   _tijd, czyw, rdwy,
  { {0x7d0d1b6f, 0x00000000, 0x00000000, 0x00000000}},  //   _mwas,   ,   ,
  { {0x5695041f, 0x66f40545, 0x00000000, 0x00000000}},  //   _завт, _апсу,   ,
  { {0xd24e0025, 0xe3b003ec, 0x7d0d0146, 0x00000000}},  //   منى_, جره_, _owas,
  { {0x6353006b, 0x3ea03e7a, 0x2fc731e6, 0x00000000}},  //   _mənə, _rmit_, _syng_,
  { {0x3ea000c7, 0x00000000, 0x00000000, 0x00000000}},  //   _smit_,   ,   ,
  { {0x3dc9006a, 0x7d0d0518, 0x3f69017a, 0x00000000}},  //   _ayaw_, _awas, чино_,
  { {0x7d0d01aa, 0xdd1e001a, 0x2018000c, 0x00000000}},  //   _bwas, _câşt, órir_,
  { {0x20c2009f, 0x6114007e, 0x224d0032, 0x00000000}},  //   rðir_, _адчу, meek_,
  { {0x224d002d, 0x62890190, 0x7d0d01d6, 0x00000000}},  //   leek_, lkeo, _dwas,
  { {0xcb67003b, 0x60c10058, 0x00000000, 0x00000000}},  //   наре_, molm,   ,
  { {0x224d0032, 0x7d0d000a, 0xdd1e00e5, 0x00000000}},  //   neek_, _fwas, _gâşt,
  { {0x7d0d0bc4, 0x6aa4010e, 0x00000000, 0x00000000}},  // [eea0] _gwas, riif,   ,
  { {0x224d00b5, 0x6d563e7b, 0x81dc0044, 0x00000000}},  //   heek_, _isya, তুক_,
  { {0xbcfb009d, 0x7ceb002b, 0x6353006b, 0x00000000}},  //   rvée, _iżra, _fənə,
  { {0x60c10073, 0x83fc0521, 0xe6120151, 0x00000000}},  //   holm, _inđi, اشا_,
  { {0xe89b038c, 0x224d002d, 0x64a6007e, 0x00000000}},  //   _çağı, deek_, нада,
  { {0x672310ec, 0x39520016, 0x6d5600e0, 0x00000000}},  //   šnja, mwys_, _msya,
  { {0x3952018e, 0xe8be0061, 0x60c10026, 0x00000000}},  //   lwys_, ्तीच, dolm,
  { {0x09e40044, 0x224d0032, 0x66e3025f, 0x00000000}},  //   _ফ্যা, geek_, _боса,
  { {0xf1db0061, 0x39521c26, 0x05663e7c, 0x00000000}},  //   मेलन, nwys_, _яван,
  { {0x7d0d0009, 0x89370049, 0x80ca013d, 0x00000000}},  //   _rwas, עריע_, _सीखे,
  { {0x6e950081, 0x7d0d3e7d, 0x224d162d, 0x00000000}},  //   вину, _swas, beek_,
  { {0x645a1bd2, 0x7d0d01aa, 0xf3ff0011, 0x00000000}},  //   _hati, _pwas, _đãi_,
  { {0x645a0be3, 0x225100b9, 0xa06a003b, 0x00000000}},  //   _kati, ánků_, _нада_,
  { {0x6353005f, 0x645a023a, 0x60c108d3, 0x00000000}},  //   _sənə, _jati, colm,
  { {0x5b2406e7, 0x2bd60061, 0xc87f01a2, 0x00000000}},  //   льта, _धरणा, _mußt_,
  { {0x7d0d3e7e, 0x645a3e7f, 0x3952005b, 0x00000000}},  //   _twas, _lati, fwys_,
  { {0x7e6d28d4, 0x7ebd0010, 0xc98400ed, 0x00000000}},  // [eeb0] _inap, képz, луфи,
  { {0x645a066d, 0x7e6d01e5, 0x00000000, 0x00000000}},  //   _nati, _hnap,   ,
  { {0x7e6d067e, 0xf3f10011, 0x9f5e004a, 0x00000000}},  //   _knap, _bạn_, mató_,
  { {0x224d3ac8, 0x9f5e1ae2, 0x00000000, 0x00000000}},  //   xeek_, lató_,   ,
  { {0x645a0390, 0xddc4001a, 0xe3b8006b, 0x00000000}},  //   _bati, _iniţ, _axı_,
  { {0x645a3e80, 0x224d0343, 0x634a006b, 0x00000000}},  //   _cati, week_, _mənf,
  { {0x224d1cbf, 0x60c10026, 0x645a066d, 0x00000000}},  //   teek_, volm, _dati,
  { {0x75240107, 0x9f5e0010, 0xd90e00a1, 0x00000000}},  //   šiza, ható_, _دیے_,
  { {0xb3eb01fa, 0x224d3e81, 0x62890146, 0x00000000}},  //   _فعال_, reek_, rkeo,
  { {0x7e6d0020, 0x224d0a5f, 0x62890190, 0x00000000}},  //   _anap, seek_, skeo,
  { {0xb4cd007d, 0x932700a6, 0xe47a0049, 0x00000000}},  //   रती_, _سران, _קרעכ,
  { {0x645a0027, 0xdc0a0309, 0x41750025, 0x00000000}},  //   _zati, वर्ड_, _لاتس,
  { {0xe1f0006d, 0x50b50c19, 0x645a0518, 0x00000000}},  //   _اسم_, _иску, _yati,
  { {0x64940061, 0x645a006b, 0x9f5e0010, 0x00000000}},  //   _gàid, _xati, gató_,
  { {0xaac600b8, 0x80ca013d, 0x00000000, 0x00000000}},  //   نترن, _सीटे,   ,
  { {0x7e6d0026, 0x00000000, 0x00000000, 0x00000000}},  //   _gnap,   ,   ,
  { {0xea000011, 0x9f5e07f0, 0xc212009b, 0x00000000}},  // [eec0] _ngất_, bató_, יהן_,
  { {0xe9d70822, 0x39520007, 0x7c8501fc, 0x00000000}},  //   тку_, rwys_, _буџе,
  { {0x645a0038, 0xe3b80276, 0x00000000, 0x00000000}},  //   _rati, _adın_,   ,
  { {0x9bb700b6, 0x645a191c, 0x68ed010a, 0x00000000}},  //   _יהיה_, _sati, _žodž,
  { {0x645a1ed9, 0x9553067a, 0x00000000, 0x00000000}},  //   _pati, لخوا,   ,
  { {0x645a3e82, 0x00000000, 0x00000000, 0x00000000}},  //   _qati,   ,   ,
  { {0x07a63e83, 0x0396005e, 0x98a301ee, 0x00000000}},  //   _равн, ърдя, _тире,
  { {0xcb13009b, 0x357300a1, 0x645a0020, 0x00000000}},  //   בלה_, _چھوڑ, _wati,
  { {0x645a3e84, 0x273c2be1, 0x00000000, 0x00000000}},  //   _tati, lín_,   ,
  { {0x764200d2, 0x00000000, 0x00000000, 0x00000000}},  //   lfoy,   ,   ,
  { {0x273c3e85, 0x00000000, 0x00000000, 0x00000000}},  //   nín_,   ,   ,
  { {0x61fb0912, 0xad9b000c, 0x00000000, 0x00000000}},  //   ccul, lbúi,   ,
  { {0x9f5e0047, 0x7e6d0059, 0x273c0051, 0x00000000}},  //   tató_, _vnap, hín_,
  { {0x273c15e3, 0x00000000, 0x00000000, 0x00000000}},  //   kín_,   ,   ,
  { {0x9f5e3e86, 0x273c0142, 0x2ac7003b, 0x00000000}},  //   rató_, jín_, вљав,
  { {0x31660119, 0x7e6d2094, 0x9ab4007e, 0x00000000}},  //   _kroz_, _unap, айсц,
  { {0x2ab701d5, 0x22460093, 0x9f5e004a, 0x00000000}},  // [eed0] għba_, _mbok_, pató_,
  { {0x634a005f, 0x7d1b0285, 0xad1c009b, 0x00000000}},  //   _kənd, áusu, _חוזר,
  { {0xb8fa007d, 0x22460036, 0x59d50061, 0x00000000}},  //   _डी_, _obok_, _दरवर,
  { {0x67230091, 0x634a006b, 0xbebd0089, 0x00000000}},  //   šnjo, _zəng, drīk,
  { {0x45450054, 0x961d0089, 0xcad60104, 0x00000000}},  //   انتق, _noņe, _תורת_,
  { {0x85b80025, 0xb4cd007d, 0x273c0142, 0x00000000}},  //   خامس_, रते_, bín_,
  { {0x4429027d, 0x273c3e87, 0xf6e7007e, 0x00000000}},  //   ğa_, cín_, _ацан,
  { {0x31660107, 0x442915ec, 0xf3f10082, 0x00000000}},  //   _broz_, şa_, _tạo_,
  { {0x10150b52, 0x22460022, 0xddc60036, 0x00000000}},  //   льня, _dbok_, zekł,
  { {0x205500ed, 0x634a006b, 0x26cf1c91, 0x00000000}},  //   утир, _bənd, llgo_,
  { {0x7c380073, 0x44f9001d, 0x25d30067, 0x00000000}},  //   _övri, _hè_, _तरुण,
  { {0x44f92115, 0x634a013f, 0x00000000, 0x00000000}},  //   _kè_, _səng,   ,
  { {0x394b0c0d, 0x273c0d7f, 0x25e6013d, 0x00000000}},  //   _npcs_, zín_, जेपी_,
  { {0x44f92ef4, 0x6cd60025, 0x25d60049, 0x00000000}},  //   _mè_, اقسا, טורן_,
  { {0x44f90607, 0xeb9a0242, 0x00000000, 0x00000000}},  //   _lè_, хив_,   ,
  { {0x225f0169, 0x273c0142, 0x29020022, 0x00000000}},  //   nduk_, vín_, _ptka_,
  { {0x44f93e88, 0x213f003f, 0x66d115b3, 0x00000000}},  // [eee0] _nè_, ntuh_, råkl,
  { {0x2ab7002b, 0xc8ca01fa, 0xb4cd0204, 0x00000000}},  //   rħba_, روان_, रतो_,
  { {0xbcfb00f4, 0xfaa60140, 0xa6e90082, 0x00000000}},  //   nvén, _бано, _thự,
  { {0x44f9001d, 0x273c113f, 0x225f016e, 0x00000000}},  //   _bè_, rín_, jduk_,
  { {0x44f9159f, 0x997500ed, 0x273c0051, 0x00000000}},  //   _cè_, _курш, sín_,
  { {0x44f92110, 0x2a60288d, 0x394019f0, 0x00000000}},  //   _dè_, ldib_, mtis_,
  { {0x39400006, 0x66190036, 0x4394007e, 0x00000000}},  //   ltis_, bawk, райс,
  { {0x44f90607, 0x7d040091, 0x6e240009, 0x00000000}},  //   _fè_, _otis, _ndib,
  { {0x3940010a, 0x225d01d5, 0x44f901aa, 0x00000000}},  //   ntis_, _dawk_, _gè_,
  { {0x395700b6, 0x6e24022b, 0x39400006, 0x00000000}},  //   נשים_, _adib, itis_,
  { {0x7d040173, 0x3940006c, 0xdef7007e, 0x00000000}},  //   _atis, htis_, лыя_,
  { {0x44f901aa, 0x61f60025, 0x00000000, 0x00000000}},  //   _yè_, _إساء,   ,
  { {0xeda72e2d, 0xb5fd0b8e, 0x6e240016, 0x00000000}},  //   ушно, _inšt, _ddib,
  { {0x6e24005f, 0x62823e89, 0x26c60085, 0x00000000}},  //   _edib, _hooo, hooo_,
  { {0x7777027b, 0x7d1d19da, 0x39400dec, 0x00000000}},  //   xxxx, ssss, etis_,
  { {0x8c44006b, 0x628204eb, 0x2b5a00d4, 0x00000000}},  //   əşmi, _jooo, _dspc_,
  { {0x39400006, 0x26c61aa3, 0x7dec0089, 0x00000000}},  // [eef0] gtis_, dooo_, _cēsī,
  { {0xddc40182, 0x634a006b, 0x6d4d011c, 0x00000000}},  //   _uniš, _mənb, _ipaa,
  { {0x501b00b6, 0x44f915de, 0x68ee011c, 0x00000000}},  //   גובו, _sè_, _dibd,
  { {0x44f90263, 0x395900d9, 0x394000f6, 0x00000000}},  //   _pè_, _tsss_, btis_,
  { {0x39403e8a, 0xfd1f0197, 0xbcfb0010, 0x00000000}},  //   ctis_, nsì_, zvén,
  { {0x44f93e8b, 0x290900b0, 0x6385007c, 0x00000000}},  //   _vè_, mpaa_, игла,
  { {0x44f90607, 0xe1f10025, 0x7af70032, 0x00000000}},  //   _wè_, يسة_, _juxt,
  { {0x44f90263, 0x26c606c2, 0x7af7006b, 0x00000000}},  //   _tè_, cooo_, _muxt,
  { {0x81a80055, 0x62820107, 0x225f014a, 0x00000000}},  //   _খুব_, _dooo, rduk_,
  { {0xe8e0001d, 0x7aef0a16, 0x10a501ee, 0x00000000}},  //   _địa_, _lict, рион,
  { {0x32550077, 0x7d0402db, 0x6d4d3e8c, 0x00000000}},  //   _ввер, _stis, _apaa,
  { {0xbcfb0047, 0x7aef00f6, 0x394006e8, 0x00000000}},  //   rvén, _nict, ytis_,
  { {0x76490020, 0x69cf0173, 0x46560049, 0x00000000}},  //   _mbey, _nyce, בױרן_,
  { {0xab2a3e8d, 0xafe5007c, 0x628200bb, 0x00000000}},  //   кога_, _колл, _zooo,
  { {0x7649192a, 0x44250035, 0x2caa0459, 0x00000000}},  //   _obey, _mdl_, ribd_,
  { {0x39400dac, 0x44253e8e, 0x6569050f, 0x00000000}},  //   ttis_, _ldl_, _oreh,
  { {0x7d0405fa, 0x4425005b, 0xdc0c007f, 0x00000000}},  // [ef00] _utis, _odl_, lėči,
  { {0x3940010a, 0xfd1300a1, 0xd826005e, 0x00000000}},  //   rtis_, _بجٹ_, рджи,
  { {0x3940017b, 0x7aef00ab, 0x634a006b, 0x00000000}},  //   stis_, _fict, _mənc,
  { {0x75240107, 0x44250c2c, 0x0566019d, 0x00000000}},  //   šizm, _adl_, ивен,
  { {0x7ae40f7f, 0x68ee01d5, 0x09e40044, 0x00000000}},  //   mmit, _tibd, _ফ্রা,
  { {0x6569010f, 0x7ae4006c, 0x628205af, 0x00000000}},  //   _dreh, lmit, _sooo,
  { {0x44250197, 0x2d8b0c0f, 0x83fc0091, 0x00000000}},  //   _ddl_, zyce_, _nađe,
  { {0x7ae4000c, 0x59ba0164, 0x6b830129, 0x00000000}},  //   nmit, _इशार, _ànge,
  { {0x65690925, 0x7ae41469, 0x80c20061, 0x00000000}},  //   _greh, imit, रकले,
  { {0x442528cd, 0x00000000, 0x00000000, 0x00000000}},  //   _gdl_,   ,   ,
  { {0x6d4d01b5, 0xa3e20164, 0x260b0061, 0x00000000}},  //   _spaa, नेश_, ारची_,
  { {0x6146008b, 0x628200f6, 0x2d8b0036, 0x00000000}},  //   _веда, _uooo, tyce_,
  { {0xfd47008b, 0x3eab00ab, 0x00000000, 0x00000000}},  //   шэнн, rict_,   ,
  { {0x634a005f, 0xc0e335fb, 0x69cf00b4, 0x00000000}},  //   _gənc, _дочк, _ryce,
  { {0x7aef0038, 0x0b88007c, 0x8aa7007e, 0x00000000}},  //   _pict, асти_, арад,
  { {0xbea4025f, 0x780f0204, 0x6ff80044, 0x00000000}},  //   _мајк, िर्क_, _আজিজ_,
  { {0x6b5c00d8, 0xdd910014, 0x3ea9016e, 0x00000000}},  // [ef10] _pågå, _رود_, _imat_,
  { {0x7af7008e, 0xa3d7013d, 0x7ae4010e, 0x00000000}},  //   _tuxt, _सरल_, amit,
  { {0x7ae43e8f, 0x29090020, 0x44250146, 0x00000000}},  //   bmit, spaa_, _rdl_,
  { {0xd24606ea, 0x656902b2, 0x44250058, 0x00000000}},  //   _عن_, _preh, _sdl_,
  { {0x44250412, 0xbebd0089, 0x00000000, 0x00000000}},  //   _pdl_, brīv,   ,
  { {0xbebd0089, 0x58d4005e, 0xe7870131, 0x00000000}},  //   nsīb, _моят, _кубо,
  { {0xd7950054, 0x3ea900b0, 0xa3d70061, 0x00000000}},  //   _الأخ, _omat_, _सरळ_,
  { {0x163403c8, 0xfbb80104, 0xb5fd10f5, 0x00000000}},  //   _меся, יפות_, _baše,
  { {0x659403f3, 0x4425023a, 0x798d0093, 0x00000000}},  //   _дату, _tdl_, nyaw,
  { {0xdce40868, 0x3ea90127, 0x4425300a, 0x00000000}},  //   _prič, _amat_, _udl_,
  { {0xaec6007e, 0xb4e301f5, 0xd3a7007e, 0x00000000}},  //   йбол, नगी_, _трап,
  { {0x1d0a3e90, 0x29050de0, 0x24851f9d, 0x00000000}},  //   леми_, _član_, _holm_,
  { {0x6aad3240, 0x24850004, 0x26cd00e7, 0x00000000}},  //   diaf, _kolm_, _mkeo_,
  { {0xfc03005e, 0xdce40161, 0x798d2492, 0x00000000}},  //   зпро, _trič, dyaw,
  { {0x634a006b, 0xdca33c05, 0xeb9700e2, 0x00000000}},  //   _kəna, чари, бир_,
  { {0x629b00b0, 0x3ea90361, 0xed5a17a4, 0x00000000}},  //   nhuo, _gmat_, _бои_,
  { {0x7ae40219, 0x634a006b, 0x7c960014, 0x00000000}},  // [ef20] rmit, _məna, _هشدا,
  { {0x7ae40f48, 0xc610007d, 0x3afc32f5, 0x00000000}},  //   smit, ार्य_, _típ_,
  { {0xe7e30309, 0x25bf0035, 0x91c9013d, 0x00000000}},  //   केला_, _axul_, _हुसै,
  { {0x26df000b, 0xad9b00fa, 0x6aad0740, 0x00000000}},  //   _chuo_, mbúr, ciaf,
  { {0xceb3009b, 0x00000000, 0x00000000, 0x00000000}},  //   היא_,   ,   ,
  { {0xb8960054, 0x98a00166, 0x24850048, 0x00000000}},  //   _السع, drić_, _colm_,
  { {0xa3e203d7, 0xa278007c, 0x7ce03e91, 0x00000000}},  //   नें_, ибку_, mörd,
  { {0x634a006b, 0x00000000, 0x00000000, 0x00000000}},  //   _cəna,   ,   ,
  { {0xd0100054, 0xb5fd0134, 0x66020022, 0x00000000}},  //   ولة_, _inšp, mcok,
  { {0x212b2454, 0x00000000, 0x00000000, 0x00000000}},  //   ácha_,   ,   ,
  { {0x443e01a3, 0xbebd0089, 0x66d804bb, 0x00000000}},  //   _ict_, krīt, níko,
  { {0x7d16018e, 0x7ce00788, 0x2ee001aa, 0x00000000}},  //   _bwys, hörd, _chif_,
  { {0xf1b90825, 0x443e00fa, 0x00000000, 0x00000000}},  //   taše_, _kct_,   ,
  { {0xc0aa0123, 0x67230825, 0xfaf30025, 0x00000000}},  //   _حاصل_, šnji, كثر_,
  { {0x201e1158, 0xf1b925ec, 0x443e00fa, 0x00000000}},  //   mati_, raše_, _mct_,
  { {0x201e001b, 0x7d79026c, 0x3ea90169, 0x00000000}},  //   lati_, _نمبر_, _umat_,
  { {0x6aad22c2, 0x7ce003a9, 0xad2700a1, 0x00000000}},  // [ef30] riaf, förd, _اربو,
  { {0x201e01bc, 0x798d0169, 0x443e0082, 0x00000000}},  //   nati_, ryaw, _nct_,
  { {0x23a702fb, 0x798d0093, 0x69c10036, 0x00000000}},  //   _केंद, syaw, _śled,
  { {0x3eb914b4, 0x443e00ab, 0xf7700137, 0x00000000}},  //   nnst_, _act_, عال_,
  { {0x201e0be3, 0x2a3a007b, 0x3eb900ab, 0x00000000}},  //   kati_, _דערמ, inst_,
  { {0x201e0340, 0x634a006b, 0xd4690140, 0x00000000}},  //   jati_, _səna, рике_,
  { {0x68ff001c, 0x201e0209, 0xa5c30036, 0x00000000}},  //   lqqd, dati_, _łódz,
  { {0xcfce0044, 0x38630ea9, 0x634a006b, 0x00000000}},  //   রধান, _hajr_, _qəna,
  { {0x2ee0018e, 0x201e0fe0, 0x38630066, 0x00000000}},  //   _rhif_, fati_, _kajr_,
  { {0x4f250407, 0x3eb905c6, 0x661b00d9, 0x00000000}},  //   одоб, enst_, _heuk,
  { {0x661b00b5, 0x56b50049, 0x629b0082, 0x00000000}},  //   _keuk, ַפֿן_, phuo,
  { {0x7d16018e, 0x7af80010, 0x661b00bb, 0x00000000}},  //   _pwys, _évti, _jeuk,
  { {0x7ce0010f, 0x7c3e0203, 0x00000000, 0x00000000}},  //   höre, _pcpr,   ,
  { {0x201e0198, 0xb87b00d4, 0x3f690088, 0x00000000}},  //   cati_, _guíx, _вико_,
  { {0xe519013d, 0x00000000, 0x00000000, 0x00000000}},  //   नीति_,   ,   ,
  { {0x83fc0091, 0x00000000, 0x00000000, 0x00000000}},  //   _mađa,   ,   ,
  { {0xed5a0265, 0xd943007c, 0xf8aa0816, 0x00000000}},  // [ef40] _топ_, мети, авак_,
  { {0x7ce00039, 0x7e6427ce, 0x00000000, 0x00000000}},  //   före, _haip,   ,
  { {0x160a0025, 0xc8150088, 0x7e6400b0, 0x00000000}},  //   لياً_, яєть, _kaip,
  { {0x201e0209, 0x443e07b0, 0x7e640145, 0x00000000}},  //   zati_, _sct_, _jaip,
  { {0x443e161c, 0x7e64011c, 0x6d460056, 0x00000000}},  //   _pct_, _maip, ntka,
  { {0x7e640d90, 0x6c7a0049, 0x6d460145, 0x00000000}},  //   _laip, שאַפ, itka,
  { {0x201e0119, 0x3eb901e5, 0x00000000, 0x00000000}},  //   vati_, ynst_,   ,
  { {0x09de0183, 0x201e0169, 0x7e64011c, 0x00000000}},  //   _मराठ, wati_, _naip,
  { {0xa5070088, 0x443e0082, 0x60f7007e, 0x00000000}},  //   _мета_, _tct_, оныя_,
  { {0xdb1e028c, 0x443e12ec, 0x661b002d, 0x00000000}},  //   _expé, _uct_, _zeuk,
  { {0x201e2866, 0x0206008b, 0xd7d0001c, 0x00000000}},  //   rati_, _дзен, _तुमच,
  { {0x201e0209, 0xeeab0457, 0x7e6421e7, 0x00000000}},  //   sati_, рток_, _caip,
  { {0x201e0475, 0x6fca0061, 0xc2e90647, 0x00000000}},  //   pati_, _सुरू, _اعلم_,
  { {0xcce706ea, 0x6458006c, 0x443c00e5, 0x00000000}},  //   تسجي, nevi, ngv_,
  { {0x7ce00039, 0x6d4604cb, 0x6e9501ab, 0x00000000}},  //   förb, atka, _нику,
  { {0x645800ea, 0x00000000, 0x00000000, 0x00000000}},  //   hevi,   ,   ,
  { {0x64580d96, 0xb5fd0091, 0x661b040f, 0x00000000}},  // [ef50] kevi, _naša, _reuk,
  { {0x6458091e, 0xf1b9092f, 0x7ce004ce, 0x00000000}},  //   jevi, naša_, töre,
  { {0x64580056, 0x2bd20061, 0x7e643491, 0x00000000}},  //   devi, _दुपा, _yaip,
  { {0x6e3d001f, 0x201c3e92, 0x7ce00d47, 0x00000000}},  //   ngsb, _levi_, röre,
  { {0x3d0f0061, 0x260a013d, 0x7ce000f8, 0x00000000}},  //   तीचे_, ाड़ी_, söre,
  { {0x645800b5, 0x201c0284, 0xfaf801b2, 0x00000000}},  //   gevi, _nevi_, _دریغ_,
  { {0x68fd256b, 0x661b0d25, 0xa3570167, 0x00000000}},  //   _husd, _teuk, تیاط_,
  { {0x3bbc009b, 0x644a0026, 0x68fd30a1, 0x00000000}},  //   ימוד, affi, _kusd,
  { {0x64580030, 0xdb0a06b8, 0x201c0026, 0x00000000}},  //   bevi, čnéh, _bevi_,
  { {0x645817f3, 0xd24e0123, 0x76590016, 0x00000000}},  //   cevi, پنی_, lewy,
  { {0x201c0207, 0x7e6401c5, 0x5f0507d0, 0x00000000}},  //   _devi_, _paip, язна,
  { {0xc33201f8, 0xed5a0437, 0x76590016, 0x00000000}},  //   _טוב_, бом_, newy,
  { {0xdd92023c, 0x23900089, 0x7e643e93, 0x00000000}},  //   روس_, _vējš_, _vaip,
  { {0x8fa50099, 0x644100d4, 0xe0d80088, 0x00000000}},  //   _нале, _jcli, _дві_,
  { {0x68fd010f, 0x3a203e94, 0xeb970216, 0x00000000}},  //   _ausd, taip_, пир_,
  { {0x6458016c, 0x68f50089, 0x68fd05a6, 0x00000000}},  //   zevi, _aizd, _busd,
  { {0x6458005f, 0x68f5005d, 0x3a200051, 0x00000000}},  // [ef60] yevi, _bizd, raip_,
  { {0x244f005a, 0x29000065, 0xb5fd0d90, 0x00000000}},  //   nımı_, rqia_, _raša,
  { {0x6458068f, 0xabfb00b3, 0x3b0a012b, 0x00000000}},  //   vevi, _להיר, _ћемо_,
  { {0xb5fd0d90, 0x76590007, 0x6441013f, 0x00000000}},  //   _paša, gewy, _acli,
  { {0x244f014a, 0x68fd0022, 0x20070544, 0x00000000}},  //   kımı_, _gusd, _ofni_,
  { {0x7afe008d, 0xb5fd0107, 0xb4d60309, 0x00000000}},  //   _kupt, _vaša, सते_,
  { {0x2f013e95, 0x201c01aa, 0x289b00a3, 0x00000000}},  //   _nóg_, _revi_, _פילא,
  { {0x64580089, 0x201c0089, 0x4ece0044, 0x00000000}},  //   sevi, _sevi_, রগুল,
  { {0x64581b43, 0xb5fd0107, 0x7afe001a, 0x00000000}},  //   pevi, _kašn, _lupt,
  { {0x6722001e, 0xf8cc013d, 0x64410048, 0x00000000}},  //   ņoju, ़किय, _gcli,
  { {0x442c3e96, 0xf1b9021c, 0x7afe0093, 0x00000000}},  //   _idd_, raša_, _nupt,
  { {0x2007009f, 0x442c0011, 0x2126012d, 0x00000000}},  //   _efni_, _hdd_, _tvoh_,
  { {0x201c3e97, 0x6d5d00b5, 0x442c3e98, 0x00000000}},  //   _tevi_, uwsa, _kdd_,
  { {0x64410009, 0x68fd1f31, 0xe7be0164, 0x00000000}},  //   _xcli, _rusd, ्थाप,
  { {0x66d8000c, 0x7afe001a, 0x442c0253, 0x00000000}},  //   ríkj, _cupt, _mdd_,
  { {0x628603b6, 0x68f5005a, 0x68fd3e99, 0x00000000}},  //   ökoh, _sizd, _pusd,
  { {0x68f5016e, 0xf8b10167, 0x442c3e9a, 0x00000000}},  // [ef70] _pizd, نکس_, _odd_,
  { {0x7d0d0020, 0xb4d60061, 0x442c06ed, 0x00000000}},  //   _itas, सतो_, _ndd_,
  { {0x59f90057, 0xf093052f, 0x64410c10, 0x00000000}},  //   _меня_, ענע_, _rcli,
  { {0x442c0038, 0x940c005f, 0xe7300355, 0x00000000}},  //   _add_, _ildə_, اصل_,
  { {0xd126031d, 0x290b0010, 0x644100bb, 0x00000000}},  //   _جم_, _utca_, _pcli,
  { {0x2a690004, 0x39493e9b, 0x442c009d, 0x00000000}},  //   ldab_, mtas_, _cdd_,
  { {0x442c254b, 0x6e2d0363, 0x255d01aa, 0x00000000}},  //   _ddd_, _odab, _wňl_,
  { {0x2a690004, 0x39493e9c, 0x6e2d0117, 0x00000000}},  //   ndab_, otas_, _ndab,
  { {0x244f005d, 0x21690594, 0x7d0d0117, 0x00000000}},  //   tımı_, ципи_, _ntas,
  { {0x26cf0555, 0x39491049, 0x6e2d01a3, 0x00000000}},  //   logo_, itas_, _adab,
  { {0xd2510054, 0x244f005a, 0x39490051, 0x00000000}},  //   _لنا_, rımı_, htas_,
  { {0x39493e9d, 0x7afe1911, 0x26cf00ee, 0x00000000}},  //   ktas_, _rupt, nogo_,
  { {0x504500ed, 0x244f014a, 0x442c0016, 0x00000000}},  //   _желб, pımı_, _ydd_,
  { {0x442c008e, 0x7ce00039, 0x2f010048, 0x00000000}},  //   _xdd_, föra, _tóg_,
  { {0x38ad005f, 0xcee900d3, 0xb5fd1c61, 0x00000000}},  //   _görə_, ترین_, _našo,
  { {0x628b3e9e, 0xa3e202d2, 0x3b0700ed, 0x00000000}},  //   _jogo, नेट_, ќето_,
  { {0x26cf000b, 0x628b01d9, 0x3946008b, 0x00000000}},  // [ef80] dogo_, _mogo, ьнаг,
  { {0x66092e51, 0xddc406b8, 0x316d009d, 0x00000000}},  //   _afek, _kniž, ivez_,
  { {0x26cf0181, 0x75290197, 0xfaa6007e, 0x00000000}},  //   fogo_, _avez, _жано,
  { {0x628b11e6, 0x26cf0020, 0xbc3a00a1, 0x00000000}},  //   _nogo, gogo_, _اسکا_,
  { {0x39490211, 0xb5fd0521, 0x2ab7002b, 0x00000000}},  //   ctas_, _tašn, għbu_,
  { {0x69c60066, 0xe2f8007e, 0x00000000, 0x00000000}},  //   _ixke, пекі_,   ,
  { {0xbcfb0047, 0xf626025f, 0x442c004a, 0x00000000}},  //   lvét, _одво, _vdd_,
  { {0xa686008b, 0xd048006b, 0xf99f000a, 0x00000000}},  //   _ўлад, ələy, _ofèl_,
  { {0x628b0bf8, 0x041d0055, 0x442c1cdc, 0x00000000}},  //   _dogo, _নারী_, _tdd_,
  { {0x442c0190, 0x297b0049, 0x00000000, 0x00000000}},  //   _udd_, קטיא,   ,
  { {0x75293e9f, 0xf83700b6, 0x628b0010, 0x00000000}},  //   _zvez, ונית_, _fogo,
  { {0xe7e603d7, 0x628b022b, 0xb5fd0142, 0x00000000}},  //   _करना_, _gogo, _našl,
  { {0x41e20201, 0xa06a003b, 0x39490d7b, 0x00000000}},  //   _परिस, _мада_, xtas_,
  { {0xbef5013e, 0x00000000, 0x00000000, 0x00000000}},  //   _říča,   ,   ,
  { {0xdfd00054, 0x1bd404f1, 0xa3e20061, 0x00000000}},  //   _حيث_, воря, नेच_,
  { {0x39490039, 0x6e2d002d, 0xb5fd0006, 0x00000000}},  //   ttas_, _udab, _rašo,
  { {0x7d0d13df, 0x39490006, 0xdced0161, 0x00000000}},  // [ef90] _utas, utas_, _hrač,
  { {0x39491f51, 0x7bc0005a, 0xcc2700a1, 0x00000000}},  //   rtas_, ğmur, _کرکٹ,
  { {0x752902d7, 0x87040088, 0xea000082, 0x00000000}},  //   _svez, вяче, _ngặt_,
  { {0xb5fd33e5, 0x39490006, 0x61e20089, 0x00000000}},  //   _vašo, ptas_, _ozol,
  { {0x7aed00f4, 0xdd32006b, 0x628b3ea0, 0x00000000}},  //   mmat, _məşq, _rogo,
  { {0x7aed2962, 0xb5fd3ea1, 0x628b00ca, 0x00000000}},  //   lmat, _zašl, _sogo,
  { {0x628b3d7f, 0x7aed0032, 0x7ce03ea2, 0x00000000}},  //   _pogo, omat, körn,
  { {0xc2450256, 0x7aed3ea3, 0x7ce0000c, 0x00000000}},  //   хник, nmat, jörn,
  { {0xddc43ea4, 0x316d00f4, 0x628b016c, 0x00000000}},  //   _sniž, uvez_, _vogo,
  { {0x7aed01a3, 0x316d2b25, 0x93bc001a, 0x00000000}},  //   hmat, rvez_, _adău,
  { {0xc0a806f1, 0x7aed04cb, 0xe7e30204, 0x00000000}},  //   بايل_, kmat, केचा_,
  { {0xed5a1843, 0xdced04c8, 0xf77201ce, 0x00000000}},  //   пом_, _drač, אקט_,
  { {0x7aed0127, 0xdb0a00b9, 0x8d760025, 0x00000000}},  //   dmat, čníh, راحا,
  { {0x7aed0277, 0x66d8000c, 0xddc401f3, 0x00000000}},  //   emat, ríki, _iniż,
  { {0xb5fd3ea5, 0xa09a00a0, 0x7aed00ea, 0x00000000}},  //   _pašl, _מיסט, fmat,
  { {0x7aed027b, 0xb8660123, 0xdce4012d, 0x00000000}},  //   gmat, کارو, _orić,
  { {0x510c0049, 0xdced1032, 0x38a4010f, 0x00000000}},  // [efa0] ַהאַ, _zrač, _jörg_,
  { {0x7aed3ea6, 0x6e2615b7, 0x38a4000c, 0x00000000}},  //   amat, lakb, _mörg_,
  { {0x78be001c, 0x6f0b001a, 0x3ea00190, 0x00000000}},  //   rnpv, _încă, _klit_,
  { {0xd7ef0025, 0x7aed1ba2, 0xe1e70137, 0x00000000}},  //   حكم_, cmat, _مس_,
  { {0xbcfb3ea7, 0x66d103b1, 0x00000000, 0x00000000}},  //   lvér, råkp,   ,
  { {0xf36601f9, 0x3ea00129, 0x00000000, 0x00000000}},  //   етин, _llit_,   ,
  { {0x61e20047, 0xcc3b0049, 0x37e30088, 0x00000000}},  //   _szol, לעסט, _борг,
  { {0x290200b0, 0x75490010, 0x386a00d2, 0x00000000}},  //   _kuka_, öszö, _habr_,
  { {0x634a005f, 0x29020145, 0x5bbd007d, 0x00000000}},  //   _məni, _juka_, _ईश्व,
  { {0xdced1581, 0x29020127, 0x7aed0091, 0x00000000}},  //   _prač, _muka_, zmat,
  { {0x2902016e, 0xdfd00025, 0x7aed24f0, 0x00000000}},  //   _luka_, شيح_, ymat,
  { {0xdced0e0f, 0x71a6007e, 0x764200e7, 0x00000000}},  //   _vrač, _паез, ngoy,
  { {0x6562010f, 0x7aed0af3, 0xf8bf00b9, 0x00000000}},  //   nwoh, vmat, _svém_,
  { {0xe04a007a, 0x7aed0066, 0x3ea015fb, 0x00000000}},  //   _رشته_, wmat, _elit_,
  { {0x7aed006c, 0x75f6014a, 0x29023ea8, 0x00000000}},  //   tmat, _yüzü, _auka_,
  { {0xb5fd129d, 0x290204cb, 0x7aed07ff, 0x00000000}},  //   _pašm, _buka_, umat,
  { {0x200b0046, 0x634a005f, 0x19580147, 0x00000000}},  // [efb0] ście_, _dəni, наты_,
  { {0x290f001e, 0x2902183a, 0x26c40166, 0x00000000}},  //   īga_, _duka_, _ajmo_,
  { {0x7aed010e, 0xe7e60061, 0xdce401ed, 0x00000000}},  //   pmat, _करणा_, _srić,
  { {0x6aa40abe, 0xb5fd0521, 0x31660032, 0x00000000}},  //   chif, _tašm, _osoz_,
  { {0xb5fd0107, 0xd46902ea, 0x00000000, 0x00000000}},  //   _hašk, диле_,   ,
  { {0x2298009f, 0x64cb0164, 0x6e260010, 0x00000000}},  //   _fékk_, िवेश, zakb,
  { {0x64a20a1e, 0x753c0089, 0x38a4006b, 0x00000000}},  //   раща, _ārze, _dörd_,
  { {0xe7e602fb, 0x3959014a, 0x67d40194, 0x00000000}},  //   _करता_, _kpss_, _сосу,
  { {0x7ce00d47, 0xb5fd0059, 0x98a90036, 0x00000000}},  //   förl, _lašk, grać_,
  { {0xd3a71447, 0xf99f000a, 0x3eb201d6, 0x00000000}},  //   _преп, _afèk_, _smyt_,
  { {0x09de0164, 0x6e26011c, 0xbea6003b, 0x00000000}},  //   _मर्य, takb, ванк,
  { {0x4427020c, 0x2bd5013d, 0x98a90036, 0x00000000}},  //   lan_, _धड़ा, brać_,
  { {0x61450072, 0x4427002d, 0x38a401a2, 0x00000000}},  //   _рела, oan_, _höre_,
  { {0x4427020c, 0x634a006b, 0xfce60545, 0x00000000}},  //   nan_, _səni, того,
  { {0x644300db, 0x442704be, 0x2902027e, 0x00000000}},  //   igni, ian_, _suka_,
  { {0x4427033b, 0xdd920076, 0x3ea0006a, 0x00000000}},  //   han_, _نوع_, _ulit_,
  { {0x4427020c, 0x6f031db2, 0x2bd20164, 0x00000000}},  // [efc0] kan_, _hunc, _दुरा,
  { {0x44273ea9, 0x2902037e, 0x6f0304cb, 0x00000000}},  //   jan_, _vuka_, _kunc,
  { {0x7d04049b, 0xdc9b009b, 0x6e240145, 0x00000000}},  //   _huis, _חייל, _keib,
  { {0x6f033eaa, 0x7d04000b, 0x44273eab, 0x00000000}},  //   _munc, _kuis, ean_,
  { {0x44273eac, 0x7d0402ae, 0x76420483, 0x00000000}},  //   fan_, _juis, rgoy,
  { {0x6e24002a, 0x7d04021e, 0x4427066d, 0x00000000}},  //   _leib, _muis, gan_,
  { {0x7d040100, 0x6f030977, 0x61f7006b, 0x00000000}},  //   _luis, _nunc, əblə,
  { {0x68fc235c, 0x442700b0, 0x6e242313, 0x00000000}},  //   _hird, aan_, _neib,
  { {0x44270e69, 0x7ce0014a, 0x7d04009d, 0x00000000}},  //   ban_, törl, _nuis,
  { {0x44270038, 0x38a40039, 0x7ce00a5d, 0x00000000}},  //   can_, _före_, förm,
  { {0x38a4011f, 0x394000c7, 0x6e240016, 0x00000000}},  //   _göre_, huis_, _beib,
  { {0x527603ab, 0xb5fd0107, 0x7d040051, 0x00000000}},  //   _جائز, _rašk, _buis,
  { {0x7d04028c, 0x6143007e, 0xb5fd167a, 0x00000000}},  //   _cuis, _веча, _sašk,
  { {0x7d04037f, 0xd1970104, 0xb5fd16d0, 0x00000000}},  //   _duis, _בכדי_, _pašk,
  { {0x99bf0055, 0x395904be, 0xcf8f003b, 0x00000000}},  //   _আরেক, _spss_, _тј_,
  { {0x5a3400d7, 0x68fc0051, 0x7d040b51, 0x00000000}},  //   инст, _aird, _fuis,
  { {0x44270811, 0x3eb90004, 0x39400129, 0x00000000}},  // [efd0] yan_, mist_, guis_,
  { {0x3eb90004, 0x44273716, 0xb5fd18db, 0x00000000}},  //   list_, xan_, _tašk,
  { {0x442732f6, 0x7e6d29be, 0x68fc0569, 0x00000000}},  //   van_, _kaap, _dird,
  { {0x44271463, 0xb5fd037e, 0x7e6d006c, 0x00000000}},  //   wan_, _kaši, _jaap,
  { {0x6d4f0f57, 0xc984007c, 0x7e6d2eac, 0x00000000}},  //   ntca, _кури, _maap,
  { {0xdfc60054, 0xb5fd0c47, 0x44270169, 0x00000000}},  //   _هي_, _maši, uan_,
  { {0x4427020c, 0x7afd0010, 0x7c253ead, 0x00000000}},  //   ran_, _kist, _mehr,
  { {0x4427020c, 0x36d52821, 0x5694008b, 0x00000000}},  //   san_, _собр, _каст,
  { {0x7afd01d5, 0x6f030119, 0x225f0116, 0x00000000}},  //   _mist, _sunc, reuk_,
  { {0x7afd0f68, 0x6f0312e9, 0xb5fd0410, 0x00000000}},  //   _list, _punc, _naši,
  { {0x69dd0146, 0x7d0400f4, 0x7ea60779, 0x00000000}},  //   _lyse, _suis, _lópe,
  { {0x3eb936f8, 0x7afd01eb, 0x7d04028c, 0x00000000}},  //   gist_, _nist, _puis,
  { {0x6d4f001c, 0x7d040489, 0x44253eae, 0x00000000}},  //   gtca, _quis, _kel_,
  { {0x7afd3eaf, 0x3ebe0047, 0x44250119, 0x00000000}},  //   _aist, őtt_, _jel_,
  { {0x7afd01cd, 0x442501a3, 0x7c25002b, 0x00000000}},  //   _bist, _mel_, _dehr,
  { {0x3eb9027b, 0x7d043eb0, 0x68fc08ad, 0x00000000}},  //   cist_, _tuis, _sird,
  { {0x6d4f001c, 0xb5fd041a, 0x3edb007b, 0x00000000}},  // [efe0] ctca, _faši, _אַזא,
  { {0x4425213b, 0xe9d72cb4, 0x7afd018e, 0x00000000}},  //   _nel_, уку_, _eist,
  { {0x7afd027b, 0x6ac60151, 0x69dd00d9, 0x00000000}},  //   _fist, _مقدم, _eyse,
  { {0x3940028c, 0x7afd0168, 0xfbd3009b, 0x00000000}},  //   puis_, _gist, _לתת_,
  { {0x68fc001e, 0x394000f4, 0x3cfd006b, 0x00000000}},  //   _tird, quis_, _üzvü_,
  { {0x4425000d, 0x7afd0027, 0x00000000, 0x00000000}},  //   _cel_, _zist,   ,
  { {0x442506c2, 0xd047006b, 0x07d80014, 0x00000000}},  //   _del_, _ölən, _شهرک_,
  { {0x7afd027b, 0x4425006c, 0xe20a00b4, 0x00000000}},  //   _xist, _eel_, _otóż_,
  { {0x44250bc4, 0xe6930025, 0x09c40044, 0x00000000}},  //   _fel_, _القد, ্ধকা,
  { {0x2e24001d, 0x7e6d00b0, 0x3eb900bb, 0x00000000}},  //   _đườn, _saap, wist_,
  { {0x3eb90edb, 0x3246002c, 0x2d990007, 0x00000000}},  //   tist_, _مناف, wyse_,
  { {0x6d4f001c, 0x442518d9, 0x7c253267, 0x00000000}},  //   ttca, _zel_, _sehr,
  { {0x7afd08a6, 0x99bf0055, 0x212b0051, 0x00000000}},  //   _rist, _আর্ক, ácht_,
  { {0x2d990007, 0x3076012b, 0x200e0197, 0x00000000}},  //   ryse_, _људс, _uffi_,
  { {0x7afd021e, 0x3eb90c78, 0x709b0049, 0x00000000}},  //   _pist, pist_, _אױגו,
  { {0x3861010f, 0x7c25010f, 0xc9870467, 0x00000000}},  //   wehr_, _wehr, лузи,
  { {0x7c25006b, 0xf1b90ed8, 0x3a2901d6, 0x00000000}},  // [eff0] _tehr, taši_, raap_,
  { {0x7afd00bb, 0x9c470088, 0x00000000, 0x00000000}},  //   _wist, _схил,   ,
  { {0x4425001c, 0x7afd0233, 0x69dd0fb6, 0x00000000}},  //   _rel_, _tist, _wyse,
  { {0x44250004, 0xaa6700e3, 0x7afd016e, 0x00000000}},  //   _sel_, _сток, _uist,
  { {0x442504bd, 0xa2b3013d, 0xddc40006, 0x00000000}},  //   _pel_, इफस्, _kaiš,
  { {0xd4910082, 0x00000000, 0x00000000, 0x00000000}},  //   _tìm_,   ,   ,
  { {0x4425009f, 0xddc40006, 0x98a00006, 0x00000000}},  //   _vel_, _maiš, usią_,
  { {0xd6c304e1, 0x44250250, 0xddc40006, 0x00000000}},  //   _امری, _wel_, _laiš,
  { {0x8447002c, 0x38a40039, 0x95cb10d8, 0x00000000}},  //   _مخال, _höra_, _чува_,
  { {0x38a40039, 0x4095007c, 0xddc41435, 0x00000000}},  //   _köra_, ррит, _naiš,
  { {0xaec6007c, 0x212d0199, 0x8e860088, 0x00000000}},  //   ибол, sseh_, агне,
  { {0x9fa2000c, 0x00000000, 0x00000000, 0x00000000}},  //   ríða_,   ,   ,
  { {0x9fa2000c, 0xee37004c, 0x00000000, 0x00000000}},  //   síða_, шня_,   ,
  { {0x659a0049, 0x61e6014a, 0x634a006b, 0x00000000}},  //   דישק, ükle, _tənt,
  { {0x7c220521, 0xdee6017a, 0x00000000, 0x00000000}},  //   _đord, _коки,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,

  { {0x7ce003a9, 0xd946030d, 0x7bde00b4, 0x00000000}},  // [f000] höri, рези, _wypu,
  { {0xddc40e3f, 0xdbdf000c, 0x26c7004a, 0x00000000}},  //   _gaiš, _tíði, énon_,
  { {0x6e3600b9, 0x291f0023, 0x00000000, 0x00000000}},  //   _kdyb, _çuan_,   ,
  { {0xe7370081, 0xf1b901c5, 0x98a00243, 0x00000000}},  //   рец_, lašu_, ksić_,
  { {0x25a00195, 0xa806007c, 0x00000000, 0x00000000}},  //   áil_, _взгл,   ,
  { {0xe71a0380, 0x7ce0072d, 0x38a40039, 0x00000000}},  //   _ليست_, föri, _föra_,
  { {0x38a40073, 0x25a00387, 0x3952007f, 0x00000000}},  //   _göra_, šil_, ltys_,
  { {0xcb13009b, 0x634a006b, 0x00000000, 0x00000000}},  //   חלה_, _səns,   ,
  { {0x3952010a, 0xe5a301fb, 0xdb230048, 0x00000000}},  //   ntys_, _дити, órúc,
  { {0xb5fd001e, 0x92c80044, 0x00000000, 0x00000000}},  //   _pašv, োগে_,   ,
  { {0x7879007b, 0x8c010044, 0x645a013f, 0x00000000}},  //   אָרו, ্রমন_, _ibti,
  { {0x26c63eb1, 0x3952007f, 0x00000000, 0x00000000}},  //   nnoo_, ktys_,   ,
  { {0x1cbb031d, 0x6dcb007e, 0x91e32e81, 0x00000000}},  //   ناسب_, тынг_, _доце,
  { {0xfa230044, 0x9d180a85, 0x00000000, 0x00000000}},  //   _ফাইল_, рорт_,   ,
  { {0x62820116, 0xddc4007f, 0x6017009b, 0x00000000}},  //   _knoo, _vaiš, _דחוף_,
  { {0xb34502d5, 0xb5fd0626, 0x6e360036, 0x00000000}},  //   luçã, _kašt, _gdyb,
  { {0xf80723ee, 0x645a0e98, 0x628201ee, 0x00000000}},  // [f010] ачен, _obti, _mnoo,
  { {0x2bd2007d, 0xb5fd0091, 0x645e006c, 0x00000000}},  //   _दुका, _mašt, õpil,
  { {0x628201d6, 0xb06500b0, 0x7ea6000c, 0x00000000}},  //   _onoo, lmää, _hópa,
  { {0x7ea6000c, 0xcfa80044, 0x645a0035, 0x00000000}},  //   _kópa, _ওখান, _abti,
  { {0x6c78089d, 0xb5fd07ac, 0x2bdb013d, 0x00000000}},  //   _صحیح_, _našt, _मुता,
  { {0xb717023c, 0x38a400f8, 0x645a004a, 0x00000000}},  //   _نظرت, _hörn_, _cbti,
  { {0xb34502d5, 0xddc4001a, 0xd7c90025, 0x00000000}},  //   duçã, _obiş, _صوره_,
  { {0xb5fd037e, 0x224b001f, 0x7ce0014a, 0x00000000}},  //   _bašt, ück_, röri,
  { {0x765b0045, 0x00000000, 0x00000000, 0x00000000}},  //   _ibuy,   ,   ,
  { {0x10a5007c, 0x657b0dfc, 0x62820087, 0x00000000}},  //   сион, _iruh, _enoo,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x395200b0, 0x00000000, 0x00000000, 0x00000000}},  //   ytys_,   ,   ,
  { {0xc1080011, 0x8f6700a1, 0x765b33b9, 0x00000000}},  //   _hỗn_, _چلتے_, _mbuy,
  { {0x61eb0ad8, 0x98a70224, 0xb3450181, 0x00000000}},  //   _izgl, čně_, cuçã,
  { {0xb5fd0119, 0x38a4009f, 0x765b0009, 0x00000000}},  //   _zašt, _börn_, _obuy,
  { {0xbebd0089, 0xad9b00c4, 0x8f9a009b, 0x00000000}},  //   usīt, rcúr, _תיקי,
  { {0x8c46007e, 0x7bc1009d, 0x6d403017, 0x00000000}},  // [f020] _лепе, ûlur, ámad,
  { {0x6d460149, 0x3952178b, 0x765b0145, 0x00000000}},  //   muka, rtys_, _abuy,
  { {0xe61a256f, 0x6d4601a3, 0xeb9a16e3, 0x00000000}},  //   где_, luka, _син_,
  { {0x7c2e3eb2, 0x657b3eb3, 0xd6d90088, 0x00000000}},  //   labr, _bruh, аті_,
  { {0x7ae40066, 0x7af60176, 0x00000000, 0x00000000}},  //   mlit, mmyt,   ,
  { {0x7ae4021e, 0x657b0428, 0xb5fd0006, 0x00000000}},  //   llit, _druh, _rašt,
  { {0x6d4601a3, 0xf743012c, 0x7ae4010e, 0x00000000}},  //   huka, _неро, olit,
  { {0x6d460149, 0xb5fd010a, 0xc1140080, 0x00000000}},  //   kuka, _pašt, омиј,
  { {0xddcd190a, 0x6d4604cb, 0x1a9b0049, 0x00000000}},  //   _snaž, juka, טיקע,
  { {0x7ae40016, 0x6d46033b, 0x39400051, 0x00000000}},  //   hlit, duka, iris_,
  { {0x7c2e0006, 0x201e0006, 0x7ae4006c, 0x00000000}},  //   dabr, rbti_, klit,
  { {0x442e0016, 0x6d460066, 0x39401992, 0x00000000}},  //   laf_, fuka, kris_,
  { {0xf1940057, 0xd0120014, 0x6d460010, 0x00000000}},  //   _филь, _فلش_, guka,
  { {0x39403443, 0x442e0397, 0x7c2e000c, 0x00000000}},  //   dris_, naf_, gabr,
  { {0x7ae40a15, 0x394011f6, 0xb0650103, 0x00000000}},  //   flit, eris_, smää,
  { {0x6d46006a, 0x3da7003b, 0x442e0016, 0x00000000}},  //   buka, _гроб, haf_,
  { {0x26c700f4, 0x442e0935, 0x3940302e, 0x00000000}},  // [f030] énom_, kaf_, gris_,
  { {0x7c2e00d4, 0x37ab02ea, 0x442e0258, 0x00000000}},  //   cabr, лтен_, jaf_,
  { {0x7ae401aa, 0x39403eb4, 0x442e0016, 0x00000000}},  //   blit, aris_, daf_,
  { {0x39400089, 0xdced0091, 0xc519007e, 0x00000000}},  //   bris_, _brać, аўкі_,
  { {0x4efc0049, 0x61e20010, 0x442e02ef, 0x00000000}},  //   אלאג, _nyol, faf_,
  { {0x2ecf0055, 0x8339007c, 0x6aad01a2, 0x00000000}},  //   রতিষ, ачит_, lhaf,
  { {0x3ea2000c, 0x61fe006b, 0x61e20022, 0x00000000}},  //   ykkt_, əzlə, _ayol,
  { {0x29030f68, 0x290b037e, 0x765b0061, 0x00000000}},  //   _hija_, _kuca_, _ubuy,
  { {0x657b0061, 0x442e3eb5, 0x3f77001a, 0x00000000}},  //   _uruh, baf_, _său_,
  { {0x6d460e88, 0x3ea904fa, 0x442e0016, 0x00000000}},  //   vuka, _alat_, caf_,
  { {0x290325c3, 0x3e8a06bb, 0x290b0207, 0x00000000}},  //   _mija_, айно_, _luca_,
  { {0x2919006c, 0x60c8006c, 0x7ce001a2, 0x00000000}},  //   _otsa_, andm, hört,
  { {0x7c2e000c, 0x61eb0afe, 0x290b0035, 0x00000000}},  //   tabr, _uzgl, _nuca_,
  { {0x8fa5007c, 0x6ae201f5, 0x3f77001a, 0x00000000}},  //   _мале, पत्र, _tău_,
  { {0x6d460149, 0x7ae40051, 0x3ea900ab, 0x00000000}},  //   suka, tlit, _flat_,
  { {0x394036b1, 0xa92610f3, 0x6aad3eb6, 0x00000000}},  //   tris_, ждал, ghaf,
  { {0x2903001e, 0x7ae4000c, 0x442e018e, 0x00000000}},  // [f040] _bija_, rlit, yaf_,
  { {0x39401ce2, 0x7ae4073a, 0x29030107, 0x00000000}},  //   rris_, slit, _cija_,
  { {0x7ae41d9e, 0x29030065, 0x76590016, 0x00000000}},  //   plit, _dija_, ffwy,
  { {0x6aad001f, 0x2f5a007b, 0x7d7700a6, 0x00000000}},  //   chaf, ידענ, _امیر_,
  { {0x20070198, 0x20030746, 0x29033eb7, 0x00000000}},  //   _ogni_, žjih_, _fija_,
  { {0xdced0091, 0x54b701e1, 0xb4e403d7, 0x00000000}},  //   _vrać, огія_, नते_,
  { {0x644a01d6, 0xe7370264, 0x7cf200ea, 0x00000000}},  //   rgfi, _мер_, mærd,
  { {0x442e018e, 0xdced016c, 0x3a370049, 0x00000000}},  //   saf_, _trać, ֿרים_,
  { {0x210402d2, 0xdddd0036, 0x5066007e, 0x00000000}},  //   रदेश_, zesł, отна,
  { {0x61e20263, 0x442e3eb8, 0x2ee00276, 0x00000000}},  //   _vyol, qaf_, _akif_,
  { {0x7336026c, 0xa2e63eb9, 0x4ada0061, 0x00000000}},  //   _ذرائ, _дожд, ढवाव,
  { {0x442c0030, 0x7eb60089, 0x20070016, 0x00000000}},  //   _hed_, kšpu, _egni_,
  { {0x442c0027, 0x217600ed, 0x6f040035, 0x00000000}},  //   _ked_, _фуер, _diic,
  { {0x442c0b41, 0xa0671cf4, 0x7d1d000c, 0x00000000}},  //   _jed_, _мача_, rpss,
  { {0x442c1bea, 0x290b0209, 0x6aad1642, 0x00000000}},  //   _med_, _suca_, thaf,
  { {0x29030107, 0x7ce00002, 0x3ea921fb, 0x00000000}},  //   _sija_, förs, _ulat_,
  { {0x442c018e, 0x81dc0055, 0x255e001e, 0x00000000}},  // [f050] _oed_, ণের_, nālā_,
  { {0x6aad1b76, 0xab870099, 0x5e3500a1, 0x00000000}},  //   shaf, _думк, _بڑھا,
  { {0x6aad009f, 0x2903070c, 0x6e2d04be, 0x00000000}},  //   phaf, _vija_, _keab,
  { {0x41ca001c, 0xe81b0164, 0x442c006c, 0x00000000}},  //   ापास, _प्रा_, _aed_,
  { {0x29033eba, 0x442c05d0, 0xa5670b03, 0x00000000}},  //   _tija_, _bed_, تدان,
  { {0x6e2d002a, 0x7d0d00b0, 0xd5ae0025, 0x00000000}},  //   _leab, _muas, طفى_,
  { {0x9505026c, 0x7d0d3ebb, 0xd04e006b, 0x00000000}},  //   _کہتے_, _luas, _ödən,
  { {0x442c01d6, 0xe3b0023c, 0x26cd0521, 0x00000000}},  //   _eed_, خره_, _ujeo_,
  { {0x0577007a, 0x7d0d002a, 0xb5fd3ebc, 0x00000000}},  //   _بازد, _nuas, _gašp,
  { {0xdce40046, 0x442c04b3, 0x7fd5007e, 0x00000000}},  //   _ksią, _ged_, зімі,
  { {0x2bdb0201, 0x3949004a, 0x7cf20190, 0x00000000}},  //   _मुला, huas_, nære,
  { {0x75290009, 0x7d0d02ef, 0x26dd0036, 0x00000000}},  //   _kwez, _buas, nowo_,
  { {0x6e2d0032, 0x7d0d10c9, 0xd0090478, 0x00000000}},  //   _deab, _cuas, _леле_,
  { {0x711a00b6, 0x7529000b, 0x317a00a3, 0x00000000}},  //   _הוספ, _mwez, _לאנד,
  { {0x6e2d002a, 0x7cf20030, 0xafe2007c, 0x00000000}},  //   _feab, værd, _пошл,
  { {0x6609020e, 0x2bdb0061, 0x7d0d0fcc, 0x00000000}},  //   _ngek, _मुळा, _fuas,
  { {0xf2d2007b, 0x39490211, 0x7d0d3ebd, 0x00000000}},  // [f060] גען_, guas_, _guas,
  { {0x62990390, 0x4d7b007b, 0x6aa405b7, 0x00000000}},  //   _lowo, _פריע, skif,
  { {0x442c0af7, 0xdc9b0476, 0x4c9b009b, 0x00000000}},  //   _red_, _הייל, _השיע,
  { {0x62990046, 0x7e760146, 0x2d80000a, 0x00000000}},  //   _nowo, _jayp, _krie_,
  { {0xe5a30072, 0x60c10890, 0x442c1163, 0x00000000}},  //   ници, kilm, _ped_,
  { {0x442c01d5, 0x7cf205b7, 0x38a406a1, 0x00000000}},  //   _qed_, bære, _mörk_,
  { {0x442c02cc, 0x60c10279, 0x26dd2ab2, 0x00000000}},  //   _ved_, dilm, bowo_,
  { {0xfa97007b, 0xb909001d, 0x6299023a, 0x00000000}},  //   ִדיש_, _nghị_, _cowo,
  { {0x442c00b9, 0x62990036, 0x6e2d1c37, 0x00000000}},  //   _ted_, _dowo, _reab,
  { {0xf48406c6, 0x20090279, 0xd2590089, 0x00000000}},  //   _تاری, _şair_, riņa_,
  { {0x2d803ebe, 0x7d0d04cb, 0x0857009b, 0x00000000}},  //   _arie_, _suas, הבים_,
  { {0x7d0d027e, 0x2d80009d, 0x88c40044, 0x00000000}},  //   _puas, _brie_, ্তিক,
  { {0x7d0d0d87, 0x60c13ebf, 0x2d800181, 0x00000000}},  //   _quas, bilm, _crie_,
  { {0x2d800100, 0x60c11ad2, 0x649d00f6, 0x00000000}},  //   _drie_, cilm, _hèir,
  { {0x905b009b, 0xc053009b, 0x2d800322, 0x00000000}},  //   _הכות, _נזק_, _erie_,
  { {0x7cf20637, 0x2d800637, 0x39493ec0, 0x00000000}},  //   være, _frie_, tuas_,
  { {0x2d800173, 0x00000000, 0x00000000, 0x00000000}},  // [f070] _grie_,   ,   ,
  { {0x39490145, 0x7cf208e0, 0x00000000, 0x00000000}},  //   ruas_, tære,   ,
  { {0x8d1800e9, 0x00000000, 0x00000000, 0x00000000}},  //   _وزیر_,   ,   ,
  { {0x75290ed7, 0x394904be, 0x7cf20190, 0x00000000}},  //   _pwez, puas_, rære,
  { {0xf6501095, 0xb609001e, 0x60c10180, 0x00000000}},  //   ائم_, višķ, yilm,
  { {0x7b080051, 0x6299010f, 0xd0060025, 0x00000000}},  //   _óstá, _sowo, _لل_,
  { {0x62990046, 0x60c10334, 0xb6090089, 0x00000000}},  //   _powo, vilm, tišķ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7529000b, 0x60c1014a, 0x7ce01829, 0x00000000}},  //   _uwez, tilm, körp,
  { {0x629909bd, 0x7e760058, 0x00000000, 0x00000000}},  //   _wowo, _sayp,   ,
  { {0x60c1038c, 0x7e76001c, 0x6e4601fc, 0x00000000}},  //   rilm, _payp, менз,
  { {0x2d80010a, 0x00000000, 0x00000000, 0x00000000}},  //   _prie_,   ,   ,
  { {0x63a3005b, 0xf2d81847, 0x60c11d83, 0x00000000}},  //   lynn, _عظمت_, pilm,
  { {0x7e7600bb, 0x00000000, 0x00000000, 0x00000000}},  //   _wayp,   ,   ,
  { {0x1ae600e2, 0x6fb20025, 0x3bd5007c, 0x00000000}},  //   довм, _لموا, еютс,
  { {0x2d800068, 0x00000000, 0x00000000, 0x00000000}},  //   _trie_,   ,   ,
  { {0x2d800023, 0x00000000, 0x00000000, 0x00000000}},  // [f080] _urie_,   ,   ,
  { {0xbddb0129, 0xb8660445, 0xfc06007c, 0x00000000}},  //   rgèt, بارو, _оппо,
  { {0x7c3e107b, 0xb3a90180, 0x00000000, 0x00000000}},  //   _idpr, çılı,   ,
  { {0x9f9600b6, 0x63a3272b, 0x00000000, 0x00000000}},  //   ודעה_, dynn,   ,
  { {0x7ae9002b, 0x95531125, 0x00000000, 0x00000000}},  //   ċett, نخوا,   ,
  { {0x63a30016, 0x6d4604be, 0xcdb7009b, 0x00000000}},  //   fynn, irka, ופנה_,
  { {0x38780051, 0xbddb00f4, 0x63a33ec1, 0x00000000}},  //   _iarr_, ngèr, gynn,
  { {0xd13a007c, 0x26c23ec2, 0x387800f8, 0x00000000}},  //   охо_, _öko_, _harr_,
  { {0x7c3e01d9, 0x00000000, 0x00000000, 0x00000000}},  //   _odpr,   ,   ,
  { {0x63a3018e, 0x634a006b, 0x4fc6142c, 0x00000000}},  //   bynn, _mənz, дсма,
  { {0xc108001d, 0x3878164d, 0x63a30016, 0x00000000}},  //   _mỗi_, _marr_, cynn,
  { {0xc108001d, 0xd12f0167, 0x7c3e00d2, 0x00000000}},  //   _lỗi_, _چمن_, _adpr,
  { {0x752201aa, 0x6ce70088, 0x6aa3001a, 0x00000000}},  //   npoz, діве, _înfi,
  { {0xdce40046, 0xfc64005e, 0x443e0032, 0x00000000}},  //   _księ, късн, _jdt_,
  { {0xc1080011, 0x443e0145, 0x6d4601a3, 0x00000000}},  //   _nỗi_, _mdt_, arka,
  { {0x6d460107, 0x634a006b, 0x00000000, 0x00000000}},  //   brka, _bənz,   ,
  { {0x3878002a, 0x752205c5, 0x6d46016c, 0x00000000}},  // [f090] _barr_, jpoz, crka,
  { {0x1b1e0055, 0x38780051, 0x6b7501fc, 0x00000000}},  //   _ফিরে_, _carr_, _злоу,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x443e0066, 0x1995326d, 0x7bd70066, 0x00000000}},  //   _adt_, _замя, _ixxu,
  { {0x38783ec3, 0x2a790066, 0x443e0035, 0x00000000}},  //   _farr_, _iasb_, _bdt_,
  { {0x38780173, 0x00000000, 0x00000000, 0x00000000}},  //   _garr_,   ,   ,
  { {0x25a9152a, 0x443e0145, 0x395900d9, 0x00000000}},  //   šal_, _ddt_, _hqss_,
  { {0x6d4601c9, 0x63a30016, 0x443e0133, 0x00000000}},  //   yrka, rynn, _edt_,
  { {0x212b0263, 0xf07600a1, 0x4105092b, 0x00000000}},  //   èch_, ڑیوں_, нзив,
  { {0x443e02ad, 0x3f5800c4, 0x00000000, 0x00000000}},  //   _gdt_, féu_,   ,
  { {0xd2510647, 0x4427004a, 0x7ea601e5, 0x00000000}},  //   _منا_, mbn_, _hópi,
  { {0x6d46050f, 0x037802fd, 0x9f470023, 0x00000000}},  //   trka, _زحمت_, _hynë_,
  { {0x628b011c, 0x0d830088, 0x661b0020, 0x00000000}},  //   _ingo, глян, _mfuk,
  { {0x3f580919, 0x6d4601e5, 0x00000000, 0x00000000}},  //   béu_, rrka,   ,
  { {0xeb9a0088, 0x75220395, 0x6d460087, 0x00000000}},  //   чив_, zpoz, srka,
  { {0x8a0603f3, 0xc3320104, 0xc1080082, 0x00000000}},  //   езбе, טול_, _rỗi_,
  { {0xd9430726, 0xe9d7005e, 0x44270093, 0x00000000}},  // [f0a0] лети, ект_, kbn_,
  { {0x2bdb006e, 0x660d0ed9, 0x26cf0032, 0x00000000}},  //   _मुका, žakl, engo_,
  { {0xe666003b, 0xd70a007c, 0x628b0133, 0x00000000}},  //   етло, чнее_, _ongo,
  { {0xdce40006, 0x634a006b, 0x443e02d4, 0x00000000}},  //   _priė, _tənz, _sdt_,
  { {0xf99200a6, 0x1a9b007b, 0x7ea60181, 0x00000000}},  //   _صبح_, _זיכע, _cópi,
  { {0x628b042d, 0x26cf3ec4, 0x752206ed, 0x00000000}},  //   _ango, ango_, rpoz,
  { {0xd62a1dac, 0x6205006b, 0x43940069, 0x00000000}},  //   _нове_, ərlə, тайс,
  { {0x04ca00a1, 0x290a0010, 0x00000000, 0x00000000}},  //   _کوئي_, _hiba_,   ,
  { {0x443e029a, 0x290a01aa, 0x7ae30181, 0x00000000}},  //   _tdt_, _kiba_, _ínte,
  { {0xdfda0265, 0x60f7007e, 0x7e642a36, 0x00000000}},  //   зъм_, нныя_, _abip,
  { {0xf8b300b3, 0x6909049c, 0x290a3ec5, 0x00000000}},  //   רשת_, _ožen, _miba_,
  { {0x234b00a2, 0x93250167, 0x7ae60058, 0x00000000}},  //   _رسمی_, _شرمن, _nkkt,
  { {0x25a604bd, 0xf2370049, 0xbcfb009d, 0x00000000}},  //   nyol_, _טראץ_, ntég,
  { {0x290a0061, 0x3f5800c4, 0x00000000, 0x00000000}},  //   _niba_, péu_,   ,
  { {0x6aaf0026, 0xee3f01dc, 0x207b0049, 0x00000000}},  //   _plcf, lkým_, _מאגא,
  { {0x290a001a, 0x00000000, 0x00000000, 0x00000000}},  //   _aiba_,   ,   ,
  { {0x290a3ec6, 0x7e7d01a2, 0x00000000, 0x00000000}},  // [f0b0] _biba_, mdsp,   ,
  { {0x5b153be5, 0x7e7d01bf, 0x290a01c5, 0x00000000}},  //   _имот, ldsp, _ciba_,
  { {0xe70b00a6, 0x290a0e21, 0x6d5d0f4f, 0x00000000}},  //   ستان_, _diba_, ltsa,
  { {0x26cf2d21, 0x6d5d01b1, 0x00000000, 0x00000000}},  //   ungo_, otsa,   ,
  { {0x6d5d022b, 0x290a007f, 0x7e7d3ec7, 0x00000000}},  //   ntsa, _fiba_, idsp,
  { {0xe7330647, 0xdced04eb, 0x6d5d01a2, 0x00000000}},  //   _مصر_, _krađ, itsa,
  { {0x8c1c00b6, 0x6d5d0004, 0x58d40256, 0x00000000}},  //   לוגי, htsa, _сорт,
  { {0x7ea602d5, 0x7aed165e, 0x7e7d0030, 0x00000000}},  //   _tópi, nlat, jdsp,
  { {0x6d4f037e, 0x7aed0032, 0x44270093, 0x00000000}},  //   juca, ilat, pbn_,
  { {0x6d4f001a, 0x39490181, 0x7aed0052, 0x00000000}},  //   duca, iras_, hlat,
  { {0x6ef60047, 0x64410058, 0xfbc60044, 0x00000000}},  //   vább, _idli, _শুনত,
  { {0x38a40002, 0x39490006, 0x628b011c, 0x00000000}},  //   _hört_, kras_, _ungo,
  { {0x2d8401ca, 0x6d4f0107, 0xee3f0161, 0x00000000}},  //   íme_, guca, ckým_,
  { {0x10a20131, 0x7e7d0168, 0x00000000, 0x00000000}},  //   _вишн, adsp,   ,
  { {0x39493000, 0x290a0727, 0x6ef60010, 0x00000000}},  //   eras_, _riba_, rább,
  { {0x7aed1b04, 0x39490285, 0x6d4f0a89, 0x00000000}},  //   glat, fras_, buca,
  { {0x64410209, 0x39490181, 0x290a0c8f, 0x00000000}},  // [f0c0] _odli, gras_, _piba_,
  { {0xdd31005f, 0x64413ec8, 0x61eb01e5, 0x00000000}},  //   ləşd, _ndli, _mygl,
  { {0xdced0119, 0x7aed010f, 0x39492e86, 0x00000000}},  //   _građ, blat, aras_,
  { {0x3949201f, 0x76a901fb, 0x7aed0129, 0x00000000}},  //   bras_, нтів_, clat,
  { {0x7ae4021e, 0x290a1636, 0x3949008e, 0x00000000}},  //   moit, _tiba_, cras_,
  { {0x7ae400b0, 0xf4d00044, 0x2f1a0089, 0x00000000}},  //   loit, িত্ব, _līga_,
  { {0x3ea000c7, 0x7ea6000c, 0x38a4014a, 0x00000000}},  //   _ooit_, _hópu, _dört_,
  { {0xf77701f8, 0x7ae400b0, 0xb6a3041f, 0x00000000}},  //   _בעלי_, noit, _кисл,
  { {0xb6a30265, 0x26c400f4, 0x6d400521, 0x00000000}},  //   _титл, _immo_, šmaj,
  { {0x7ae4021e, 0x7aed0095, 0x00000000, 0x00000000}},  //   hoit, zlat,   ,
  { {0x7ae40234, 0x7aed31a3, 0xf837009b, 0x00000000}},  //   koit, ylat, כנית_,
  { {0x7ae4021e, 0x6d4f3035, 0x6d5d20b4, 0x00000000}},  //   joit, tuca, ttsa,
  { {0x3ea0028c, 0x6d5d3ec9, 0x7ae43eca, 0x00000000}},  //   _doit_, utsa, doit,
  { {0x40340081, 0x39490181, 0x6d5d0374, 0x00000000}},  //   _секс, vras_, rtsa,
  { {0x6d5d0190, 0x9f58021e, 0xc33900b9, 0x00000000}},  //   stsa, ärä_, žívá,
  { {0x394902d5, 0x6ab60016, 0x7ae40032, 0x00000000}},  //   tras_, ghyf, goit,
  { {0x394917e0, 0xac190069, 0x89340025, 0x00000000}},  // [f0d0] uras_, _попу_, لعلا,
  { {0x7aed049a, 0x39493ecb, 0x6ef60010, 0x00000000}},  //   slat, rras_, mába,
  { {0x7aed0428, 0xdced0521, 0x6ef60010, 0x00000000}},  //   plat, _urađ, lába,
  { {0x60c80127, 0x38a43ecc, 0x394905a0, 0x00000000}},  //   hidm, _börs_, pras_,
  { {0xd12606b4, 0x64410061, 0x6ef60010, 0x00000000}},  //   _دم_, _pdli, nába,
  { {0x6f0d3ecd, 0xd25901c5, 0x00000000, 0x00000000}},  //   _liac, miņi_,   ,
  { {0xf794007e, 0xd5bf0089, 0x2ca101a3, 0x00000000}},  //   _карэ, _šādu_, _mohd_,
  { {0x4ee50044, 0x6ef60010, 0x6aad2050, 0x00000000}},  //   নগুল, kába, nkaf,
  { {0x2f1a001e, 0x6ef60010, 0x00e500e3, 0x00000000}},  //   _rīga_, jába, лжин,
  { {0x3ea0028c, 0x7ae41806, 0xa5da0049, 0x00000000}},  //   _soit_, zoit, _אַבי,
  { {0xb5fd010a, 0x1eca0aa2, 0x61eb0046, 0x00000000}},  //   _rašy, елни_, _wygl,
  { {0x1e9601a4, 0x7fb3006b, 0x6f0d00b4, 0x00000000}},  //   урор, nəqə, _ciac,
  { {0x3ea03ae7, 0x7ae4021e, 0x6f0d001a, 0x00000000}},  //   _voit_, voit, _diac,
  { {0xe1f00426, 0x38b60030, 0x6f0d0197, 0x00000000}},  //   _بسم_, _kære_, _eiac,
  { {0x3ea03ece, 0x6f0d0051, 0x2ca5000c, 0x00000000}},  //   _toit_, _fiac, ölda_,
  { {0x6f0d0207, 0x2d96007c, 0x00000000, 0x00000000}},  //   _giac, _брос,   ,
  { {0xceb40163, 0x7ae400b0, 0x38b605b7, 0x00000000}},  // [f0e0] _ilə_, roit, _lære_,
  { {0x48c40055, 0x47bf0044, 0x7ae400b0, 0x00000000}},  //   ্ত্র, ্থনী, soit,
  { {0x7ae436fe, 0x38b601e3, 0xbcfb009d, 0x00000000}},  //   poit, _nære_, utée,
  { {0xbcfb009d, 0x4438007f, 0x00000000, 0x00000000}},  //   rtée, _žr_,   ,
  { {0x64a60822, 0x8e570476, 0xbcfb009d, 0x00000000}},  //   лада, רינג_, stée,
  { {0xd37a0069, 0x04c80076, 0xbcfb009d, 0x00000000}},  //   ечи_, ضوعي_, ptée,
  { {0x38b60030, 0x38a40039, 0x60c80203, 0x00000000}},  //   _værd_, _förr_, vidm,
  { {0x57e701f9, 0x66e63ecf, 0x6ef60010, 0x00000000}},  //   _сдсм_, _соба, yába,
  { {0xd0100054, 0x6f0d002a, 0xc05a0451, 0x00000000}},  //   يلة_, _riac, нін_,
  { {0x2ee90fc1, 0x6f0d005b, 0xbcfb0010, 0x00000000}},  //   _skaf_, _siac, ztéb,
  { {0x6f0d3e18, 0x645a005f, 0x3f870091, 0x00000000}},  //   _piac, _icti, _crnu_,
  { {0x6ef61acf, 0x91860380, 0x7d160284, 0x00000000}},  //   tába, _مجتم, _buys,
  { {0x69093ed0, 0x6f0d0027, 0x60c80173, 0x00000000}},  //   _džej, _viac, pidm,
  { {0xceb4005f, 0x6ef603b5, 0xb17b0097, 0x00000000}},  //   _elə_, rába, _נטור,
  { {0x6ef60010, 0x645a04c1, 0x2cb30082, 0x00000000}},  //   sába, _mcti, _vlxd_,
  { {0x8aa43ed1, 0xd2590089, 0x6ef60010, 0x00000000}},  //   бруд, tiņi_, pába,
  { {0x38350216, 0x6aad01e5, 0x9f4b0010, 0x00000000}},  // [f0f0] инар, rkaf, ülök_,
  { {0x6aad00eb, 0x201e0173, 0x00000000, 0x00000000}},  //   skaf, ncti_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x17f80054, 0x2f1a0089, 0x7c3701c3, 0x00000000}},  //   اركة_, _līgo_, _hexr,
  { {0xa5640054, 0x7fb3013f, 0x00000000, 0x00000000}},  //   مدون, rəqə,   ,
  { {0xd4690175, 0xdb1e00c4, 0x628000d9, 0x00000000}},  //   тике_, _expõ, edmo,
  { {0x63aa005b, 0x00000000, 0x00000000, 0x00000000}},  //   gyfn,   ,   ,
  { {0x38b602cc, 0xb145013b, 0xe8e00011, 0x00000000}},  //   _være_, анил, _đứa_,
  { {0xe0d909bb, 0xd6d80069, 0xf77000a1, 0x00000000}},  //   кви_, _стр_, _واہ_,
  { {0x1f650057, 0x05de0309, 0x34940131, 0x00000000}},  //   аком, _फुटब, _лаур,
  { {0xb4fa0049, 0x00000000, 0x00000000, 0x00000000}},  //   _ספעי,   ,   ,
  { {0xdee600ed, 0x00000000, 0x00000000, 0x00000000}},  //   роми,   ,   ,
  { {0x59a50061, 0x2d8900f6, 0x00000000, 0x00000000}},  //   _गॅलर, _crae_,   ,
  { {0x7cf23ed2, 0x69090089, 0x00000000, 0x00000000}},  //   mærk, _džek,   ,
  { {0xea5a01f9, 0x00000000, 0x00000000, 0x00000000}},  //   крај_,   ,   ,
  { {0x3eb9010f, 0x00000000, 0x00000000, 0x00000000}},  //   chst_,   ,   ,
  { {0x3b0705f6, 0xa96a0644, 0xc9a727c6, 0x00000000}},  // [f100] рето_, ضمام_, авте_,
  { {0xd2590089, 0xa96700d7, 0x7afd0023, 0x00000000}},  //   miņu_, рифа_, _ehst,
  { {0x7c3c2828, 0x657b008a, 0xd2590089, 0x00000000}},  //   marr, _asuh, liņu_,
  { {0x7c3c022b, 0x9f4700b9, 0x95ca0c4e, 0x00000000}},  //   larr, _nyní_, кула_,
  { {0x97840014, 0xd2590089, 0xdb1e00fa, 0x00000000}},  //   _گیاه, niņu_, _expô,
  { {0x7c3c318c, 0x00000000, 0x00000000, 0x00000000}},  //   narr,   ,   ,
  { {0xa69602a8, 0x39403ed3, 0xe737007c, 0x00000000}},  //   _крај, lsis_, _вес_,
  { {0x7c3c022b, 0x66e3003b, 0x3a2013b8, 0x00000000}},  //   harr, _доса, ncip_,
  { {0x7c3c022b, 0x39402b5f, 0x628000c4, 0x00000000}},  //   karr, nsis_, rdmo,
  { {0x7c3c000c, 0xa0a60364, 0x3940009d, 0x00000000}},  //   jarr, ршил, isis_,
  { {0x7c3c022b, 0x38170104, 0x443c08a8, 0x00000000}},  //   darr, יקים_, mav_,
  { {0xa186045a, 0x39400772, 0x443c3ed4, 0x00000000}},  //   _выкл, ksis_, lav_,
  { {0x7c3c022b, 0x6562033b, 0x6efd0010, 0x00000000}},  //   farr, ntoh, jébe,
  { {0x7c3c022b, 0x64581288, 0x443c014a, 0x00000000}},  //   garr, ngvi, nav_,
  { {0xa3cc01f5, 0x0c84007e, 0x00000000, 0x00000000}},  //   रपट_, цыям,   ,
  { {0x25600263, 0x443c00f8, 0x2d890211, 0x00000000}},  //   kòl_, hav_, _trae_,
  { {0x443c01cd, 0x7bde050a, 0x65620065, 0x00000000}},  // [f110] kav_, _expu, jtoh,
  { {0x7c3c0118, 0x1a6500a2, 0x256001aa, 0x00000000}},  //   carr, _گیری_, dòl_,
  { {0x39400006, 0x443c3eae, 0x3e860010, 0x00000000}},  //   asis_, dav_, sítő_,
  { {0x6e3d0058, 0x65620023, 0x6d4f0048, 0x00000000}},  //   nasb, ftoh, orca,
  { {0x98b3005f, 0x39400232, 0x442e0045, 0x00000000}},  //   şdır_, csis_, fbf_,
  { {0x7cf20030, 0x443c1693, 0x64580abc, 0x00000000}},  //   værk, gav_, ggvi,
  { {0x291900ea, 0xd2590089, 0x67d40793, 0x00000000}},  //   _husa_, ziņu_, _дору,
  { {0x7c3c002d, 0x6b83008e, 0x7cf20737, 0x00000000}},  //   zarr, _ángu, tærk,
  { {0x443c0119, 0x7c3c0032, 0x7659005b, 0x00000000}},  //   bav_, yarr, mgwy,
  { {0x291901a3, 0x92c90044, 0x7c3c0de2, 0x00000000}},  //   _musa_, োতে_, xarr,
  { {0x7c3c0211, 0x14d600b3, 0x2911133d, 0x00000000}},  //   varr, _פועל_, _miza_,
  { {0x394004a5, 0x29113a05, 0x6ef600d6, 0x00000000}},  //   ysis_, _liza_, rábo,
  { {0x7c3c022b, 0xe7f40201, 0x2919023a, 0x00000000}},  //   tarr, _अर्थ_, _nusa_,
  { {0x6efd3ed5, 0x2911016e, 0xd2590089, 0x00000000}},  //   vébe, _niza_, riņu_,
  { {0x6d4f0048, 0x7cf20637, 0xe0d00439, 0x00000000}},  //   arca, næri, _غزه_,
  { {0x7c3c0219, 0x25600263, 0x6b63008b, 0x00000000}},  //   sarr, yòl_, якса,
  { {0x7c3c002d, 0xbcfb0051, 0xfaa33ed6, 0x00000000}},  // [f120] parr, stéa, чато,
  { {0xeb9a012b, 0x7c3c002b, 0x6efd0010, 0x00000000}},  //   _био_, qarr, rébe,
  { {0x25600263, 0x39403ed7, 0xbb860054, 0x00000000}},  //   wòl_, ssis_, _الجي,
  { {0x394021e4, 0xe7370200, 0xef120049, 0x00000000}},  //   psis_, сец_, פּע_,
  { {0x443c0004, 0x29193ed8, 0x6bd700a2, 0x00000000}},  //   tav_, _gusa_, _نویس_,
  { {0x29111242, 0x65620065, 0x38b6000c, 0x00000000}},  //   _giza_, rtoh, _færa_,
  { {0x443c01cd, 0x961d001e, 0x65620065, 0x00000000}},  //   rav_, _saņe, stoh,
  { {0x65620065, 0x256001aa, 0x57b40061, 0x00000000}},  //   ptoh, pòl_, ंनीह,
  { {0x5a9b0049, 0xb3a9019a, 0x00000000, 0x00000000}},  //   רשפא, çırı,   ,
  { {0xf993009b, 0x6aa606d3, 0x397b00a0, 0x00000000}},  //   פרת_, _lokf, נטינ,
  { {0x64483ed9, 0xd0100025, 0x6d4401cb, 0x00000000}},  //   _iddi, بلد_, _avia,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d440061, 0x6e3d19ce, 0x3a390142, 0x00000000}},  //   _cvia, rasb, _resp_,
  { {0x291901a3, 0x9f340088, 0x3f98006c, 0x00000000}},  //   _rusa_, _декі, ärus_,
  { {0x29190032, 0xdddd0010, 0x6aa60039, 0x00000000}},  //   _susa_, reső, _bokf,
  { {0x62820e00, 0x291938a5, 0x8aa4060e, 0x00000000}},  //   _jaoo, _pusa_, пруд,
  { {0x64480142, 0x19590147, 0x291100fa, 0x00000000}},  // [f130] _oddi, разы_, _piza_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xb065021e, 0x00000000, 0x00000000, 0x00000000}},  //   llää,   ,   ,
  { {0x64480038, 0x35f50264, 0xb6c900a1, 0x00000000}},  //   _addi, опер, جائے_,
  { {0x29111391, 0xd5670069, 0x29190225, 0x00000000}},  //   _tiza_, степ, _uusa_,
  { {0x7659018e, 0xfbd00123, 0x81cc0044, 0x00000000}},  //   sgwy, _آتی_, _শুভ_,
  { {0x5c5c0049, 0x68fa009b, 0x47bf0044, 0x00000000}},  //   אדוק, _כלשה, ্থহী,
  { {0x64480047, 0x7f41001c, 0x6e3b000c, 0x00000000}},  //   _eddi, vslq, ðubl,
  { {0x26cf00f7, 0x76493eda, 0xb5fd00ca, 0x00000000}},  //   migo_, _idey, _obši,
  { {0x26cf011c, 0x7e6d0009, 0x6e240026, 0x00000000}},  //   ligo_, _abap, _sfib,
  { {0xb4e50164, 0x6d440142, 0x78a700ca, 0x00000000}},  //   नवी_, _svia, _mojv,
  { {0x26cf005b, 0xdce40089, 0x44250203, 0x00000000}},  //   nigo_, _oriģ, _hfl_,
  { {0x21a509ae, 0xbcfb0047, 0xe29f009f, 0x00000000}},  //   _филм, rtén, öðu_,
  { {0x6c3601b7, 0x26cf06a9, 0x212d01a3, 0x00000000}},  //   تفسا, higo_, mpeh_,
  { {0x442505ad, 0xbea6004d, 0x2b4300f6, 0x00000000}},  //   _mfl_, _макк, gsjc_,
  { {0x75290107, 0x26cf0059, 0x00000000, 0x00000000}},  //   _otez, jigo_,   ,
  { {0x26cf3edb, 0xd6cf0044, 0x442501e5, 0x00000000}},  // [f140] digo_, িকায, _ofl_,
  { {0x2d800009, 0x44250133, 0x0903105c, 0x00000000}},  //   _isie_, _nfl_, дпун,
  { {0xe61a012b, 0xfaa60d68, 0xf7720b6c, 0x00000000}},  //   аде_, _дано, باء_,
  { {0x44253edc, 0x366a01ee, 0x00000000, 0x00000000}},  //   _afl_, радо_,   ,
  { {0x85761298, 0xe5a3142c, 0x4425007f, 0x00000000}},  //   تدائ, мици, _bfl_,
  { {0x2d802046, 0x7af600b0, 0x7ae90059, 0x00000000}},  //   _msie_, llyt, čete,
  { {0xb4ca03d7, 0x26cf1d5e, 0x6282012d, 0x00000000}},  //   _लगी_, bigo_, _paoo,
  { {0xc29801fe, 0x6b8300c4, 0x71461ba3, 0x00000000}},  //   ских_, _ânge, охож,
  { {0x3952000a, 0xddcf0035, 0x00000000, 0x00000000}},  //   nrys_, iecţ,   ,
  { {0x92ca0044, 0x7af60016, 0x6ef60048, 0x00000000}},  //   লকে_, hlyt, lábh,
  { {0xb4d6001c, 0x2d801d1f, 0xf4870bb6, 0x00000000}},  //   ाची_, _asie_, _باقی,
  { {0x216a01f9, 0x00000000, 0x00000000, 0x00000000}},  //   _види_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x26cf0020, 0x3a3f0e0d, 0x6ef60048, 0x00000000}},  //   zigo_, _žup_, hábh,
  { {0x0b8801fe, 0x7af60039, 0x8aa701ee, 0x00000000}},  //   ости_, flyt, орад,
  { {0x6d480036, 0x7c41016c, 0x00000000, 0x00000000}},  //   ądar, _švrć,   ,
  { {0x26cf0197, 0xb955005e, 0x6d4004a5, 0x00000000}},  // [f150] vigo_, яващ, šmar,
  { {0x3ea90082, 0x60da01a2, 0x00000000, 0x00000000}},  //   _hoat_, nntm,   ,
  { {0x26cf3edd, 0x78a7003b, 0x75290514, 0x00000000}},  //   tigo_, _vojv, _stez,
  { {0x4b7a007b, 0x442500f6, 0x9f4b0010, 0x00000000}},  //   _פארו, _sfl_, ülék_,
  { {0xceb40049, 0x26cf0181, 0x7989002b, 0x00000000}},  //   ויף_, rigo_, _ġeww,
  { {0x7d7c00a3, 0x3b09006b, 0xf484003b, 0x00000000}},  //   ינדו, lmaq_, дућн,
  { {0x5c38009b, 0x163502d9, 0x61e20032, 0x00000000}},  //   חרון_, _невя, _axol,
  { {0xd36e0076, 0xc245007c, 0x3b09006b, 0x00000000}},  //   اهي_, чник, nmaq_,
  { {0xddc40059, 0xdced0006, 0x8467005e, 0x00000000}},  //   _obiš, _apač, _мъже,
  { {0x44250146, 0xdce4002b, 0x64570b33, 0x00000000}},  //   _ufl_, _oriġ, óxid,
  { {0xf1a80014, 0x3ea900ab, 0xc0a8067a, 0x00000000}},  //   مایه_, _boat_, تايل_,
  { {0x2485032e, 0x3ea90133, 0xbcfb0010, 0x00000000}},  //   _halm_, _coat_, stél,
  { {0x2485002b, 0x29030fcf, 0x00000000, 0x00000000}},  //   _kalm_, _ohja_,   ,
  { {0xc212009b, 0x6729016c, 0x7cf200ea, 0x00000000}},  //   _נהג_, _čejn, jært,
  { {0xa09a0097, 0xfce3004c, 0xddcf001a, 0x00000000}},  //   _ליסט, хоро, tecţ,
  { {0xaa7b009f, 0x39520016, 0xa926007c, 0x00000000}},  //   _skýr, trys_, здал,
  { {0x3e5b00b6, 0xddcf001a, 0x7af604a5, 0x00000000}},  // [f160] _הדפס, recţ, rlyt,
  { {0xb4ca02d2, 0x6d4604d3, 0xd9100167, 0x00000000}},  //   _लगे_, mska, ئیس_,
  { {0x6d460378, 0x7c3e001e, 0xec3700a0, 0x00000000}},  //   lska, _iepr, _מאיר_,
  { {0x7aed03d1, 0xeafa00a6, 0x39520007, 0x00000000}},  //   coat, _درخت_, prys_,
  { {0x6d4602e1, 0x7c3e10ed, 0xdbce0279, 0x00000000}},  //   nska, _kepr, _bıça,
  { {0xb4d6001c, 0xf746053c, 0x6d462001, 0x00000000}},  //   ाचे_, _него, iska,
  { {0x2ca50daf, 0x69c4002b, 0x7c3e01aa, 0x00000000}},  //   öldi_, lzie, _mepr,
  { {0x6aa4002b, 0x62660025, 0x6d46122f, 0x00000000}},  //   njif, سابق, kska,
  { {0x69c4059b, 0xd041006b, 0xdb070010, 0x00000000}},  //   nzie, lilə, nyjá,
  { {0x6d4601c3, 0x3b09006b, 0x55bb009b, 0x00000000}},  //   dska, zmaq_, _הממו,
  { {0xd041005f, 0x443e0089, 0x3b09006b, 0x00000000}},  //   nilə, _iet_, ymaq_,
  { {0x443e049b, 0x6f040af7, 0x3b09006b, 0x00000000}},  //   _het_, _chic, xmaq_,
  { {0xbcfb0428, 0x50b7007a, 0x443e2e92, 0x00000000}},  //   stém, زدید_, _ket_,
  { {0x69c437d1, 0xd041006b, 0x212b102e, 0x00000000}},  //   dzie, kilə, íche_,
  { {0x443e049b, 0x3b09005f, 0x7aed01c5, 0x00000000}},  //   _met_, tmaq_, toat,
  { {0x443e2e9d, 0xd041006b, 0xcff700a3, 0x00000000}},  //   _let_, dilə, _מצוה_,
  { {0xdd910a90, 0x3b09006b, 0x7aed0023, 0x00000000}},  // [f170] _شود_, rmaq_, roat,
  { {0x443e298f, 0x7c3e023d, 0x26cd0521, 0x00000000}},  //   _net_, _gepr, _smeo_,
  { {0x7aed0035, 0x69c40035, 0x3b09006b, 0x00000000}},  //   poat, azie, pmaq_,
  { {0x24850066, 0xae01013d, 0x6ab6004a, 0x00000000}},  //   _salm_, _ईरान_, ckyf,
  { {0xe9450167, 0x443e0a98, 0x24851b2a, 0x00000000}},  //   _ترجی, _bet_, _palm_,
  { {0x443e02b6, 0x69090006, 0xfb1a00a1, 0x00000000}},  //   _cet_, _ežer, _دریں_,
  { {0x443e05cb, 0xd041006b, 0x6d460089, 0x00000000}},  //   _det_, cilə, zska,
  { {0x443e0007, 0x6d460036, 0x26cd0521, 0x00000000}},  //   _eet_, yska, _umeo_,
  { {0x443e1d81, 0x248501c3, 0x746b00e2, 0x00000000}},  //   _fet_, _talm_, _грев_,
  { {0x443e0038, 0x6d4602e1, 0x2ef21eb0, 0x00000000}},  //   _get_, vska, _skyf_,
  { {0xdee601b3, 0x64430585, 0x69c4185d, 0x00000000}},  //   дони, mani, zzie,
  { {0x644305e1, 0x6d461dd0, 0x443e00b5, 0x00000000}},  //   lani, tska, _zet_,
  { {0x443e00ab, 0xd041006b, 0x629900c7, 0x00000000}},  //   _yet_, zilə, _inwo,
  { {0x6f040038, 0x64430620, 0xfd5f001d, 0x00000000}},  //   _whic, nani, _huyệ,
  { {0x7c3e008d, 0x6d4601e3, 0x6f043ede, 0x00000000}},  //   _vepr, sska, _thic,
  { {0x69c43edf, 0x62890d44, 0x6d460039, 0x00000000}},  //   tzie, ndeo, pska,
  { {0x644318d5, 0xda650054, 0xf2d201ce, 0x00000000}},  // [f180] kani, عافي, דען_,
  { {0x64430004, 0x69c400b5, 0xfd5f0011, 0x00000000}},  //   jani, rzie, _luyệ,
  { {0x64430620, 0x443e0018, 0x9989016c, 0x00000000}},  //   dani, _ret_, rbaš_,
  { {0xd041005f, 0x443e1ef2, 0x2d920065, 0x00000000}},  //   rilə, _set_, _krye_,
  { {0x6443000b, 0x443e2256, 0x62890016, 0x00000000}},  //   fani, _pet_, ddeo,
  { {0x84380025, 0x443e0023, 0x62993ee0, 0x00000000}},  //   أكثر_, _qet_, _anwo,
  { {0x443e3ee1, 0xd90d025a, 0xd7f20025, 0x00000000}},  //   _vet_, _ایل_, _شكر_,
  { {0xa2e300ed, 0x2a6034b4, 0x443e1aaf, 0x00000000}},  //   којд, ngib_, _wet_,
  { {0x443e0263, 0xfd5f0011, 0x29180127, 0x00000000}},  //   _tet_, _duyệ, _kira_,
  { {0xbcfb0010, 0x62990016, 0x92be0044, 0x00000000}},  //   rték, _enwo, ঁচে_,
  { {0x0857019b, 0xdfd003ec, 0x00000000, 0x00000000}},  //   ובים_, ايج_,   ,
  { {0x291820a7, 0x22930025, 0x752000e7, 0x00000000}},  //   _lira_, _للمس, _kumz,
  { {0x2f1a0089, 0x56370049, 0x00000000, 0x00000000}},  //   _rīgu_, ואכע_,   ,
  { {0xbca50025, 0x29180145, 0x00000000, 0x00000000}},  //   رمزي, _nira_,   ,
  { {0xbcfb0051, 0x5f9402dc, 0x00000000, 0x00000000}},  //   ntéi, _чийт,   ,
  { {0x64430046, 0x5f0403f3, 0xe188001d, 0x00000000}},  //   zani, _изја, _kỳ_,
  { {0x64432175, 0x7e7d00ab, 0x98b90264, 0x00000000}},  // [f190] yani, mesp, плат_,
  { {0x64433ee2, 0xe1880082, 0x00000000, 0x00000000}},  //   xani, _mỳ_,   ,
  { {0x29180756, 0x644313a1, 0x6d5d0169, 0x00000000}},  //   _dira_, vani, lusa,
  { {0x64430df0, 0xcf93007b, 0x7e7d0089, 0x00000000}},  //   wani, כטע_, nesp,
  { {0x64430046, 0x29183ee3, 0x6d5d006c, 0x00000000}},  //   tani, _fira_, nusa,
  { {0xd00600f3, 0xc484008b, 0x29180919, 0x00000000}},  //   _مل_, клік, _gira_,
  { {0xa3c903d7, 0x64430868, 0x39491325, 0x00000000}},  //   _लेख_, rani, lsas_,
  { {0x715901be, 0x39490c1b, 0x7e7d00f8, 0x00000000}},  //   прос_, osas_, jesp,
  { {0x644339e2, 0x7e7d05d5, 0x6d5d1540, 0x00000000}},  //   pani, desp, jusa,
  { {0x2918027b, 0x39490181, 0x6d5d006c, 0x00000000}},  //   _xira_, isas_, dusa,
  { {0xfd5f001d, 0x64410089, 0x00000000, 0x00000000}},  //   _tuyệ, _ieli,   ,
  { {0x64410b83, 0x39490ebc, 0xee3701e1, 0x00000000}},  //   _heli, ksas_, нню_,
  { {0x6441010a, 0x6d5d14f7, 0xd0a80167, 0x00000000}},  //   _keli, gusa, سطین_,
  { {0x64413ee4, 0x2d920007, 0x31560097, 0x00000000}},  //   _jeli, _vrye_, _ניצן_,
  { {0x64410149, 0x7ae90213, 0x39491b04, 0x00000000}},  //   _meli, četn, esas_,
  { {0x291803dd, 0xfd4a0265, 0x7e7d0851, 0x00000000}},  //   _sira_, _език_, cesp,
  { {0x6d5d0197, 0x29181ec6, 0x0906004c, 0x00000000}},  // [f1a0] cusa, _pira_, епан,
  { {0x6441001e, 0xe8f70816, 0x29180023, 0x00000000}},  //   _neli, елу_, _qira_,
  { {0xf0b60049, 0x29182343, 0x00000000, 0x00000000}},  //   עלער_, _vira_,   ,
  { {0x75200020, 0x2918003f, 0x64412cdc, 0x00000000}},  //   _pumz, _wira_, _aeli,
  { {0x6441288b, 0x29180c79, 0x25080167, 0x00000000}},  //   _beli, _tira_, ورتی_,
  { {0x64410059, 0x7e7d115e, 0x7ebf0065, 0x00000000}},  //   _celi, zesp, _mëpa,
  { {0xc5f10044, 0x6d5d01a2, 0xd467003b, 0x00000000}},  //   জেলা_, zusa, хије_,
  { {0xc6150044, 0x6441006c, 0x6d5d0058, 0x00000000}},  //   াড়া_, _eeli, yusa,
  { {0x7e7d00c4, 0xbcfb3ee5, 0x7bc7002b, 0x00000000}},  //   vesp, stéi, zzju,
  { {0x6441011f, 0x6d5d006c, 0x53a6007e, 0x00000000}},  //   _geli, vusa, _пазб,
  { {0x7e7d0039, 0xde590088, 0x00000000, 0x00000000}},  //   tesp, мані_,   ,
  { {0x6d5d0149, 0x828901fb, 0x64410213, 0x00000000}},  //   tusa, _осіб_, _zeli,
  { {0x7e7d0292, 0x3b191347, 0x6441019a, 0x00000000}},  //   resp, _risq_, _yeli,
  { {0x6d5d0149, 0x38b6000c, 0x5ff431ca, 0x00000000}},  //   rusa, _færi_, _излу,
  { {0x6d5d0518, 0x7e7d3ee6, 0x79860145, 0x00000000}},  //   susa, pesp, _askw,
  { {0x6d5d0525, 0x39493ee7, 0x539b009b, 0x00000000}},  //   pusa, tsas_, הילו,
  { {0x38c9026c, 0x394939df, 0x00000000, 0x00000000}},  // [f1b0] وائی_, usas_,   ,
  { {0x39491325, 0x81e20044, 0x3b1901d5, 0x00000000}},  //   rsas_, _ধরা_, _wisq_,
  { {0x394902d5, 0x79863ee8, 0xd2460123, 0x00000000}},  //   ssas_, _eskw, _پن_,
  { {0x64413ee9, 0xc5d501fb, 0x442c0190, 0x00000000}},  //   _seli, кіль, _afd_,
  { {0x09db0055, 0xd12604e8, 0x442c0e9b, 0x00000000}},  //   _দরকা, _خم_, _bfd_,
  { {0x64410065, 0xbcfb009d, 0x00000000, 0x00000000}},  //   _qeli, buée,   ,
  { {0x61fc005f, 0x442c3eea, 0x656b002b, 0x00000000}},  //   ərli, _dfd_, stgh,
  { {0x64410168, 0x3cf30061, 0x9324025a, 0x00000000}},  //   _weli, ंकडे_, درون,
  { {0xc692007b, 0x64410357, 0xa156012b, 0x00000000}},  //   _דאן_, _teli, вању_,
  { {0x409501e0, 0xe0d6007c, 0x00000000, 0x00000000}},  //   трит, квы_,   ,
  { {0x6009007c, 0x6d4d00b0, 0x662800f8, 0x00000000}},  //   ьном_, _avaa, _åskå,
  { {0x38b6009f, 0x623502dc, 0xba3b147f, 0x00000000}},  //   _væri_, _реду, _moïs,
  { {0x0d9900a5, 0x0d8309b2, 0x628b0045, 0x00000000}},  //   нтры_, алян, _iago,
  { {0x628b0271, 0x6e2d0288, 0x00000000, 0x00000000}},  //   _hago, _efab,   ,
  { {0x316d00f4, 0x8c43007c, 0x99800006, 0x00000000}},  //   ltez_, ресе, ybių_,
  { {0x7db60088, 0x628b0213, 0x00000000, 0x00000000}},  //   _асоц, _jago,   ,
  { {0x628b0244, 0x316d00f4, 0x6aaf0026, 0x00000000}},  // [f1c0] _mago, ntez_, _docf,
  { {0x628b0181, 0xed5901ca, 0x6efd0010, 0x00000000}},  //   _lago, áže_, yébk,
  { {0x442c0ace, 0x00000000, 0x00000000, 0x00000000}},  //   _rfd_,   ,   ,
  { {0x628b0091, 0xb6cb00a1, 0x442c3eeb, 0x00000000}},  //   _nago, وانے_, _sfd_,
  { {0x64a6003b, 0xd90d00a1, 0x99800006, 0x00000000}},  //   када, زیہ_, rbių_,
  { {0x628b00e0, 0x44f3007e, 0x00000000, 0x00000000}},  //   _aago, апіс,   ,
  { {0x628b006a, 0xbcfb00f4, 0xc7a300d7, 0x00000000}},  //   _bago, quée, _кирк,
  { {0xbcfb1f2c, 0x628b06d2, 0x00000000, 0x00000000}},  //   ltét, _cago,   ,
  { {0x628b022b, 0x442c3eec, 0xf1a3007e, 0x00000000}},  //   _dago, _tfd_, арэн,
  { {0xbcfb3eed, 0x628b00d9, 0xf8bf0068, 0x00000000}},  //   ntét, _eago, _tuée_,
  { {0x628b00ea, 0x00000000, 0x00000000, 0x00000000}},  //   _fago,   ,   ,
  { {0x628b0032, 0xe3160025, 0x26c611c8, 0x00000000}},  //   _gago, _شباب, nhoo_,
  { {0x316d00f4, 0x62800181, 0xd1300123, 0x00000000}},  //   ctez_, memo, _امت_,
  { {0x628b01d9, 0x38b6000c, 0x00000000, 0x00000000}},  //   _zago, _kæru_,   ,
  { {0x628b0202, 0x00000000, 0x00000000, 0x00000000}},  //   _yago,   ,   ,
  { {0x62800211, 0x00000000, 0x00000000, 0x00000000}},  //   nemo,   ,   ,
  { {0x5a44007e, 0xbcfb004a, 0x00000000, 0x00000000}},  // [f1d0] рэса, ruéb,   ,
  { {0x6280007f, 0x2d890026, 0x63b83eee, 0x00000000}},  //   hemo, _isae_, kyvn,
  { {0x62800056, 0x00000000, 0x00000000, 0x00000000}},  //   kemo,   ,   ,
  { {0x62800142, 0x7ebf0023, 0x79840045, 0x00000000}},  //   jemo, _mëpo, bwiw,
  { {0x62800489, 0x628b0016, 0x00000000, 0x00000000}},  //   demo, _rago,   ,
  { {0x628b006a, 0xe73301af, 0x00000000, 0x00000000}},  //   _sago, _نصر_,   ,
  { {0x628b1a16, 0xbcfb0010, 0x58d4005e, 0x00000000}},  //   _pago, ltés, _торт,
  { {0x62800cc0, 0x316d00f4, 0x8c1c01ce, 0x00000000}},  //   gemo, ttez_, וווי,
  { {0xbcfb0047, 0xdb150047, 0x316d00f4, 0x00000000}},  //   ntés, gyzé, utez_,
  { {0x628b0020, 0x316d3eef, 0x3e7e0082, 0x00000000}},  //   _wago, rtez_, _ắt_,
  { {0x628b0010, 0x62800b76, 0xd048005f, 0x00000000}},  //   _tago, bemo, nidə,
  { {0xed5a0902, 0x62800b76, 0x316d2265, 0x00000000}},  //   ном_, cemo, ptez_,
  { {0xd048006b, 0x00000000, 0x00000000, 0x00000000}},  //   hidə,   ,   ,
  { {0xa069005e, 0x00000000, 0x00000000, 0x00000000}},  //   _чака_,   ,   ,
  { {0x4a9a007e, 0x5ea60025, 0x00000000, 0x00000000}},  //   нтаў_, _ممثل,   ,
  { {0x0e66013b, 0x290a0065, 0xc332009b, 0x00000000}},  //   _скин, _shba_, מול_,
  { {0x3ea0011c, 0xaff400a1, 0x1a0602e9, 0x00000000}},  // [f1e0] _init_, _مہیا_, упам,
  { {0x4c860888, 0x62803ef0, 0x291c0039, 0x00000000}},  //   _слов, zemo, öva_,
  { {0xf8bf00f6, 0x657b00e0, 0x6280004a, 0x00000000}},  //   _atés_, _apuh, yemo,
  { {0xbcfb01e5, 0x85ea15c4, 0xf74300e2, 0x00000000}},  //   stét, ндев_, сецо,
  { {0x62800181, 0x7d1e0ac2, 0x00000000, 0x00000000}},  //   vemo, _kips,   ,
  { {0x5334007e, 0x7ae40059, 0xbcfb26f7, 0x00000000}},  //   аект, lnit, ltér,
  { {0x62802c9b, 0xbcfb000c, 0x27f70161, 0x00000000}},  //   temo, bréf, čené_,
  { {0x7ae40368, 0x7d1e001a, 0x96950216, 0x00000000}},  //   nnit, _lips, _круш,
  { {0x62802a9a, 0x7ae420d4, 0xddcd016c, 0x00000000}},  //   remo, init, _obaš,
  { {0x7ae4010f, 0x3ea00023, 0x7d1e3ef1, 0x00000000}},  //   hnit, _anit_, _nips,
  { {0x7ae41470, 0x644a0197, 0x2018003c, 0x00000000}},  //   knit, mafi, äri_,
  { {0x7ae90295, 0x394201c3, 0x9ec703ec, 0x00000000}},  //   četk, _owks_, ازده,
  { {0x7ae43ef2, 0x3ea000fa, 0x3b00013f, 0x00000000}},  //   dnit, _dnit_, dliq_,
  { {0x644a0127, 0x5f94007c, 0xe3b100a1, 0x00000000}},  //   nafi, _викт, _ارے_,
  { {0xdb580b7b, 0x26c40058, 0x60da04cb, 0x00000000}},  //   лют_, _olmo_, mitm,
  { {0xfebb007a, 0x5a35026b, 0x644a006b, 0x00000000}},  //   _ساعت_, рнат, hafi,
  { {0x200b0036, 0x19580783, 0x644a0020, 0x00000000}},  // [f1f0] ęcie_, латы_, kafi,
  { {0x7ae408ce, 0x644a29fc, 0xbcfb0010, 0x00000000}},  //   anit, jafi, rtés,
  { {0x6457362f, 0x644a005f, 0xf807007e, 0x00000000}},  //   óxim, dafi, учан,
  { {0xbcfb00f4, 0xaa950088, 0xbb3a0104, 0x00000000}},  //   ctér, _тимч, _שערי,
  { {0xe5a50216, 0x6d4f002a, 0xd46901fc, 0x00000000}},  //   рили, nsca, виле_,
  { {0x26c4010e, 0xd7fb0140, 0x2249016e, 0x00000000}},  //   _elmo_, _зуб_, _žak_,
  { {0x60da00eb, 0x38b6043e, 0x6d5d01a2, 0x00000000}},  //   ditm, _vært_, hrsa,
  { {0x29010f68, 0x6d5d0107, 0x6f0d0011, 0x00000000}},  //   llha_, krsa, _nhac,
  { {0x91e50920, 0x645e0b33, 0x67270022, 0x00000000}},  //   ропе, ópic, _hujj,
  { {0x7ae41332, 0x6d4f02c2, 0x764b011c, 0x00000000}},  //   znit, dsca, lagy,
  { {0x46b90061, 0x6d4f00fa, 0x7d1e05e0, 0x00000000}},  //   _आवाह, esca, _rips,
  { {0x6f0d0e6d, 0x764b0b57, 0x67270045, 0x00000000}},  //   _chac, nagy, _mujj,
  { {0x7ae4013e, 0x6f0d0009, 0x69091ae3, 0x00000000}},  //   vnit, _dhac, _džez,
  { {0x764b258d, 0x3fc701b2, 0x00000000, 0x00000000}},  //   hagy, _مدعی_,   ,
  { {0xbcfb2b25, 0x6d4f16b8, 0x6d5d0051, 0x00000000}},  //   ttér, asca, arsa,
  { {0x3ea0020c, 0x6aad000c, 0x2a6b00d4, 0x00000000}},  //   _unit_, gjaf, _cccb_,
  { {0x7d1e0073, 0x2d8c001e, 0x7ae4051b, 0x00000000}},  // [f200] _tips, ādes_, rnit,
  { {0xbcfb3ef3, 0x7ae40292, 0xdced0066, 0x00000000}},  //   stér, snit, _traġ,
  { {0x5c5b00b6, 0x644a006b, 0x6609000a, 0x00000000}},  //   _בדיק, vafi, _azek,
  { {0x6d440036, 0x644a0020, 0x7ae4006b, 0x00000000}},  //   _kwia, wafi, qnit,
  { {0x644a3ef4, 0x66090046, 0x7bce010f, 0x00000000}},  //   tafi, _czek, lzbu,
  { {0x66093ef5, 0xc4480014, 0xbcfb3ef6, 0x00000000}},  //   _dzek, ایان_, créd,
  { {0x66090047, 0x764b020e, 0x6e243ef7, 0x00000000}},  //   _ezek, bagy, _ogib,
  { {0x6d4f0bc7, 0x644a0c04, 0x6e2401f3, 0x00000000}},  //   ysca, safi, _ngib,
  { {0x60f83879, 0x644a0173, 0x3cf83ef8, 0x00000000}},  //   лния_, pafi, korv_,
  { {0x6d5d0107, 0x6e2417f8, 0x6f0d0133, 0x00000000}},  //   vrsa, _agib, _shac,
  { {0x60da002d, 0x69cd0190, 0x6f0d0051, 0x00000000}},  //   ritm, zzae, _phac,
  { {0x6d4f1651, 0x6448014a, 0x2abc0048, 0x00000000}},  //   tsca, _hedi, _uíbh_,
  { {0x64481d7d, 0x6d5d0fe4, 0x00000000, 0x00000000}},  //   _kedi, ursa,   ,
  { {0x644806a6, 0x6f0d0436, 0x91bb009b, 0x00000000}},  //   _jedi, _whac, _במדי,
  { {0x6d4f00bb, 0x6f0d0051, 0xaa590088, 0x00000000}},  //   ssca, _thac, ливу_,
  { {0x644800eb, 0x8aa4053f, 0x1b190783, 0x00000000}},  //   _ledi, оруд, ужбы_,
  { {0x6d440046, 0x31640009, 0x00000000, 0x00000000}},  // [f210] _gwia, numz_,   ,
  { {0x6448011f, 0xd70f007d, 0x66093ef9, 0x00000000}},  //   _nedi, िष्ठ_, _rzek,
  { {0x66090010, 0x6d440036, 0xbcfb009d, 0x00000000}},  //   _szek, _zwia, grée,
  { {0xdfc600a1, 0x2b5e01dc, 0x00000000, 0x00000000}},  //   _ہي_, átce_,   ,
  { {0xd4d9008b, 0x64480125, 0x8e9800b3, 0x00000000}},  //   лькі_, _bedi, ידאו_,
  { {0xdfc606ea, 0x644806c2, 0x00000000, 0x00000000}},  //   _في_, _cedi,   ,
  { {0xbcfb009d, 0xc6a70d73, 0x00000000, 0x00000000}},  //   crée, _краи,   ,
  { {0x6609002d, 0x61e401ed, 0x00000000, 0x00000000}},  //   _tzek, _žila,   ,
  { {0x66003efa, 0xeaaa0049, 0x6f1800f6, 0x00000000}},  //   _gymk, רױפֿ, _èxci,
  { {0x64483efb, 0x7e6d008e, 0x26dd3eeb, 0x00000000}},  //   _gedi, _acap, liwo_,
  { {0x7afd0cfd, 0x25db006e, 0x6d440036, 0x00000000}},  //   _okst, _खेती_, _swia,
  { {0x64480032, 0xd4910082, 0xf6790049, 0x00000000}},  //   _zedi, _hà_, נאָמ,
  { {0xa2a40309, 0x6448005a, 0x75290553, 0x00000000}},  //   कार्, _yedi, _juez,
  { {0xa5da0049, 0x7afd000c, 0x76490022, 0x00000000}},  //   אַלי, _akst, _leey,
  { {0x44250058, 0x75210089, 0xd4910082, 0x00000000}},  //   _mgl_, _milz, _mà_,
  { {0x6e24050f, 0xd4910011, 0x7bce01a2, 0x00000000}},  //   _ugib, _là_, rzbu,
  { {0x6720002b, 0x6d443efc, 0x00000000, 0x00000000}},  // [f220] _rimj, _uwia,   ,
  { {0x7afd02cc, 0x6c860025, 0xbcfb00f4, 0x00000000}},  //   _ekst, _الدم, trée,
  { {0x78b501cd, 0x64483efd, 0xdb1c0065, 0x00000000}},  //   _dozv, _redi, nyrë,
  { {0x6448020c, 0x6efd0353, 0xbcfb009d, 0x00000000}},  //   _sedi, lébr, rrée,
  { {0x673b0091, 0x64483efe, 0x75210190, 0x00000000}},  //   _čuje, _pedi, _bilz,
  { {0x6fca03d7, 0x442500f6, 0x395200e5, 0x00000000}},  //   ानमं, _cgl_, msys_,
  { {0x64480027, 0xdb1c0023, 0x67200c43, 0x00000000}},  //   _vedi, jyrë, _timj,
  { {0x4425000a, 0xdd2d0006, 0x64480544, 0x00000000}},  //   _egl_, vėžy, _wedi,
  { {0x3952103b, 0x7521185d, 0x64480095, 0x00000000}},  //   nsys_, _filz, _tedi,
  { {0x7e6d0412, 0x752123cf, 0x9f54189c, 0x00000000}},  //   _scap, _gilz, овоч,
  { {0x2d800736, 0xa50700ed, 0x224d0afd, 0x00000000}},  //   _apie_, _уефа_, baek_,
  { {0x814300a6, 0xeeab39ae, 0x20020089, 0x00000000}},  //   _کنون, уток_, āki_,
  { {0x200b0046, 0x26c70023, 0x7e6d00d9, 0x00000000}},  //   ęcia_, ënoi_, _vcap,
  { {0x1fa60088, 0x00000000, 0x00000000, 0x00000000}},  //   _григ,   ,   ,
  { {0x78b50428, 0x2a690022, 0x2ac7003b, 0x00000000}},  //   _rozv, tgab_, бљав,
  { {0x7e6d027e, 0x7f3b0049, 0x83370049, 0x00000000}},  //   _ucap, _געהו, מאלס_,
  { {0x78270025, 0x2a6908e8, 0x00000000, 0x00000000}},  // [f230] معال, rgab_,   ,
  { {0x764902d4, 0x00000000, 0x00000000, 0x00000000}},  //   _seey,   ,   ,
  { {0xddcd0036, 0x5695007c, 0x00000000, 0x00000000}},  //   _udał, жает,   ,
  { {0x8f9b009b, 0x442500fa, 0x00000000, 0x00000000}},  //   טיבי, _sgl_,   ,
  { {0x98c5014a, 0x442500e5, 0x61e411b9, 0x00000000}},  //   ştır_, _pgl_, _žiln,
  { {0x2d99010e, 0x23350e8a, 0x00000000, 0x00000000}},  //   ivse_, охир,   ,
  { {0xd4910011, 0x4425258a, 0x26dd0173, 0x00000000}},  //   _và_, _vgl_, piwo_,
  { {0x6b8300c4, 0x00000000, 0x00000000, 0x00000000}},  //   _ângu,   ,   ,
  { {0x4425023a, 0x0595007a, 0x3f9c006c, 0x00000000}},  //   _tgl_, _بازگ, _arvu_,
  { {0xe0d90265, 0xdb1c0065, 0x4425016e, 0x00000000}},  //   рво_, tyrë, _ugl_,
  { {0x248701aa, 0xd0093eff, 0xbef70061, 0x00000000}},  //   menm_, рене_, ीतून_,
  { {0x6e2900b9, 0x3f8e0087, 0x00000000, 0x00000000}},  //   žebn, _dsfu_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6efd009d, 0x2d8001c3, 0x00000000, 0x00000000}},  //   rébr, _wpie_,   ,
  { {0x3946007e, 0xbcfb0068, 0x39520544, 0x00000000}},  //   жнаг, tréc, tsys_,
  { {0xcee90014, 0xdce40066, 0x00000000, 0x00000000}},  // [f240] _درون_, _esiġ,   ,
  { {0x3952005b, 0xe9d7007e, 0x2487012d, 0x00000000}},  //   rsys_, цку_, jenm_,
  { {0xd7ff001a, 0x562a21b5, 0x00000000, 0x00000000}},  //   _ţări_, ажем_,   ,
  { {0xbcfb00f4, 0x98af0089, 0x39523659, 0x00000000}},  //   préc, īgā_, psys_,
  { {0xddcd0036, 0x94aa0081, 0x645e1690, 0x00000000}},  //   _gdań, итка_, ópio,
  { {0xe71a0014, 0x00000000, 0x00000000, 0x00000000}},  //   _چيست_,   ,   ,
  { {0xd467012b, 0xe71a0014, 0xa3fa0044, 0x00000000}},  //   ције_, _نيست_, েখ্য_,
  { {0xfbe80082, 0x00000000, 0x00000000, 0x00000000}},  //   _đề_,   ,   ,
  { {0xcb13019b, 0x76420093, 0x045a00a6, 0x00000000}},  //   ולה_, mboy, _نجات_,
  { {0x397b0097, 0x3f9c1435, 0xa50a0216, 0x00000000}},  //   סטינ, _prvu_, _теза_,
  { {0xd1b7026c, 0x6d56000a, 0x00000000, 0x00000000}},  //   مایا_, _avya,   ,
  { {0x7642013f, 0x00000000, 0x00000000, 0x00000000}},  //   nboy,   ,   ,
  { {0xf65300b6, 0x171b0049, 0xdce40066, 0x00000000}},  //   וצר_, יוטע, _ssiġ,
  { {0x20d30025, 0x6fb60025, 0x61ed0006, 0x00000000}},  //   _يتوج, _ومشا, _žalg,
  { {0x80a30014, 0xbcfb2496, 0x4439006b, 0x00000000}},  //   _زمين, gréa, _əs_,
  { {0x690b04bd, 0x65620232, 0x00000000, 0x00000000}},  //   güen, kroh,   ,
  { {0x76423f00, 0x645a0142, 0x00000000, 0x00000000}},  // [f250] dboy, _odti,   ,
  { {0xf8070088, 0x6562010f, 0xdef9002b, 0x00000000}},  //   очен, droh, duċi_,
  { {0xbcfb009d, 0x68ee0022, 0x602d0010, 0x00000000}},  //   créa, _djbd, _hőmé,
  { {0x0f7b00b6, 0xabfa009b, 0x645a0145, 0x00000000}},  //   שראל, _להתר, _adti,
  { {0x65620093, 0x1a6800a1, 0x00000000, 0x00000000}},  //   groh, _ذیلی_,   ,
  { {0x6fca0164, 0xab980014, 0x645a0288, 0x00000000}},  //   ानां, _اخیر_, _cdti,
  { {0x0768007e, 0xaabf0316, 0x00000000, 0x00000000}},  //   _маёй_, _एकाक,   ,
  { {0xd2a90057, 0x2d84014a, 0x52a9003b, 0x00000000}},  //   ские_, çmek_, свим_,
  { {0x21390065, 0xa3db007d, 0x00000000, 0x00000000}},  //   ësh_, _ढेर_,   ,
  { {0x753b004a, 0x98bd007d, 0xa0690098, 0x00000000}},  //   _ituz, ोसिए, љана_,
  { {0x64430059, 0x8fa5231f, 0x00000000, 0x00000000}},  //   mbni, чане,   ,
  { {0xe29801fb, 0xf99f0173, 0x60ca01a2, 0x00000000}},  //   _має_, _orè_, _elfm,
  { {0xe0ce01fb, 0x260f0061, 0x7ebf0023, 0x00000000}},  //   _зв_, तेची_, _nëpu,
  { {0x408700e1, 0x213f3f01, 0x913a009b, 0x00000000}},  //   _фудб, mpuh_, _העסק,
  { {0x6f06001c, 0x76420253, 0xf99f0173, 0x00000000}},  //   plkc, yboy, _arè_,
  { {0x8b233354, 0xaf760049, 0xf99f0026, 0x00000000}},  //   едсе, _זעקס_, _brè_,
  { {0xf98300ed, 0x798d011c, 0x753b0009, 0x00000000}},  // [f260] нгто, gwaw, _ntuz,
  { {0x6443012d, 0x2d922492, 0x765b0145, 0x00000000}},  //   jbni, _isye_, _aduy,
  { {0x76420146, 0xf99f01aa, 0x66e61079, 0x00000000}},  //   tboy, _erè_, пожа,
  { {0x690b0a0a, 0xf99f0263, 0x65620065, 0x00000000}},  //   qüen, _frè_, troh,
  { {0xa50a20d2, 0xf99f000a, 0x862301ab, 0x00000000}},  //   беда_, _grè_, ньше,
  { {0x39400039, 0x2d9201aa, 0x65620065, 0x00000000}},  //   mpis_, _msye_, rroh,
  { {0xb62a0011, 0xbcfb0010, 0x00000000, 0x00000000}},  //   _chợđ, krén,   ,
  { {0x994c0027, 0x26cf0009, 0x65623f02, 0x00000000}},  //   _môže_, chgo_, proh,
  { {0x644300f8, 0x7faa006b, 0x00000000, 0x00000000}},  //   bbni, vəqq,   ,
  { {0x26c6152f, 0x9405006b, 0x00000000, 0x00000000}},  //   lkoo_, _lalə_,   ,
  { {0xb4e8001c, 0x7d07016c, 0x2d920173, 0x00000000}},  //   मची_, vljs, _asye_,
  { {0x0b000044, 0x61ed00ca, 0x6b9c04eb, 0x00000000}},  //   ্দুল_, _žale, dvrg,
  { {0x68fe00b5, 0xa0a600d7, 0x7faa006b, 0x00000000}},  //   kopd, _надд, rəqq,
  { {0x39400142, 0x2ceb1280, 0x01370097, 0x00000000}},  //   dpis_, сьмо_, _צרות_,
  { {0x2d92000a, 0x307b009b, 0x00000000, 0x00000000}},  //   _esye_, _האונ,   ,
  { {0x59de0316, 0xf99f01aa, 0xbcfb0a50, 0x00000000}},  //   _नेहर, _prè_, ntéz,
  { {0x61e40087, 0x39400058, 0x798d00e7, 0x00000000}},  // [f270] _žilj, gpis_, uwaw,
  { {0x7e7d0112, 0xf99f01aa, 0x798d008a, 0x00000000}},  //   lfsp, _vrè_, rwaw,
  { {0x753b0ec0, 0x00000000, 0x00000000, 0x00000000}},  //   _stuz,   ,   ,
  { {0xa63401fb, 0xf99f01aa, 0x672e002b, 0x00000000}},  //   енці, _trè_, _dubj,
  { {0x7aed001a, 0x8c19007a, 0xa4d50088, 0x00000000}},  //   mnat, _ديگر_, моді,
  { {0x644301a2, 0x8339004d, 0x00000000, 0x00000000}},  //   ubni, очит_,   ,
  { {0x20c9009f, 0x64430089, 0xe4500379, 0x00000000}},  //   _búin_, rbni, اضه_,
  { {0x7aed08b2, 0x5694008b, 0x2326022a, 0x00000000}},  //   nnat, _паст, мощи_,
  { {0xf4870680, 0x7aed002d, 0x753b0ff1, 0x00000000}},  //   _нужн, inat, _utuz,
  { {0x3ea90129, 0x7aed0016, 0x629d0027, 0x00000000}},  //   _anat_, hnat, ôsob,
  { {0x3e8a01e0, 0x656b3f03, 0x39400e3c, 0x00000000}},  //   ойно_, lugh, zpis_,
  { {0x32e30263, 0xee371001, 0x39403f04, 0x00000000}},  //   _dèyè_, мню_, ypis_,
  { {0x291a3f05, 0x00000000, 0x00000000, 0x00000000}},  //   ympa_,   ,   ,
  { {0x7aed0275, 0xdef9002b, 0x00000000, 0x00000000}},  //   enat, duċu_,   ,
  { {0x212f3174, 0xeb970088, 0x7aed3f06, 0x00000000}},  //   _hugh_, мир_, fnat,
  { {0x7aed0198, 0x21270011, 0x3ea90c7d, 0x00000000}},  //   gnat, _hinh_, _gnat_,
  { {0x212700ad, 0x672e0038, 0x68fe0146, 0x00000000}},  // [f280] _kinh_, _subj, topd,
  { {0xa3bf0316, 0x6d920521, 0x7aed0145, 0x00000000}},  //   ुना_, ržać, anat,
  { {0x2127001d, 0x7aed3f07, 0x68fe00d9, 0x00000000}},  //   _minh_, bnat, ropd,
  { {0x2127001d, 0xb6c503e8, 0x656b0197, 0x00000000}},  //   _linh_, нсій, fugh,
  { {0x20c90048, 0x7ae401b1, 0x00000000, 0x00000000}},  //   _rúin_, miit,   ,
  { {0x7ae408b2, 0x2127001d, 0xb4e80061, 0x00000000}},  //   liit, _ninh_, मचे_,
  { {0xd8230517, 0x212f0026, 0x26cd000a, 0x00000000}},  //   _адри, _augh_, _fleo_,
  { {0x78bc0010, 0x7ae40052, 0x6b830039, 0x00000000}},  //   _horv, niit, _änge,
  { {0x78bc0368, 0x21270011, 0x69c41715, 0x00000000}},  //   _korv, _binh_, nyie,
  { {0x7aed0119, 0x6f0400e7, 0x61ed0e0d, 0x00000000}},  //   znat, _akic, _žalc,
  { {0x20c9002a, 0x21270011, 0x442c0022, 0x00000000}},  //   _iúil_, _dinh_, _igd_,
  { {0xa1c619a2, 0x7ae400e7, 0xa3e4013d, 0x00000000}},  //   _обед, jiit, _पेय_,
  { {0x2007005f, 0x78bc0007, 0x7aed0b41, 0x00000000}},  //   _eyni_, _oorv, vnat,
  { {0x7e7d001c, 0x7c8415c4, 0x3ea900d9, 0x00000000}},  //   sfsp, кусе, _wnat_,
  { {0x7aed2548, 0x2b580009, 0x00000000, 0x00000000}},  //   tnat, gsrc_,   ,
  { {0x3ea90058, 0xb895009e, 0x7528193e, 0x00000000}},  //   _unat_, کارڈ, _lidz,
  { {0x2bff03d7, 0x6e2d3f08, 0x3b09006b, 0x00000000}},  // [f290] _शुरू_, _igab, rlaq_,
  { {0x273701d5, 0x2127001d, 0x75283f09, 0x00000000}},  //   _aħna_, _xinh_, _nidz,
  { {0x78bc1339, 0x7d050093, 0x7aed0203, 0x00000000}},  //   _dorv, _ikhs, pnat,
  { {0x6d4d01bb, 0x9967005e, 0x442c0036, 0x00000000}},  //   _kwaa, _отгл, _agd_,
  { {0xca240072, 0x78bc0374, 0x2d4d01ca, 0x00000000}},  //   _афри, _forv, nže_,
  { {0x656b0692, 0x62823f0a, 0xa8a401fc, 0x00000000}},  //   rugh, _aboo, _ирск,
  { {0x7528008f, 0x21270082, 0x20c90048, 0x00000000}},  //   _didz, _rinh_, _dúil_,
  { {0x212700ad, 0x2d4d004f, 0x6595007e, 0x00000000}},  //   _sinh_, kže_, _пабу,
  { {0x6abd000c, 0x15f3006e, 0x442c0022, 0x00000000}},  //   _mosf, _आखिर_, _fgd_,
  { {0x6f040073, 0x62821b2a, 0x7ae41bd7, 0x00000000}},  //   _skic, _eboo, ziit,
  { {0x21270011, 0xf8b200b3, 0x14ac01f5, 0x00000000}},  //   _vinh_, אשי_, चारण,
  { {0x62820061, 0x61ea0010, 0x6d4d00e0, 0x00000000}},  //   _gboo, ámlá, _bwaa,
  { {0x67290046, 0x2127001d, 0x2901006c, 0x00000000}},  //   _miej, _tinh_, koha_,
  { {0x62990300, 0x6f1d00d9, 0x6d4d07a5, 0x00000000}},  //   _hawo, amsc, _dwaa,
  { {0x629907a3, 0xa2a40061, 0x316d009d, 0x00000000}},  //   _kawo, काच्, luez_,
  { {0x78bc16df, 0x629b010a, 0x61e40027, 0x00000000}},  //   _sorv, nduo, _žili,
  { {0xdca6005c, 0x7ae40cc9, 0x78bc00b0, 0x00000000}},  // [f2a0] _запи, riit, _porv,
  { {0x62993f0b, 0x7ae40ac2, 0xf99f000a, 0x00000000}},  //   _lawo, siit, _iyèl_,
  { {0x6abd0253, 0x6d4d00b5, 0xb80a0025, 0x00000000}},  //   _fosf, _zwaa, أيام_,
  { {0x20c9002a, 0xd041005f, 0x442c0283, 0x00000000}},  //   _súil_, rhlə, _sgd_,
  { {0xe5a303f3, 0x78bc0190, 0x442c0059, 0x00000000}},  //   лици, _torv, _pgd_,
  { {0xf99f01aa, 0x6609224b, 0x00000000, 0x00000000}},  //   _myèl_, _dyek,   ,
  { {0x75280089, 0x62990173, 0x9294007e, 0x00000000}},  //   _vidz, _bawo, вайц,
  { {0x75280046, 0xd2500025, 0x6299005b, 0x00000000}},  //   _widz, جنة_, _cawo,
  { {0xc486003b, 0x316d0211, 0x62990173, 0x00000000}},  //   _плак, guez_, _dawo,
  { {0xbcfb3590, 0x6e2d0197, 0x442c0022, 0x00000000}},  //   trém, _sgab, _ugd_,
  { {0x6d4d0007, 0x29180066, 0xa30b009e, 0x00000000}},  //   _swaa, _mhra_, _کرلے_,
  { {0xbcfb009d, 0xf99f000a, 0x316d009d, 0x00000000}},  //   rrém, _byèl_, buez_,
  { {0x2918002b, 0x98a301aa, 0x6f1d01a2, 0x00000000}},  //   _ohra_, _sijč_, rmsc,
  { {0x62990046, 0x628000c7, 0x2d4d04eb, 0x00000000}},  //   _zawo, lfmo, rže_,
  { {0x2f120010, 0x6d4d00e0, 0x6abd0145, 0x00000000}},  //   sága_, _wwaa, _posf,
  { {0x6d4d3f0c, 0xf99f0173, 0x00000000, 0x00000000}},  //   _twaa, _fyèl_,   ,
  { {0x68e5014a, 0x6d4d1519, 0x00000000, 0x00000000}},  // [f2b0] tihd, _uwaa,   ,
  { {0x629b0006, 0x67290a67, 0x00000000, 0x00000000}},  //   zduo, _siej,   ,
  { {0xec3600b6, 0x69c1006b, 0x66090093, 0x00000000}},  //   _באתר_, _əley, _syek,
  { {0xb8c8006e, 0x291800e0, 0x67290023, 0x00000000}},  //   _खो_, _ehra_, _qiej,
  { {0x67290211, 0x9f5c021e, 0xd00600a1, 0x00000000}},  //   _viej, _hyvä_, _چل_,
  { {0x62992492, 0x67290036, 0x00000000, 0x00000000}},  //   _sawo, _wiej,   ,
  { {0x629901aa, 0xef1f0180, 0xf8f4007e, 0x00000000}},  //   _pawo, kmü_, _спрэ,
  { {0xddcd002b, 0x316d3f0d, 0x00000000, 0x00000000}},  //   _bbaż, tuez_,   ,
  { {0x629b010a, 0x36d4007c, 0x00000000, 0x00000000}},  //   rduo, _сотр,   ,
  { {0x62990022, 0xf99f000a, 0x00000000, 0x00000000}},  //   _wawo, _nyèm_,   ,
  { {0xf99f0263, 0x62990487, 0x2d8900c4, 0x00000000}},  //   _syèl_, _tawo, _apae_,
  { {0xed5a2c00, 0xdee60088, 0xfe720025, 0x00000000}},  //   мом_, томи, جدد_,
  { {0x316d028c, 0xf1d9013d, 0x00000000, 0x00000000}},  //   quez_, _बेचन,   ,
  { {0x71d60097, 0x00000000, 0x00000000, 0x00000000}},  //   _בונד_,   ,   ,
  { {0xe7e1001c, 0xfd500082, 0x7afb00ca, 0x00000000}},  //   _गेला_, nnhạ, čutn,
  { {0xc332019b, 0x00000000, 0x00000000, 0x00000000}},  //   שון_,   ,   ,
  { {0x3b0700e3, 0xeabf0011, 0xbcfb00d4, 0x00000000}},  // [f2c0] тето_, _giùm_, gués,
  { {0x07a601e1, 0x00000000, 0x00000000, 0x00000000}},  //   казн,   ,   ,
  { {0xc00f0082, 0x00000000, 0x00000000, 0x00000000}},  //   _đuối_,   ,   ,
  { {0xdd1101dc, 0x2bf7009b, 0x7b13013f, 0x00000000}},  //   mýšl, _ימין_, lçun,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf8bf0011, 0xbcfb00fa, 0x00000000, 0x00000000}},  //   _quét_, quét,   ,
  { {0x289b0049, 0x00000000, 0x00000000, 0x00000000}},  //   _קילא,   ,   ,
  { {0xb865026c, 0xf1a601ee, 0x00000000, 0x00000000}},  //   _لاہو, врон,   ,
  { {0xe5260264, 0x62800270, 0x00000000, 0x00000000}},  //   _адап, rfmo,   ,
  { {0x30a62e54, 0x2a620022, 0x00000000, 0x00000000}},  //   трив, _ldkb_,   ,
  { {0x64580006, 0x443e0190, 0x0857009b, 0x00000000}},  //   mavi, _ift_, כבים_,
  { {0x6458010a, 0xe246006d, 0xdce60089, 0x00000000}},  //   lavi, _شخصي, vukā,
  { {0x443e0047, 0x20020046, 0xbcfb0010, 0x00000000}},  //   _kft_, łki_, nség,
  { {0x64580006, 0x31570049, 0x752f00f6, 0x00000000}},  //   navi, _יידן_, _ècze,
  { {0x6d460169, 0x443e0232, 0x00000000, 0x00000000}},  //   apka, _mft_,   ,
  { {0x64580388, 0x443e3f0e, 0x13e50044, 0x00000000}},  //   havi, _lft_, _পুড়,
  { {0x5a340057, 0x443e3f0f, 0x29fa0082, 0x00000000}},  // [f2d0] рнут, _oft_, ỏan_,
  { {0x645804a9, 0x2b410082, 0x06ca0044, 0x00000000}},  //   javi, _tthc_, লোমি,
  { {0x64581a9d, 0x05db013d, 0x00000000, 0x00000000}},  //   davi, _मेजब,   ,
  { {0x443e2756, 0x46150014, 0xbcfb3be0, 0x00000000}},  //   _aft_, هوار, dréi,
  { {0x3cf80167, 0x6d5d00b0, 0xbcfb0010, 0x00000000}},  //   _سعید_, nssa, gség,
  { {0xb97a00b6, 0xf77304e1, 0x64580006, 0x00000000}},  //   _אנשי, _پاس_, gavi,
  { {0x443e3f10, 0x1cbc0049, 0x00000000, 0x00000000}},  //   _dft_, ומגע,   ,
  { {0x81de0055, 0x443e3f11, 0xc6a4004d, 0x00000000}},  //   _দুই_, _eft_, _круи,
  { {0x35f5007e, 0x6458016e, 0xbcfb009d, 0x00000000}},  //   _спар, bavi, préh,
  { {0x2ecc0164, 0x409500e3, 0x443e00d9, 0x00000000}},  //   ास्त, урит, _gft_,
  { {0xd2510054, 0xceea003b, 0x6d5d00b0, 0x00000000}},  //   _هنا_, едне_, essa,
  { {0xc33200b6, 0x656b001a, 0x623500ed, 0x00000000}},  //   _הוא_, orgh, _седу,
  { {0x0165003b, 0xa069005e, 0x6d5d0190, 0x00000000}},  //   _скло, _зала_, gssa,
  { {0x515a009b, 0x7659005b, 0xa3ca013d, 0x00000000}},  //   _טכנו, hawy, रैक_,
  { {0xbcfb0047, 0xbea60888, 0x6b630088, 0x00000000}},  //   zség, _байк, йкра,
  { {0x64580c47, 0xd00e0379, 0x6d463f12, 0x00000000}},  //   zavi, _علي_, ppka,
  { {0x200b0036, 0x317f002d, 0xa967005e, 0x00000000}},  // [f2e0] ęciu_, ntuz_, лита_,
  { {0x317f002d, 0x7b13006b, 0xa90a0379, 0x00000000}},  //   ituz_, lçul, ريال_,
  { {0x64580006, 0x2f190047, 0x3f510089, 0x00000000}},  //   vavi, sége_, nšu_,
  { {0xbcfb3f13, 0x7b13006b, 0x64580258, 0x00000000}},  //   tség, nçul, wavi,
  { {0xbddb009d, 0x00000000, 0x00000000, 0x00000000}},  //   ccèd,   ,   ,
  { {0x3f5118c5, 0xbcfb2c3e, 0x00000000, 0x00000000}},  //   kšu_, tréi,   ,
  { {0xbcfb0047, 0xa3e4013d, 0x929d0036, 0x00000000}},  //   sség, _पेश_, woła,
  { {0x7e640d16, 0x645826f2, 0x443e00d9, 0x00000000}},  //   _ndip, savi, _wft_,
  { {0x64581322, 0x3f51001e, 0xe5a301ee, 0x00000000}},  //   pavi, ešu_, _лити,
  { {0x7e640093, 0xe97b007b, 0x6458006b, 0x00000000}},  //   _adip, עניש, qavi,
  { {0x3f51001e, 0x33f6007c, 0x22860887, 0x00000000}},  //   gšu_, _счас, _булг,
  { {0x6d5d1d30, 0xbcfb0068, 0x00000000, 0x00000000}},  //   tssa, isée,   ,
  { {0x6d5d1684, 0xdced0066, 0x00000000, 0x00000000}},  //   ussa, _jsaħ,   ,
  { {0x67220850, 0x940c006b, 0x6d5d05e0, 0x00000000}},  //   hmoj, _sadə_, rssa,
  { {0xd5a4009c, 0xcb1b00ed, 0x6d5d12e0, 0x00000000}},  //   _کہ_, еќа_, sssa,
  { {0x63a80107, 0x6d5d02e1, 0x6b9b0036, 0x00000000}},  //   _mrdn, pssa, ługo,
  { {0x0855041f, 0xa8550aa2, 0x6722012d, 0x00000000}},  // [f2f0] иваю, икач, dmoj,
  { {0xd7fb007e, 0xe6c00091, 0xa3d4006e, 0x00000000}},  //   нуе_, _čišć, हना_,
  { {0x96351deb, 0x317f0032, 0xec1502fd, 0x00000000}},  //   анец, ztuz_, _خودد,
  { {0xbcfb00f4, 0xe70b03ec, 0xba3b009d, 0x00000000}},  //   sséd, رتان_, _qaïd,
  { {0x286b300e, 0x63a8006b, 0x4a5a009b, 0x00000000}},  //   _прво_, _ardn, _בדרו,
  { {0x64a5008b, 0x939501d8, 0x67221b1b, 0x00000000}},  //   рака, لجبا, amoj,
  { {0xe299008b, 0x39490089, 0x32d500ed, 0x00000000}},  //   вай_, lpas_, ицис,
  { {0x05150055, 0xd05a005f, 0x394900b0, 0x00000000}},  //   াদের_, mitə, opas_,
  { {0x50b5007e, 0x394901d6, 0x00000000, 0x00000000}},  //   асну, npas_,   ,
  { {0x317f002d, 0x394900c4, 0x00000000, 0x00000000}},  //   rtuz_, ipas_,   ,
  { {0x6d440027, 0x63a80107, 0x20021e00, 0x00000000}},  //   _stia, _grdn, şkin_,
  { {0x3f510089, 0x733a0049, 0x00000000, 0x00000000}},  //   ršu_, _סענס,   ,
  { {0x20d501fb, 0xe0ce005e, 0x224d04d4, 0x00000000}},  //   _війс, _дв_, mbek_,
  { {0xc5f200b6, 0xa06900ed, 0x224d0646, 0x00000000}},  //   קדם_, _рака_, lbek_,
  { {0xfbc30364, 0x6b8300f8, 0xca56003b, 0x00000000}},  //   обро, _ängl, итањ,
  { {0x4a460139, 0x38c802fd, 0x7b13013f, 0x00000000}},  //   рнав, گاری_, qçul,
  { {0x60c31338, 0x61ed01ae, 0x6f2400a1, 0x00000000}},  // [f300] _konm, _žalj, _پڑھن,
  { {0x38c806c6, 0xebe600ed, 0x61e6000c, 0x00000000}},  //   داری_, _вооп, úkli,
  { {0x3949008e, 0x81cb0044, 0x2d8200ea, 0x00000000}},  //   apas_, রছি_, ltke_,
  { {0x4aca02f4, 0x64411408, 0xe5c601fb, 0x00000000}},  //   _रविव, _afli, исло,
  { {0x67223f14, 0xbcfb00f4, 0xa5da0025, 0x00000000}},  //   rmoj, ssée, خبار_,
  { {0x60c301aa, 0x3ea000f4, 0x316d0285, 0x00000000}},  //   _nonm, _lait_, drez_,
  { {0xbcfb009d, 0x316d3f15, 0x00000000, 0x00000000}},  //   prév, erez_,   ,
  { {0x7af600b0, 0x316d009d, 0xdb1c0039, 0x00000000}},  //   nnyt, frez_, byrå,
  { {0x64410016, 0x60c300d4, 0xbcfb009d, 0x00000000}},  //   _ffli, _bonm, nséc,
  { {0x60c31526, 0x26c4049a, 0xf48400d3, 0x00000000}},  //   _conm, _homo_, _داری,
  { {0x8369026c, 0x3ea03e3d, 0x7d070065, 0x00000000}},  //   _مصنف_, _bait_, vojs,
  { {0x7afb0059, 0x91b70014, 0x3ea00048, 0x00000000}},  //   čutk, _چطور_, _cait_,
  { {0x60c30066, 0x25a60112, 0x316d0035, 0x00000000}},  //   _fonm, nvol_, crez_,
  { {0x7d02002a, 0x26c415e3, 0x9fe60014, 0x00000000}},  //   _íosl, _lomo_, _پسته,
  { {0x3ea0028c, 0x7d070107, 0xd0f50309, 0x00000000}},  //   _fait_, rojs, ीकरण_,
  { {0x5a350200, 0x9f040025, 0xdee4003b, 0x00000000}},  //   снат, _وووو, _моји,
  { {0x7afa009f, 0xbcfb000c, 0x7b130095, 0x00000000}},  // [f310] étta, frét, lçuk,
  { {0x39490016, 0x3ea0002d, 0x58bb0379, 0x00000000}},  //   rpas_, _zait_, خارج_,
  { {0x39490007, 0x26c401d9, 0xb8080025, 0x00000000}},  //   spas_, _bomo_, ليكم_,
  { {0x26c423ea, 0x394902e1, 0xd05a006b, 0x00000000}},  //   _como_, ppas_, ritə,
  { {0xe5a5013b, 0xd05a005f, 0x26c40020, 0x00000000}},  //   сили, sitə, _domo_,
  { {0x316d00f4, 0xbcfb00f4, 0xf487060e, 0x00000000}},  //   vrez_, crét, рудн,
  { {0x6f0d0521, 0x60da0045, 0x00000000, 0x00000000}},  //   _okac, dhtm,   ,
  { {0x7aed0462, 0x23690e3b, 0x1bf80104, 0x00000000}},  //   niat, čaj_, יצור_,
  { {0x200202b9, 0x69cd00f6, 0x60c30c8f, 0x00000000}},  //   şkil_, nyae, _ponm,
  { {0x147704e8, 0x316d1a2e, 0x3ea000f4, 0x00000000}},  //   _خارج, rrez_, _sait_,
  { {0x85040b03, 0xbea60131, 0x3ea00058, 0x00000000}},  //   _بولن, банк, _pait_,
  { {0x661b00c4, 0x316d0036, 0x00000000, 0x00000000}},  //   _kzuk, prez_,   ,
  { {0x7d1e0061, 0x216901bd, 0x60c32a9c, 0x00000000}},  //   _phps, _сили_, _tonm,
  { {0x229300a1, 0x3ea000ab, 0x60da05c6, 0x00000000}},  //   _دلچس, _wait_, chtm,
  { {0x7aed060c, 0x2d820c8a, 0x3ea00068, 0x00000000}},  //   fiat, stke_, _tait_,
  { {0x7aed0390, 0x7f3a007b, 0x1ee800a2, 0x00000000}},  //   giat, _געקו, _خوبی_,
  { {0x5d860025, 0x26c40c35, 0x2ca10288, 0x00000000}},  // [f320] _الخل, _romo_, _fahd_,
  { {0x26c40020, 0x7af60039, 0xbcfb009d, 0x00000000}},  //   _somo_, snyt, rséc,
  { {0xbcfb000c, 0x661b0032, 0x26c40052, 0x00000000}},  //   rrét, _azuk, _pomo_,
  { {0x7aed20ce, 0x66760054, 0x25a63f16, 0x00000000}},  //   ciat, إدار, tvol_,
  { {0x7bce00e5, 0xb33c0066, 0x00000000, 0x00000000}},  //   lybu, _irħi,   ,
  { {0xc95301f8, 0x6d56018e, 0x25a622d8, 0x00000000}},  //   _ממש_, _mwya, rvol_,
  { {0x26c41d12, 0x25a600c7, 0xbcfb124d, 0x00000000}},  //   _tomo_, svol_, nséa,
  { {0x26c40198, 0x6aa40fad, 0x25a6040f, 0x00000000}},  //   _uomo_, ndif, pvol_,
  { {0xc05a0245, 0x79843242, 0xc5c60044, 0x00000000}},  //   лін_, ntiw, _শেরপ,
  { {0x7aed28ea, 0x7afb221d, 0x7642004a, 0x00000000}},  //   ziat, čuti, lcoy,
  { {0x60da3f17, 0xd041006b, 0x645a0e3f, 0x00000000}},  //   rhtm, nklə, _ieti,
  { {0xe3b1026c, 0x645a3f18, 0x60da0065, 0x00000000}},  //   _کرے_, _heti, shtm,
  { {0x7aed0198, 0x645a020c, 0xd24f0054, 0x00000000}},  //   viat, _keti, _أنه_,
  { {0x7aed0036, 0x645a0065, 0x6e360010, 0x00000000}},  //   wiat, _jeti, _egyb,
  { {0x645a011f, 0x75b40061, 0xd00f0025, 0x00000000}},  //   _meti, ंमुळ, _كله_,
  { {0x61ed04a5, 0x645a07ac, 0x6d56018e, 0x00000000}},  //   _žali, _leti, _fwya,
  { {0x1ef80025, 0x79840058, 0xfbd000a1, 0x00000000}},  // [f330] _دعوة_, gtiw, وتہ_,
  { {0x7aed3153, 0xa3ab013d, 0x00000000, 0x00000000}},  //   siat, खिम_,   ,
  { {0x661b0046, 0x7aed0c0e, 0x77990081, 0x00000000}},  //   _szuk, piat, ркер_,
  { {0xbcfb1184, 0x1b170044, 0x00000000, 0x00000000}},  //   prés, _দূরে_,   ,
  { {0x645a3f19, 0x356b00e3, 0x7984005b, 0x00000000}},  //   _beti, урен_, ctiw,
  { {0x645a0091, 0xf99f000a, 0xa3490069, 0x00000000}},  //   _ceti, _dyèt_, азка_,
  { {0x2f120047, 0x36d50545, 0x00000000, 0x00000000}},  //   sági_, _довр,   ,
  { {0x645a006c, 0xb1451f70, 0x00000000, 0x00000000}},  //   _eeti, онил,   ,
  { {0x645a001a, 0x00000000, 0x00000000, 0x00000000}},  //   _feti,   ,   ,
  { {0x645a011f, 0xa0690098, 0x1f65004c, 0x00000000}},  //   _geti, јана_, оком,
  { {0x69100004, 0xdbf20224, 0x7afd0087, 0x00000000}},  //   päev, _příp, _ojst,
  { {0x753b0020, 0xf99f0026, 0x82340014, 0x00000000}},  //   _kuuz, _osè_, _فرها,
  { {0x645a038c, 0x69cb0030, 0xfe7100a1, 0x00000000}},  //   _yeti, øgel, رگٹ_,
  { {0x753b24ce, 0x6b9e0068, 0x64432086, 0x00000000}},  //   _muuz, _pspg, ncni,
  { {0xea5a00ec, 0xda5a0751, 0xdea200a1, 0x00000000}},  //   ирај_, ираш_, _قیدی,
  { {0x25ad3f1a, 0x7bce0036, 0xbddb009d, 0x00000000}},  //   _orel_, rybu, rbèr,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [f340]   ,   ,   ,
  { {0x186a003b, 0x6aa40240, 0x79843f1b, 0x00000000}},  //   ражи_, sdif, rtiw,
  { {0x79840127, 0x645a16ac, 0xf99f0173, 0x00000000}},  //   stiw, _reti, _esè_,
  { {0x268a06ea, 0x645a0149, 0xd041006b, 0x00000000}},  //   شخصي_, _seti, rklə,
  { {0x645a028c, 0x65960025, 0xba480006, 0x00000000}},  //   _peti, تجار, grįž,
  { {0x53340088, 0x65620145, 0x779100a1, 0x00000000}},  //   пект, rsoh, بیہا,
  { {0x645a0065, 0xf4870123, 0x00000000, 0x00000000}},  //   _veti, تانی,   ,
  { {0xd1410036, 0x8bfc0044, 0x00000000, 0x00000000}},  //   knąć_, _ইরান_,   ,
  { {0x645a01a3, 0x673c0bac, 0x25ad0087, 0x00000000}},  //   _teti, _hurj, _grel_,
  { {0x673c006c, 0x2a601f40, 0x00000000, 0x00000000}},  //   _kurj, haib_,   ,
  { {0x320a0036, 0x66fc0059, 0x2d920173, 0x00000000}},  //   łby_, nčko, _apye_,
  { {0xb35700a1, 0x673c01ed, 0x00000000, 0x00000000}},  //   _بیٹا_, _murj,   ,
  { {0xc333009b, 0x673c0288, 0x00000000, 0x00000000}},  //   _חוף_, _lurj,   ,
  { {0xd12f008b, 0xe5710049, 0x316600ca, 0x00000000}},  //   _іх_, ײַך_, _ivoz_,
  { {0xfbe10044, 0x66fc0059, 0xac191344, 0x00000000}},  //   _মুজত, jčko, сову_,
  { {0x988500b9, 0x644c006b, 0xa3ab007d, 0x00000000}},  //   _vůči_, əniş, खित_,
  { {0x49750b87, 0x09751969, 0xb33c0066, 0x00000000}},  // [f350] ялас, ягаю, _irħu,
  { {0x673c1ed5, 0x7e7d0030, 0x37ab0d73, 0x00000000}},  //   _burj, lgsp, итен_,
  { {0xf99f01aa, 0x872b007e, 0x6d4f0026, 0x00000000}},  //   _pyès_, аўда_, lpca,
  { {0x41ca0309, 0x673c270f, 0x00000000, 0x00000000}},  //   िहास, _durj,   ,
  { {0x2aba009b, 0x00000000, 0x00000000, 0x00000000}},  //   _המרא,   ,   ,
  { {0x03a50072, 0x673c0066, 0xf99f0173, 0x00000000}},  //   зико, _furj, _fyèr_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc7b200b6, 0xd299007e, 0x3834013a, 0x00000000}},  //   _אבל_, сткі_, _інтр,
  { {0xc8ff0044, 0x225f0006, 0xf4870245, 0x00000000}},  //   ্গীত_, rauk_, _мужн,
  { {0x39590058, 0x3a390022, 0x225f19d2, 0x00000000}},  //   _mwss_, _lgsp_, sauk_,
  { {0xb5fd07ac, 0x9f58000c, 0xa4fa0049, 0x00000000}},  //   _odšk, ærð_, _פלעט,
  { {0xfaff048a, 0x61ed3804, 0xa3e4007d, 0x00000000}},  //   _një_, _žalu, _पेट_,
  { {0xf1a7005e, 0xbddb0115, 0xbcfb0249, 0x00000000}},  //   _френ, scèn, trép,
  { {0x6cd60054, 0x3861010f, 0xed1700a1, 0x00000000}},  //   أقسا, jahr_, ےہیں_,
  { {0x38610022, 0xd14100b4, 0x00000000, 0x00000000}},  //   dahr_, snąć_,   ,
  { {0x39463f1c, 0x00000000, 0x00000000, 0x00000000}},  //   знаг,   ,   ,
  { {0x2a603f1d, 0x3861010f, 0xcf250439, 0x00000000}},  // [f360] raib_, fahr_, _تروي,
  { {0xe9d70175, 0x673c03b6, 0x66fc012d, 0x00000000}},  //   чку_, _purj, tčko,
  { {0x98aa001a, 0x394b04a5, 0x00000000, 0x00000000}},  //   _aibă_, _etcs_,   ,
  { {0xfaff008d, 0x66fc00ca, 0x7d0e33cd, 0x00000000}},  //   _gjë_, rčko, lobs,
  { {0xa3e4013d, 0x3940002b, 0x00000000, 0x00000000}},  //   _पेज_, qqis_,   ,
  { {0x1394073b, 0x00000000, 0x00000000, 0x00000000}},  //   дикю,   ,   ,
  { {0x398600fa, 0xd467003b, 0x00000000, 0x00000000}},  //   lôs_, чије_,   ,
  { {0xe3af004b, 0x225d0022, 0x46a3007e, 0x00000000}},  //   ارو_, _cewk_, _пасв,
  { {0xe1660025, 0x54360070, 0x6aa60023, 0x00000000}},  //   أدبي, _فرار, _makf,
  { {0x03a6013b, 0x54671e6a, 0x95eb00a1, 0x00000000}},  //   _низо, _наум_, _طبقہ_,
  { {0xb4d80309, 0x3f63007c, 0xf1f70014, 0x00000000}},  //   ासी_, нтяб, قعیت_,
  { {0xe8b9007d, 0x333b009b, 0x77f70104, 0x00000000}},  //   _उच्च, _התאמ, למיד_,
  { {0x628200bb, 0x7e7d00f8, 0x316600ca, 0x00000000}},  //   _icoo, rgsp, _uvoz_,
  { {0xdcef001a, 0x00000000, 0x00000000, 0x00000000}},  //   ducă,   ,   ,
  { {0x6aa605ad, 0x00000000, 0x00000000, 0x00000000}},  //   _bakf,   ,   ,
  { {0x60ca0007, 0x68ee0129, 0x0f7b009b, 0x00000000}},  //   _hofm, _ambd, _האהב,
  { {0x6f0f012d, 0xaf3403ec, 0x00000000, 0x00000000}},  // [f370] mocc, _ثروت,   ,
  { {0x6d4d0013, 0x7d0e0056, 0x6f0f0207, 0x00000000}},  //   _itaa, cobs, locc,
  { {0x6aa60022, 0xf79901b2, 0xbcfb0068, 0x00000000}},  //   _fakf, تناب_, nsém,
  { {0x6f0f0207, 0xfaff0065, 0x398600c4, 0x00000000}},  //   nocc, _ujë_, bôs_,
  { {0x1a680123, 0x64a5007e, 0x3e880010, 0x00000000}},  //   _ریلی_, дала, lító_,
  { {0x6d4d0020, 0x7e6d00d2, 0x62820045, 0x00000000}},  //   _mtaa, _ldap, _acoo,
  { {0xf8b200b3, 0x628201f3, 0x00000000, 0x00000000}},  //   _בשם_, _bcoo,   ,
  { {0x660d006c, 0x78a73f1e, 0x62820032, 0x00000000}},  //   üaks, _hajv, _ccoo,
  { {0x6f0f0026, 0xc69200a3, 0x30750407, 0x00000000}},  //   docc, _באן_, мунс,
  { {0xe0d10025, 0xbddb009d, 0x628200fa, 0x00000000}},  //   ئزة_, rcèl, _ecoo,
  { {0x5f060088, 0x6d4d00e7, 0x00000000, 0x00000000}},  //   дзна, _ataa,   ,
  { {0x03780123, 0x6f0f0026, 0x00000000, 0x00000000}},  //   _رحمت_, gocc,   ,
  { {0xc33200a0, 0x7d0e0203, 0x00000000, 0x00000000}},  //   _סוד_, tobs,   ,
  { {0xee37007e, 0xddc40035, 0x00000000, 0x00000000}},  //   ьня_, _adiţ,   ,
  { {0x6f0f0197, 0x7d0e368b, 0x6d4d0288, 0x00000000}},  //   bocc, robs, _etaa,
  { {0x629b0016, 0x7b3c0091, 0x6f0f3f1f, 0x00000000}},  //   neuo, _očuv, cocc,
  { {0x6aa6014a, 0x00000000, 0x00000000, 0x00000000}},  // [f380] _vakf,   ,   ,
  { {0xddc4001a, 0x6aa63169, 0x629b0016, 0x00000000}},  //   _ediţ, _wakf, heuo,
  { {0x78a70087, 0x6aa600f8, 0x00000000, 0x00000000}},  //   _dajv, _takf,   ,
  { {0xe61a102a, 0x398600c4, 0x00000000, 0x00000000}},  //   оде_, pôs_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6569012d, 0xa5330088, 0x00000000, 0x00000000}},  //   _dveh, вніч,   ,
  { {0x779102fd, 0x00000000, 0x00000000, 0x00000000}},  //   _میلا,   ,   ,
  { {0x416a003b, 0x291a004a, 0x00000000, 0x00000000}},  //   ојом_, llpa_,   ,
  { {0xcb13009b, 0x05ba0025, 0xc486003b, 0x00000000}},  //   כלה_, _بدأت_, _олак,
  { {0xba3b00f6, 0x7b130023, 0xa1270025, 0x00000000}},  //   _raïm, nçur, وكيل_,
  { {0x6d4d049b, 0x6f0f0197, 0xdce40161, 0x00000000}},  //   _staa, tocc, _cvič,
  { {0x26c608d9, 0x25a43f20, 0x00000000, 0x00000000}},  //   njoo_, _ksml_,   ,
  { {0x6f0f0207, 0x0cab114a, 0xbcfb009d, 0x00000000}},  //   rocc, отви_, ssém,
  { {0x6f0f0197, 0xa19302ea, 0x00000000, 0x00000000}},  //   socc, _рашч,   ,
  { {0x6d34007c, 0x6f0f17f8, 0x1fa3007e, 0x00000000}},  //   терф, pocc, _арыг,
  { {0x62800a0b, 0x3e880010, 0x00000000, 0x00000000}},  //   ngmo, rító_,   ,
  { {0xeabf0011, 0x3e880010, 0x6d4d0020, 0x00000000}},  // [f390] _chùa_, sító_, _utaa,
  { {0x3ea901bb, 0xad270025, 0xb5fd00d0, 0x00000000}},  //   _haat_, _تربو, _ješe,
  { {0x8c4400ed, 0xb5fd0e00, 0x656900d2, 0x00000000}},  //   _шеќе, _meše, _sveh,
  { {0xb5fd04c8, 0x33260082, 0x501b009b, 0x00000000}},  //   _leše, _nhox_, חובו,
  { {0x3ea93f21, 0x672b0635, 0x00000000, 0x00000000}},  //   _maat_, rmgj,   ,
  { {0x3ea90100, 0xa3ab0316, 0x7d020051, 0x00000000}},  //   _laat_, खिल_, _íost,
  { {0x29030066, 0x00000000, 0x00000000, 0x00000000}},  //   _ijja_,   ,   ,
  { {0x3ea90173, 0x3326013f, 0x00000000, 0x00000000}},  //   _naat_, _chox_,   ,
  { {0x7afa009f, 0x629b0016, 0xddc43f22, 0x00000000}},  //   étti, reuo, _odiš,
  { {0x629b018e, 0x7ae101d6, 0x00000000, 0x00000000}},  //   seuo, ëltj,   ,
  { {0x325501fb, 0x81e70044, 0x3ea90116, 0x00000000}},  //   _звер, _মুখ_, _baat_,
  { {0x3ea900d9, 0x7ce201d6, 0xe0bf0044, 0x00000000}},  //   _caat_, _môre, ইসেন,
  { {0x5d67007c, 0xd0d5022a, 0x9dba007e, 0x00000000}},  //   ниям_, _подъ, чыну_,
  { {0x332d008e, 0x00000000, 0x00000000, 0x00000000}},  //   lmex_,   ,   ,
  { {0x69cb04ce, 0xc4d200a0, 0x00000000, 0x00000000}},  //   ägen, נגל_,   ,
  { {0x3ea902ae, 0xfaa3007e, 0x2fd80737, 0x00000000}},  //   _gaat_, ласо, ørge_,
  { {0xc332019b, 0x8c46017f, 0xa926003b, 0x00000000}},  // [f3a0] רון_, _пепе, едал,
  { {0x7d5701ce, 0x7e662119, 0x00000000, 0x00000000}},  //   _רייד_, lakp,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2903002b, 0x7e660058, 0x00000000, 0x00000000}},  //   _ejja_, nakp,   ,
  { {0x6834012d, 0x7ae4096a, 0x00000000, 0x00000000}},  //   dždž, mhit,   ,
  { {0x33260066, 0xdb05010f, 0x7ae413e4, 0x00000000}},  //   _shox_, _erhä, lhit,
  { {0x969601f9, 0xb5fd0229, 0x2f190010, 0x00000000}},  //   _праш, _reše, ségi_,
  { {0x6b830039, 0x31c602e9, 0x00000000, 0x00000000}},  //   _ånge, есов,   ,
  { {0x7e660fef, 0x343a004b, 0x3ea901c3, 0x00000000}},  //   dakp, _فساد_, _raat_,
  { {0x3ea90390, 0x63b70129, 0x2ee0003f, 0x00000000}},  //   _saat_, çanè, _alif_,
  { {0x2018000c, 0xa2c001f5, 0x443e0145, 0x00000000}},  //   æri_, वाद्, _igt_,
  { {0x753a19f5, 0x7ae400ca, 0x7e6600e0, 0x00000000}},  //   _hitz, jhit, gakp,
  { {0xc2e90025, 0xed58007e, 0x7ae40023, 0x00000000}},  //   _تعلم_, ноў_, dhit,
  { {0x2ee0014a, 0x6e24012d, 0x7ae4006c, 0x00000000}},  //   _elif_, _dzib, ehit,
  { {0x6fe6009d, 0x753a01a2, 0x3ea9003f, 0x00000000}},  //   _décé, _mitz, _taat_,
  { {0x3da70099, 0x753a002d, 0x7cd8005a, 0x00000000}},  //   _зроб, _litz, _ağrı,
  { {0x5a3500e3, 0xfc3000a1, 0x443e00f6, 0x00000000}},  // [f3b0] тнат, لحہ_, _ogt_,
  { {0x6f1d001f, 0x394f001e, 0xf80702d3, 0x00000000}},  //   llsc, īgs_, нчен,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x443e0007, 0x753a002d, 0xf65303ab, 0x00000000}},  //   _agt_, _aitz, ائض_,
  { {0x443e023a, 0x753a0c0e, 0xe5a5007c, 0x00000000}},  //   _bgt_, _bitz, тили,
  { {0x443e153c, 0xdb1c000c, 0x6f1d010f, 0x00000000}},  //   _cgt_, lyrð, hlsc,
  { {0x753a022b, 0x443e004a, 0x798d09d0, 0x00000000}},  //   _ditz, _dgt_, ltaw,
  { {0x6aad020c, 0x443e00bb, 0x753a0032, 0x00000000}},  //   ndaf, _egt_, _eitz,
  { {0x798d2d2d, 0x26dc0089, 0x30790025, 0x00000000}},  //   ntaw, īvot_, وحدة_,
  { {0x76590016, 0x7ae401ee, 0x2901002b, 0x00000000}},  //   lbwy, zhit, nnha_,
  { {0x22950025, 0x7e660058, 0x290100c4, 0x00000000}},  //   _للاس, takp, inha_,
  { {0x92eb035b, 0x753a002d, 0x661b0022, 0x00000000}},  //   _عراق_, _zitz, _kyuk,
  { {0x09d60044, 0x6aad00ea, 0x69c4002b, 0x00000000}},  //   _সেনা, ddaf, xxie,
  { {0x7ae40009, 0x66090066, 0x623400e2, 0x00000000}},  //   whit, _mxek, _сечу,
  { {0x5f06005e, 0x61e91b34, 0x29130035, 0x00000000}},  //   _изка, lzel, doxa_,
  { {0x69c4002d, 0x6f040093, 0x673b007f, 0x00000000}},  //   txie, _ujic, _niuj,
  { {0x61e9001f, 0xf2d2007b, 0x7ae4023a, 0x00000000}},  // [f3c0] nzel, בען_, rhit,
  { {0x7d7b019b, 0x7ae40020, 0x4d7b00a3, 0x00000000}},  //   _קניו, shit, _קריע,
  { {0x7ae41a90, 0x753a0302, 0xcc7700b6, 0x00000000}},  //   phit, _ritz, _בעיה_,
  { {0x753a010f, 0x443e01a3, 0xcf920049, 0x00000000}},  //   _sitz, _sgt_, שטא_,
  { {0xa2c0062e, 0x443e3f23, 0x7afa000c, 0x00000000}},  //   वास्, _pgt_, éttu,
  { {0xd90d026c, 0x7e641744, 0x61e921ca, 0x00000000}},  //   _ٹیم_, _leip, dzel,
  { {0x66092c9f, 0x443e0082, 0x61e900bb, 0x00000000}},  //   _exek, _vgt_, ezel,
  { {0xbebb0065, 0x753a010f, 0x7e642e86, 0x00000000}},  //   hmër, _witz, _neip,
  { {0x7f430219, 0x443e16d4, 0x7ae3001a, 0x00000000}},  //   _aunq, _tgt_, _înte,
  { {0x6729002b, 0x443e0129, 0x753a00b5, 0x00000000}},  //   _zhej, _ugt_, _uitz,
  { {0x03a301fb, 0x287b0104, 0x60da00d9, 0x00000000}},  //   _вихо, ונימ, rktm,
  { {0x7f430207, 0x7336039d, 0xeae40044, 0x00000000}},  //   _dunq, _شرائ, নচুম,
  { {0x6d440181, 0x61e90036, 0x91e32d6f, 0x00000000}},  //   _cuia, czel, _коце,
  { {0x09d60044, 0x6fb40355, 0x40a800a6, 0x00000000}},  //   _সেভা, _ممتا, _سختی_,
  { {0xb5fd1701, 0xac180088, 0xa3ab013d, 0x00000000}},  //   _meša, вору_, खिए_,
  { {0x798d0066, 0x38630030, 0x29180f99, 0x00000000}},  //   ttaw, _sejr_, _akra_,
  { {0x6d4416b2, 0x6aad0169, 0xd5a400a1, 0x00000000}},  // [f3d0] _guia, rdaf, _بہ_,
  { {0x798d3f24, 0x67290065, 0xef1f005d, 0x00000000}},  //   rtaw, _shej, llü_,
  { {0x798d0046, 0x0675060e, 0x61e90f5d, 0x00000000}},  //   staw, гуля, zzel,
  { {0xcf93007b, 0xf7700084, 0xe7580088, 0x00000000}},  //   יטע_, زام_, тиці_,
  { {0x442501aa, 0xa4d50088, 0x83fc0521, 0x00000000}},  //   _szl_, лоді, _ređa,
  { {0xd0060054, 0x05740025, 0x61e90059, 0x00000000}},  //   _هل_, شاهد, vzel,
  { {0xb5fd05fa, 0xf4840098, 0x672932fc, 0x00000000}},  //   _deša, ручн, _thej,
  { {0xd18501e0, 0x61e900b5, 0x63a80045, 0x00000000}},  //   глий, tzel, _dsdn,
  { {0x3949002b, 0x7e6400b0, 0x61e904eb, 0x00000000}},  //   nqas_, _reip, uzel,
  { {0x61e91594, 0x9fc900e2, 0x7e640943, 0x00000000}},  //   rzel, егоа_, _seip,
  { {0x61e90010, 0x7e64006c, 0xba3b147f, 0x00000000}},  //   szel, _peip, _taïw,
  { {0x61e90010, 0x6d44010e, 0x00000000, 0x00000000}},  //   pzel, _puia,   ,
  { {0xeabf0011, 0xcdf60a78, 0xa2c0007d, 0x00000000}},  //   _chùm_, учны, वार्,
  { {0x71720014, 0x9d430131, 0x4df50131, 0x00000000}},  //   _اهوا, серд, ряют,
  { {0x3bd50057, 0x75ea0047, 0x6fb20014, 0x00000000}},  //   аютс, _közé, _هموا,
  { {0xe7f90164, 0xef1f006b, 0x224d02bb, 0x00000000}},  //   ्पना_, clü_, ncek_,
  { {0xf2d2007b, 0x316d0601, 0x6441174b, 0x00000000}},  // [f3e0] זען_, nsez_, _ogli,
  { {0x64411a0b, 0xbd5b009b, 0xe8f701ee, 0x00000000}},  //   _ngli, _רכיש, глу_,
  { {0xb5fd01a8, 0x2d820091, 0x69cb0030, 0x00000000}},  //   _reša, luke_, øger,
  { {0x76a90088, 0x64410197, 0x5b7b0049, 0x00000000}},  //   ктів_, _agli, _ארטא,
  { {0x2d821ee4, 0xb5fd01ee, 0x64410045, 0x00000000}},  //   nuke_, _peša, _bgli,
  { {0x291e0010, 0x644100f6, 0xd76600a1, 0x00000000}},  //   _óta_, _cgli, _مارٹ,
  { {0xb5fd01ee, 0xd377007e, 0xa2c001f5, 0x00000000}},  //   _veša, гчы_, वाल्,
  { {0x3ea22995, 0x6441009d, 0xa3b700a1, 0x00000000}},  //   jekt_, _egli, ااور_,
  { {0x3ea200bb, 0x638a00c4, 0x2d822066, 0x00000000}},  //   dekt_, _bênç, juke_,
  { {0xc7af026c, 0xa0a601ee, 0x00000000, 0x00000000}},  //   _بڑے_, ушил,   ,
  { {0x3ea206d3, 0xba3b023f, 0xc917009b, 0x00000000}},  //   fekt_, _haït, רחית_,
  { {0x78ae0089, 0x753d0010, 0xc207009e, 0x00000000}},  //   _labv, _észr, ئقین_,
  { {0xef1f011f, 0x2d820032, 0xb5fd00ca, 0x00000000}},  //   rlü_, guke_, _lešn,
  { {0x1fa6003b, 0x3ead00b9, 0xd12f0025, 0x00000000}},  //   _бриг, žet_, _فمن_,
  { {0xe814001c, 0xac192898, 0x00000000, 0x00000000}},  //   _तुला_, тову_,   ,
  { {0x4a553f25, 0x2d820091, 0xb5fd0087, 0x00000000}},  //   ркас, buke_, _odšp,
  { {0xe9750025, 0x00000000, 0x00000000, 0x00000000}},  // [f3f0] شهاد,   ,   ,
  { {0x940a006b, 0x00000000, 0x00000000, 0x00000000}},  //   şmən_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x8aa7007e, 0x35b502dc, 0x644100f6, 0x00000000}},  //   _срод, ибер, _sgli,
  { {0x298b0d99, 0x7cf4006b, 0x394901d5, 0x00000000}},  //   _ясно_, _sürə, qqas_,
  { {0x81d30044, 0x2ee20309, 0x00000000, 0x00000000}},  //   _হইল_, _पत्त,   ,
  { {0x2d82118e, 0x3ea2013f, 0x00000000, 0x00000000}},  //   zuke_, yekt_,   ,
  { {0xc2450088, 0x316d0032, 0x41b501b7, 0x00000000}},  //   шник, tsez_, لمعر,
  { {0xa487057d, 0x6aaf00d9, 0x398f3f26, 0x00000000}},  //   _مجان, _macf, nüs_,
  { {0xd12e031d, 0xe0d6007c, 0x3ea200bb, 0x00000000}},  //   ومي_, ивы_, wekt_,
  { {0x316d00f4, 0x037800a1, 0xd0090999, 0x00000000}},  //   ssez_, _محنت_, тене_,
  { {0x6126000c, 0x2d82006c, 0x63bc000c, 0x00000000}},  //   rðla, tuke_, _árna,
  { {0x3ea2127c, 0xb5fd0521, 0xa1580245, 0x00000000}},  //   rekt_, _mešo, _бачу_,
  { {0x2d821435, 0x3ea20056, 0xed5700e2, 0x00000000}},  //   ruke_, sekt_, рор_,
  { {0x3ea23f27, 0xfaf600c2, 0x4c6700e2, 0x00000000}},  //   pekt_, ачаю, рисн_,
  { {0x80da0044, 0x2d821dce, 0x00000000, 0x00000000}},  //   যোদ্, puke_,   ,

  { {0xe9d701f9, 0x78660216, 0x44320011, 0x00000000}},  // [f400] акт_, иказ, ̀y_,
  { {0xab66007e, 0x00000000, 0x00000000, 0x00000000}},  //   _квол,   ,   ,
  { {0x629903de, 0x6c7b01ce, 0x5ea90044, 0x00000000}},  //   _obwo, _בריד, গারে,
  { {0x5a9600ed, 0x398f014a, 0x00000000, 0x00000000}},  //   _троф, büs_,   ,
  { {0x7ceb010f, 0x6aa400e7, 0x00000000, 0x00000000}},  //   _dürf, meif,   ,
  { {0x6aa43f28, 0x25a6005b, 0x00000000, 0x00000000}},  //   leif, rwol_,   ,
  { {0x2727006c, 0xbddb009d, 0xb4e60204, 0x00000000}},  //   sõna_, ncèr, _पती_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc05a0245, 0x9f4d013e, 0x00000000, 0x00000000}},  //   кін_, ěným_,   ,
  { {0x0cc10055, 0x67220fc6, 0x6b9e0292, 0x00000000}},  //   _উত্ত, lloj, _oppg,
  { {0x92e40044, 0x6722019a, 0x61e5006b, 0x00000000}},  //   _নদী_, oloj, _əhli,
  { {0x798401d6, 0x00000000, 0x00000000, 0x00000000}},  //   kuiw,   ,   ,
  { {0x7ceb0bea, 0x1154007e, 0xfe6e0014, 0x00000000}},  //   _jürg, _уклю, ژگی_,
  { {0x7ceb006c, 0x8ff700a1, 0xe3b100a1, 0x00000000}},  //   _mürg, اریر_, _برے_,
  { {0x7f840054, 0x67220964, 0x212b009d, 0x00000000}},  //   _العن, kloj, îche_,
  { {0xbcfb0010, 0xb5fd01ed, 0x00000000, 0x00000000}},  //   gsér, _bešl,   ,
  { {0x09cd0044, 0x2ca3012d, 0x8d950025, 0x00000000}},  // [f410] _রেজা, pejd_, _الخش,
  { {0x261a03d7, 0x63ba00ea, 0x398f014a, 0x00000000}},  //   _बड़ी_, _ortn, rüs_,
  { {0xba3b04bd, 0xf7730025, 0x00000000, 0x00000000}},  //   _païs, تاذ_,   ,
  { {0x7ceb010f, 0xba190025, 0x67220267, 0x00000000}},  //   _bürg, _ميجا_, gloj,
  { {0x63ba0210, 0xb5fd016c, 0x39460048, 0x00000000}},  //   _artn, _vešo, íost_,
  { {0xb4e1013d, 0x64a50fc0, 0x81cc0044, 0x00000000}},  //   दसे_, сака, রনা_,
  { {0xbcfb00f4, 0xe299007e, 0xe3b30014, 0x00000000}},  //   nséq, гай_, ترش_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7ceb0279, 0xeabf0082, 0x00000000, 0x00000000}},  //   _kürd, _chùi_,   ,
  { {0x70c9012b, 0x25ad0016, 0x6aa40de1, 0x00000000}},  //   угог_, _isel_, zeif,
  { {0x798400e7, 0x00000000, 0x00000000, 0x00000000}},  //   zuiw,   ,   ,
  { {0xed5a02b8, 0x62990061, 0x6717007d, 0x00000000}},  //   лом_, _ubwo, तविक_,
  { {0x6d4b028c, 0x225f01a3, 0x00000000, 0x00000000}},  //   _égal, mbuk_,   ,
  { {0xa06901f9, 0x7bdc28df, 0x62891e85, 0x00000000}},  //   _сака_, tyru, lgeo,
  { {0xcb030164, 0x4b260025, 0x60c30056, 0x00000000}},  //   रचंड_, معرف, _innm,
  { {0x612f05b7, 0x9e662194, 0x4a46007e, 0x00000000}},  //   følg, _увид, снав,
  { {0xc3320104, 0x6aa43f29, 0xab2701ab, 0x00000000}},  // [f420] לול_, reif, сота_,
  { {0xac86022a, 0x5e5702fd, 0xbcfb00c4, 0x00000000}},  //   _угол, _پلیس_, ssér,
  { {0x6b9e1908, 0xe3b80279, 0x7ceb165e, 0x00000000}},  //   _uppg, _ayın_, _sürg,
  { {0x612f068f, 0x7ceb010e, 0x24b900a1, 0x00000000}},  //   bølg, _pürg, یننگ_,
  { {0x3f85027e, 0x60c30051, 0x7ceb0010, 0x00000000}},  //   hulu_, _onnm, _fürd,
  { {0x3f85002d, 0x28c9007d, 0x00000000, 0x00000000}},  //   kulu_, राणि,   ,
  { {0x25ad021f, 0x00000000, 0x00000000, 0x00000000}},  //   _esel_,   ,   ,
  { {0xa3c903d7, 0x63ba02db, 0x291a00ee, 0x00000000}},  //   _ऊपर_, _vrtn, lopa_,
  { {0x26c4008e, 0xdced05c5, 0x69fb0049, 0x00000000}},  //   _inmo_, _svač, ָליק,
  { {0x7ceb014a, 0x6f74004d, 0xff98003b, 0x00000000}},  //   _küre, огоф, акој_,
  { {0x3f8501c5, 0x3eb23f2a, 0x64a300c0, 0x00000000}},  //   gulu_, _bayt_, _хаха,
  { {0x216a00ed, 0xceeb0379, 0x291a00f8, 0x00000000}},  //   _биди_, اردن_, hopa_,
  { {0x317f0b76, 0x291a34d6, 0x00000000, 0x00000000}},  //   cruz_, kopa_,   ,
  { {0x3f85006b, 0x80e20044, 0x00000000, 0x00000000}},  //   bulu_, _পদক্,   ,
  { {0xe0fb009b, 0x00000000, 0x00000000, 0x00000000}},  //   _גלגל,   ,   ,
  { {0x7ceb005a, 0x6ee612c3, 0x00000000, 0x00000000}},  //   _sürd, _tóba,   ,
  { {0xf770009e, 0x00000000, 0x00000000, 0x00000000}},  // [f430] ہان_,   ,   ,
  { {0x6e2d0091, 0x291a0453, 0x28c9006e, 0x00000000}},  //   _izab, gopa_, राधि,
  { {0xf770002c, 0x7ae3001a, 0x442c0035, 0x00000000}},  //   فان_, _înto, _nzd_,
  { {0x7ceb3f2b, 0xdb1f00b0, 0x00000000, 0x00000000}},  //   _würd, äväk,   ,
  { {0xb5fd010a, 0x3f8522fc, 0x7aed0b57, 0x00000000}},  //   _iešk, zulu_, mhat,
  { {0x7aed0047, 0x291a0919, 0x87e701e0, 0x00000000}},  //   lhat, copa_, _любе,
  { {0x2ee90016, 0x6f0d10c1, 0x62890116, 0x00000000}},  //   _olaf_, _ojac, tgeo,
  { {0x7aed0e69, 0x394300d9, 0x442c0068, 0x00000000}},  //   nhat, _hijs_, _dzd_,
  { {0xe5c70216, 0xb5fd0dc6, 0x62890549, 0x00000000}},  //   _усво, _mešk, rgeo,
  { {0x3eb2006b, 0x7ceb014a, 0x4f9539ae, 0x00000000}},  //   _sayt_, _yüre, орму,
  { {0x1eca09ae, 0x3255041f, 0x6e2d3f2c, 0x00000000}},  //   ални_, _двер, _azab,
  { {0x7d1e001c, 0xf77201ce, 0x82340063, 0x00000000}},  //   _skps, וקט_, _کرما,
  { {0x7aed0010, 0x6f0d01ee, 0x3f85013f, 0x00000000}},  //   dhat, _djac, sulu_,
  { {0x6f0d0b50, 0x6e2d05fa, 0x64910521, 0x00000000}},  //   _ejac, _dzab, _užič,
  { {0x7fd501e1, 0x6e2d002d, 0x8c43026b, 0x00000000}},  //   _філі, _ezab, дере,
  { {0x7aed258d, 0x394b00f6, 0x0d86007c, 0x00000000}},  //   ghat, _bucs_, _длин,
  { {0x7ceb011f, 0x291a00ca, 0x394b00f6, 0x00000000}},  // [f440] _süre, topa_, _cucs_,
  { {0xed590802, 0x39590022, 0xe8c7007e, 0x00000000}},  //   íže_, _dtss_, огул_,
  { {0x291a005f, 0x7d1c0046, 0xab2a01fb, 0x00000000}},  //   ropa_, mors, _вона_,
  { {0x7aed0161, 0x7d1c0010, 0xe5c6007c, 0x00000000}},  //   chat, lors, жско,
  { {0x7ae4007f, 0x00000000, 0x00000000, 0x00000000}},  //   mkit,   ,   ,
  { {0xd37a01f9, 0x7ceb3f2d, 0x7ae400b0, 0x00000000}},  //   ачи_, _türe, lkit,
  { {0x2480011f, 0x7ae43f2e, 0x80b20044, 0x00000000}},  //   ğim_, okit, জাম্,
  { {0x2480014a, 0x7ae40f38, 0x7d1c0161, 0x00000000}},  //   şim_, nkit, hors,
  { {0x7d1c09c8, 0x7ae42de8, 0x39940039, 0x00000000}},  //   kors, ikit, näs_,
  { {0x7aed0010, 0x83fc0166, 0x6f0d0022, 0x00000000}},  //   zhat, _leđi, _sjac,
  { {0x6e2d0047, 0x6f0d022e, 0x7ae400b0, 0x00000000}},  //   _szab, _pjac, kkit,
  { {0x79960036, 0x6e240009, 0xbcfb009d, 0x00000000}},  //   ktyw, _byib, ipée,
  { {0x7d1c05b7, 0x6ab6005b, 0xb5fd0087, 0x00000000}},  //   fors, ddyf, _rešk,
  { {0x7d1c037e, 0x394b19e3, 0x00000000, 0x00000000}},  //   gors, _rucs_,   ,
  { {0x7aed3f2f, 0xb5fd0107, 0x394b0e27, 0x00000000}},  //   that, _pešk, _sucs_,
  { {0xb6060243, 0x3da7007e, 0x7ae4011c, 0x00000000}},  //   _kršć, _дроб, gkit,
  { {0x7aed3f30, 0xb5fd00b9, 0x6e2d0009, 0x00000000}},  // [f450] rhat, _vešk, _uzab,
  { {0x7aed0041, 0x7d1c0207, 0x6f1d18f8, 0x00000000}},  //   shat, cors, losc,
  { {0xb5fd0119, 0x7aed0010, 0x60d8000a, 0x00000000}},  //   _tešk, phat, _movm,
  { {0x6f1d3f31, 0x7ae40009, 0x394300bb, 0x00000000}},  //   nosc, ckit, _wijs_,
  { {0x7ceb02b9, 0x7cf00073, 0x6d450010, 0x00000000}},  //   _gürc, _därf, _kiha,
  { {0x6d4501a3, 0x7e6d0051, 0xd466017f, 0x00000000}},  //   _jiha, _leap, пише_,
  { {0x6d4500e5, 0x044238a1, 0x6f1d00b4, 0x00000000}},  //   _miha, нешн, kosc,
  { {0x29010acc, 0x6d450149, 0xdb17027b, 0x00000000}},  //   liha_, _liha, _orxí,
  { {0x7d1c3f32, 0x4445026c, 0x6d45002d, 0x00000000}},  //   yors, _فراہ, _oiha,
  { {0x6d45014a, 0xb5fd0006, 0x7ae4002d, 0x00000000}},  //   _niha, _neši, zkit,
  { {0x7d1c063c, 0x7ae4010a, 0x25ff0061, 0x00000000}},  //   vors, ykit, _शेती_,
  { {0x7e6d0f23, 0x6f1d0197, 0x25bf0116, 0x00000000}},  //   _ceap, gosc, _krul_,
  { {0x7d1c0027, 0x7cf00004, 0x6d45002d, 0x00000000}},  //   tors, _järg, _biha,
  { {0x7afd00b5, 0xeab2026c, 0x7cf00004, 0x00000000}},  //   _amst, کٹر_, _märg,
  { {0x7d1c0047, 0x6d45020c, 0xb5fd0006, 0x00000000}},  //   rors, _diha, _deši,
  { {0x7d1c0207, 0x6f1d0197, 0x399400b0, 0x00000000}},  //   sors, cosc, täs_,
  { {0x7ae42cbb, 0xbebb0065, 0x6d450022, 0x00000000}},  // [f460] rkit, ymëz, _fiha,
  { {0x7ae43f33, 0x6d45011c, 0x7afd0270, 0x00000000}},  //   skit, _giha, _emst,
  { {0x064a0076, 0x2d8f0039, 0x69cb0a35, 0x00000000}},  //   ملاً_, _äger_, äger,
  { {0xe73700aa, 0xd9460216, 0x6d450032, 0x00000000}},  //   пех_, _неми, _ziha,
  { {0x29011bac, 0xd1380006, 0x6d453f34, 0x00000000}},  //   biha_, ymą_, _yiha,
  { {0x44250224, 0xbcfb009d, 0x798400e7, 0x00000000}},  //   _byl_, ppée, mriw,
  { {0xdc36007b, 0x07a3007c, 0xdcb10082, 0x00000000}},  //   האַט_, _парн, ổi_,
  { {0x7ceb3f35, 0x7cf03f36, 0x442508c9, 0x00000000}},  //   _müra, _färg, _dyl_,
  { {0x6f1d021c, 0x44250095, 0x7cf0010e, 0x00000000}},  //   vosc, _eyl_, _kärd,
  { {0x60f801fb, 0x3ea001aa, 0x2019006b, 0x00000000}},  //   іння_, _abit_, əsiz_,
  { {0xd1380a67, 0xb5fd0dbd, 0x6f1d0197, 0x00000000}},  //   rmą_, _reši, tosc,
  { {0x6d4501a3, 0xd1380006, 0x7cf000f8, 0x00000000}},  //   _siha, smą_, _lärd,
  { {0x6d45020c, 0x44250007, 0xd24f0025, 0x00000000}},  //   _piha, _zyl_, _إنه_,
  { {0xd12f01fb, 0x317b01ce, 0x31570104, 0x00000000}},  //   _їх_, _פרומ, _ציון_,
  { {0x78b500ee, 0x50b70054, 0x6d45044e, 0x00000000}},  //   _razv, _ردود_, _viha,
  { {0x78b50b29, 0x7c250428, 0x6d450b7e, 0x00000000}},  //   _sazv, _vyhr, _wiha,
  { {0x29011bac, 0xdb240010, 0xf8c90164, 0x00000000}},  // [f470] tiha_, írás, रालय,
  { {0x3eab0866, 0x63ad0036, 0x2d8b012d, 0x00000000}},  //   lect_, łani, muce_,
  { {0x2d8b013e, 0x5eb00044, 0x5695007c, 0x00000000}},  //   luce_, টারে, дает,
  { {0x3eb93f37, 0x7afd010f, 0x2d99040f, 0x00000000}},  //   ndst_, _umst, otse_,
  { {0x83fc0119, 0x7cf00039, 0x3eab001a, 0x00000000}},  //   _među, _färd, iect_,
  { {0x2d99006c, 0x44253f38, 0xeabf0045, 0x00000000}},  //   itse_, _pyl_, _thùs_,
  { {0xe784003b, 0xb5fd3f39, 0x00000000, 0x00000000}},  //   _путо, _nešv,   ,
  { {0x3eab0f44, 0x2d8b15d7, 0x2d99006c, 0x00000000}},  //   ject_, kuce_, ktse_,
  { {0x2d8b3940, 0x059500a2, 0x44251c26, 0x00000000}},  //   juce_, _تازگ, _wyl_,
  { {0x2d8b1468, 0xddc40006, 0x60090140, 0x00000000}},  //   duce_, _neiš, жном_,
  { {0x9eaa01f9, 0x7cf00004, 0x3eab3f3a, 0x00000000}},  //   овна_, _järe, fect_,
  { {0x441a0049, 0x141a0049, 0xa2e40088, 0x00000000}},  //   _וועס, _וועב, _поєд,
  { {0x2d8b037e, 0x25a40061, 0xf1a701ab, 0x00000000}},  //   guce_, _xpml_, _хрен,
  { {0xc172009b, 0xfaff0023, 0x00000000, 0x00000000}},  //   _יחד_, _amë_,   ,
  { {0x2d9900bb, 0x00000000, 0x00000000, 0x00000000}},  //   atse_,   ,   ,
  { {0x41d10061, 0xee0a1192, 0x3eb90009, 0x00000000}},  //   _तपास, _мейл_, cdst_,
  { {0x39460c4e, 0x798400e7, 0x3b070745, 0x00000000}},  // [f480] днаг, uriw, фето_,
  { {0x4999007c, 0xcc8a0014, 0x7cf03f3b, 0x00000000}},  //   ятся_, _بنده_, _bäre,
  { {0x09d60055, 0x7cf00073, 0xda6601ee, 0x00000000}},  //   _সেখা, _värd, _овни,
  { {0xc6a302a8, 0x7cf00039, 0x2d54006c, 0x00000000}},  //   врши, _däre, _käe_,
  { {0xd5ad009e, 0x00000000, 0x00000000, 0x00000000}},  //   یہہ_,   ,   ,
  { {0x2d54010e, 0x00000000, 0x00000000, 0x00000000}},  //   _mäe_,   ,   ,
  { {0x938a007e, 0x7cf0010e, 0x3eab004a, 0x00000000}},  //   іска_, _kärb, yect_,
  { {0x7ceb010f, 0x27e7068f, 0xc6c3022a, 0x00000000}},  //   _nürn, ønne_, _ийск,
  { {0x2d543f3c, 0x00000000, 0x00000000, 0x00000000}},  //   _näe_,   ,   ,
  { {0xf651026c, 0x5436004b, 0x160403d7, 0x00000000}},  //   _لئے_, _قرار, _शेयर_,
  { {0xddc40006, 0x3eab00ab, 0xe29a00ed, 0x00000000}},  //   _reiš, tect_, _маж_,
  { {0x2d8b1d1f, 0xda1e0061, 0x7cf0150e, 0x00000000}},  //   tuce_, पथात_, _närb,
  { {0x800800a1, 0x80da0044, 0x7ae3001a, 0x00000000}},  //   ترکہ_, যোগ্, _înti,
  { {0x2d8b0145, 0x2d990abf, 0x273500f8, 0x00000000}},  //   ruce_, rtse_, pång_,
  { {0x7cf003a2, 0x3eab1e47, 0x2d8b0eae, 0x00000000}},  //   _bärb, pect_, suce_,
  { {0x3f8c00e7, 0x00000000, 0x00000000, 0x00000000}},  //   mudu_,   ,   ,
  { {0xb5fd0224, 0x3f8c002b, 0x44290082, 0x00000000}},  // [f490] _ješt, ludu_, ́a_,
  { {0xb5fd1d9b, 0xf80702dc, 0x5a343f3d, 0x00000000}},  //   _mešt, мчен, тнут,
  { {0x3f8c0ec4, 0xb5fd0062, 0x7cf001a2, 0x00000000}},  //   nudu_, _lešt, _färb,
  { {0x645a177d, 0x26c9004a, 0x7cf000b0, 0x00000000}},  //   _afti, ñao_, _väre,
  { {0xb5fd0119, 0x7cf0010f, 0x5a44216a, 0x00000000}},  //   _nešt, _wäre, _аэра,
  { {0x98c4007c, 0x6aad3f3e, 0x3f8c01a3, 0x00000000}},  //   _иссл, leaf, kudu_,
  { {0xaa7b000c, 0x27350039, 0x09e40044, 0x00000000}},  //   _flýt, tånd_, _নেপা,
  { {0x645a0359, 0xdb05155e, 0x09d60044, 0x00000000}},  //   _efti, _erhö, _সেটা,
  { {0x31790047, 0x6d5f0066, 0x00000000, 0x00000000}},  //   ész_, _ntqa,   ,
  { {0xddc43f3f, 0x69c00e00, 0xc8d20164, 0x00000000}},  //   _afiş, _šmek, सायट,
  { {0x3f8c0009, 0x5f060088, 0x2c1f0061, 0x00000000}},  //   gudu_, езна, _मुलं_,
  { {0x32750049, 0xb5fd0bd9, 0x80cd0061, 0x00000000}},  //   _װײַל_, _fešt, ताहे,
  { {0xc33200b6, 0xcd360752, 0xb5fd06ed, 0x00000000}},  //   _עוד_, فرآب, _gešt,
  { {0x3f8c3f40, 0x61340129, 0x8b6600a1, 0x00000000}},  //   budu_, tàle, فارم,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6aad0007, 0xbcfb0048, 0x00000000, 0x00000000}},  //   geaf, rpéa,   ,
  { {0x27180235, 0x00000000, 0x00000000, 0x00000000}},  // [f4a0] nčne_,   ,   ,
  { {0xee37008b, 0x3c660099, 0xb865221c, 0x00000000}},  //   _яны_, _яког, نامو,
  { {0xb895005e, 0x61f7006b, 0x66e600c0, 0x00000000}},  //   ъртъ, _əxla, ножа,
  { {0x6b7b009b, 0x6aad3f41, 0x00000000, 0x00000000}},  //   _צרכנ, ceaf,   ,
  { {0x86230194, 0x09e302dc, 0x645a0045, 0x00000000}},  //   льше, _боян, _pfti,
  { {0xb5fd0027, 0xb4ea006e, 0x00000000, 0x00000000}},  //   _rešt, मसे_,   ,
  { {0xa3d40242, 0xb5fd00ca, 0x779100a1, 0x00000000}},  //   тойч, _sešt, _نیلا,
  { {0x3f8c0521, 0xf74301ee, 0x85580bb6, 0x00000000}},  //   vudu_, _бесо, _قیصر_,
  { {0x80c90044, 0x6f06013f, 0x00000000, 0x00000000}},  //   াউন্, dikc,   ,
  { {0xb5fd3f42, 0x55770049, 0x6722006c, 0x00000000}},  //   _vešt, _נעבן_, looj,
  { {0x612f0637, 0x941c006b, 0x6d5f002b, 0x00000000}},  //   møll, yevə_, _stqa,
  { {0x3f8c0145, 0x00000000, 0x00000000, 0x00000000}},  //   rudu_,   ,   ,
  { {0xc0e60242, 0x3f8c016e, 0x00000000, 0x00000000}},  //   _подк, sudu_,   ,
  { {0x63a80145, 0x00000000, 0x00000000, 0x00000000}},  //   _kpdn,   ,   ,
  { {0x672b0d3e, 0x00000000, 0x00000000, 0x00000000}},  //   ylgj,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xfeb8007a, 0x6aad0133, 0x00000000, 0x00000000}},  // [f4b0] _سايت_, reaf,   ,
  { {0x6aad0190, 0x00000000, 0x00000000, 0x00000000}},  //   seaf,   ,   ,
  { {0x7d070825, 0xdced012d, 0xcc56009b, 0x00000000}},  //   mijs, _avać, _בבתי_,
  { {0x7d0700b5, 0x39b20173, 0x7ce201c3, 0x00000000}},  //   lijs, _fņs_, _fôrs,
  { {0x2a7600a0, 0x2a6930b9, 0x04b800a1, 0x00000000}},  //   _בערך_, mbab_, ڑپوں_,
  { {0x2a690390, 0xf773035b, 0x64a5003b, 0x00000000}},  //   lbab_, _مار_, така,
  { {0x94740014, 0x29030023, 0xc6a70467, 0x00000000}},  //   ادها, _imja_, _праи,
  { {0x63510089, 0x7d07016c, 0x69c0007f, 0x00000000}},  //   _jāni, hijs, _šmei,
  { {0x7cf00039, 0x7ae30035, 0x00000000, 0x00000000}},  //   _lära, _întu,   ,
  { {0x2258013e, 0x00000000, 0x00000000, 0x00000000}},  //   ěrka_,   ,   ,
  { {0x7d0700ee, 0x12e701fb, 0x2cba0300, 0x00000000}},  //   dijs, _підг, _rapd_,
  { {0xd3560104, 0x752300e7, 0x2cba01d6, 0x00000000}},  //   _סיני_, lonz, _sapd_,
  { {0x7ceb011f, 0xdce40166, 0x6f0611e4, 0x00000000}},  //   _türl, _sviđ, rikc,
  { {0x7d070825, 0x7cf000f8, 0x2b4b2378, 0x00000000}},  //   gijs, _bära, _aicc_,
  { {0xab2a0407, 0x394a11d1, 0x00000000, 0x00000000}},  //   дова_, _ribs_,   ,
  { {0x7a38000c, 0x7bc500f6, 0x7cf000f8, 0x00000000}},  //   _nútí, _drhu, _dära,
  { {0xee3a0265, 0x7d0700bb, 0xbb43003b, 0x00000000}},  // [f4c0] _юни_, bijs, ретк,
  { {0x7d070746, 0xb95b001d, 0xbc6a02fd, 0x00000000}},  //   cijs, _trìn, _تمدن_,
  { {0x752306b1, 0x2a690c2c, 0xdce404eb, 0x00000000}},  //   donz, bbab_, _uviđ,
  { {0x6d4b00f4, 0x224f0022, 0x27e706ec, 0x00000000}},  //   _égar, _nggk_, ønna_,
  { {0x80b2001c, 0x6b830039, 0x394a00fa, 0x00000000}},  //   _असले, _ångr, _tibs_,
  { {0x26cd000b, 0x75230555, 0x6722010e, 0x00000000}},  //   _eneo_, gonz, sooj,
  { {0x6f040197, 0xe3af0379, 0xc6230044, 0x00000000}},  //   _omic, قري_, বেলা_,
  { {0x7d0701ae, 0x66e309b2, 0x78bc0e2d, 0x00000000}},  //   zijs, _коса, _harv,
  { {0x09e40044, 0x7ceb005d, 0xe5720025, 0x00000000}},  //   _নেতা, _sürm, _خطأ_,
  { {0x6f043f43, 0x78bc1241, 0x30a30088, 0x00000000}},  //   _amic, _jarv, арюв,
  { {0x3af500ea, 0x6ee6004a, 0x2d8400d2, 0x00000000}},  //   _håpe_, _lóbu, ámen_,
  { {0x78bc0056, 0x7d0700bb, 0xb5fd0087, 0x00000000}},  //   _larv, wijs, _kešp,
  { {0x442c018e, 0x7d070059, 0xf0b7007a, 0x00000000}},  //   _hyd_, tijs, رایش_,
  { {0x7cf00004, 0x78bc006c, 0x48bd0044, 0x00000000}},  //   _pära, _narv, _আক্র,
  { {0x7d0712ac, 0x69c60056, 0x2b4b0085, 0x00000000}},  //   rijs, _arke, _picc_,
  { {0x7bc50f3a, 0x7cf0006c, 0x442c0016, 0x00000000}},  //   _vrhu, _vära, _myd_,
  { {0x78bc0aaa, 0x442c05b7, 0x7d07040d, 0x00000000}},  // [f4d0] _barv, _lyd_, pijs,
  { {0x7cf00039, 0x3324002b, 0x78bc0335, 0x00000000}},  //   _härn, homx_, _carv,
  { {0x69c6011f, 0x7cf023df, 0x78bc0350, 0x00000000}},  //   _erke, _kärn, _darv,
  { {0x95990269, 0x7cf00039, 0x7af60161, 0x00000000}},  //   етку_, _järn, chyt,
  { {0x78bc0018, 0xbebb0065, 0x7bd8001a, 0x00000000}},  //   _farv, llës, ăbuş,
  { {0x442c018e, 0x78bc032e, 0x7aed002d, 0x00000000}},  //   _byd_, _garv, lkat,
  { {0x442c0016, 0x75230197, 0x2489006b, 0x00000000}},  //   _cyd_, ronz, ğam_,
  { {0x248901f6, 0x69c6093b, 0xe3b0023c, 0x00000000}},  //   şam_, _yrke, تره_,
  { {0x7aed010a, 0x6e2d3f44, 0x6abd0ec1, 0x00000000}},  //   ikat, _nyab, _masf,
  { {0x6ff3005f, 0x2cb100b9, 0x442c0016, 0x00000000}},  //   ləcə, jezd_, _fyd_,
  { {0x6e360046, 0x332d0249, 0x442c1b6c, 0x00000000}},  //   _szyb, plex_, _gyd_,
  { {0x6e2d0061, 0x63050167, 0x6ff3006b, 0x00000000}},  //   _byab, _حوصل, nəcə,
  { {0x6e2d0009, 0x7aed0056, 0x27180059, 0x00000000}},  //   _cyab, dkat, nčna_,
  { {0x61e91205, 0x6e2d0a1d, 0x7aed0190, 0x00000000}},  //   myel, _dyab, ekat,
  { {0x92d50044, 0x2d8b0035, 0x61e90095, 0x00000000}},  //   হসী_, arce_, lyel,
  { {0x7cf00073, 0x7aed006a, 0x78bc05e0, 0x00000000}},  //   _gärn, gkat, _sarv,
  { {0x4a75008b, 0x78bc0eb4, 0x61e93f45, 0x00000000}},  // [f4e0] рыст, _parv, nyel,
  { {0x4a430457, 0x2b400133, 0x673b214c, 0x00000000}},  //   снув, smic_, _ahuj,
  { {0x7e76000c, 0x78bc0864, 0xdc9b00a0, 0x00000000}},  //   _keyp, _varv, _אייל,
  { {0x7aed3f46, 0xe61a0175, 0x66760d3a, 0x00000000}},  //   ckat, нде_, ادار,
  { {0x78bc0b3e, 0x442c3f47, 0x69c63f48, 0x00000000}},  //   _tarv, _syd_, _urke,
  { {0x7ae3000d, 0x6d5628f4, 0x69c43f49, 0x00000000}},  //   _într, _muya, mvie,
  { {0x74690088, 0x7cf00039, 0x6abd0022, 0x00000000}},  //   трів_, _läro, _yasf,
  { {0x41b4023c, 0x81cd0044, 0x69c43f4a, 0x00000000}},  //   لمبر, রহন_, ovie,
  { {0x69c4028c, 0x61e90047, 0xdce40046, 0x00000000}},  //   nvie, gyel, _zwią,
  { {0x442c0343, 0x7aed002d, 0x4376007c, 0x00000000}},  //   _tyd_, zkat, _будт,
  { {0x7cf00004, 0x7aed008d, 0x3366012b, 0x00000000}},  //   _pärn, ykat, _свег,
  { {0x7ceb01f6, 0x69c4010a, 0x63ba0036, 0x00000000}},  //   _türk, kvie, _istn,
  { {0x2d8b009d, 0x6d56008e, 0x7cf003af, 0x00000000}},  //   urce_, _cuya, _värn,
  { {0x69c41c71, 0x6d56014a, 0x00000000, 0x00000000}},  //   dvie, _duya,   ,
  { {0x69c401c5, 0x7aed0772, 0x6ff3006b, 0x00000000}},  //   evie, tkat, yəcə,
  { {0x7cf00039, 0x7ceb2222, 0x6a150264, 0x00000000}},  //   _härl, _müri, амбу,
  { {0x7aed1964, 0x7cf00039, 0x69c40089, 0x00000000}},  // [f4f0] rkat, _kärl, gvie,
  { {0x7aed001e, 0x6729022e, 0x673b37ef, 0x00000000}},  //   skat, _skej, _shuj,
  { {0x7c29010f, 0x61fb0afb, 0xb8dd007d, 0x00000000}},  //   ßerd, zzul, _आस_,
  { {0xf7700025, 0xf990026c, 0xb8ec006e, 0x00000000}},  //   سام_, تبہ_, _शो_,
  { {0x6ff3005f, 0x69c40082, 0x1efc0049, 0x00000000}},  //   rəcə, cvie, עלדע,
  { {0xbf020204, 0x61fb3f4b, 0x798d3f4c, 0x00000000}},  //   _लग्न_, vzul, mraw,
  { {0x6ed8001c, 0x3ea9023a, 0x62993d3e, 0x00000000}},  //   यामु, _obat_, _pcwo,
  { {0x61fb002d, 0x61e90173, 0x661b002d, 0x00000000}},  //   tzul, tyel, _txuk,
  { {0x61fb3f4d, 0x7e7600e0, 0xa2a10309, 0x00000000}},  //   uzul, _reyp, क्ष्,
  { {0x3ea90f57, 0x6ee600c4, 0x61fb0e42, 0x00000000}},  //   _abat_, _nóbr, rzul,
  { {0x3dc9006a, 0x69c43f4e, 0x6d561d42, 0x00000000}},  //   _araw_, zvie, _suya,
  { {0xed5a013b, 0xfe46004c, 0x6d560058, 0x00000000}},  //   ком_, инно, _puya,
  { {0x23690091, 0x7ceb010f, 0xde36007e, 0x00000000}},  //   ćaju_, _züri, рэнь,
  { {0x3dc93f4f, 0x317f014a, 0x272e000c, 0x00000000}},  //   _draw_, msuz_, rýni_,
  { {0x8c46004c, 0x317f0477, 0x4a9a007e, 0x00000000}},  //   реве, lsuz_, ктаў_,
  { {0x69c4001e, 0xf1a903d7, 0x6d563f50, 0x00000000}},  //   tvie, _कहान, _tuya,
  { {0x0906008b, 0x5f4400a1, 0x798d0007, 0x00000000}},  // [f500] апан, _پچھل, graw,
  { {0xe8f7058f, 0xa2cc001c, 0xdd7b0049, 0x00000000}},  //   алу_, _दोन्, _שטיל,
  { {0x25ad001a, 0x69c416a6, 0xd90d0167, 0x00000000}},  //   _apel_, svie, ریف_,
  { {0x317f26e4, 0x69c409a1, 0xd7ef0025, 0x00000000}},  //   ksuz_, pvie, بكم_,
  { {0x28760783, 0x798d0cc0, 0x7cf008e8, 0x00000000}},  //   _выбр, craw, _lärm,
  { {0x05140044, 0x7ceb0d24, 0x7c290095, 0x00000000}},  //   িত্র_, _püri, şere,
  { {0x7cf00039, 0xd377007e, 0x24850022, 0x00000000}},  //   _närm, ачы_, _ddlm_,
  { {0xf1a6008b, 0x3878053d, 0x16040061, 0x00000000}},  //   арон, _herr_, _शेअर_,
  { {0x7cf003af, 0xb5a90025, 0xa63400a1, 0x00000000}},  //   _pärl, _مالك_, _اکاؤ,
  { {0x4fc600ed, 0x5f94004d, 0x7ceb010e, 0x00000000}},  //   асма, биот, _türi,
  { {0x7cf00073, 0x38780065, 0x0857009b, 0x00000000}},  //   _värl, _merr_, יבים_,
  { {0x7cf00039, 0x3dc90036, 0xd36f0014, 0x00000000}},  //   _därm, _praw_, _آهن_,
  { {0xae010201, 0x00000000, 0x00000000, 0x00000000}},  //   _लेखन_,   ,   ,
  { {0x3e750011, 0x7cf00894, 0x6143003b, 0x00000000}},  //   ất_, _härj, _деча,
  { {0x81cd0044, 0xead501ab, 0x7cf00052, 0x00000000}},  //   রহণ_, бовь, _kärj,
  { {0x7cf00368, 0x798d0036, 0x8e850025, 0x00000000}},  //   _järj, traw, _الظه,
  { {0x13af0044, 0x7e7d006c, 0x4c95005e, 0x00000000}},  // [f510] কিয়, masp, _липс,
  { {0xd8790647, 0x7e7d0089, 0x5cb9007e, 0x00000000}},  //   امات_, lasp, _слоў_,
  { {0x25ad0a74, 0x38780ede, 0x00000000, 0x00000000}},  //   _spel_, _derr_,   ,
  { {0x798d0046, 0x7e7d00e7, 0x25ad00d9, 0x00000000}},  //   praw, nasp, _ppel_,
  { {0x929d0036, 0xc9840143, 0x38780023, 0x00000000}},  //   siłk, _мури, _ferr_,
  { {0x43850025, 0x7e7d1e17, 0x00000000, 0x00000000}},  //   ملتق, hasp,   ,
  { {0x39590239, 0x31660288, 0x9f64006b, 0x00000000}},  //   _huss_, _atoz_, ətçi_,
  { {0x569404af, 0x7e7d037e, 0x98b90006, 0x00000000}},  //   _маст, jasp, _pusė_,
  { {0x224b0039, 0xc69200a3, 0x7e7d03c2, 0x00000000}},  //   äck_, _מאן_, dasp,
  { {0x3959001f, 0x9f4e00b9, 0xa3d7013d, 0x00000000}},  //   _muss_, ěním_, ामद_,
  { {0x7cf000f8, 0x7e7d0190, 0xe43503d9, 0x00000000}},  //   _färj, fasp, _افاد,
  { {0x7cf00073, 0x613d00f4, 0x1efa0025, 0x00000000}},  //   _värm, dèle, اعدة_,
  { {0xd25601f8, 0x7cf0010f, 0x01650aed, 0x00000000}},  //   _השנה_, _wärm, _укло,
  { {0x1d190077, 0xed57007c, 0x463a0049, 0x00000000}},  //   аюсь_, сор_, טערע,
  { {0x6f9506ea, 0x7f850054, 0x00000000, 0x00000000}},  //   _العض, _البن,   ,
  { {0x395903af, 0x7cf000b0, 0x271800ca, 0x00000000}},  //   _buss_, _kärk, včno_,
  { {0x9f460010, 0x7cf000b0, 0x00000000, 0x00000000}},  // [f520] szló_, _järk,   ,
  { {0x7cf0039e, 0x23b701f5, 0xa3d7007d, 0x00000000}},  //   _märk, _आनंद, ामा_,
  { {0x395900f6, 0x387801e5, 0x00000000, 0x00000000}},  //   _euss_, _verr_,   ,
  { {0xe9a601e0, 0xf72901fb, 0xf74300da, 0x00000000}},  //   _ламп, ацій_, пехо,
  { {0xd90d026c, 0x9412005f, 0x38780023, 0x00000000}},  //   ریہ_, əyə_, _terr_,
  { {0x26c012f8, 0x6ab6000c, 0x2d8200ea, 0x00000000}},  //   žio_, leyf, iske_,
  { {0x7ae60142, 0x290a0058, 0xddc4016c, 0x00000000}},  //   _kokt, _imba_, _neiž,
  { {0x2d820277, 0x7e7d0032, 0x7ae62a04, 0x00000000}},  //   kske_, xasp, _jokt,
  { {0x2d82092f, 0xe45200a6, 0x7e7d01ee, 0x00000000}},  //   jske_, _فضا_, vasp,
  { {0x2d820091, 0x7e7d0093, 0x3ae7006c, 0x00000000}},  //   dske_, wasp, _lõpp_,
  { {0x33f60264, 0xe4d701ef, 0xdeb50147, 0x00000000}},  //   _учас, _دولت_, обны,
  { {0x7ae6011f, 0x2d820bf8, 0x80d60204, 0x00000000}},  //   _nokt, fske_, बाहे,
  { {0x7e7d357d, 0x290a00e7, 0x00000000, 0x00000000}},  //   rasp, _omba_,   ,
  { {0x613d1259, 0x2b5a00f6, 0xc19b009b, 0x00000000}},  //   tèle, _bupc_, _עשוי,
  { {0xe7e30055, 0x7ae6194d, 0x2d820521, 0x00000000}},  //   _মধ্য, _bokt, aske_,
  { {0x290a097e, 0x7bc729f9, 0x395900f8, 0x00000000}},  //   _amba_, rvju, _puss_,
  { {0x6f0f0197, 0x49bb0014, 0x00000000, 0x00000000}},  // [f530] micc, دازد_,   ,
  { {0x7cf00039, 0x6f0f0197, 0x612f06ec, 0x00000000}},  //   _närh, licc, sølv,
  { {0xc5e60044, 0xe7b503e6, 0x7ceb006b, 0x00000000}},  //   _খেলা_, تماد, _qüru,
  { {0x290a0697, 0x6f0f04b8, 0x00000000, 0x00000000}},  //   _emba_, nicc,   ,
  { {0x1a9a0049, 0x85a7003b, 0x7ceb2beb, 0x00000000}},  //   _דירע, сјед, _fürt,
  { {0x92d50055, 0x6f0f0026, 0x9a290082, 0x00000000}},  //   _হতে_, hicc, _gươm_,
  { {0x7ae6014a, 0xf794007e, 0x7cf01b6b, 0x00000000}},  //   _yokt, _нарэ, _särk,
  { {0x23a10036, 0x2d820030, 0x7ceb005a, 0x00000000}},  //   rój_, yske_, _kürs,
  { {0x44290046, 0x6f0f029a, 0x50b501ab, 0x00000000}},  //   ła_, dicc, осну,
  { {0x672b008d, 0x9f8501fb, 0x2d820340, 0x00000000}},  //   logj, огод, vske_,
  { {0xef1a012b, 0x6f0f0066, 0x273c3f51, 0x00000000}},  //   имо_, ficc, lína_,
  { {0x2d821502, 0x2f54004c, 0x7cf0021e, 0x00000000}},  //   tske_, ятьс, _tärk,
  { {0x2d843f52, 0xed5a007c, 0x7ae601c5, 0x00000000}},  //   éme_, рог_, _rokt,
  { {0xa0693b88, 0x2d823f53, 0xdbc7000c, 0x00000000}},  //   _така_, rske_, töðv,
  { {0xf0b801ef, 0x6f0f0026, 0x7ae60022, 0x00000000}},  //   _دانش_, bicc, _pokt,
  { {0xed5a15c4, 0x2d82037e, 0x629b0006, 0x00000000}},  //   _кои_, pske_, nguo,
  { {0x60c30f5c, 0xdb050030, 0x7ae600ea, 0x00000000}},  // [f540] _kanm, _ophæ, _vokt,
  { {0x92d50044, 0x60c30173, 0x00000000, 0x00000000}},  //   _হতো_, _janm,   ,
  { {0x60c30263, 0x6569008d, 0x68e700b9, 0x00000000}},  //   _manm, _ateh, _dojd,
  { {0x60c30263, 0x7c3e066e, 0x27e70039, 0x00000000}},  //   _lanm, _izpr, änna_,
  { {0xf5b6031d, 0x7ceb014a, 0x00000000, 0x00000000}},  //   تصاد, _gürs,   ,
  { {0xf366003b, 0x7ceb01df, 0x2cb80912, 0x00000000}},  //   отин, _hürr, nerd_,
  { {0xbcfb00f4, 0x3ea0231b, 0x00000000, 0x00000000}},  //   mpét, _ocit_,   ,
  { {0x60c3017c, 0x6569002b, 0x7cf00039, 0x00000000}},  //   _aanm, _fteh, _däri,
  { {0x60c30173, 0x7984018e, 0x2cb800b5, 0x00000000}},  //   _banm, nsiw, kerd_,
  { {0x60c30016, 0x26c41163, 0x00000000, 0x00000000}},  //   _canm, _hamo_,   ,
  { {0x44383f54, 0x60c30018, 0x26c4011c, 0x00000000}},  //   _ár_, _danm, _kamo_,
  { {0x7413007a, 0x26c60020, 0x26c400ca, 0x00000000}},  //   _توما, ndoo_, _jamo_,
  { {0x60c30263, 0xdce4092f, 0x6f0f0555, 0x00000000}},  //   _fanm, _etič, ricc,
  { {0x62800010, 0x6f0f0197, 0x2cb83f55, 0x00000000}},  //   lamo, sicc, gerd_,
  { {0x6f0f0197, 0x672b0022, 0x00000000, 0x00000000}},  //   picc, yogj,   ,
  { {0x62800006, 0x60c30263, 0xda0c03d7, 0x00000000}},  //   namo, _zanm, _सेहत_,
  { {0x3eb90004, 0x6f0d3f56, 0x68e71a2d, 0x00000000}},  // [f550] mest_, _imac, _pojd,
  { {0x3eb91c0b, 0xa2cc02d2, 0x8b080224, 0x00000000}},  //   lest_, _दोस्, _pořá,
  { {0x6569001f, 0x62800006, 0x2d99006c, 0x00000000}},  //   _steh, kamo, luse_,
  { {0x6280010a, 0x95d9007c, 0x26c42c23, 0x00000000}},  //   jamo, йдет_, _camo_,
  { {0x443e0047, 0x62801770, 0xb065021e, 0x00000000}},  //   _azt_, damo, nkää,
  { {0x7cf00004, 0xe4c217bc, 0xdb1e000a, 0x00000000}},  //   _päri, ейши, _aspè,
  { {0x60c301aa, 0x3eb9006c, 0x2d990030, 0x00000000}},  //   _ranm, kest_, huse_,
  { {0x3eb90209, 0x66b40057, 0x8c1c0097, 0x00000000}},  //   jest_, _обсу, יווי,
  { {0x443e0047, 0xdce41531, 0x65690521, 0x00000000}},  //   _ezt_, _stič, _uteh,
  { {0x6f0d1368, 0x2d993f57, 0xdb1e3f58, 0x00000000}},  //   _amac, duse_, _espè,
  { {0x62800211, 0x60c30168, 0x2cb800b5, 0x00000000}},  //   bamo, _vanm, verd_,
  { {0x7cf03f59, 0x62800489, 0x2cb801d6, 0x00000000}},  //   _järv, camo, werd_,
  { {0x2d99006c, 0x60c32965, 0x2cb824b6, 0x00000000}},  //   guse_, _tanm, terd_,
  { {0xb6060062, 0xa3cf006e, 0x6aaf004a, 0x00000000}},  //   _ukáž, शिप_, _abcf,
  { {0xdce40107, 0x1d07003b, 0xa021010e, 0x00000000}},  //   _utič, чери_, ööde,
  { {0x7cf003af, 0x2d9903c6, 0x3ea016d0, 0x00000000}},  //   _närv, buse_, _ucit_,
  { {0x26c400fa, 0xc332009b, 0x2cb8040f, 0x00000000}},  // [f560] _ramo_, תון_, perd_,
  { {0x49990057, 0x26c401d9, 0x62801ae2, 0x00000000}},  //   ются_, _samo_, zamo,
  { {0x628b0de0, 0x62800dfb, 0xbcfb263c, 0x00000000}},  //   _odgo, yamo, rpét,
  { {0xe73a0057, 0x6602002d, 0x628012dd, 0x00000000}},  //   щее_, tzok, xamo,
  { {0xbcfb00f4, 0x62800285, 0x27180059, 0x00000000}},  //   mpér, vamo, nčni_,
  { {0x7ae40091, 0x6fdb0061, 0x26c400e7, 0x00000000}},  //   ljit, यमां, _wamo_,
  { {0x26c40119, 0x62800977, 0x25a60142, 0x00000000}},  //   _tamo_, tamo, stol_,
  { {0x7af60006, 0x7ae41137, 0x00000000, 0x00000000}},  //   nkyt, njit,   ,
  { {0x62801770, 0x6f0d0061, 0x00000000, 0x00000000}},  //   ramo, _rmac,   ,
  { {0x2d990004, 0x6f0d120c, 0xc22300a1, 0x00000000}},  //   vuse_, _smac, رکنو,
  { {0x3eb908ce, 0xdb1e1729, 0x6f1d0211, 0x00000000}},  //   test_, _espé, érco,
  { {0x2d990004, 0x7f440b33, 0x2b4924d9, 0x00000000}},  //   tuse_, _chiq, xmac_,
  { {0x3eb900ab, 0x7ae43f5a, 0x00000000, 0x00000000}},  //   rest_, djit,   ,
  { {0x3eb90004, 0x2d99006c, 0xa2a20061, 0x00000000}},  //   sest_, ruse_, _गाड्,
  { {0x3eb90047, 0x6e2402d5, 0x2d990004, 0x00000000}},  //   pest_, _exib, suse_,
  { {0x7ae4008d, 0x2d99001a, 0x8037009b, 0x00000000}},  //   gjit, puse_, _מנוע_,
  { {0x2b493f5b, 0xfc3000a1, 0xa2a1006e, 0x00000000}},  // [f570] rmac_, نحہ_, क्ट्,
  { {0x98b80006, 0xa3cf0316, 0x00000000, 0x00000000}},  //   _mirė_, शिम_,   ,
  { {0x6f1d3f5c, 0x7e7f0023, 0xbcfb0068, 0x00000000}},  //   onsc, _keqp, spés,
  { {0x6f1d3f5d, 0x69cf016c, 0x645a123c, 0x00000000}},  //   nnsc, _trce, _agti,
  { {0x6f1d0129, 0x7cf00dac, 0xd1380006, 0x00000000}},  //   insc, _värv, klą_,
  { {0x3f853f5e, 0x7afd21b3, 0xe5700025, 0x00000000}},  //   yslu_, _hlst, اطن_,
  { {0x6d57006b, 0x68e3000c, 0xa2e5007c, 0x00000000}},  //   _mixa, öndu, дойд,
  { {0xa2a201f5, 0x7cf031f5, 0x6d571aaa, 0x00000000}},  //   _गाण्, _härt, _lixa,
  { {0x659400ed, 0xb14501ab, 0x00000000, 0x00000000}},  //   _пату, мнил,   ,
  { {0x27180059, 0x7f440023, 0x00000000, 0x00000000}},  //   včni_, _shiq,   ,
  { {0x7cf00004, 0x2611013d, 0x3afc00b9, 0x00000000}},  //   _märt, _देती_, _lípa_,
  { {0x64413f5f, 0x7c29011f, 0x6d45002b, 0x00000000}},  //   _izli, ğerl, _ahha,
  { {0x3f85002b, 0x6d570032, 0x00000000, 0x00000000}},  //   sslu_, _bixa,   ,
  { {0x3e7c001d, 0x7afd0a75, 0x6d453438, 0x00000000}},  //   ật_, _alst, _chha,
  { {0x6aad006b, 0x00000000, 0x00000000, 0x00000000}},  //   ffaf,   ,   ,
  { {0x765b00ad, 0x6d570129, 0xff260088, 0x00000000}},  //   _nguy, _eixa, _імпо,
  { {0x7af60ecb, 0x6d8800a1, 0x08c60745, 0x00000000}},  // [f580] rkyt, _عمدہ_, мбан,
  { {0x7af61415, 0x7afd000c, 0xbcfb009d, 0x00000000}},  //   skyt, _elst, spér,
  { {0x81e30044, 0x66e63f60, 0x7cf000f8, 0x00000000}},  //   ননি_, можа, _därt,
  { {0x6b9c0085, 0x00000000, 0x00000000, 0x00000000}},  //   murg,   ,   ,
  { {0x6b9c01c5, 0xd5b0035b, 0xe4e60088, 0x00000000}},  //   lurg, افت_, дійн,
  { {0x81e30044, 0x7cf001a2, 0x44252909, 0x00000000}},  //   ননা_, _gärt, _bxl_,
  { {0xec360049, 0x98a3025f, 0x442501f3, 0x00000000}},  //   ואַר_, _шире, _cxl_,
  { {0x7cf023fa, 0xfbc00044, 0x8afb0049, 0x00000000}},  //   _kärs, _উপাত, ַליז,
  { {0x7cf0006c, 0x6b9c0032, 0x69c40316, 0x00000000}},  //   _järs, hurg, रिटी,
  { {0x6b9c002d, 0x7cf000f8, 0x00000000, 0x00000000}},  //   kurg, _märs,   ,
  { {0xd0100647, 0x39580995, 0x00000000, 0x00000000}},  //   الج_, _mirs_,   ,
  { {0x7996369c, 0x65600020, 0x6b9c000c, 0x00000000}},  //   kryw, _kumh, durg,
  { {0x656004be, 0x6f1d01a2, 0x7cf03355, 0x00000000}},  //   _jumh, rnsc, _närs,
  { {0xa2b802f4, 0x799636a3, 0x65600048, 0x00000000}},  //   ्यक्, dryw, _mumh,
  { {0x7c34085f, 0xd00f0604, 0x6b9c000c, 0x00000000}},  //   верх, _рф_, gurg,
  { {0xaf080025, 0xcf270d3a, 0xa3cf007d, 0x00000000}},  //   _يقوم_, _ترتي, शित_,
  { {0x79960036, 0x29130032, 0x00000000, 0x00000000}},  // [f590] gryw, tixa_,   ,
  { {0x7b67022a, 0x3eb20036, 0xf1c80011, 0x00000000}},  //   _отме, _zbyt_, _mỡ_,
  { {0xf1c80011, 0x6b9c0035, 0x29133f61, 0x00000000}},  //   _lỡ_, curg, rixa_,
  { {0x7afd164d, 0x7bc50065, 0x7cf00510, 0x00000000}},  //   _ulst, _ishu, _färs,
  { {0xe578008b, 0x65603f62, 0xf1c80082, 0x00000000}},  //   дзі_, _cumh, _nỡ_,
  { {0xa3c300b9, 0x7d150e99, 0x7cf00dac, 0x00000000}},  //   _září_, nizs, _härr,
  { {0xe3b1035b, 0x2911005d, 0x44250190, 0x00000000}},  //   ارت_, _imza_, _qxl_,
  { {0xe0bb0044, 0x7bc500e7, 0x44253e70, 0x00000000}},  //   _অচেন, _mshu, _vxl_,
  { {0x2b590857, 0x9f520224, 0xf1c80011, 0x00000000}},  //   _misc_, ází_, _cỡ_,
  { {0xf48500a1, 0xf1c80082, 0x60090437, 0x00000000}},  //   _سائی, _dỡ_, зном_,
  { {0x79960036, 0x64410089, 0x7bc50009, 0x00000000}},  //   zryw, _uzli, _nshu,
  { {0x7b030004, 0x59df006e, 0x00000000, 0x00000000}},  //   _jõud, नमार,   ,
  { {0xf1c80011, 0x7bc50020, 0x200500b4, 0x00000000}},  //   _gỡ_, _ashu, szli_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7cf00039, 0x1c390088, 0x00000000, 0x00000000}},  //   _särs, дять_,   ,
  { {0x7b030004, 0x39580066, 0x2b590093, 0x00000000}},  //   _nõud, _sirs_, _cisc_,
  { {0x2b591ce2, 0x39580059, 0x7bc5016c, 0x00000000}},  // [f5a0] _disc_, _pirs_, _eshu,
  { {0x7cf0225c, 0x6b9c129a, 0xe4f4013d, 0x00000000}},  //   _värs, purg, _अवधि_,
  { {0x2b590b50, 0x395808ad, 0x7cf003a2, 0x00000000}},  //   _fisc_, _virs_, _färr,
  { {0xb5aa0054, 0x6d4b00f6, 0x6d4e01a2, 0x00000000}},  //   كاتك_, _ègar, lmba,
  { {0x39580190, 0xfa3600a1, 0x6d4e3f63, 0x00000000}},  //   _tirs_, _سرحد, omba,
  { {0x69c6057e, 0x6367047f, 0xf1c80011, 0x00000000}},  //   _iske, _sına, _rỡ_,
  { {0x6d4e033b, 0xf1c80082, 0xccf300b3, 0x00000000}},  //   imba, _sỡ_, רכו_,
  { {0xc7d700b6, 0x2611006e, 0x6d4e01a2, 0x00000000}},  //   _אולי_, _देवी_, hmba,
  { {0xc1b70930, 0x00000000, 0x00000000, 0x00000000}},  //   елых_,   ,   ,
  { {0xa2d5001c, 0xf1c80011, 0x68ee013e, 0x00000000}},  //   _मोठ्, _vỡ_, _jobd,
  { {0x7d150010, 0x68ee0022, 0x00000000, 0x00000000}},  //   vizs, _mobd,   ,
  { {0x6d4e00bb, 0x032602dc, 0x00000000, 0x00000000}},  //   emba, _яден,   ,
  { {0x2b5905f7, 0x9df80401, 0x00000000, 0x00000000}},  //   _risc_, енят_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb1e00f7, 0x69c63334, 0x7d153f64, 0x00000000}},  //   _espí, _aske, rizs,
  { {0x3f9e1bf5, 0x6d4e0eb0, 0x00000000, 0x00000000}},  //   mutu_, amba,   ,
  { {0x0f58007b, 0x7b03006c, 0x2b5900d4, 0x00000000}},  // [f5b0] _איהם_, _nõue, _visc_,
  { {0x613d01aa, 0x68ee00f6, 0x7bc501c3, 0x00000000}},  //   yèlm, _cobd, _tshu,
  { {0x3f9e022b, 0x2d8b0046, 0x69c6022b, 0x00000000}},  //   nutu_, lsce_, _eske,
  { {0x613d01aa, 0x00000000, 0x00000000, 0x00000000}},  //   vèlm,   ,   ,
  { {0x64a50888, 0x3f9e3f65, 0x7cf005e0, 0x00000000}},  //   вала, hutu_, _kärp,
  { {0x2d9915a1, 0x26c90091, 0x613d01aa, 0x00000000}},  //   irse_, žao_, tèlm,
  { {0x6282017c, 0x7c29010f, 0xddcd016c, 0x00000000}},  //   _beoo, ßerh, _neaž,
  { {0x0ed00061, 0x3f9e010e, 0x00000000, 0x00000000}},  //   _तोंड, dutu_,   ,
  { {0x2d8b0046, 0xa2a2007d, 0x7aef004a, 0x00000000}},  //   jsce_, _गार्, _moct,
  { {0xd12e006d, 0x98b4016c, 0x7e6d00f6, 0x00000000}},  //   يمي_, čeću_, _afap,
  { {0x52b50025, 0x3f9e002d, 0x2d99037f, 0x00000000}},  //   _لماذ, gutu_, erse_,
  { {0x7aef06c2, 0x62820116, 0x521500c0, 0x00000000}},  //   _noct, _geoo, _идет,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x3f9e218d, 0xed571a59, 0xdfa903ec, 0x00000000}},  //   butu_, коя_, _قطعه_,
  { {0xed57012b, 0x6d4e0065, 0x2d99008e, 0x00000000}},  //   тор_, rmba, arse_,
  { {0x38c8089d, 0x7aef008e, 0x00000000, 0x00000000}},  //   کاری_, _coct,   ,
  { {0xfd120025, 0x00000000, 0x00000000, 0x00000000}},  // [f5c0] _نجد_,   ,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x24870263, 0xc8b5007e, 0x00000000, 0x00000000}},  //   danm_, ысты,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1d029d, 0x05b40025, 0x00000000, 0x00000000}},  //   érci, امتح,   ,
  { {0x68460072, 0x3f9e014a, 0xa5330451, 0x00000000}},  //   _анга, yutu_, аніч,
  { {0x17c703dc, 0x69c40036, 0x60ca000c, 0x00000000}},  //   _игри_, lwie, _rafm,
  { {0x6aa400b5, 0x14d20061, 0x69c400b4, 0x00000000}},  //   ngif, _धोरण, owie,
  { {0xcb1301f8, 0x44320046, 0x7c29014a, 0x00000000}},  //   ילה_, ły_, ğeri,
  { {0xa3cf013d, 0x6722010a, 0x3f9e177c, 0x00000000}},  //   शिश_, lnoj, tutu_,
  { {0x69c4010f, 0x6282006c, 0x389b00a0, 0x00000000}},  //   hwie, _teoo, ויינ,
  { {0x3f9e002d, 0x69c40066, 0x753d0089, 0x00000000}},  //   rutu_, kwie, _īszi,
  { {0xf1940e09, 0x4106025f, 0x6aa40030, 0x00000000}},  //   _силь, _издв, dgif,
  { {0x3f9e0107, 0x2d800036, 0x2d8b016c, 0x00000000}},  //   putu_, _dwie_, rsce_,
  { {0x7ceb010f, 0x8aa70088, 0x6aa40030, 0x00000000}},  //   _kürz, крад, fgif,
  { {0x9057009b, 0x99800036, 0x2cad00b9, 0x00000000}},  //   _בסוף_, dził_, řed_,
  { {0x690b00b4, 0x561d0044, 0x00000000, 0x00000000}},  // [f5d0] dżer, _তর্ক_,   ,
  { {0xdb1e00d4, 0x3dc90058, 0x00000000, 0x00000000}},  //   _espà, _isaw_,   ,
  { {0xccf200b6, 0xfd13026c, 0x248701aa, 0x00000000}},  //   _הכי_, _مجھ_, vanm_,
  { {0x07a4103e, 0x69c401d6, 0x00000000, 0x00000000}},  //   раїн, bwie,   ,
  { {0xf773026c, 0xa6340106, 0x5a9a009b, 0x00000000}},  //   _چار_, анці, _אשרא,
  { {0xf77301b7, 0x6fd50061, 0x00000000, 0x00000000}},  //   _نار_, धिमं,   ,
  { {0x22460010, 0x2b4b0022, 0x00000000, 0x00000000}},  //   _azok_, _khcc_,   ,
  { {0x24870263, 0x72c519ea, 0xd1c905b5, 0x00000000}},  //   sanm_, убиз, елие_,
  { {0x798d0016, 0x78880089, 0xdced01ee, 0x00000000}},  //   nsaw, būvē, _atač,
  { {0x0cce0055, 0x2fc70085, 0x00000000, 0x00000000}},  //   _রক্ত, _psng_,   ,
  { {0xb4cf001c, 0x26df012d, 0x69c400b4, 0x00000000}},  //   षयी_, _knuo_, zwie,
  { {0x24850433, 0xddc40089, 0x213e0133, 0x00000000}},  //   _helm_, _afiš, alth_,
  { {0xe0ce0265, 0x2903201a, 0x6aa400d8, 0x00000000}},  //   _лв_, _olja_, vgif,
  { {0x333f002b, 0x67220ade, 0x00000000, 0x00000000}},  //   llux_, znoj,   ,
  { {0x3ea901aa, 0x6aa400ea, 0x798d0016, 0x00000000}},  //   _fcat_, tgif, esaw,
  { {0x69c40036, 0xdce40166, 0x2b4b0011, 0x00000000}},  //   twie, _otić, _chcc_,
  { {0x09e30113, 0x6aa4018d, 0x6f043f66, 0x00000000}},  // [f5e0] ботн, rgif, _ilic,
  { {0x69c41594, 0xa2d501f5, 0x60c10095, 0x00000000}},  //   rwie, _मोस्, nelm,
  { {0x6f04051d, 0x6aa40073, 0xb0a60061, 0x00000000}},  //   _klic, pgif, _खासग,
  { {0x2bd1001c, 0xbc1b007b, 0xdb9b0104, 0x00000000}},  //   हिरा, _טויש, _אסטר,
  { {0x6d5e0020, 0x60c1010c, 0x6722007f, 0x00000000}},  //   _kipa, kelm, rnoj,
  { {0x60c1021e, 0x6f040129, 0xa7860d3a, 0x00000000}},  //   jelm, _llic, _مشرو,
  { {0x60c13f67, 0x6d5e0020, 0xd90d00a1, 0x00000000}},  //   delm, _mipa, _تیل_,
  { {0x6d5e0209, 0x291a0020, 0xaa7b0027, 0x00000000}},  //   _lipa, lipa_, _inýc,
  { {0x8af0005f, 0x171b007b, 0x7b03006c, 0x00000000}},  //   mməd, _נומע, _jõua,
  { {0x60c10943, 0x3ea90061, 0x8af0006b, 0x00000000}},  //   gelm, _scat_, lməd,
  { {0x6f043f68, 0x2b400059, 0xd36f0025, 0x00000000}},  //   _blic, klic_, _فهل_,
  { {0x6d5e022b, 0x291a001a, 0xb8570049, 0x00000000}},  //   _aipa, hipa_, טשיג_,
  { {0x6d5e027b, 0x7b03006c, 0x291a1b76, 0x00000000}},  //   _bipa, _nõua, kipa_,
  { {0x6f040412, 0x6d5e0089, 0x656f00f4, 0x00000000}},  //   _elic, _cipa, _éche,
  { {0x6d5e0149, 0x7c3e0142, 0x5eba0055, 0x00000000}},  //   _dipa, _cypr, ইয়ে,
  { {0x6f040016, 0x7b64007c, 0x543b0049, 0x00000000}},  //   _glic, стре, געלא,
  { {0xad270188, 0x443e068f, 0x6d5e0026, 0x00000000}},  // [f5f0] _مردو, _lyt_, _fipa,
  { {0x4a54012b, 0x0edd001c, 0x6d5e011c, 0x00000000}},  //   скус, याकड, _gipa,
  { {0x443e3f69, 0x2b400038, 0xf7700025, 0x00000000}},  //   _nyt_, blic_, كان_,
  { {0x1b7a0049, 0x60c10148, 0x0c740014, 0x00000000}},  //   _שטרע, zelm, _پدید,
  { {0xa68401fb, 0xb8db0044, 0x60c13f6a, 0x00000000}},  //   слід, _অফ_, yelm,
  { {0x443e3f6b, 0x29033f6c, 0x60c100eb, 0x00000000}},  //   _byt_, _ulja_, xelm,
  { {0x60c10181, 0x2bd8007d, 0xfbd801f5, 0x00000000}},  //   velm, डिया, डियम,
  { {0x41b50242, 0x443e1beb, 0xe61000a2, 0x00000000}},  //   асот, _dyt_, _کشف_,
  { {0x60c13ac6, 0x6289018e, 0x54a70d3a, 0x00000000}},  //   telm, raeo, _محاف,
  { {0x6f0418a7, 0x6f160804, 0xa2d5007d, 0x00000000}},  //   _slic, _smyc, _मोर्,
  { {0x6d5e0207, 0x60c11bd5, 0x6f04001a, 0x00000000}},  //   _ripa, relm, _plic,
  { {0x6d5e0a0d, 0x7f4d3f6d, 0x7aed0066, 0x00000000}},  //   _sipa, _chaq, jjat,
  { {0x7aed002b, 0x7f5f005f, 0x60c100d4, 0x00000000}},  //   djat, _diqq, pelm,
  { {0xdca6098c, 0x4e960014, 0xa0660256, 0x00000000}},  //   јави, دشگر, _каша_,
  { {0x6d5e3f6e, 0x673b0009, 0x2b40016c, 0x00000000}},  //   _vipa, _okuj, tlic_,
  { {0x67290065, 0x7c3e0161, 0x7aed0065, 0x00000000}},  //   _njej, _vypr, gjat,
  { {0x6d5e05ea, 0x7c3e0036, 0x61fb3f6f, 0x00000000}},  // [f600] _tipa, _wypr, nyul,
  { {0xe9d70175, 0x63a337a9, 0x5dfb00a0, 0x00000000}},  //   шку_, kunn, _ספינ,
  { {0x7d1c12db, 0xcd290464, 0x63a3328a, 0x00000000}},  //   mirs, _حسين_, junn,
  { {0xe9a6008b, 0x7d1c0676, 0x291a0166, 0x00000000}},  //   _камп, lirs, sipa_,
  { {0xfb370049, 0x6286000c, 0x8af0006b, 0x00000000}},  //   _כאטש_, ðkom, rməd,
  { {0x63a33cb0, 0x7d1c014a, 0x186a00ed, 0x00000000}},  //   funn, nirs, _јави_,
  { {0x63a3000c, 0x291800f6, 0xe3b8013f, 0x00000000}},  //   gunn, _imra_, _axır_,
  { {0xb6a331c9, 0x67290065, 0x7b03006c, 0x00000000}},  //   _мисл, _gjej, _lõun,
  { {0xdb070010, 0x443e0016, 0x7d1c1109, 0x00000000}},  //   ntjá, _wyt_, kirs,
  { {0x63a304d4, 0x7aed002b, 0x7f4d0023, 0x00000000}},  //   bunn, zjat, _shaq,
  { {0x7d1c1d8a, 0xd8d70049, 0x64483288, 0x00000000}},  //   dirs, בויט_, _uzdi,
  { {0xd041006b, 0x7760002b, 0xdb230276, 0x00000000}},  //   ndlə, _jimx, ürüc,
  { {0x7d1c000c, 0x7e7d384f, 0x7e470b91, 0x00000000}},  //   firs, rbsp, рхне,
  { {0x7d1c3f70, 0xd041006b, 0x00000000, 0x00000000}},  //   girs, hdlə,   ,
  { {0x9b68025f, 0x7aed3f71, 0x7f4d0023, 0x00000000}},  //   ишта_, tjat, _thaq,
  { {0x5f730070, 0x6e2d0032, 0x2cba000a, 0x00000000}},  //   _باور, _txab, _ebpd_,
  { {0x7aed1978, 0x6f1d3f72, 0x7d1c0211, 0x00000000}},  // [f610] rjat, misc, birs,
  { {0x6f1d010f, 0x7d1c008e, 0x7aed2a12, 0x00000000}},  //   lisc, cirs, sjat,
  { {0x9675007e, 0x8e380014, 0x7aed2b0c, 0x00000000}},  //   былі, _مسیر_, pjat,
  { {0xb8fe03d7, 0x6f1d3f73, 0xec3600b6, 0x00000000}},  //   _दो_, nisc, _לאתר_,
  { {0x5887008b, 0x76400016, 0x2611006e, 0x00000000}},  //   _выба, _cymy, _देखी_,
  { {0x63a3021e, 0x6f1d3f74, 0xd006039d, 0x00000000}},  //   tunn, hisc, _فل_,
  { {0x67290039, 0xc952009b, 0x6f1d01a2, 0x00000000}},  //   _tjej, _ממך_, kisc,
  { {0x63a33f75, 0x61e923ca, 0x668200a1, 0x00000000}},  //   runn, txel, _فیمل,
  { {0x6f1d0270, 0x7d1c006b, 0x63a31f47, 0x00000000}},  //   disc, yirs, sunn,
  { {0x25bf0093, 0x7e640016, 0x60e90bff, 0x00000000}},  //   _ipul_, _sgip, умом_,
  { {0x68f530a2, 0x6f1d05c6, 0x7d1c3f76, 0x00000000}},  //   _mozd, fisc, virs,
  { {0x81c60055, 0x6f1d05c6, 0x7c38068f, 0x00000000}},  //   _উপর_, gisc, _øvri,
  { {0x2d84028c, 0xa3cf0201, 0x2f5501fb, 0x00000000}},  //   ème_, शिक_, ютьс,
  { {0x64411919, 0xd37e0107, 0x68f5041a, 0x00000000}},  //   _kyli, šćen_, _nozd,
  { {0x7d1c000c, 0x656102d5, 0xd041013f, 0x00000000}},  //   rirs, _milh, ydlə,
  { {0x64410006, 0x8bc5007e, 0x6f1d016c, 0x00000000}},  //   _myli, ўсёд, cisc,
  { {0xe9da045a, 0x7d1c2a8f, 0x68f50095, 0x00000000}},  // [f620] ыка_, pirs, _bozd,
  { {0xdb070010, 0x65610066, 0x088a0025, 0x00000000}},  //   rtjá, _nilh, اناً_,
  { {0x64411ab8, 0xdb07000c, 0x00000000, 0x00000000}},  //   _nyli, stjá,   ,
  { {0x7b03006c, 0xdd8f007a, 0x76a90088, 0x00000000}},  //   _jõul, _توی_, итів_,
  { {0x65610181, 0xd041006b, 0x6441026d, 0x00000000}},  //   _bilh, rdlə, _ayli,
  { {0x273c027b, 0x68f50059, 0x64410387, 0x00000000}},  //   tíns_, _gozd, _byli,
  { {0x76400036, 0x7760002b, 0x00000000, 0x00000000}},  //   _wymy, _timx,   ,
  { {0x6441024d, 0xf1a60088, 0x1b7b0049, 0x00000000}},  //   _dyli, брон, נטפע,
  { {0x656102d5, 0xe29f000c, 0x9aeb0049, 0x00000000}},  //   _filh, óða_, אַיִ,
  { {0x656f00f4, 0x61e401d5, 0x6f1d1594, 0x00000000}},  //   _écha, _ġild, wisc,
  { {0x6f1d04e5, 0x61e40006, 0x32020161, 0x00000000}},  //   tisc, _šild, šky_,
  { {0x71a6008b, 0xb7db0097, 0x00000000, 0x00000000}},  //   _гадз, אקטי,   ,
  { {0x6f1d0707, 0x644101a2, 0x78bc1adc, 0x00000000}},  //   risc, _zyli, _obrv,
  { {0x6f1d3f74, 0xd1300025, 0x00000000, 0x00000000}},  //   sisc, _تمت_,   ,
  { {0x6f1d08ed, 0x68f508e2, 0x64410052, 0x00000000}},  //   pisc, _rozd, _xyli,
  { {0xae9b0025, 0x00000000, 0x00000000, 0x00000000}},  //   _إضغط_,   ,   ,
  { {0x248e0022, 0x98e50025, 0x00000000, 0x00000000}},  // [f630] kafm_, يكرو,   ,
  { {0x29070b22, 0x25a62bdd, 0xc86701ab, 0x00000000}},  //   óna_, duol_, стаи,
  { {0xf84b01e0, 0x68f501ee, 0x25bf0112, 0x00000000}},  //   учай_, _vozd, _spul_,
  { {0x17f80025, 0x6561009d, 0x64413f77, 0x00000000}},  //   حركة_, _silh, _ryli,
  { {0xa3ab01f5, 0x656100c4, 0x6569008e, 0x00000000}},  //   कून_, _pilh, _queh,
  { {0x69cf0107, 0x73990072, 0xdb1e01d6, 0x00000000}},  //   _isce, атис_, _appè,
  { {0x05160025, 0x6561000c, 0x00000000, 0x00000000}},  //   تيوب_, _vilh,   ,
  { {0x8c1c01ce, 0x6561010f, 0x69dd016c, 0x00000000}},  //   טווי, _wilh, _krse,
  { {0x6441010b, 0x2d9e0036, 0x65611ab4, 0x00000000}},  //   _wyli, ątek_, _tilh,
  { {0xc1050025, 0xdb070039, 0x6441007f, 0x00000000}},  //   زوجي, ltjä, _tyli,
  { {0xceea0849, 0xd8d80049, 0x78ba0010, 0x00000000}},  //   адне_, מוזט_, _ötve,
  { {0x69cf0197, 0x69dd0016, 0xc7d6009b, 0x00000000}},  //   _osce, _orse, קורי_,
  { {0xee3700c2, 0x200308fb, 0x629901aa, 0x00000000}},  //   жня_, šji_, _idwo,
  { {0x628b002d, 0x00000000, 0x00000000, 0x00000000}},  //   _hego,   ,   ,
  { {0x628b0022, 0x2fdc0087, 0x00000000, 0x00000000}},  //   _kego, _grvg_,   ,
  { {0x28ac03d7, 0x3eab001c, 0x1a2a05f6, 0x00000000}},  //   _चाहि, cgct_, ажби_,
  { {0x628b0047, 0x3b0700e3, 0x8d760070, 0x00000000}},  // [f640] _mego, цето_, _بابا,
  { {0x628b0e49, 0xbebb00bb, 0x69dd00ca, 0x00000000}},  //   _lego, riëe, _drse,
  { {0x69cf0779, 0x69dd010f, 0x62990036, 0x00000000}},  //   _esce, _erse, _odwo,
  { {0xe73a007c, 0x69dd0009, 0x25a6005b, 0x00000000}},  //   шее_, _frse, tuol_,
  { {0x6445006c, 0x7ae600bb, 0x00000000, 0x00000000}},  //   ühin, _inkt,   ,
  { {0x62990292, 0x33980025, 0x628b3f78, 0x00000000}},  //   _adwo, منتج_, _aego,
  { {0x261a03d7, 0x628b00b5, 0x689100a1, 0x00000000}},  //   _मेरी_, _bego, _سینئ,
  { {0x628b00c4, 0xc3d5007e, 0xcfcf0044, 0x00000000}},  //   _cego, яўчы, িমান,
  { {0x628b01aa, 0x80d30044, 0xe81e0061, 0x00000000}},  //   _dego, তান্, _येता_,
  { {0x628b0087, 0x62990085, 0xe4520bb6, 0x00000000}},  //   _eego, _edwo, _قضا_,
  { {0x436a0478, 0x00000000, 0x00000000, 0x00000000}},  //   _таен_,   ,   ,
  { {0x628b0546, 0x543b0049, 0x00000000, 0x00000000}},  //   _gego, _דעבא,   ,
  { {0xc69301f8, 0xe0cf0014, 0x3eb9059b, 0x00000000}},  //   ואר_, رزی_, rfst_,
  { {0x628b022b, 0x224b010f, 0x7ae60023, 0x00000000}},  //   _zego, ücke_, _ankt,
  { {0xcb1b00ed, 0x7b2c006b, 0x60c80146, 0x00000000}},  //   аќа_, rğun, medm,
  { {0x290a001a, 0x539b0097, 0xdd910025, 0x00000000}},  //   _alba_, יילו, _كوب_,
  { {0x5d840025, 0x00000000, 0x00000000, 0x00000000}},  // [f650] _قليل,   ,   ,
  { {0x2bcb0061, 0x69dd016c, 0x60c800e0, 0x00000000}},  //   ाबदा, _vrse, nedm,
  { {0x6d47092f, 0xb8d30204, 0xd7fb00ed, 0x00000000}},  //   mlja, _टा_, јуз_,
  { {0x6d47000c, 0x290a02c9, 0x00000000, 0x00000000}},  //   llja, _elba_,   ,
  { {0x628b1a64, 0x69dd00bb, 0x69cf0197, 0x00000000}},  //   _rego, _urse, _usce,
  { {0x628b04bd, 0xdb070039, 0xd7fb030d, 0x00000000}},  //   _sego, stjä, _куб_,
  { {0x7b03006c, 0x49000061, 0x628b00c4, 0x00000000}},  //   _nõuk, _शकतो_, _pego,
  { {0x6aad000c, 0x1616013d, 0x656f009d, 0x00000000}},  //   ngaf, _देकर_, _écho,
  { {0x628b0087, 0x91b00082, 0x257000f6, 0x00000000}},  //   _vego, _đại_, _gàl_,
  { {0xa3bb1095, 0x628b00d9, 0x3f870022, 0x00000000}},  //   _ناصر_, _wego, _pwnu_,
  { {0x628b0770, 0x6d4700d0, 0x75370089, 0x00000000}},  //   _tego, dlja, ļazī,
  { {0x672b0d3e, 0x91f70025, 0x00000000, 0x00000000}},  //   nngj, _وأشا,   ,
  { {0x91e502dc, 0x00000000, 0x00000000, 0x00000000}},  //   _холе,   ,   ,
  { {0x657b000b, 0x91f6009b, 0x2d9e0161, 0x00000000}},  //   _mtuh, _ממנו_, čte_,
  { {0xe8df0011, 0x00000000, 0x00000000, 0x00000000}},  //   _ngực_,   ,   ,
  { {0x63ae0030, 0xe9df1573, 0x999f016c, 0x00000000}},  //   _åbne, _brú_, _šuš_,
  { {0x6d470746, 0xc33200a0, 0x80ce0044, 0x00000000}},  // [f660] blja, גון_, ়ার্,
  { {0x29cd012d, 0x6eff0023, 0xcdb7009b, 0x00000000}},  //   _dža_, _dëbu, _צפיה_,
  { {0x78a3000c, 0x7d1e00f6, 0x929d0036, 0x00000000}},  //   ónva, _imps, zkła,
  { {0x60c80046, 0x248c00b9, 0x257000f6, 0x00000000}},  //   zedm, _sedm_, _pàl_,
  { {0xa4d40088, 0x00000000, 0x00000000, 0x00000000}},  //   долі,   ,   ,
  { {0xb4d6006e, 0x00000000, 0x00000000, 0x00000000}},  //   िये_,   ,   ,
  { {0xdc9b00a0, 0x60c801e3, 0x2795003b, 0x00000000}},  //   ציקל, vedm, _оштр,
  { {0x6d470bf8, 0x00000000, 0x00000000, 0x00000000}},  //   zlja,   ,   ,
  { {0x79960036, 0xd5c00061, 0xd5280082, 0x00000000}},  //   nsyw, _एहिज, _cộn,
  { {0x67223227, 0xdce40fcd, 0x00000000, 0x00000000}},  //   lioj, _otiđ,   ,
  { {0x6d470295, 0xc4d30104, 0xe1ef0167, 0x00000000}},  //   vlja, _רגע_, نسی_,
  { {0x7d1e0abf, 0x67220006, 0x00000000, 0x00000000}},  //   _amps, nioj,   ,
  { {0x6d47092f, 0x7b2c006b, 0x66022434, 0x00000000}},  //   tlja, rğul, nyok,
  { {0xeb05007d, 0x7b03010e, 0xed590006, 0x00000000}},  //   रस्त_, _tõuk, įžo_,
  { {0x00bb009b, 0xcc54005e, 0x8af0006b, 0x00000000}},  //   _המומ, евръ, rmən,
  { {0x6d471279, 0x5bb8007c, 0x213e1238, 0x00000000}},  //   slja, ялся_, loth_,
  { {0x6d4710f7, 0x67220023, 0x2ee90026, 0x00000000}},  // [f670] plja, dioj, _inaf_,
  { {0x8af0005f, 0xb4d6006e, 0x98b30035, 0x00000000}},  //   lməl, ियो_, doxă_,
  { {0x6f0d00b5, 0x657b0b77, 0xf6d50088, 0x00000000}},  //   _klac, _stuh, діля,
  { {0xe9df193c, 0xd4910082, 0x8af0013f, 0x00000000}},  //   _trú_, _còn_, nməl,
  { {0xd5bb1280, 0x672b0023, 0x6f0d168d, 0x00000000}},  //   ссе_, rngj, _mlac,
  { {0x6f0d0221, 0x2b4906fa, 0x044500e2, 0x00000000}},  //   _llac, llac_, мелн,
  { {0x6f0d01f6, 0xb0a60061, 0xcc7800b3, 0x00000000}},  //   _olac, _खाजग, הגות_,
  { {0x25a0016e, 0x07090025, 0x61e40006, 0x00000000}},  //   šila_, _بيري_, _šila,
  { {0x59e0013d, 0x00000000, 0x00000000, 0x00000000}},  //   नियर,   ,   ,
  { {0x6f0d014a, 0xa2bd0164, 0x224600e0, 0x00000000}},  //   _alac, _वॉर्, _dyok_,
  { {0x6f0d0498, 0x7523012d, 0x1eca0aa2, 0x00000000}},  //   _blac, minz, олни_,
  { {0x75230937, 0xe1f10025, 0x00000000, 0x00000000}},  //   linz, _لست_,   ,
  { {0x6f0d0036, 0x213e01d6, 0xee3a01e1, 0x00000000}},  //   _dlac, both_, інг_,
  { {0xcb6a0c27, 0x60250ab7, 0x333f3f79, 0x00000000}},  //   жаве_, _одла, loux_,
  { {0x6f0d010f, 0xdc6702ea, 0x7fd50088, 0x00000000}},  //   _flac, дард_, _цілі,
  { {0x6f0d3b3d, 0x25ee001c, 0x75230061, 0x00000000}},  //   _glac, _आपली_, hinz,
  { {0x31673f7a, 0x14ae0061, 0x2d95007e, 0x00000000}},  // [f680] _kinz_, _घालण, _прэс,
  { {0x66020020, 0x00000000, 0x00000000, 0x00000000}},  //   vyok,   ,   ,
  { {0x8af0006b, 0x75230026, 0xd2590089, 0x00000000}},  //   lməm, dinz, meņu_,
  { {0xe5c60175, 0x333f00f4, 0x464a00e3, 0x00000000}},  //   дско, joux_, озен_,
  { {0x67220006, 0x333f009d, 0x38710048, 0x00000000}},  //   rioj, doux_, íorú_,
  { {0x672207d3, 0xd37a017a, 0x66020022, 0x00000000}},  //   sioj, очи_, ryok,
  { {0xbebb00bb, 0x68fc3f7b, 0xe3af03ec, 0x00000000}},  //   diën, _iord, لري_,
  { {0x68fc1484, 0xc298003b, 0x00000000, 0x00000000}},  //   _hord, чких_,   ,
  { {0x68fc0004, 0x75230142, 0x00000000, 0x00000000}},  //   _kord, binz,   ,
  { {0x6f0d00b5, 0x75230ec0, 0xbebb0328, 0x00000000}},  //   _slac, cinz, giën,
  { {0x6f0d028a, 0x68fc0059, 0x213e00f8, 0x00000000}},  //   _plac, _mord, roth_,
  { {0x65680065, 0x522602dc, 0x69c600d9, 0x00000000}},  //   _hidh, _офла, _opke,
  { {0x68fc01bb, 0x8af0006b, 0x2f02000c, 0x00000000}},  //   _oord, rməl, _nógu_,
  { {0x68fc02cc, 0x656801d5, 0xbebb00b5, 0x00000000}},  //   _nord, _jidh, ciën,
  { {0xb06501c2, 0x6f0d0142, 0x5ec40044, 0x00000000}},  //   rjää, _tlac, ষয়ে,
  { {0x6568008d, 0x64480145, 0x752300d2, 0x00000000}},  //   _lidh, _mydi, zinz,
  { {0x68fc0472, 0x7e6d3f7c, 0x64480007, 0x00000000}},  // [f690] _bord, _igap, _lydi,
  { {0x656838d6, 0x25a6005b, 0xba54003b, 0x00000000}},  //   _nidh, drol_, твуј,
  { {0xf77005d4, 0x68fc1de2, 0x644822d8, 0x00000000}},  //   لان_, _dord, _nydi,
  { {0x65681dec, 0x61e20a83, 0x25a62108, 0x00000000}},  //   _aidh, _orol, frol_,
  { {0x68fc004e, 0x6568000b, 0x6448014a, 0x00000000}},  //   _ford, _bidh, _aydi,
  { {0x19b601f8, 0x7afd07fc, 0xaabb00a1, 0x00000000}},  //   _אפשר_, _host, _ادھر_,
  { {0x61e2018e, 0x64480b9b, 0x75230142, 0x00000000}},  //   _arol, _cydi, rinz,
  { {0x61e20006, 0x7afd021e, 0x75233f7d, 0x00000000}},  //   _brol, _jost, sinz,
  { {0x75230020, 0xbebb00b5, 0x61e20197, 0x00000000}},  //   pinz, tiën, _crol,
  { {0x7f560023, 0x61e23f7e, 0x65680048, 0x00000000}},  //   _shyq, _drol, _gidh,
  { {0x7afd01b5, 0xff260594, 0xbebb0112, 0x00000000}},  //   _oost, емно, riën,
  { {0x7afd108c, 0x6da60057, 0x6d4500ea, 0x00000000}},  //   _nost, нима, _akha,
  { {0x61e20270, 0xa3ab0061, 0xbd36005e, 0x00000000}},  //   _grol, कूर_, ехвъ,
  { {0x7afd0207, 0x8af0006b, 0xd196009b, 0x00000000}},  //   _aost, rməm, _טכני_,
  { {0x7afd3f7f, 0x2d99010e, 0x9f520010, 0x00000000}},  //   _bost, asse_, ázó_,
  { {0x7afd051b, 0x68fc014a, 0x6d450843, 0x00000000}},  //   _cost, _sord, _ekha,
  { {0x68fc0197, 0x31b901aa, 0x8af0006b, 0x00000000}},  // [f6a0] _pord, nèz_, lmək,
  { {0x38c80167, 0x290e3f80, 0x7afd00ea, 0x00000000}},  //   باری_, ófa_, _eost,
  { {0x7afd048c, 0xcd020036, 0x68fc010f, 0x00000000}},  //   _fost, ęść_, _vord,
  { {0x7afd38c8, 0x68fc0f12, 0x65680020, 0x00000000}},  //   _gost, _word, _sidh,
  { {0x45d434a9, 0x6f1d0129, 0xd6d900b4, 0x00000000}},  //   толс, èrci, _dał_,
  { {0x7afd0620, 0x25a6049a, 0x9f59002a, 0x00000000}},  //   _zost, rrol_, árú_,
  { {0xa3ab03d7, 0x65680f86, 0x3ea0000a, 0x00000000}},  //   कूल_, _vidh, _odit_,
  { {0x61e218a7, 0x2d9902b6, 0x25a60022, 0x00000000}},  //   _prol, ysse_, prol_,
  { {0xe737005e, 0x6568002b, 0x644801c3, 0x00000000}},  //   _чет_, _tidh, _wydi,
  { {0x61e201b5, 0x3ea00022, 0x64483f81, 0x00000000}},  //   _vrol, _adit_, _tydi,
  { {0x4034004c, 0xb3e90025, 0xd1b700a1, 0x00000000}},  //   тенс, _يعمل_, وایا_,
  { {0x61e202e1, 0xbebb00bb, 0x7b03010e, 0x00000000}},  //   _trol, ciël, _jõut,
  { {0x7afd00b9, 0xc3330104, 0x2d99009d, 0x00000000}},  //   _rost, _גוף_, usse_,
  { {0x7afd0198, 0xd24f0054, 0x3ea00038, 0x00000000}},  //   _sost, _انه_, _edit_,
  { {0xf0930104, 0x2bc83f82, 0x6456006b, 0x00000000}},  //   _ענק_, нуто_, əyic,
  { {0xa3e1006e, 0x7b03006c, 0x00000000, 0x00000000}},  //   दित_, _nõut,   ,
  { {0x7afd059a, 0xe29f000c, 0x9f5f0010, 0x00000000}},  // [f6b0] _vost, óði_, sztó_,
  { {0x6d4500e7, 0x7c3800fa, 0x656f0068, 0x00000000}},  //   _ukha, çarã, _échi,
  { {0x281506c6, 0x7afd11e8, 0x56950057, 0x00000000}},  //   خواس, _tost, вает,
  { {0x7afd3f83, 0x31b90173, 0x00000000, 0x00000000}},  //   _uost, yèz_,   ,
  { {0xdb1e00fa, 0xdb07013e, 0x2d8001c3, 0x00000000}},  //   _espó, nují, _xtie_,
  { {0xf99201f8, 0x387a0061, 0xfaff0007, 0x00000000}},  //   _דרך_, ccpr_, _hoë_,
  { {0xdce50059, 0xdb0700b9, 0x291101d6, 0x00000000}},  //   _nihč, hují, _ilza_,
  { {0xdb07013e, 0x00000000, 0x00000000, 0x00000000}},  //   kují,   ,   ,
  { {0x26cf0036, 0x61e40051, 0xbebb0112, 0x00000000}},  //   mego_, _áill, riël,
  { {0x26cf081d, 0x600926f5, 0xdb0700b9, 0x00000000}},  //   lego_, дном_, dují,
  { {0x2d803f84, 0x7b03006c, 0x61ed0006, 0x00000000}},  //   _stie_, _jõus, _šald,
  { {0xe2900054, 0x26cf0046, 0x8af0006b, 0x00000000}},  //   _هذه_, nego_, rmək,
  { {0xe0ce0265, 0xc332009b, 0xeab200a1, 0x00000000}},  //   _кв_, _דוא_, یٹس_,
  { {0xa3b5007d, 0x628900b5, 0x26cf00fa, 0x00000000}},  //   _जमा_, lbeo, hego_,
  { {0x7b03006c, 0xad9b0010, 0xfaff01c3, 0x00000000}},  //   _nõus, nyúj, _boë_,
  { {0x26cf0046, 0x3f853f85, 0x628900d9, 0x00000000}},  //   jego_, mplu_, nbeo,
  { {0x26cf1cc7, 0xdb07013e, 0x00000000, 0x00000000}},  // [f6c0] dego_, cují,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xd9450025, 0x3f850032, 0x00000000, 0x00000000}},  //   ائقي, nplu_,   ,
  { {0x6d4e02e1, 0xd7ef0025, 0xc6a3004c, 0x00000000}},  //   llba, تكم_, арши,
  { {0xdb1e0046, 0xe7690644, 0x6d4e130a, 0x00000000}},  //   _wspó, رحمن_, olba,
  { {0xfaff0116, 0x00000000, 0x00000000, 0x00000000}},  //   _zoë_,   ,   ,
  { {0x25ee03d7, 0xdb0700b9, 0x9423003b, 0x00000000}},  //   _आपकी_, zují, имље,
  { {0x26cf0046, 0x61d801e0, 0x6d4e01a2, 0x00000000}},  //   cego_, емия_, hlba,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb0700b9, 0x70ac0061, 0x00000000, 0x00000000}},  //   vují, चलेल,   ,
  { {0xd00701b3, 0xf651026c, 0xb4ae0309, 0x00000000}},  //   веќе_, _نئے_, कली_,
  { {0xb226007c, 0x61ed0c8a, 0x6d4e0c4c, 0x00000000}},  //   _имел, _šale, elba,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xed58008b, 0x26cf23dd, 0x25f50061, 0x00000000}},  //   коў_, zego_, ्हती_,
  { {0x212b1e83, 0x26cf0058, 0xac19003b, 0x00000000}},  //   èche_, yego_, хову_,
  { {0xdb1c1259, 0xdb0700b9, 0x6d4e0168, 0x00000000}},  //   ntrè, pují, alba,
  { {0xaa5500ed, 0xba5500ed, 0x61e404eb, 0x00000000}},  // [f6d0] уваш, увај, _šilj,
  { {0x26cf0046, 0x2bab013d, 0x00000000, 0x00000000}},  //   wego_, _छिपा,   ,
  { {0x3d0803d7, 0x26cf0046, 0x00000000, 0x00000000}},  //   _सकते_, tego_,   ,
  { {0x59f9005e, 0x98ba0089, 0x00000000, 0x00000000}},  //   _земя_, ropā_,   ,
  { {0x26cf3f86, 0xdb1e000c, 0xe610023c, 0x00000000}},  //   rego_, _uppá, يشه_,
  { {0xe795089d, 0x7b030004, 0x26cf3f87, 0x00000000}},  //   _مارک, _tõus, sego_,
  { {0xe787025f, 0xf8b200b3, 0x27f700a1, 0x00000000}},  //   _југо, _לשם_, _جہاد_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc692009b, 0x60c104a5, 0xb1450534, 0x00000000}},  //   _לאן_, tflm, лнил,
  { {0x28c6006e, 0x00000000, 0x00000000, 0x00000000}},  //   र्पि,   ,   ,
  { {0xb447007e, 0x7aef0068, 0x00000000, 0x00000000}},  //   _рэак, _onct,   ,
  { {0x7b0a0802, 0xe37a0049, 0x25790173, 0x00000000}},  //   _výuk, _טרער, _kèl_,
  { {0xdb1c0023, 0xe29f000c, 0xa0c50014, 0x00000000}},  //   strë, óðu_, _ميشو,
  { {0x9d560070, 0x25790173, 0x00000000, 0x00000000}},  //   انست, _mèl_,   ,
  { {0xf99f0263, 0xfaa6007e, 0xc0c8003b, 0x00000000}},  //   _avè_, лаво, _јуче_,
  { {0x28c6007d, 0x00000000, 0x00000000, 0x00000000}},  //   र्नि,   ,   ,
  { {0xdb1c00f4, 0x7f3b0049, 0x387f0477, 0x00000000}},  // [f6e0] ntré, _רעפו, _şura_,
  { {0x7aef0009, 0xe9d700a5, 0x61e603b1, 0x00000000}},  //   _enct, ыку_, åkli,
  { {0xa686012b, 0x66e6003b, 0x80b80044, 0x00000000}},  //   глед, ложа, _অসম্,
  { {0x25790263, 0x5ea60044, 0xb4dc013d, 0x00000000}},  //   _bèl_, গ্রে, _तोड़_,
  { {0x6a9b00a0, 0x257900d4, 0x00000000, 0x00000000}},  //   _אשכנ, _cèl_,   ,
  { {0xb4ae0164, 0xbf100061, 0x6ab632a5, 0x00000000}},  //   कले_, ासुन_, lgyf,
  { {0xa3f20044, 0x00000000, 0x00000000, 0x00000000}},  //   জন্য_,   ,   ,
  { {0x6ab60016, 0xdced006b, 0x25790173, 0x00000000}},  //   ngyf, _otağ, _fèl_,
  { {0xc4ca005e, 0x2579000a, 0x80cd0044, 0x00000000}},  //   _плаж_, _gèl_, ়যন্,
  { {0x6456006b, 0x7ddb00f8, 0x00000000, 0x00000000}},  //   əyin, _läså,   ,
  { {0xbf10001c, 0x5ede0044, 0x58f70049, 0x00000000}},  //   ासून_, যানে, אמיע_,
  { {0xa3e1007d, 0x41e60688, 0xe29a00e2, 0x00000000}},  //   दिर_, _مستف, _чад_,
  { {0x3fc80123, 0xe29b0049, 0x00000000, 0x00000000}},  //   ردگی_, _טשאר,   ,
  { {0x61db019b, 0x28c60309, 0x307601fc, 0x00000000}},  //   _נקוד, र्मि, _судс,
  { {0x9405005f, 0xc5e4009e, 0x00000000, 0x00000000}},  //   _belə_, _کۓ_,   ,
  { {0xd5d401f5, 0x00000000, 0x00000000, 0x00000000}},  //   _धनंज,   ,   ,
  { {0x3f9e3f88, 0xaa7b000c, 0x00000000, 0x00000000}},  // [f6f0] lstu_, _snýs,   ,
  { {0xd257009b, 0x257901aa, 0x0a681662, 0x00000000}},  //   רשמה_, _rèl_, урси_,
  { {0x25790263, 0x6d470006, 0xccf2009b, 0x00000000}},  //   _sèl_, moja, _וכי_,
  { {0x6d4701c5, 0x3f9e00b0, 0xbd8802fd, 0x00000000}},  //   loja, istu_, _جنین_,
  { {0xdb07009f, 0x4a9a0049, 0xaa9a009b, 0x00000000}},  //   stjó, _בירג, _בברכ,
  { {0x3f9e001e, 0x6d470dec, 0x290f0089, 0x00000000}},  //   kstu_, noja, īgas_,
  { {0x99920046, 0xd7e40451, 0x36d53f89, 0x00000000}},  //   czył_, _літо, _ковр,
  { {0x2903000b, 0x25793f8a, 0xdc0f013e, 0x00000000}},  //   _hoja_, _tèl_, _něče,
  { {0x29030119, 0x6d470550, 0xf4d900e3, 0x00000000}},  //   _koja_, koja, _имаш_,
  { {0x672b0a61, 0xbfc500ed, 0x6445006c, 0x00000000}},  //   ligj, абок, ühis,
  { {0x2903000b, 0x6d4717dc, 0xdb1c00f4, 0x00000000}},  //   _moja_, doja, stré,
  { {0x290302d5, 0xf3b60049, 0x00000000, 0x00000000}},  //   _loja_, _כּדי_,   ,
  { {0x4cdf0044, 0x6d47008e, 0x6b850048, 0x00000000}},  //   মানু, foja, _athg,
  { {0x6d470550, 0xed5a003b, 0x8af0006b, 0x00000000}},  //   goja, тог_, hmət,
  { {0xfc030264, 0xab2a0088, 0x5ecb0044, 0x00000000}},  //   опро, вова_, িয়ে,
  { {0x672b008d, 0x25a00209, 0x2d9601e0, 0x00000000}},  //   jigj, šili_, _крос,
  { {0x8af0005f, 0xcb6700aa, 0x6d471288, 0x00000000}},  // [f700] dmət, рате_, boja,
  { {0x236f0065, 0x2903004a, 0x98a60081, 0x00000000}},  //   _ligj_, _coja_, риже,
  { {0x29030065, 0x00000000, 0x00000000, 0x00000000}},  //   _doja_,   ,   ,
  { {0xeab205d4, 0x6f0412aa, 0x99920036, 0x00000000}},  //   _بعد_, _joic, rzył_,
  { {0x25a00051, 0x45d6005e, 0x6f040036, 0x00000000}},  //   éil_, рцет, _moic,
  { {0xdc190036, 0x29030023, 0xa4d405b8, 0x00000000}},  //   _włąc, _goja_, сокі,
  { {0x6f160039, 0xf8c601f5, 0xa50700ec, 0x00000000}},  //   _olyc, र्णय, реја_,
  { {0x25a9073a, 0x6d473f8b, 0x6f040035, 0x00000000}},  //   šala_, zoja, _noic,
  { {0x8af03f8c, 0x7d01009f, 0x6d470020, 0x00000000}},  //   lməs, ölsk, yoja,
  { {0x30a30088, 0x506618ea, 0xdce50035, 0x00000000}},  //   орюв, итна, _mihă,
  { {0x6d470089, 0x8af0006b, 0x3f9e00b9, 0x00000000}},  //   voja, nməs, ustu_,
  { {0x3f9e000c, 0x6f040b17, 0x645a0089, 0x00000000}},  //   rstu_, _coic, _izti,
  { {0x6d47010a, 0x6f040051, 0x2ee030ea, 0x00000000}},  //   toja, _doic, _daif_,
  { {0x6d470006, 0x4c94030d, 0x40940025, 0x00000000}},  //   uoja, жирс, _الثر,
  { {0x8af0005f, 0x6d472f0e, 0x29030779, 0x00000000}},  //   ymət, roja, _roja_,
  { {0x290300c4, 0x5b140077, 0x200f01ca, 0x00000000}},  //   _soja_, омст, íliš_,
  { {0x212c0051, 0x2903010e, 0x00000000, 0x00000000}},  // [f710] oidh_, _poja_,   ,
  { {0x6cd50167, 0x7c3e0026, 0x645a0288, 0x00000000}},  //   _اقدا, _fxpr, _ozti,
  { {0x672b3f8d, 0x00000000, 0x00000000, 0x00000000}},  //   tigj,   ,   ,
  { {0x63670010, 0x35f50451, 0x7d05012d, 0x00000000}},  //   _tűni, йпер, _hohs,
  { {0x8af0006b, 0x672b0023, 0x7c3b0276, 0x00000000}},  //   rmət, rigj, ğuru,
  { {0x69dd002b, 0x28c6006e, 0x212c0023, 0x00000000}},  //   _isse, र्दि, jidh_,
  { {0x7d05041d, 0xdb0e0374, 0x629b323a, 0x00000000}},  //   _mohs, ttbø, tauo,
  { {0x7d050240, 0x8af0006b, 0x5c38009b, 0x00000000}},  //   _lohs, lmər, ירון_,
  { {0x443e01aa, 0x212c002a, 0x67293f8e, 0x00000000}},  //   _ext_, fidh_, _imej,
  { {0x6f040051, 0x2ee0254e, 0xdb0705e0, 0x00000000}},  //   _soic, _saif_, lujä,
  { {0x6f040207, 0xf77000a1, 0x2011134a, 0x00000000}},  //   _poic, _راہ_, ázi_,
  { {0x6d5e008d, 0x212c002a, 0x69dd0207, 0x00000000}},  //   _shpa, aidh_, _osse,
  { {0x6d5e0061, 0xd0e20061, 0x6f04028a, 0x00000000}},  //   _phpa, _कोकण_, _voic,
  { {0x3079007b, 0x332d01d5, 0xd5fa00b3, 0x00000000}},  //   _גאַנ, liex_, אפשר,
  { {0x67290059, 0x8af0006b, 0xb09a0104, 0x00000000}},  //   _omej, yləd, _עיקר,
  { {0x62990263, 0x673b1aa8, 0x9f483f8f, 0x00000000}},  //   _jewo, _njuj, _orné_,
  { {0xdb07010e, 0x6299000a, 0x00000000, 0x00000000}},  // [f720] dujä, _mewo,   ,
  { {0x67290020, 0x332d002b, 0x8af0006b, 0x00000000}},  //   _amej, hiex_, tməs,
  { {0x69dd051b, 0x409a0049, 0x309a0049, 0x00000000}},  //   _esse, רבעס, רשעמ,
  { {0x7bde2ec8, 0x37ab025a, 0x63ae0030, 0x00000000}},  //   _ispu, ائلی_, _åbni,
  { {0xa50a014c, 0xdb1c3f90, 0x673b012d, 0x00000000}},  //   леда_, ntrí, _djuj,
  { {0x7ae4022b, 0x69c40d90, 0xe0c70025, 0x00000000}},  //   ldit, mtie, _عز_,
  { {0x6299023d, 0x3a200061, 0xd90d00a1, 0x00000000}},  //   _bewo, lzip_, _جیل_,
  { {0x69c401d6, 0x52140242, 0x61eb0087, 0x00000000}},  //   otie, ждит, _brgl,
  { {0x629901aa, 0x80dc0044, 0x3a20010f, 0x00000000}},  //   _dewo, বাস্, nzip_,
  { {0x443e001c, 0x69c40006, 0xf8d8013d, 0x00000000}},  //   _txt_, itie, ड़िय,
  { {0x32ca03c8, 0x332d01d5, 0x212c0051, 0x00000000}},  //   _было_, biex_, ridh_,
  { {0x62992295, 0x69c43f91, 0x61e40006, 0x00000000}},  //   _gewo, ktie, _šilu,
  { {0x7ae40207, 0x5fda0061, 0x201e0010, 0x00000000}},  //   ddit, _बनवल, szti_,
  { {0x80dc0044, 0x7e763f92, 0x7ae4017b, 0x00000000}},  //   বাহ্, _egyp, edit,
  { {0xb7b30044, 0x69c40089, 0xac18019d, 0x00000000}},  //   _ঘন্ট, etie, бору_,
  { {0x69c41bec, 0xd1380fed, 0x7bde1ba1, 0x00000000}},  //   ftie, lną_, _dspu,
  { {0x69c401c5, 0x6f1d0048, 0x00000000, 0x00000000}},  // [f730] gtie, mhsc,   ,
  { {0x67291457, 0xd1380036, 0x7ae4010e, 0x00000000}},  //   _smej, nną_, adit,
  { {0x69c40168, 0x47d506dd, 0xb901013d, 0x00000000}},  //   atie, تيار, _दस_,
  { {0x69c4002b, 0x7b2c006b, 0x00000000, 0x00000000}},  //   btie, nşul,   ,
  { {0xd24600a2, 0x69c402ae, 0xf7700151, 0x00000000}},  //   _آن_, ctie, رام_,
  { {0x25a90059, 0xd1380036, 0x332d002b, 0x00000000}},  //   šalo_, jną_, wiex_,
  { {0xd1380036, 0x67290066, 0x62990173, 0x00000000}},  //   dną_, _tmej, _pewo,
  { {0x67293f93, 0x176807e1, 0x13090152, 0x00000000}},  //   _umej, _груп_, рний_,
  { {0x65940147, 0xdb1c00c4, 0x2d8900f6, 0x00000000}},  //   _нату, ltrã, _ntae_,
  { {0x3ea93f94, 0x61eb00ca, 0x00000000, 0x00000000}},  //   _adat_, _vrgl,   ,
  { {0x69c4022b, 0x61e43f95, 0x629901aa, 0x00000000}},  //   ztie, _šilt, _tewo,
  { {0xd1380036, 0x657b3f96, 0xd5a70088, 0x00000000}},  //   aną_, _kuuh, _вiдп,
  { {0x69c401d5, 0x7d1c0009, 0x657b00ea, 0x00000000}},  //   xtie, thrs, _juuh,
  { {0x3f6600f4, 0x3ea90129, 0x7ae4002b, 0x00000000}},  //   _cœur_, _edat_, wdit,
  { {0x61e9021e, 0x3a9a007c, 0x00000000, 0x00000000}},  //   lvel, итаю_,   ,
  { {0x6f1d010f, 0xa3ea006e, 0xf3eb0044, 0x00000000}},  //   chsc, मित_, _কথার_,
  { {0xfce62415, 0x7ae41c28, 0x69c401c5, 0x00000000}},  // [f740] _допо, rdit, utie,
  { {0xe8f701f9, 0x3a200009, 0x7ae43f97, 0x00000000}},  //   олу_, rzip_, sdit,
  { {0x7bde0091, 0x28c6007d, 0x00000000, 0x00000000}},  //   _uspu, र्षि,   ,
  { {0x69c40211, 0x61e91dcd, 0xd1380036, 0x00000000}},  //   ptie, kvel, zną_,
  { {0x2ba80061, 0xbebb0065, 0xd1380fed, 0x00000000}},  //   गळवा, shëg, yną_,
  { {0xb7da00a1, 0x28c6007d, 0x61e90010, 0x00000000}},  //   _پورا_, र्शि, dvel,
  { {0x61e900bb, 0x00000000, 0x00000000, 0x00000000}},  //   evel,   ,   ,
  { {0xf1a60373, 0xe73a005e, 0xd1380036, 0x00000000}},  //   орон, _теб_, wną_,
  { {0xd1380036, 0x61e9000c, 0xd13a0364, 0x00000000}},  //   tną_, gvel, ихо_,
  { {0x4fc6007c, 0x00000000, 0x00000000, 0x00000000}},  //   осма,   ,   ,
  { {0x6f1d0051, 0x61e9060c, 0xd1380fed, 0x00000000}},  //   thsc, avel, rną_,
  { {0xd1380036, 0x3f66009d, 0xd12f0bb6, 0x00000000}},  //   sną_, _sœur_, _یمن_,
  { {0x224b010f, 0x63750006, 0x63b80161, 0x00000000}},  //   ückt_, _išna, luvn,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc04f02f0, 0x2a70006b, 0x3ea90087, 0x00000000}},  //   _ці_, ənbə_, _tdat_,
  { {0x798d01aa, 0x00000000, 0x00000000, 0x00000000}},  //   tpaw,   ,   ,
  { {0xbebb01c3, 0x00000000, 0x00000000, 0x00000000}},  // [f750] biër,   ,   ,
  { {0x2907000c, 0x657b0052, 0x00000000, 0x00000000}},  //   ðna_, _ruuh,   ,
  { {0x61e90089, 0x5ede0044, 0xbf780082, 0x00000000}},  //   zvel, যারে, _đuợc_,
  { {0x5ead0044, 0x63b8003b, 0x80ca01f5, 0x00000000}},  //   ট্রে, duvn, त्ते,
  { {0xd618006d, 0xbafa009b, 0x8afa009b, 0x00000000}},  //   يتها_, _ההרש, _הפרק,
  { {0x03950242, 0x2db8009b, 0xb97a009b, 0x00000000}},  //   прия, קלון_, _לנשי,
  { {0x7bc73f98, 0x8ccd013d, 0xdb070027, 0x00000000}},  //   ntju, द्यो, dujú,
  { {0x11d90054, 0xd3d80025, 0x25b0014a, 0x00000000}},  //   موعة_, تبها_, üllü_,
  { {0xdb1c002a, 0x00000000, 0x00000000, 0x00000000}},  //   ntrá,   ,   ,
  { {0x44b41d68, 0xf485009e, 0x00000000, 0x00000000}},  //   _обус, _رائی,   ,
  { {0xdee600ed, 0x59dd01f5, 0x777c004a, 0x00000000}},  //   пони, _नैसर, _xurx,
  { {0xd2510025, 0xba3b01d6, 0x224b01a2, 0x00000000}},  //   _كنا_, _geïg, ücks_,
  { {0xee370088, 0x5ede0044, 0x00000000, 0x00000000}},  //   зня_, যালে,   ,
  { {0x3f770035, 0xc0e501ab, 0x00000000, 0x00000000}},  //   _băut_, _хокк,   ,
  { {0xeb970256, 0xbebb0328, 0x00000000, 0x00000000}},  //   зис_, riër,   ,
  { {0xbebb01d6, 0x00000000, 0x00000000, 0x00000000}},  //   siër,   ,   ,
  { {0x61ed3002, 0x3b0705f6, 0xbebb00c1, 0x00000000}},  // [f760] _šalj, чето_, piër,
  { {0x3ea200d9, 0x00000000, 0x00000000, 0x00000000}},  //   lakt_,   ,   ,
  { {0x6d4e0022, 0x00000000, 0x00000000, 0x00000000}},  //   moba,   ,   ,
  { {0x6d4e0091, 0xd048006b, 0x940c006b, 0x00000000}},  //   loba, gedə, _gedə_,
  { {0x5fdd013d, 0x7ae600f8, 0x00000000, 0x00000000}},  //   _फैसल, _iakt,   ,
  { {0x6d4e0247, 0x3ea2373b, 0x00000000, 0x00000000}},  //   noba, hakt_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x66e3058f, 0xa6b5007c, 0x7ae60039, 0x00000000}},  //   _поса, _осущ, _jakt,
  { {0x7ae60056, 0x6d4e3f99, 0xcad70097, 0x00000000}},  //   _makt, koba, לוקת_,
  { {0xf55a0025, 0x28cf0164, 0x290a00eb, 0x00000000}},  //   _الطب_, स्पि, _joba_,
  { {0x6d4e0036, 0x25a60058, 0x7ae600f8, 0x00000000}},  //   doba, lsol_, _oakt,
  { {0x3f8a001e, 0x7ae60ebc, 0xc7b300b6, 0x00000000}},  //   ību_, _nakt, עבר_,
  { {0x25a6014a, 0x6d4e19d5, 0xdced01f3, 0x00000000}},  //   nsol_, foba, _jwaħ,
  { {0x60180265, 0x6d4e005b, 0x61e2051b, 0x00000000}},  //   _моля_, goba, _isol,
  { {0x2a790022, 0x60da013f, 0xb5fd00ca, 0x00000000}},  //   _pgsb_, metm, _izše,
  { {0x7ae60065, 0x60da014a, 0xe7f0007d, 0x00000000}},  //   _cakt, letm, घटना_,
  { {0x7ae62ecb, 0x6d4e10ae, 0x7bc700f8, 0x00000000}},  // [f770] _dakt, boba, stju,
  { {0x290a0762, 0x60da014a, 0x7ae600ea, 0x00000000}},  //   _coba_, netm, _eakt,
  { {0xdb1c3f9a, 0x290a01ca, 0x8af0006b, 0x00000000}},  //   strá, _doba_, mlən,
  { {0x8af0013f, 0x00000000, 0x00000000, 0x00000000}},  //   llən,   ,   ,
  { {0x84e52015, 0xa5093370, 0x60da0095, 0x00000000}},  //   долж, жела_, ketm,
  { {0x290a00ca, 0x3ea200bb, 0x8af0006b, 0x00000000}},  //   _goba_, zakt_, nlən,
  { {0x67d41dac, 0xa3d2025f, 0x7ae60095, 0x00000000}},  //   _пору, војч, _yakt,
  { {0x68e70209, 0x6d4e1658, 0x63a80022, 0x00000000}},  //   _hajd, zoba, _dvdn,
  { {0xc245004c, 0x6d4e0020, 0x8af0006b, 0x00000000}},  //   ьник, yoba, klən,
  { {0x80bd0061, 0x6d4e0032, 0x68e70066, 0x00000000}},  //   _शाळे, xoba, _jajd,
  { {0x68e73f9b, 0x3ea2000c, 0x932700a1, 0x00000000}},  //   _majd, takt_, _ٹران,
  { {0x6d4e0173, 0x61e20066, 0x6fbf0061, 0x00000000}},  //   woba, _fsol, लंबू,
  { {0x6d4e3f9c, 0x7ae60429, 0x8af0006b, 0x00000000}},  //   toba, _rakt, flən,
  { {0x7ae60065, 0x3ea200ea, 0xdd8f0025, 0x00000000}},  //   _sakt, sakt_, شوف_,
  { {0x6d4e050a, 0x290a0129, 0x7ae60065, 0x00000000}},  //   roba, _roba_, _pakt,
  { {0xc05200b6, 0x8f9a00b3, 0x290a0340, 0x00000000}},  //   _שזה_, _ויקי, _soba_,
  { {0x7ae63f9d, 0xc332009b, 0x68e71087, 0x00000000}},  // [f780] _vakt, דון_, _bajd,
  { {0x7ae60149, 0x8af0006b, 0x3ea009cb, 0x00000000}},  //   _wakt, clən, _heit_,
  { {0x3ce70316, 0x7ae60027, 0x46ea1e4d, 0x00000000}},  //   _छोटे_, _takt, жден_,
  { {0xe737003b, 0x3a3f25f3, 0x60da0792, 0x00000000}},  //   мех_, _župe_, zetm,
  { {0xa5da06dd, 0x056a06e3, 0xd6e00044, 0x00000000}},  //   تبار_, ојки_, ণালয,
  { {0xa3ea03d7, 0x3ea0009f, 0xa507003b, 0x00000000}},  //   मिल_, _leit_, деља_,
  { {0x25a60a06, 0xdb1c0030, 0x61e20066, 0x00000000}},  //   ssol_, rtræ, _ssol,
  { {0x8af0006b, 0xdb1c158f, 0x25a60d48, 0x00000000}},  //   zlən, stræ, psol_,
  { {0xdb1c0afc, 0x672200e7, 0x00000000, 0x00000000}},  //   mträ, mhoj,   ,
  { {0xdb1c04ce, 0x6aa40020, 0x00000000, 0x00000000}},  //   lträ, haif,   ,
  { {0x20183f9e, 0x60da011f, 0x3ea001e5, 0x00000000}},  //   ári_, retm, _beit_,
  { {0xdb1c2683, 0x7d1e0059, 0x2018002b, 0x00000000}},  //   nträ, _alps, ġri_,
  { {0x8af0006b, 0xdb1c01a2, 0x2d800035, 0x00000000}},  //   tlən, iträ, _cuie_,
  { {0x2d8001d6, 0x00000000, 0x00000000, 0x00000000}},  //   _duie_,   ,   ,
  { {0x3ea000c7, 0x8af0006b, 0x68e700b4, 0x00000000}},  //   _feit_, rlən, _rajd,
  { {0x61ed010a, 0x25a900ee, 0x09d80044, 0x00000000}},  //   _šali, šali_, সিনা,
  { {0xf1bc0044, 0x67220065, 0x2ee906ed, 0x00000000}},  // [f790] _অনুভ, dhoj, _iaaf_,
  { {0x3ea0001f, 0x80dc0044, 0x8af0006b, 0x00000000}},  //   _zeit_, বাক্, lləl,
  { {0x68e73f9f, 0xdb1c01a2, 0x63651465, 0x00000000}},  //   _vajd, fträ, lóne,
  { {0x19950147, 0x6f0d001a, 0x81d50044, 0x00000000}},  //   _памя, _joac, হিত_,
  { {0x25a92dc6, 0x2ee904cb, 0x68e70022, 0x00000000}},  //   éal_, _maaf_, _tajd,
  { {0x6f0d062c, 0x23660161, 0x2edc013d, 0x00000000}},  //   _loac, _ahoj_, _बस्त,
  { {0xc7c41ef9, 0x3f8e00d9, 0x3f7e01f3, 0x00000000}},  //   _исти, _ntfu_, _uċuh_,
  { {0x645f006b, 0x67220020, 0xc2c50025, 0x00000000}},  //   əqil, choj, ريخي,
  { {0xe1f10318, 0x26dd0263, 0x28cf02f4, 0x00000000}},  //   اسب_, mewo_, स्थि,
  { {0x3ea0001f, 0x2d8001c3, 0xdb1c00f8, 0x00000000}},  //   _seit_, _ruie_, mtrå,
  { {0x6f0d00fa, 0x2d8000e5, 0x00000000, 0x00000000}},  //   _boac, _suie_,   ,
  { {0x28cf006e, 0x2ee90026, 0xe1f109b9, 0x00000000}},  //   स्ति, _caaf_, _مست_,
  { {0x3ea0021a, 0x2d80004a, 0x78a50052, 0x00000000}},  //   _veit_, _quie_, kahv,
  { {0x3ea0010f, 0xc0e2025f, 0x81d50044, 0x00000000}},  //   _weit_, _бошк, হিদ_,
  { {0x6aa4000b, 0x8c43034b, 0x6c360025, 0x00000000}},  //   taif, гере, رفرا,
  { {0x8af0006b, 0x62890048, 0x2ee90112, 0x00000000}},  //   lməz, nceo, _gaaf_,
  { {0xe9d70404, 0x6aa41b88, 0x6df30025, 0x00000000}},  // [f7a0] нкт_, raif, _مكيا,
  { {0xebe60581, 0x30bd0044, 0xdb1c032e, 0x00000000}},  //   _зооп, _অসুস, dtrå,
  { {0xdb1c04ce, 0xdc9b00a0, 0x67220023, 0x00000000}},  //   tträ, _מייל, thoj,
  { {0xe5c60057, 0xf8b000a1, 0x6602002d, 0x00000000}},  //   еско, _چکا_, txok,
  { {0xdb1c03a9, 0xceb30104, 0x8af0006b, 0x00000000}},  //   rträ, ריד_, nləm,
  { {0x53e601be, 0xdb1c3fa0, 0x67220065, 0x00000000}},  //   ециа, strä, shoj,
  { {0xd9430256, 0xbebb0065, 0xdb1c0039, 0x00000000}},  //   _сери, dhën, pträ,
  { {0xdb1c0023, 0x8af0006b, 0x6d5c01a2, 0x00000000}},  //   durë, kləm, hlra,
  { {0x2ee9046a, 0x2b400035, 0xa3ac013d, 0x00000000}},  //   _raaf_, inic_, _कटक_,
  { {0x2b400899, 0x6f0d001a, 0x00000000, 0x00000000}},  //   hnic_, _soac,   ,
  { {0x44380901, 0x6e9504b5, 0xdb1c0023, 0x00000000}},  //   _är_, кину, gurë,
  { {0x2b403804, 0x00000000, 0x00000000, 0x00000000}},  //   jnic_,   ,   ,
  { {0xe3370049, 0x657a3fa1, 0x67d3013e, 0x00000000}},  //   _אראפ_, _kith, mějš,
  { {0x6365008e, 0x6456006b, 0x7e640079, 0x00000000}},  //   róne, əyir, _dzip,
  { {0x8af0005f, 0x657a010f, 0x602600f4, 0x00000000}},  //   lməy, _mith, _démé,
  { {0x67d30224, 0x657a0273, 0x645a1238, 0x00000000}},  //   nějš, _lith, _myti,
  { {0x7b64007c, 0x645a0006, 0x8af0006b, 0x00000000}},  // [f7b0] утре, _lyti, nməy,
  { {0xb4df0061, 0x63b80626, 0x657a0051, 0x00000000}},  //   _तसे_, krvn, _nith,
  { {0x645a0541, 0x81d60044, 0xe8df0011, 0x00000000}},  //   _nyti, াটি_, _ngục_,
  { {0xf770004b, 0x2b400129, 0x657a002a, 0x00000000}},  //   مان_, cnic_, _aith,
  { {0x7aed001a, 0x657a0051, 0x645a000a, 0x00000000}},  //   mdat, _bith, _ayti,
  { {0x7aed0004, 0x81d60055, 0xbc380014, 0x00000000}},  //   ldat, াটা_, _آسیا_,
  { {0x7aed001a, 0x69cd20d9, 0x8af0006b, 0x00000000}},  //   odat, ltae, zləm,
  { {0xf99f0263, 0x657a3339, 0x527505f6, 0x00000000}},  //   _kwè_, _eith, купу,
  { {0xf99f01aa, 0x69cd00b0, 0x7aed00d4, 0x00000000}},  //   _jwè_, ntae, idat,
  { {0x657a0ea9, 0x7aed00b0, 0xdb1c0065, 0x00000000}},  //   _gith, hdat, turë,
  { {0x7afd00c7, 0x69cd0934, 0x28c6006e, 0x00000000}},  //   _onst, htae, र्टि,
  { {0xa2950088, 0x657a00d9, 0xfaff0065, 0x00000000}},  //   _раді, _zith, _shën_,
  { {0xf7720452, 0xd00e00a6, 0x2b4000ca, 0x00000000}},  //   יקט_, ملی_, vnic_,
  { {0x7afd0002, 0x7aed00d9, 0xdbdc000c, 0x00000000}},  //   _anst, edat, _báða,
  { {0x2b400059, 0xdca3012c, 0xf99f000a, 0x00000000}},  //   tnic_, раси, _awè_,
  { {0xf99f01aa, 0x7aed011c, 0x3a3f016e, 0x00000000}},  //   _bwè_, gdat, _župa_,
  { {0x2b40001a, 0x1ce700a1, 0x8ff700a1, 0x00000000}},  // [f7c0] rnic_, رکیٹ_, _آرڈر_,
  { {0x7afd099e, 0x2b400d2e, 0xa92300e2, 0x00000000}},  //   _enst, snic_, адул,
  { {0x7aed0035, 0x657a3fa2, 0x25ad0da9, 0x00000000}},  //   bdat, _rith, _avel_,
  { {0x645a0dc6, 0x7bce03cc, 0x752101a2, 0x00000000}},  //   _ryti, mtbu, _allz,
  { {0x67d30224, 0xd707005e, 0x00000000, 0x00000000}},  //   vějš, ънце_,   ,
  { {0xd9460256, 0x5ede0044, 0x00000000, 0x00000000}},  //   _реги, যাটে,   ,
  { {0x7bce2a1a, 0x657a002f, 0x67d300b9, 0x00000000}},  //   ntbu, _vith, tějš,
  { {0x657a0038, 0x645a3fa3, 0x8af0006b, 0x00000000}},  //   _with, _vyti, tməy,
  { {0x80bd0061, 0x657a0122, 0xdb1c0068, 0x00000000}},  //   _शाखे, _tith, guré,
  { {0x8af0005f, 0x657a00c7, 0x7bce0066, 0x00000000}},  //   rməy, _uith, ktbu,
  { {0x61ed1d37, 0x7aed0036, 0x9406023c, 0x00000000}},  //   _šalt, ydat, _جواه,
  { {0x612401aa, 0x7aed00bb, 0xdbdc000c, 0x00000000}},  //   _sòld, xdat, _ráða,
  { {0xa3ea007d, 0xa3de013d, 0x7aed04eb, 0x00000000}},  //   मिक_, दौर_, vdat,
  { {0xc27b0476, 0xba3b00c7, 0x7aed2b6e, 0x00000000}},  //   _חרדי, _beïn, wdat,
  { {0xd1380a3d, 0x00000000, 0x00000000, 0x00000000}},  //   mią_,   ,   ,
  { {0xc8c6006e, 0x69cd00b0, 0x2bb80025, 0x00000000}},  //   र्घट, ttae, ضافة_,
  { {0x7aed04b8, 0x28a7007c, 0x58d505f6, 0x00000000}},  // [f7d0] rdat, вшег, лоат,
  { {0x69cd002d, 0xd1380fed, 0x7d1c0288, 0x00000000}},  //   rtae, nią_, ckrs,
  { {0x7aed067e, 0x6d550059, 0xba3b0250, 0x00000000}},  //   pdat, moza, _geïn,
  { {0x6d550107, 0x7afd03a1, 0x69cd0048, 0x00000000}},  //   loza, _unst, ptae,
  { {0xd1380006, 0x6365000c, 0x00000000, 0x00000000}},  //   kią_, jóna,   ,
  { {0x044506e1, 0xd4690545, 0xdb07004a, 0x00000000}},  //   лелн, ниле_, pujó,
  { {0x888200a6, 0x00000000, 0x00000000, 0x00000000}},  //   _ایمن,   ,   ,
  { {0x22400e00, 0xdb1c3820, 0x6d550232, 0x00000000}},  //   _žika_, turé, hoza,
  { {0x78b2000c, 0x6d550010, 0x3f5900c4, 0x00000000}},  //   _ákvö, koza, héus_,
  { {0x600926f0, 0xbebb0023, 0x6f1d00bb, 0x00000000}},  //   еном_, shël, eksc,
  { {0xbea60216, 0x3ea601e0, 0xdb1c00f4, 0x00000000}},  //   ланк, линг, suré,
  { {0x51f50084, 0x2911004a, 0x3f910089, 0x00000000}},  //   _مستر, _loza_, īzu_,
  { {0x2d8400f4, 0xd1381f00, 0xef17007c, 0x00000000}},  //   ême_, bią_, умя_,
  { {0x6d55202b, 0xfaff0065, 0xc6360049, 0x00000000}},  //   goza, _anë_, אָלק_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3b603d7, 0x7d1c05fa, 0xba3b0129, 0x00000000}},  //   _जिस_, skrs, _veïn,
  { {0x7bce0b38, 0x29113fa4, 0x00000000, 0x00000000}},  // [f7e0] stbu, _boza_,   ,
  { {0x28cf007d, 0x8ca5013d, 0x6d55004a, 0x00000000}},  //   स्लि, करणो, coza,
  { {0x79963fa5, 0x29110035, 0x9b460b03, 0x00000000}},  //   spyw, _doza_, _مندو,
  { {0x79960640, 0x00000000, 0x00000000, 0x00000000}},  //   ppyw,   ,   ,
  { {0x35b6022a, 0x36360054, 0x753801ee, 0x00000000}},  //   ущес, دراس, tivz,
  { {0x2cb33fa6, 0x29111150, 0xb5fd00ca, 0x00000000}},  //   _xdxd_, _goza_, _izšl,
  { {0xfaff0065, 0xd4990088, 0x287507d0, 0x00000000}},  //   _ynë_, трі_, _вытр,
  { {0xdc08001e, 0xd1380036, 0x79860020, 0x00000000}},  //   dēļa, wią_, _kukw,
  { {0x79860020, 0x6d553fa7, 0x8646003b, 0x00000000}},  //   _jukw, yoza, _снаж,
  { {0x8af0006b, 0x79860dfc, 0x6aa602e1, 0x00000000}},  //   sləh, _mukw, _lekf,
  { {0xd1380a67, 0x39570104, 0x798600e7, 0x00000000}},  //   rią_, רשים_, _lukw,
  { {0x68ee016a, 0xd24f007a, 0xd1380aec, 0x00000000}},  //   _labd, _کنه_, sią_,
  { {0x62822b63, 0x6d55016c, 0x835300a1, 0x00000000}},  //   _igoo, toza, _اپنا,
  { {0xceb4005f, 0x2eed00ca, 0xdfec013d, 0x00000000}},  //   _edə_, žef_, _जनपद_,
  { {0x6d550047, 0xdc21002b, 0x6aa601c3, 0x00000000}},  //   roza, _iċċe, _bekf,
  { {0xab62005d, 0x9b580242, 0x6d55002d, 0x00000000}},  //   şünc, гист_, soza,
  { {0x29113fa8, 0xba3b0116, 0xbebb0023, 0x00000000}},  // [f7f0] _poza_, _geïl, rkëd,
  { {0x68ee3fa9, 0x79860009, 0x3f5900fa, 0x00000000}},  //   _cabd, _dukw, péus_,
  { {0x1a65007a, 0x2911057c, 0x7aee00b0, 0x00000000}},  //   _چیزی_, _voza_, öntä,
  { {0xfaff008d, 0xef1f0676, 0x36d500ed, 0x00000000}},  //   _unë_, nkü_, родр,
  { {0x660501a4, 0x79860009, 0x3f66009d, 0x00000000}},  //   рпла, _gukw, _vœux_,
  { {0x661900b4, 0x6282017b, 0x63650048, 0x00000000}},  //   rywk, _agoo, gónn,
  { {0x5eab0044, 0x63410089, 0x6d400068, 0x00000000}},  //   _কানে, lēni, émai,
  { {0xdc2101d5, 0x11d90025, 0x7aef004a, 0x00000000}},  //   _aċċe, نوعة_, _jact,
  { {0x8627008b, 0x629b010a, 0x1306007c, 0x00000000}},  //   _сьве, rbuo, рный_,
  { {0x7aef0f6a, 0xdb1c0190, 0x62820045, 0x00000000}},  //   _lact, strø, _egoo,
  { {0x5f061aea, 0x80a70044, 0x634800b9, 0x00000000}},  //   азна, _খাদ্, měnn,
  { {0x539a009b, 0x25a0001a, 0xdc2101d5, 0x00000000}},  //   _ייעו, ţile_, _eċċe,
  { {0xe3c70044, 0x78b50340, 0x00000000, 0x00000000}},  //   _শনিব, _odzv,   ,
  { {0x78a70224, 0x4087025f, 0xc24401e1, 0x00000000}},  //   _nejv, _судб, _унік,
  { {0xbb560025, 0x7aef00ab, 0x68ee2c4c, 0x00000000}},  //   لنسب, _bact, _rabd,
  { {0x7aef001c, 0x68ee003f, 0x798601c3, 0x00000000}},  //   _cact, _sabd, _pukw,

  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [f800]   ,   ,   ,
  { {0x3f870066, 0x63750006, 0xba3b0328, 0x00000000}},  //   _kunu_, _išnu, _geïm,
  { {0x7aef0038, 0x3f870521, 0x2ba5006e, 0x00000000}},  //   _fact, _junu_, गीदा,
  { {0x3f87000c, 0x7a2c009d, 0x7bde002b, 0x00000000}},  //   _munu_, _côté, _ippu,
  { {0x7ae43faa, 0x55060893, 0x1a9b0049, 0x00000000}},  //   meit, ичка, _ביכע,
  { {0x7ae4010f, 0xb796003b, 0x2240012d, 0x00000000}},  //   leit, _враћ, _žiko_,
  { {0x66e602e9, 0xb226000c, 0x69c40de1, 0x00000000}},  //   _кова, kvæð, luie,
  { {0xb02400ad, 0x7ae400b0, 0xdb1c0023, 0x00000000}},  //   _ngườ, neit, drrë,
  { {0x69c43fab, 0x00000000, 0x00000000, 0x00000000}},  //   nuie,   ,   ,
  { {0x3f8701f6, 0x7ae4001f, 0x7bde0207, 0x00000000}},  //   _bunu_, heit, _oppu,
  { {0x7ae43fac, 0x61eb04bd, 0xe3b200a1, 0x00000000}},  //   keit, _esgl, _ذرا_,
  { {0xe29a012b, 0x7ae41329, 0x69c42572, 0x00000000}},  //   _рад_, jeit, kuie,
  { {0x7bde1017, 0x3eab0038, 0x7ae40016, 0x00000000}},  //   _appu, ract_, deit,
  { {0x2d9902c2, 0x69c40cea, 0x7c8400c0, 0x00000000}},  //   rpse_, duie, жуте,
  { {0x7ae43fad, 0x7aef0129, 0x06bc0055, 0x00000000}},  //   feit, _pact, _ইউনি,
  { {0xbb28007e, 0x7ae4002d, 0x307b00b3, 0x00000000}},  //   ацуе_, geit, _באונ,
  { {0x69c40219, 0x7bde0207, 0x7aef00d9, 0x00000000}},  // [f810] guie, _eppu, _vact,
  { {0x3ea900ab, 0x3cf10009, 0x00000000, 0x00000000}},  //   _heat_, qdzv_,   ,
  { {0x7ae412dc, 0xf8071606, 0x6d470091, 0x00000000}},  //   beit, шчан, mnja,
  { {0x7ae40181, 0x14c9001c, 0x69c40035, 0x00000000}},  //   ceit, _राहण, buie,
  { {0x8af0006b, 0x69c4001a, 0x3ea900ab, 0x00000000}},  //   tləv, cuie, _meat_,
  { {0x3ea9002a, 0x63653fae, 0xcd980097, 0x00000000}},  //   _leat_, tóno, סדות_,
  { {0xd7c9007a, 0x6d4701c3, 0x2d8100ca, 0x00000000}},  //   _حوزه_, inja, _mihe_,
  { {0x68e500b0, 0x6aad29fc, 0x27fc0190, 0x00000000}},  //   lehd, naaf, ævne_,
  { {0x6d471531, 0x00000000, 0x00000000, 0x00000000}},  //   knja,   ,   ,
  { {0x7ae4010f, 0x8af0006b, 0x6aad00bb, 0x00000000}},  //   zeit, llət, haaf,
  { {0x3ea903ca, 0x6d470825, 0x14190025, 0x00000000}},  //   _beat_, dnja, _حياة_,
  { {0x2d81021e, 0x643a0049, 0xdb1c06c2, 0x00000000}},  //   _aihe_, _געענ, turí,
  { {0x7ae43a14, 0x3209005d, 0x2d810009, 0x00000000}},  //   veit, _çay_, _bihe_,
  { {0x40950054, 0x7ae43687, 0xb226000c, 0x00000000}},  //   _الغر, weit, svæð,
  { {0x7ae4046a, 0xab2a012b, 0x61e901a2, 0x00000000}},  //   teit, гова_, lwel,
  { {0x69c43faf, 0x6d472911, 0x2903016e, 0x00000000}},  //   tuie, anja, _anja_,
  { {0x6f040c1f, 0x7ae407e6, 0x61e9010f, 0x00000000}},  // [f820] _inic, reit, nwel,
  { {0x7ae4001f, 0x6d4705fa, 0x2d810061, 0x00000000}},  //   seit, cnja, _gihe_,
  { {0x61e90abe, 0x7ae4002d, 0x7bde006c, 0x00000000}},  //   hwel, peit, _uppu,
  { {0x61e93fb0, 0x6f16009d, 0x69c4009d, 0x00000000}},  //   kwel, _joyc, puie,
  { {0x69c40219, 0x6f041d48, 0xdbe3000c, 0x00000000}},  //   quie, _mnic, _héða,
  { {0x61e90ace, 0x25690051, 0x6f160288, 0x00000000}},  //   dwel, túla_, _loyc,
  { {0x6f04060c, 0x63a40166, 0x61e901c3, 0x00000000}},  //   _onic, ćino, ewel,
  { {0x070c007d, 0xfbd3009b, 0x61e90016, 0x00000000}},  //   _सचिव_, פתח_, fwel,
  { {0x44200089, 0x8af0006b, 0x61e90016, 0x00000000}},  //   ņi_, lləs, gwel,
  { {0x80d30061, 0x672211e8, 0x644f0036, 0x00000000}},  //   ब्ले, lkoj, _ście,
  { {0x6d470746, 0xb5fd01ca, 0xdb1c09c8, 0x00000000}},  //   vnja, _vyše, ntró,
  { {0x0dcb09da, 0x395a0190, 0x67220997, 0x00000000}},  //   луги_, hops_, nkoj,
  { {0x60c8001c, 0xe28700a6, 0x6d470295, 0x00000000}},  //   pgdm, _اطمی, tnja,
  { {0x30390014, 0x672225b9, 0x6f040583, 0x00000000}},  //   اتیک_, hkoj, _enic,
  { {0x6d4710ec, 0x3ea90b3d, 0xc2eb0044, 0x00000000}},  //   rnja, _teat_, কারি_,
  { {0x6d47037e, 0x213e005b, 0x6124000a, 0x00000000}},  //   snja, lith_, _kòlo,
  { {0x8af0005f, 0x5939008b, 0xa2d001f5, 0x00000000}},  // [f830] vlət, азаў_, _धान्,
  { {0x6d4000f4, 0x213e04c1, 0x7e6d002d, 0x00000000}},  //   émat, nith_, _izap,
  { {0x61e9210e, 0x6124000a, 0x201e007f, 0x00000000}},  //   zwel, _lòlo, nyti_,
  { {0x959902be, 0xcf930049, 0x61e90016, 0x00000000}},  //   атку_, לטע_, ywel,
  { {0x7bd50032, 0xd5bb3fb1, 0x61e90322, 0x00000000}},  //   ltzu, усе_, xwel,
  { {0x201e010a, 0x395a00d9, 0x03950ae0, 0x00000000}},  //   kyti_, cops_, ория,
  { {0xdb1c0819, 0x7bd5022b, 0x8af0005f, 0x00000000}},  //   ctró, ntzu, mlər,
  { {0x8af0005f, 0x201e010a, 0xb06500b0, 0x00000000}},  //   llər, dyti_, hdää,
  { {0xe6130025, 0x7bc701a3, 0x61e900b5, 0x00000000}},  //   _عشر_, huju, uwel,
  { {0x61e9063c, 0x8af0005f, 0x7bc7006c, 0x00000000}},  //   rwel, nlər, kuju,
  { {0xa0690113, 0x61e90678, 0xdf4a0ae0, 0x00000000}},  //   рана_, swel, изод_,
  { {0x61e90066, 0x7bc70b4a, 0x213e005b, 0x00000000}},  //   pwel, duju, aith_,
  { {0x8af0005f, 0x9267007a, 0x7d1704b3, 0x00000000}},  //   klər, _ادام, _boxs,
  { {0xdb1c014a, 0x7e6d012d, 0x23dd007d, 0x00000000}},  //   strü, _dzap, _महाद,
  { {0x8af0005f, 0x67290ce2, 0x30790049, 0x00000000}},  //   dlər, _olej, _דאַנ,
  { {0x2b4900f4, 0x6f04051b, 0xff5202fd, 0x00000000}},  //   gnac_, _unic, _تخت_,
  { {0x395a0bd3, 0x8af0006b, 0xdb1c1db2, 0x00000000}},  // [f840] tops_, flər, gurá,
  { {0x672907ed, 0xd91000a6, 0x9d46109f, 0x00000000}},  //   _alej, ریز_, _феод,
  { {0x395a01d6, 0x7bc70ebe, 0x6d5c3fb2, 0x00000000}},  //   rops_, cuju, mora,
  { {0xd6d90088, 0x395a0022, 0xa026003c, 0x00000000}},  //   йті_, sops_, ltöö,
  { {0x67220065, 0x8af0005f, 0x7d17006b, 0x00000000}},  //   rkoj, blər, _yoxs,
  { {0xdb1c04bd, 0x7af6010a, 0x67290010, 0x00000000}},  //   ctrò, ldyt, _elej,
  { {0x612400f6, 0x67290cb8, 0x6d5c0032, 0x00000000}},  //   _dòll, _flej, iora,
  { {0x291806c2, 0x6d5c0016, 0x213e0016, 0x00000000}},  //   _hora_, hora, with_,
  { {0xb06500b0, 0x69d63bb7, 0x7bc70ec4, 0x00000000}},  //   ydää, ntye, zuju,
  { {0x6d5c0f6a, 0x201e010a, 0x7af600b0, 0x00000000}},  //   jora, tyti_, hdyt,
  { {0x6d5c0489, 0x291801d9, 0x27fa2b0c, 0x00000000}},  //   dora, _mora_, nvpn_,
  { {0x8af0005f, 0x201e010a, 0x69d60173, 0x00000000}},  //   zlər, ryti_, ktye,
  { {0x6d5c0016, 0x8af0006b, 0x7bc7027e, 0x00000000}},  //   fora, ylər, wuju,
  { {0x6d5c002d, 0x7bc70169, 0x2918065c, 0x00000000}},  //   gora, tuju, _nora_,
  { {0x8af0005f, 0x2aab003b, 0xe9ff0082, 0x00000000}},  //   vlər, итао_, _biếc_,
  { {0x7bc701a3, 0x7bd52920, 0x3f9e1cf6, 0x00000000}},  //   ruju, rtzu, mptu_,
  { {0x8af0005f, 0x2918000b, 0x6d5c0b25, 0x00000000}},  // [f850] tlər, _bora_, bora,
  { {0x29180035, 0x6d5c20e4, 0xc867005e, 0x00000000}},  //   _cora_, cora, отеи,
  { {0x8af0005f, 0x67293dae, 0x29180065, 0x00000000}},  //   rlər, _plej, _dora_,
  { {0xf77006dd, 0xd366007a, 0x8af0006b, 0x00000000}},  //   نان_, _سه_, slər,
  { {0xd24606ea, 0x291809f7, 0xfa9600a3, 0x00000000}},  //   _أن_, _fora_, _מדרש_,
  { {0xd00606ea, 0x29183fb3, 0x63650285, 0x00000000}},  //   _كل_, _gora_, móni,
  { {0x61e2191c, 0x63651238, 0x00000000, 0x00000000}},  //   _apol, lóni,   ,
  { {0x6d5c1091, 0x673b0009, 0x13090088, 0x00000000}},  //   zora, _umuj, сний_,
  { {0x6d5c3fb4, 0x68f50a32, 0x63653fb5, 0x00000000}},  //   yora, _kazd, nóni,
  { {0x68f50620, 0x2cb10871, 0x81dc0044, 0x00000000}},  //   _jazd, jazd_, ডিং_,
  { {0x6d5c0198, 0x7af600b0, 0x7f5d00f6, 0x00000000}},  //   vora, ydyt, fosq,
  { {0xd34304e1, 0xbebb0065, 0x68f5008f, 0x00000000}},  //   _تفصی, dhës, _lazd,
  { {0x6365000c, 0x425400e2, 0x00000000, 0x00000000}},  //   jóni, _отшт,   ,
  { {0x68f50253, 0xa037016c, 0x6365077b, 0x00000000}},  //   _nazd, _šćuć, dóni,
  { {0x6d5c1cc4, 0xf09200b6, 0xfaa601ee, 0x00000000}},  //   rora, _אנו_, забо,
  { {0x63650841, 0x6d5c0211, 0xa026042b, 0x00000000}},  //   fóni, sora, stöö,
  { {0x6d5c020c, 0x61fb00b5, 0x29183fb6, 0x00000000}},  // [f860] pora, nvul, _pora_,
  { {0x0e5701f8, 0x38c800a6, 0x69d60052, 0x00000000}},  //   _משפט_, تاری_, rtye,
  { {0xe9ff0011, 0x29180129, 0x69d60052, 0x00000000}},  //   _tiếc_, _vora_, stye,
  { {0x7bc1016c, 0x00000000, 0x00000000, 0x00000000}},  //   šluc,   ,   ,
  { {0x29181962, 0x62860006, 0x61fb1fed, 0x00000000}},  //   _tora_, žkok, jvul,
  { {0x68f50047, 0x644f0036, 0x634800b9, 0x00000000}},  //   _gazd, _ścia, měni,
  { {0x61e20428, 0x69c401c5, 0x00000000, 0x00000000}},  //   _spol, lrie,   ,
  { {0xe73a005e, 0xdb24009d, 0x68f500b4, 0x00000000}},  //   _уеб_, érès, _zazd,
  { {0x68f5047f, 0x057603ab, 0x5eab0044, 0x00000000}},  //   _yazd, _فائد, _কালে,
  { {0x859b00b6, 0x3a370104, 0x7d1a0039, 0x00000000}},  //   _לשמו, פרים_, ötsl,
  { {0x69c4001f, 0xbebb0065, 0x63ad016c, 0x00000000}},  //   hrie, dhër, ćanc,
  { {0x69c4125c, 0xc178007f, 0x612d0048, 0x00000000}},  //   krie, smė_, _cúlb,
  { {0xc333009b, 0xada4007e, 0x61e20a6e, 0x00000000}},  //   _אוף_, наўл, _upol,
  { {0x14df03d7, 0xc16f01fb, 0x69c41617, 0x00000000}},  //   प्पण, _її_, drie,
  { {0x68f50ed8, 0x69c4190c, 0x60db009b, 0x00000000}},  //   _razd, erie, _הקונ,
  { {0x69c4010f, 0xae9b0054, 0x63650181, 0x00000000}},  //   frie, _اضغط_, tóni,
  { {0x69c4001e, 0x2395001e, 0x68f53fb7, 0x00000000}},  // [f870] grie, _māja_, _pazd,
  { {0x63650819, 0x9e670014, 0x00000000, 0x00000000}},  //   róni, _واکن,   ,
  { {0x290701f6, 0x68f505fa, 0x69c40f30, 0x00000000}},  //   ına_, _vazd, arie,
  { {0x69c4049b, 0xcfae0044, 0xfaa500a6, 0x00000000}},  //   brie, _কমান, _تجدی,
  { {0xa3cf001c, 0xb8d30055, 0x69c413ba, 0x00000000}},  //   वून_, _টা_, crie,
  { {0x85e80088, 0xf99200a3, 0xba3b00f6, 0x00000000}},  //   ядів_, _ברך_, _deït,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xf77301ef, 0x61240173, 0x00000000, 0x00000000}},  //   _ساز_, _fòlk,   ,
  { {0x4cb30055, 0x201800b0, 0xdb240010, 0x00000000}},  //   _জানু, ärin_, érés,
  { {0x61fb0168, 0x70c70061, 0x00000000, 0x00000000}},  //   rvul, ललेल,   ,
  { {0xceea3fb8, 0x69c40027, 0x00000000, 0x00000000}},  //   одне_, zrie,   ,
  { {0xe28e03f3, 0xd5d10201, 0x26cf27bd, 0x00000000}},  //   _ја_, _समाज, nggo_,
  { {0xee3716c1, 0xc332009b, 0x612d0048, 0x00000000}},  //   дня_, _בוא_, _cúlc,
  { {0x69c4028c, 0xd00e00a1, 0x00000000, 0x00000000}},  //   vrie, _چلو_,   ,
  { {0x69c41ecf, 0xeb970256, 0x00000000, 0x00000000}},  //   wrie, дис_,   ,
  { {0x69c403a1, 0x61ed0006, 0xbebb0065, 0x00000000}},  //   trie, _šaly, shër,
  { {0xaa43091b, 0xf2d20049, 0x798700b5, 0x00000000}},  // [f880] ветл, כען_, _bijw,
  { {0x69c40238, 0x6d8b0089, 0x14d20061, 0x00000000}},  //   rrie, _pļav, _साधण,
  { {0x28dd013d, 0x69c4245c, 0x00000000, 0x00000000}},  //   न्धि, srie,   ,
  { {0x69c4001e, 0x6fc50061, 0x9f5d0f6c, 0x00000000}},  //   prie, _विनं, _prvé_,
  { {0x6d4e00bb, 0xf99f00f6, 0xba3b01c3, 0x00000000}},  //   onba, _crèd_, _deïs,
  { {0x6d4e2a1e, 0x62990173, 0x00000000, 0x00000000}},  //   nnba, _afwo,   ,
  { {0x6d4e01a2, 0x00000000, 0x00000000, 0x00000000}},  //   inba,   ,   ,
  { {0x05000044, 0x6d4e01a2, 0xba3b0112, 0x00000000}},  //   ্সের_, hnba, _geïs,
  { {0xa3ba0204, 0x6365000c, 0x966300a8, 0x00000000}},  //   _अटक_, jónu, _акте,
  { {0xb5fd01ca, 0xe506023c, 0xd1300318, 0x00000000}},  //   _myšl, _تبري, امد_,
  { {0xe29a007e, 0x00000000, 0x00000000, 0x00000000}},  //   _дае_,   ,   ,
  { {0x6d4e1ae5, 0x2240016c, 0x42261f70, 0x00000000}},  //   enba, _žiku_, _одев,
  { {0xde6402dc, 0x00000000, 0x00000000, 0x00000000}},  //   върп,   ,   ,
  { {0xdb150010, 0x6d4e06ec, 0x00000000, 0x00000000}},  //   mszé, gnba,   ,
  { {0xd30f0011, 0x1bd42bda, 0x212b0068, 0x00000000}},  //   _mệnh_, коря, êche_,
  { {0x290a0263, 0xd30f0011, 0xa3cf0309, 0x00000000}},  //   _anba_, _lệnh_, वंत_,
  { {0x49750269, 0xfb8400a5, 0x6d8b01c5, 0x00000000}},  // [f890] елас, тырн, _pļau,
  { {0x612400f6, 0xe6a7006e, 0x00000000, 0x00000000}},  //   _bòli, खर्ज,   ,
  { {0xe610007a, 0x00000000, 0x00000000, 0x00000000}},  //   یشه_,   ,   ,
  { {0x7c2801e3, 0x63650048, 0x00000000, 0x00000000}},  //   ødre, nónt,   ,
  { {0xd30f001d, 0x612400d4, 0x3f89007f, 0x00000000}},  //   _bệnh_, _eòli, _miau_,
  { {0x7aed0051, 0x29350049, 0x67d5003b, 0x00000000}},  //   leat, _טאָן_, _погу,
  { {0xf8b20097, 0xba3b0328, 0xf7700014, 0x00000000}},  //   _תשל_, _geïr, _چاق_,
  { {0xdb1c0039, 0x7aed0585, 0xae0f0316, 0x00000000}},  //   strö, neat, ामान_,
  { {0x6d4e1bf4, 0xa2d0007d, 0x00000000, 0x00000000}},  //   ynba, _धार्,   ,
  { {0x7aed01a2, 0xb6cc019a, 0x63ba0288, 0x00000000}},  //   heat, _çürü, _fvtn,
  { {0x7aed0315, 0xd0093fb9, 0xa2d70061, 0x00000000}},  //   keat, чене_, _याप्,
  { {0xdb1c00f4, 0xf99f01aa, 0x25ad040f, 0x00000000}},  //   ntrô, _otè_, _kwel_,
  { {0x7aed002d, 0x00000000, 0x00000000, 0x00000000}},  //   deat,   ,   ,
  { {0xdd8f03d9, 0x823400f3, 0xf99f0173, 0x00000000}},  //   صوف_, _جرما, _orèb_,
  { {0x6d4e01e3, 0xf99f01aa, 0x69c20061, 0x00000000}},  //   rnba, _atè_, _लिही,
  { {0x7aed0035, 0x28dd007d, 0x3f890082, 0x00000000}},  //   geat, न्सि, _giau_,
  { {0xc33200a0, 0x6fc50204, 0x628601ca, 0x00000000}},  // [f8a0] און_, _विडं, žkov,
  { {0xf99f000a, 0x612400d4, 0xb5fd0161, 0x00000000}},  //   _dtè_, _pòli, _vyšl,
  { {0x7aed1b27, 0xacd70049, 0x6146009d, 0x00000000}},  //   beat, _אויפ_, _hélè,
  { {0x7bce0760, 0xbbe90167, 0xe9a602dc, 0x00000000}},  //   mubu, _کریم_, _памп,
  { {0x7d1e1263, 0x00000000, 0x00000000, 0x00000000}},  //   _kops,   ,   ,
  { {0x6603003b, 0x6ab60fd1, 0x7d1e0087, 0x00000000}},  //   упља, layf, _jops,
  { {0x7bce3fba, 0xe4a50088, 0xe8cc0061, 0x00000000}},  //   nubu, тріо, ालीच,
  { {0x7d1e139b, 0x2d92000a, 0xdb150010, 0x00000000}},  //   _lops, _ouye_, tszé,
  { {0x3202004f, 0x3f89023a, 0x7bce04cb, 0x00000000}},  //   íky_, _riau_, hubu,
  { {0x7bdc0fd6, 0x3f8900f6, 0xd4910082, 0x00000000}},  //   ktru, _siau_, _hàn_,
  { {0x39960018, 0x41c2024c, 0x64a3007c, 0x00000000}},  //   _læs_, _शिवस, _саха,
  { {0xe2920054, 0xd378016e, 0xceeb0025, 0x00000000}},  //   _إذا_, _opći_, أردن_,
  { {0x614600f4, 0x1603013d, 0x5ce70088, 0x00000000}},  //   _célè, लियर_, нюва,
  { {0x7d1e3fbb, 0x7bdc0a5e, 0x7bc700ca, 0x00000000}},  //   _cops, ftru, trju,
  { {0x81dc0055, 0x7aed03b6, 0xf4220044, 0x00000000}},  //   ডিও_, teat, _ভেতর_,
  { {0xdb070056, 0x00000000, 0x00000000, 0x00000000}},  //   nsjø,   ,   ,
  { {0xf9930879, 0x6f0d3fbc, 0x7aed038f, 0x00000000}},  // [f8b0] ابر_, _inac, reat,
  { {0x7bce011c, 0x7aed0032, 0x00000000, 0x00000000}},  //   bubu, seat,   ,
  { {0x6d473f5f, 0x7aed00ab, 0x6f0d09b0, 0x00000000}},  //   mija, peat, _knac,
  { {0xdcfe001a, 0x25ad000a, 0x00000000, 0x00000000}},  //   _tipă, _pwel_,   ,
  { {0xf7700188, 0x6f0d00e7, 0xdb0700ea, 0x00000000}},  //   حال_, _mnac, dsjø,
  { {0x6d470ade, 0xcd98009b, 0xe4c20194, 0x00000000}},  //   nija, עדות_, айши,
  { {0x6f0d00d9, 0xdce40089, 0x63ad11af, 0x00000000}},  //   _onac, _etiķ, ćano,
  { {0x4905001c, 0xd5ac009e, 0x00000000, 0x00000000}},  //   _होतो_, _کہو_,   ,
  { {0xc69200b6, 0x659508fd, 0x6d470639, 0x00000000}},  //   _כאן_, _разу, kija,
  { {0x6f0d2d1b, 0x7bdc02d4, 0x00000000, 0x00000000}},  //   _anac, ytru,   ,
  { {0x7bdc219f, 0x656300c4, 0xbea6007e, 0x00000000}},  //   xtru, monh, канк,
  { {0x7d1e003b, 0x44270016, 0x7bce0045, 0x00000000}},  //   _sops, myn_, vubu,
  { {0x6d470089, 0x7d1e00b9, 0x733a0049, 0x00000000}},  //   fija, _pops, _קענס,
  { {0x6da300e3, 0x6d47006c, 0x7bce01a3, 0x00000000}},  //   рира, gija, tubu,
  { {0x442736ce, 0x7d1e001a, 0xdc6702dc, 0x00000000}},  //   nyn_, _vops, вард_,
  { {0x7bce28d4, 0x629b1746, 0xef26014a, 0x00000000}},  //   rubu, ncuo, çüde_,
  { {0x6d470d0f, 0xe9da1969, 0x7bce1ccf, 0x00000000}},  // [f8c0] bija, ька_, subu,
  { {0x6d47001e, 0x6f0d0821, 0x6ab6011f, 0x00000000}},  //   cija, _znac, sayf,
  { {0x2cb8009d, 0x8cd7013d, 0xfaff0023, 0x00000000}},  //   mard_, _बातो, _ikën_,
  { {0x4427018e, 0xe5c631ca, 0x2cb8009d, 0x00000000}},  //   dyn_, вско, lard_,
  { {0x2cb80009, 0x6124000a, 0x7ae900f6, 0x00000000}},  //   oard_, _kòlt, _ñeta,
  { {0x2cb800f4, 0x442733a1, 0xb9070044, 0x00000000}},  //   nard_, fyn_, _মো_,
  { {0xd9430920, 0x44270016, 0x612400f6, 0x00000000}},  //   _тери, gyn_, _mòlt,
  { {0x51f80057, 0x236d01d9, 0x2cb805c6, 0x00000000}},  //   ению_, glej_, hard_,
  { {0x68fc011f, 0x8755005e, 0x2cb800f8, 0x00000000}},  //   _kard, _сърц, kard_,
  { {0x68fc022b, 0x6f0d0039, 0x4427018e, 0x00000000}},  //   _jard, _snac, byn_,
  { {0x443803bd, 0x68fc00f4, 0x6d470213, 0x00000000}},  //   _år_, _mard, vija,
  { {0x645a006b, 0x6d471cc5, 0x68fc0095, 0x00000000}},  //   _ixti, wija, _lard,
  { {0xa2d703d7, 0x2cb83fbd, 0xb5fd0006, 0x00000000}},  //   _यात्, fard_, _ryšk,
  { {0x2cb80549, 0x8af0006b, 0xdb1c01a2, 0x00000000}},  //   gard_, hnəd, hrrä,
  { {0x6d470ade, 0xa5cc013d, 0x25690010, 0x00000000}},  //   rija, _समझौ, múlt_,
  { {0x68fc2686, 0x6d472f0e, 0x7f560065, 0x00000000}},  //   _aard, sija, _gjyq,
  { {0x68fc0046, 0x3eb93fbe, 0x27ea023a, 0x00000000}},  // [f8d0] _bard, mast_, _apbn_,
  { {0x66020190, 0x442700b0, 0xacf5003b, 0x00000000}},  //   dvok, yyn_, _спољ,
  { {0x68fc0065, 0x6d45002b, 0xdb150010, 0x00000000}},  //   _dard, _imha, lszí,
  { {0x3eb90bf3, 0xdbd10004, 0x855700a1, 0x00000000}},  //   nast_, _müüg, ھیار_,
  { {0x44272333, 0x68fc0a18, 0x2d9c0059, 0x00000000}},  //   wyn_, _fard, _čvek_,
  { {0x7afd3fbf, 0x44272d22, 0x3eb9006c, 0x00000000}},  //   _hast, tyn_, hast_,
  { {0xe299008b, 0x3eb93fc0, 0x656300c4, 0x00000000}},  //   най_, kast_, ronh,
  { {0x44270016, 0x3eb93fc1, 0x821900ed, 0x00000000}},  //   ryn_, jast_, ецот_,
  { {0x645a106f, 0x3eb93fc2, 0x44270056, 0x00000000}},  //   _exti, dast_, syn_,
  { {0x7afd253f, 0x6033006b, 0x629b0197, 0x00000000}},  //   _last, ləmə, scuo,
  { {0x3eb91a90, 0x5eab0055, 0x2cb800f4, 0x00000000}},  //   fast_, _কাজে, vard_,
  { {0x6d4506fb, 0x3eb93696, 0x7521010f, 0x00000000}},  //   _amha, gast_, _holz,
  { {0x2b490142, 0xc0e500e3, 0xd4910011, 0x00000000}},  //   diac_, _болк, _làm_,
  { {0x7afd061f, 0x6ed60164, 0x2cb818dc, 0x00000000}},  //   _aast, _भावु, uard_,
  { {0x75210087, 0x3eb9010e, 0xb7ce0044, 0x00000000}},  //   _molz, bast_, _রন্ট,
  { {0x68fc04b9, 0x7afd3e56, 0x765b005f, 0x00000000}},  //   _sard, _cast, _oxuy,
  { {0x68fc010a, 0x7afd3fc3, 0x6720121b, 0x00000000}},  // [f8e0] _pard, _dast, _romj,
  { {0x63ad0119, 0x68fc006b, 0x7afd3fc4, 0x00000000}},  //   ćanj, _qard, _east,
  { {0x68fc3fc5, 0x78b5000d, 0x8caa007d, 0x00000000}},  //   _vard, _dezv, _ज्यो,
  { {0x7afd0599, 0x25a60093, 0x8af0006b, 0x00000000}},  //   _gast, tpol_, yləy,
  { {0x68fc0325, 0x15d9026c, 0x75210207, 0x00000000}},  //   _tard, ندوں_, _bolz,
  { {0x25a6023a, 0x75213fc6, 0x7ae401a3, 0x00000000}},  //   rpol_, _colz, lfit,
  { {0xc61c0055, 0x25a63800, 0x7afd3fc7, 0x00000000}},  //   _দেখা_, spol_, _yast,
  { {0x7ae41003, 0x436700ec, 0x6136009d, 0x00000000}},  //   nfit, лајн_, _mâle,
  { {0x3eb9224a, 0x64a60780, 0x14d60167, 0x00000000}},  //   vast_, _база, _مزاح,
  { {0x20070087, 0x06bc0044, 0x752106f8, 0x00000000}},  //   _brni_, _ইউটি, _golz,
  { {0x25a40365, 0x04930054, 0x3eb92161, 0x00000000}},  //   _html_, _المح, tast_,
  { {0x7bc1016c, 0x6fc50061, 0x32060133, 0x00000000}},  //   šluk, _विरं, _troy_,
  { {0x3eb90004, 0x88cc0044, 0x8af0006b, 0x00000000}},  //   rast_, র্যক, qləy,
  { {0x798e0009, 0x31650009, 0x3eb93fc8, 0x00000000}},  //   _nibw, colz_, sast_,
  { {0x3eb900b5, 0x9f6b0131, 0x7ae40aba, 0x00000000}},  //   past_, _приз_, ffit,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x7afd08b2, 0x2b49064f, 0xa99700f3, 0x00000000}},  // [f8f0] _vast, riac_, اشرت,
  { {0x2b490027, 0x7afd0787, 0x29dd0026, 0x00000000}},  //   siac_, _wast, rìa_,
  { {0xe79600a1, 0x6033006b, 0x61e00009, 0x00000000}},  //   لانک, təmə, html,
  { {0x75210059, 0x7afd0051, 0x00000000, 0x00000000}},  //   _solz, _uast,   ,
  { {0xfad6007b, 0xeef8007b, 0x499300a1, 0x00000000}},  //   _דורך_, טמאר_, _طیار,
  { {0x69cd018e, 0xc7b70389, 0x6d553fc9, 0x00000000}},  //   mrae, _مصرع, nnza,
  { {0xc293026c, 0xc6a701fc, 0x752100d9, 0x00000000}},  //   میاب, _брзи, _volz,
  { {0x130902d3, 0x03250081, 0x00000000, 0x00000000}},  //   тний_, рдин,   ,
  { {0x651500a1, 0x798e0045, 0x00000000, 0x00000000}},  //   _پوائ, _yibw,   ,
  { {0x6009102a, 0x29013fca, 0x6609022b, 0x00000000}},  //   вном_, ndha_, _irek,
  { {0xb4c30164, 0xa2f50769, 0x032b0088, 0x00000000}},  //   ्ली_, _впеч, _підп_,
  { {0x66090089, 0x6d553fcb, 0x8e86005e, 0x00000000}},  //   _krek, enza, игне,
  { {0x471a009b, 0x6d8b002b, 0xe28e00e2, 0x00000000}},  //   דורג, _eżam, _фа_,
  { {0x69cd2333, 0x660909ef, 0x2007012d, 0x00000000}},  //   drae, _mrek, _trni_,
  { {0x20070e0d, 0x00000000, 0x00000000, 0x00000000}},  //   _urni_,   ,   ,
  { {0x69cd10af, 0x6d55008e, 0x660919e1, 0x00000000}},  //   frae, anza, _orek,
  { {0x7ae40065, 0x3946007e, 0x3ead004a, 0x00000000}},  // [f900] rfit, анаг, ñete_,
  { {0xf092007b, 0x78bb00f4, 0x3b00006b, 0x00000000}},  //   ַנד_, _œuvr, sdiq_,
  { {0x66090032, 0x98aa0035, 0x798e00e7, 0x00000000}},  //   _arek, _albă_, _vibw,
  { {0x66e60147, 0x66090635, 0x29110afb, 0x00000000}},  //   рода, _brek, _enza_,
  { {0x6b8401b5, 0x22a600b9, 0x395809af, 0x00000000}},  //   mmig, níků_, _tjrs_,
  { {0x6609000c, 0x03c6109e, 0x6b84010e, 0x00000000}},  //   _drek, асим, lmig,
  { {0xdb150010, 0xd4990088, 0x81d20044, 0x00000000}},  //   lszá, урі_, _হৈং_,
  { {0x6609009f, 0x6b840211, 0x80d80164, 0x00000000}},  //   _frek, nmig, _माहे,
  { {0x24f61fa3, 0x6609164d, 0xe5a300ed, 0x00000000}},  //   _вчер, _grek, _мити,
  { {0xf8b30049, 0x99b10044, 0x6b84010f, 0x00000000}},  //   ֿשר_, _চমৎক, hmig,
  { {0xb4d20201, 0x88cc0044, 0x00000000, 0x00000000}},  //   वली_, র্থক,   ,
  { {0x91e60751, 0xdb150010, 0x14170025, 0x00000000}},  //   _воде, kszá, _خيمة_,
  { {0x51f606b4, 0x9df83fcc, 0x7bce0270, 0x00000000}},  //   _خسار, анят_, erbu,
  { {0xa3b3007d, 0xc04600a1, 0x69cd321f, 0x00000000}},  //   जीव_, _پختو, vrae,
  { {0xb17b01ce, 0xf99f000a, 0x00000000, 0x00000000}},  //   _שטור, _erèl_,   ,
  { {0x69cd158a, 0x9e67026c, 0x4ea700ec, 0x00000000}},  //   trae, _پابن, _трка,
  { {0x63ad0166, 0x6ce701ff, 0xdb150010, 0x00000000}},  // [f910] ćani, _кіне, gszá,
  { {0x69cd018e, 0xf8070404, 0x66093fcd, 0x00000000}},  //   rrae, ичен, _rrek,
  { {0x69cd051c, 0x29011c75, 0x29880545, 0x00000000}},  //   srae, rdha_, рсто_,
  { {0xdb07000c, 0x69cd04a5, 0x7bd5005d, 0x00000000}},  //   rsjó, prae, muzu,
  { {0x66050057, 0xdb07000c, 0xaae60167, 0x00000000}},  //   спла, ssjó, _اسپو,
  { {0x637e0065, 0xb4c3007d, 0xdb1c008e, 0x00000000}},  //   hënd, ्ले_, buró,
  { {0x637e0023, 0x0394007e, 0x660900d9, 0x00000000}},  //   kënd, орыя, _wrek,
  { {0x66093fce, 0x612d11ea, 0xfc580104, 0x00000000}},  //   _trek, _túlk, יבוש_,
  { {0xe1f10025, 0x1306007c, 0x1634007c, 0x00000000}},  //   سسة_, сный_, _детя,
  { {0x23e701fb, 0x7bd51be0, 0x64a4003b, 0x00000000}},  //   _відв, kuzu, _мађа,
  { {0x612d0047, 0xe8df001d, 0x4049151c, 0x00000000}},  //   _júli, _ngọc_, упно_,
  { {0x22950054, 0x7bd5002d, 0x6d8b0066, 0x00000000}},  //   _الإس, duzu, _użaj,
  { {0x52850054, 0xf99f000a, 0x00000000, 0x00000000}},  //   _الشك, _brèm_,   ,
  { {0xdca30072, 0x7bd524f9, 0x6136001a, 0x00000000}},  //   зари, fuzu, _vâlc,
  { {0xd4910011, 0x201800b0, 0x7bd50032, 0x00000000}},  //   _bài_, ärit_, guzu,
  { {0x2b9c00b9, 0xdb150010, 0xbebb0023, 0x00000000}},  //   _víc_, tszá, skër,
  { {0x3b07005e, 0xf99f000a, 0x00000000, 0x00000000}},  // [f920] щето_, _frèm_,   ,
  { {0xdb150047, 0x7bd53fcf, 0x20181afa, 0x00000000}},  //   rszá, buzu, årig_,
  { {0xdb150010, 0xc6250044, 0x6d4e0142, 0x00000000}},  //   sszá, _মেলা_, miba,
  { {0x6d4e027c, 0x98b8005d, 0x00000000, 0x00000000}},  //   liba, ızın_,   ,
  { {0x80d80164, 0x23950089, 0x2cba0022, 0x00000000}},  //   _माले, _māju_, _kepd_,
  { {0x6d4e1163, 0xb4d2001c, 0xdb05009d, 0x00000000}},  //   niba, वले_, _athè,
  { {0x69d6008e, 0xa3180131, 0x29370049, 0x00000000}},  //   luye, ижку_, _פאלן_,
  { {0xe44f0054, 0x7af6009f, 0x6d4e011c, 0x00000000}},  //   عضو_, neyt, hiba,
  { {0x6d4e1577, 0x69d6038e, 0x94060014, 0x00000000}},  //   kiba, nuye, _گواه,
  { {0x6d4e2be4, 0x3b0200f6, 0x00000000, 0x00000000}},  //   jiba, _lakq_,   ,
  { {0x5eaa0055, 0x28dd013d, 0x6d4e07ef, 0x00000000}},  //   _কয়ে, न्टि, diba,
  { {0xe29a01f9, 0x3f800082, 0x6d4e0328, 0x00000000}},  //   _сад_, _chiu_, eiba,
  { {0x5186008b, 0x13ad0055, 0x637e008d, 0x00000000}},  //   _лука, _গিয়, rënd,
  { {0x6d4e0059, 0x7bd5002d, 0xab95003b, 0x00000000}},  //   giba, tuzu, жављ,
  { {0x2bd90061, 0xdfa60380, 0x7c3402dc, 0x00000000}},  //   बंधा, _احتي, перх,
  { {0x905700b3, 0xb06500b0, 0x637e0023, 0x00000000}},  //   _לסוף_, seää, qënd,
  { {0x7bd51bd8, 0x6d4e36dd, 0x69d60011, 0x00000000}},  // [f930] suzu, biba, guye,
  { {0x2be2013d, 0x127b0049, 0x27050011, 0x00000000}},  //   _पहचा, ראמע, _ồn_,
  { {0xd4910082, 0x60c70036, 0xaa9519ea, 0x00000000}},  //   _tài_, ójmi, _минч,
  { {0x69d6008e, 0x2d9b0065, 0x00000000, 0x00000000}},  //   buye, _kuqe_,   ,
  { {0x2cb20073, 0x35e701fb, 0xf77300a1, 0x00000000}},  //   _ändå_, сцев, _ہار_,
  { {0x2c8300f4, 0xa50901ee, 0x00000000, 0x00000000}},  //   cédé_, река_,   ,
  { {0xe3b2026c, 0xdb053fd0, 0x3ea200f8, 0x00000000}},  //   ورٹ_, _athé, yckt_,
  { {0x29032340, 0x6d4e006b, 0x644f0036, 0x00000000}},  //   _haja_, ziba, _ścis,
  { {0x6d4e0009, 0x612d0010, 0x00000000, 0x00000000}},  //   yiba, _múlv,   ,
  { {0x290302e0, 0x95570151, 0x3f800023, 0x00000000}},  //   _jaja_, _اخرا, _shiu_,
  { {0x3d1d007d, 0xe73000a1, 0x6d4e3fd1, 0x00000000}},  //   माने_, _غصہ_, viba,
  { {0x3f6a0931, 0x6d4e3fd2, 0x3e8a004d, 0x00000000}},  //   римо_, wiba, ийно_,
  { {0xc332009b, 0x5fc5006e, 0x7c2e0016, 0x00000000}},  //   _קוד_, _विकल, wybr,
  { {0x2903010f, 0x61fb1725, 0x69d60009, 0x00000000}},  //   _naja_, mwul, vuye,
  { {0x69cb0219, 0x6d4e3fd3, 0xfc0300ed, 0x00000000}},  //   ágen, riba, мпро,
  { {0x6d4e0006, 0xdb1c000c, 0x69d63fd4, 0x00000000}},  //   siba, gurð, tuye,
  { {0x29033026, 0x2d930601, 0x7af6000c, 0x00000000}},  // [f940] _baja_, _fixe_, reyt,
  { {0x38cb06c6, 0x29030211, 0x69d63fd5, 0x00000000}},  //   لامی_, _caja_, ruye,
  { {0x6f040066, 0xdb1c000c, 0xeb9a003b, 0x00000000}},  //   _kaic, burð, _њим_,
  { {0x69d6009d, 0x9411006b, 0xeab20025, 0x00000000}},  //   puye, _üzə_, _تعد_,
  { {0x6f04001a, 0x29031ae2, 0x442e0016, 0x00000000}},  //   _maic, _faja_, wyf_,
  { {0x6f0410d9, 0x69c4002b, 0x29030b2e, 0x00000000}},  //   _laic, msie, _gaja_,
  { {0x69c40007, 0x6f1617cf, 0x78bc0026, 0x00000000}},  //   lsie, _onyc, _ierv,
  { {0x44200119, 0x442e0343, 0x31c602d3, 0x00000000}},  //   ći_, ryf_, осов,
  { {0x69c41aef, 0x78bc0095, 0x290300e7, 0x00000000}},  //   nsie, _kerv, _yaja_,
  { {0x69c43fd6, 0x67221da2, 0x6f160284, 0x00000000}},  //   isie, ljoj, _anyc,
  { {0xa2e6012b, 0x78bc11a1, 0x6f043fd7, 0x00000000}},  //   _можд, _merv, _baic,
  { {0x69c4055f, 0x7528016c, 0x93fb009b, 0x00000000}},  //   ksie, _hodz, _כלבי,
  { {0xada4007e, 0x76420c97, 0x6f042139, 0x00000000}},  //   маўл, nzoy, _daic,
  { {0x3af50011, 0x2369183b, 0x00000000, 0x00000000}},  //   _ấp_, čaje_,   ,
  { {0x29030127, 0x69c40bd7, 0x6f041f74, 0x00000000}},  //   _raja_, esie, _faic,
  { {0x29030149, 0x31a001aa, 0x6d5e00f6, 0x00000000}},  //   _saja_, _kòz_, _ejpa,
  { {0x78bc0093, 0x67221c70, 0x2903008e, 0x00000000}},  // [f950] _berv, djoj, _paja_,
  { {0x48ab0888, 0x75280267, 0x26df0258, 0x00000000}},  //   ртам_, _nodz, _scuo_,
  { {0x78bc0030, 0x29033fd8, 0x69c43fd9, 0x00000000}},  //   _derv, _vaja_, asie,
  { {0x290306fe, 0x67220065, 0x753a002d, 0x00000000}},  //   _waja_, gjoj, _altz,
  { {0x78bc00c4, 0xa3dd0061, 0x29030145, 0x00000000}},  //   _ferv, थून_, _taja_,
  { {0x78bc000c, 0x75280036, 0x64a50c4e, 0x00000000}},  //   _gerv, _codz, чака,
  { {0x612d167d, 0x0edb0061, 0x7d0515df, 0x00000000}},  //   _múlt, _भांड, _mahs,
  { {0xdce7016c, 0xbfa30082, 0x799d3fda, 0x00000000}},  //   dojč, _diễ, _kusw,
  { {0xe4e70099, 0x4cd30044, 0x6f041965, 0x00000000}},  //   _міжн, দ্যু, _raic,
  { {0x75280046, 0x7d05002b, 0x799d0020, 0x00000000}},  //   _godz, _nahs, _musw,
  { {0x63ad0243, 0x6f040048, 0x6abd01c3, 0x00000000}},  //   ćans, _paic, _oesf,
  { {0x67290066, 0x75280006, 0xe3b00151, 0x00000000}},  //   _joej, _zodz, _شرم_,
  { {0x7d05014a, 0x799d0022, 0x6f0400c8, 0x00000000}},  //   _bahs, _nusw, _vaic,
  { {0xcfe9007a, 0x612d0051, 0x3f9c00e7, 0x00000000}},  //   _هفته_, _cúlt, _fuvu_,
  { {0x799d001f, 0x6f0401eb, 0x60c10173, 0x00000000}},  //   _ausw, _taic, malm,
  { {0x3f670265, 0x69c4095c, 0x799d0093, 0x00000000}},  //   _нищо_, tsie, _busw,
  { {0x6abd332a, 0x78bc2e92, 0x79953fdb, 0x00000000}},  // [f960] _desf, _perv, _bizw,
  { {0x01bd0055, 0x69c40007, 0x7aef001c, 0x00000000}},  //   _আমাদ, rsie, _ebct,
  { {0x75280046, 0x78bc049b, 0x28e20204, 0x00000000}},  //   _rodz, _verv, _पाठि,
  { {0x320f158d, 0xe61a0e85, 0x673b001a, 0x00000000}},  //   _orgy_, йде_, _cluj,
  { {0x78bc3fdc, 0x75280667, 0x60c10047, 0x00000000}},  //   _terv, _podz, kalm,
  { {0x3ae8026c, 0x994f005d, 0x60c1002b, 0x00000000}},  //   _ابھی_, müş_, jalm,
  { {0x8af0005f, 0x60c10047, 0x673b008e, 0x00000000}},  //   ynəl, dalm, _fluj,
  { {0xdce70091, 0x320f3663, 0x31a001aa, 0x00000000}},  //   vojč, _brgy_, _pòz_,
  { {0x2576007a, 0x3f9c016c, 0x60c10d16, 0x00000000}},  //   _فهرس, _suvu_, falm,
  { {0x60c10047, 0xe1ef0380, 0x64a300ed, 0x00000000}},  //   galm, اسي_, _зафа,
  { {0x64430046, 0x06e30055, 0x7d0501a3, 0x00000000}},  //   czni, _নোটি, _rahs,
  { {0x987b009b, 0x60c1006c, 0x6d5c00b0, 0x00000000}},  //   מריק, aalm, enra,
  { {0x60c127f5, 0x6abd1824, 0x0e3401ab, 0x00000000}},  //   balm, _resf, еняю,
  { {0x60c10e32, 0x799d24a8, 0x5ba70888, 0x00000000}},  //   calm, _rusw, зраз,
  { {0x961d0089, 0x799d1164, 0x3e850089, 0x00000000}},  //   _izņe, _susw, _sūtī_,
  { {0x799501c3, 0x905b009b, 0x2b400048, 0x00000000}},  //   _sizw, _לכות, ghic_,
  { {0x433b0049, 0x78a50190, 0x7d050b2b, 0x00000000}},  // [f970] צעמב, tchv, _tahs,
  { {0x673b001a, 0x67290022, 0x9cf5007e, 0x00000000}},  //   _sluj, _soej, _ўзні,
  { {0x673b0129, 0x78a50b3a, 0x6abd0190, 0x00000000}},  //   _pluj, rchv, _tesf,
  { {0xf770023c, 0x6d8b002b, 0x06751280, 0x00000000}},  //   هان_, _eżat, муля,
  { {0x7aed1f4c, 0xc1780006, 0x7bc70dbf, 0x00000000}},  //   mfat, klė_, lsju,
  { {0x7aed0133, 0x00000000, 0x00000000, 0x00000000}},  //   lfat,   ,   ,
  { {0x60c103b6, 0x7bc700f8, 0x6729046a, 0x00000000}},  //   valm, nsju, _toej,
  { {0x7aed0039, 0x60c1002b, 0x613f009d, 0x00000000}},  //   nfat, walm, _mêle,
  { {0x60c1147e, 0x7aed018e, 0x45d400ed, 0x00000000}},  //   talm, ifat, _потс,
  { {0xe1250088, 0x3ea924d6, 0x26cd0145, 0x00000000}},  //   ємни, _afat_, _hdeo_,
  { {0x60c116df, 0xf770026c, 0xf99f01aa, 0x00000000}},  //   ralm, _شاہ_, _grèv_,
  { {0xd24e06c6, 0x60c10052, 0x994f0180, 0x00000000}},  //   انی_, salm, yüş_,
  { {0x612d0048, 0x00000000, 0x00000000, 0x00000000}},  //   _dúlr,   ,   ,
  { {0x61e90e66, 0xeb9a1b89, 0x00000000, 0x00000000}},  //   mtel, жив_,   ,
  { {0x7aed095f, 0x8b9600ed, 0x2b400133, 0x00000000}},  //   ffat, драч, thic_,
  { {0x25ad014a, 0x7e7600b0, 0x61e90032, 0x00000000}},  //   _otel_, _tyyp, otel,
  { {0x61e9000d, 0x794001a2, 0x092a060e, 0x00000000}},  // [f980] ntel, _löwe, ожай_,
  { {0x994f0279, 0xe9d7165b, 0x23600825, 0x00000000}},  //   rüş_, ьку_, čiji_,
  { {0x61e9003c, 0x2b4000ab, 0xad1b01ce, 0x00000000}},  //   htel, phic_, _וויר,
  { {0x7bdc01a3, 0x25ad0022, 0x48fa013d, 0x00000000}},  //   muru, _btel_, _उसको_,
  { {0x7bdc0149, 0x80c30055, 0xb0dd013d, 0x00000000}},  //   luru, _শান্, _मांग,
  { {0xf99f01aa, 0x6d8b002b, 0x61e92dbb, 0x00000000}},  //   _prèv_, _użat, dtel,
  { {0x7bdc0149, 0x61e9095c, 0xdce70089, 0x00000000}},  //   nuru, etel, nojā,
  { {0x61e90056, 0xbebb0023, 0x00000000, 0x00000000}},  //   ftel, gjël,   ,
  { {0x7bdc1ac5, 0x057601d8, 0x61e91267, 0x00000000}},  //   huru, _قائد, gtel,
  { {0x7bdc1bbf, 0x23690f3a, 0x3ea9001a, 0x00000000}},  //   kuru, čaja_, _sfat_,
  { {0x61e90142, 0xa2d70061, 0x3f523cda, 0x00000000}},  //   atel, _याच्, ršun_,
  { {0xdb150010, 0x69d60023, 0xf99f0173, 0x00000000}},  //   sszú, krye, _krèt_,
  { {0x61e9000d, 0x7e2b007e, 0x00000000, 0x00000000}},  //   ctel, ціна_,   ,
  { {0xd01002fd, 0x961d0089, 0xc05a0088, 0x00000000}},  //   _ملت_, _uzņe, _мій_,
  { {0x7bdc022b, 0xdd94007e, 0x00000000, 0x00000000}},  //   guru, тары,   ,
  { {0xd1381f00, 0x7bc71d43, 0x00000000, 0x00000000}},  //   lką_, rsju,   ,
  { {0x0dbb06c6, 0xf99f04bd, 0x7aed05fe, 0x00000000}},  // [f990] _باعث_, _què_, rfat,
  { {0x7bdc022b, 0xd1380bd7, 0x7aed01bc, 0x00000000}},  //   buru, nką_, sfat,
  { {0x25ad0100, 0x61e93fdd, 0x7bdc2ac7, 0x00000000}},  //   _stel_, ztel, curu,
  { {0x29070340, 0x61e90036, 0x98bf005a, 0x00000000}},  //   žna_, ytel, ırın_,
  { {0xd2460054, 0x6b8d00f4, 0x79a400ed, 0x00000000}},  //   _إن_, mmag, _арсе,
  { {0x3878009f, 0x0608008b, 0xf99f0173, 0x00000000}},  //   _fyrr_, ьнік_, _drèt_,
  { {0x36d503f3, 0x9f463fde, 0x61e901f3, 0x00000000}},  //   _повр, stlé_, wtel,
  { {0x61e906d5, 0x6b8d3fdf, 0xf99f01aa, 0x00000000}},  //   ttel, nmag, _frèt_,
  { {0x6b8d0111, 0x61e900c7, 0x6d553fe0, 0x00000000}},  //   imag, utel, kiza,
  { {0x7bdc005a, 0x320d294b, 0x70d90061, 0x00000000}},  //   yuru, rvey_, ढलेल,
  { {0x6d550213, 0xdbd703b6, 0x5ee10204, 0x00000000}},  //   diza, _jääv, _काश्_,
  { {0x61e9283e, 0x9f480030, 0x7bdc0cd7, 0x00000000}},  //   ptel, _opnå_, vuru,
  { {0xee373fe1, 0x6d553fe2, 0x6b8d0239, 0x00000000}},  //   еня_, fiza, dmag,
  { {0x7bdc01a3, 0x6d550bb2, 0x63a10a0e, 0x00000000}},  //   turu, giza, _kuln,
  { {0x6b8d000c, 0x629c00b9, 0x6b66005c, 0x00000000}},  //   fmag, ěrov, еква,
  { {0x28e2001c, 0xab2700d1, 0x7bdc04cb, 0x00000000}},  //   _पाहि, носа_, ruru,
  { {0x2d96222e, 0xe9da0265, 0x7bdc0169, 0x00000000}},  // [f9a0] _прос, яка_, suru,
  { {0x6d553673, 0x7bdc002d, 0x186a005e, 0x00000000}},  //   ciza, puru, пази_,
  { {0x3d1d0061, 0x31360049, 0x5975007e, 0x00000000}},  //   मारे_, ענעם_, тыту,
  { {0xf99f0263, 0x6b8d00fa, 0x00000000, 0x00000000}},  //   _prèt_, cmag,   ,
  { {0xba9b00a0, 0x6a9b00b3, 0x2d9a3fe3, 0x00000000}},  //   _מסכי, _משכנ, _kipe_,
  { {0x9633008b, 0x83f80069, 0x63a11a16, 0x00000000}},  //   ыніц, декс_, _buln,
  { {0x7696011f, 0x63a1016c, 0x00000000, 0x00000000}},  //   _büyü, _culn,   ,
  { {0x290a0760, 0xf99f1e83, 0xd1380036, 0x00000000}},  //   _haba_, _grès_, wką_,
  { {0x05660269, 0xd250007a, 0x6d5501aa, 0x00000000}},  //   _зван, شند_, yiza,
  { {0xd1380006, 0x2d9a00e7, 0x660200e7, 0x00000000}},  //   uką_, _nipe_, mwok,
  { {0xd1380bd7, 0x290a0022, 0x6b8d0232, 0x00000000}},  //   rką_, _maba_, ymag,
  { {0x290a359e, 0xd1380a67, 0xdb1c0210, 0x00000000}},  //   _laba_, ską_, nsrä,
  { {0x6b43006c, 0xb7f60044, 0x8233031d, 0x00000000}},  //   _jõge, ঘটিত_, _مروا,
  { {0x290a0225, 0x2c0d0061, 0x2d9a0026, 0x00000000}},  //   _naba_, हिलं_, _cipe_,
  { {0x291f0011, 0x2d9a0022, 0x68fe01c3, 0x00000000}},  //   _đua_, _dipe_, depd,
  { {0x6d553fe4, 0x6b8d00e0, 0xaf370439, 0x00000000}},  //   siza, umag, _سرعت,
  { {0x290a06fe, 0x6d55008e, 0xdb1c0039, 0x00000000}},  // [f9b0] _baba_, piza, dsrä,
  { {0x3eb9001f, 0x602a006b, 0xdbd700b0, 0x00000000}},  //   lbst_, həmm, _pääv,
  { {0xb9090201, 0x290a3fe5, 0xf99f146b, 0x00000000}},  //   _या_, _daba_, _près_,
  { {0x613f009d, 0x00000000, 0x00000000, 0x00000000}},  //   _mêla,   ,   ,
  { {0xa50901f9, 0x5b14005e, 0x3eb901a2, 0x00000000}},  //   дела_, _смят, ibst_,
  { {0xf99f000a, 0x290a3fe6, 0x00000000, 0x00000000}},  //   _frèr_, _gaba_,   ,
  { {0xf99f028c, 0x3ce903d7, 0xe4c80439, 0x00000000}},  //   _très_, _जाने_, ربون_,
  { {0x63a106c2, 0x3f89001d, 0x290a0107, 0x00000000}},  //   _vuln, _nhau_, _zaba_,
  { {0x33920025, 0x1306007c, 0x290a0061, 0x00000000}},  //   جليز, тный_, _yaba_,
  { {0x63a1006c, 0x290a01f3, 0x00000000, 0x00000000}},  //   _tuln, _xaba_,   ,
  { {0x3f6a003b, 0x602a006b, 0xdb0e0203, 0x00000000}},  //   дино_, qəml, msbö,
  { {0xbebb0065, 0x3f89307a, 0x00000000, 0x00000000}},  //   njëh, _chau_,   ,
  { {0x28e20164, 0xdb1c2229, 0x00000000, 0x00000000}},  //   _पालि, nsrå,   ,
  { {0x3afc0082, 0xde030545, 0x00000000, 0x00000000}},  //   _ập_, јпри,   ,
  { {0x290a002b, 0x00000000, 0x00000000, 0x00000000}},  //   _raba_,   ,   ,
  { {0x290a0020, 0xf8b90082, 0x60c300be, 0x00000000}},  //   _saba_, _đũa_, _henm,
  { {0xc3320104, 0x2d9a19ed, 0x60c31243, 0x00000000}},  // [f9c0] בון_, _tipe_, _kenm,
  { {0x3ce9006e, 0x60c30022, 0xb4c20061, 0x00000000}},  //   _जाये_, _jenm, _्ये_,
  { {0x290a006c, 0x60c301aa, 0xdb1c04ce, 0x00000000}},  //   _vaba_, _menm, tsrä,
  { {0x290a0009, 0x60c30173, 0x6b43006c, 0x00000000}},  //   _waba_, _lenm, _põge,
  { {0x290a011c, 0x66e3013b, 0x7ae400e0, 0x00000000}},  //   _taba_, роча, mgit,
  { {0x7ae4006c, 0xcdb7009b, 0x66020093, 0x00000000}},  //   lgit, דפסה_, rwok,
  { {0x66020022, 0x00000000, 0x00000000, 0x00000000}},  //   swok,   ,   ,
  { {0xd5b2007a, 0x7ae43fe7, 0x68e101e5, 0x00000000}},  //   _نفر_, ngit, _öldr,
  { {0xe5a63fe8, 0x799c0045, 0x60c30095, 0x00000000}},  //   _ризи, _kirw, _benm,
  { {0x3ea000f4, 0xc3d6007e, 0x00000000, 0x00000000}},  //   _agit_, _аўды,   ,
  { {0x60c307f4, 0x41d4024c, 0x70540879, 0x00000000}},  //   _denm, _दिवस, انجا,
  { {0x60c30250, 0x20070022, 0x26c400ca, 0x00000000}},  //   _eenm, _dsni_, _jemo_,
  { {0x26c401c5, 0x3eb9010f, 0x60c30173, 0x00000000}},  //   _memo_, rbst_, _fenm,
  { {0x60c30190, 0x799c0093, 0x61e0063f, 0x00000000}},  //   _genm, _nirw, muml,
  { {0x2d4d0107, 0x60c800ea, 0x3f890082, 0x00000000}},  //   džet_, madm, _thau_,
  { {0xeab30054, 0x7ae40197, 0x26c40253, 0x00000000}},  //   شعر_, ggit, _nemo_,
  { {0x61e00095, 0x6f0d00e5, 0x00000000, 0x00000000}},  // [f9d0] numl, _iaac,   ,
  { {0x58b80054, 0x3ad30011, 0xd8b80025, 0x00000000}},  //   نامج_, ệp_, ندما_,
  { {0xd7d50098, 0x637e0065, 0x61e00279, 0x00000000}},  //   ужењ, rënj, huml,
  { {0x26c4037e, 0x23660091, 0x61e00089, 0x00000000}},  //   _cemo_, _njoj_, kuml,
  { {0x61e006a7, 0x80c30044, 0x799c228c, 0x00000000}},  //   juml, _শাস্, _firw,
  { {0xa3e90887, 0x6b9d0058, 0x6f0d01c5, 0x00000000}},  //   едка_, _hisg, _laac,
  { {0x60c30263, 0x29013fe9, 0xe4e40088, 0x00000000}},  //   _renm, meha_, річн,
  { {0x44290119, 0x6aad00f6, 0x60c30173, 0x00000000}},  //   ća_, ncaf, _senm,
  { {0x6b9d2008, 0x60c31bcb, 0x69cd0016, 0x00000000}},  //   _misg, _penm, nsae,
  { {0x81450014, 0x29012e55, 0x66090c21, 0x00000000}},  //   اندن, neha_, _isek,
  { {0x68e50051, 0x6f0d0087, 0x6aad3be4, 0x00000000}},  //   ighd, _baac, kcaf,
  { {0xe1f1007a, 0x29cf001e, 0x8af0006b, 0x00000000}},  //   _هست_, kļa_, nnət,
  { {0x8e5601ff, 0x60c300b5, 0x60c80145, 0x00000000}},  //   утні, _tenm, badm,
  { {0x6da31e6a, 0x29010243, 0x6b9d0051, 0x00000000}},  //   сира, jeha_, _aisg,
  { {0x8c43005e, 0x09cc0061, 0x656300ea, 0x00000000}},  //   бере, ाळ्य, innh,
  { {0x6b9d0026, 0x6aaf0045, 0x00000000, 0x00000000}},  //   _cisg, _cfcf,   ,
  { {0x7ae4006c, 0xc33200b3, 0x6b9d02f1, 0x00000000}},  // [f9e0] rgit, זון_, _disg,
  { {0x26c402c9, 0x00000000, 0x00000000, 0x00000000}},  //   _semo_,   ,   ,
  { {0x3ce902fb, 0x6b9d00dc, 0x61e00213, 0x00000000}},  //   _जाते_, _fisg, zuml,
  { {0x7bdb00a0, 0x7bce00ea, 0x6aad0197, 0x00000000}},  //   _אקטו, msbu, ccaf,
  { {0x7bce00f8, 0x26c40059, 0x66093fea, 0x00000000}},  //   lsbu, _vemo_, _csek,
  { {0x18a30264, 0x2901016c, 0x15b9007e, 0x00000000}},  //   _гарм, ceha_, тыцы_,
  { {0x26c401d9, 0xec360049, 0x7bce0125, 0x00000000}},  //   _temo_, טאַר_, nsbu,
  { {0x53340478, 0xb0420082, 0xf7430a85, 0x00000000}},  //   реит, _ngưở, _лесо,
  { {0x602a006b, 0x00000000, 0x00000000, 0x00000000}},  //   məmi,   ,   ,
  { {0x61e0011f, 0x7f44301e, 0x2154007e, 0x00000000}},  //   ruml, _aliq, ркоў,
  { {0x637e0065, 0x7bce0521, 0xd8db0049, 0x00000000}},  //   hëni, jsbu, עקטר,
  { {0x7f443feb, 0x60c80056, 0x395a00ab, 0x00000000}},  //   _cliq, sadm, hips_,
  { {0x6b9d005b, 0x2d4d04eb, 0x00000000, 0x00000000}},  //   _risg, džer_,   ,
  { {0x3d0f013d, 0x6f0d0020, 0xdb150a36, 0x00000000}},  //   ायें_, _waac, sszü,
  { {0x6f0d001c, 0x602a006b, 0xbc9500ed, 0x00000000}},  //   _taac, kəmi, равј,
  { {0x6d470048, 0x290100e7, 0x00000000, 0x00000000}},  //   shja, weha_,   ,
  { {0xb955005e, 0x6b9d008f, 0x7bce00ea, 0x00000000}},  // [f9f0] аващ, _visg, asbu,
  { {0xdb150010, 0x395a2009, 0x6b9d3416, 0x00000000}},  //   tszó, gips_, _wisg,
  { {0x6d45005f, 0x290125ba, 0x660904b3, 0x00000000}},  //   _ilha, reha_, _ssek,
  { {0x657a01f3, 0x6b9d04df, 0xa615007c, 0x00000000}},  //   _akth, _uisg, имеч,
  { {0x3d0a001c, 0x29011dbd, 0xceb400a3, 0x00000000}},  //   ायचे_, peha_, ציס_,
  { {0xdfc605f3, 0x66090059, 0x290f0089, 0x00000000}},  //   _وي_, _vsek, ēgas_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x2b490082, 0x657a00ea, 0x613f00c4, 0x00000000}},  //   nhac_, _ekth, _pêlo,
  { {0x6d450181, 0xb1450407, 0x8cba013d, 0x00000000}},  //   _olha, инил, ्रमो,
  { {0xe9ff0011, 0x00000000, 0x00000000, 0x00000000}},  //   _giấc_,   ,   ,
  { {0x0467003b, 0xb4d10204, 0x7f4400f6, 0x00000000}},  //   _стам, वणी_, _pliq,
  { {0x6d4501a3, 0x2f560088, 0x823400a2, 0x00000000}},  //   _alha, ртос, _گرما,
  { {0x9394025a, 0x6da602dc, 0xdb1c00ea, 0x00000000}},  //   _اجلا, рига, msrø,
  { {0x8234007a, 0x2d9e059f, 0xc0e20500, 0x00000000}},  //   _درما, öte_, _дошк,
  { {0x3079007b, 0xb7b00055, 0x20790049, 0x00000000}},  //   _באַנ, _চট্ট, _באַא,
  { {0x6d450010, 0xbb4300ed, 0x7bdc0288, 0x00000000}},  //   _elha, оеск, rrru,
  { {0x395a0039, 0xeb970057, 0x3b0700e3, 0x00000000}},  // [fa00] tips_, рит_, шето_,
  { {0x1aee0044, 0x7bce0146, 0x00000000, 0x00000000}},  //   _চোখে_, psbu,   ,
  { {0x602a006b, 0xc796007e, 0x395a0f12, 0x00000000}},  //   təmi, арды, rips_,
  { {0x28e202fb, 0x09e6007c, 0x2b4900b4, 0x00000000}},  //   _पाकि, _комн, chac_,
  { {0x613f01c3, 0x224d1282, 0x00000000, 0x00000000}},  //   _pêll, jzek_,   ,
  { {0x6d5c0213, 0x2b400fdf, 0x00000000, 0x00000000}},  //   nira, lkic_,   ,
  { {0x0fe00055, 0xaaaa007d, 0x4aaa01f5, 0x00000000}},  //   _বন্ধ, _कलाक, _कलाव,
  { {0x6d5c3fec, 0x320a0036, 0x2b400521, 0x00000000}},  //   hira, łbym_, nkic_,
  { {0x6d5c04be, 0xd5a40014, 0x21660c65, 0x00000000}},  //   kira, _طلای, итог,
  { {0x6d5c00f0, 0x3253007e, 0x09f7009b, 0x00000000}},  //   jira, івэр, סמים_,
  { {0x9406007a, 0x13060265, 0x506600ed, 0x00000000}},  //   _خواه, _взем, ртпа,
  { {0x6d5c00c4, 0xd4910011, 0xc2e90025, 0x00000000}},  //   eira, _này_, _معهم_,
  { {0x6d5c00ee, 0x224d0036, 0x5186003b, 0x00000000}},  //   fira, czek_, _кука,
  { {0x657d048a, 0x6d5c3fed, 0x00000000, 0x00000000}},  //   _ësht, gira,   ,
  { {0x443c0047, 0xb0b7009b, 0x00000000, 0x00000000}},  //   nyv_, _דפוס_,   ,
  { {0x4fb301fa, 0x7e6d022b, 0x3ce90204, 0x00000000}},  //   _بصور, _txap, _जावे_,
  { {0x6d5c3fee, 0x63a8106b, 0x2df500a1, 0x00000000}},  // [fa10] bira, _ludn, _آخر,
  { {0x23692794, 0x6d5c0340, 0x00000000, 0x00000000}},  //   čaji_, cira,   ,
  { {0x2d831279, 0x57f5013b, 0x69c00023, 0x00000000}},  //   mlje_, спет, _çmen,
  { {0xd366023c, 0x2d830065, 0x2b40016c, 0x00000000}},  //   _ره_, llje_, ckic_,
  { {0xa99700a6, 0x201a0e0d, 0x00000000, 0x00000000}},  //   _نشست, _špil_,   ,
  { {0x3a3600b3, 0xb4d10061, 0x63a80091, 0x00000000}},  //   _הרשם_, वणे_, _budn,
  { {0xbebb0065, 0x63a80091, 0x6e3d005b, 0x00000000}},  //   njës, _cudn, hysb,
  { {0x6d5c3fef, 0x224d002d, 0x29110010, 0x00000000}},  //   zira, tzek_, _haza_,
  { {0x6d5c3645, 0x2911014a, 0x00000000, 0x00000000}},  //   yira, _kaza_,   ,
  { {0x661b0288, 0x77b301f3, 0x29113ff0, 0x00000000}},  //   _iruk, _eħxe, _jaza_,
  { {0x224d115b, 0x9327025a, 0x29110dec, 0x00000000}},  //   szek_, _پران, _maza_,
  { {0x6d5c20bc, 0x661b00f8, 0x69dd0061, 0x00000000}},  //   wira, _kruk, _पिढी,
  { {0x6d5c3ff1, 0xf1a7012b, 0x23740025, 0x00000000}},  //   tira, _трен, _بالح,
  { {0x628b0825, 0x661b3ff2, 0x7c3c05b7, 0x00000000}},  //   _izgo, _mruk, tyrr,
  { {0x6d5c3d7f, 0x8c432308, 0x92e90055, 0x00000000}},  //   rira, пере, য়ী_,
  { {0xaec6013b, 0xce5a0014, 0x6d5c046e, 0x00000000}},  //   _убил, _مشخص_, sira,
  { {0x29112d02, 0x2d830ce4, 0x2b40016c, 0x00000000}},  // [fa20] _baza_, blje_, rkic_,
  { {0xeeeb001d, 0x4a4300ed, 0x2911008e, 0x00000000}},  //   ượng_, чнув, _caza_,
  { {0x3ead1581, 0x661b010e, 0x9b4603ec, 0x00000000}},  //   žete_, _aruk, _هندو,
  { {0x661b0c64, 0x63a800ee, 0x6f060107, 0x00000000}},  //   _bruk, _rudn, nekc,
  { {0x2911093e, 0x991601fb, 0x6b840039, 0x00000000}},  //   _faza_, _льві, mlig,
  { {0x6b840018, 0x661b0046, 0x29113ff3, 0x00000000}},  //   llig, _druk, _gaza_,
  { {0x68ee0009, 0xd37a17a4, 0x00000000, 0x00000000}},  //   _icbd, лчи_,   ,
  { {0x6b840239, 0x661b00d8, 0x938a007c, 0x00000000}},  //   nlig, _fruk, ысла_,
  { {0xcb13009b, 0x29110276, 0x6d8000b0, 0x00000000}},  //   ללה_, _yaza_, löau,
  { {0x3a3700b6, 0x63a80047, 0x6b8414c3, 0x00000000}},  //   צרים_, _tudn, hlig,
  { {0xe97b007b, 0x2d830825, 0x6b840039, 0x00000000}},  //   רניש, vlje_, klig,
  { {0x6b84033d, 0x8f470057, 0x88ae0044, 0x00000000}},  //   jlig, сход, গরিক,
  { {0x6b8405fe, 0x7f5d009d, 0x81a60025, 0x00000000}},  //   dlig, risq, _احصل,
  { {0x63a23945, 0xd7d80061, 0x6b650006, 0x00000000}},  //   _hion, डळाच, mėgi,
  { {0x63a20e10, 0x29111632, 0x7bda1088, 0x00000000}},  //   _kion, _raza_, štun,
  { {0x6b8427a1, 0x63a20020, 0x2d830243, 0x00000000}},  //   glig, _jion, slje_,
  { {0x63a22302, 0x2d830c1e, 0x2911001a, 0x00000000}},  // [fa30] _mion, plje_, _paza_,
  { {0x63a21063, 0x3947081d, 0x6b843ff4, 0x00000000}},  //   _lion, óns_, alig,
  { {0x6b840282, 0xe78701e1, 0x7d07050f, 0x00000000}},  //   blig, будо, mejs,
  { {0x63a200e7, 0x7d070253, 0x61e0012d, 0x00000000}},  //   _nion, lejs, krml,
  { {0x2911008e, 0xd6290aed, 0x62821b87, 0x00000000}},  //   _taza_, роле_, _nyoo,
  { {0x81b70055, 0x628b00f5, 0x63a20258, 0x00000000}},  //   _ছিল_, _rzgo, _aion,
  { {0xf8ae06c6, 0x63a20207, 0x62820022, 0x00000000}},  //   _شکل_, _bion, _ayoo,
  { {0x661b1e4a, 0x63a20051, 0xf77300a6, 0x00000000}},  //   _truk, _cion, _راز_,
  { {0x661b0061, 0x26cf00d6, 0x63a23ff5, 0x00000000}},  //   _uruk, mago_, _dion,
  { {0x92e908b7, 0x26cf29d8, 0x628b0059, 0x00000000}},  //   য়ে_, lago_, _vzgo,
  { {0x5f06102a, 0x63a20051, 0x6b840784, 0x00000000}},  //   озна, _fion, ylig,
  { {0x26cf0d58, 0x7c2a0129, 0x63a21746, 0x00000000}},  //   nago_, _àfri, _gion,
  { {0x6b8401bf, 0x23780010, 0x628b3ff6, 0x00000000}},  //   vlig, _írja_, _uzgo,
  { {0x7afd23b9, 0x23690825, 0x63a2142e, 0x00000000}},  //   _abst, čaju_, _zion,
  { {0x6b8402e1, 0x26cf0173, 0xdca3007c, 0x00000000}},  //   tlig, kago_, дари,
  { {0xeeeb0011, 0x26cf00ca, 0x7bda007f, 0x00000000}},  //   ưỡng_, jago_, štuo,
  { {0x6b8427a1, 0x26cf002d, 0x00000000, 0x00000000}},  // [fa40] rlig, dago_,   ,
  { {0x6b8406d3, 0x7afd0058, 0xf99f000a, 0x00000000}},  //   slig, _ebst, _krèy_,
  { {0xb9020754, 0x6b8401bf, 0xcc8a0014, 0x00000000}},  //   _नए_, plig, _خنده_,
  { {0xe61a0072, 0x06860264, 0xf99f000a, 0x00000000}},  //   иде_, оген, _apèd_,
  { {0x63a202c9, 0x00000000, 0x00000000, 0x00000000}},  //   _rion,   ,   ,
  { {0x6d4e0082, 0x00000000, 0x00000000, 0x00000000}},  //   nhba,   ,   ,
  { {0xf7460216, 0x26cf006a, 0x53e6007e, 0x00000000}},  //   _дево, bago_, іцка,
  { {0x26cf00ab, 0x7d07281a, 0x38cb00a1, 0x00000000}},  //   cago_, zejs, _ماہی_,
  { {0x63a2000b, 0x0566132e, 0x416a003b, 0x00000000}},  //   _vion, _дван, ијом_,
  { {0x321d018e, 0x929d0046, 0x201c01d9, 0x00000000}},  //   _drwy_, pełn, _prvi_,
  { {0x63a22a9b, 0x6d4e0051, 0xf8b30104, 0x00000000}},  //   _tion, dhba, ושת_,
  { {0x80ba02fb, 0x71a6007e, 0x00000000, 0x00000000}},  //   _श्रे, _дадз,   ,
  { {0x7d070ede, 0x7bda016c, 0x079b00a3, 0x00000000}},  //   tejs, štul, יסטל,
  { {0x26cf002d, 0x656a0051, 0x00000000, 0x00000000}},  //   zago_, nnfh,   ,
  { {0x7d070030, 0x33260719, 0x93bc0035, 0x00000000}},  //   rejs, _knox_, _drăg,
  { {0xdb1c01aa, 0x26cf0032, 0x99030061, 0x00000000}},  //   nprè, xago_, रज्ञ_,
  { {0xaf4b06c6, 0x7d070036, 0x1a6500a1, 0x00000000}},  // [fa50] _مشکل_, pejs, سیسی_,
  { {0xcd000046, 0x6d4e010f, 0x929d0036, 0x00000000}},  //   ęści_, chba, zeło,
  { {0x26cf149a, 0xfe190164, 0xb8d3007d, 0x00000000}},  //   tago_, दिवस_, _ऑल_,
  { {0x47580088, 0x00000000, 0x00000000, 0x00000000}},  //   орія_,   ,   ,
  { {0x26cf002d, 0x98aa0036, 0x7aed01c3, 0x00000000}},  //   rago_, _sobą_, mgat,
  { {0x7aed1957, 0x26cf0197, 0x25bd0016, 0x00000000}},  //   lgat, sago_, rpwl_,
  { {0x26cf0b76, 0x64a2003b, 0x7aed0026, 0x00000000}},  //   pago_, наша, ogat,
  { {0x7aed0149, 0x6d4e012d, 0x00000000, 0x00000000}},  //   ngat, zhba,   ,
  { {0xc2e80025, 0x93bc0035, 0x00000000, 0x00000000}},  //   زعيم_, _arăd,   ,
  { {0x3ea9002a, 0x2eb6006e, 0xe3b3023c, 0x00000000}},  //   _agat_, ूर्त, _قرص_,
  { {0xf3f00025, 0x00000000, 0x00000000, 0x00000000}},  //   _لأن_,   ,   ,
  { {0x321d018e, 0x3f6a0256, 0x25a500ab, 0x00000000}},  //   _trwy_, симо_, _hill_,
  { {0x9f463dc1, 0x25a50339, 0x7aed3ff7, 0x00000000}},  //   nulé_, _kill_, dgat,
  { {0xb226000c, 0x7aed0207, 0x61e9154f, 0x00000000}},  //   stæð, egat, muel,
  { {0xa066008b, 0x3ead0af3, 0x93bc001a, 0x00000000}},  //   _наша_, žeta_, _grăd,
  { {0x6d4e0039, 0x25a501d5, 0x8b951021, 0x00000000}},  //   shba, _lill_, друч,
  { {0x6d4e0045, 0x00000000, 0x00000000, 0x00000000}},  // [fa60] phba,   ,   ,
  { {0x7aed002d, 0xef180089, 0xe9d70b7b, 0x00000000}},  //   agat, ēļu_, яку_,
  { {0xdb24026c, 0x0d3b009b, 0x5d3b009b, 0x00000000}},  //   _ہوگی, _הגיב, _התיא,
  { {0x7aed001c, 0x61e92917, 0x6f16016b, 0x00000000}},  //   cgat, kuel, _jayc,
  { {0xd6cf00b8, 0xceb300b3, 0x25a500ab, 0x00000000}},  //   اقه_, גיד_, _bill_,
  { {0x25a50051, 0x320d00ea, 0x00000000, 0x00000000}},  //   _cill_, dwey_,   ,
  { {0xa84a0025, 0x5334004d, 0xb4ac00e8, 0x00000000}},  //   _الأم_, дейт, _गली_,
  { {0xe3af007a, 0x25ad00ab, 0x98a302d3, 0x00000000}},  //   درو_, _fuel_, _чисе,
  { {0x61e9008e, 0x25a512a0, 0xdb1c0666, 0x00000000}},  //   guel, _fill_, rprè,
  { {0x25a50319, 0x7aed0010, 0xdb1c0129, 0x00000000}},  //   _gill_, zgat, sprè,
  { {0x7bda0213, 0x7aed02d4, 0x6f160a89, 0x00000000}},  //   štuj, ygat, _bayc,
  { {0x6d5e01d9, 0x753a002d, 0x61e904de, 0x00000000}},  //   _ampa, _hotz, buel,
  { {0x61e90211, 0x753a021f, 0xd33700b3, 0x00000000}},  //   cuel, _kotz, _מראה_,
  { {0x753a002d, 0x93bc0035, 0x7bd51b8a, 0x00000000}},  //   _jotz, _trăd, tszu,
  { {0x01330644, 0x317e002d, 0x753a0032, 0x00000000}},  //   _سعود, motz_, _motz,
  { {0x7aed001a, 0x753a002d, 0x6d5e0971, 0x00000000}},  //   ugat, _lotz, _empa,
  { {0x7aed1180, 0x7bd50047, 0xad270070, 0x00000000}},  // [fa70] rgat, sszu, _فردو,
  { {0x7aed003d, 0x48ab007e, 0x25ad00e0, 0x00000000}},  //   sgat, стам_, _ruel_,
  { {0x61e90211, 0x25a50022, 0xf7700bb6, 0x00000000}},  //   zuel, _rill_, گال_,
  { {0xf7730a4f, 0xf1dd013d, 0x25a50150, 0x00000000}},  //   راض_, _मिलन, _sill_,
  { {0x61e921ba, 0x25ad1017, 0x25a50857, 0x00000000}},  //   xuel, _quel_, _pill_,
  { {0x61e90211, 0x6d4700ea, 0xc9840088, 0x00000000}},  //   vuel, nkja, _зуси,
  { {0x25a51908, 0xe9ff0011, 0x753a0129, 0x00000000}},  //   _vill_, _khắc_, _dotz,
  { {0x25a53ff8, 0x7528245c, 0x7f4d0066, 0x00000000}},  //   _will_, _endz, _nlaq,
  { {0x25a50901, 0x6d473ff9, 0xf7700123, 0x00000000}},  //   _till_, kkja, _صاف_,
  { {0xdb1c00f4, 0x7f4d2b9a, 0x753a002d, 0x00000000}},  //   rpré, _alaq, _gotz,
  { {0x656302d5, 0xdb1c04bd, 0x61e92318, 0x00000000}},  //   minh, spré, suel,
  { {0x65630181, 0xe9ff0011, 0x7f4d009d, 0x00000000}},  //   linh, _nhắc_, _claq,
  { {0x61e91729, 0x51553ffa, 0xa29401e1, 0x00000000}},  //   quel, _отку, _заці,
  { {0x236d1191, 0x656334a1, 0x2480014a, 0x00000000}},  //   lnej_, ninh, şime_,
  { {0x6da300d7, 0x628f0166, 0xe1f90006, 0x00000000}},  //   тира, škoć, ltų_,
  { {0xe9ff001d, 0x236d05fd, 0x65633676, 0x00000000}},  //   _chắc_, nnej_, hinh,
  { {0xe1f9010a, 0x6563002b, 0xed5a10f2, 0x00000000}},  // [fa80] ntų_, kinh, _мои_,
  { {0x69d63ffb, 0x65630181, 0x644316a7, 0x00000000}},  //   rsye, jinh, kyni,
  { {0x65630181, 0x776204d2, 0x673b01aa, 0x00000000}},  //   dinh, tiox, _bouj,
  { {0xe1f9010a, 0x64430036, 0x236d0871, 0x00000000}},  //   ktų_, dyni, jnej_,
  { {0x236d09b6, 0x673b12a9, 0x656300c4, 0x00000000}},  //   dnej_, _douj, finh,
  { {0x64430016, 0x67291827, 0x65632274, 0x00000000}},  //   fyni, _enej, ginh,
  { {0x8af0006b, 0x29181290, 0x64433ffc, 0x00000000}},  //   biət, _iara_, gyni,
  { {0x68fe001c, 0x27f701c8, 0x29183716, 0x00000000}},  //   lfpd, žení_, _hara_,
  { {0x6d47009f, 0x291832cd, 0x26c60011, 0x00000000}},  //   ykja, _kara_, mboo_,
  { {0x2918002b, 0x291a3ffd, 0x65630181, 0x00000000}},  //   _jara_, ndpa_, cinh,
  { {0x29183ffe, 0x7f4d00f4, 0xc0570088, 0x00000000}},  //   _mara_, _plaq, дія_,
  { {0x122a007c, 0x236d05fd, 0x00000000, 0x00000000}},  //   _моей_, cnej_,   ,
  { {0x2918001a, 0x00000000, 0x00000000, 0x00000000}},  //   _oara_,   ,   ,
  { {0x2918002b, 0x59b501f5, 0x00000000, 0x00000000}},  //   _nara_, _अंबर,   ,
  { {0x6d47000c, 0x7f4d19ee, 0x6b511a96, 0x00000000}},  //   rkja, _tlaq, _låge,
  { {0x656302d5, 0x6d473fff, 0x3a220022, 0x00000000}},  //   zinh, skja, _brkp_,
  { {0x29184000, 0x64430036, 0xd91b007c, 0x00000000}},  // [fa90] _bara_, zyni, жье_,
  { {0x291804fa, 0x65634001, 0x236d4002, 0x00000000}},  //   _cara_, xinh, znej_,
  { {0x2918002a, 0xe9ff001d, 0x65630181, 0x00000000}},  //   _dara_, _thắc_, vinh,
  { {0xe1f90006, 0x6443007f, 0x00000000, 0x00000000}},  //   ytų_, vyni,   ,
  { {0x29184003, 0x65630181, 0x64430016, 0x00000000}},  //   _fara_, tinh, wyni,
  { {0x2918022b, 0xfbd000d3, 0x64434004, 0x00000000}},  //   _gara_, _حتی_, tyni,
  { {0x673b11aa, 0x656302d5, 0xd883007a, 0x00000000}},  //   _touj, rinh, _شهری,
  { {0x65631329, 0x2918002d, 0x6b510039, 0x00000000}},  //   sinh, _zara_, _fåge,
  { {0x236d4005, 0x65630181, 0x6443005b, 0x00000000}},  //   rnej_, pinh, syni,
  { {0xdb060065, 0xe1f90006, 0x236d05fd, 0x00000000}},  //   _pikë, rtų_, snej_,
  { {0xe1f9010a, 0x00000000, 0x00000000, 0x00000000}},  //   stų_,   ,   ,
  { {0xe1f90006, 0x2b49012d, 0x00000000, 0x00000000}},  //   ptų_, jkac_,   ,
  { {0x3ea40039, 0xe1170044, 0x00000000, 0x00000000}},  //   ämt_, ়াবহ_,   ,
  { {0x98aa0224, 0xdb050010, 0x61fb28d4, 0x00000000}},  //   _době_, _ruhá, mtul,
  { {0xeb9a003b, 0x3b9600ec, 0x61fb2c2c, 0x00000000}},  //   зив_, ејат, ltul,
  { {0x291801a3, 0xdbd60004, 0x2be10164, 0x00000000}},  //   _sara_, _rääg, _फिरा,
  { {0x61fb12e9, 0x6f0416b1, 0xa9260780, 0x00000000}},  // [faa0] ntul, _ibic, ндал,
  { {0x5e57007b, 0x291811ca, 0x6e240032, 0x00000000}},  //   _נייע_, _qara_, _irib,
  { {0x29180073, 0x6e240059, 0x61fb006c, 0x00000000}},  //   _vara_, _hrib, htul,
  { {0x3ae8026c, 0x291801d5, 0x6e2419c5, 0x00000000}},  //   _کبھی_, _wara_, _krib,
  { {0x291814e8, 0x8af0006b, 0x6f0400e7, 0x00000000}},  //   _tara_, rhəd, _mbic,
  { {0x69c41011, 0x59b502d2, 0x6b51032e, 0x00000000}},  //   mpie, _अंतर, _våge,
  { {0x6f040587, 0xf8a7007d, 0x66e60594, 0x00000000}},  //   _obic, _कृपय, _пова,
  { {0x31c6178d, 0xe805013d, 0x6e240035, 0x00000000}},  //   нсов, _रहता_, _orib,
  { {0x3f820007, 0x69c401c5, 0x61fb011c, 0x00000000}},  //   doku_, npie, gtul,
  { {0x6f040f99, 0x09f7009b, 0x2ee04006, 0x00000000}},  //   _abic, עמים_, _adif_,
  { {0xf65f009f, 0xb4cc02fb, 0x3957009b, 0x00000000}},  //   _þær_, लरी_, גשים_,
  { {0x3f820066, 0x98aa00b9, 0x3ead01e3, 0x00000000}},  //   goku_, _sobě_, øet_,
  { {0x614601fb, 0x61fb000d, 0x69c40036, 0x00000000}},  //   _педа, ctul, jpie,
  { {0x02170097, 0xc69300a3, 0x65610050, 0x00000000}},  //   _נחום_, טאר_, _xmlh,
  { {0xef1f005d, 0x3f82006b, 0x64580b5e, 0x00000000}},  //   nlük_, boku_, nzvi,
  { {0xa3e8006e, 0xbddb01aa, 0xfaff0023, 0x00000000}},  //   _बिन_, lyèm, _ajër_,
  { {0x6e24001e, 0x69c411de, 0x58d9007e, 0x00000000}},  // [fab0] _grib, gpie, ддзя_,
  { {0x6f0f095e, 0x6f1d05c6, 0xbddb01aa, 0x00000000}},  //   lecc, ldsc, nyèm,
  { {0x2d830006, 0x69c40197, 0x6f1d00d9, 0x00000000}},  //   moje_, apie, odsc,
  { {0x6458001c, 0xdc360049, 0x2d834007, 0x00000000}},  //   dzvi, _סארט_, loje_,
  { {0xd7740644, 0xdcfc15d7, 0x6b8d0d3e, 0x00000000}},  //   دالع, zorč, mlag,
  { {0x2d8328da, 0x00000000, 0x00000000, 0x00000000}},  //   noje_,   ,   ,
  { {0xb6f5003b, 0x00000000, 0x00000000, 0x00000000}},  //   _извј,   ,   ,
  { {0x6b8d010f, 0x6f0f0129, 0x61fb000c, 0x00000000}},  //   nlag, jecc, ttul,
  { {0x11d60025, 0x29cf3e64, 0xa235007e, 0x00000000}},  //   نوية_, nża_, тэйш,
  { {0x2d83010a, 0x6b8d001f, 0xd68401fb, 0x00000000}},  //   joje_, hlag, _сусп,
  { {0x61fb1f37, 0x69c40046, 0xf8b201f8, 0x00000000}},  //   stul, zpie, ישי_,
  { {0x7d0e0093, 0x6b8d00b5, 0x61fb001a, 0x00000000}},  //   webs, jlag, ptul,
  { {0x6b8d01d9, 0xee370152, 0x780d006e, 0x00000000}},  //   dlag, вня_, सबुक_,
  { {0x4d151fea, 0x2d834008, 0xd1380036, 0x00000000}},  //   льст, goje_, cją_,
  { {0x69dd0039, 0x6b8d010f, 0x61e91cef, 0x00000000}},  //   _avse, flag, lrel,
  { {0x6f040219, 0x6b8d37ad, 0x6e244009, 0x00000000}},  //   _ubic, glag, _trib,
  { {0xf2d2007b, 0x6e240f06, 0x2d8324f2, 0x00000000}},  // [fac0] יען_, _urib, boje_,
  { {0x63ab400a, 0x69c40036, 0x08c301fc, 0x00000000}},  //   _lign, rpie, ибун,
  { {0x69c40e42, 0x07a601e1, 0x6b8d009d, 0x00000000}},  //   spie, важн, blag,
  { {0x0bb700b6, 0x66e60920, 0x6b8d400b, 0x00000000}},  //   _שלכם_, тода, clag,
  { {0x6b8400f4, 0x628e0036, 0x61e9016c, 0x00000000}},  //   moig, ębok, jrel,
  { {0xa8060b11, 0x61e9400c, 0x44250035, 0x00000000}},  //   _изгл, drel, _brl_,
  { {0x6f0f0211, 0x63ab1733, 0x86ea0025, 0x00000000}},  //   yecc, _bign, _يعرف_,
  { {0xb6c800a1, 0x628b0146, 0x63ab1f38, 0x00000000}},  //   _سارے_, _bygo, _cign,
  { {0xf74300ed, 0x6f0f0197, 0x61e91fe8, 0x00000000}},  //   _тето, vecc, grel,
  { {0x63ab400d, 0x6b8d0059, 0x4a9b0049, 0x00000000}},  //   _eign, zlag, ויפג,
  { {0x2d8324f2, 0x6f0f400e, 0x61e9001a, 0x00000000}},  //   voje_, tecc, arel,
  { {0x6b8400f4, 0xf99f01aa, 0x2d54006c, 0x00000000}},  //   joig, _apèl_, _näeb_,
  { {0x6f0f0845, 0x2d830ac5, 0x61e9014a, 0x00000000}},  //   recc, toje_, crel,
  { {0xe9ff00ad, 0xac1900ed, 0x6f0f0e32, 0x00000000}},  //   _nhạc_, ногу_, secc,
  { {0x2d83004f, 0x6b8d00f8, 0x6f0f1e5a, 0x00000000}},  //   roje_, tlag, pecc,
  { {0x2d830993, 0x00000000, 0x00000000, 0x00000000}},  //   soje_,   ,   ,
  { {0x6b8d010f, 0x2d830cd5, 0xdb120051, 0x00000000}},  // [fad0] rlag, poje_, ágái,
  { {0x6b8d1413, 0x29cf1f27, 0x291901d8, 0x00000000}},  //   slag, rża_, عقاد_,
  { {0x6c35004b, 0x6b8d0039, 0x61e909fc, 0x00000000}},  //   _صفحا, plag, zrel,
  { {0x7bc701d5, 0x61e904d7, 0xc2e80055, 0x00000000}},  //   mpju, yrel, ক্তি_,
  { {0x44250412, 0x63ab000c, 0x6b51032e, 0x00000000}},  //   _srl_, _rign, _gåga,
  { {0x75d20025, 0x61e93abf, 0x442500b4, 0x00000000}},  //   حيوا, vrel, _prl_,
  { {0x63ab1003, 0xdcfc0089, 0xad9b004a, 0x00000000}},  //   _pign, norā, ctúe,
  { {0x61e9049a, 0xb8820428, 0x93bc0011, 0x00000000}},  //   trel, číta, _trăn,
  { {0x63ab1e5a, 0x61e911de, 0x97820014, 0x00000000}},  //   _vign, urel, _اینه,
  { {0x61e9022b, 0x63ab0022, 0x442500e7, 0x00000000}},  //   rrel, _wign, _trl_,
  { {0x44250365, 0x63ab011c, 0x4ad30061, 0x00000000}},  //   _url_, _tign, तराव,
  { {0x628b0046, 0x69c111b0, 0x61e9164f, 0x00000000}},  //   _tygo, _člen, prel,
  { {0xcdf6045a, 0x91e50a85, 0x00000000, 0x00000000}},  //   ычны, _соле,   ,
  { {0x7bdc00f8, 0xd048006b, 0x00000000, 0x00000000}},  //   tsru, hadə,   ,
  { {0x24d80044, 0x3b0a00e2, 0x6b5102e7, 0x00000000}},  //   _সামহ, нево_, _såga,
  { {0x7bdc010e, 0x00000000, 0x00000000, 0x00000000}},  //   rsru,   ,   ,
  { {0x0eaa01fb, 0x7bdc00f8, 0x00000000, 0x00000000}},  // [fae0] _який_, ssru,   ,
  { {0x6b5138c6, 0x7bda0010, 0x00000000, 0x00000000}},  //   _våga, átus,   ,
  { {0xd048005f, 0x46ea0113, 0x3cfb009b, 0x00000000}},  //   fadə, еден_, _אלינ,
  { {0x27e70051, 0x7d1e28fb, 0xcc3b0049, 0x00000000}},  //   ánna_, _haps, _נעכט,
  { {0x7d1e014a, 0xe9ff0011, 0x1634053f, 0x00000000}},  //   _kaps, _thạc_, реля,
  { {0x7af60006, 0xef1f0276, 0x7d1e0052, 0x00000000}},  //   lgyt, zdü_, _japs,
  { {0x4ab8013d, 0x97b500ed, 0x6d4e0328, 0x00000000}},  //   _अलाव, _всуш, ikba,
  { {0x7d1e0368, 0x3ead129d, 0x75d60439, 0x00000000}},  //   _laps, žeti_, _ميرا,
  { {0x316a01c0, 0x39b20173, 0x6d4e121b, 0x00000000}},  //   ешно_, _fņse_, kkba,
  { {0x7d1e0224, 0x6d4e00b5, 0x845a00ed, 0x00000000}},  //   _naps, jkba, _прет_,
  { {0x8937007b, 0xb4c2006e, 0x661d000c, 0x00000000}},  //   אריע_, ूरी_, _áskr,
  { {0x60c4011f, 0x3cfa00d4, 0x6d4e0328, 0x00000000}},  //   _şimd, _acpv_, ekba,
  { {0xe2920054, 0x246e005f, 0x5ce701fb, 0x00000000}},  //   _اذا_, _həm_, люва,
  { {0x7c8700e3, 0x74ca0309, 0xd048006b, 0x00000000}},  //   губе, _स्मृ, zadə,
  { {0x0704007d, 0x7d1e007f, 0x00000000, 0x00000000}},  //   रभाव_, _daps,   ,
  { {0x60da014a, 0x6d4e0010, 0x00000000, 0x00000000}},  //   latm, akba,   ,
  { {0x5a350893, 0x13cd0044, 0x4cd40044, 0x00000000}},  // [faf0] шнат, রওয়, _তারু,
  { {0xdd92026c, 0x2907400f, 0x93bc00e5, 0x00000000}},  //   _ووٹ_, ýna_, _arăm,
  { {0x6aa60055, 0xdb1c04bb, 0x7b084010, 0x00000000}},  //   গুলো, sprá, ístí,
  { {0x7d1e00b9, 0x644a33ff, 0x7bc50288, 0x00000000}},  //   _zaps, dyfi, _ithu,
  { {0x60da0173, 0x7d1e014a, 0x00000000, 0x00000000}},  //   katm, _yaps,   ,
  { {0xe5a502d3, 0x60da0022, 0x00000000, 0x00000000}},  //   шили, jatm,   ,
  { {0x36d5007e, 0x60da0276, 0xa9540088, 0x00000000}},  //   _вобр, datm, _укрі,
  { {0x29134011, 0x39430087, 0x93bc0035, 0x00000000}},  //   lexa_, _hojs_, _grăm,
  { {0x6d4e0007, 0x00000000, 0x00000000, 0x00000000}},  //   ykba,   ,   ,
  { {0xe610036d, 0x661b0058, 0x291300f6, 0x00000000}},  //   _عشق_, _isuk, nexa_,
  { {0x6b510073, 0xb4c10164, 0x764b0016, 0x00000000}},  //   _någo, ंडी_, lygy,
  { {0x3f6a003b, 0x00000000, 0x00000000, 0x00000000}},  //   тимо_,   ,   ,
  { {0x7bc5009f, 0x43840054, 0x7d1e01a2, 0x00000000}},  //   _athu, _النق, _paps,
  { {0x3943291b, 0x661b0020, 0xc5d70044, 0x00000000}},  //   _nojs_, _msuk, _সমাপ,
  { {0xdca6012b, 0x6d4e00b5, 0xdfd10025, 0x00000000}},  //   рави, rkba, _بيع_,
  { {0x6d4e03ba, 0x207a0049, 0x00000000, 0x00000000}},  //   skba, _באצא,   ,
  { {0xe8fa003b, 0xc33201f8, 0x44200011, 0x00000000}},  // [fb00] кла_, חון_, ̉i_,
  { {0x38cb0167, 0x9f460048, 0xad9b0048, 0x00000000}},  //   نامی_, irlí_, rtúc,
  { {0x661b0cfc, 0x00000000, 0x00000000, 0x00000000}},  //   _asuk,   ,   ,
  { {0xe5c6007e, 0xe7390016, 0x6c7b00b3, 0x00000000}},  //   аско, _siŵr_, _יריד,
  { {0xb4c101f5, 0x799c0016, 0x661b0010, 0x00000000}},  //   ंडू_, _thrw, _csuk,
  { {0xe5e50025, 0x6e3b01a2, 0x6b5102e1, 0x00000000}},  //   إثني, äubi, _lågl,
  { {0x6c7a0049, 0x60da03f1, 0xad9b004a, 0x00000000}},  //   כאַפ, vatm, ntúa,
  { {0x644a4012, 0x00000000, 0x00000000, 0x00000000}},  //   ryfi,   ,   ,
  { {0x644a2cde, 0xd1300025, 0x61d7007e, 0x00000000}},  //   syfi, كمة_, амыя_,
  { {0x71740025, 0x62990036, 0x2154007e, 0x00000000}},  //   إهدا, _dzwo, скоў,
  { {0x60da0279, 0x66024013, 0x733600a1, 0x00000000}},  //   ratm, ltok, _پرائ,
  { {0x6722008d, 0x660200e7, 0xdb1c01a2, 0x00000000}},  //   ndoj, otok, nprä,
  { {0x60da0d5b, 0x660200b0, 0x7a0a0089, 0x00000000}},  //   patm, ntok, nētā,
  { {0x660200b0, 0x00000000, 0x00000000, 0x00000000}},  //   itok,   ,   ,
  { {0x06d70055, 0x61e2000c, 0x7b67007c, 0x00000000}},  //   _হাসি, _hvol, атае,
  { {0x67200182, 0x290a0010, 0xc2e80044, 0x00000000}},  //   _namj, _abba_, ক্রি_,
  { {0x88c70025, 0x00000000, 0x00000000, 0x00000000}},  // [fb10] لتال,   ,   ,
  { {0x93bc0035, 0x66020087, 0xe9ff0082, 0x00000000}},  //   _vrăj, dtok, _nhấc_,
  { {0x7d15014a, 0xad9b004a, 0x69c60095, 0x00000000}},  //   mezs, ctúa, _etke,
  { {0x61e2037e, 0x290a00f8, 0x2ef906d3, 0x00000000}},  //   _ovol, _ebba_, ngsf_,
  { {0x6d450004, 0x67200627, 0x316c01c3, 0x00000000}},  //   _koha, _damj, kidz_,
  { {0x6d450b6e, 0xb4c10164, 0x5dda0049, 0x00000000}},  //   _joha, ंडे_, אַקס,
  { {0x6d450518, 0x04451662, 0x61e20dc9, 0x00000000}},  //   _moha, сейн, _avol,
  { {0x6d4520e3, 0xe2990780, 0x21294014, 0x00000000}},  //   _loha, лай_, _şah_,
  { {0x7769002b, 0x661b4015, 0x201c0022, 0x00000000}},  //   _imex, _usuk, _asvi_,
  { {0x67200166, 0x8c49014a, 0x26dd0009, 0x00000000}},  //   _zamj, _kaşı, lawo_,
  { {0x04950054, 0x60d800fa, 0x5edc0044, 0x00000000}},  //   _الاح, _devm, _ভাবে,
  { {0x2f5601fb, 0x09cd0044, 0x8c49006b, 0x00000000}},  //   стос, _লিনা, _maşı,
  { {0x6d4523d9, 0x877a0049, 0x75214016, 0x00000000}},  //   _boha, רארי, _kalz,
  { {0x6d4509af, 0x27e1012d, 0xd4910082, 0x00000000}},  //   _coha, kshn_, _kỳ_,
  { {0x224d0047, 0x7521014a, 0x61e20428, 0x00000000}},  //   lyek_, _malz, _zvol,
  { {0x236d0036, 0xdb0d010f, 0x6e470023, 0x00000000}},  //   niej_, rmaß, ërbë,
  { {0x224d0047, 0xeb97007c, 0xbb43012b, 0x00000000}},  // [fb20] nyek_, сит_, четк,
  { {0x8c4901f6, 0x67201087, 0xa3e8007d, 0x00000000}},  //   _başı, _samj, _बिल_,
  { {0x236d0046, 0x6d5c0051, 0x67200065, 0x00000000}},  //   kiej_, mhra, _pamj,
  { {0x8c49005f, 0x660200b0, 0x6722007f, 0x00000000}},  //   _daşı, ttok, udoj,
  { {0x6d450020, 0x67220f42, 0x660200b0, 0x00000000}},  //   _yoha, rdoj, utok,
  { {0x75210e1d, 0x66023727, 0xdb1c010f, 0x00000000}},  //   _calz, rtok, sprä,
  { {0xf863017a, 0x66020e88, 0x61e24017, 0x00000000}},  //   _евро, stok, _svol,
  { {0x60d8005d, 0x236d0036, 0x66020253, 0x00000000}},  //   _sevm, giej_, ptok,
  { {0x75210846, 0x224d0010, 0x6d5c08ca, 0x00000000}},  //   _falz, gyek_, khra,
  { {0x8c4901f6, 0x00000000, 0x00000000, 0x00000000}},  //   _yaşı,   ,   ,
  { {0x6d450f55, 0x6d5c0142, 0x2d8a0134, 0x00000000}},  //   _roha, dhra, dobe_,
  { {0x236d0036, 0x224d0093, 0x6d450010, 0x00000000}},  //   ciej_, byek_, _soha,
  { {0x8af0006b, 0x6e220089, 0x442c0093, 0x00000000}},  //   rhəl, _šobr, _hrd_,
  { {0x6d5c016d, 0x63ba00d2, 0x2d8a01ed, 0x00000000}},  //   ghra, _kutn, gobe_,
  { {0x93bc001a, 0x6d450ec2, 0x00000000, 0x00000000}},  //   _brăi, _voha,   ,
  { {0x442c01a2, 0x63ba04eb, 0xc178007f, 0x00000000}},  //   _mrd_, _mutn, lnė_,
  { {0x6d5c002a, 0x442c0117, 0x8b0400b9, 0x00000000}},  // [fb30] bhra, _lrd_, ířat,
  { {0x6d5c018e, 0x236d0046, 0xdd0e005f, 0x00000000}},  //   chra, ziej_, mışd,
  { {0x6e2d06a6, 0x63ba01ca, 0x76b900ed, 0x00000000}},  //   _hrab, _nutn, алер_,
  { {0x7521010f, 0x6e2d0387, 0x3f8b016c, 0x00000000}},  //   _salz, _krab, nocu_,
  { {0x442c002a, 0x80de0044, 0xdd0e006b, 0x00000000}},  //   _ard_, _মান্, nışd,
  { {0x67d51076, 0x8c49011f, 0x6e2d0020, 0x00000000}},  //   _могу, _taşı, _mrab,
  { {0x58d40242, 0xdb1c15b3, 0x442c0085, 0x00000000}},  //   _хост, språ, _crd_,
  { {0x225f022b, 0xc1780006, 0x442c0052, 0x00000000}},  //   tzuk_, enė_, _drd_,
  { {0x24890046, 0x60c4006b, 0x44270082, 0x00000000}},  //   łam_, _şima, svn_,
  { {0x60090bff, 0x6f0d3320, 0x442c0009, 0x00000000}},  //   аном_, _abac, _frd_,
  { {0x236d0046, 0x6e2d4018, 0x73c4023c, 0x00000000}},  //   piej_, _arab, _فيلم,
  { {0x5ea80055, 0x6e2d0882, 0x9eaa026b, 0x00000000}},  //   _ক্ষে, _brab, ивна_,
  { {0x6d5c002a, 0x200a011f, 0x6e2d10c5, 0x00000000}},  //   thra, çbir_, _crab,
  { {0x6e2d1992, 0x127a0049, 0x8af0013f, 0x00000000}},  //   _drab, _דאנע, rhəm,
  { {0x6e2d0756, 0x2d8a0235, 0x8b2600ed, 0x00000000}},  //   _erab, robe_, одве,
  { {0x6d5c3121, 0x6e2d01f4, 0x5dda00e2, 0x00000000}},  //   shra, _frab, _кфор_,
  { {0x2480014a, 0x5ea80044, 0x6d5c0133, 0x00000000}},  // [fb40] ğimi_, _ক্রে, phra,
  { {0x248001df, 0x6b5812e1, 0xad9b2285, 0x00000000}},  //   şimi_, _díga, ntúl,
  { {0x93bc001a, 0x20050095, 0x00000000, 0x00000000}},  //   _trăi, ntli_,   ,
  { {0xab2a00d7, 0x6b5800c4, 0xad9b0048, 0x00000000}},  //   _тома_, _fíga, htúl,
  { {0xe534007e, 0x6b810010, 0xa3dc01f5, 0x00000000}},  //   зель, élge, तीन_,
  { {0x442c03fd, 0x63ba0ad8, 0x03c62488, 0x00000000}},  //   _prd_, _putn, осим,
  { {0x399400b0, 0x398f3b03, 0x00000000, 0x00000000}},  //   jäsi_, rüst_,   ,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xdb04009d, 0xdd0e013f, 0x00000000, 0x00000000}},  //   rmiè, xışd,   ,
  { {0x3a37012e, 0x442c00ca, 0x6f0d0a15, 0x00000000}},  //   קרים_, _trd_, _sbac,
  { {0x4034004d, 0x41b400a2, 0xb8bb0049, 0x00000000}},  //   ченс, _کمتر, יזיש,
  { {0x6e2d1750, 0xc1780006, 0xdb0f0051, 0x00000000}},  //   _prab, snė_, _ticé,
  { {0xdb06021e, 0x637e0089, 0x628e01a2, 0x00000000}},  //   _mikä, cīna, ßbod,
  { {0xc5f301f8, 0x6e2d003b, 0x6ad3013d, 0x00000000}},  //   ודש_, _vrab, तर्र,
  { {0x63a20011, 0x5c044019, 0x6b581ad4, 0x00000000}},  //   _khon, мята, _síga,
  { {0x5ed50044, 0xa3dc007d, 0x6f0d0091, 0x00000000}},  //   _থাকে, तीय_, _ubac,
  { {0x63a2401a, 0x6e2d401b, 0xecf9007e, 0x00000000}},  // [fb50] _mhon, _urab, _лепш_,
  { {0xceb4009b, 0x69cd00ea, 0x00000000, 0x00000000}},  //   _קיץ_, rpae,   ,
  { {0x63a2018e, 0xdce70089, 0x6b960016, 0x00000000}},  //   _ohon, cijā, blyg,
  { {0x8c1a00a0, 0x00000000, 0x00000000, 0x00000000}},  //   _פורי,   ,   ,
  { {0xbc68007a, 0xeb3a0049, 0xf770006d, 0x00000000}},  //   _همین_, _הערש, خال_,
  { {0x6b8d15ed, 0x63a2401c, 0x6d5500d9, 0x00000000}},  //   loag, _ahon, nkza,
  { {0x63a23d37, 0xc79600a1, 0x00000000, 0x00000000}},  //   _bhon, _کھلا_,   ,
  { {0x63a2002a, 0x85b9044b, 0xc245041f, 0x00000000}},  //   _chon, _глас_, зник,
  { {0xe1f10025, 0x95c8003b, 0xddc60036, 0x00000000}},  //   رسة_, _духа_, zykł,
  { {0xc692007b, 0x44f402b8, 0xf0651b7f, 0x00000000}},  //   _טאן_, _опус, зкоп,
  { {0x63a20051, 0xad9b00d4, 0x6b8d002d, 0x00000000}},  //   _fhon, rtúl, koag,
  { {0x7c2a00f7, 0x20050276, 0x6b8d0022, 0x00000000}},  //   _áfri, rtli_, joag,
  { {0x63a9401d, 0x200500b9, 0xc6090055, 0x00000000}},  //   mmen, stli_, লিকা_,
  { {0x63a2122b, 0xc1040379, 0x91a700a1, 0x00000000}},  //   _zhon, _يوني, _بنتے_,
  { {0x63a90006, 0x7bce0141, 0x913a009b, 0x00000000}},  //   omen, upbu, _לעסק,
  { {0xbb4301f9, 0x63a900ab, 0xdce70089, 0x00000000}},  //   неск, nmen, rijā,
  { {0x63a9028c, 0x80de0055, 0xb18300b9, 0x00000000}},  // [fb60] imen, _মাত্, šťuj,
  { {0x63a9010f, 0x6d5501a2, 0xa92300d7, 0x00000000}},  //   hmen, ckza, ндул,
  { {0x63a906e8, 0xdb1c068f, 0x6b8d0032, 0x00000000}},  //   kmen, kprø, boag,
  { {0x63a90161, 0x2d982e6d, 0x1fbd0044, 0x00000000}},  //   jmen, llre_, _আবাস,
  { {0x63a90006, 0x63a20b73, 0xba76023c, 0x00000000}},  //   dmen, _rhon, _راحت,
  { {0x63a900f4, 0x63a20051, 0x00000000, 0x00000000}},  //   emen, _shon,   ,
  { {0x63a2190f, 0x29370049, 0x63a901c3, 0x00000000}},  //   _phon, _צאלן_, fmen,
  { {0x80de0055, 0x987b0476, 0x291a0059, 0x00000000}},  //   _মাধ্, _האלט, lepa_,
  { {0x0566003b, 0xa3dc013d, 0x93bc001a, 0x00000000}},  //   _еван, _तौर_, _arăt,
  { {0x63a90a15, 0x394a192b, 0x291a097e, 0x00000000}},  //   amen, _jobs_, nepa_,
  { {0x394a0066, 0x63a90061, 0xf2db0044, 0x00000000}},  //   _mobs_, bmen, _ধারণ,
  { {0x389b0476, 0x643b0049, 0x63a91caa, 0x00000000}},  //   מיינ, _לעבנ, cmen,
  { {0x7d030039, 0xa3c2013d, 0x4cd40044, 0x00000000}},  //   _önsk, _एंड_, _তাজু,
  { {0x61430081, 0x291a0243, 0x93bc00e5, 0x00000000}},  //   _печа, jepa_, _frăt,
  { {0x6d5500b5, 0xab950088, 0x93bc0035, 0x00000000}},  //   rkza, диві, _grăt,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xa3dc001c, 0x6b8d002d, 0x394a401e, 0x00000000}},  // [fb70] तीत_, roag, _bobs_,
  { {0xa8a7005e, 0x3f99002b, 0x6b5800d4, 0x00000000}},  //   прек, llsu_, _fígo,
  { {0xf990025a, 0xaf200055, 0x63a900ab, 0x00000000}},  //   ابق_, ধারণ_, ymen,
  { {0x63a90009, 0x00000000, 0x00000000, 0x00000000}},  //   xmen,   ,   ,
  { {0x63a9297c, 0x5a3401ff, 0x00000000, 0x00000000}},  //   vmen, _знят,   ,
  { {0xdb17049a, 0x63a9401f, 0xe6180088, 0x00000000}},  //   _muxí, wmen, яді_,
  { {0x63a9011f, 0x00000000, 0x00000000, 0x00000000}},  //   tmen,   ,   ,
  { {0x63a92505, 0x00000000, 0x00000000, 0x00000000}},  //   umen,   ,   ,
  { {0x10f5007e, 0x00000000, 0x00000000, 0x00000000}},  //   мяня,   ,   ,
  { {0x63a9000c, 0xdb1c0190, 0xd5b101b2, 0x00000000}},  //   smen, sprø, _شفا_,
  { {0x63a90038, 0x24550318, 0xdb170181, 0x00000000}},  //   pmen, _تناس, _auxí,
  { {0x83670123, 0x325501ee, 0x25bf25b3, 0x00000000}},  //   _عدال, _овер, _kuul_,
  { {0x25bf269f, 0x6f63007e, 0x93bc00e5, 0x00000000}},  //   _juul_, твяз, _frăs,
  { {0x61fb0020, 0x25bf010e, 0x93bc0035, 0x00000000}},  //   muul, _muul_, _grăs,
  { {0x394a4020, 0x61fb01b1, 0xdbf2013e, 0x00000000}},  //   _robs_, luul, přít,
  { {0xf09200b6, 0xe9da0256, 0x21270011, 0x00000000}},  //   _שנה_, жка_, _hanh_,
  { {0x13d60055, 0x6f041706, 0xe3b8014a, 0x00000000}},  // [fb80] সওয়, _icic, _asıl_,
  { {0x6e24002b, 0x66060bac, 0xdb1e0023, 0x00000000}},  //   _isib, _äkki, _kupë,
  { {0x7d1c4021, 0x291a0db7, 0x21270011, 0x00000000}},  //   mers, repa_, _manh_,
  { {0x61fb3723, 0x21270011, 0x6e240066, 0x00000000}},  //   kuul, _lanh_, _ksib,
  { {0x7ae436f9, 0x21270011, 0x5976007e, 0x00000000}},  //   mait, _oanh_, _жыву,
  { {0x7ae431b2, 0x2ee000eb, 0x6e240020, 0x00000000}},  //   lait, _leif_, _msib,
  { {0xc10e0011, 0x69c4002b, 0x1394004d, 0x00000000}},  //   _bỗng_, lqie, никю,
  { {0x7ae4002a, 0x25bf0087, 0x61fb0009, 0x00000000}},  //   nait, _fuul_, fuul,
  { {0x7d1c0056, 0x21270082, 0x6e24002b, 0x00000000}},  //   kers, _banh_, _nsib,
  { {0x7d1c36e0, 0x7ae4028c, 0x21270011, 0x00000000}},  //   jers, hait, _canh_,
  { {0x7ae42a94, 0x2127001d, 0xb226009f, 0x00000000}},  //   kait, _danh_, fræð,
  { {0x6d5e2756, 0x7ae400b0, 0x61fb0009, 0x00000000}},  //   _alpa, jait, buul,
  { {0x7ae4002a, 0x7d1c010f, 0xad9b0051, 0x00000000}},  //   dait, fers, ltúi,
  { {0x7d1c01bf, 0x6b5103b1, 0xada4007e, 0x00000000}},  //   gers, _lågt, каўл,
  { {0x7ae438ab, 0x6e2401bc, 0xad9b0051, 0x00000000}},  //   fait, _esib, ntúi,
  { {0x6d5e0211, 0x7ae4002d, 0x00000000, 0x00000000}},  //   _elpa, gait,   ,
  { {0x753a0493, 0xad9b0051, 0x9f460161, 0x00000000}},  // [fb90] _ontz, htúi, nulý_,
  { {0x6f1d03c7, 0x752805c9, 0x2127001d, 0x00000000}},  //   lesc, _nadz, _xanh_,
  { {0x9cd600b6, 0x7ae40c54, 0x2d910142, 0x00000000}},  //   _אותה_, bait, moze_,
  { {0x6f1d000d, 0x753a022b, 0x2d9100b5, 0x00000000}},  //   nesc, _antz, loze_,
  { {0xc10e0082, 0x60ca00ea, 0xa3dc01f5, 0x00000000}},  //   _rỗng_, _offm, तीस_,
  { {0x64a509b2, 0xd6d70044, 0xf56800a1, 0x00000000}},  //   нала, _হাওয, ومنٹ_,
  { {0x6f1d007f, 0x21270082, 0x68e500b0, 0x00000000}},  //   kesc, _ranh_, mahd,
  { {0x753a19f5, 0x2d910061, 0x7d1c014a, 0x00000000}},  //   _entz, hoze_, zers,
  { {0x2d910061, 0x2ee004f2, 0x44c70065, 0x00000000}},  //   koze_, _reif_, _tё_,
  { {0x2901011c, 0x2ee00020, 0x6f044022, 0x00000000}},  //   ngha_, _seif_, _scic,
  { {0x61fb0009, 0x7ae400e7, 0x6e240066, 0x00000000}},  //   suul, yait, _ssib,
  { {0x6f1d04e5, 0x7d1c0036, 0x6d890027, 0x00000000}},  //   gesc, wers, hľad,
  { {0x80de0055, 0x7ae40f38, 0x7d1c4023, 0x00000000}},  //   _মার্, vait, ters,
  { {0x61e908ce, 0x7ae4018e, 0xd1380036, 0x00000000}},  //   msel, wait, gląd_,
  { {0x61e90160, 0x69cf001e, 0x7ae40094, 0x00000000}},  //   lsel, _atce, tait,
  { {0x6f1d241d, 0x44251494, 0x69c4002b, 0x00000000}},  //   cesc, _msl_, tqie,
  { {0x61e9081d, 0x7ae4002a, 0xf2d2061e, 0x00000000}},  // [fba0] nsel, rait, טען_,
  { {0x7ae44024, 0x61e900b0, 0x44250d44, 0x00000000}},  //   sait, isel, _osl_,
  { {0x75280036, 0x69cf1016, 0x62990016, 0x00000000}},  //   _radz, _etce, _lywo,
  { {0xaa460b5f, 0x61e91be4, 0xdc77007b, 0x00000000}},  //   _земл, ksel, _טעיפ_,
  { {0x44250197, 0x61e90030, 0x67294025, 0x00000000}},  //   _asl_, jsel, _daej,
  { {0x61e905b7, 0x6f1d4026, 0xdb1e237c, 0x00000000}},  //   dsel, zesc, _supè,
  { {0x61e90190, 0xbf200061, 0x18a30256, 0x00000000}},  //   esel, _बसून_, _барм,
  { {0x4425010f, 0x62991ffe, 0x23a10010, 0x00000000}},  //   _dsl_, _bywo, tója_,
  { {0x36670f09, 0x6f1d0638, 0xd1300025, 0x00000000}},  //   _зато_, vesc, لمة_,
  { {0x04180044, 0x506601fc, 0x753a0032, 0x00000000}},  //   থিবী_, етма, _untz,
  { {0x74130084, 0x6f1d0035, 0xa3dc013d, 0x00000000}},  //   _مولا, tesc, तीश_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6f1d03c7, 0x2d910161, 0x00000000, 0x00000000}},  //   resc, toze_,   ,
  { {0x6b510073, 0x3014008b, 0x6f1d000d, 0x00000000}},  //   _någr, _адкр, sesc,
  { {0x6f1d001a, 0x44250056, 0xac9511a6, 0x00000000}},  //   pesc, _xsl_, тавш,
  { {0x409b009b, 0xddd000b9, 0x7bc3009d, 0x00000000}},  //   _מבוס, řeši, _énum,
  { {0x2d910263, 0x23850089, 0x00000000, 0x00000000}},  // [fbb0] poze_, nēja_,   ,
  { {0xfbd0026c, 0x7c250022, 0x00000000, 0x00000000}},  //   شتہ_, _tshr,   ,
  { {0x2d540004, 0xb8080025, 0xdb1c0010, 0x00000000}},  //   _päev_, فيلم_, gpró,
  { {0x45d50069, 0x57270025, 0x0675004c, 0x00000000}},  //   водс, عراق, куля,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x4a5a012e, 0x44252075, 0x61e9006c, 0x00000000}},  //   _חדשו, _psl_, vsel,
  { {0xa3dc0365, 0xd7f8012b, 0xdb1e00f4, 0x00000000}},  //   तील_, _пут_, _supé,
  { {0x61e9003c, 0x44254027, 0x2b4904eb, 0x00000000}},  //   tsel, _vsl_, njac_,
  { {0x35b5008b, 0xdb061e20, 0x61e9007f, 0x00000000}},  //   _абар, _shkë, usel,
  { {0xfa980049, 0x442510ea, 0x00000000, 0x00000000}},  //   עדזש_, _tsl_,   ,
  { {0xe5360049, 0x44250197, 0x62990036, 0x00000000}},  //   _שטעט_, _usl_, _wywo,
  { {0x61e903b6, 0x3f84006c, 0xdb0501a2, 0x00000000}},  //   psel, õmu_, _zuhö,
  { {0xc7b20476, 0xdb1c010f, 0xfe25007e, 0x00000000}},  //   יבט_, rprü, льён,
  { {0xdb1c010f, 0x332d1838, 0xf1ba0082, 0x00000000}},  //   sprü, ldex_, _giơ_,
  { {0xeb9a0265, 0x69cb1d66, 0xfce308d6, 0x00000000}},  //   див_, ígen, росо,
  { {0x332d4028, 0x00000000, 0x00000000, 0x00000000}},  //   ndex_,   ,   ,
  { {0x320d00f6, 0xdd8a0423, 0xeb97007c, 0x00000000}},  // [fbc0] ntey_, _обид_, тит_,
  { {0xa3c10316, 0x3d11006e, 0xe8f7019d, 0x00000000}},  //   ंदा_, द्दे_, клу_,
  { {0x23850089, 0xd70a01ab, 0x6b5800fa, 0x00000000}},  //   zēja_, днее_, _lígi,
  { {0x6d5c0089, 0x6561010e, 0x6e3608e0, 0x00000000}},  //   lkra, _allh, _kryb,
  { {0x660f00f8, 0xdb1c01e5, 0x00000000, 0x00000000}},  //   _äckl, spró,   ,
  { {0x6d5c0059, 0x6b831374, 0x23850089, 0x00000000}},  //   nkra, _íngr, vēja_,
  { {0x8af03f8c, 0xa3dc006e, 0x6f164002, 0x00000000}},  //   hkəm, तीं_, _obyc,
  { {0x040d001d, 0x2d54006c, 0x23850089, 0x00000000}},  //   _hướn, _käes_, tēja_,
  { {0x24920036, 0x6d5c000c, 0x60cd0180, 0x00000000}},  //   łym_, kkra, _şama,
  { {0xd5ae026c, 0x6d5c0142, 0x23850089, 0x00000000}},  //   _بہت_, jkra, rēja_,
  { {0x250b026c, 0x395700b6, 0x934604b6, 0x00000000}},  //   _ترقی_, דשים_, _инже,
  { {0x6d5c0277, 0xdcfc012d, 0xe4790049, 0x00000000}},  //   ekra, dorđ, _אָנש,
  { {0x6458010a, 0x6d5c4029, 0x6e36005b, 0x00000000}},  //   lyvi, fkra, _cryb,
  { {0xd12f0054, 0x6fca0164, 0x040d0011, 0x00000000}},  //   _ومن_, _संपू, _nướn,
  { {0xc04f0088, 0x30a3005e, 0x9f5f0023, 0x00000000}},  //   _ті_, _кръв, nutë_,
  { {0xe0b70049, 0x00000000, 0x00000000, 0x00000000}},  //   _בלוט_,   ,   ,
  { {0x6e360006, 0x48fe0204, 0x5f7400a2, 0x00000000}},  // [fbd0] _gryb, _लाखो_, _خاور,
  { {0x6d5c0039, 0x7bc10010, 0x6458402a, 0x00000000}},  //   ckra, ílus, kyvi,
  { {0x1aef0044, 0xc7f5012b, 0x2d830091, 0x00000000}},  //   ঙ্গে_, узећ, mnje_,
  { {0x29072608, 0x2bb40061, 0xfaff0065, 0x00000000}},  //   żna_, ंगणा, _emër_,
  { {0xd246039d, 0xb9090055, 0x7bc50504, 0x00000000}},  //   _ان_, _যা_, _huhu,
  { {0x7bc5000b, 0x24090d03, 0x6b581343, 0x00000000}},  //   _kuhu, енки_, _rígi,
  { {0x7bc51cc1, 0x37c400e2, 0x3f8200b4, 0x00000000}},  //   _juhu, _вљуб, ynku_,
  { {0xbebb008d, 0x6d5c0089, 0xe1f90006, 0x00000000}},  //   ndës, zkra, trų_,
  { {0x7bc504be, 0x2bb40061, 0x2d83183b, 0x00000000}},  //   _luhu, ंगता, knje_,
  { {0x2d83037e, 0xdb0f00c4, 0x040d0011, 0x00000000}},  //   jnje_, _ficç, _xướn,
  { {0x2d83092f, 0xdee6003b, 0x64580061, 0x00000000}},  //   dnje_, лони, cyvi,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x9f60000c, 0x5f0501f5, 0x6d5c073a, 0x00000000}},  //   _þrír_, _वार्_, tkra,
  { {0x31790049, 0x7bc50035, 0x8e7501e1, 0x00000000}},  //   _ראַד, _buhu, руюч,
  { {0x6d5c39ab, 0xd00e039d, 0xeb0f0061, 0x00000000}},  //   rkra, _فلو_, ाभूत_,
  { {0x7bc52626, 0x040d0011, 0x6e360036, 0x00000000}},  //   _duhu, _sướn, _tryb,
  { {0xa3ab00e8, 0x61fb00eb, 0x2d8300ca, 0x00000000}},  // [fbe0] _गठन_, nrul, bnje_,
  { {0x6d5a006c, 0x645d006b, 0x61fb0145, 0x00000000}},  //   ötad, _əsir, irul,
  { {0x7bc50061, 0x040d0082, 0x00000000, 0x00000000}},  //   _guhu, _vướn,   ,
  { {0x23850089, 0x61fb046a, 0xf7290088, 0x00000000}},  //   dējo_, krul, кцій_,
  { {0x040d001d, 0xe505006e, 0x7bc51e3a, 0x00000000}},  //   _tướn, _राशि_, _zuhu,
  { {0xad9b402b, 0x64580006, 0x61fb163a, 0x00000000}},  //   ltúr, tyvi, drul,
  { {0xbebb008d, 0x2918402c, 0x98a30089, 0x00000000}},  //   ndër, _ibra_, _tajā_,
  { {0x6b841aef, 0x2d8312d6, 0x69c60bd5, 0x00000000}},  //   nnig, znje_, _kuke,
  { {0xa686005e, 0xd25002fd, 0x7ae612fd, 0x00000000}},  //   _слад, زند_, _mekt,
  { {0xd1300167, 0x69c6023a, 0xb426035b, 0x00000000}},  //   آمد_, _muke, _معصو,
  { {0x69c61b51, 0xad9b1c59, 0x660200b0, 0x00000000}},  //   _luke, ktúr, luok,
  { {0xa3c10309, 0x7ae62d0f, 0x7bc50c04, 0x00000000}},  //   ंदर_, _nekt, _ruhu,
  { {0x291806c2, 0x69c60006, 0x2d830825, 0x00000000}},  //   _obra_, _nuke, tnje_,
  { {0x7bc508b2, 0xbd450025, 0xa903007d, 0x00000000}},  //   _puhu, جنسي, _लाइफ_,
  { {0x69c6022b, 0x7ae616b4, 0x2d830c1e, 0x00000000}},  //   _auke, _bekt, rnje_,
  { {0x2d83037e, 0x6602007f, 0x29180285, 0x00000000}},  //   snje_, kuok, _abra_,
  { {0x49750878, 0x2d832794, 0x67220211, 0x00000000}},  // [fbf0] алас, pnje_, deoj,
  { {0x69c6008d, 0x7bc5000b, 0x66020006, 0x00000000}},  //   _duke, _tuhu, duok,
  { {0x290f0036, 0x7ae60232, 0x69c60032, 0x00000000}},  //   ęga_, _fekt, _euke,
  { {0x98140025, 0x7ae600d9, 0x61e2000a, 0x00000000}},  //   إبلا, _gekt, _owol,
  { {0xa509003b, 0x69c60009, 0x25be000a, 0x00000000}},  //   вела_, _guke, _bitl_,
  { {0x499300a1, 0x61fb014a, 0x23850089, 0x00000000}},  //   _ایئر, vrul, tējo_,
  { {0x67d40057, 0x97a709c0, 0x61e200f6, 0x00000000}},  //   _госу, _брал, _awol,
  { {0xe299008b, 0x78ba2c52, 0x986a0279, 0x00000000}},  //   кай_, _útva, lığa_,
  { {0xe6670cb7, 0x69c0009d, 0x163404dd, 0x00000000}},  //   _ство, _émet, _летя,
  { {0x50b501ee, 0x3f890145, 0x23850089, 0x00000000}},  //   исну, _ajau_, pējo_,
  { {0x68e72b0c, 0xa0a50081, 0x93190025, 0x00000000}},  //   _mejd, ранд, _لقاء_,
  { {0x75230207, 0xbebb0023, 0x68300010, 0x00000000}},  //   lenz, vdër, lódá,
  { {0x614501f9, 0x91e50216, 0x44270016, 0x00000000}},  //   _вела, _толе, lwn_,
  { {0x68e701ca, 0x75233734, 0x69c600ea, 0x00000000}},  //   _nejd, nenz, _ruke,
  { {0xad9b009f, 0x69c604a5, 0x61e2326f, 0x00000000}},  //   ttúr, _suke, _zwol,
  { {0x7523010f, 0x69c600b0, 0xee3a02dc, 0x00000000}},  //   henz, _puke, _ани_,

  { {0x7ae60056, 0xdb1d0666, 0x8d760151, 0x00000000}},  // [fc00] _vekt, _misè, _نادا,
  { {0x2fc70811, 0x75230526, 0xebe60920, 0x00000000}},  //   _kung_, jenz, _кооп,
  { {0x2d98008d, 0x752313f0, 0x7ae626bf, 0x00000000}},  //   more_, denz, _tekt,
  { {0x69c600b0, 0x66020006, 0x2d98051b, 0x00000000}},  //   _tuke, tuok, lore_,
  { {0x2fc7402d, 0x75230253, 0x68e70146, 0x00000000}},  //   _lung_, fenz, _fejd,
  { {0x75230fb1, 0x66020997, 0x2d98402e, 0x00000000}},  //   genz, ruok, nore_,
  { {0x2fc7006a, 0xf8aa013d, 0xdb1d000a, 0x00000000}},  //   _nung_, _करिय, _bisè,
  { {0x2d981202, 0xe3af0d3a, 0x9f5f009d, 0x00000000}},  //   hore_, وري_, puté_,
  { {0x75230253, 0x2d982cb2, 0x2fc700ea, 0x00000000}},  //   benz, kore_, _aung_,
  { {0xf8aa0201, 0x2fc7402f, 0x2d9829b5, 0x00000000}},  //   _कराय, _bung_, jore_,
  { {0x2fc7001d, 0x2d98002d, 0x656a0051, 0x00000000}},  //   _cung_, dore_, mhfh,
  { {0x2fc7001d, 0x442c0035, 0x00000000, 0x00000000}},  //   _dung_, _isd_,   ,
  { {0x2d980038, 0x98a70107, 0x442c0bec, 0x00000000}},  //   fore_, _čiča_, _hsd_,
  { {0x2d980617, 0xa1570b87, 0x7f88006b, 0x00000000}},  //   gore_, _вашу_, lıql,
  { {0x442c041e, 0x6c540072, 0x92e80044, 0x00000000}},  //   _jsd_, окру, বলী_,
  { {0x7523010f, 0x68e74030, 0x442c1fc2, 0x00000000}},  //   zenz, _sejd, _msd_,
  { {0x2d980007, 0x98a30046, 0x442c3120, 0x00000000}},  // [fc10] bore_, _mają_, _lsd_,
  { {0x2d98028c, 0x2fc7006a, 0x23660065, 0x00000000}},  //   core_, _yung_, _lloj_,
  { {0xd87901f7, 0x752301bc, 0x2fc70011, 0x00000000}},  //   دمات_, venz, _xung_,
  { {0xf77006b4, 0x7523002b, 0x3f990091, 0x00000000}},  //   وان_, wenz, nosu_,
  { {0x752313f0, 0x7aed03b6, 0x442c0197, 0x00000000}},  //   tenz, maat, _asd_,
  { {0x7aed02ae, 0x442c0051, 0x2ee90133, 0x00000000}},  //   laat, _bsd_, _leaf_,
  { {0x7523054f, 0xdb1d4031, 0x6f0d008e, 0x00000000}},  //   renz, _aisé, _ocac,
  { {0x75234032, 0x2d980065, 0x7aed003c, 0x00000000}},  //   senz, zore_, naat,
  { {0x75234033, 0x2fc70011, 0x2d980173, 0x00000000}},  //   penz, _sung_, yore_,
  { {0x0fd91036, 0x442c1a9b, 0x2fc70487, 0x00000000}},  //   льмы_, _fsd_, _pung_,
  { {0x2d980213, 0x6e2d0101, 0x7aed003c, 0x00000000}},  //   vore_, _asab, kaat,
  { {0x320409b6, 0x2fc70082, 0x6b5800f6, 0x00000000}},  //   bumy_, _vung_, _lígr,
  { {0x2d980198, 0xd00e00a6, 0x6e2d0010, 0x00000000}},  //   tore_, ولی_, _csab,
  { {0x61d600b6, 0x2fc70011, 0x5fcf0061, 0x00000000}},  //   _הוסף_, _tung_, _संपल,
  { {0x2d984034, 0x645c0004, 0x442c00ea, 0x00000000}},  //   rore_, _ürit, _xsd_,
  { {0x2d98008d, 0xd113007d, 0x256b01e3, 0x00000000}},  //   sore_, त्रण_, _følg_,
  { {0x20051fec, 0x7f440a15, 0xdb1e32b6, 0x00000000}},  // [fc20] luli_, _iniq, _cupá,
  { {0x7aed001c, 0xfe3701ce, 0xeaaf00a1, 0x00000000}},  //   aaat, _פריי_, رٹل_,
  { {0xb17a007b, 0x20050466, 0x7d5701ce, 0x00000000}},  //   נטער, nuli_, _הייד_,
  { {0x7aed0061, 0x7bdc3a9a, 0x6e2d0058, 0x00000000}},  //   caat, mpru, _ysab,
  { {0x2005011c, 0xdcf50089, 0x68f8025a, 0x00000000}},  //   huli_, lizā, _نکاح_,
  { {0x442c001a, 0x200500e7, 0x78ba0010, 0x00000000}},  //   _psd_, kuli_, _útvo,
  { {0xdcf5001e, 0x888400a6, 0xb97b0049, 0x00000000}},  //   nizā, _بیان, _ענלי,
  { {0xd32601fb, 0x51f8007c, 0xcc3b0049, 0x00000000}},  //   ськи, анию_, רעקט,
  { {0x637e0006, 0x42540014, 0x7f88013f, 0x00000000}},  //   gūna, زندر, rıql,
  { {0x77620066, 0x6f0d0197, 0x463b0049, 0x00000000}},  //   lkox, _scac, _געמע,
  { {0x442c001d, 0x2005001a, 0x6e2d4035, 0x00000000}},  //   _usd_, guli_, _ssab,
  { {0xd041005f, 0x3f670088, 0xd5be01c5, 0x00000000}},  //   nclə, стоб, žāda_,
  { {0x7aed4036, 0x88c00044, 0x225a004b, 0x00000000}},  //   vaat, েরিক, _حجاب_,
  { {0x41b6005e, 0x7aed00e7, 0xdb0d0048, 0x00000000}},  //   _усет, waat, rmaí,
  { {0x7aed001c, 0xd0b2005f, 0x317b009b, 0x00000000}},  //   taat, yğəm, _תרומ,
  { {0x317e002d, 0x6e2d0085, 0x00000000, 0x00000000}},  //   litz_, _tsab,   ,
  { {0x6e2d0129, 0x7aed003c, 0x656830a0, 0x00000000}},  // [fc30] _usab, raat, _oldh,
  { {0x7aed03b6, 0xb88201ca, 0xd058006b, 0x00000000}},  //   saat, čína, _sevə,
  { {0x6d4503a1, 0x3a290019, 0x7aed0103, 0x00000000}},  //   _inha, swap_, paat,
  { {0x317e0032, 0x00000000, 0x00000000, 0x00000000}},  //   hitz_,   ,   ,
  { {0x20054037, 0xf8ae00a6, 0x940b0061, 0x00000000}},  //   zuli_, _یکم_, सूनच_,
  { {0x99890046, 0x637e0006, 0x23d50072, 0x00000000}},  //   stał_, vūna, оцир,
  { {0x317e0288, 0xa349004d, 0x00000000, 0x00000000}},  //   ditz_, изка_,   ,
  { {0x6fcf02fb, 0xe1f9019d, 0x6568000c, 0x00000000}},  //   _संबं, аги_, _eldh,
  { {0xc79600a1, 0x6d4500b0, 0xdc3c0802, 0x00000000}},  //   _بھلا_, _onha, váče,
  { {0x7f56006b, 0xbebb01d6, 0x317e0032, 0x00000000}},  //   _soyq, reël, gitz_,
  { {0xcea90097, 0xdb040051, 0x92f900f3, 0x00000000}},  //   _סי_, rmiú, _نفاذ_,
  { {0x60dc01f6, 0x6d454038, 0x25f0013d, 0x00000000}},  //   ırma, _anha, ुंची_,
  { {0xd109007a, 0x6d5700f8, 0x200500a9, 0x00000000}},  //   _نقشه_, _boxa, suli_,
  { {0xafe51662, 0x200500b0, 0xdcf50089, 0x00000000}},  //   _докл, puli_, tizā,
  { {0xeb7a06e3, 0xdb060010, 0x6da302dc, 0x00000000}},  //   асај_, _mikö, фира,
  { {0xe80d001c, 0x7f440549, 0x6d4500ab, 0x00000000}},  //   ांना_, _uniq, _enha,
  { {0x7bdc127c, 0xfaa30a30, 0xe9d70454, 0x00000000}},  // [fc40] spru, дато, жку_,
  { {0x77694039, 0x7bdc002b, 0x2cad00b9, 0x00000000}},  //   _alex, ppru, ředa_,
  { {0xad9b0051, 0x236d012d, 0x6c68009e, 0x00000000}},  //   srúc, khej_, _طلحہ_,
  { {0x99800006, 0xdcfc007f, 0x00000000, 0x00000000}},  //   tvių_, torė,   ,
  { {0x9b8a00a1, 0xd041006b, 0x236d0065, 0x00000000}},  //   _منگل_, rclə, dhej_,
  { {0x77690032, 0x9633007e, 0x00000000, 0x00000000}},  //   _elex, ьніц,   ,
  { {0x317e18d9, 0xdcf5001a, 0x77690905, 0x00000000}},  //   vitz_, liză, _flex,
  { {0x3958028c, 0x938a0098, 0x317e0f10, 0x00000000}},  //   _hors_, јска_, witz_,
  { {0x914a007e, 0x395802c0, 0x317e0032, 0x00000000}},  //   ачна_, _kors_, titz_,
  { {0x5503041f, 0x00000000, 0x00000000, 0x00000000}},  //   _опуб,   ,   ,
  { {0x6d57001a, 0x39580286, 0x317e0f30, 0x00000000}},  //   _roxa, _mors_, ritz_,
  { {0x395800f4, 0x317e010f, 0x6d5a0dac, 0x00000000}},  //   _lors_, sitz_, ötan,
  { {0x3ead0030, 0x6ce60061, 0x443e016e, 0x00000000}},  //   ået_, करंग_, _hrt_,
  { {0x3958010a, 0x7d1b0091, 0x443e225a, 0x00000000}},  //   _nors_, đuso, _krt_,
  { {0x6602403a, 0x443e06ed, 0x00000000, 0x00000000}},  //   hrok, _jrt_,   ,
  { {0x443e00b5, 0x3a22023a, 0x66020161, 0x00000000}},  //   _mrt_, _bpkp_, krok,
  { {0x39580007, 0x443e0bce, 0x4fb403d6, 0x00000000}},  // [fc50] _bors_, _lrt_, _تصور,
  { {0xc4c4026c, 0x443e403b, 0xad9b009f, 0x00000000}},  //   _لے_, _ort_, brúa,
  { {0x3958403c, 0x00000000, 0x00000000, 0x00000000}},  //   _dors_,   ,   ,
  { {0xe80c001c, 0x66020190, 0x00000000, 0x00000000}},  //   _हमरा_, frok,   ,
  { {0x8af0005f, 0x443e0e6e, 0x66270054, 0x00000000}},  //   rkət, _art_, تراك,
  { {0x443e00c4, 0x3958005b, 0xe5780088, 0x00000000}},  //   _brt_, _gors_, озі_,
  { {0x5fc60061, 0x00000000, 0x00000000, 0x00000000}},  //   _रंगल,   ,   ,
  { {0x660201b5, 0x224d002d, 0x443e00c4, 0x00000000}},  //   brok, txek_, _drt_,
  { {0x443e009f, 0x0ca8013d, 0x660200d9, 0x00000000}},  //   _ert_, _गर्म, crok,
  { {0x8af0006b, 0x60090140, 0x236d0023, 0x00000000}},  //   nkər, бном_, shej_,
  { {0x443e00bb, 0xdb1d0051, 0x225f01a3, 0x00000000}},  //   _grt_, _aisí, syuk_,
  { {0x88d10044, 0x9f5f00f6, 0x2a60013f, 0x00000000}},  //   িরিক, gutà_, yyib_,
  { {0x443e0010, 0x3ea4000c, 0xe28e01ee, 0x00000000}},  //   _zrt_, æmt_, _ча_,
  { {0xd2560104, 0xe80c013d, 0xad9b000c, 0x00000000}},  //   _משנה_, _हमला_, trúa,
  { {0xdb1d0051, 0x2b590129, 0x66020e0d, 0x00000000}},  //   _eisí, _bosc_, zrok,
  { {0x3958403d, 0x5aca00ed, 0xaffa0049, 0x00000000}},  //   _sors_, слам_, _פּוי,
  { {0x3f820bd6, 0x9b46026c, 0xe8fa0069, 0x00000000}},  // [fc60] miku_, _ہندو, йла_,
  { {0x23850089, 0xdcf50035, 0x9f5f0062, 0x00000000}},  //   mēju_, riză, vrté_,
  { {0x2b590115, 0xc7260242, 0x39583d4f, 0x00000000}},  //   _fosc_, здей, _vors_,
  { {0x66020168, 0xe5c60184, 0x395801d6, 0x00000000}},  //   trok, пско, _wors_,
  { {0xe5340057, 0x39580193, 0x7ae40020, 0x00000000}},  //   дель, _tors_, mbit,
  { {0x66020e33, 0x443e0093, 0x2bb4013d, 0x00000000}},  //   rrok, _prt_, ंगका,
  { {0x7bc6000b, 0x6ba70181, 0xe73a004d, 0x00000000}},  //   _kiku, _órgã, _лев_,
  { {0x443e07a0, 0x07a30245, 0xe76a039d, 0x00000000}},  //   _vrt_, _засн, _احسن_,
  { {0x3f8211b2, 0x7bc60142, 0xa6aa0b03, 0x00000000}},  //   diku_, _miku, _طارق_,
  { {0x7bc6001e, 0x443e1bae, 0x26c00006, 0x00000000}},  //   _liku, _trt_, žios_,
  { {0x3f8201d5, 0x6e240006, 0x443e0032, 0x00000000}},  //   fiku_, _apib, _urt_,
  { {0xdb0400f4, 0x69da00b9, 0x7bc60020, 0x00000000}},  //   blié, _čten, _niku,
  { {0x614604af, 0x3a3b0061, 0x62340ae0, 0x00000000}},  //   _неда, xvqp_, _целу,
  { {0xb2bb00a0, 0x7bc600b0, 0xdb1d00c4, 0x00000000}},  //   _המדר, _aiku, _visí,
  { {0xaeec0055, 0x7bc60009, 0x63a2002b, 0x00000000}},  //   _কারণ_, _biku, _kkon,
  { {0xdb1d0161, 0x7bc60690, 0x7ae402c6, 0x00000000}},  //   _tisí, _ciku, gbit,
  { {0x2aab0001, 0x63a2000b, 0x7bc6403e, 0x00000000}},  // [fc70] ство_, _mkon, _diku,
  { {0xd1380aec, 0x799e0455, 0x38c9025a, 0x00000000}},  //   ndą_, gopw, زائی_,
  { {0x63a20f9e, 0x2d830213, 0x764005d2, 0x00000000}},  //   _okon, mije_, _army,
  { {0x2d830213, 0x7bc6403f, 0x6d4f0107, 0x00000000}},  //   lije_, _giku, škač,
  { {0x6b8d0203, 0x00000000, 0x00000000, 0x00000000}},  //   mnag,   ,   ,
  { {0x2d830295, 0x63a2006a, 0x3f820091, 0x00000000}},  //   nije_, _akon, ziku_,
  { {0x26d2011f, 0x7bc60045, 0x2fdc00d9, 0x00000000}},  //   ıyor_, _yiku, _ntvg_,
  { {0xc245012b, 0x6b8d11be, 0x2d83016c, 0x00000000}},  //   дник, nnag, hije_,
  { {0x69c713df, 0x6b8d2627, 0x3f82006c, 0x00000000}},  //   _kije, inag, viku_,
  { {0x2d8301aa, 0x69cf0ce0, 0x7aef3e56, 0x00000000}},  //   jije_, _muce, _lect,
  { {0x3f824040, 0x7afd07ac, 0x69cf0211, 0x00000000}},  //   tiku_, _odst, _luce,
  { {0x69c70182, 0x6f0f001c, 0x69dd006c, 0x00000000}},  //   _lije, ggcc, _otse,
  { {0x3f82097f, 0x2d83021c, 0x7bc633d1, 0x00000000}},  //   riku_, fije_, _riku,
  { {0x7bc64041, 0x2d830bf8, 0x69c70091, 0x00000000}},  //   _siku, gije_, _nije,
  { {0xdca30920, 0x69dd1f2e, 0x7bc60145, 0x00000000}},  //   вари, _atse, _piku,
  { {0x6b8d19cd, 0x63a91147, 0x6f0f001c, 0x00000000}},  //   gnag, nlen, cgcc,
  { {0x2d83021d, 0x7bc64042, 0x7ae41b5c, 0x00000000}},  // [fc80] bije_, _viku, rbit,
  { {0x2d83092f, 0x69c70209, 0x0d83085f, 0x00000000}},  //   cije_, _cije, _альн,
  { {0x69c712e0, 0x63a906e6, 0x7bc64043, 0x00000000}},  //   _dije, klen, _tiku,
  { {0x68ee2893, 0x63bb1aa8, 0xdb1d0181, 0x00000000}},  //   _webd, jmun, _visã,
  { {0x63a94044, 0x4425088a, 0x63bb01e5, 0x00000000}},  //   dlen, _apl_, dmun,
  { {0x63a24045, 0x6b844046, 0x63a900b4, 0x00000000}},  //   _skon, liig, elen,
  { {0x63a90016, 0x44252b60, 0x00000000, 0x00000000}},  //   flen, _cpl_,   ,
  { {0xdb0d02d5, 0xf626098c, 0x6d5a0004, 0x00000000}},  //   rmaç, _одбо, ötaj,
  { {0x644115cd, 0x4425006c, 0x20050026, 0x00000000}},  //   _erli, _epl_, erli_,
  { {0xbe140044, 0x7bde0091, 0x64410087, 0x00000000}},  //   িবাদ_, _otpu, _frli,
  { {0x63a910a4, 0x6441037e, 0x2d830825, 0x00000000}},  //   blen, _grli, vije_,
  { {0x63a900f4, 0x63a20161, 0xdb0f00f6, 0x00000000}},  //   clen, _ukon, _licò,
  { {0x2d834047, 0x20050197, 0xc0460014, 0x00000000}},  //   tije_, arli_, سخگو,
  { {0x63a00232, 0x6e3d0190, 0x69cf145e, 0x00000000}},  //   lomn, rvsb, _ruce,
  { {0x69c70182, 0x69cf00d6, 0xe571007b, 0x00000000}},  //   _rije, _suce, אַן_,
  { {0x69c70209, 0x63a00107, 0x2d830340, 0x00000000}},  //   _sije, nomn, sije_,
  { {0x200c002b, 0x69c70091, 0x6b8d00f4, 0x00000000}},  // [fc90] ludi_, _pije, rnag,
  { {0x63a9014a, 0x9f5f0051, 0x63bb006b, 0x00000000}},  //   zlen, irtí_, zmun,
  { {0x69c70363, 0x7aef041d, 0x63a9014a, 0x00000000}},  //   _vije, _tect, ylen,
  { {0xf8df02f4, 0x28df02fb, 0x63a90061, 0x00000000}},  //   _प्रय, _प्रि, xlen,
  { {0x69c70209, 0x200c1cce, 0x69dd01c9, 0x00000000}},  //   _tije, hudi_, _utse,
  { {0x660b00c7, 0x212c0065, 0x63a903cd, 0x00000000}},  //   rugk, jedh_, wlen,
  { {0x63a90047, 0x03a508d6, 0x64a20175, 0x00000000}},  //   tlen, нико, лаша,
  { {0x4255026b, 0x23850089, 0x64410ce4, 0x00000000}},  //   етот, vējs_, _vrli,
  { {0x63a9011f, 0x26cd0d3f, 0x00000000, 0x00000000}},  //   rlen, _igeo_,   ,
  { {0x63bb000c, 0x44250e9b, 0xd5b11289, 0x00000000}},  //   smun, _tpl_, _صفا_,
  { {0x63bb0479, 0x3ea904cb, 0x200c012d, 0x00000000}},  //   pmun, _ayat_, gudi_,
  { {0xc27502ea, 0x63a00382, 0xb2750269, 0x00000000}},  //   _плеј, comn, _плеш,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x200508fb, 0x200c0091, 0x00000000, 0x00000000}},  //   prli_, budi_,   ,
  { {0x6ea002fb, 0x3f6a012b, 0xc4d2009b, 0x00000000}},  //   _गुरु, _нико_, רגל_,
  { {0x92c30055, 0xe9da007e, 0x645c00d4, 0x00000000}},  //   ্রী_, зка_, _àrie,
  { {0x6b84224c, 0xe1f90006, 0x3946007e, 0x00000000}},  // [fca0] riig, nsų_, ннаг,
  { {0x850e013d, 0x26cd0032, 0x6b8406ed, 0x00000000}},  //   _साइट_, _ageo_, siig,
  { {0x3c39013e, 0x00000000, 0x00000000, 0x00000000}},  //   rývá_,   ,   ,
  { {0x09e61c84, 0x68e301f6, 0xd6c40014, 0x00000000}},  //   _помн, ında, نمای,
  { {0x6d5e0059, 0x16342e54, 0x92c30044, 0x00000000}},  //   _kopa, теля, ্রু_,
  { {0x7af60922, 0x26cd0026, 0x6d5e0052, 0x00000000}},  //   layt, _egeo_, _jopa,
  { {0x6d5e0c2d, 0x69d60065, 0x5334005e, 0x00000000}},  //   _mopa, lqye, вейт,
  { {0x31c8007d, 0x8c1b00a0, 0x63750048, 0x00000000}},  //   रद्ध, לוצי, _lánf,
  { {0xc2980805, 0x320d2892, 0x200c0009, 0x00000000}},  //   ьких_, guey_, wudi_,
  { {0x63a00142, 0x200c4048, 0x02e0007d, 0x00000000}},  //   somn, tudi_, _ग्रह_,
  { {0x63a04049, 0xb4cc0164, 0x69d60023, 0x00000000}},  //   pomn, रखी_, hqye,
  { {0x20020825, 0x200c28d3, 0x753a0032, 0x00000000}},  //   čki_, rudi_, _hatz,
  { {0x2fc90061, 0x753a010f, 0x200c404a, 0x00000000}},  //   _viag_, _katz, sudi_,
  { {0x6d5e00f4, 0x238c00b9, 0x6d89012d, 0x00000000}},  //   _copa, ději_, džac,
  { {0xfbd90055, 0x1fa7007c, 0x850e006e, 0x00000000}},  //   ধীনত, _приг, _साईट_,
  { {0x7af6404b, 0x9b580256, 0x753a002d, 0x00000000}},  //   gayt, нист_, _latz,
  { {0x7f4d404c, 0x00000000, 0x00000000, 0x00000000}},  // [fcb0] _inaq,   ,   ,
  { {0x7cd9007c, 0x93bc0035, 0x753a0032, 0x00000000}},  //   _юмор_, _spăl, _natz,
  { {0x7f4d0023, 0x00000000, 0x00000000, 0x00000000}},  //   _knaq,   ,   ,
  { {0xdddd0036, 0x7f4d002b, 0x00000000, 0x00000000}},  //   mysł, _jnaq,   ,
  { {0x753a022b, 0x26c2013e, 0x7f4d0066, 0x00000000}},  //   _batz, _úkol_, _mnaq,
  { {0xceb400a0, 0x753a00e5, 0x6d5e00f6, 0x00000000}},  //   ניס_, _catz, _xopa,
  { {0x753a404d, 0xd4e40088, 0x00000000, 0x00000000}},  //   _datz, уючи,   ,
  { {0x6604016c, 0x78b500ca, 0x00000000, 0x00000000}},  //   šika, _izzv,   ,
  { {0xa53501e0, 0x45d50088, 0x753a0035, 0x00000000}},  //   _инач, _розс, _fatz,
  { {0x673b0020, 0x753a002d, 0xeeeb0082, 0x00000000}},  //   _hauj, _gatz, ướng_,
  { {0xdee60216, 0x92c30044, 0x7f5f01f3, 0x00000000}},  //   кони, ্রে_, _boqq,
  { {0x6d5e2136, 0x2d910207, 0x673b0288, 0x00000000}},  //   _sopa, enze_, _jauj,
  { {0x6d5e0036, 0x9f5f00b0, 0x4de20044, 0x00000000}},  //   _popa, yttö_, _বিহং,
  { {0xdb1d0f3c, 0x6025008b, 0x61fb27d2, 0x00000000}},  //   _lisä, _адка, msul,
  { {0xdca601fe, 0x61fb26d3, 0xddca0010, 0x00000000}},  //   тави, lsul, ínűl,
  { {0x673b0736, 0x98a700b9, 0x2d91404e, 0x00000000}},  //   _nauj, žně_, anze_,
  { {0x6d5e002d, 0x81e50055, 0x7af60288, 0x00000000}},  // [fcc0] _topa, _ফিড_, rayt,
  { {0xbef20061, 0x7af600e0, 0x00000000, 0x00000000}},  //   _अजुन_, sayt,   ,
  { {0x61fb006b, 0x673b010f, 0x00000000, 0x00000000}},  //   hsul, _bauj,   ,
  { {0x61fb08af, 0x753a01a2, 0x6a86007c, 0x00000000}},  //   ksul, _satz, _алма,
  { {0x9f5900f4, 0x637500f1, 0x00000000, 0x00000000}},  //   éré_, _mánd,   ,
  { {0xb4cc0061, 0xe5e50025, 0x6e29014a, 0x00000000}},  //   रखे_, اثني, çebi,
  { {0x29180180, 0xbef20061, 0xe9df001d, 0x00000000}},  //   _icra_, _अजून_, _trúc_,
  { {0x442001d5, 0x60cd014a, 0x673b404f, 0x00000000}},  //   ċi_, _şamp, _gauj,
  { {0x171b007b, 0x75820123, 0x61fb011c, 0x00000000}},  //   _קומע, _پیغم, gsul,
  { {0x71740b59, 0x673b120f, 0x7f5f0026, 0x00000000}},  //   اهدا, _zauj, _soqq,
  { {0x7bda008e, 0x63750048, 0x00000000, 0x00000000}},  //   ítul, _bánd,   ,
  { {0x6375004a, 0xbb1b0035, 0xbebb01d6, 0x00000000}},  //   _cánd, _amîn, deër,
  { {0x5f941277, 0x76420e5e, 0x6375008e, 0x00000000}},  //   рият, nvoy, _dánd,
  { {0x7e600039, 0x61ed005a, 0x61e20e31, 0x00000000}},  //   ämpa, _çala, _itol,
  { {0x08f10044, 0x7f4d002b, 0x7f5f006b, 0x00000000}},  //   _চালু_, _tnaq, _toqq,
  { {0x22460387, 0xa05700a0, 0x29184050, 0x00000000}},  //   _krok_, _יסוד_, _acra_,
  { {0x33260009, 0xdb04000c, 0x201e1c86, 0x00000000}},  // [fcd0] _mbox_, rmið, ltti_,
  { {0xdb1d021e, 0xd7e701fb, 0x201e0197, 0x00000000}},  //   _sisä, відо, otti_,
  { {0x213e0061, 0x201e021e, 0xa9c40425, 0x00000000}},  //   idth_, ntti_, рстк,
  { {0x201e021e, 0xaa590437, 0xd6db0088, 0x00000000}},  //   itti_, _зиму_, єте_,
  { {0xf7700123, 0x63b9018e, 0x98b1001a, 0x00000000}},  //   غام_, _rhwn, _bază_,
  { {0xe9df004a, 0xa9790049, 0x00000000, 0x00000000}},  //   _grúa_, _טאָכ,   ,
  { {0x61e23890, 0xdb040010, 0x22460022, 0x00000000}},  //   _atol, lliá, _arok_,
  { {0x61fb0be4, 0x22460b38, 0x33260f6d, 0x00000000}},  //   tsul, _brok_, _cbox_,
  { {0x68f50047, 0x201e1c89, 0x61fb0032, 0x00000000}},  //   _kezd, etti_, usul,
  { {0x68f54051, 0x61fb1403, 0x63750010, 0x00000000}},  //   _jezd, rsul, _sánd,
  { {0x61fb000c, 0xbfc6005e, 0xa0690887, 0x00000000}},  //   ssul, лбок, хана_,
  { {0xeeeb00ad, 0x201804bd, 0x33264052, 0x00000000}},  //   ường_, ària_, _gbox_,
  { {0x65610039, 0x5fcf0309, 0x201e20b0, 0x00000000}},  //   _kolh, _संकल, atti_,
  { {0x68f50142, 0x90450439, 0x00000000, 0x00000000}},  //   _nezd, _منته,   ,
  { {0xab2a017a, 0xd0110025, 0x65610181, 0x00000000}},  //   нова_, _الع_, _molh,
  { {0xf09200b6, 0x29030010, 0x333f002b, 0x00000000}},  //   _לנו_, _adja_, ndux_,
  { {0xf2d2007b, 0x68f54053, 0xbebb01d6, 0x00000000}},  // [fce0] מען_, _bezd, seër,
  { {0x29030087, 0x00000000, 0x00000000, 0x00000000}},  //   _cdja_,   ,   ,
  { {0x9d1b007b, 0x00000000, 0x00000000, 0x00000000}},  //   _אויט,   ,   ,
  { {0x2a69000a, 0x6375004a, 0xe9df004a, 0x00000000}},  //   byab_, _yáne, _irún_,
  { {0x656101d9, 0xe9df000c, 0x98b10035, 0x00000000}},  //   _bolh, _trúa_, _pază_,
  { {0x65610181, 0xad9b4054, 0xceb30104, 0x00000000}},  //   _colh, trúi, ציג_,
  { {0x61e20db9, 0x3a2001aa, 0xb426026c, 0x00000000}},  //   _stol, ltip_, اعتو,
  { {0x69ce0066, 0x2b400129, 0x61e200ea, 0x00000000}},  //   _hibe, ndic_, _ptol,
  { {0x69ce0509, 0x65610181, 0xc1741192, 0x00000000}},  //   _kibe, _folh, илищ,
  { {0x6f044055, 0xe8e00011, 0x2ee00022, 0x00000000}},  //   _adic, _đớn_, _afif_,
  { {0x69ce4056, 0x05770025, 0x7e6000f8, 0x00000000}},  //   _mibe, _حملة_, ämpn,
  { {0x201e4057, 0x998901df, 0x236d0027, 0x00000000}},  //   rtti_, ktaş_, ckej_,
  { {0x11540f6f, 0x61e20047, 0xf1ba001d, 0x00000000}},  //   _вклю, _utol, _thơ_,
  { {0x6f0416ca, 0x442c01a3, 0x2d8a00fa, 0x00000000}},  //   _edic, _kpd_, gibe_,
  { {0x2903012d, 0x80db009b, 0x00000000, 0x00000000}},  //   _rdja_, _אחוז,   ,
  { {0x442c0093, 0x68f54058, 0x69ce0022, 0x00000000}},  //   _mpd_, _sezd, _aibe,
  { {0x3f8b0d01, 0x3d950088, 0x60d70065, 0x00000000}},  // [fcf0] micu_, _випр, _çamë,
  { {0x69ce027b, 0x2d8a0211, 0x6448051b, 0x00000000}},  //   _cibe, cibe_, _ordi,
  { {0x69ce020c, 0x383500e2, 0xdb1e004a, 0x00000000}},  //   _dibe, рнер, _cupó,
  { {0x3f8b0868, 0x69ce0270, 0x656104d3, 0x00000000}},  //   nicu_, _eibe, _solh,
  { {0x64480252, 0x442c4059, 0x8afa009b, 0x00000000}},  //   _ardi, _apd_, _בהרי,
  { {0x442c0093, 0x7aed26c4, 0x69ce10d2, 0x00000000}},  //   _bpd_, lbat, _gibe,
  { {0x65610007, 0xf99f01aa, 0x7bcf0dfc, 0x00000000}},  //   _volh, _avèg_, _kicu,
  { {0x7aed022b, 0x442c023a, 0x69ce1a19, 0x00000000}},  //   nbat, _dpd_, _zibe,
  { {0x3f8b037e, 0x6448022b, 0x7bcf001a, 0x00000000}},  //   dicu_, _erdi, _micu,
  { {0x7bcf405a, 0x442c0022, 0x236d120f, 0x00000000}},  //   _licu, _fpd_, skej_,
  { {0x8af0005f, 0x3f8b0107, 0x6e2d027e, 0x00000000}},  //   rkəz, ficu_, _apab,
  { {0x76490263, 0x8fa6005c, 0x7bcf001a, 0x00000000}},  //   _krey, раме, _nicu,
  { {0x200c21de, 0x6d890466, 0xee3702dc, 0x00000000}},  //   ardi_, ržan, аня_,
  { {0xeeeb001d, 0x427a009b, 0x63a405d2, 0x00000000}},  //   ưởng_, _באנג, čine,
  { {0x2d8a058a, 0x69ce0576, 0x6b66005e, 0x00000000}},  //   ribe_, _ribe, аква,
  { {0x3f8b0107, 0x69ce083a, 0x7aed011c, 0x00000000}},  //   cicu_, _sibe, gbat,
  { {0x2b4002e7, 0x69ce00b7, 0x7bcf04cb, 0x00000000}},  // [fd00] rdic_, _pibe, _dicu,
  { {0x67290006, 0x61ed002b, 0x3a200095, 0x00000000}},  //   _abej, _ħall, rtip_,
  { {0x7aed22b0, 0x69ce0190, 0xa856025f, 0x00000000}},  //   bbat, _vibe, штај,
  { {0x7649405b, 0x7bcf18b5, 0x70d20309, 0x00000000}},  //   _brey, _gicu, _सल्ल,
  { {0x442c010f, 0x7649008e, 0x61e900bb, 0x00000000}},  //   _spd_, _crey, jpel,
  { {0x3f8b037e, 0x7649000c, 0x320d0923, 0x00000000}},  //   zicu_, _drey, drey_,
  { {0x9cd7009b, 0x61e92b9e, 0x00000000, 0x00000000}},  //   בוצה_, epel,   ,
  { {0x7649000c, 0x200c0107, 0x320d0258, 0x00000000}},  //   _frey, vrdi_, frey_,
  { {0x3f8b0ebe, 0x7649375b, 0x63750211, 0x00000000}},  //   vicu_, _grey, _sánc,
  { {0x7aed001a, 0x64480059, 0x200c0059, 0x00000000}},  //   zbat, _trdi, trdi_,
  { {0x6448002d, 0x4034005e, 0x3f8b0091, 0x00000000}},  //   _urdi, щенс, ticu_,
  { {0x320d0145, 0x63ab012d, 0xde59007e, 0x00000000}},  //   brey_, _gkgn, гамі_,
  { {0xa116007a, 0x3f8b2d18, 0x7bcf0970, 0x00000000}},  //   _نوشت, ricu_, _ricu,
  { {0x7bcf0198, 0x3f8b037e, 0xac190175, 0x00000000}},  //   _sicu, sicu_, логу_,
  { {0x7bcf405c, 0x7aed00d9, 0x3f8b016e, 0x00000000}},  //   _picu, tbat, picu_,
  { {0xdb1e00d4, 0x6d5a0c43, 0x00000000, 0x00000000}},  //   _supò, ötar,   ,
  { {0x7aed000d, 0x4975008b, 0x7bcf004a, 0x00000000}},  // [fd10] rbat, блас, _vicu,
  { {0x6375000c, 0x7aed002d, 0x628d016c, 0x00000000}},  //   _mána, sbat, _žaok,
  { {0xd24601ef, 0x63752363, 0x7bcf00e5, 0x00000000}},  //   _کن_, _lána, _ticu,
  { {0x76490173, 0xdc360049, 0x6e440014, 0x00000000}},  //   _prey, _פארט_, _انیم,
  { {0x6375009f, 0xd6d90036, 0xa5090216, 0x00000000}},  //   _nána, _cała_, гела_,
  { {0x2a3a0049, 0x6b8d0238, 0xdcfe00e5, 0x00000000}},  //   _געשמ, liag, _impă,
  { {0x69c50bdf, 0x00000000, 0x00000000, 0x00000000}},  //   mmhe,   ,   ,
  { {0x7649000c, 0x6b8d01a3, 0xc5e60044, 0x00000000}},  //   _trey, niag, _নিরপ,
  { {0x63750051, 0x81df0044, 0x61e90009, 0x00000000}},  //   _cána, ধীন_, upel,
  { {0x6b8d022b, 0x320d0211, 0x61e90127, 0x00000000}},  //   hiag, rrey_, rpel,
  { {0xa0a5008b, 0x61e93841, 0x6b8d2558, 0x00000000}},  //   санд, spel, kiag,
  { {0x61e91d18, 0xe3b003ec, 0x6375405d, 0x00000000}},  //   ppel, _قرن_, _fána,
  { {0xaaa70204, 0x63a901d6, 0x00000000, 0x00000000}},  //   _कुलक, moen,   ,
  { {0x63a91158, 0x61e6405e, 0x00000000, 0x00000000}},  //   loen, íkle,   ,
  { {0xdd8f002c, 0xc0c8003b, 0xbddb0173, 0x00000000}},  //   روف_, _куће_, nvèj,
  { {0xef1a007c, 0x63a91b61, 0x6b8d1e17, 0x00000000}},  //   _сми_, noen, giag,
  { {0x3de20044, 0x2d9a00c4, 0x00000000, 0x00000000}},  // [fd20] _বিকল, _tjpe_,   ,
  { {0x63a900b5, 0xd9100123, 0xe8f7105c, 0x00000000}},  //   hoen, بیس_, йлу_,
  { {0x63a9002d, 0x6b8d142e, 0x46ea00e2, 0x00000000}},  //   koen, biag, гден_,
  { {0x7c3e0363, 0x69c500c7, 0xc795007e, 0x00000000}},  //   _ispr, amhe, орчы,
  { {0x63a901bb, 0x2d98008e, 0x200300ca, 0x00000000}},  //   doen, onre_, šjih_,
  { {0x9633007e, 0x3ea001d6, 0x7c3e405f, 0x00000000}},  //   яніц, _mxit_, _kspr,
  { {0xf74602b8, 0xe3af02fd, 0x27ed012d, 0x00000000}},  //   _лево, کرو_, _čeng_,
  { {0x63a9002d, 0xd377007e, 0x2b420087, 0x00000000}},  //   goen, йчы_, _jakc_,
  { {0x3ea00023, 0x00000000, 0x00000000, 0x00000000}},  //   _nxit_,   ,   ,
  { {0xe80d001c, 0x7c3e0142, 0x6b8d0032, 0x00000000}},  //   ांचा_, _ospr, ziag,
  { {0x649a00aa, 0x63a90039, 0x7c3e0109, 0x00000000}},  //   _стар_, boen, _nspr,
  { {0x443e08ba, 0x83c60242, 0x289b00a3, 0x00000000}},  //   _ist_, _убеж, ריטא,
  { {0x6b8d0061, 0x82b61847, 0x71a6007e, 0x00000000}},  //   viag, _احاط, _ладз,
  { {0x6143007e, 0x00000000, 0x00000000, 0x00000000}},  //   _неча,   ,   ,
  { {0x443e0059, 0x6b8d1806, 0x3ea00133, 0x00000000}},  //   _jst_, tiag, _exit_,
  { {0x7c3e00eb, 0x236601ed, 0x00000000, 0x00000000}},  //   _dspr, _jooj_,   ,
  { {0x7c3e1017, 0x6b8d00f4, 0x443e3c70, 0x00000000}},  // [fd30] _espr, riag, _lst_,
  { {0x443e006c, 0x63a94060, 0x8895005e, 0x00000000}},  //   _ost_, zoen, оизх,
  { {0x69c5002a, 0xdb0d0051, 0x63a90020, 0x00000000}},  //   rmhe, llaí, yoen,
  { {0xdb0d002a, 0x00000000, 0x00000000, 0x00000000}},  //   olaí,   ,   ,
  { {0x443e1d47, 0x637c008e, 0x00000000, 0x00000000}},  //   _ast_, _ménd,   ,
  { {0xd5af026c, 0xa3e90887, 0x443e016b, 0x00000000}},  //   رہا_, адка_, _bst_,
  { {0xdcf5001e, 0x7c3e0045, 0x00000000, 0x00000000}},  //   lizē, _xspr,   ,
  { {0x9f5f0051, 0x11e51867, 0x4209003b, 0x00000000}},  //   artú_, ожим, анио_,
  { {0x443e0a8d, 0x63a90039, 0xdcf50089, 0x00000000}},  //   _est_, roen, nizē,
  { {0x63a90215, 0x63a40213, 0x443e0943, 0x00000000}},  //   soen, čina, _fst_,
  { {0x25a0002a, 0x443e0784, 0x7dc00010, 0x00000000}},  //   éile_, _gst_, nöse,
  { {0xd6d90036, 0x1eca05a5, 0x200b036a, 0x00000000}},  //   _mało_, илни_, čci_,
  { {0xdb0d0051, 0x256b08e0, 0x00000000, 0x00000000}},  //   glaí, _følt_,   ,
  { {0x9f460051, 0x29cd0521, 0x00000000, 0x00000000}},  //   mplí_, _džak_,   ,
  { {0x3d1b03d7, 0x8c430256, 0x63754061, 0x00000000}},  //   _बारे_, мере, _jáno,
  { {0xdb040051, 0xe8e00082, 0x3ea00032, 0x00000000}},  //   lliú, _đốn_, _txit_,
  { {0xc33201f8, 0x39431a6c, 0xdb0d0051, 0x00000000}},  // [fd40] וון_, _bajs_, claí,
  { {0x61e40051, 0x9f5f008e, 0xad9b4062, 0x00000000}},  //   _éile, butó_, lsún,
  { {0xb17a0049, 0x6d890107, 0x7c3e4063, 0x00000000}},  //   סטער, džah, _uspr,
  { {0xd3780091, 0xe51c0061, 0x9f5f0026, 0x00000000}},  //   _kuće_, _नाहि_, lutò_,
  { {0xe5c60264, 0x443e0145, 0xdcf50089, 0x00000000}},  //   оско, _sst_, cizē,
  { {0x7ae41651, 0x1dbc006e, 0x53e6005e, 0x00000000}},  //   lcit, ोगित, оциа,
  { {0x475a0ae0, 0x660218fb, 0xd37a01c0, 0x00000000}},  //   _края_, ssok, ичи_,
  { {0x68fc0007, 0x7ae4060c, 0x93bc001a, 0x00000000}},  //   _herd, ncit, _apăr,
  { {0xa5f701f9, 0x2e24000c, 0x98b800e5, 0x00000000}},  //   _меѓу_, jöf_, _fară_,
  { {0x443e00c4, 0x317800b4, 0x98b800e5, 0x00000000}},  //   _tst_, órz_, _gară_,
  { {0x68fc04cb, 0x443e0036, 0xd8db0049, 0x00000000}},  //   _merd, _ust_, יקיר,
  { {0x65680065, 0x68fc014a, 0x7f4400fa, 0x00000000}},  //   _hodh, _lerd, _caiq,
  { {0x316700d9, 0x68fc1784, 0x7f4402d4, 0x00000000}},  //   _fonz_, _oerd, _daiq,
  { {0x68fc014a, 0xdb0d0051, 0xad9b0051, 0x00000000}},  //   _nerd, rlaí, asún,
  { {0x65680051, 0x00000000, 0x00000000, 0x00000000}},  //   _modh,   ,   ,
  { {0x65680065, 0xdcf50089, 0x7ae41ea6, 0x00000000}},  //   _lodh, tizē, gcit,
  { {0x68fc4064, 0x637c0211, 0x29d50025, 0x00000000}},  // [fd50] _berd, _géne, سياس,
  { {0x68fc018e, 0xdcf50089, 0x6f1d0146, 0x00000000}},  //   _cerd, rizē, lgsc,
  { {0x2d914065, 0x4735005c, 0x39430064, 0x00000000}},  //   mize_, знес, _vajs_,
  { {0x6d45006a, 0x6f1d00b5, 0x68fc01b5, 0x00000000}},  //   _haha, ngsc, _eerd,
  { {0x6d45006a, 0x637c027b, 0x68fc0292, 0x00000000}},  //   _kaha, _xéne, _ferd,
  { {0x2d91265d, 0x68fc018e, 0x6d4501a3, 0x00000000}},  //   nize_, _gerd, _jaha,
  { {0x6d454066, 0x7afd0368, 0x69dd27a1, 0x00000000}},  //   _maha, _kest, _huse,
  { {0x7afd1f8a, 0x6d450811, 0x69dd000b, 0x00000000}},  //   _jest, _laha, _kuse,
  { {0x7afd0cce, 0x68fc005d, 0x2d910173, 0x00000000}},  //   _mest, _yerd, kize_,
  { {0x69dd0292, 0x7afd000c, 0x2901144f, 0x00000000}},  //   _muse, _lest, naha_,
  { {0x69d51111, 0x7afd00f7, 0xcea900a3, 0x00000000}},  //   _mize, _oest, _עי_,
  { {0x7afd4067, 0x2901006a, 0x69d508a0, 0x00000000}},  //   _nest, haha_, _lize,
  { {0x6d450085, 0x2d9101aa, 0x720500a1, 0x00000000}},  //   _baha, fize_, _عہدہ_,
  { {0x2d910061, 0x6d454068, 0x637c4069, 0x00000000}},  //   gize_, _caha, _véne,
  { {0x7afd406a, 0x69dd027b, 0x3079007b, 0x00000000}},  //   _best, _ause, _לאַנ,
  { {0x7afd0387, 0x69dd0056, 0x68fc406b, 0x00000000}},  //   _cest, _buse, _serd,
  { {0x7afd33a6, 0x2d84028c, 0x7ae404b4, 0x00000000}},  // [fd60] _dest, èmes_, rcit,
  { {0x7afd061f, 0x7ae40198, 0xe8e00011, 0x00000000}},  //   _eest, scit, _đồn_,
  { {0x69d502d5, 0x69dd005b, 0xeaaf00a1, 0x00000000}},  //   _dize, _euse, نٹہ_,
  { {0x68fc08ba, 0x69dd0a86, 0x6d45022b, 0x00000000}},  //   _werd, _fuse, _zaha,
  { {0x69d50854, 0x68fc020c, 0x69dd0009, 0x00000000}},  //   _fize, _terd, _guse,
  { {0x7afd0036, 0x290a0107, 0x6d45002b, 0x00000000}},  //   _zest, _udba_, _xaha,
  { {0x777b1f5b, 0x7afd00ab, 0x798e0009, 0x00000000}},  //   _flux, _yest, _imbw,
  { {0x63a40627, 0x7afd049a, 0xf743406c, 0x00000000}},  //   čino, _xest, _песо,
  { {0x20071089, 0x65680051, 0x2d912c0b, 0x00000000}},  //   _avni_, _todh, yize_,
  { {0xad9b002a, 0x44270009, 0x64410009, 0x00000000}},  //   gsúl, btn_, _fsli,
  { {0x6d452222, 0x2d911c5c, 0x7bde406d, 0x00000000}},  //   _raha, vize_, _nupu,
  { {0x6d450127, 0x929d0036, 0x2d9100d9, 0x00000000}},  //   _saha, wałe, wize_,
  { {0x2d9101aa, 0x6e3d02ae, 0x6d450127, 0x00000000}},  //   tize_, uwsb, _paha,
  { {0xeb9f00ea, 0x3b0b0045, 0x644101d6, 0x00000000}},  //   _sjø_, _sdcq_, _ysli,
  { {0x2d912fdb, 0x6d47002b, 0x69dd0255, 0x00000000}},  //   rize_, rdja, _suse,
  { {0x6d452c60, 0x69dd0089, 0x2d910857, 0x00000000}},  //   _waha, _puse, size_,
  { {0x6d451bdd, 0x2901168f, 0x6d89016c, 0x00000000}},  // [fd70] _taha, taha_, džav,
  { {0x6827007e, 0x3958009d, 0x9f5f0048, 0x00000000}},  //   зьдз, _cnrs_, istí_,
  { {0x69d50010, 0xb4bb0061, 0x68e50b19, 0x00000000}},  //   _vize, _घरे_, rchd,
  { {0x69dd093b, 0x2901020c, 0x5695007c, 0x00000000}},  //   _tuse, saha_, мает,
  { {0x69d50010, 0x8b0800b9, 0x69dd010e, 0x00000000}},  //   _tize, stří, _uuse,
  { {0x44270145, 0x2b49012d, 0x660d406e, 0x00000000}},  //   ttn_, ldac_, šako,
  { {0x98b80a67, 0x00000000, 0x00000000, 0x00000000}},  //   _parą_,   ,   ,
  { {0x2b4900e5, 0x77050014, 0x6f0d0045, 0x00000000}},  //   ndac_, _آژان, _ndac,
  { {0x3a2904cb, 0xa5f8007c, 0x44270c06, 0x00000000}},  //   ntap_, _нету_, stn_,
  { {0x60090264, 0xfaff0007, 0x442701a3, 0x00000000}},  //   оном_, _leë_, ptn_,
  { {0x64410166, 0x8fa6005e, 0x00000000, 0x00000000}},  //   _usli, дане,   ,
  { {0x6f0d0799, 0x00000000, 0x00000000, 0x00000000}},  //   _cdac,   ,   ,
  { {0x7bde1632, 0xe28e005e, 0xfaff01d6, 0x00000000}},  //   _supu, _ра_, _voël_,
  { {0x7bde20bc, 0xd13104e8, 0x01c800a1, 0x00000000}},  //   _pupu, _شمع_, _فونٹ_,
  { {0x2d840006, 0x224d03b5, 0xfce3030d, 0x00000000}},  //   ėme_, lvek_, тосо,
  { {0xd3780091, 0x05dd006e, 0x66090b18, 0x00000000}},  //   _kuća_, मदाब, _ovek,
  { {0xef190036, 0x2b590022, 0x27ed012d, 0x00000000}},  // [fd80] óże_, _dnsc_, _čena_,
  { {0x637c00f4, 0x7bde0052, 0x851c006e, 0x00000000}},  //   _ména, _tupu, _नाइट_,
  { {0xcb6a406f, 0x98b8012d, 0x6b8f0045, 0x00000000}},  //   _дане_, _marć_, _fmcg,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x6d890ce4, 0x6609016c, 0xeb3b009b, 0x00000000}},  //   ržav, _cvek, _ועכש,
  { {0x798e00e7, 0x00000000, 0x00000000, 0x00000000}},  //   _umbw,   ,   ,
  { {0xbddb02d0, 0x00000000, 0x00000000, 0x00000000}},  //   lvèt,   ,   ,
  { {0x637c0068, 0x7af60203, 0x00000000, 0x00000000}},  //   _béna, nbyt,   ,
  { {0xc29802d3, 0x998900b4, 0x00000000, 0x00000000}},  //   яких_, brań_,   ,
  { {0x99de007e, 0x637c0068, 0x00000000, 0x00000000}},  //   вiка_, _déna,   ,
  { {0x66090107, 0xa0a616e8, 0xf993009b, 0x00000000}},  //   _zvek, ьшил, כרז_,
  { {0xf99f000a, 0x77b800f6, 0x00000000, 0x00000000}},  //   _avèl_, fíxi,   ,
  { {0xdb0d04bd, 0x9df8004d, 0x00000000, 0x00000000}},  //   llaç, мнят_,   ,
  { {0x63ad25c2, 0xfaff01c3, 0x00000000, 0x00000000}},  //   čane, _seë_,   ,
  { {0x1fa7012b, 0x00000000, 0x00000000, 0x00000000}},  //   _ориг,   ,   ,
  { {0x3f8233dc, 0x9b580517, 0x7af61810, 0x00000000}},  //   chku_, мист_, gbyt,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  // [fd90]   ,   ,   ,
  { {0x2eaa0049, 0xc1780006, 0xfaff0007, 0x00000000}},  //   _משפּ, nkė_, _weë_,
  { {0x63a40091, 0x3a290007, 0x38c900a1, 0x00000000}},  //   činj, stap_, سائی_,
  { {0x8c1a007b, 0x3a2909d7, 0x2b590026, 0x00000000}},  //   _צורי, ptap_, _unsc_,
  { {0x65950fc0, 0x7bcd4070, 0x00000000, 0x00000000}},  //   наду, mmau,   ,
  { {0x63a200b0, 0xdb0d00c4, 0x7bcd4071, 0x00000000}},  //   _ajon, flaç, lmau,
  { {0x23d500ed, 0x637c009d, 0xf8690025, 0x00000000}},  //   нцир, _séna, _عمري_,
  { {0xc245003b, 0x130901fb, 0x66090039, 0x00000000}},  //   еник, чний_, _tvek,
  { {0x260900e8, 0x4615004b, 0x63a21a7c, 0x00000000}},  //   _सिटी_, _سوار, _djon,
  { {0xf1b90107, 0x8065004d, 0x7af600b9, 0x00000000}},  //   kuše_, евож, zbyt,
  { {0x2d83008d, 0xf1b9016c, 0x00000000, 0x00000000}},  //   dhje_, juše_,   ,
  { {0x92bd0055, 0x63a20065, 0xf1b94072, 0x00000000}},  //   _আলী_, _gjon, duše_,
  { {0x69c7021e, 0xa159003b, 0x00000000, 0x00000000}},  //   _ohje, _наду_,   ,
  { {0x63bb4073, 0x7bc6008d, 0x3f820065, 0x00000000}},  //   llun, _shku, shku_,
  { {0xdca301f9, 0x6d890006, 0x7af634fa, 0x00000000}},  //   гари, ežas, tbyt,
  { {0x63bb0030, 0xbb430fc0, 0x00000000, 0x00000000}},  //   nlun, леск,   ,
  { {0xfce60216, 0x63bb0444, 0x6ea800a1, 0x00000000}},  // [fda0] _попо, ilun, _زندہ_,
  { {0x63bb001f, 0xe9df00f6, 0xf1b9013e, 0x00000000}},  //   hlun, _arús_, buše_,
  { {0x69c7008d, 0x63bb05ad, 0x6d890733, 0x00000000}},  //   _dhje, klun, ržat,
  { {0x66e6007e, 0xb6a60745, 0x929d00b4, 0x00000000}},  //   хода, ниел, zała,
  { {0x63bb0da6, 0x6d8900d0, 0xe4e60088, 0x00000000}},  //   dlun, mžar, нійн,
  { {0x63a24074, 0xb6cb00a1, 0xb8f60025, 0x00000000}},  //   _sjon, سانے_, _سكرب,
  { {0x63bb01e5, 0x63a21978, 0x00000000, 0x00000000}},  //   flun, _pjon,   ,
  { {0x32660265, 0x63bb4075, 0x929d0036, 0x00000000}},  //   етов, glun, wała,
  { {0x6f06001e, 0xe1ef00d3, 0xdb0d0181, 0x00000000}},  //   dakc, یسی_, slaç,
  { {0xdb0d153c, 0x394a000a, 0x82330025, 0x00000000}},  //   plaç, _jabs_, اريا,
  { {0x63bb013e, 0x98b80036, 0x63a200d9, 0x00000000}},  //   blun, _parę_, _tjon,
  { {0x394a0089, 0x67224076, 0x63bb18fb, 0x00000000}},  //   _labs_, ngoj, clun,
  { {0x59b0001c, 0x2d830065, 0x6d890059, 0x00000000}},  //   जकार, thje_, džar,
  { {0x52d70097, 0x7ec90089, 0x00000000, 0x00000000}},  //   _נוגע_, _rūpī,   ,
  { {0x61e2021e, 0x41c30774, 0x213e0010, 0x00000000}},  //   _huol, _حقوق, meth_,
  { {0x213e19ff, 0x61e22985, 0x2d830065, 0x00000000}},  //   leth_, _kuol, shje_,
  { {0x201e01bc, 0x4fd8009b, 0x394a0007, 0x00000000}},  // [fdb0] luti_, _אוהב_, _babs_,
  { {0x394a27c2, 0x3d1b0061, 0x61e20026, 0x00000000}},  //   _cabs_, _बाटे_, _muol,
  { {0x201e0e1c, 0x39a4098c, 0xac990014, 0x00000000}},  //   nuti_, уштв, _آنجا_,
  { {0x6b84192b, 0x00000000, 0x00000000, 0x00000000}},  //   chig,   ,   ,
  { {0x69c7008d, 0x61e212ce, 0x213e0319, 0x00000000}},  //   _thje, _nuol, keth_,
  { {0xe4e701fb, 0x201e0149, 0x7d070134, 0x00000000}},  //   хідн, kuti_, najs,
  { {0x63bb000c, 0xad9b0051, 0xa4930bb6, 0x00000000}},  //   tlun, gsúi, دیات,
  { {0x201e01bc, 0x637c00f4, 0x2b4b00f6, 0x00000000}},  //   duti_, _déno, _jacc_,
  { {0x63bb0039, 0x201e0173, 0x6f0601ee, 0x00000000}},  //   rlun, euti_, vakc,
  { {0x63bb000c, 0x7d070023, 0x213e005b, 0x00000000}},  //   slun, jajs, geth_,
  { {0xf99f0263, 0x290304cb, 0x7d0706b8, 0x00000000}},  //   _avèk_, _meja_, dajs,
  { {0x213e018e, 0x290318bc, 0x22920014, 0x00000000}},  //   aeth_, _leja_, الیس,
  { {0x213e0016, 0x6f060036, 0x333f009d, 0x00000000}},  //   beth_, rakc, meux_,
  { {0x201e006a, 0x333f00f4, 0xc0e2007c, 0x00000000}},  //   buti_, leux_, _кошк,
  { {0x5c1509b5, 0x1c390077, 0x201e0035, 0x00000000}},  //   льту, нять_, cuti_,
  { {0x26df0020, 0x333f00f4, 0xbebb0065, 0x00000000}},  //   _nguo_, neux_, rfër,
  { {0xe9da0888, 0xbb43017f, 0x29034077, 0x00000000}},  // [fdc0] дка_, шетк, _beja_,
  { {0x63a406a6, 0x7d560049, 0x8c9601e1, 0x00000000}},  //   čini, _ייִד_, _армі,
  { {0x290307b9, 0x2d980ce0, 0x92bd0055, 0x00000000}},  //   _deja_, mire_, _আলো_,
  { {0x8a06102a, 0x2d984078, 0x6d4e0030, 0x00000000}},  //   _изме, lire_, ldba,
  { {0x394a0270, 0x29034079, 0x6722407a, 0x00000000}},  //   _tabs_, _feja_, rgoj,
  { {0x6f0423b7, 0x6375009f, 0x2d98303d, 0x00000000}},  //   _leic, _mánu, nire_,
  { {0x7c2e0039, 0x61e2407b, 0x43940517, 0x00000000}},  //   ntbr, _suol, лакс,
  { {0x61e22bb3, 0x201e0bd5, 0xe3af0380, 0x00000000}},  //   _puol, vuti_, يري_,
  { {0xc7d7012f, 0x2fc9018e, 0x69dc0c04, 0x00000000}},  //   _יולי_, _rhag_, _kire,
  { {0x61e20207, 0xd1300647, 0x201e0207, 0x00000000}},  //   _vuol, حمد_, tuti_,
  { {0x213e3e04, 0x6f040016, 0xd91b01ce, 0x00000000}},  //   reth_, _beic, וויל,
  { {0x6d5e0002, 0x6d4e1243, 0x61e2021e, 0x00000000}},  //   _anpa, edba, _tuol,
  { {0x2d980011, 0x69dc31b2, 0x6f040051, 0x00000000}},  //   fire_, _oire, _deic,
  { {0x201e04d4, 0x2d98160b, 0x69dc1b85, 0x00000000}},  //   puti_, gire_, _nire,
  { {0x2903008d, 0x6f0431f0, 0x7d070a10, 0x00000000}},  //   _reja_, _feic, rajs,
  { {0x290302d5, 0x69dc0211, 0x2d982d2e, 0x00000000}},  //   _seja_, _aire, aire_,
  { {0x2d98001a, 0x69dc014a, 0x26170061, 0x00000000}},  // [fdd0] bire_, _bire, _निधी_,
  { {0x2d980412, 0x6f04010f, 0x69dc023a, 0x00000000}},  //   cire_, _zeic, _cire,
  { {0x290302d5, 0xe7190025, 0x333f009d, 0x00000000}},  //   _veja_, فيات_, yeux_,
  { {0xf77006f1, 0x69dc0048, 0xe7050014, 0x00000000}},  //   يان_, _eire, اسای,
  { {0x333f00f4, 0x7aed407c, 0x29031b83, 0x00000000}},  //   veux_, mcat, _teja_,
  { {0x7aed0420, 0x69dc011f, 0xceb40097, 0x00000000}},  //   lcat, _gire, סיס_,
  { {0x7bdd0020, 0x333f009d, 0xf1b933dc, 0x00000000}},  //   _kisu, teux_, juša_,
  { {0x2d9801aa, 0x69dc022b, 0x2a6d0046, 0x00000000}},  //   zire_, _zire, _żeby_,
  { {0x7bdd0207, 0x333f028c, 0x6f04010f, 0x00000000}},  //   _misu, reux_, _reic,
  { {0x6f041625, 0x7aed0009, 0x7bdd0052, 0x00000000}},  //   _seic, hcat, _lisu,
  { {0x2d98407d, 0x6f041c7e, 0xc058007e, 0x00000000}},  //   vire_, _peic, віў_,
  { {0x7bdd0065, 0x6375407e, 0x32450084, 0x00000000}},  //   _nisu, _cánt, _منصف,
  { {0x6f04407f, 0x877a0049, 0x2d982172, 0x00000000}},  //   _veic, גארי, tire_,
  { {0x6f04010f, 0x7c2e0c7a, 0x9f5f00b0, 0x00000000}},  //   _weic, ttbr, estä_,
  { {0x2d984080, 0x6f044081, 0x7bdd1fe2, 0x00000000}},  //   rire_, _teic, _bisu,
  { {0x7aed001c, 0x7c2e01d6, 0x2d980e5f, 0x00000000}},  //   gcat, rtbr, sire_,
  { {0x320d01aa, 0x69dc0181, 0x7bdd04cb, 0x00000000}},  // [fde0] nsey_, _pire, _disu,
  { {0x6d5e2528, 0x7aed004a, 0x3a2001d6, 0x00000000}},  //   _unpa, acat, ruip_,
  { {0x7aed0541, 0x7bdd058b, 0xb17a0049, 0x00000000}},  //   bcat, _fisu, עטער,
  { {0x7aed4082, 0xdc9b00a3, 0x69dc00ab, 0x00000000}},  //   ccat, _טייל, _wire,
  { {0xd5ba045a, 0x69dc0549, 0x6375000c, 0x00000000}},  //   нск_, _tire, _láns,
  { {0x75d40076, 0x7bdd0035, 0x9f5f032e, 0x00000000}},  //   جيتا, _zisu, mstå_,
  { {0xf9830175, 0x764901aa, 0x07a605f6, 0x00000000}},  //   _угро, _esey, _бавн,
  { {0x0877007b, 0x5214017a, 0xf1b90166, 0x00000000}},  //   _געלט_, адит, vuša_,
  { {0xbb3b0049, 0x3f9911e4, 0x77910241, 0x00000000}},  //   געפי, visu_, _بینا,
  { {0xc3390010, 0x00000000, 0x00000000, 0x00000000}},  //   áírá,   ,   ,
  { {0xc05701e1, 0x9f5f00b0, 0x403404b6, 0x00000000}},  //   гія_, ystä_, шенс,
  { {0xe81c006e, 0x7dc00039, 0x00000000, 0x00000000}},  //   _पटना_, lösh,   ,
  { {0x7bdd0198, 0x3f990107, 0x957c0036, 0x00000000}},  //   _risu, risu_, _ciąg,
  { {0x091a0055, 0x7bdd0cfc, 0x7aed0009, 0x00000000}},  //   ন্তু_, _sisu, wcat,
  { {0x3f990161, 0x7bdd023e, 0x7aed02d4, 0x00000000}},  //   pisu_, _pisu, tcat,
  { {0x6e2d002b, 0x00000000, 0x00000000, 0x00000000}},  //   _tqab,   ,   ,
  { {0x7aed1b3e, 0xbda70879, 0xdb04000c, 0x00000000}},  // [fdf0] rcat, _محدو, rlið,
  { {0x7aed0375, 0x7bdd0093, 0xdb04000c, 0x00000000}},  //   scat, _wisu, slið,
  { {0x7bdd0209, 0x98c701bd, 0x00000000, 0x00000000}},  //   _tisu, усал,   ,
  { {0x290e1573, 0x2057009b, 0xa5f9012d, 0x00000000}},  //   ófar_, טיבל_, веду_,
  { {0xd2460644, 0xd1380036, 0x00000000, 0x00000000}},  //   _بن_, ciąg_,   ,
  { {0x5a9a0452, 0x27150011, 0x61e9006b, 0x00000000}},  //   _ישרא, ền_, vqel,
  { {0x6498005e, 0x00000000, 0x00000000, 0x00000000}},  //   лтър_,   ,   ,
  { {0x63ad0142, 0x091a0044, 0x320d1352, 0x00000000}},  //   čano, ন্দু_, tsey_,
  { {0x4175025a, 0x99800142, 0x00000000, 0x00000000}},  //   لادس, stiť_,   ,
  { {0x637501ca, 0x320d00ab, 0x9d270044, 0x00000000}},  //   _páns, rsey_, য়ুন_,
  { {0xd7a90204, 0x00000000, 0x00000000, 0x00000000}},  //   _कदाच,   ,   ,
  { {0x20182b3d, 0x6235041f, 0x320d1eb0, 0x00000000}},  //   ária_, _веду, psey_,
  { {0xde36007e, 0x39840039, 0x24a70089, 0x00000000}},  //   шэнь, _lösa_, šumā_,
  { {0xe2c80088, 0x8cb1013d, 0x00000000, 0x00000000}},  //   _слід_, _आँखो,   ,
  { {0x6da30794, 0x41260088, 0xeb9a2415, 0x00000000}},  //   цира, _тощо_, вив_,
  { {0x237f0161, 0x6fb30379, 0xdca30088, 0x00000000}},  //   nkuj_, _وموا, іати,
  { {0x6da601fb, 0x1d1a0077, 0xa3c80204, 0x00000000}},  // [fe00] _випа, _июнь_, ोगत_,
  { {0x9f5f1861, 0xe8f726f0, 0x00000000, 0x00000000}},  //   rstå_, илу_,   ,
  { {0xd116009b, 0x00000000, 0x00000000, 0x00000000}},  //   שקעה_,   ,   ,
  { {0xf1b9129d, 0x7c3e01d5, 0x9f5f01c9, 0x00000000}},  //   kušo_, _ippr, pstå_,
  { {0xf1b90089, 0x00000000, 0x00000000, 0x00000000}},  //   jušo_,   ,   ,
  { {0x5e57007b, 0x7b3e0036, 0x61e40051, 0x00000000}},  //   יינע_, _dłuż, _éili,
  { {0x98a30517, 0xe4b8008b, 0x3a322a1c, 0x00000000}},  //   _дире, ылкі_, ltyp_,
  { {0xea00001d, 0xd3780091, 0xfaff0007, 0x00000000}},  //   _luật_, _kući_, _hoër_,
  { {0x68e9001a, 0xe3af0070, 0x3a3201a2, 0x00000000}},  //   _şedi, برو_, ntyp_,
  { {0x7c3e0292, 0xaa370097, 0x637c009d, 0x00000000}},  //   _oppr, סטיק_, _méni,
  { {0x0496008b, 0xb36602dc, 0x637c0068, 0x00000000}},  //   _траў, _вълк, _léni,
  { {0x63a40059, 0x1df90783, 0x8af0006b, 0x00000000}},  //   čins, лемы_, ndəd,
  { {0x6f160016, 0x3ead0023, 0x00000000, 0x00000000}},  //   _ddyc, çet_,   ,
  { {0x443e2bde, 0x6f160036, 0x2d850036, 0x00000000}},  //   _kpt_, _edyc, óle_,
  { {0x25b90051, 0x8af0013f, 0x00000000, 0x00000000}},  //   _ísle_, kdəd,   ,
  { {0xdb0400f4, 0x7e62003b, 0x443e00c4, 0x00000000}},  //   nniè, _šope, _mpt_,
  { {0x443e0253, 0x00000000, 0x00000000, 0x00000000}},  // [fe10] _lpt_,   ,   ,
  { {0x443e0899, 0x29074083, 0x645a008e, 0x00000000}},  //   _opt_, úna_, _orti,
  { {0x6f16018e, 0x7b3e0036, 0x7e7d01c3, 0x00000000}},  //   _ydyc, _służ, lysp,
  { {0x30d90049, 0x60d90049, 0x637c4084, 0x00000000}},  //   אַנע, אַנג, _féni,
  { {0xf7700151, 0x98a701f6, 0xbb3a007b, 0x00000000}},  //   بال_, ını_, _גערי,
  { {0xd90f06c6, 0x99850054, 0x00000000, 0x00000000}},  //   _آیا_, _السو,   ,
  { {0x443e0145, 0x645a0166, 0xd7fb0545, 0x00000000}},  //   _cpt_, _crti, _југ_,
  { {0x443e0127, 0x201e016c, 0x645a0062, 0x00000000}},  //   _dpt_, drti_, _drti,
  { {0xd24e0379, 0x443e0190, 0x645c2779, 0x00000000}},  //   فني_, _ept_, _árin,
  { {0x05740647, 0x443e0011, 0x237f4085, 0x00000000}},  //   _والد, _fpt_, skuj_,
  { {0x200301aa, 0xc35502dc, 0x39510089, 0x00000000}},  //   èji_, _гълъ, _mazs_,
  { {0x083a0049, 0x765b03b3, 0x00000000, 0x00000000}},  //   נערל, _kruy,   ,
  { {0x201e3272, 0xf38c0049, 0xddc40035, 0x00000000}},  //   arti_, _בראָ, _criş,
  { {0x61fb020c, 0x7d170009, 0xea000082, 0x00000000}},  //   mpul, _cdxs, _quật_,
  { {0x7ff501fa, 0xddc4014a, 0x6ff501b7, 0x00000000}},  //   _استا, _eriş, _استط,
  { {0x637c4086, 0xd378016c, 0xeb97017a, 0x00000000}},  //   _péni, _pući_, бис_,
  { {0x61fb0032, 0x00000000, 0x00000000, 0x00000000}},  // [fe20] npul,   ,   ,
  { {0x186a012b, 0xbd4603ec, 0x673b00e7, 0x00000000}},  //   лази_, _اندي, _abuj,
  { {0x63ad0746, 0x7c3e03ed, 0x3a320210, 0x00000000}},  //   čanj, _uppr, styp_,
  { {0xdc3b007b, 0xcb6a01fb, 0xf7290088, 0x00000000}},  //   _געטר, _саме_, ицій_,
  { {0x9412005f, 0xa4f800a1, 0x765b00d4, 0x00000000}},  //   əcək_, لکار_, _cruy,
  { {0x86070025, 0x645a0bf8, 0x7d0e01a2, 0x00000000}},  //   حقوق_, _prti, nabs,
  { {0x29180026, 0x7e7d0036, 0x7bc4007f, 0x00000000}},  //   _idra_, zysp, oliu,
  { {0x645a0209, 0x201e18a2, 0x799e0020, 0x00000000}},  //   _vrti, vrti_, lipw,
  { {0xdb04028c, 0xa686008b, 0x7d0e0030, 0x00000000}},  //   rniè, _улад, kabs,
  { {0x20180fb3, 0x21660113, 0x64a6025f, 0x00000000}},  //   ário_, стиг, _лаза,
  { {0xc32a0054, 0xdb0f0047, 0x645a0032, 0x00000000}},  //   _مكان_, ődés, _urti,
  { {0x2d9a0093, 0x290a01ee, 0x7e7d0639, 0x00000000}},  //   _ampe_, _leba_, tysp,
  { {0x2918281a, 0x00000000, 0x00000000, 0x00000000}},  //   _odra_,   ,   ,
  { {0x291c0010, 0xc69301ce, 0x3ce50292, 0x00000000}},  //   óval_, לאר_, ølv_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xec340088, 0x8fa4025f, 0xce6b00ed, 0x00000000}},  //   янсь, _наје, _брод_,
  { {0x290a037e, 0x3a2000c7, 0x6f0f0197, 0x00000000}},  // [fe30] _beba_, grip_, macc,
  { {0x6f0f0207, 0x290a00d4, 0xe9190088, 0x00000000}},  //   lacc, _ceba_, рожі_,
  { {0x290a4087, 0x6d474088, 0x2606013d, 0x00000000}},  //   _deba_, meja, सीसी_,
  { {0x6f0f3b45, 0x6d471be3, 0xd3780091, 0x00000000}},  //   nacc, leja, _kuću_,
  { {0xf77001b7, 0x3669012d, 0x6bd700a1, 0x00000000}},  //   عام_, рало_, _پتھر,
  { {0x6d470181, 0xce3800b6, 0x9f480065, 0x00000000}},  //   neja, צאות_, _punë_,
  { {0xf8bf0164, 0x290101f3, 0x5fc90067, 0x00000000}},  //   _्रिय, mbha_, रताल,
  { {0x765b001d, 0x69c50016, 0x7dc0222d, 0x00000000}},  //   _truy, llhe, löst,
  { {0x6f0f029a, 0x6d47236c, 0x64580197, 0x00000000}},  //   dacc, keja, avvi,
  { {0x61fb2e93, 0x6d470022, 0x2d8300bb, 0x00000000}},  //   rpul, jeja, jkje_,
  { {0x6f0f4089, 0x3f89408a, 0x6d470006, 0x00000000}},  //   facc, _blau_, deja,
  { {0x6f0f001c, 0x44270149, 0x3f8904bd, 0x00000000}},  //   gacc, mun_, _clau_,
  { {0x44270fbd, 0x63a9006c, 0x25fd0061, 0x00000000}},  //   lun_, mnen, रीची_,
  { {0x6f0f001c, 0x6d470004, 0x63bb013e, 0x00000000}},  //   aacc, geja, loun,
  { {0x4427408b, 0xfce30264, 0x63a90239, 0x00000000}},  //   nun_, доро, onen,
  { {0x6f0f001c, 0x61eb408c, 0xbea60265, 0x00000000}},  //   cacc, _kugl, _майк,
  { {0x44270149, 0x61eb1308, 0x63a90052, 0x00000000}},  // [fe40] hun_, _jugl, inen,
  { {0x44271105, 0x63bb013e, 0x644100bb, 0x00000000}},  //   kun_, houn, _opli,
  { {0x61eb0198, 0x46ea0751, 0x63bb0173, 0x00000000}},  //   _lugl, аден_, koun,
  { {0xe73a0a27, 0x6b8d1a3b, 0x4427408d, 0x00000000}},  //   ред_, chag, dun_,
  { {0x63bb0211, 0x998902aa, 0xab5b010f, 0x00000000}},  //   doun, staš_, _thür,
  { {0xa2da02fb, 0x4427000c, 0x8c43011f, 0x00000000}},  //   _पृष्, fun_, ışve,
  { {0x61eb000c, 0x44270238, 0x799c0009, 0x00000000}},  //   _augl, gun_, _imrw,
  { {0x63a90374, 0x6d470036, 0x6b840032, 0x00000000}},  //   gnen, zeja, nkig,
  { {0xfbd300b6, 0xb6a30088, 0x7dc031da, 0x00000000}},  //   ותה_, _житл, nöss,
  { {0x44270169, 0xc05a007e, 0x61eb000c, 0x00000000}},  //   bun_, аім_, _dugl,
  { {0x6f0f141d, 0x4427028c, 0x61e301f6, 0x00000000}},  //   tacc, cun_, _dinl,
  { {0x91e601f9, 0x63bb0f44, 0x61eb3de6, 0x00000000}},  //   _доде, coun, _fugl,
  { {0x6f0f0555, 0x61eb408e, 0xb7db009b, 0x00000000}},  //   racc, _gugl, יקטי,
  { {0x6f0f0912, 0x26c40026, 0x637c1152, 0x00000000}},  //   sacc, _mymo_, _vénu,
  { {0x6d470006, 0xfe6e06c6, 0x672b05c8, 0x00000000}},  //   reja, نگی_, yggj,
  { {0x6d47033b, 0x63a0073a, 0x8af8006b, 0x00000000}},  //   seja, nimn, _şərq,
  { {0x4427408f, 0x628000ab, 0x6ce701ff, 0x00000000}},  // [fe50] zun_, nymo, _міне,
  { {0x44274090, 0x63ad0eae, 0x67f301d5, 0x00000000}},  //   yun_, čani, _aħja,
  { {0x7dc00002, 0xa3e601f5, 0x63bb0020, 0x00000000}},  //   röst, _यंग_, youn,
  { {0x44274091, 0x6b8409b0, 0x81c20044, 0x00000000}},  //   vun_, ckig, ্দি_,
  { {0xaaf60097, 0x64411d7a, 0x63a91962, 0x00000000}},  //   _מזרח_, _spli, vnen,
  { {0x442737a9, 0x6f0d4092, 0x61eb000c, 0x00000000}},  //   tun_, _leac, _rugl,
  { {0x63bb24bf, 0x61eb4093, 0x63a90027, 0x00000000}},  //   toun, _sugl, tnen,
  { {0x4427288b, 0x61eb0207, 0x059500d3, 0x00000000}},  //   run_, _pugl, _کارگ,
  { {0x44271113, 0x63a92c1f, 0x1306007c, 0x00000000}},  //   sun_, rnen, чный_,
  { {0x4427020c, 0x6b84002d, 0x63bb0133, 0x00000000}},  //   pun_, zkig, soun,
  { {0x7dc00047, 0x6f0d192b, 0x637c0010, 0x00000000}},  //   zöss, _beac, _pént,
  { {0x6f0d0051, 0x66090112, 0x61e3005b, 0x00000000}},  //   _ceac, _kwek, _winl,
  { {0x6f0d0051, 0xee3701fb, 0x203200a1, 0x00000000}},  //   _deac, пня_, وفیس,
  { {0x66090020, 0xf1b90089, 0x20110010, 0x00000000}},  //   _mwek, kuši_, ázis_,
  { {0xaffe001d, 0xf1b9001e, 0x6f0d0051, 0x00000000}},  //   _trướ, juši_, _feac,
  { {0xeb970a27, 0x6f0d00b5, 0x33f10285, 0x00000000}},  //   пис_, _geac, _máx_,
  { {0xada60140, 0x6b840032, 0x6b9d01f3, 0x00000000}},  // [fe60] _наил, rkig, _dmsg,
  { {0x6b840274, 0x998000ca, 0x63a000ca, 0x00000000}},  //   skig, stiž_, zimn,
  { {0x98a300ed, 0x628000b4, 0x660900a9, 0x00000000}},  //   нифе, zymo, _awek,
  { {0xdb240167, 0x66090045, 0x00000000, 0x00000000}},  //   _توحی, _bwek,   ,
  { {0x83fc0521, 0x66030959, 0xad9b004a, 0x00000000}},  //   _mrđe, епча, spúe,
  { {0xf1b90209, 0xdb0d000c, 0x186a1079, 0x00000000}},  //   buši_, llað, _лаги_,
  { {0x9f590065, 0x6609040f, 0xf99f0173, 0x00000000}},  //   ërë_, _ewek, _mwèl_,
  { {0x7af604a5, 0x6609000a, 0x00000000, 0x00000000}},  //   ncyt, _fwek,   ,
  { {0x6f0d0f12, 0xbebb0065, 0x2fd90009, 0x00000000}},  //   _reac, ngët, vmsg_,
  { {0x6f0d002a, 0xb6030224, 0xf99f01aa, 0x00000000}},  //   _seac, ášen, _nwèl_,
  { {0x65680018, 0x6f0d00ab, 0x62800016, 0x00000000}},  //   _indh, _peac, symo,
  { {0xfaff0065, 0x657a0048, 0x00000000, 0x00000000}},  //   _anën_, _hoth,   ,
  { {0x51180b5f, 0x657a0023, 0x6f0d0035, 0x00000000}},  //   _долю_, _koth, _veac,
  { {0x657a0022, 0x2fd90009, 0x6b9d00d9, 0x00000000}},  //   _joth, smsg_, _smsg,
  { {0x6f0d4094, 0x657a0531, 0x21570151, 0x00000000}},  //   _teac, _moth, _رجوع_,
  { {0x8bc4025f, 0xf1b94095, 0xe0850076, 0x00000000}},  //   есуд, vuši_, _تجهي,
  { {0xb5fd10c1, 0x2b490048, 0x00000000, 0x00000000}},  // [fe70] _krše, reac_,   ,
  { {0x657a00ab, 0x3a290022, 0xf1b901c5, 0x00000000}},  //   _noth, ruap_, tuši_,
  { {0x473500ed, 0xdb0d000c, 0xa3cc0061, 0x00000000}},  //   днес, blað, ळता_,
  { {0x65681659, 0xf1b901c5, 0x6609097e, 0x00000000}},  //   _andh, ruši_, _pwek,
  { {0xcd3400a6, 0xa3c0007d, 0xf1b94096, 0x00000000}},  //   _غریب, ंकन_, suši_,
  { {0x657a002a, 0x09e4008b, 0xceb40049, 0x00000000}},  //   _coth, _поўн, עיס_,
  { {0x6d5700f8, 0x657a2088, 0x00000000, 0x00000000}},  //   _maxa, _doth,   ,
  { {0xe1f9013b, 0x29130adb, 0x9f5f004a, 0x00000000}},  //   оги_, laxa_, istó_,
  { {0x6d57008e, 0x66090020, 0x657a0051, 0x00000000}},  //   _oaxa, _uwek, _foth,
  { {0x297a0049, 0x224d01d6, 0x00000000, 0x00000000}},  //   ַטרא, rwek_,   ,
  { {0xff26007c, 0x29380049, 0xbef90061, 0x00000000}},  //   ммно, לאזן_, ंडून_,
  { {0x6b83001a, 0x3f6a003b, 0x00000000, 0x00000000}},  //   _îngh, цимо_,   ,
  { {0xceb4005f, 0xa3b80b03, 0x6d57006b, 0x00000000}},  //   _edən_, _عامر_, _baxa,
  { {0x2d9e01aa, 0xf0b8007a, 0x6d5700c4, 0x00000000}},  //   òte_, _کاهش_, _caxa,
  { {0xef1f0279, 0xdb0d000c, 0xdca601ab, 0x00000000}},  //   mkün_, tlað, фави,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0xc33200b6, 0xfaa3041f, 0x6d570203, 0x00000000}},  // [fe80] כון_, вато, _faxa,
  { {0xe9d70500, 0x77694097, 0x2617013d, 0x00000000}},  //   дку_, _anex, _निजी_,
  { {0x657a0051, 0x2d0a0061, 0x00000000, 0x00000000}},  //   _roth, वरील_,   ,
  { {0x657a0abb, 0x00000000, 0x00000000, 0x00000000}},  //   _soth,   ,   ,
  { {0x657a0d00, 0x6d57006b, 0x00000000, 0x00000000}},  //   _poth, _yaxa,   ,
  { {0x2913004a, 0x776900d9, 0x00000000, 0x00000000}},  //   caxa_, _enex,   ,
  { {0xb1760011, 0xc7a6044b, 0xd6d90036, 0x00000000}},  //   _nhượ, _живк, _mały_,
  { {0x44200213, 0x7c37014a, 0x395800d9, 0x00000000}},  //   či_, _çarş, _hars_,
  { {0x657a0129, 0x07a3012b, 0x914a091b, 0x00000000}},  //   _toth, _ратн, очна_,
  { {0x660204d4, 0xa6970097, 0x9f5f009d, 0x00000000}},  //   mpok, _חכמה_, mpté_,
  { {0xb5fd0ab8, 0x201810fa, 0x39581e63, 0x00000000}},  //   _vrše, éri_, _mars_,
  { {0x395800eb, 0x59d0013d, 0x6e950a1e, 0x00000000}},  //   _lars_, _तीसर, еиму,
  { {0x6602002d, 0x5f94005e, 0xdb0600b0, 0x00000000}},  //   npok, тият, _ykkö,
  { {0xea00001d, 0xd6d90036, 0x39580058, 0x00000000}},  //   _xuất_, _cały_, _nars_,
  { {0x4c950545, 0x9fad013e, 0x00000000, 0x00000000}},  //   хивс, _měú_,   ,
  { {0x69d4006e, 0x395808e0, 0x798e0016, 0x00000000}},  //   _बीबी, _aars_, _albw,
  { {0x6d570181, 0x777b1824, 0x39580549, 0x00000000}},  // [fe90] _taxa, _roux, _bars_,
  { {0xc4c4009c, 0x395800ab, 0x66022041, 0x00000000}},  //   _نے_, _cars_, dpok,
  { {0x7d1501df, 0x395800ca, 0xf1b90079, 0x00000000}},  //   mazs, _dars_, mušt_,
  { {0x8af0005f, 0xea00001d, 0x39580133, 0x00000000}},  //   ndəl, _suất_, _ears_,
  { {0x77690011, 0x39581ce0, 0x2b590051, 0x00000000}},  //   _vnex, _fars_, _iasc_,
  { {0x39584098, 0xea000082, 0x00000000, 0x00000000}},  //   _gars_, _quất_,   ,
  { {0xf992009b, 0x29110032, 0x6fd6013e, 0x00000000}},  //   _גרם_, _ieza_, láce,
  { {0x58d4005c, 0x77690133, 0x29110045, 0x00000000}},  //   _рост, _unex, _heza_,
  { {0xb5c9026c, 0x8af0006b, 0x2b590048, 0x00000000}},  //   _فورم_, ddəl, _masc_,
  { {0xf992007b, 0xb1760011, 0x3cfb013d, 0x00000000}},  //   ָרט_, _phượ, ्रों_,
  { {0xcea901f8, 0x2cfb03d7, 0x29112367, 0x00000000}},  //   _פי_, ्रैल_, _meza_,
  { {0x63ad091e, 0xdef9008b, 0x2b5929c9, 0x00000000}},  //   čans, дыё_, _nasc_,
  { {0xe28e3e2e, 0x8db60088, 0x00000000, 0x00000000}},  //   _са_, есві,   ,
  { {0x29110061, 0xc69201ce, 0xef1f0047, 0x00000000}},  //   _neza_, ראך_, lkül_,
  { {0x8c43041f, 0x2b590129, 0x395800f6, 0x00000000}},  //   лере, _basc_, _rars_,
  { {0xffd6008b, 0x39580abb, 0x44270051, 0x00000000}},  //   _яўля, _sars_, irn_,
  { {0x39580ee5, 0x29110032, 0x44270471, 0x00000000}},  // [fea0] _pars_, _beza_, hrn_,
  { {0x2911014a, 0x3958013f, 0x00000000, 0x00000000}},  //   _ceza_, _qars_,   ,
  { {0x395822b0, 0x6d4e154f, 0x661b4099, 0x00000000}},  //   _vars_, meba, _avuk,
  { {0x6d5c2d47, 0x7e640065, 0x395801ac, 0x00000000}},  //   ldra, _krip, _wars_,
  { {0xe5c6013b, 0xb8f60055, 0x7bc63426, 0x00000000}},  //   нско, _হল_, _ikku,
  { {0x6d5c1992, 0x499100a1, 0x7e6400e7, 0x00000000}},  //   ndra, _پیمر, _mrip,
  { {0x6846007c, 0x66021712, 0x6d5c01c5, 0x00000000}},  //   _янва, spok, idra,
  { {0xddcd001a, 0x6d4e01a3, 0x2b400082, 0x00000000}},  //   _oraş, heba, nfic_,
  { {0x6d4e409a, 0xb5fd0107, 0x44270016, 0x00000000}},  //   keba, _vršc, arn_,
  { {0x6d4e016e, 0x6d5c409b, 0x44270e0d, 0x00000000}},  //   jeba, jdra, brn_,
  { {0x6d4e1244, 0x7bc6009f, 0x661b04c8, 0x00000000}},  //   deba, _okku, _zvuk,
  { {0xddcd001a, 0x7e640093, 0x6d5c08d8, 0x00000000}},  //   _braş, _brip, edra,
  { {0x63a2409c, 0x443c010e, 0x442e00c4, 0x00000000}},  //   _imon, ltv_, luf_,
  { {0x6d4e010f, 0x6d5c1aef, 0x7e64409d, 0x00000000}},  //   geba, gdra, _drip,
  { {0x3ce50073, 0x443c0190, 0x2b4000ab, 0x00000000}},  //   älv_, ntv_, ffic_,
  { {0xa3c003d7, 0x5ba40454, 0x7e640035, 0x00000000}},  //   ंकि_, груз, _frip,
  { {0x6d4e04cb, 0x63a2409e, 0x2b59016b, 0x00000000}},  // [feb0] beba, _mmon, _vasc_,
  { {0x442e409f, 0x6d4e0035, 0x443c0146, 0x00000000}},  //   kuf_, ceba, ktv_,
  { {0x63a20970, 0x7c2e008e, 0xa3c0006e, 0x00000000}},  //   _omon, cubr, ंका_,
  { {0x6a15007c, 0x291100e7, 0x8c1a00b3, 0x00000000}},  //   _имму, _weza_, _קורי,
  { {0x29110107, 0x6e3d2123, 0x7bcd2839, 0x00000000}},  //   _teza_, ntsb, mlau,
  { {0x83fc01a8, 0x64a5007e, 0x7bcd08ea, 0x00000000}},  //   _srđa, кала, llau,
  { {0x7bc6009f, 0x58d41737, 0x69c70023, 0x00000000}},  //   _ykku, _борт, _ikje,
  { {0xc24501fb, 0x7bcd1642, 0x44270a35, 0x00000000}},  //   вник, nlau, rrn_,
  { {0x6d5c07c3, 0x2489001e, 0x6d4e0e06, 0x00000000}},  //   ydra, ņam_, yeba,
  { {0x443c0c48, 0x7bcd0218, 0x63a2002d, 0x00000000}},  //   btv_, hlau, _emon,
  { {0x7bcd010a, 0xe0cf0055, 0x6d4e0190, 0x00000000}},  //   klau, রশ্ন, veba,
  { {0x7e64167a, 0x8fa60265, 0x6d450051, 0x00000000}},  //   _prip, таме, _abha,
  { {0x27760049, 0x6d5c1aef, 0x7bcd0ba5, 0x00000000}},  //   דערש_, tdra, dlau,
  { {0x7afd2c1a, 0x63a20006, 0xf1b9016c, 0x00000000}},  //   _afst, _zmon, krši_,
  { {0x6e3d0c4c, 0x711a0097, 0x7bcd1177, 0x00000000}},  //   atsb, _חוצפ, flau,
  { {0x2005002b, 0x39840210, 0x7c2e0bf3, 0x00000000}},  //   mpli_, _löst_, rubr,
  { {0x6f09049a, 0x6d5c40a0, 0x7c2e40a1, 0x00000000}},  // [fec0] ñece, pdra, subr,
  { {0x7afd000c, 0x7bcd0d8f, 0x660000ca, 0x00000000}},  //   _efst, alau, _rtmk,
  { {0x8af0005f, 0x38cb00a1, 0x200501aa, 0x00000000}},  //   ndək, وامی_, npli_,
  { {0xe7d00055, 0x7bcd00d4, 0x00000000, 0x00000000}},  //   িদ্য, clau,   ,
  { {0x442e0022, 0x63a20066, 0x00000000, 0x00000000}},  //   wuf_, _rmon,   ,
  { {0xdb0d00f4, 0x63a20197, 0x443c25e9, 0x00000000}},  //   nnaî, _smon, ttv_,
  { {0xb5fd041a, 0x61ea051b, 0x7f8600c4, 0x00000000}},  //   _vrša, _rifl, _hóqu,
  { {0x443c00d4, 0x7bc40035, 0xf48333ef, 0x00000000}},  //   rtv_, noiu, рушн,
  { {0x442e1c8a, 0xd25100a1, 0x443c01e5, 0x00000000}},  //   suf_, منٹ_, stv_,
  { {0xceb4006b, 0x69c30059, 0x443c133d, 0x00000000}},  //   _edək_, čneg, ptv_,
  { {0xb4250070, 0x7bcd08ea, 0x00000000, 0x00000000}},  //   _معنو, ylau,   ,
  { {0x331a06c6, 0x8383007c, 0x6e3d0aa4, 0x00000000}},  //   _آزاد_, _выше, ttsb,
  { {0x61ea2cfa, 0xdd910025, 0x00000000, 0x00000000}},  //   _tifl, موح_,   ,
  { {0x6e3d0056, 0x4034003b, 0x00000000, 0x00000000}},  //   rtsb, _бекс,   ,
  { {0x3a29001c, 0x7bcd000c, 0xebc7003b, 0x00000000}},  //   wrap_, tlau, вљан,
  { {0x3a2901d6, 0x69c70292, 0xf1b90091, 0x00000000}},  //   trap_, _skje, vrši_,
  { {0x7bcd0218, 0x7d021131, 0x6d41006c, 0x00000000}},  // [fed0] rlau, _şose, õlas,
  { {0x7bcd010a, 0x6d410009, 0x3a290146, 0x00000000}},  //   slau, òlad, rrap_,
  { {0x39840039, 0x7bcd046e, 0x764901a2, 0x00000000}},  //   _röst_, plau, _spey,
  { {0x2d81010f, 0x6d58000c, 0x56950242, 0x00000000}},  //   _hohe_, _óvar, лает,
  { {0x2d812033, 0x8af0006b, 0x6b8d00ea, 0x00000000}},  //   _kohe_, zdək, mkag,
  { {0x69c70056, 0x00000000, 0x00000000, 0x00000000}},  //   _ukje,   ,   ,
  { {0x03a5102a, 0x69c50065, 0x628608e0, 0x00000000}},  //   лико, mohe, økon,
  { {0x69c50065, 0xdb0400c4, 0x6b8d40a2, 0x00000000}},  //   lohe, rniç, nkag,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x69c50065, 0x6009007c, 0x27ed0011, 0x00000000}},  //   nohe, нном_, _hien_,
  { {0x27ed01d5, 0x6b8d177d, 0xf3350025, 0x00000000}},  //   _kien_, kkag, _مفاج,
  { {0x27ed01d5, 0x69c540a3, 0x8af0006b, 0x00000000}},  //   _jien_, hohe, rdək,
  { {0x61450551, 0x63a940a4, 0x69c5008d, 0x00000000}},  //   _бела, mien, kohe,
  { {0x27ed028c, 0x63a9001f, 0x69c50065, 0x00000000}},  //   _lien_, lien, johe,
  { {0x6b96018e, 0xa066005e, 0x69c50065, 0x00000000}},  //   thyg, _баща_, dohe,
  { {0x09be0183, 0x27ed40a5, 0x6b8d119d, 0x00000000}},  //   ्त्य, _nien_, gkag,
  { {0x39960030, 0x629b40a6, 0x7db603e6, 0x00000000}},  // [fee0] _læse_, nzuo, _مصدا,
  { {0x63a9022b, 0x7a47001e, 0x69c50065, 0x00000000}},  //   hien, dītā, gohe,
  { {0x27ed364e, 0x63a90fec, 0x6f160d59, 0x00000000}},  //   _bien_, kien, _keyc,
  { {0x63a9010a, 0x4b560265, 0x6d5e0020, 0x00000000}},  //   jien, _съот, _hapa,
  { {0x6d5e40a7, 0x63a90a98, 0x27ed3d1f, 0x00000000}},  //   _kapa, dien, _dien_,
  { {0x6b83001a, 0x63a901b5, 0x9f99009d, 0x00000000}},  //   _îngr, eien, réé_,
  { {0x69dc001f, 0x6d5e0b9a, 0x63a938ea, 0x00000000}},  //   _ihre, _mapa, fien,
  { {0x291a0169, 0x6d5e1116, 0x27ed40a8, 0x00000000}},  //   lapa_, _lapa, _gien_,
  { {0x171b0049, 0x7a470089, 0x5186007e, 0x00000000}},  //   _רומע, cītā, гуна,
  { {0x6d5e006a, 0x27ed02ae, 0x291a027e, 0x00000000}},  //   _napa, _zien_, napa_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x645a0163, 0x63a90781, 0x69c5008d, 0x00000000}},  //   _isti, cien, zohe,
  { {0x6d5e04cb, 0x69dc0fd6, 0x291a0056, 0x00000000}},  //   _bapa, _ohre, kapa_,
  { {0xf99f0263, 0xf23700b3, 0x69c50023, 0x00000000}},  //   _jwèt_, _ערוץ_, xohe,
  { {0x6d5e30bc, 0x291a1794, 0xfbd3023c, 0x00000000}},  //   _dapa, dapa_, متر_,
  { {0x9b5801e0, 0x6d61016c, 0x3b5500ed, 0x00000000}},  //   лист_, _žvać, јкар,
  { {0x27ed028c, 0x69c5008d, 0x69dc002a, 0x00000000}},  // [fef0] _rien_, tohe, _bhre,
  { {0x7f5f005f, 0x27ed0343, 0x645a002d, 0x00000000}},  //   _haqq, _sien_, _osti,
  { {0x69c5008d, 0x629b0197, 0x201e006c, 0x00000000}},  //   rohe, zzuo, nsti_,
  { {0x69c5008d, 0x201e0089, 0x7a470089, 0x00000000}},  //   sohe, isti_, tītā,
  { {0x63a90580, 0x6d5e011f, 0x27ed40a9, 0x00000000}},  //   vien, _yapa, _vien_,
  { {0x201e001e, 0x63a90046, 0x361a026c, 0x00000000}},  //   ksti_, wien, ئرنگ_,
  { {0x27ed0168, 0x7a47001e, 0xf99f01aa, 0x00000000}},  //   _tien_, sītā, _dwèt_,
  { {0x637c0010, 0x629b0032, 0x63a900c4, 0x00000000}},  //   _kény, tzuo, uien,
  { {0x645a06c0, 0x201e03b6, 0xe29900ed, 0x00000000}},  //   _esti, esti_, тап_,
  { {0x63a9010a, 0xd49b012b, 0x6f160253, 0x00000000}},  //   sien, _пре_, _seyc,
  { {0x63a92e3f, 0x6d5e033b, 0x637c0010, 0x00000000}},  //   pien, _rapa, _lény,
  { {0x6d5e006a, 0xdee601fc, 0xe47a0049, 0x00000000}},  //   _sapa, иони, _ברעכ,
  { {0x2d980051, 0x291a0058, 0x201e00b0, 0x00000000}},  //   thre_, yapa_, asti_,
  { {0xc0e50200, 0xf2d2009b, 0x6d5e006b, 0x00000000}},  //   _колк, _ועד_, _qapa,
  { {0x6d5e021e, 0xfce60f13, 0x403200ec, 0x00000000}},  //   _vapa, рово, _дејс,
  { {0x6d5e0020, 0x291a0020, 0xb5fd0bf8, 0x00000000}},  //   _wapa, wapa_, _pršl,
  { {0x6d5e021e, 0x637c0047, 0x69dc0124, 0x00000000}},  // [ff00] _tapa, _pénz, _phre,
  { {0x186a0369, 0x9d4600c0, 0xdcfe16d0, 0x00000000}},  //   кази_, _теод, _kopč,
  { {0x291a020c, 0x7d1c0051, 0xe8110061, 0x00000000}},  //   rapa_, mars, डीला_,
  { {0xf7460088, 0x637c0047, 0x291a003f, 0x00000000}},  //   редо, _fény, sapa_,
  { {0xf99f000a, 0x00000000, 0x00000000, 0x00000000}},  //   _pwèt_,   ,   ,
  { {0x7d1c009f, 0xd547005e, 0x23ba0089, 0x00000000}},  //   nars, ипче_, dīja_,
  { {0x9f4f00f6, 0x291800e5, 0x00000000, 0x00000000}},  //   _sufí_, _iera_,   ,
  { {0x7d1c0059, 0x29180065, 0x00000000, 0x00000000}},  //   hars, _hera_,   ,
  { {0x2918317c, 0x3a2040aa, 0x1dc6006e, 0x00000000}},  //   _kera_, nsip_, लकात,
  { {0x7d1c000c, 0x645a0009, 0x291804be, 0x00000000}},  //   jars, _tsti, _jera_,
  { {0x7d1c01d9, 0x29180039, 0xf48709bc, 0x00000000}},  //   dars, _mera_, _پالی,
  { {0x77620555, 0x291800f8, 0x27f80087, 0x00000000}},  //   ndox, _lera_, _murn_,
  { {0x6d8b006b, 0x7d1c29fc, 0x76420052, 0x00000000}},  //   _müav, fars, ntoy,
  { {0x29181395, 0x91e3003b, 0xdb040051, 0x00000000}},  //   _nera_, _доче, cniú,
  { {0xb0570025, 0x9d18007e, 0x5f7709b9, 0x00000000}},  //   _نشيط_, рост_, _ناظر,
  { {0x5bb8007c, 0x386d00b9, 0x853c0006, 0x00000000}},  //   ался_, _čer_, _smėl,
  { {0x6f1d010f, 0x291840ab, 0x7d1701f3, 0x00000000}},  // [ff10] masc, _bera_, _texs,
  { {0x7d1c40ac, 0x6f1d0207, 0xd1380006, 0x00000000}},  //   cars, lasc, ngą_,
  { {0x29180129, 0x6ff3000d, 0xfbd000a1, 0x00000000}},  //   _dera_, _făcu, ستہ_,
  { {0xf568026c, 0x6d550020, 0x637c0047, 0x00000000}},  //   یمنٹ_, leza, _tény,
  { {0x291800f4, 0x6f1d001a, 0xf7700a4f, 0x00000000}},  //   _fera_, iasc, ظام_,
  { {0x2918009f, 0x6d552367, 0x00000000, 0x00000000}},  //   _gera_, neza,   ,
  { {0xf8e50055, 0x88e50055, 0xb8950054, 0x00000000}},  //   _প্রথ, _প্রক, _الأع,
  { {0x44290213, 0x61b102fb, 0x23ba001e, 0x00000000}},  //   ča_, ीक्ष, tīja_,
  { {0x6d5540ad, 0x6f1d0129, 0x957c0036, 0x00000000}},  //   keza, dasc, _piąt,
  { {0x29010211, 0x6fd6008e, 0xdd000089, 0x00000000}},  //   ncha_, táco, ātīg,
  { {0x6f1d0207, 0x6d5510d2, 0x29010087, 0x00000000}},  //   fasc, deza, icha_,
  { {0x6f1d016e, 0xd1380006, 0x64431b0d, 0x00000000}},  //   gasc, agą_, mtni,
  { {0x656100b9, 0x6e2900b9, 0x00000000, 0x00000000}},  //   _kalh, šebn,   ,
  { {0x6d5500bb, 0xdcfe40ae, 0xdd920025, 0x00000000}},  //   geza, _topč, أوس_,
  { {0x64430eea, 0x7d1c0211, 0xab2a0088, 0x00000000}},  //   ntni, rars, лова_,
  { {0x2918028c, 0x7d1c0059, 0xfbdf0011, 0x00000000}},  //   _sera_, sars, _chê_,
  { {0x6d551526, 0x7d1c152b, 0x2918006a, 0x00000000}},  // [ff20] beza, pars, _pera_,
  { {0xf2d2007b, 0x64430039, 0x8af0005f, 0x00000000}},  //   לען_, ktni, ddət,
  { {0x29180635, 0x3a200207, 0x644340af, 0x00000000}},  //   _vera_, ssip_, jtni,
  { {0x290140b0, 0x2918002b, 0x764200f4, 0x00000000}},  //   acha_, _wera_, ttoy,
  { {0x64430036, 0x29180065, 0x9f480051, 0x00000000}},  //   etni, _tera_, _bunú_,
  { {0xb9960054, 0x644301bf, 0x27f800ab, 0x00000000}},  //   _السب, ftni, _turn_,
  { {0x6561011c, 0x64430737, 0x76422468, 0x00000000}},  //   _dalh, gtni, stoy,
  { {0xf74300a8, 0x6d552645, 0xbebb0023, 0x00000000}},  //   _несо, zeza, rgëz,
  { {0x6f1d0365, 0x27e60866, 0x65610181, 0x00000000}},  //   vasc, mmon_, _falh,
  { {0x6f0440b1, 0xd1380006, 0x656100c4, 0x00000000}},  //   _afic, ugą_, _galh,
  { {0x6d5501ae, 0x6f1d0598, 0x6f09008e, 0x00000000}},  //   veza, tasc, ñeco,
  { {0x8af0006b, 0x6d550d16, 0x27e61bcb, 0x00000000}},  //   ndəs, weza, nmon_,
  { {0x6f1d002a, 0x41e60106, 0x32060058, 0x00000000}},  //   rasc, _ліка, _utoy_,
  { {0x6f1d0061, 0xd0100a4f, 0x27e60065, 0x00000000}},  //   sasc, _قلت_, hmon_,
  { {0xfbdf0011, 0x6f1d3fce, 0x6d55016e, 0x00000000}},  //   _phê_, pasc, reza,
  { {0x6ab4001c, 0x00000000, 0x00000000, 0x00000000}},  //   ंपूर,   ,   ,
  { {0x6d550211, 0x75280036, 0x8af0006b, 0x00000000}},  // [ff30] peza, _oddz, ddəs,
  { {0x7e6d0b33, 0x644340b2, 0xf99f000a, 0x00000000}},  //   _irap, ytni, _etèn_,
  { {0x290140b3, 0xfbdf0082, 0x00000000, 0x00000000}},  //   rcha_, _thê_,   ,
  { {0x9be40451, 0x2901010f, 0x656100ea, 0x00000000}},  //   _ніяк, scha_, _salh,
  { {0xbb3a007b, 0xeb3a0049, 0xb5fd0746, 0x00000000}},  //   _דערי, _דערש, _krši,
  { {0x644340b4, 0x69ce01c3, 0x00000000, 0x00000000}},  //   ttni, _gkbe,   ,
  { {0x65611382, 0x81c30044, 0x224f0022, 0x00000000}},  //   _valh, ্ষম_, _spgk_,
  { {0x0205026b, 0x6561008a, 0x644340b5, 0x00000000}},  //   озин, _walh, rtni,
  { {0x644301d9, 0x0cd60309, 0x656100c4, 0x00000000}},  //   stni, _धर्म, _talh,
  { {0x6d8b006b, 0x059500a6, 0x66090091, 0x00000000}},  //   _müas, _بارگ, _itek,
  { {0x8af0005f, 0x6e240209, 0x7e6d05f9, 0x00000000}},  //   ndər, _svib, _arap,
  { {0xa2aa0061, 0xb5fd40b6, 0x98b30006, 0x00000000}},  //   _जेव्, _arši, ždės_,
  { {0x7e6d0035, 0x63ab0009, 0xee3702dc, 0x00000000}},  //   _crap, _imgn, оня_,
  { {0x7e6d3ec9, 0xbddb0129, 0xa06900ed, 0x00000000}},  //   _drap, stèn, _вака_,
  { {0x67290578, 0xa3de0061, 0x27e600b4, 0x00000000}},  //   _odej, _दीड_, ymon_,
  { {0x7e6d03eb, 0x0b46007e, 0x67290023, 0x00000000}},  //   _frap, ўнан, _ndej,
  { {0x4425001e, 0x7e6d00fe, 0x66091489, 0x00000000}},  // [ff40] _lvl_, _grap, _ntek,
  { {0x3f820091, 0x6f2400a1, 0x6729004a, 0x00000000}},  //   ljku_, _بڑھن, _adej,
  { {0x66091126, 0x6729002b, 0x442519cb, 0x00000000}},  //   _atek, _bdej, _nvl_,
  { {0x66090288, 0x6fd60062, 0x00000000, 0x00000000}},  //   _btek, dáck,   ,
  { {0x44250190, 0x16a7014c, 0x672901f3, 0x00000000}},  //   _avl_, овци_, _ddej,
  { {0x27e6005b, 0x69ce002d, 0x00000000, 0x00000000}},  //   smon_, _ukbe,   ,
  { {0x66091b01, 0x6fdd0068, 0x00000000, 0x00000000}},  //   _etek, héca,   ,
  { {0x24800091, 0x050a0044, 0xe7370a85, 0x00000000}},  //   ćim_, রণের_, _мес_,
  { {0xef1f01f6, 0xd250007a, 0xc17a0088, 0x00000000}},  //   kkür_, رند_, аїн_,
  { {0x7e6d0ea9, 0x67290667, 0x00000000, 0x00000000}},  //   _rrap, _zdej,   ,
  { {0x9f520173, 0x7e6d00e0, 0x00000000, 0x00000000}},  //   _kiyè_, _srap,   ,
  { {0x7e6d0065, 0xd36f0025, 0x9f5201aa, 0x00000000}},  //   _prap, _لهم_, _jiyè_,
  { {0x80ca0309, 0x35df013d, 0xb5fd0c8a, 0x00000000}},  //   _सुरे, _पीड़, _prši,
  { {0x0dcb1c7b, 0x7e6d40b7, 0x8af0006b, 0x00000000}},  //   руми_, _vrap, ydər,
  { {0x5f95007c, 0x2bd90752, 0x7e6d0133, 0x00000000}},  //   _никт, مارک_, _wrap,
  { {0x81c30044, 0x00000000, 0x00000000, 0x00000000}},  //   ্ষণ_,   ,   ,
  { {0x3a320007, 0x5a35005e, 0x00000000, 0x00000000}},  // [ff50] gryp_, янат,   ,
  { {0xa2dd0164, 0x89370025, 0x2b490035, 0x00000000}},  //   _परस्, تعرا, sfac_,
  { {0x2a69006c, 0xbddb0173, 0x9f52000a, 0x00000000}},  //   svab_, ntèm, _biyè_,
  { {0xf7730426, 0xcd34009e, 0x00000000, 0x00000000}},  //   باط_, _ٹریب,   ,
  { {0xddc405fa, 0xa50900c0, 0x4b7a00b3, 0x00000000}},  //   _hriš, бела_, _הארו,
  { {0x2b9c0224, 0xddc440b8, 0x05a80088, 0x00000000}},  //   _více_, _kriš, овій_,
  { {0xdb0d00c4, 0x00000000, 0x00000000, 0x00000000}},  //   gnaç,   ,   ,
  { {0x7bcd00c4, 0x7dd21f7d, 0x00000000, 0x00000000}},  //   noau, læst,   ,
  { {0x660916d8, 0x3e720082, 0x0eaa0061, 0x00000000}},  //   _utek, _môtô_, _चेंड,
  { {0x10a504b6, 0xdb160010, 0x6fd61c59, 0x00000000}},  //   зион, rnyé, máci,
  { {0x6fd640b9, 0x00000000, 0x00000000, 0x00000000}},  //   láci,   ,   ,
  { {0x320d062a, 0x00000000, 0x00000000, 0x00000000}},  //   ppey_,   ,   ,
  { {0x6fd60027, 0x63bb005d, 0x7bcd004a, 0x00000000}},  //   náci, mnun, doau,
  { {0xddc41adc, 0x661d000c, 0x2d830023, 0x00000000}},  //   _briš, _æsku, gjje_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x63bb1642, 0x6fd61db8, 0x60dc169c, 0x00000000}},  //   nnun, káci, ürme,
  { {0x63bb00db, 0x799e005b, 0xdcfe00e5, 0x00000000}},  // [ff60] inun, thpw, _copă,
  { {0x63bb001f, 0x291c1690, 0x6fd60142, 0x00000000}},  //   hnun, úva_, dáci,
  { {0xacfb009b, 0xddc412db, 0x7bcd0026, 0x00000000}},  //   _להיכ, _griš, boau,
  { {0x63bb01d5, 0x7d1e014a, 0xe73a091b, 0x00000000}},  //   jnun, _heps, сед_,
  { {0x63bb0fb5, 0x6fd640ba, 0x7d1e007f, 0x00000000}},  //   dnun, gáci, _keps,
  { {0x7d1e0190, 0x7dd20030, 0xe5a3007c, 0x00000000}},  //   _jeps, mæss, ничи,
  { {0x63bb14b4, 0x81c30055, 0x09e30099, 0x00000000}},  //   fnun, ্ষা_, _чорн,
  { {0x48e10061, 0x7d1e18d5, 0x58bb00b6, 0x00000000}},  //   _करतो_, _leps, _המלצ,
  { {0xdcfc0089, 0x61e30009, 0x6fd600c4, 0x00000000}},  //   nkrē, _bhnl, cáci,
  { {0x63bb0211, 0x7d1e013e, 0x3f570082, 0x00000000}},  //   anun, _neps, _ầu_,
  { {0xd25000a6, 0x53fa0014, 0x68050006, 0x00000000}},  //   رنگ_, _طراح_, _kėda,
  { {0x2d8c03aa, 0x67220020, 0x00000000, 0x00000000}},  //   öden_, naoj,   ,
  { {0xbddb028c, 0xe8b90309, 0x4cd60044, 0x00000000}},  //   stèm, _आश्च, _দলগু,
  { {0xddc40cce, 0x7d1e06ed, 0x395a0068, 0x00000000}},  //   _priš, _ceps, jeps_,
  { {0x6fd62b90, 0x7d1e0093, 0x7bcd01a2, 0x00000000}},  //   záci, _deps, toau,
  { {0x23cc0164, 0x69c307ac, 0x2366016c, 0x00000000}},  //   ाविद, čnem, _jaoj_,
  { {0x6fdd00f4, 0xbddb0173, 0x7bcd01a2, 0x00000000}},  // [ff70] léco, ntèk, roau,
  { {0x395a0061, 0x127b007b, 0x213e0866, 0x00000000}},  //   geps_, זאמע, ngth_,
  { {0x4af9007c, 0x63bb0279, 0x27e40022, 0x00000000}},  //   _меню_, ynun, _bhmn_,
  { {0x6fd61db8, 0xe7380088, 0x6b9602d4, 0x00000000}},  //   táci, зеї_, ckyg,
  { {0xb8d4024c, 0xe4c5006b, 0x00000000, 0x00000000}},  //   _जे_, _köçə,   ,
  { {0x6fd62b90, 0x00000000, 0x00000000, 0x00000000}},  //   ráci,   ,   ,
  { {0xa3e90256, 0x26c400fa, 0xcabf0044, 0x00000000}},  //   одка_, _exmo_, _আরিফ,
  { {0x6fdd009d, 0x00000000, 0x00000000, 0x00000000}},  //   déco,   ,   ,
  { {0x63bb0218, 0x6fdd0285, 0xb5fd01ed, 0x00000000}},  //   rnun, técn, _pršu,
  { {0xcabf0044, 0x00000000, 0x00000000, 0x00000000}},  //   _আরাফ,   ,   ,
  { {0x75231425, 0xf9920097, 0xe8110061, 0x00000000}},  //   manz, דרי_, डीचा_,
  { {0x7d1e008d, 0x7523010f, 0x68ec006b, 0x00000000}},  //   _seps, lanz, ündə,
  { {0x614501be, 0x59bf0164, 0xa3ca00e8, 0x00000000}},  //   _жела, ्वार, लकर_,
  { {0x752308ed, 0xe9ff001d, 0x61fd0428, 0x00000000}},  //   nanz, _hoặc_, íslu,
  { {0x9f5d01aa, 0x45220044, 0x00000000, 0x00000000}},  //   _ouvè_, _নামক_,   ,
  { {0xee3a046c, 0x4427037d, 0x75231601, 0x00000000}},  //   _дни_, isn_, hanz,
  { {0x6d4f000c, 0x31670087, 0x75232a95, 0x00000000}},  // [ff80] únað, _kanz_, kanz,
  { {0x7e6411ad, 0x8e370049, 0x75233eb7, 0x00000000}},  //   _isip, _קניא_, janz,
  { {0x395a40bb, 0x75233e17, 0x77660265, 0x00000000}},  //   reps_, danz, дълж,
  { {0x6d5c3681, 0x442701f3, 0x7c3c0032, 0x00000000}},  //   lera, dsn_, murr,
  { {0xe5c60175, 0x75230207, 0x7c3c002d, 0x00000000}},  //   мско, fanz, lurr,
  { {0x75230a19, 0x2b40121e, 0x2d980010, 0x00000000}},  //   ganz, lgic_, nkre_,
  { {0x3e85008d, 0x6d5c002d, 0xd94300e2, 0x00000000}},  //   _këtë_, iera, _шери,
  { {0x6d5c002d, 0x00000000, 0x00000000, 0x00000000}},  //   hera,   ,   ,
  { {0x6d5c022b, 0x75230311, 0xfd650011, 0x00000000}},  //   kera, banz, _chuồ,
  { {0x75231ad2, 0x7c3c022b, 0x6d5c016e, 0x00000000}},  //   canz, kurr, jera,
  { {0x130a007c, 0x80d60044, 0x7e6400e7, 0x00000000}},  //   _дней_, ডেন্, _asip,
  { {0x656806fe, 0x7c3c0207, 0x66000020, 0x00000000}},  //   _hadh, durr, _kumk,
  { {0x6d5c0263, 0x6568000b, 0x16dc0061, 0x00000000}},  //   fera, _kadh, _बरोब,
  { {0x6d5c0127, 0x3167001f, 0x701900a1, 0x00000000}},  //   gera, _ganz_, _کروڑ_,
  { {0x656823d3, 0x0cd40088, 0xfbd3023c, 0x00000000}},  //   _madh, ворю, نتر_,
  { {0x02e20061, 0x75230020, 0x656802bf, 0x00000000}},  //   _पराभ, zanz, _ladh,
  { {0x6d5c0149, 0x657a0100, 0x75230dfc, 0x00000000}},  // [ff90] bera, _onth, yanz,
  { {0x6d5c0073, 0xf77000d3, 0x65680020, 0x00000000}},  //   cera, یان_, _nadh,
  { {0xb90703d7, 0x752301d5, 0x47351fd9, 0x00000000}},  //   _पर_, vanz, енес,
  { {0x752340bc, 0x657a0549, 0x61f80cb2, 0x00000000}},  //   wanz, _anth, _livl,
  { {0x7523000b, 0xa509003b, 0x65680a75, 0x00000000}},  //   tanz, пела_, _badh,
  { {0x6568161d, 0x6e2000c4, 0xd4690aed, 0x00000000}},  //   _cadh, âmbi, зике_,
  { {0x7523054f, 0x6d45000b, 0x6e3d07c4, 0x00000000}},  //   ranz, _mcha, husb,
  { {0x61c702fb, 0x6d5c0027, 0x752300ac, 0x00000000}},  //   रक्ष, zera, sanz,
  { {0x656840bd, 0x7c3c117a, 0x6d452b72, 0x00000000}},  //   _fadh, zurr, _ocha,
  { {0x6d5c40be, 0x67202d14, 0xdd31006b, 0x00000000}},  //   xera, _zemj, _rəşa,
  { {0xd00e00a6, 0x61f80091, 0x644a1a8d, 0x00000000}},  //   یلی_, _divl, ctfi,
  { {0x6d45028c, 0x6d5c0d31, 0x3f6a2e81, 0x00000000}},  //   _acha, wera, чимо_,
  { {0xa195008b, 0x6fd6008e, 0x316701a2, 0x00000000}},  //   _падч, dáct, _tanz_,
  { {0x6145350f, 0x7c3c002d, 0x75210010, 0x00000000}},  //   _чека, turr, _jelz,
  { {0x6d5c0073, 0xc4d2007b, 0x6d4e22d8, 0x00000000}},  //   rera, ָגן_, rfba,
  { {0x6d5c40bf, 0xd00e0b59, 0x6d4540c0, 0x00000000}},  //   sera, _الي_, _echa,
  { {0x6d5c049a, 0xfaa302d3, 0xdb0f0010, 0x00000000}},  // [ffa0] pera, гато, ájár,
  { {0xe9d701f9, 0x7c3c1983, 0x752100b9, 0x00000000}},  //   еку_, purr, _nelz,
  { {0x65682927, 0x776900d9, 0x2005013f, 0x00000000}},  //   _radh, _baex, nqli_,
  { {0xd6d90046, 0x69d52cb2, 0x65680048, 0x00000000}},  //   _był_, _ekze, _sadh,
  { {0xb7d7023c, 0x21250022, 0x6e29012d, 0x00000000}},  //   روها_, kalh_, šebv,
  { {0xceb3007b, 0x6d451f8b, 0x04660fa6, 0x00000000}},  //   ניג_, _xcha, етим,
  { {0x6fd60047, 0x64480009, 0x61f80023, 0x00000000}},  //   nács, _qqdi, _rivl,
  { {0x65680020, 0xff5f009d, 0x443c05ad, 0x00000000}},  //   _wadh, noît_, ruv_,
  { {0x644a000c, 0x65681740, 0x320f0009, 0x00000000}},  //   stfi, _tadh, _ctgy_,
  { {0xe4d60054, 0x200e0022, 0xc0ca003b, 0x00000000}},  //   _كتاب, _ptfi_, зуме_,
  { {0x89370049, 0xc953009b, 0x7f5d062a, 0x00000000}},  //   ערטע_, אמת_, tesq,
  { {0x6d4540c1, 0x6e3d0232, 0x442c0433, 0x00000000}},  //   _scha, tusb, _ivd_,
  { {0x7f5d06fa, 0x93cb00a1, 0x3f9901ee, 0x00000000}},  //   resq, _عامہ_, rksu_,
  { {0xc297008b, 0x127b0049, 0x81de0044, 0x00000000}},  //   _якіх_, _מאדע, _দূর_,
  { {0xe0d4007b, 0x2167003b, 0x0133035b, 0x00000000}},  //   _בײַ_, _чији_, _صعود,
  { {0x442c01c5, 0x00000000, 0x00000000, 0x00000000}},  //   _mvd_,   ,   ,
  { {0x6fd60211, 0x6d4500f4, 0x6f0d0544, 0x00000000}},  // [ffb0] ráct, _tcha, _ifac,
  { {0x6d4540c2, 0x442c00f6, 0xc4c400a1, 0x00000000}},  //   _ucha, _ovd_, _هے_,
  { {0xbb1b00f4, 0xa9c40088, 0x394100f8, 0x00000000}},  //   _boît, устк, rghs_,
  { {0x752140c3, 0x1ab5007e, 0xdb0700b0, 0x00000000}},  //   _selz, _абмя, ämät,
  { {0x442c0056, 0x00000000, 0x00000000, 0x00000000}},  //   _avd_,   ,   ,
  { {0x442c0f46, 0x00000000, 0x00000000, 0x00000000}},  //   _bvd_,   ,   ,
  { {0x442c0085, 0xd4660aef, 0x6592003b, 0x00000000}},  //   _cvd_, вище_, рају,
  { {0x442c40c4, 0x58d40f40, 0x752100bb, 0x00000000}},  //   _dvd_, _сост, _welz,
  { {0x35f50265, 0xdcfe0209, 0x4222007c, 0x00000000}},  //   _апар, _uopć, адыв,
  { {0x6fdd028c, 0x6f0d000d, 0x21750256, 0x00000000}},  //   léch, _afac, туир,
  { {0x8fa60265, 0x00000000, 0x00000000, 0x00000000}},  //   ване,   ,   ,
  { {0x2005006b, 0xb4cd013d, 0x21250022, 0x00000000}},  //   rqli_, रथी_, salh_,
  { {0xe28e103e, 0x9e63008b, 0xfe7900a5, 0x00000000}},  //   _та_, авяд, нёры_,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x224d0010, 0x6f0d0016, 0x00000000, 0x00000000}},  //   ltek_, _ffac,   ,
  { {0x224d004e, 0x25e8013d, 0x236d0065, 0x00000000}},  //   otek_, _चीनी_, ndej_,
  { {0x224d0010, 0xff5f009d, 0x00000000, 0x00000000}},  // [ffc0] ntek_, roît_,   ,
  { {0x224d002d, 0x957c0036, 0x00000000, 0x00000000}},  //   itek_, _wiąz,   ,
  { {0x98b1011f, 0xdca6003b, 0x574a007e, 0x00000000}},  //   _bazı_, _рани, дзем_,
  { {0x224d33e4, 0x6f0d0026, 0x7e761d8f, 0x00000000}},  //   ktek_, _xfac, _kryp,
  { {0x442c0039, 0xe5341734, 0x473301ff, 0x00000000}},  //   _svd_, гель, рніс,
  { {0xd693012b, 0x35b6005e, 0x442c2fec, 0x00000000}},  //   ришћ, ъщес, _pvd_,
  { {0x67e3010e, 0x00000000, 0x00000000, 0x00000000}},  //   sõja,   ,   ,
  { {0x68e314c9, 0x69de146c, 0x442c00b5, 0x00000000}},  //   ünde, llpe, _vvd_,
  { {0x6f0d0048, 0xc566003b, 0x00000000, 0x00000000}},  //   _rfac, _икак,   ,
  { {0x6f0d0cc8, 0xa3e70061, 0x00000000, 0x00000000}},  //   _sfac, _मीठ_,   ,
  { {0x98b1005a, 0x6e2d0107, 0x493b009b, 0x00000000}},  //   _yazı_, _svab, וגיו,
  { {0x23ba01c5, 0x00000000, 0x00000000, 0x00000000}},  //   tīju_,   ,   ,
  { {0x63a2011c, 0x539b0104, 0x7e76032c, 0x00000000}},  //   _ilon, _קידו, _cryp,
  { {0x7bc60107, 0x7e760190, 0x00000000, 0x00000000}},  //   _ajku, _dryp,   ,
  { {0x1df8007c, 0x07220316, 0x7ae60288, 0x00000000}},  //   теры_, मराव_, _azkt,
  { {0x7e760006, 0xddcd0035, 0x00000000, 0x00000000}},  //   _fryp, _braţ,   ,
  { {0x98b10279, 0x7e7600b4, 0x00000000, 0x00000000}},  // [ffd0] _razı_, _gryp,   ,
  { {0x645a0472, 0x63a20016, 0xdd9100a1, 0x00000000}},  //   _opti, _llon, _چوک_,
  { {0x224d0010, 0x38c90167, 0x7bc8009d, 0x00000000}},  //   ztek_, رائی_, éduc,
  { {0x224d0c0f, 0xe7d10044, 0xddcd0035, 0x00000000}},  //   ytek_, িষ্য, _fraţ,
  { {0xf7700879, 0x26c90181, 0x6fdd009d, 0x00000000}},  //   تال_, çao_, réch,
  { {0x63a20038, 0x69cb0010, 0xbf1f0061, 0x00000000}},  //   _alon, éged, परुन_,
  { {0x63a20472, 0x224d0066, 0x26d2014a, 0x00000000}},  //   _blon, wtek_, üyor_,
  { {0x224d0047, 0x04560054, 0x24890119, 0x00000000}},  //   ttek_, الية_, ćam_,
  { {0x645a00f6, 0x63a203b2, 0xc7b200b3, 0x00000000}},  //   _epti, _dlon, _הבן_,
  { {0x224d108d, 0x63a20133, 0x972400a1, 0x00000000}},  //   rtek_, _elon, _مفہو,
  { {0x224d014a, 0xbf1f0061, 0x00000000, 0x00000000}},  //   stek_, परून_,   ,
  { {0x63a214d9, 0x224d0010, 0x6d57006b, 0x00000000}},  //   _glon, ptek_, _abxa,
  { {0x52740014, 0x00000000, 0x00000000, 0x00000000}},  //   _پانز,   ,   ,
  { {0xde03007c, 0x7e7640c5, 0x8c4600e2, 0x00000000}},  //   спри, _vryp, леге,
  { {0x00000000, 0x00000000, 0x00000000, 0x00000000}},  //     ,   ,   ,
  { {0x39960698, 0x7e760133, 0x6d8b006b, 0x00000000}},  //   _læst_, _tryp, _müay,
  { {0x4e1d013d, 0x6e290107, 0x39ea003b, 0x00000000}},  // [ffe0] बीआई_, šebr, едао_,
  { {0x8d660057, 0x3996000c, 0x680c0477, 0x00000000}},  //   _свое, _næst_, _ağda,
  { {0xf99f00d4, 0x485a007e, 0xe73a017f, 0x00000000}},  //   _atès_, эраў_, еее_,
  { {0x69c70066, 0x7c2e03b4, 0x46a60356, 0x00000000}},  //   _ejje, msbr, лаев,
  { {0x9f8b006c, 0x6d410daf, 0xddcd40c6, 0x00000000}},  //   _tööl_, ólag, _hraš,
  { {0x7bc4010a, 0x63a20059, 0xddcd40c7, 0x00000000}},  //   lniu, _slon, _kraš,
  { {0x69c30209, 0x63a240c8, 0x7c2e09b0, 0x00000000}},  //   čnet, _plon, nsbr,
  { {0x6fdd0181, 0x7c2e01d6, 0x61ea0023, 0x00000000}},  //   péci, isbr, _shfl,
  { {0xf1260373, 0x89d700a1, 0x63a240c9, 0x00000000}},  //   льно, _شوہر_, _vlon,
  { {0x39960030, 0x865b0097, 0xddcd016e, 0x00000000}},  //   _gæst_, _אדמי, _oraš,
  { {0x645a103f, 0x3f920279, 0x63a2008a, 0x00000000}},  //   _upti, _boyu_, _tlon,
  { {0x7c2e0018, 0xdb0d00c4, 0x63a240ca, 0x00000000}},  //   dsbr, miaç, _ulon,
  { {0x221601fb, 0xdb0d02d5, 0x9f92009f, 0x00000000}},  //   _сфер, liaç, ráð_,
  { {0xa6d10044, 0xddcd0091, 0x00000000, 0x00000000}},  //   ়েকট, _braš,   ,
  { {0x2b9c001d, 0x442e0173, 0x7c2e06a1, 0x00000000}},  //   _kích_, nsf_, gsbr,
  { {0xddcd04eb, 0x395800fa, 0x00000000, 0x00000000}},  //   _draš, _abrs_,   ,
  { {0x645c006c, 0x38780145, 0x00000000, 0x00000000}},  // [fff0] _ärif, _arrr_,   ,
  { {0x6d41000c, 0x00000000, 0x00000000, 0x00000000}},  //   ólad,   ,   ,
  { {0x31570049, 0xddcd01ed, 0x765b08d9, 0x00000000}},  //   ריבן_, _graš, _spuy,
  { {0x2d93027b, 0xbddb00f4, 0x6d470d3e, 0x00000000}},  //   _hoxe_, ctèr, lgja,
  { {0x3669003b, 0x38780145, 0x320600e0, 0x00000000}},  //   тало_, _errr_, _nuoy_,
  { {0x6d4740cb, 0xae1d013d, 0x2d93002d, 0x00000000}},  //   ngja, बीएन_, _joxe_,
  { {0x38781346, 0xcd9800b6, 0x2b9c0011, 0x00000000}},  //   _grrr_, רדות_, _bích_,
  { {0x437501fb, 0x6b8d04cb, 0x42550745, 0x00000000}},  //   рукт, njag, атот,
  { {0x69c50007, 0x6aad0026, 0x9f8401df, 0x00000000}},  //   onhe, nzaf, lıç_,
  { {0x69c50304, 0x672b000c, 0x2d9300e5, 0x00000000}},  //   nnhe, lagj, _noxe_,
  { {0xdb0d02d5, 0x656300bb, 0x27ed0011, 0x00000000}},  //   ciaç, menh, _khen_,
  { {0x6f0f001c, 0x65630e24, 0x72d50cb7, 0x00000000}},  //   gccc, lenh, _коеф,
  { {0x6443018e, 0x539a012e, 0x7c2e00d9, 0x00000000}},  //   luni, _שינו, wsbr,
  { {0xddcd010a, 0x7c2e0039, 0x6d4740cc, 0x00000000}},  //   _praš, tsbr, ggja,
  { {0xab2a008b, 0x1c39041f, 0x672b0ef8, 0x00000000}},  //   кова_, лять_, kagj,
  { {0x6f0f001c, 0x63a90056, 0x63bb0035, 0x00000000}},  //   cccc, nhen, niun,

  };
  // table_hash = 508d-88e1, unused_entries = 79675 (30.39%)

static const uint32 kQuadChromeInd[16589] = {
  // [0000]
  0x00000000, 0x0e001c23, 0x06001014, 0x01004208,   //  bg.ru..._880 sv.de..._660 mt.en..._430
  0x0000191c, 0x38000512, 0x0000160f, 0x0000660f,   // et......_800 fr.ca..._640 lt......_600 af......_600
  0x45401d08, 0x00001a06, 0x00008c01, 0x00003f1c,   // hr.sl.sk_443 xxx......_400 ht......_200 sw......_800
  0x0000140f, 0x0000171c, 0x02002e13, 0x1a002e08,   // is......_600 ro......_800 sq.da..._650 sq.xxx..._430
  // [0010]
  0x0000180f, 0x0000430f, 0x2b003f14, 0x19002114,   // hu......_600 vi......_600 sw.cy..._660 tl.et..._660
  0x00004e0f, 0x17000822, 0x00002b0f, 0x00001c2d,   // fa......_600 it.ro..._870 cy......_600 bg......_A00
  0x0000021c, 0x01001a09, 0x0000170f, 0x18000802,   // da......_800 xxx.en..._440 ro......_600 it.hu..._220
  0x00001a1c, 0x0000431c, 0x0000151c, 0x0000061c,   // xxx......_800 vi......_800 lv......_800 de......_800
  // [0020]
  0x00003f0f, 0x1d0c4502, 0x00002701, 0x00002e06,   // sw......_600 sk.pl.hr_222 id......_200 sq......_400
  0x45000c12, 0x0000370f, 0x00000801, 0x0000451c,   // pl.sk..._640 ar......_600 it......_200 sk......_800
  0x2e001414, 0x1a2e1f12, 0x00001f1c, 0x0000420f,   // is.sq..._660 ga.sq.xxx_654 ga......_800 mt......_600
  0x374e3314, 0x00003a0f, 0x27192907, 0x2e001e09,   // ur.fa.ar_666 eu......_600 ms.et.id_432 sr.sq..._440
  // [0030]
  0x0000020f, 0x43002b13, 0x00003a06, 0x1a001f13,   // da......_600 cy.vi..._650 eu......_400 ga.xxx..._650
  0x04003f13, 0x00001706, 0x00000c0f, 0x18002e12,   // sw.fi..._650 ro......_400 pl......_600 sq.hu..._640
  0x0000011c, 0x0000100f, 0x0b000d02, 0x00001e0f,   // en......_800 sv......_600 pt.no..._220 sr......_600
  0x19000414, 0x0d001002, 0x450c3a02, 0x27002913,   // fi.et..._660 sv.pt..._220 eu.pl.sk_222 ms.id..._650
  // [0040]
  0x16001722, 0x2e003f02, 0x40001602, 0x01000608,   // ro.lt..._870 sw.sq..._220 lt.sl..._220 de.en..._430
  0x0000260f, 0x00001a01, 0x00000c1c, 0x0000181c,   // bn......_600 xxx......_200 pl......_800 hu......_800
  0x00001f06, 0x00005c0f, 0x00000f01, 0x37334e13,   // ga......_400 yi......_600 es......_200 fa.ur.ar_665
  0x0e002314, 0x0e001c09, 0x0b000202, 0x45001223,   // uk.ru..._660 bg.ru..._440 da.no..._220 cs.sk..._880
  // [0050]
  0x01001a08, 0x00001f0f, 0x00000406, 0x0d000102,   // xxx.en..._430 ga......_600 fi......_400 en.pt..._220
  0x0000371c, 0x0000261c, 0x00000b0f, 0x00000e1c,   // ar......_800 bn......_800 no......_600 ru......_800
  0x00002106, 0x0000400f, 0x4b002213, 0x00002b06,   // tl......_400 sl......_600 tr.az..._650 cy......_400
  0x23000e02, 0x4b002214, 0x00001c0f, 0x00004b1c,   // ru.uk..._220 tr.az..._660 bg......_600 az......_800
  // [0060]
  0x3f001f12, 0x00001a0f, 0x45001209, 0x33004e11,   // ga.sw..._640 xxx......_600 cs.sk..._440 fa.ur..._630
  0x1d451e08, 0x00002e0f, 0x00004206, 0x24001a11,   // sr.sk.hr_443 sq......_600 mt......_400 xxx.hi..._630
  0x00000501, 0x1c000e02, 0x0000211c, 0x00004b0f,   // fr......_200 ru.bg..._220 tl......_800 az......_600
  0x0000190f, 0x4e003713, 0x1a002412, 0x04002707,   // et......_600 ar.fa..._650 hi.xxx..._640 id.fi..._420
  // [0070]
  0x37334e12, 0x1f008c02, 0x1e002502, 0x0000101c,   // fa.ur.ar_654 ht.ga..._220 mk.sr..._220 sv......_800
  0x1d001908, 0x01000c09, 0x37004e14, 0x23000e13,   // et.hr..._430 pl.en..._440 fa.ar..._660 ru.uk..._650
  0x020b1408, 0x16001e02, 0x00004e1c, 0x00005c1c,   // is.no.da_443 sr.lt..._220 fa......_800 yi......_800
  0x00000e0f, 0x1a002413, 0x0000300f, 0x00001606,   // ru......_600 hi.xxx..._650 be......_600 lt......_400
  // [0080]
  0x1e002521, 0x0e002502, 0x00004306, 0x1e232508,   // mk.sr..._860 mk.ru..._220 vi......_400 mk.uk.sr_443
  0x374e3312, 0x00002901, 0x1e230e09, 0x00004001,   // ur.fa.ar_654 ms......_200 ru.uk.sr_444 sl......_200
  0x0000230f, 0x0000150f, 0x27002909, 0x0000301c,   // uk......_600 lv......_600 ms.id..._440 be......_800
  0x052e0107, 0x00002e1c, 0x00000f06, 0x15001613,   // en.sq.fr_432 sq......_800 es......_400 lt.lv..._650
  // [0090]
  0x06002b02, 0x1e001d14, 0x14001814, 0x00002706,   // cy.de..._220 hr.sr..._660 hu.is..._660 id......_400
  0x04001f02, 0x00002206, 0x45004202, 0x07005c14,   // ga.fi..._220 tr......_400 mt.sk..._220 yi.iw..._660
  0x25001e13, 0x30002323, 0x250e1caf, 0x0000070f,   // sr.mk..._650 uk.be..._880 bg.ru.mk_655 iw......_600
  0x0000332d, 0x00000506, 0x00003306, 0x0000141c,   // ur......_A00 fr......_400 ur......_400 is......_800
  // [00a0]
  0x5c000714, 0x0000330f, 0x33004e12, 0x07005c13,   // iw.yi..._660 ur......_600 fa.ur..._640 yi.iw..._650
  0x22002b09, 0x0e003013, 0x33004e14, 0x3f1a2109,   // cy.tr..._440 be.ru..._650 fa.ur..._660 tl.xxx.sw_444
  0x25000e14, 0x29003f09, 0x1e251c02, 0x0000010f,   // ru.mk..._660 sw.ms..._440 bg.mk.sr_222 en......_600
  0x1a000614, 0x0000432d, 0x42001a23, 0x2e008c09,   // de.xxx..._660 vi......_A00 xxx.mt..._880 ht.sq..._440
  // [00b0]
  0x0000040f, 0x01000323, 0x27000f09, 0x5c000712,   // fi......_600 nl.en..._880 es.id..._440 iw.yi..._640
  0x00000c06, 0x0000030f, 0x0000071c, 0x2b000202,   // pl......_400 nl......_600 iw......_800 da.cy..._220
  0x37004e22, 0x0000120f, 0x060315a4, 0x00000306,   // fa.ar..._870 cs......_600 lv.nl.de_433 nl......_400
  0x42000514, 0x00005c2d, 0x8c002b02, 0x40000b09,   // fr.mt..._660 yi......_A00 cy.ht..._220 no.sl..._440
  // [00c0]
  0x1e001c02, 0x66000312, 0x0e302360, 0x22004b11,   // bg.sr..._220 nl.af..._640 uk.be.ru_664 az.tr..._630
  0x00000d06, 0x30001c21, 0x2b141013, 0x03006614,   // pt......_400 bg.be..._860 sv.is.cy_665 af.nl..._660
  0x16001508, 0x4b0f0d08, 0x00004006, 0x10021a09,   // lv.lt..._430 pt.es.az_443 sl......_400 xxx.da.sv_444
  0x66000502, 0x19001402, 0x10002e13, 0x1f000609,   // fr.af..._220 is.et..._220 sq.sv..._650 de.ga..._440
  // [00d0]
  0x1d004002, 0x1c0e1e12, 0x00001201, 0x33004e21,   // sl.hr..._220 sr.ru.bg_654 cs......_200 fa.ur..._860
  0x00003806, 0x0b001a02, 0x0f000d02, 0x25001c02,   // ca......_400 xxx.no..._220 pt.es..._220 bg.mk..._220
  0x0b001013, 0x00000301, 0x0e002514, 0x06001414,   // sv.no..._650 nl......_200 mk.ru..._660 is.de..._660
  0x0d000f08, 0x06000f02, 0x1a008c08, 0x1a000502,   // es.pt..._430 es.de..._220 ht.xxx..._430 fr.xxx..._220
  // [00e0]
  0x00002101, 0x1e002522, 0x00002506, 0x25001c14,   // tl......_200 mk.sr..._870 mk......_400 bg.mk..._660
  0x0d003f02, 0x00001701, 0x140b1007, 0x00003f06,   // sw.pt..._220 ro......_200 sv.no.is_432 sw......_400
  0x1a002411, 0x4e003322, 0x00000b06, 0x10000202,   // hi.xxx..._630 ur.fa..._870 no......_400 da.sv..._220
  0x1e002513, 0x0000250f, 0x1e1d4002, 0x274b2902,   // mk.sr..._650 mk......_600 sl.hr.sr_222 ms.az.id_222
  // [00f0]
  0x29003f14, 0x0f001809, 0x06000402, 0x37003312,   // sw.ms..._660 hu.es..._440 fi.de..._220 ur.ar..._640
  0x0000050f, 0x0c001e02, 0x00003801, 0x0f000d13,   // fr......_600 sr.pl..._220 ca......_200 pt.es..._650
  0x00001006, 0x4e3337af, 0x00000d01, 0x3f1a8c09,   // sv......_400 ar.ur.fa_655 pt......_200 ht.xxx.sw_444
  0x272e1faf, 0x18000d02, 0x66000107, 0x2e002b08,   // ga.sq.id_655 pt.hu..._220 en.af..._420 cy.sq..._430
  // [0100]
  0x03006623, 0x22001a02, 0x1e250eaf, 0x19000413,   // af.nl..._880 xxx.tr..._220 ru.mk.sr_655 fi.et..._650
  0x5c000713, 0x182e4360, 0x30002322, 0x1d001e09,   // iw.yi..._650 vi.sq.hu_664 uk.be..._870 sr.hr..._440
  0x38000402, 0x06000b09, 0x0000161c, 0x0c002b14,   // fi.ca..._220 no.de..._440 lt......_800 cy.pl..._660
  0x66000409, 0x04003814, 0x00001906, 0x0000060f,   // fi.af..._440 ca.fi..._660 et......_400 de......_600
  // [0110]
  0x04002e02, 0x21001a02, 0x66000309, 0x1c002523,   // sq.fi..._220 xxx.tl..._220 nl.af..._440 mk.bg..._880
  0x19000109, 0x05003808, 0x03006609, 0x3f001a08,   // en.et..._440 ca.fr..._430 af.nl..._440 xxx.sw..._430
  0x20003802, 0x1e001d23, 0x66000f09, 0x10000211,   // ca.gl..._220 hr.sr..._880 es.af..._440 da.sv..._630
  0x0000210f, 0x3f001a07, 0x1e001c12, 0x0000221c,   // tl......_600 xxx.sw..._420 bg.sr..._640 tr......_800
  // [0120]
  0x22006609, 0x30000e02, 0x1f000109, 0x4e003313,   // af.tr..._440 ru.be..._220 en.ga..._440 ur.fa..._650
  0x1f002b14, 0x66000602, 0x1f004209, 0x0000291c,   // cy.ga..._660 de.af..._220 mt.ga..._440 ms......_800
  0x04006614, 0x0000380f, 0x03003f08, 0x00001e1c,   // af.fi..._660 ca......_600 sw.nl..._430 sr......_800
  0x1e0e2302, 0x00001e01, 0x5c000720, 0x07005c23,   // uk.ru.sr_222 sr......_200 iw.yi..._850 yi.iw..._880
  // [0130]
  0x1e230e14, 0x0e002309, 0x061f01a4, 0x00000106,   // ru.uk.sr_666 uk.ru..._440 en.ga.de_433 en......_400
  0x40004513, 0x02032e08, 0x25001e20, 0x334e3714,   // sk.sl..._650 sq.nl.da_443 sr.mk..._850 ar.fa.ur_666
  0x2b1f3fa4, 0x00003006, 0x30002309, 0x0e001e02,   // sw.ga.cy_433 be......_400 uk.be..._440 sr.ru..._220
  0x1d004512, 0x0000240f, 0x00001206, 0x00004b06,   // sk.hr..._640 hi......_600 cs......_400 az......_400
  // [0140]
  0x0e001e09, 0x1a000302, 0x0000450f, 0x1e002508,   // sr.ru..._440 nl.xxx..._220 sk......_600 mk.sr..._430
  0x3a004002, 0x00002906, 0x00000201, 0x0e003014,   // sl.eu..._220 ms......_400 da......_200 be.ru..._660
  0x22001814, 0x29002723, 0x0000220f, 0x18001609,   // hu.tr..._660 id.ms..._880 tr......_600 lt.hu..._440
  0x251e1c13, 0x1c251ea4, 0x42012707, 0x2b000302,   // bg.sr.mk_665 sr.mk.bg_433 id.en.mt_432 nl.cy..._220
  // [0150]
  0x2e001009, 0x374e3313, 0x0e002312, 0x0e1c25af,   // sv.sq..._440 ur.fa.ar_665 uk.ru..._640 mk.bg.ru_655
  0x8c000d09, 0x04002122, 0x8c002108, 0x04000313,   // pt.ht..._440 tl.fi..._870 tl.ht..._430 nl.fi..._650
  0x66000413, 0x2b001a22, 0x430419a4, 0x19000309,   // fi.af..._650 xxx.cy..._870 et.fi.vi_433 nl.et..._440
  0x66000322, 0x27293f60, 0x3f002102, 0x18451260,   // nl.af..._870 sw.ms.id_664 tl.sw..._220 cs.sk.hu_664
  // [0160]
  0x19006614, 0x12004514, 0x2e003f08, 0x00004b2d,   // af.et..._660 sk.cs..._660 sw.sq..._430 az......_A00
  0x24001a14, 0x40124513, 0x1e001d13, 0x4e003314,   // xxx.hi..._660 sk.cs.sl_665 hr.sr..._650 ur.fa..._660
  0x03006602, 0x29002714, 0x18003f14, 0x01004302,   // af.nl..._220 id.ms..._660 sw.hu..._660 vi.en..._220
  0x1d001e02, 0x2b001f23, 0x00001d0f, 0x06450307,   // sr.hr..._220 ga.cy..._880 hr......_600 nl.sk.de_432
  // [0170]
  0x06002709, 0x06001609, 0x45151607, 0x00008c06,   // id.de..._440 lt.de..._440 lt.lv.sk_432 ht......_400
  0x0e1c2560, 0x0e001e14, 0x04002102, 0x1f002909,   // mk.bg.ru_664 sr.ru..._660 tl.fi..._220 ms.ga..._440
  0x45002109, 0x45000209, 0x1e1c2502, 0x00001901,   // tl.sk..._440 da.sk..._440 mk.bg.sr_222 et......_200
  0x66000321, 0x03001902, 0x22036609, 0x1c001e02,   // nl.af..._860 et.nl..._220 af.nl.tr_444 sr.bg..._220
  // [0180]
  0x22004b13, 0x00000d0f, 0x1e001d21, 0x24001a21,   // az.tr..._650 pt......_600 hr.sr..._860 xxx.hi..._860
  0x25001e12, 0x03001813, 0x01001009, 0x18032e60,   // sr.mk..._640 hu.nl..._650 sv.en..._440 sq.nl.hu_664
  0x374e33af, 0x2e002213, 0x66003a21, 0x40001214,   // ur.fa.ar_655 tr.sq..._650 eu.af..._860 cs.sl..._660
  0x45431a02, 0x02006602, 0x00002b1c, 0x27006609,   // xxx.vi.sk_222 af.da..._220 cy......_800 af.id..._440
  // [0190]
  0x00000206, 0x06003809, 0x40128c08, 0x10000214,   // da......_400 ca.de..._440 ht.cs.sl_443 da.sv..._660
  0x23000e12, 0x00001f2d, 0x16000513, 0x00000806,   // ru.uk..._640 ga......_A00 fr.lt..._650 it......_400
  0x0000081c, 0x10002102, 0x4b002209, 0x5c000721,   // it......_800 tl.sv..._220 tr.az..._440 iw.yi..._860
  0x0b660212, 0x1e002314, 0x0c3f06a4, 0x10002b09,   // da.af.no_654 uk.sr..._660 de.sw.pl_433 cy.sv..._440
  // [01a0]
  0x03066609, 0x03001e09, 0x00000606, 0x0000290f,   // af.de.nl_444 sr.nl..._440 de......_400 ms......_600
  0x30002302, 0x0f192b11, 0x10000114, 0x1f001002,   // uk.be..._220 cy.et.es_653 en.sv..._660 sv.ga..._220
  0x1d001e12, 0x40001521, 0x00008c0f, 0x00000e06,   // sr.hr..._640 lv.sl..._860 ht......_600 ru......_400
  0x06000107, 0x4b002e02, 0x1e1d40af, 0x334e37af,   // en.de..._420 sq.az..._220 sl.hr.sr_655 ar.fa.ur_655
  // [01b0]
  0x3f190412, 0x19000409, 0x33004e09, 0x0000252d,   // fi.et.sw_654 fi.et..._440 fa.ur..._440 mk......_A00
  0x19660408, 0x66000314, 0x66000b02, 0x33003712,   // fi.af.et_443 nl.af..._660 no.af..._220 ar.ur..._640
  0x38001002, 0x19003814, 0x18000413, 0x03006613,   // sv.ca..._220 ca.et..._660 fi.hu..._650 af.nl..._650
  0x42000814, 0x23002502, 0x1c000e23, 0x02001014,   // it.mt..._660 mk.uk..._220 ru.bg..._880 sv.da..._660
  // [01c0]
  0x1c001e14, 0x42001509, 0x04001913, 0x00006601,   // sr.bg..._660 lv.mt..._440 et.fi..._650 af......_200
  0x10020b08, 0x00001506, 0x15000202, 0x0c451708,   // no.da.sv_443 lv......_400 da.lv..._220 ro.sk.pl_443
  0x45001222, 0x10000b14, 0x45001214, 0x38000109,   // cs.sk..._870 no.sv..._660 cs.sk..._660 en.ca..._440
  0x18000508, 0x1d001e23, 0x07005c12, 0x43001a09,   // fr.hu..._430 sr.hr..._880 yi.iw..._640 xxx.vi..._440
  // [01d0]
  0x01004309, 0x3f001702, 0x10000b22, 0x12211502,   // vi.en..._440 ro.sw..._220 no.sv..._870 lv.tl.cs_222
  0x2b170109, 0x0000421c, 0x00006606, 0x3f000d14,   // en.ro.cy_444 mt......_800 af......_400 pt.sw..._660
  0x4e373312, 0x0000401c, 0x1a004302, 0x0b001a14,   // ur.ar.fa_654 sl......_800 vi.xxx..._220 xxx.no..._660
  0x45001212, 0x3f001a14, 0x42000609, 0x4b002212,   // cs.sk..._640 xxx.sw..._660 de.mt..._440 tr.az..._640
  // [01e0]
  0x0e001c14, 0x30002314, 0x10000b07, 0x02000b14,   // bg.ru..._660 uk.be..._660 no.sv..._420 no.da..._660
  0x0e1c2507, 0x00001406, 0x18000509, 0x02000614,   // mk.bg.ru_432 is......_400 fr.hu..._440 de.da..._660
  0x08003814, 0x1e230e08, 0x2b004009, 0x17004202,   // ca.it..._660 ru.uk.sr_443 sl.cy..._440 mt.ro..._220
  0x08001813, 0x00001d06, 0x00001e06, 0x33004e22,   // hu.it..._650 hr......_400 sr......_400 fa.ur..._870
  // [01f0]
  0x02002209, 0x0b020812, 0x1e232512, 0x00004201,   // tr.da..._440 it.da.no_654 mk.uk.sr_654 mt......_200
  0x14000802, 0x24001a13, 0x4b002223, 0x4e373313,   // it.is..._220 xxx.hi..._650 tr.az..._880 ur.ar.fa_665
  0x5c000722, 0x0000251c, 0x33374e12, 0x0000231c,   // iw.yi..._870 mk......_800 fa.ar.ur_654 uk......_800
  0x1e002514, 0x10001e02, 0x1e000e23, 0x30002313,   // mk.sr..._660 sr.sv..._220 ru.sr..._880 uk.be..._650
  // [0200]
  0x25001c23, 0x24001a23, 0x3f001a02, 0x00001001,   // bg.mk..._880 xxx.hi..._880 xxx.sw..._220 sv......_200
  0x24001a12, 0x04001609, 0x45124211, 0x0000080f,   // xxx.hi..._640 lt.fi..._440 mt.cs.sk_653 it......_600
  0x45001702, 0x00001d1c, 0x29004322, 0x1a001202,   // ro.sk..._220 hr......_800 vi.ms..._870 cs.xxx..._220
  0x27002923, 0x22004509, 0x21002702, 0x01000309,   // ms.id..._880 sk.tr..._440 id.tl..._220 nl.en..._440
  // [0210]
  0x06001009, 0x00000f0f, 0x3f004313, 0x1e001d02,   // sv.de..._440 es......_600 vi.sw..._650 hr.sr..._220
  0x40001723, 0x3a006614, 0x25001e02, 0x19003f09,   // ro.sl..._880 af.eu..._660 sr.mk..._220 sw.et..._440
  0x14000614, 0x00000f1c, 0x14000b14, 0x03001f02,   // de.is..._660 es......_800 no.is..._660 ga.nl..._220
  0x1d1e4009, 0x1d001e22, 0x0000041c, 0x06006609,   // sl.sr.hr_444 sr.hr..._870 fi......_800 af.de..._440
  // [0220]
  0x0b002e22, 0x2b003813, 0x03002102, 0x42001813,   // sq.no..._870 ca.cy..._650 tl.nl..._220 hu.mt..._650
  0x0000121c, 0x15002102, 0x2e004212, 0x43171f55,   // cs......_800 tl.lv..._220 mt.sq..._640 ga.ro.vi_442
  0x0e302308, 0x40001e14, 0x1c000e13, 0x00003a1c,   // uk.be.ru_443 sr.sl..._660 ru.bg..._650 eu......_800
  0x02002b13, 0x01000214, 0x1d004209, 0x19272909,   // cy.da..._650 da.en..._660 mt.hr..._440 ms.id.et_444
  // [0230]
  0x230e30af, 0x140b0208, 0x00001806, 0x40004223,   // be.ru.uk_655 da.no.is_443 hu......_400 mt.sl..._880
  0x04003a23, 0x45004014, 0x181d4208, 0x02216612,   // eu.fi..._880 sl.sk..._660 mt.hr.hu_443 af.tl.da_654
  0x3a000109, 0x02001002, 0x0000270f, 0x42000314,   // en.eu..._440 sv.da..._220 id......_600 nl.mt..._660
  0x37004e13, 0x06036614, 0x3a001914, 0x8c000514,   // fa.ar..._650 af.nl.de_666 et.eu..._660 fr.ht..._660
  // [0240]
  0x06000202, 0x33004e08, 0x1c000e14, 0x1e001d12,   // da.de..._220 fa.ur..._430 ru.bg..._660 hr.sr..._640
  0x8c003f14, 0x23003014, 0x3f002b14, 0x00001d01,   // sw.ht..._660 be.uk..._660 cy.sw..._660 hr......_200
  0x3f041a09, 0x05000f02, 0x00003342, 0x16124513,   // xxx.fi.sw_444 es.fr..._220 ur......_C00 sk.cs.lt_665
  0x24001a22, 0x10002b13, 0x0d000823, 0x16004014,   // xxx.hi..._870 cy.sv..._650 it.pt..._880 sl.lt..._660
  // [0250]
  0x66000313, 0x0c004208, 0x0f002e02, 0x00004506,   // nl.af..._650 mt.pl..._430 sq.es..._220 sk......_400
  0x16001a08, 0x1e004514, 0x0e001c02, 0x33374e08,   // xxx.lt..._430 sk.sr..._660 bg.ru..._220 fa.ar.ur_443
  0x00003f01, 0x30230e13, 0x4e003312, 0x161e1d14,   // sw......_200 ru.uk.be_665 ur.fa..._640 hr.sr.lt_666
  0x16001402, 0x0c004512, 0x1d002102, 0x25001e14,   // is.lt..._220 sk.pl..._640 tl.hr..._220 sr.mk..._660
  // [0260]
  0x01141aa4, 0x380d2b13, 0x45160202, 0x00008c1c,   // xxx.is.en_433 cy.pt.ca_665 da.lt.sk_222 ht......_800
  0x0e002302, 0x00001c1c, 0x0c003a02, 0x0c001508,   // uk.ru..._220 bg......_800 eu.pl..._220 lv.pl..._430
  0x451240a4, 0x30001e02, 0x21004509, 0x1c002514,   // sl.cs.sk_433 sr.be..._220 sk.tl..._440 mk.bg..._660
  0x0000331c, 0x4b002208, 0x0c002b09, 0x400b1008,   // ur......_800 tr.az..._430 cy.pl..._440 sv.no.sl_443
  // [0270]
  0x06000302, 0x2b002109, 0x8c003a02, 0x16000114,   // nl.de..._220 tl.cy..._440 eu.ht..._220 en.lt..._660
  0x19001013, 0x01000402, 0x22004b09, 0x19000302,   // sv.et..._650 fi.en..._220 az.tr..._440 nl.et..._220
  0x1d218c07, 0x22004b14, 0x17000409, 0x0000200f,   // ht.tl.hr_432 az.tr..._660 fi.ro..._440 gl......_600
  0x27212902, 0x22004b22, 0x27002922, 0x3f002108,   // ms.tl.id_222 az.tr..._870 ms.id..._870 tl.sw..._430
  // [0280]
  0x14001e02, 0x27002907, 0x42000813, 0x43002702,   // sr.is..._220 ms.id..._420 it.mt..._650 id.vi..._220
  0x00002201, 0x0f000d09, 0x66000214, 0x02000609,   // tr......_200 pt.es..._440 da.af..._660 de.da..._440
  0x00003a01, 0x38054508, 0x05000107, 0x1e2e1daf,   // eu......_200 sk.fr.ca_443 en.fr..._420 hr.sq.sr_655
  0x0000051c, 0x18003a14, 0x4b002114, 0x4b0d3a02,   // fr......_800 eu.hu..._660 tl.az..._660 eu.pt.az_222
  // [0290]
  0x0f001913, 0x293f2712, 0x00000b1c, 0x38000522,   // et.es..._650 id.sw.ms_654 no......_800 fr.ca..._870
  0x4b003f23, 0x401e1d14, 0x06000208, 0x04002714,   // sw.az..._880 hr.sr.sl_666 da.de..._430 id.fi..._660
  0x29000508, 0x0f000509, 0x0f003814, 0x25002323,   // fr.ms..._430 fr.es..._440 ca.es..._660 uk.mk..._880
  0x05000614, 0x0f000d14, 0x45220c12, 0x06456602,   // de.fr..._660 pt.es..._660 pl.tr.sk_654 af.sk.de_222
  // [02a0]
  0x38000f08, 0x66024012, 0x38050108, 0x06000d09,   // es.ca..._430 sl.da.af_654 en.fr.ca_443 pt.de..._440
  0x05001714, 0x06003f22, 0x19001709, 0x25301e09,   // ro.fr..._660 sw.de..._870 ro.et..._440 sr.be.mk_444
  0x25001e23, 0x45000202, 0x1e1d4008, 0x10006609,   // sr.mk..._880 da.sk..._220 sl.hr.sr_443 af.sv..._440
  0x42003809, 0x43003802, 0x0000031c, 0x04000523,   // ca.mt..._440 ca.vi..._220 nl......_800 fr.fi..._880
  // [02b0]
  0x1e0e2502, 0x29000423, 0x1d404508, 0x1c002507,   // mk.ru.sr_222 fi.ms..._880 sk.sl.hr_443 mk.bg..._420
  0x4b006602, 0x2e003f07, 0x05000b09, 0x0f000413,   // af.az..._220 sw.sq..._420 no.fr..._440 fi.es..._650
  0x1e000e02, 0x22004b21, 0x22002e14, 0x40001814,   // ru.sr..._220 az.tr..._860 sq.tr..._660 hu.sl..._660
  0x04051f12, 0x02004b02, 0x23003002, 0x1f003f13,   // ga.fr.fi_654 az.da..._220 be.uk..._220 sw.ga..._650
  // [02c0]
  0x42000b09, 0x45002902, 0x01000302, 0x151d1ea4,   // no.mt..._440 ms.sk..._220 nl.en..._220 sr.hr.lv_433
  0x45050f02, 0x3f224ba4, 0x21001014, 0x22044b12,   // es.fr.sk_222 az.tr.sw_433 sv.tl..._660 az.fi.tr_654
  0x15000409, 0x29000809, 0x66060107, 0x0f083a08,   // fi.lv..._440 it.ms..._440 en.de.af_432 eu.it.es_443
  0x02000b23, 0x43000813, 0x121e1a02, 0x3a000808,   // no.da..._880 it.vi..._650 xxx.sr.cs_222 it.eu..._430
  // [02d0]
  0x05003802, 0x22001a09, 0x1a002421, 0x0e002313,   // ca.fr..._220 xxx.tr..._440 hi.xxx..._860 uk.ru..._650
  0x00004301, 0x00000d1c, 0x223a42a4, 0x1e081d02,   // vi......_200 pt......_800 mt.eu.tr_433 hr.it.sr_222
  0x14000202, 0x1c003012, 0x43002708, 0x40001d14,   // da.is..._220 be.bg..._640 id.vi..._430 hr.sl..._660
  0x00001c06, 0x230e1caf, 0x22004502, 0x19184208,   // bg......_400 bg.ru.uk_655 sk.tr..._220 mt.hu.et_443
  // [02e0]
  0x1e0f1d02, 0x10000b09, 0x0f002909, 0x14100209,   // hr.es.sr_222 no.sv..._440 ms.es..._440 da.sv.is_444
  0x40000809, 0x10000802, 0x1f0c3a08, 0x02001009,   // it.sl..._440 it.sv..._220 eu.pl.ga_443 sv.da..._440
  0x04000b08, 0x23001e02, 0x1e002509, 0x16003a09,   // no.fi..._430 sr.uk..._220 mk.sr..._440 eu.lt..._440
  0x0f001009, 0x12000109, 0x02004309, 0x2b002909,   // sv.es..._440 en.cs..._440 vi.da..._440 ms.cy..._440
  // [02f0]
  0x23003022, 0x2b000109, 0x8c0c3fa4, 0x3a002908,   // be.uk..._870 en.cy..._440 sw.pl.ht_433 ms.eu..._430
  0x1a002423, 0x3a002002, 0x04003a13, 0x1f181460,   // hi.xxx..._880 gl.eu..._220 eu.fi..._650 is.hu.ga_664
  0x1e001608, 0x12000f09, 0x06001809, 0x1a002422,   // lt.sr..._430 es.cs..._440 hu.de..._440 hi.xxx..._870
  0x1e003a08, 0x33004e13, 0x202e0f07, 0x15000c13,   // eu.sr..._430 fa.ur..._650 es.sq.gl_432 pl.lv..._650
  // [0300]
  0x01002702, 0x0b101460, 0x06000209, 0x0c003a09,   // id.en..._220 is.sv.no_664 da.de..._440 eu.pl..._440
  0x0b000614, 0x0c004002, 0x02001508, 0x3a002e14,   // de.no..._660 sl.pl..._220 lv.da..._430 sq.eu..._660
  0x04004509, 0x1a002414, 0x05000123, 0x15001622,   // sk.fi..._440 hi.xxx..._660 en.fr..._880 lt.lv..._870
  0x29002b14, 0x00002306, 0x14000b02, 0x210b0212,   // cy.ms..._660 uk......_400 no.is..._220 da.no.tl_654
  // [0310]
  0x19004213, 0x1a001702, 0x42004b13, 0x18004202,   // mt.et..._650 ro.xxx..._220 az.mt..._650 mt.hu..._220
  0x2e001714, 0x04003a02, 0x24001a09, 0x1d3f1702,   // ro.sq..._660 eu.fi..._220 xxx.hi..._440 ro.sw.hr_222
  0x33374eaf, 0x01002102, 0x2e001709, 0x1e1c2512,   // fa.ar.ur_655 tl.en..._220 ro.sq..._440 mk.bg.sr_654
  0x42001f09, 0x33374e13, 0x01001809, 0x40124560,   // ga.mt..._440 fa.ar.ur_665 hu.en..._440 sk.cs.sl_664
  // [0320]
  0x18001e02, 0x18004502, 0x0b000109, 0x2e0c17af,   // sr.hu..._220 sk.hu..._220 en.no..._440 ro.pl.sq_655
  0x12014502, 0x0d000f02, 0x250e1c55, 0x18001f09,   // sk.en.cs_222 es.pt..._220 bg.ru.mk_442 ga.hu..._440
  0x66000308, 0x04002909, 0x03662b12, 0x1a002b08,   // nl.af..._430 ms.fi..._440 cy.af.nl_654 cy.xxx..._430
  0x05000109, 0x1c0e1e14, 0x10000209, 0x18124508,   // en.fr..._440 sr.ru.bg_666 da.sv..._440 sk.cs.hu_443
  // [0330]
  0x1a430302, 0x1c251e09, 0x14001002, 0x06001802,   // nl.vi.xxx_222 sr.mk.bg_444 sv.is..._220 hu.de..._220
  0x22006602, 0x0d000109, 0x66002102, 0x18004214,   // af.tr..._220 en.pt..._440 tl.af..._220 mt.hu..._660
  0x1e1d38a4, 0x1a000114, 0x3a0d0b07, 0x27002902,   // ca.hr.sr_433 en.xxx..._660 no.pt.eu_432 ms.id..._220
  0x1e1c25af, 0x02001023, 0x29270b07, 0x45003802,   // mk.bg.sr_655 sv.da..._880 no.id.ms_432 ca.sk..._220
  // [0340]
  0x1e401d02, 0x12008c09, 0x45000609, 0x0000661c,   // hr.sl.sr_222 ht.cs..._440 de.sk..._440 af......_800
  0x45001812, 0x66020107, 0x14021009, 0x45003a14,   // hu.sk..._640 en.da.af_432 sv.da.is_444 eu.sk..._660
  0x38000209, 0x380d4b08, 0x1f002102, 0x0e002509,   // da.ca..._440 az.pt.ca_443 tl.ga..._220 mk.ru..._440
  0x2b002723, 0x293a2709, 0x5c000711, 0x22002123,   // id.cy..._880 id.eu.ms_444 iw.yi..._630 tl.tr..._880
  // [0350]
  0x4b002e09, 0x03002714, 0x19002708, 0x18000513,   // sq.az..._440 id.nl..._660 id.et..._430 fr.hu..._650
  0x66000522, 0x4e333713, 0x1c300e08, 0x29002214,   // fr.af..._870 ar.ur.fa_665 ru.be.bg_443 tr.ms..._660
  0x3a000409, 0x0000142d, 0x22000608, 0x374e3360,   // fi.eu..._440 is......_A00 de.tr..._430 ur.fa.ar_664
  0x19224bb4, 0x12002014, 0x3f001f09, 0x1d001009,   // az.tr.et_754 gl.cs..._660 ga.sw..._440 sv.hr..._440
  // [0360]
  0x4b220608, 0x27004302, 0x29002209, 0x1e001d22,   // de.tr.az_443 vi.id..._220 tr.ms..._440 hr.sr..._870
  0x23001c02, 0x00001a2d, 0x0c004507, 0x02660312,   // bg.uk..._220 xxx......_A00 sk.pl..._420 nl.af.da_654
  0x19000423, 0x1e232509, 0x1e121d02, 0x3f002114,   // fi.et..._880 mk.uk.sr_444 hr.cs.sr_222 tl.sw..._660
  0x06004b13, 0x37334e11, 0x17000807, 0x40002e14,   // az.de..._650 fa.ur.ar_653 it.ro..._420 sq.sl..._660
  // [0370]
  0x1d000509, 0x45051208, 0x06012ea4, 0x0e002323,   // fr.hr..._440 cs.fr.sk_443 sq.en.de_433 uk.ru..._880
  0x02000b07, 0x08001702, 0x03000b09, 0x8c000d14,   // no.da..._420 ro.it..._220 no.nl..._440 pt.ht..._660
  0x0b000223, 0x4e003712, 0x1e004002, 0x1d1e1207,   // da.no..._880 ar.fa..._640 sl.sr..._220 cs.sr.hr_432
  0x02081708, 0x14006614, 0x1d001e14, 0x06006602,   // ro.it.da_443 af.is..._660 sr.hr..._660 af.de..._220
  // [0380]
  0x4e003714, 0x40008c14, 0x17000302, 0x0b000802,   // ar.fa..._660 ht.sl..._660 nl.ro..._220 it.no..._220
  0x27662907, 0x12180f07, 0x01000d02, 0x12004502,   // ms.af.id_432 es.hu.cs_432 pt.en..._220 sk.cs..._220
  0x45000114, 0x37003308, 0x161d15a4, 0x08060b07,   // en.sk..._660 ur.ar..._430 lv.hr.lt_433 no.de.it_432
  0x22004b23, 0x8c000814, 0x05000f09, 0x1f000107,   // az.tr..._880 it.ht..._660 es.fr..._440 en.ga..._420
  // [0390]
  0x0000271c, 0x1d001609, 0x450c1260, 0x06100109,   // id......_800 lt.hr..._440 cs.pl.sk_664 en.sv.de_444
  0x15160b09, 0x12450c02, 0x06221808, 0x03002909,   // no.lt.lv_444 pl.sk.cs_222 hu.tr.de_443 ms.nl..._440
  0x660f0113, 0x1f001209, 0x19002e08, 0x450c1202,   // en.es.af_665 cs.ga..._440 sq.et..._430 cs.pl.sk_222
  0x18450f14, 0x4e373360, 0x10001923, 0x0b000107,   // es.sk.hu_666 ur.ar.fa_664 et.sv..._880 en.no..._420
  // [03a0]
  0x210b0da4, 0x06000109, 0x06001012, 0x14004309,   // pt.no.tl_433 en.de..._440 sv.de..._640 vi.is..._440
  0x2b000502, 0x04004313, 0x45000323, 0x02190ba4,   // fr.cy..._220 vi.fi..._650 nl.sk..._880 no.et.da_433
  0x66000623, 0x10000614, 0x04061008, 0x37003313,   // de.af..._880 de.sv..._660 sv.de.fi_443 ur.ar..._650
  0x2e001012, 0x43000d09, 0x22000602, 0x19001014,   // sv.sq..._640 pt.vi..._440 de.tr..._220 sv.et..._660
  // [03b0]
  0x29002102, 0x10000b08, 0x0c004209, 0x1f000302,   // tl.ms..._220 no.sv..._430 mt.pl..._440 nl.ga..._220
  0x02001402, 0x18004514, 0x04001914, 0x660204af,   // is.da..._220 sk.hu..._660 et.fi..._660 fi.da.af_655
  0x14100b13, 0x043a1a13, 0x02002902, 0x42008c23,   // no.sv.is_665 xxx.eu.fi_665 ms.da..._220 ht.mt..._880
  0x1f000f14, 0x0b021014, 0x02000502, 0x29273f02,   // es.ga..._660 sv.da.no_666 fr.da..._220 sw.id.ms_222
  // [03c0]
  0x0e231e13, 0x380f0107, 0x18001402, 0x06002e23,   // sr.uk.ru_665 en.es.ca_432 is.hu..._220 sq.de..._880
  0x2e004523, 0x08002b02, 0x45001914, 0x0d001714,   // sk.sq..._880 cy.it..._220 et.sk..._660 ro.pt..._660
  0x30000e23, 0x45001602, 0x01004314, 0x06000f09,   // ru.be..._880 lt.sk..._220 vi.en..._660 es.de..._440
  0x1a001009, 0x03002b02, 0x10000102, 0x19000102,   // sv.xxx..._440 cy.nl..._220 en.sv..._220 en.et..._220
  // [03d0]
  0x14002b02, 0x38000d02, 0x08002102, 0x2b003a02,   // cy.is..._220 pt.ca..._220 tl.it..._220 eu.cy..._220
  0x22002e23, 0x05003823, 0x374e3309, 0x0000241c,   // sq.tr..._880 ca.fr..._880 ur.fa.ar_444 hi......_800
  0x19002108, 0x37003309, 0x42001423, 0x38000107,   // tl.et..._430 ur.ar..._440 is.mt..._880 en.ca..._420
  0x25001c22, 0x1d002114, 0x0c000614, 0x14001f12,   // bg.mk..._870 tl.hr..._660 de.pl..._660 ga.is..._640
  // [03e0]
  0x25003002, 0x06001909, 0x05000802, 0x0b001409,   // be.mk..._220 et.de..._440 it.fr..._220 is.no..._440
  0x05001423, 0x43002109, 0x33374e09, 0x1f002e09,   // is.fr..._880 tl.vi..._440 fa.ar.ur_444 sq.ga..._440
  0x30002312, 0x40000c23, 0x42002114, 0x05008c14,   // uk.be..._640 pl.sl..._880 tl.mt..._660 ht.fr..._660
  0x37004e12, 0x14001014, 0x45151602, 0x3f000109,   // fa.ar..._640 sv.is..._660 lt.lv.sk_222 en.sw..._440
  // [03f0]
  0x18000d13, 0x18001002, 0x19002914, 0x1e002523,   // pt.hu..._650 sv.hu..._220 ms.et..._660 mk.sr..._880
  0x0e251e60, 0x102e0408, 0x1c003013, 0x18004023,   // sr.mk.ru_664 fi.sq.sv_443 be.bg..._650 sl.hu..._880
  0x0c171208, 0x03020b09, 0x0b001402, 0x14002214,   // cs.ro.pl_443 no.da.nl_444 is.no..._220 tr.is..._660
  0x02001902, 0x45000f02, 0x29224b02, 0x04272913,   // et.da..._220 es.sk..._220 az.tr.ms_222 ms.id.fi_665

  // [0400]
  0x17084209, 0x0e001c12, 0x38224b11, 0x01004509,   // mt.it.ro_444 bg.ru..._640 az.tr.ca_653 sk.en..._440
  0x00000e01, 0x1a004309, 0x291a0107, 0x23001e14,   // ru......_200 vi.xxx..._440 en.xxx.ms_432 sr.uk..._660
  0x05002e12, 0x42000822, 0x2e000514, 0x22001922,   // sq.fr..._640 it.mt..._870 fr.sq..._660 et.tr..._870
  0x3f002e12, 0x121d4502, 0x10004014, 0x03006608,   // sq.sw..._640 sk.hr.cs_222 sl.sv..._660 af.nl..._430
  // [0410]
  0x12004507, 0x38003a23, 0x08001714, 0x15000513,   // sk.cs..._420 eu.ca..._880 ro.it..._660 fr.lv..._650
  0x00004b0a, 0x271e1d02, 0x16003f02, 0x1d1e2ea4,   // az......_500 hr.sr.id_222 sw.lt..._220 sq.sr.hr_433
  0x3f004208, 0x08001609, 0x451d1e02, 0x21001f22,   // mt.sw..._430 lt.it..._440 sr.hr.sk_222 ga.tl..._870
  0x10001821, 0x01003802, 0x0d001e02, 0x23000e14,   // hu.sv..._860 ca.en..._220 sr.pt..._220 ru.uk..._660
  // [0420]
  0x08001709, 0x1d124511, 0x17124560, 0x0e002512,   // ro.it..._440 sk.cs.hr_653 sk.cs.ro_664 mk.ru..._640
  0x18224b12, 0x0e233013, 0x334e3712, 0x1a002914,   // az.tr.hu_654 be.uk.ru_665 ar.fa.ur_654 ms.xxx..._660
  0x12004523, 0x18001614, 0x22008c08, 0x04001921,   // sk.cs..._880 lt.hu..._660 ht.tr..._430 et.fi..._860
  0x16000414, 0x08001814, 0x0c001202, 0x1f003814,   // fi.lt..._660 hu.it..._660 cs.pl..._220 ca.ga..._660
  // [0430]
  0x012b2108, 0x37004e11, 0x8c211655, 0x06002702,   // tl.cy.en_443 fa.ar..._630 lt.tl.ht_442 id.de..._220
  0x06036608, 0x2b002102, 0x01006609, 0x230e1e08,   // af.nl.de_443 tl.cy..._220 af.en..._440 sr.ru.uk_443
  0x43000812, 0x37004e09, 0x04001008, 0x19100411,   // it.vi..._640 fa.ar..._440 sv.fi..._430 fi.sv.et_653
  0x1e003809, 0x2e004214, 0x02000b13, 0x12002e02,   // ca.sr..._440 mt.sq..._660 no.da..._650 sq.cs..._220
  // [0440]
  0x2e000609, 0x0e1c2513, 0x15000802, 0x14001908,   // de.sq..._440 mk.bg.ru_665 it.lv..._220 et.is..._430
  0x04000612, 0x37334e09, 0x380d0fa4, 0x4e373311,   // de.fi..._640 fa.ur.ar_444 es.pt.ca_433 ur.ar.fa_653
  0x66030412, 0x0b003a02, 0x66003a09, 0x251c1e09,   // fi.nl.af_654 eu.no..._220 eu.af..._440 sr.bg.mk_444
  0x12454202, 0x12454314, 0x19000402, 0x10020b14,   // mt.sk.cs_222 vi.sk.cs_666 fi.et..._220 no.da.sv_666
  // [0450]
  0x0c004009, 0x23003013, 0x5c000723, 0x22003f14,   // sl.pl..._440 be.uk..._650 iw.yi..._880 sw.tr..._660
  0x23300e13, 0x3f006609, 0x01668c02, 0x23002513,   // ru.be.uk_665 af.sw..._440 ht.af.en_222 mk.uk..._650
  0x451218a4, 0x3a003f02, 0x0e003022, 0x0d0f3814,   // hu.cs.sk_433 sw.eu..._220 be.ru..._870 ca.es.pt_666
  0x27451602, 0x16004202, 0x00001e2d, 0x04002e14,   // lt.sk.id_222 mt.lt..._220 sr......_A00 sq.fi..._660
  // [0460]
  0x10002702, 0x18002902, 0x45002b02, 0x03003823,   // id.sv..._220 ms.hu..._220 cy.sk..._220 ca.nl..._880
  0x334e3760, 0x40004514, 0x451e1d02, 0x1e1c2508,   // ar.fa.ur_664 sk.sl..._660 hr.sr.sk_222 mk.bg.sr_443
  0x17272907, 0x04124513, 0x66000302, 0x0c3f8ca4,   // ms.id.ro_432 sk.cs.fi_665 nl.af..._220 ht.sw.pl_433
  0x0e001c22, 0x2b001608, 0x16000109, 0x124504a4,   // bg.ru..._870 lt.cy..._430 en.lt..._440 fi.sk.cs_433
  // [0470]
  0x40008c09, 0x12004509, 0x1a000109, 0x14000c09,   // ht.sl..._440 sk.cs..._440 en.xxx..._440 pl.is..._440
  0x3a000623, 0x29002707, 0x07005c21, 0x22004b12,   // de.eu..._880 id.ms..._420 yi.iw..._860 az.tr..._640
  0x1c002509, 0x0b001009, 0x2b000c14, 0x1a003f08,   // mk.bg..._440 sv.no..._440 pl.cy..._660 sw.xxx..._430
  0x12451d02, 0x1c0e2513, 0x211a2909, 0x4b002222,   // hr.sk.cs_222 mk.ru.bg_665 ms.xxx.tl_444 tr.az..._870
  // [0480]
  0x21004523, 0x4b220109, 0x45011260, 0x22000b09,   // sk.tl..._880 en.tr.az_444 cs.en.sk_664 no.tr..._440
  0x190416a4, 0x42001502, 0x02220b07, 0x29002109,   // lt.fi.et_433 lv.mt..._220 no.tr.da_432 tl.ms..._440
  0x08008c23, 0x0d000f14, 0x00002e2d, 0x3a202207,   // ht.it..._880 es.pt..._660 sq......_A00 tr.gl.eu_432
  0x17001f02, 0x05004514, 0x06001214, 0x17001914,   // ga.ro..._220 sk.fr..._660 cs.de..._660 et.ro..._660
  // [0490]
  0x1d1e0107, 0x0d170109, 0x02001422, 0x03003a14,   // en.sr.hr_432 en.ro.pt_444 is.da..._870 eu.nl..._660
  0x08001a09, 0x10000622, 0x1d021e02, 0x3a4b2260,   // xxx.it..._440 de.sv..._870 sr.da.hr_222 tr.az.eu_664
  0x1a000107, 0x3a3f1a14, 0x0000201c, 0x66000323,   // en.xxx..._420 xxx.sw.eu_666 gl......_800 nl.af..._880
  0x1e451d02, 0x4b002202, 0x42004509, 0x3a4b2208,   // hr.sk.sr_222 tr.az..._220 sk.mt..._440 tr.az.eu_443
  // [04a0]
  0x3a002214, 0x1a002223, 0x16002b13, 0x1e1d4507,   // tr.eu..._660 tr.xxx..._880 cy.lt..._650 sk.hr.sr_432
  0x1e021002, 0x00001601, 0x0f002223, 0x1d1e3a02,   // sv.da.sr_222 lt......_200 tr.es..._880 eu.sr.hr_222
  0x3a000f13, 0x1d1e4507, 0x27001709, 0x22000d07,   // es.eu..._650 sk.sr.hr_432 ro.id..._440 pt.tr..._420
  0x0e002307, 0x1f000508, 0x3a002012, 0x0e003023,   // uk.ru..._420 fr.ga..._430 gl.eu..._640 be.ru..._880
  // [04b0]
  0x101d4009, 0x37004e08, 0x06000b14, 0x1a000202,   // sl.hr.sv_444 fa.ar..._430 no.de..._660 da.xxx..._220
  0x17000814, 0x1e230e60, 0x1e0e1c02, 0x01001a07,   // it.ro..._660 ru.uk.sr_664 bg.ru.sr_222 xxx.en..._420
  0x08001209, 0x38000814, 0x15160109, 0x12004513,   // cs.it..._440 it.ca..._660 en.lt.lv_444 sk.cs..._650
  0x0d001f09, 0x0000381c, 0x29002709, 0x0f002b14,   // ga.pt..._440 ca......_800 id.ms..._440 cy.es..._660
  // [04c0]
  0x3f002b09, 0x05002b02, 0x22000823, 0x22292707,   // cy.sw..._440 cy.fr..._220 it.tr..._880 id.ms.tr_432
  0x0c001a09, 0x0f036608, 0x1d000802, 0x42002902,   // xxx.pl..._440 af.nl.es_443 it.hr..._220 ms.mt..._220
  0x1d124502, 0x18004b09, 0x04000613, 0x27002914,   // sk.cs.hr_222 az.hu..._440 de.fi..._650 ms.id..._660
  0x1f030612, 0x22008c14, 0x06001008, 0x1e251ca4,   // de.nl.ga_654 ht.tr..._660 sv.de..._430 bg.mk.sr_433
  // [04d0]
  0x0c001902, 0x66001009, 0x01004502, 0x10000b02,   // et.pl..._220 sv.af..._440 sk.en..._220 no.sv..._220
  0x29002702, 0x3f001d23, 0x063a6614, 0x10000223,   // id.ms..._220 hr.sw..._880 af.eu.de_666 da.sv..._880
  0x66001814, 0x12450109, 0x24001a20, 0x2b002214,   // hu.af..._660 en.sk.cs_444 xxx.hi..._850 tr.cy..._660
  0x16002b09, 0x230e1c08, 0x3a000f09, 0x1f001a09,   // cy.lt..._440 bg.ru.uk_443 es.eu..._440 xxx.ga..._440
  // [04e0]
  0x10060412, 0x4e003321, 0x29001a02, 0x27291702,   // fi.de.sv_654 ur.fa..._860 xxx.ms..._220 ro.ms.id_222
  0x06660308, 0x03000623, 0x1a002909, 0x00001801,   // nl.af.de_443 de.nl..._880 ms.xxx..._440 hu......_200
  0x37334e60, 0x43002709, 0x1f002e14, 0x1e001d09,   // fa.ur.ar_664 id.vi..._440 sq.ga..._660 hr.sr..._440
  0x04000608, 0x0d001f11, 0x04001022, 0x1c0e2314,   // de.fi..._430 ga.pt..._630 sv.fi..._870 uk.ru.bg_666
  // [04f0]
  0x1f050109, 0x231c0eaf, 0x06001409, 0x3a000f02,   // en.fr.ga_444 ru.bg.uk_655 is.de..._440 es.eu..._220
  0x17003a02, 0x17002714, 0x380f0da4, 0x3a172e09,   // eu.ro..._220 id.ro..._660 pt.es.ca_433 sq.ro.eu_444
  0x3a001714, 0x1e1c2514, 0x29002722, 0x02000602,   // ro.eu..._660 mk.bg.sr_666 id.ms..._870 de.da..._220
  0x451e40a4, 0x04006609, 0x16001913, 0x04003f23,   // sl.sr.sk_433 af.fi..._440 et.lt..._650 sw.fi..._880
  // [0500]
  0x0e302313, 0x1d006602, 0x45120b07, 0x21003f02,   // uk.be.ru_665 af.hr..._220 no.cs.sk_432 sw.tl..._220
  0x21002902, 0x16001e08, 0x06036609, 0x3a001722,   // ms.tl..._220 sr.lt..._430 af.nl.de_444 ro.eu..._870
  0x213f0da4, 0x3f008c14, 0x0f001714, 0x0f380d08,   // pt.sw.tl_433 ht.sw..._660 ro.es..._660 pt.ca.es_443
  0x3f006602, 0x06001913, 0x1d3f4002, 0x1d004009,   // af.sw..._220 et.de..._650 sl.sw.hr_222 sl.hr..._440
  // [0510]
  0x04001012, 0x0d000409, 0x29451a02, 0x29001914,   // sv.fi..._640 fi.pt..._440 xxx.sk.ms_222 et.ms..._660
  0x1d401207, 0x19002709, 0x18000409, 0x1c002502,   // cs.sl.hr_432 id.et..._440 fi.hu..._440 mk.bg..._220
  0x3f002914, 0x0c002e09, 0x1e1d2907, 0x08000109,   // ms.sw..._660 sq.pl..._440 ms.hr.sr_432 en.it..._440
  0x1f001914, 0x10000623, 0x0c003f12, 0x251c0e08,   // et.ga..._660 de.sv..._880 sw.pl..._640 ru.bg.mk_443
  // [0520]
  0x0f008c13, 0x1d001e08, 0x1d178c02, 0x3f001d14,   // ht.es..._650 sr.hr..._430 ht.ro.hr_222 hr.sw..._660
  0x1f0f2ba4, 0x29142102, 0x3f004213, 0x45121014,   // cy.es.ga_433 tl.is.ms_222 mt.sw..._650 sv.cs.sk_666
  0x12000c02, 0x06660209, 0x0d0f3802, 0x0c006608,   // pl.cs..._220 da.af.de_444 ca.es.pt_222 af.pl..._430
  0x16151908, 0x0f380daf, 0x16001f23, 0x07005c20,   // et.lv.lt_443 pt.ca.es_655 ga.lt..._880 yi.iw..._850
  // [0530]
  0x40001622, 0x1f000114, 0x27042b08, 0x1f211912,   // lt.sl..._870 en.ga..._660 cy.fi.id_443 et.tl.ga_654
  0x251c0ea4, 0x19000b21, 0x10001722, 0x27002b09,   // ru.bg.mk_433 no.et..._860 ro.sv..._870 cy.id..._440
  0x10001413, 0x660b0309, 0x401d16af, 0x8c000614,   // is.sv..._650 nl.no.af_444 lt.hr.sl_655 de.ht..._660
  0x1c002522, 0x10000608, 0x38000523, 0x231c0e14,   // mk.bg..._870 de.sv..._430 fr.ca..._880 ru.bg.uk_666
  // [0540]
  0x0c161a12, 0x01001a02, 0x16000b02, 0x1a004b14,   // xxx.lt.pl_654 xxx.en..._220 no.lt..._220 az.xxx..._660
  0x00002b01, 0x25001e09, 0x060366a4, 0x43000512,   // cy......_200 sr.mk..._440 af.nl.de_433 fr.vi..._640
  0x06002109, 0x05000114, 0x18008c13, 0x45000d12,   // tl.de..._440 en.fr..._660 ht.hu..._650 pt.sk..._640
  0x03006607, 0x23000e07, 0x06000309, 0x42000802,   // af.nl..._420 ru.uk..._420 nl.de..._440 it.mt..._220
  // [0550]
  0x1d151602, 0x0000302d, 0x27001923, 0x3a000f08,   // lt.lv.hr_222 be......_A00 et.id..._880 es.eu..._430
  0x2b003f02, 0x0f000802, 0x16000f13, 0x27003f02,   // sw.cy..._220 it.es..._220 es.lt..._650 sw.id..._220
  0x37004e21, 0x43000d08, 0x1d1e4502, 0x3f002213,   // fa.ar..._860 pt.vi..._430 sk.sr.hr_222 tr.sw..._650
  0x1d1e3aa4, 0x1e008c09, 0x16001a09, 0x04006602,   // eu.sr.hr_433 ht.sr..._440 xxx.lt..._440 af.fi..._220
  // [0560]
  0x19002209, 0x14224255, 0x2b004223, 0x22002709,   // tr.et..._440 mt.tr.is_442 mt.cy..._880 id.tr..._440
  0x274b2212, 0x4b082214, 0x4b002b02, 0x14421209,   // tr.az.id_654 tr.it.az_666 cy.az..._220 cs.mt.is_444
  0x0b000308, 0x1a003a02, 0x42002b22, 0x38000f13,   // nl.no..._430 eu.xxx..._220 cy.mt..._870 es.ca..._650
  0x42001902, 0x14002b14, 0x06002223, 0x1f001414,   // et.mt..._220 cy.is..._660 tr.de..._880 is.ga..._660
  // [0570]
  0x3a000209, 0x42001714, 0x3f002714, 0x12000107,   // da.eu..._440 ro.mt..._660 id.sw..._660 en.cs..._420
  0x3f002723, 0x3a200107, 0x20000d02, 0x3a000622,   // id.sw..._880 en.gl.eu_432 pt.gl..._220 de.eu..._870
  0x0c001207, 0x42001708, 0x401d1209, 0x42000d02,   // cs.pl..._420 ro.mt..._430 cs.hr.sl_444 pt.mt..._220
  0x451d1e08, 0x4e003722, 0x22004202, 0x1f0c3808,   // sr.hr.sk_443 ar.fa..._870 mt.tr..._220 ca.pl.ga_443
  // [0580]
  0x0000152d, 0x230e1c09, 0x171d1ea4, 0x1d004b02,   // lv......_A00 bg.ru.uk_444 sr.hr.ro_433 az.hr..._220
  0x1f003802, 0x17000109, 0x1a063f08, 0x1d171e09,   // ca.ga..._220 en.ro..._440 sw.de.xxx_443 sr.ro.hr_444
  0x1d291e02, 0x251c0e13, 0x01000f14, 0x0f001709,   // sr.ms.hr_222 ru.bg.mk_665 es.en..._660 ro.es..._440
  0x1c0e2307, 0x1e230e12, 0x231c0e08, 0x1e002323,   // uk.ru.bg_432 ru.uk.sr_654 ru.bg.uk_443 uk.sr..._880
  // [0590]
  0x1a000c14, 0x29212e02, 0x18001f07, 0x0b001422,   // pl.xxx..._660 sq.tl.ms_222 ga.hu..._420 is.no..._870
  0x25002302, 0x0e251ca4, 0x27290b07, 0x036606a4,   // uk.mk..._220 bg.mk.ru_433 no.ms.id_432 de.af.nl_433
  0x45000613, 0x03003a02, 0x08003802, 0x03000613,   // de.sk..._650 eu.nl..._220 ca.it..._220 de.nl..._650
  0x06001202, 0x02660b07, 0x0d001902, 0x04001002,   // cs.de..._220 no.af.da_432 et.pt..._220 sv.fi..._220
  // [05a0]
  0x15001609, 0x19001a08, 0x12450102, 0x0f001412,   // lt.lv..._440 xxx.et..._430 en.sk.cs_222 is.es..._640
  0x1e003023, 0x1e251c09, 0x66000202, 0x0e251c14,   // be.sr..._880 bg.mk.sr_444 da.af..._220 bg.mk.ru_666
  0x3f000114, 0x12450107, 0x38003a09, 0x00004003,   // en.sw..._660 en.sk.cs_432 eu.ca..._440 sl......_300
  0x45000102, 0x0b001002, 0x45002702, 0x01000602,   // en.sk..._220 sv.no..._220 id.sk..._220 de.en..._220
  // [05b0]
  0x124501a4, 0x1f0b0213, 0x08004211, 0x38003a12,   // en.sk.cs_433 da.no.ga_665 mt.it..._630 eu.ca..._640
  0x10000602, 0x0e251c08, 0x1d1e1a02, 0x0b000214,   // de.sv..._220 bg.mk.ru_443 xxx.sr.hr_222 da.no..._660
  0x23003012, 0x1d161e07, 0x02000b22, 0x0e001c07,   // be.uk..._640 sr.lt.hr_432 no.da..._870 bg.ru..._420
  0x20000d14, 0x1d001a02, 0x30251e08, 0x2e121a09,   // pt.gl..._660 xxx.hr..._220 sr.mk.be_443 xxx.cs.sq_444
  // [05c0]
  0x1c232560, 0x0b021060, 0x66031009, 0x0d058c5e,   // mk.uk.bg_664 sv.da.no_664 sv.nl.af_444 ht.fr.pt_652
  0x42000613, 0x121e1d02, 0x03000614, 0x23000e21,   // de.mt..._650 hr.sr.cs_222 de.nl..._660 ru.uk..._860
  0x0b001423, 0x40000c14, 0x2b000623, 0x02100b14,   // is.no..._880 pl.sl..._660 de.cy..._880 no.sv.da_666
  0x0b021012, 0x27002908, 0x10001423, 0x14003a14,   // sv.da.no_654 ms.id..._430 is.sv..._880 eu.is..._660
  // [05d0]
  0x03000107, 0x14000b23, 0x45001202, 0x0000082d,   // en.nl..._420 no.is..._880 cs.sk..._220 it......_A00
  0x4e373314, 0x02000b02, 0x08001414, 0x1f000b09,   // ur.ar.fa_666 no.da..._220 is.it..._660 no.ga..._440
  0x01004214, 0x66001207, 0x19000602, 0x0c2e4509,   // mt.en..._660 cs.af..._420 de.et..._220 sk.sq.pl_444
  0x1a036612, 0x8c004509, 0x14000602, 0x0b000221,   // af.nl.xxx_654 sk.ht..._440 de.is..._220 da.no..._860
  // [05e0]
  0x04001909, 0x0c004502, 0x0d004523, 0x0b004014,   // et.fi..._440 sk.pl..._220 sk.pt..._880 sl.no..._660
  0x1a190402, 0x14003a09, 0x43008c02, 0x0f3a20af,   // fi.et.xxx_222 eu.is..._440 ht.vi..._220 gl.eu.es_655
  0x1d404507, 0x14000613, 0x17001614, 0x06008c09,   // sk.sl.hr_432 de.is..._650 lt.ro..._660 ht.de..._440
  0x0000022d, 0x14000b07, 0x18001413, 0x450d1202,   // da......_A00 no.is..._420 is.hu..._650 cs.pt.sk_222
  // [05f0]
  0x01000f02, 0x05228caf, 0x03000514, 0x33374e60,   // es.en..._220 ht.tr.fr_655 fr.nl..._660 fa.ar.ur_664
  0x0f001f12, 0x8c4b2260, 0x25001c13, 0x17003814,   // ga.es..._640 tr.az.ht_664 bg.mk..._650 ca.ro..._660
  0x45041602, 0x1e1d2202, 0x1d001e13, 0x22002723,   // lt.fi.sk_222 tr.hr.sr_222 sr.hr..._650 id.tr..._880
  0x08001602, 0x0c004514, 0x10020b09, 0x4b002e08,   // lt.it..._220 sk.pl..._660 no.da.sv_444 sq.az..._430
  // [0600]
  0x1a008c02, 0x17000513, 0x03000502, 0x1e252302,   // ht.xxx..._220 fr.ro..._650 fr.nl..._220 uk.mk.sr_222
  0x30230e12, 0x30001c13, 0x01000202, 0x00008c2d,   // ru.uk.be_654 bg.be..._650 da.en..._220 ht......_A00
  0x0b450107, 0x45123a02, 0x18002b02, 0x8c000109,   // en.sk.no_432 eu.cs.sk_222 cy.hu..._220 en.ht..._440
  0x17000802, 0x18003802, 0x0e302309, 0x2e000302,   // it.ro..._220 ca.hu..._220 uk.be.ru_444 nl.sq..._220
  // [0610]
  0x0c002b22, 0x1f004514, 0x3a002223, 0x10001714,   // cy.pl..._870 sk.ga..._660 tr.eu..._880 ro.sv..._660
  0x10001909, 0x10080b07, 0x45380507, 0x2e000802,   // et.sv..._440 no.it.sv_432 fr.ca.sk_432 it.sq..._220
  0x1d1e40a4, 0x0c8c18af, 0x08001723, 0x1e124502,   // sl.sr.hr_433 hu.ht.pl_655 ro.it..._880 sk.cs.sr_222
  0x16000d14, 0x27008c02, 0x07005c22, 0x0000192d,   // pt.lt..._660 ht.id..._220 yi.iw..._870 et......_A00
  // [0620]
  0x0c004523, 0x04000f09, 0x3f002202, 0x06034507,   // sk.pl..._880 es.fi..._440 tr.sw..._220 sk.nl.de_432
  0x10000823, 0x08000414, 0x1d004514, 0x1d004014,   // it.sv..._880 fi.it..._660 sk.hr..._660 sl.hr..._660
  0x05000b02, 0x08170b07, 0x01000502, 0x08003a23,   // no.fr..._220 no.ro.it_432 fr.en..._220 eu.it..._880
  0x10001702, 0x088c0b09, 0x1a002420, 0x0d0f3fa4,   // ro.sv..._220 no.ht.it_444 hi.xxx..._850 sw.es.pt_433
  // [0630]
  0x29036602, 0x66060b13, 0x2e001702, 0x3a002713,   // af.nl.ms_222 no.de.af_665 ro.sq..._220 id.eu..._650
  0x0b1002af, 0x14000b09, 0x29002e23, 0x0b000213,   // da.sv.no_655 no.is..._440 sq.ms..._880 da.no..._650
  0x45000802, 0x0c000414, 0x02002923, 0x02100baf,   // it.sk..._220 fi.pl..._660 ms.da..._880 no.sv.da_655
  0x06006614, 0x45100b02, 0x2b003809, 0x15000309,   // af.de..._660 no.sv.sk_222 ca.cy..._440 nl.lv..._440
  // [0640]
  0x45006602, 0x30000e09, 0x0e003021, 0x19002902,   // af.sk..._220 ru.be..._440 be.ru..._860 ms.et..._220
  0x4e333760, 0x1d001e07, 0x02004209, 0x4e333712,   // ar.ur.fa_664 sr.hr..._420 mt.da..._440 ar.ur.fa_654
  0x1a003f07, 0x3a000c13, 0x22000202, 0x1e251c60,   // sw.xxx..._420 pl.eu..._650 da.tr..._220 bg.mk.sr_664
  0x3a000814, 0x0f002013, 0x08003a02, 0x17004509,   // it.eu..._660 gl.es..._650 eu.it..._220 sk.ro..._440
  // [0650]
  0x08036607, 0x0c001412, 0x0c000109, 0x273a2902,   // af.nl.it_432 is.pl..._640 en.pl..._440 ms.eu.id_222
  0x15006622, 0x1d164002, 0x45083a55, 0x17006602,   // af.lv..._870 sl.lt.hr_222 eu.it.sk_442 af.ro..._220
  0x2b002702, 0x27293a02, 0x22000d02, 0x080c1209,   // id.cy..._220 eu.ms.id_222 pt.tr..._220 cs.pl.it_444
  0x29003a14, 0x3a000809, 0x3f008c08, 0x66050107,   // eu.ms..._660 it.eu..._440 ht.sw..._430 en.fr.af_432
  // [0660]
  0x1a450109, 0x06000c22, 0x0000032d, 0x66000d02,   // en.sk.xxx_444 pl.de..._870 nl......_A00 pt.af..._220
  0x06660355, 0x450c6602, 0x38000509, 0x0c001209,   // nl.af.de_442 af.pl.sk_222 fr.ca..._440 cs.pl..._440
  0x06003a02, 0x02141008, 0x03000102, 0x22002114,   // eu.de..._220 sv.is.da_443 en.nl..._220 tl.tr..._660
  0x401e1d55, 0x21000109, 0x40001514, 0x3a001913,   // hr.sr.sl_442 en.tl..._440 lv.sl..._660 et.eu..._650
  // [0670]
  0x05002214, 0x20002b02, 0x2e000123, 0x1e1d2909,   // tr.fr..._660 cy.gl..._220 en.sq..._880 ms.hr.sr_444
  0x21100b60, 0x01002b02, 0x4b002221, 0x14001921,   // no.sv.tl_664 cy.en..._220 tr.az..._860 et.is..._860
  0x06002b09, 0x1e000e14, 0x4e003711, 0x12451a07,   // cy.de..._440 ru.sr..._660 ar.fa..._630 xxx.sk.cs_432
  0x66002109, 0x14000d23, 0x10000b23, 0x0c124513,   // tl.af..._440 pt.is..._880 no.sv..._880 sk.cs.pl_665
  // [0680]
  0x1c000e22, 0x2b000d02, 0x0f002002, 0x66060314,   // ru.bg..._870 pt.cy..._220 gl.es..._220 nl.de.af_666
  0x0d420107, 0x05000302, 0x27036660, 0x18001502,   // en.mt.pt_432 nl.fr..._220 af.nl.id_664 lv.hu..._220
  0x4e373308, 0x8c004b13, 0x06002b13, 0x191d1e08,   // ur.ar.fa_443 az.ht..._650 cy.de..._650 sr.hr.et_443
  0x19100b09, 0x06000509, 0x0f183860, 0x02000b09,   // no.sv.et_444 fr.de..._440 ca.hu.es_664 no.da..._440
  // [0690]
  0x45002709, 0x03000d02, 0x08000302, 0x100b0212,   // id.sk..._440 pt.nl..._220 nl.it..._220 da.no.sv_654
  0x0e301cad, 0x19001802, 0x0c002b12, 0x3f002702,   // bg.be.ru_643 hu.et..._220 cy.pl..._640 id.sw..._220
  0x14000212, 0x05000d12, 0x0d000602, 0x1e221d02,   // da.is..._640 pt.fr..._640 de.pt..._220 hr.tr.sr_222
  0x14002b23, 0x03000809, 0x19001414, 0x37334ead,   // cy.is..._880 it.nl..._440 is.et..._660 fa.ur.ar_643
  // [06a0]
  0x1d451902, 0x10001414, 0x451e1207, 0x42001514,   // et.sk.hr_222 is.sv..._660 cs.sr.sk_432 lv.mt..._660
  0x29003f13, 0x02001802, 0x1d1e1209, 0x3f292760,   // sw.ms..._650 hu.da..._220 cs.sr.hr_444 id.ms.sw_664
  0x03001913, 0x42003f14, 0x16001902, 0x14003f14,   // et.nl..._650 sw.mt..._660 et.lt..._220 sw.is..._660
  0x1e1d1209, 0x3f001914, 0x45000814, 0x22008c09,   // cs.hr.sr_444 et.sw..._660 it.sk..._660 ht.tr..._440
  // [06b0]
  0x15001923, 0x03000802, 0x03006622, 0x38010daf,   // et.lv..._880 it.nl..._220 af.nl..._870 pt.en.ca_655
  0x37334e14, 0x22001402, 0x1e003002, 0x2e003f23,   // fa.ur.ar_666 is.tr..._220 be.sr..._220 sw.sq..._880
  0x12004522, 0x06003802, 0x19002909, 0x0e231c14,   // sk.cs..._870 ca.de..._220 ms.et..._440 bg.uk.ru_666
  0x15000f02, 0x16000814, 0x06004209, 0x0c142b12,   // es.lv..._220 it.lt..._660 mt.de..._440 cy.is.pl_654
  // [06c0]
  0x0d003802, 0x06001a13, 0x0f003802, 0x143f0208,   // ca.pt..._220 xxx.de..._650 ca.es..._220 da.sw.is_443
  0x0e231c12, 0x42001702, 0x33004e23, 0x1d228c08,   // bg.uk.ru_654 ro.mt..._220 fa.ur..._880 ht.tr.hr_443
  0x383a0f08, 0x19001822, 0x27002b13, 0x19292709,   // es.eu.ca_443 hu.et..._870 cy.id..._650 id.ms.et_444
  0x0d003f13, 0x1c2523a4, 0x02001409, 0x4b221808,   // sw.pt..._650 uk.mk.bg_433 is.da..._440 hu.tr.az_443
  // [06d0]
  0x3f000b09, 0x08001a12, 0x0f000502, 0x06001002,   // no.sw..._440 xxx.it..._640 fr.es..._220 sv.de..._220
  0x18001009, 0x04000b09, 0x2b001414, 0x0b000114,   // sv.hu..._440 no.fi..._440 is.cy..._660 en.no..._660
  0x660c4212, 0x10000207, 0x08000107, 0x8c004b21,   // mt.pl.af_654 da.sv..._420 en.it..._420 az.ht..._860
  0x0c001623, 0x33374e14, 0x3f000b13, 0x294b2208,   // lt.pl..._880 fa.ar.ur_666 no.sw..._650 tr.az.ms_443
  // [06e0]
  0x06000422, 0x1c1e2514, 0x08050109, 0x1e002512,   // fi.de..._870 mk.sr.bg_666 en.fr.it_444 mk.sr..._640
  0x0c171209, 0x06004223, 0x1d002202, 0x300e2313,   // cs.ro.pl_444 mt.de..._880 tr.hr..._220 uk.ru.be_665
  0x14001614, 0x45000b08, 0x0000372d, 0x27000422,   // lt.is..._660 no.sk..._430 ar......_A00 fi.id..._870
  0x02000b08, 0x00001501, 0x19004302, 0x1a004013,   // no.da..._430 lv......_200 vi.et..._220 sl.xxx..._650
  // [06f0]
  0x8c000502, 0x37004e23, 0x0c000609, 0x30001e09,   // fr.ht..._220 fa.ar..._880 de.pl..._440 sr.be..._440
  0x380d0f09, 0x0b4540a4, 0x21004209, 0x1f002e23,   // es.pt.ca_444 sl.sk.no_433 mt.tl..._440 sq.ga..._880
  0x06000d02, 0x08001502, 0x01000509, 0x2b001f22,   // pt.de..._220 lv.it..._220 fr.en..._440 ga.cy..._870
  0x1d451208, 0x05080114, 0x3f002909, 0x08050155,   // cs.sk.hr_443 en.it.fr_666 ms.sw..._440 en.fr.it_442
  // [0700]
  0x45160c02, 0x43000d13, 0x2e001e14, 0x08001823,   // pl.lt.sk_222 pt.vi..._650 sr.sq..._660 hu.it..._880
  0x17001209, 0x1f000409, 0x06000414, 0x08000623,   // cs.ro..._440 fi.ga..._440 fi.de..._660 de.it..._880
  0x06001422, 0x08002114, 0x193f0107, 0x1f002914,   // is.de..._870 tl.it..._660 en.sw.et_432 ms.ga..._660
  0x2e004002, 0x2e002102, 0x2e004b23, 0x224b2e60,   // sl.sq..._220 tl.sq..._220 az.sq..._880 sq.az.tr_664
  // [0710]
  0x16002e02, 0x2e001f22, 0x2e191207, 0x17001623,   // sq.lt..._220 ga.sq..._870 cs.et.sq_432 lt.ro..._880
  0x3f002e23, 0x19002e14, 0x17004502, 0x1e1d21a4,   // sq.sw..._880 sq.et..._660 sk.ro..._220 tl.hr.sr_433
  0x21001d09, 0x01004209, 0x1d274002, 0x66004209,   // hr.tl..._440 mt.en..._440 sl.id.hr_222 mt.af..._440
  0x07005c11, 0x19000f02, 0x2e000109, 0x2e004b09,   // yi.iw..._630 es.et..._220 en.sq..._440 az.sq..._440
  // [0720]
  0x040c1412, 0x120c4513, 0x27001202, 0x29003a09,   // is.pl.fi_654 sk.pl.cs_665 cs.id..._220 eu.ms..._440
  0x45000809, 0x18006602, 0x1e001c14, 0x3f002902,   // it.sk..._440 af.hu..._220 bg.sr..._660 ms.sw..._220
  0x16292709, 0x27003f09, 0x27382902, 0x23002514,   // id.ms.lt_444 sw.id..._440 ms.ca.id_222 mk.uk..._660
  0x221e1da4, 0x14001012, 0x06001407, 0x22000613,   // hr.sr.tr_433 sv.is..._640 is.de..._420 de.tr..._650
  // [0730]
  0x1e0e1c60, 0x45221213, 0x29278c12, 0x45001d02,   // bg.ru.sr_664 cs.tr.sk_665 ht.id.ms_654 hr.sk..._220
  0x16272908, 0x1c230e14, 0x0000162d, 0x0b000212,   // ms.id.lt_443 ru.uk.bg_666 lt......_A00 da.no..._640
  0x45001d14, 0x8c002702, 0x40001d02, 0x0e001c08,   // hr.sk..._660 id.ht..._220 hr.sl..._220 bg.ru..._430
  0x451d8c02, 0x14100612, 0x5c00070e, 0x45000f08,   // ht.hr.sk_222 de.sv.is_654 iw.yi..._550 es.sk..._430
  // [0740]
  0x45001002, 0x231c0e12, 0x43000509, 0x1d272902,   // sv.sk..._220 ru.bg.uk_654 fr.vi..._440 ms.id.hr_222
  0x211e1daf, 0x25001c09, 0x1e1d4012, 0x2e000814,   // hr.sr.tl_655 bg.mk..._440 sl.hr.sr_654 it.sq..._660
  0x100b0208, 0x12450d08, 0x12000609, 0x04004b09,   // da.no.sv_443 pt.sk.cs_443 de.cs..._440 az.fi..._440
  0x1d403f02, 0x14001009, 0x2b001002, 0x45194002,   // sw.sl.hr_222 sv.is..._440 sv.cy..._220 sl.et.sk_222
  // [0750]
  0x10022b08, 0x1e251c13, 0x4e003311, 0x2b008c12,   // cy.da.sv_443 bg.mk.sr_665 ur.fa..._630 ht.cy..._640
  0x0000242d, 0x66001909, 0x00003a2d, 0x45003a23,   // hi......_A00 et.af..._440 eu......_A00 eu.sk..._880
  0x01008c13, 0x401d4509, 0x8c001614, 0x04001812,   // ht.en..._650 sk.hr.sl_444 lt.ht..._660 hu.fi..._640
  0x16153a12, 0x27160202, 0x3a001414, 0x251e0e09,   // eu.lv.lt_654 da.lt.id_222 is.eu..._660 ru.sr.mk_444
  // [0760]
  0x29002114, 0x2b008c02, 0x29002712, 0x40001207,   // tl.ms..._660 ht.cy..._220 id.ms..._640 cs.sl..._420
  0x1c230e13, 0x12451855, 0x08004213, 0x2b000d14,   // ru.uk.bg_665 hu.sk.cs_442 mt.it..._650 pt.cy..._660
  0x101a1609, 0x251c0e14, 0x18000f14, 0x18000f13,   // lt.xxx.sv_444 ru.bg.mk_666 es.hu..._660 es.hu..._650
  0x38002902, 0x0f001812, 0x4b002b13, 0x18380f14,   // ms.ca..._220 hu.es..._640 cy.az..._650 es.ca.hu_666
  // [0770]
  0x1d000c14, 0x450f18a4, 0x19000b02, 0x15000b21,   // pl.hr..._660 hu.es.sk_433 no.et..._220 no.lv..._860
  0x33374e11, 0x02001021, 0x0f001820, 0x45190455,   // fa.ar.ur_653 sv.da..._860 hu.es..._850 fi.et.sk_442
  0x15000402, 0x38000f14, 0x0c000114, 0x18000f09,   // fi.lv..._220 es.ca..._660 en.pl..._660 es.hu..._440
  0x0d002213, 0x43001a02, 0x1a004208, 0x45061702,   // tr.pt..._650 xxx.vi..._220 mt.xxx..._430 ro.de.sk_222
  // [0780]
  0x1c003002, 0x0f000109, 0x1d190109, 0x30000e14,   // be.bg..._220 en.es..._440 en.et.hr_444 ru.be..._660
  0x01002909, 0x29004309, 0x301c2511, 0x2b000107,   // ms.en..._440 vi.ms..._440 mk.bg.be_653 en.cy..._420
  0x10000612, 0x0f381812, 0x1d000d09, 0x8c000409,   // de.sv..._640 hu.ca.es_654 pt.hr..._440 fi.ht..._440
  0x122b4502, 0x1e0e1c08, 0x0e233009, 0x22001914,   // sk.cy.cs_222 bg.ru.sr_443 be.uk.ru_444 et.tr..._660
  // [0790]
  0x1e001509, 0x1f002b23, 0x22001809, 0x1e002313,   // lv.sr..._440 cy.ga..._880 hu.tr..._440 uk.sr..._650
  0x1e1c2513, 0x42001913, 0x2e000b02, 0x250e1c14,   // mk.bg.sr_665 et.mt..._650 no.sq..._220 bg.ru.mk_666
  0x22184ba4, 0x0c003802, 0x18002223, 0x183f0802,   // az.hu.tr_433 ca.pl..._220 tr.hu..._880 it.sw.hu_222
  0x4b001813, 0x06002b12, 0x22184507, 0x03663807,   // hu.az..._650 cy.de..._640 sk.hu.tr_432 ca.af.nl_432
  // [07a0]
  0x1d004013, 0x29001f23, 0x10660309, 0x0c008c09,   // sl.hr..._650 ga.ms..._880 nl.af.sv_444 ht.pl..._440
  0x04003f09, 0x03006612, 0x1d1e1502, 0x0d001f13,   // sw.fi..._440 af.nl..._640 lv.sr.hr_222 ga.pt..._650
  0x02001412, 0x1f006602, 0x03003808, 0x0e1e2312,   // is.da..._640 af.ga..._220 ca.nl..._430 uk.sr.ru_654
  0x12454002, 0x0c000809, 0x17000808, 0x2e006602,   // sl.sk.cs_222 it.pl..._440 it.ro..._430 af.sq..._220
  // [07b0]
  0x40000202, 0x4b002109, 0x2e000c09, 0x14000222,   // da.sl..._220 tl.az..._440 pl.sq..._440 da.is..._870
  0x21001214, 0x2e002b13, 0x1e1d1613, 0x01004514,   // cs.tl..._660 cy.sq..._650 lt.hr.sr_665 sk.en..._660
  0x01003a09, 0x17008c02, 0x45180b13, 0x0e1e2513,   // eu.en..._440 ht.ro..._220 no.hu.sk_665 mk.sr.ru_665
  0x18001623, 0x18002121, 0x01002b14, 0x02200109,   // lt.hu..._880 tl.hu..._860 cy.en..._660 en.gl.da_444
  // [07c0]
  0x0c002b08, 0x0c3a18af, 0x22000d08, 0x2b001014,   // cy.pl..._430 hu.eu.pl_655 pt.tr..._430 sv.cy..._660
  0x10000208, 0x08000b09, 0x3a080b07, 0x16190b09,   // da.sv..._430 no.it..._440 no.it.eu_432 no.et.lt_444
  0x17000b09, 0x05001f09, 0x23000e23, 0x05001f13,   // no.ro..._440 ga.fr..._440 ru.uk..._880 ga.fr..._650
  0x02106609, 0x05001f14, 0x450c2b02, 0x2b001012,   // af.sv.da_444 ga.fr..._660 cy.pl.sk_222 sv.cy..._640
  // [07d0]
  0x0e003012, 0x401d1e07, 0x3a153f08, 0x3f001613,   // be.ru..._640 sr.hr.sl_432 sw.lv.eu_443 lt.sw..._650
  0x2e1d2707, 0x14662108, 0x45213a02, 0x27292e02,   // id.hr.sq_432 tl.af.is_443 eu.tl.sk_222 sq.ms.id_222
  0x25001e21, 0x12001614, 0x18001f13, 0x0e002511,   // sr.mk..._860 lt.cs..._660 ga.hu..._650 mk.ru..._630
  0x19001023, 0x27291e02, 0x3f292709, 0x3a380f07,   // sv.et..._880 sr.ms.id_222 id.ms.sw_444 es.ca.eu_432
  // [07e0]
  0x14004214, 0x1c002314, 0x04004522, 0x1e004202,   // mt.is..._660 uk.bg..._660 sk.fi..._870 mt.sr..._220
  0x45001207, 0x66001412, 0x06000d23, 0x45002909,   // cs.sk..._420 is.af..._640 pt.de..._880 ms.sk..._440
  0x43001502, 0x04192e13, 0x1d1e0b07, 0x06000314,   // lv.vi..._220 sq.et.fi_665 no.sr.hr_432 nl.de..._660
  0x1a000802, 0x2e000f14, 0x14003802, 0x18003a02,   // it.xxx..._220 es.sq..._660 ca.is..._220 eu.hu..._220
  // [07f0]
  0x0f003807, 0x0c451260, 0x2e000c02, 0x05006609,   // ca.es..._420 cs.sk.pl_664 pl.sq..._220 af.fr..._440
  0x8c000214, 0x27002920, 0x032e0b07, 0x3f151608,   // da.ht..._660 ms.id..._850 no.sq.nl_432 lt.lv.sw_443
  0x06006623, 0x10004002, 0x2e000323, 0x18000113,   // af.de..._880 sl.sv..._220 nl.sq..._880 en.hu..._650
  0x45120107, 0x45001813, 0x01001014, 0x45120109,   // en.cs.sk_432 hu.sk..._650 sv.en..._660 en.cs.sk_444

  // [0800]
  0x22292712, 0x0c001208, 0x45001213, 0x8c000209,   // id.ms.tr_654 cs.pl..._430 cs.sk..._650 da.ht..._440
  0x0c001013, 0x0e002322, 0x3f061a12, 0x42001a09,   // sv.pl..._650 uk.ru..._870 xxx.de.sw_654 xxx.mt..._440
  0x06002209, 0x10002708, 0x10020b13, 0x2e002908,   // tr.de..._440 id.sv..._430 no.da.sv_665 ms.sq..._430
  0x1c000e08, 0x1e0e2360, 0x2e000b21, 0x034066a4,   // ru.bg..._430 uk.ru.sr_664 no.sq..._860 af.sl.nl_433
  // [0810]
  0x02000d02, 0x0000212d, 0x0e2330a4, 0x16002221,   // pt.da..._220 tl......_A00 be.uk.ru_433 tr.lt..._860
  0x16000c02, 0x43211a09, 0x30001e14, 0x0f000823,   // pl.lt..._220 xxx.tl.vi_444 sr.be..._660 it.es..._880
  0x30002512, 0x20000f23, 0x38140faf, 0x45298c02,   // mk.be..._640 es.gl..._880 es.is.ca_655 ht.ms.sk_222
  0x1c002323, 0x0000202d, 0x1c0e2313, 0x27221602,   // uk.bg..._880 gl......_A00 uk.ru.bg_665 lt.tr.id_222
  // [0820]
  0x02001713, 0x1d1e0c02, 0x23003023, 0x1d1e2202,   // ro.da..._650 pl.sr.hr_222 be.uk..._880 tr.sr.hr_222
  0x17000123, 0x401e1d13, 0x0c451208, 0x1c230eaf,   // en.ro..._880 hr.sr.sl_665 cs.sk.pl_443 ru.uk.bg_655
  0x21006602, 0x10002e08, 0x0b000f09, 0x0c002002,   // af.tl..._220 sq.sv..._430 es.no..._440 gl.pl..._220
  0x21003a02, 0x19000407, 0x15004502, 0x15003802,   // eu.tl..._220 fi.et..._420 sk.lv..._220 ca.lv..._220
  // [0830]
  0x29182b02, 0x27292108, 0x45000c13, 0x0c001712,   // cy.hu.ms_222 tl.ms.id_443 pl.sk..._650 ro.pl..._640
  0x8c000c12, 0x17000102, 0x14000402, 0x21000114,   // pl.ht..._640 en.ro..._220 fi.is..._220 en.tl..._660
  0x29000107, 0x1e302302, 0x22002914, 0x21000f13,   // en.ms..._420 uk.be.sr_222 ms.tr..._660 es.tl..._650
  0x1d1e0412, 0x3f272108, 0x4e373309, 0x10001209,   // fi.sr.hr_654 tl.id.sw_443 ur.ar.fa_444 cs.sv..._440
  // [0840]
  0x150416af, 0x0f002022, 0x18000f12, 0x10003a02,   // lt.fi.lv_655 gl.es..._870 es.hu..._640 eu.sv..._220
  0x06100408, 0x0f002023, 0x45004209, 0x03003814,   // fi.sv.de_443 gl.es..._880 mt.sk..._440 ca.nl..._660
  0x0d380860, 0x1c1e2508, 0x14000612, 0x3a000614,   // it.ca.pt_664 mk.sr.bg_443 de.is..._640 de.eu..._660
  0x1a001913, 0x01000514, 0x00002142, 0x062203a4,   // et.xxx..._650 fr.en..._660 tl......_C00 nl.tr.de_433
  // [0850]
  0x04002e13, 0x08000d02, 0x18002b12, 0x12002214,   // sq.fi..._650 pt.it..._220 cy.hu..._640 tr.cs..._660
  0x0d001823, 0x05002709, 0x19000607, 0x01001a14,   // hu.pt..._880 id.fr..._440 de.et..._420 xxx.en..._660
  0x380343a4, 0x12040602, 0x1d000609, 0x43002b02,   // vi.nl.ca_433 de.fi.cs_222 de.hr..._440 cy.vi..._220
  0x40001d13, 0x08000114, 0x06002213, 0x300e2314,   // hr.sl..._650 en.it..._660 tr.de..._650 uk.ru.be_666
  // [0860]
  0x42004502, 0x45001208, 0x02002e12, 0x42000202,   // sk.mt..._220 cs.sk..._430 sq.da..._640 da.mt..._220
  0x1e001014, 0x1c300e60, 0x1a000123, 0x1c251e08,   // sv.sr..._660 ru.be.bg_664 en.xxx..._880 sr.mk.bg_443
  0x1d1e4509, 0x1a004209, 0x42000109, 0x06001522,   // sk.sr.hr_444 mt.xxx..._440 en.mt..._440 lv.de..._870
  0x1e302512, 0x29000602, 0x45004023, 0x16000802,   // mk.be.sr_654 de.ms..._220 sl.sk..._880 it.lt..._220
  // [0870]
  0x8c004209, 0x45000c14, 0x0e231eaf, 0x42001602,   // mt.ht..._440 pl.sk..._660 sr.uk.ru_655 lt.mt..._220
  0x0c001d14, 0x01000209, 0x1e1d1508, 0x04660308,   // hr.pl..._660 da.en..._440 lv.hr.sr_443 nl.af.fi_443
  0x230e3008, 0x37334eaf, 0x42001e02, 0x0c161509,   // be.ru.uk_443 fa.ur.ar_655 sr.mt..._220 lv.lt.pl_444
  0x3a003f09, 0x1d2e1502, 0x4b222909, 0x15424013,   // sw.eu..._440 lv.sq.hr_222 ms.tr.az_444 sl.mt.lv_665
  // [0880]
  0x18004002, 0x3a001902, 0x03001f14, 0x3f000409,   // sl.hu..._220 et.eu..._220 ga.nl..._660 fi.sw..._440
  0x18451212, 0x0f003a02, 0x4b000f09, 0x30001c02,   // cs.sk.hu_654 eu.es..._220 es.az..._440 bg.be..._220
  0x0e003002, 0x40154209, 0x05000d02, 0x1e044012,   // be.ru..._220 mt.lv.sl_444 pt.fr..._220 sl.fi.sr_654
  0x17003809, 0x05002e02, 0x15001608, 0x14004202,   // ca.ro..._440 sq.fr..._220 lt.lv..._430 mt.is..._220
  // [0890]
  0x22004b02, 0x15004214, 0x1e1d3aa4, 0x1c002513,   // az.tr..._220 mt.lv..._660 eu.hr.sr_433 mk.bg..._650
  0x19001009, 0x0d002e12, 0x03663f08, 0x1d292702,   // sv.et..._440 sq.pt..._640 sw.af.nl_443 id.ms.hr_222
  0x0e002522, 0x01001714, 0x272918a4, 0x1f000402,   // mk.ru..._870 ro.en..._660 hu.ms.id_433 fi.ga..._220
  0x27008c13, 0x4e003323, 0x05000414, 0x1e1d40a4,   // ht.id..._650 ur.fa..._880 fi.fr..._660 sl.hr.sr_433
  // [08a0]
  0x06003a23, 0x19002223, 0x0f020b09, 0x22006622,   // eu.de..._880 tr.et..._880 no.da.es_444 af.tr..._870
  0x17001814, 0x03002202, 0x04000802, 0x19002214,   // hu.ro..._660 tr.nl..._220 it.fi..._220 tr.et..._660
  0x19002702, 0x22002714, 0x18124514, 0x14001214,   // id.et..._220 id.tr..._660 sk.cs.hu_666 cs.is..._660
  0x1e0c0302, 0x16001513, 0x01002014, 0x22000402,   // nl.pl.sr_222 lv.lt..._650 gl.en..._660 fi.tr..._220
  // [08b0]
  0x01660312, 0x2e140408, 0x04001923, 0x15002702,   // nl.af.en_654 fi.is.sq_443 et.fi..._880 id.lv..._220
  0x20003823, 0x19004002, 0x4b002e12, 0x0000262d,   // ca.gl..._880 sl.et..._220 sq.az..._640 bn......_A00
  0x2b050109, 0x0d1617a4, 0x0000062d, 0x433f0d08,   // en.fr.cy_444 ro.lt.pt_433 de......_A00 pt.sw.vi_443
  0x02061f12, 0x03000423, 0x1e431d09, 0x22040107,   // ga.de.da_654 fi.nl..._880 hr.vi.sr_444 en.fi.tr_432
  // [08c0]
  0x2e001902, 0x45003f12, 0x3f2940af, 0x0d004322,   // et.sq..._220 sw.sk..._640 sl.ms.sw_655 vi.pt..._870
  0x40002222, 0x1e0c1d02, 0x0d004313, 0x0c161008,   // tr.sl..._870 hr.pl.sr_222 vi.pt..._650 sv.lt.pl_443
  0x0b000208, 0x2b001009, 0x14002902, 0x0f001a02,   // da.no..._430 sv.cy..._440 ms.is..._220 xxx.es..._220
  0x14001f22, 0x07005c09, 0x01001902, 0x291f2109,   // ga.is..._870 yi.iw..._440 et.en..._220 tl.ga.ms_444
  // [08d0]
  0x45000109, 0x3a002108, 0x12450c14, 0x08000f02,   // en.sk..._440 tl.eu..._430 pl.sk.cs_666 es.it..._220
  0x4e003307, 0x15001402, 0x25000e02, 0x02450b08,   // ur.fa..._420 is.lv..._220 ru.mk..._220 no.sk.da_443
  0x66001502, 0x27000302, 0x0d000b09, 0x06000b13,   // lv.af..._220 nl.id..._220 no.pt..._440 no.de..._650
  0x29451207, 0x45120202, 0x1d401ea4, 0x03001e02,   // cs.sk.ms_432 da.cs.sk_222 sr.sl.hr_433 sr.nl..._220
  // [08e0]
  0x0b000209, 0x17000d13, 0x0c124514, 0x27002109,   // da.no..._440 pt.ro..._650 sk.cs.pl_666 tl.id..._440
  0x1d002222, 0x22020b09, 0x14002b09, 0x0c000314,   // tr.hr..._870 no.da.tr_444 cy.is..._440 nl.pl..._660
  0x19000609, 0x01002e09, 0x06000502, 0x0d000809,   // de.et..._440 sq.en..._440 fr.de..._220 it.pt..._440
  0x200d0f07, 0x06000802, 0x14220607, 0x29000123,   // es.pt.gl_432 it.de..._220 de.tr.is_432 en.ms..._880
  // [08f0]
  0x1d004202, 0x02192b08, 0x4b124508, 0x25001c12,   // mt.hr..._220 cy.et.da_443 sk.cs.az_443 bg.mk..._640
  0x45004b09, 0x1f004308, 0x103a0b07, 0x05001502,   // az.sk..._440 vi.ga..._430 no.eu.sv_432 lv.fr..._220
  0x29000b09, 0x42083807, 0x2b2e1412, 0x1d004012,   // no.ms..._440 ca.it.mt_432 is.sq.cy_654 sl.hr..._640
  0x00001c01, 0x30001e23, 0x10001813, 0x3f000302,   // bg......_200 sr.be..._880 hu.sv..._650 nl.sw..._220
  // [0900]
  0x23000e09, 0x0000102d, 0x230e1e13, 0x2b6621af,   // ru.uk..._440 sv......_A00 sr.ru.uk_665 tl.af.cy_655
  0x16002b02, 0x02000109, 0x16002e09, 0x20000d22,   // cy.lt..._220 en.da..._440 sq.lt..._440 pt.gl..._870
  0x01003f09, 0x10002b12, 0x2e004514, 0x1f000d02,   // sw.en..._440 cy.sv..._640 sk.sq..._660 pt.ga..._220
  0x2b200d13, 0x06001209, 0x18140d55, 0x2e001207,   // pt.gl.cy_665 cs.de..._440 pt.is.hu_442 cs.sq..._420
  // [0910]
  0x45004007, 0x12184002, 0x01000802, 0x38001f21,   // sl.sk..._420 sl.hu.cs_222 it.en..._220 ga.ca..._860
  0x16000d09, 0x2b662160, 0x38001202, 0x0d002023,   // pt.lt..._440 tl.af.cy_664 cs.ca..._220 gl.pt..._880
  0x23251c08, 0x38000f02, 0x14001023, 0x30002502,   // bg.mk.uk_443 es.ca..._220 sv.is..._880 mk.be..._220
  0x400d1209, 0x1d001214, 0x1e1d1207, 0x43063808,   // cs.pt.sl_444 cs.hr..._660 cs.hr.sr_432 ca.de.vi_443
  // [0920]
  0x1c002302, 0x40061209, 0x1a002109, 0x45000509,   // uk.bg..._220 cs.de.sl_444 tl.xxx..._440 fr.sk..._440
  0x18003f02, 0x40001e02, 0x1e1d0f02, 0x45001a08,   // sw.hu..._220 sr.sl..._220 es.hr.sr_222 xxx.sk..._430
  0x29451d02, 0x193f0408, 0x15190408, 0x1c1e2513,   // hr.sk.ms_222 fi.sw.et_443 fi.et.lv_443 mk.sr.bg_665
  0x0c000b14, 0x45001409, 0x14001013, 0x1e1d4014,   // no.pl..._660 is.sk..._440 sv.is..._650 sl.hr.sr_666
  // [0930]
  0x0e003009, 0x23001e13, 0x431d1e08, 0x19000408,   // be.ru..._440 sr.uk..._650 sr.hr.vi_443 fi.et..._430
  0x04001912, 0x29006614, 0x1e401d55, 0x17003f14,   // et.fi..._640 af.ms..._660 hr.sl.sr_442 sw.ro..._660
  0x19001702, 0x1d174002, 0x0b000c13, 0x0b001014,   // ro.et..._220 sl.ro.hr_222 pl.no..._650 sv.no..._660
  0x16000c14, 0x40006614, 0x1d001702, 0x45001211,   // pl.lt..._660 af.sl..._660 ro.hr..._220 cs.sk..._630
  // [0940]
  0x40002b14, 0x12450caf, 0x40001714, 0x00000401,   // cy.sl..._660 pl.sk.cs_655 ro.sl..._660 fi......_200
  0x66000b09, 0x0b021013, 0x05001009, 0x22004014,   // no.af..._440 sv.da.no_665 sv.fr..._440 sl.tr..._660
  0x38003a14, 0x3a001f23, 0x1f003a13, 0x30001c09,   // eu.ca..._660 ga.eu..._880 eu.ga..._650 bg.be..._440
  0x17002912, 0x3f000423, 0x1f001714, 0x45003f02,   // ms.ro..._640 fi.sw..._880 ro.ga..._660 sw.sk..._220
  // [0950]
  0x1e1a1d02, 0x01001709, 0x4b660355, 0x14000123,   // hr.xxx.sr_222 ro.en..._440 nl.af.az_442 en.is..._880
  0x251e1c09, 0x012e0b08, 0x66001714, 0x4b000509,   // bg.sr.mk_444 no.sq.en_443 ro.af..._660 fr.az..._440
  0x20000f22, 0x0e002507, 0x66001914, 0x66002114,   // es.gl..._870 mk.ru..._420 et.af..._660 tl.af..._660
  0x66001902, 0x06000308, 0x38000f23, 0x04000809,   // et.af..._220 nl.de..._430 es.ca..._880 it.fi..._440
  // [0960]
  0x1d041802, 0x04001908, 0x17008c08, 0x24001a08,   // hu.fi.hr_222 et.fi..._430 ht.ro..._430 xxx.hi..._430
  0x15001612, 0x454303a4, 0x2b000f14, 0x1d008c14,   // lt.lv..._640 nl.vi.sk_433 es.cy..._660 ht.hr..._660
  0x3a001809, 0x8c003f09, 0x1f003f09, 0x2b003802,   // hu.eu..._440 sw.ht..._440 sw.ga..._440 ca.cy..._220
  0x453f3a02, 0x10001f08, 0x08008c02, 0x1d002709,   // eu.sw.sk_222 ga.sv..._430 ht.it..._220 id.hr..._440
  // [0970]
  0x27000809, 0x29270109, 0x42001414, 0x291d1e08,   // it.id..._440 en.id.ms_444 is.mt..._660 sr.hr.ms_443
  0x42003a23, 0x2b000122, 0x29420408, 0x0d000f23,   // eu.mt..._880 en.cy..._870 fi.mt.ms_443 es.pt..._880
  0x0d001209, 0x14422ba4, 0x19000f08, 0x45154202,   // cs.pt..._440 cy.mt.is_433 es.et..._430 mt.lv.sk_222
  0x0f004002, 0x2b002122, 0x3f008c02, 0x29004214,   // sl.es..._220 tl.cy..._870 ht.sw..._220 mt.ms..._660
  // [0980]
  0x43002b08, 0x10001614, 0x3a003802, 0x05004214,   // cy.vi..._430 lt.sv..._660 ca.eu..._220 mt.fr..._660
  0x22184b12, 0x1c002311, 0x30230ea4, 0x42001202,   // az.hu.tr_654 uk.bg..._630 ru.uk.be_433 cs.mt..._220
  0x2b004212, 0x18001a22, 0x04001209, 0x45001008,   // mt.cy..._640 xxx.hu..._870 cs.fi..._440 sv.sk..._430
  0x25001e22, 0x42002b14, 0x01001002, 0x430f0da4,   // sr.mk..._870 cy.mt..._660 sv.en..._220 pt.es.vi_433
  // [0990]
  0x29451402, 0x02001a09, 0x4b001814, 0x2e001614,   // is.sk.ms_222 xxx.da..._440 hu.az..._660 lt.sq..._660
  0x18004b02, 0x15001602, 0x22002902, 0x04001613,   // az.hu..._220 lt.lv..._220 ms.tr..._220 lt.fi..._650
  0x2e000413, 0x1e001c13, 0x1d2729a4, 0x0c1d1e09,   // fi.sq..._650 bg.sr..._650 ms.id.hr_433 sr.hr.pl_444
  0x8c004308, 0x12451e02, 0x22008c23, 0x06101912,   // vi.ht..._430 sr.sk.cs_222 ht.tr..._880 et.sv.de_654
  // [09a0]
  0x15000c22, 0x15004308, 0x15000c23, 0x04001409,   // pl.lv..._870 vi.lv..._430 pl.lv..._880 is.fi..._440
  0x0c001514, 0x2e006609, 0x450c1502, 0x06001412,   // lv.pl..._660 af.sq..._440 lv.pl.sk_222 is.de..._640
  0x4b001602, 0x15004523, 0x45000c11, 0x16004b14,   // lt.az..._220 sk.lv..._880 pl.sk..._630 az.lt..._660
  0x3a008c02, 0x193f3808, 0x1e251c14, 0x0d000509,   // ht.eu..._220 ca.sw.et_443 bg.mk.sr_666 fr.pt..._440
  // [09b0]
  0x10000609, 0x4b000d09, 0x30001c14, 0x15000209,   // de.sv..._440 pt.az..._440 bg.be..._660 da.lv..._440
  0x14001007, 0x0e233014, 0x0c004513, 0x04061013,   // sv.is..._420 be.uk.ru_666 sk.pl..._650 sv.de.fi_665
  0x29004502, 0x37334e08, 0x03002108, 0x1e1c2509,   // sk.ms..._220 fa.ur.ar_443 tl.nl..._430 mk.bg.sr_444
  0x4e003320, 0x21003f14, 0x66012b07, 0x29223f02,   // ur.fa..._850 sw.tl..._660 cy.en.af_432 sw.tr.ms_222
  // [09c0]
  0x0e302314, 0x45033802, 0x0b181060, 0x8c050107,   // uk.be.ru_666 ca.nl.sk_222 sv.hu.no_664 en.fr.ht_432
  0x3f004014, 0x3f003a23, 0x1d1e1202, 0x8c003f11,   // sl.sw..._660 eu.sw..._880 cs.sr.hr_222 sw.ht..._630
  0x0c001802, 0x02140107, 0x8c004009, 0x06001408,   // hu.pl..._220 en.is.da_432 sl.ht..._440 is.de..._430
  0x0c003f09, 0x27162902, 0x06003a13, 0x27291602,   // sw.pl..._440 ms.lt.id_222 eu.de..._650 lt.ms.id_222
  // [09d0]
  0x42000302, 0x03002610, 0x29272209, 0x8c006620,   // nl.mt..._220 bn.nl..._620 tr.id.ms_444 af.ht..._850
  0x27222902, 0x27290109, 0x66030613, 0x8c002109,   // ms.tr.id_222 en.ms.id_444 de.nl.af_665 tl.ht..._440
  0x1d008c02, 0x0f000123, 0x250e1c08, 0x8c000c13,   // ht.hr..._220 en.es..._880 bg.ru.mk_443 pl.ht..._650
  0x45002914, 0x45000107, 0x250e1c13, 0x1a003f12,   // ms.sk..._660 en.sk..._420 bg.ru.mk_665 sw.xxx..._640
  // [09e0]
  0x8c001a02, 0x1e001809, 0x2b004222, 0x17001514,   // xxx.ht..._220 hu.sr..._440 mt.cy..._870 lv.ro..._660
  0x29002708, 0x8c002214, 0x30002509, 0x1a001914,   // id.ms..._430 tr.ht..._660 mk.be..._440 et.xxx..._660
  0x251c0eaf, 0x10001812, 0x40000802, 0x1f001008,   // ru.bg.mk_655 hu.sv..._640 it.sl..._220 sv.ga..._430
  0x0f141f08, 0x14004513, 0x18451214, 0x27002e12,   // ga.is.es_443 sk.is..._650 cs.sk.hu_666 sq.id..._640
  // [09f0]
  0x04001014, 0x1c002313, 0x8c1a38a4, 0x21002914,   // sv.fi..._660 uk.bg..._650 ca.xxx.ht_433 ms.tl..._660
  0x40001614, 0x293f2702, 0x27291402, 0x38000d14,   // lt.sl..._660 id.sw.ms_222 is.ms.id_222 pt.ca..._660
  0x101d1e08, 0x2b000809, 0x06000814, 0x16003802,   // sr.hr.sv_443 it.cy..._440 it.de..._660 ca.lt..._220
  0x1e1d4502, 0x22001923, 0x040610ad, 0x12001914,   // sk.hr.sr_222 et.tr..._880 sv.de.fi_643 et.cs..._660
  // [0a00]
  0x22040108, 0x450d3812, 0x0f003a12, 0x16081208,   // en.fi.tr_443 ca.pt.sk_654 eu.es..._640 cs.it.lt_443
  0x12002114, 0x08000323, 0x0d003813, 0x17003822,   // tl.cs..._660 nl.it..._880 ca.pt..._650 ca.ro..._870
  0x170d3860, 0x273f1a02, 0x0d003814, 0x10004309,   // ca.pt.ro_664 xxx.sw.id_222 ca.pt..._660 vi.sv..._440
  0x4b124514, 0x22002e22, 0x19001602, 0x1d1e4002,   // sk.cs.az_666 sq.tr..._870 lt.et..._220 sl.sr.hr_222
  // [0a10]
  0x45002e02, 0x151d1e08, 0x0e301c13, 0x3f004514,   // sq.sk..._220 sr.hr.lv_443 bg.be.ru_665 sk.sw..._660
  0x1e1d1202, 0x0d000802, 0x17003802, 0x053f0107,   // cs.hr.sr_222 it.pt..._220 ca.ro..._220 en.sw.fr_432
  0x2b002902, 0x08004214, 0x3f001822, 0x3a421a60,   // ms.cy..._220 mt.it..._660 hu.sw..._870 xxx.mt.eu_664
  0x1e0b1d12, 0x21008c13, 0x1c000e12, 0x21001209,   // hr.no.sr_654 ht.tl..._650 ru.bg..._640 cs.tl..._440
  // [0a20]
  0x66008c09, 0x1f000612, 0x18660308, 0x27296602,   // ht.af..._440 de.ga..._640 nl.af.hu_443 af.ms.id_222
  0x27458c08, 0x21003823, 0x1a001e09, 0x1e002302,   // ht.sk.id_443 ca.tl..._880 sr.xxx..._440 uk.sr..._220
  0x40171455, 0x22001713, 0x19036608, 0x061004af,   // is.ro.sl_442 ro.tr..._650 af.nl.et_443 fi.sv.de_655
  0x38000123, 0x14002b13, 0x03008c02, 0x06001007,   // en.ca..._880 cy.is..._650 ht.nl..._220 sv.de..._420
  // [0a30]
  0x23002523, 0x12450c13, 0x120c4508, 0x1e0e2313,   // mk.uk..._880 pl.sk.cs_665 sk.pl.cs_443 uk.ru.sr_665
  0x10008c09, 0x10000613, 0x06001812, 0x0c001a08,   // ht.sv..._440 de.sv..._650 hu.de..._640 xxx.pl..._430
  0x1e004023, 0x38000508, 0x12000602, 0x22004002,   // sl.sr..._880 fr.ca..._430 de.cs..._220 sl.tr..._220
  0x04001013, 0x16000c09, 0x22001502, 0x22003a13,   // sv.fi..._650 pl.lt..._440 lv.tr..._220 eu.tr..._650
  // [0a40]
  0x38001e02, 0x0c001f07, 0x29001402, 0x22001008,   // sr.ca..._220 ga.pl..._420 is.ms..._220 sv.tr..._430
  0x1a002709, 0x12140d13, 0x10002714, 0x0d001f02,   // id.xxx..._440 pt.is.cs_665 id.sv..._660 ga.pt..._220
  0x06001f23, 0x1f003a02, 0x66141f12, 0x22001709,   // ga.de..._880 eu.ga..._220 ga.is.af_654 ro.tr..._440
  0x0d1f43ad, 0x45011502, 0x1f001421, 0x33003713,   // vi.ga.pt_643 lv.en.sk_222 is.ga..._860 ar.ur..._650
  // [0a50]
  0x12451812, 0x17003a13, 0x0c001611, 0x20003814,   // hu.sk.cs_654 eu.ro..._650 lt.pl..._630 ca.gl..._660
  0x0000170a, 0x0c001608, 0x1f001823, 0x020308a4,   // ro......_500 lt.pl..._430 hu.ga..._880 it.nl.da_433
  0x0d001402, 0x0b001602, 0x66030260, 0x2e000309,   // is.pt..._220 lt.no..._220 da.nl.af_664 nl.sq..._440
  0x15001623, 0x06001013, 0x03001002, 0x8c001a09,   // lt.lv..._880 sv.de..._650 sv.nl..._220 xxx.ht..._440
  // [0a60]
  0x43000109, 0x42002e13, 0x0c001609, 0x1a001809,   // en.vi..._440 sq.mt..._650 lt.pl..._440 hu.xxx..._440
  0x16003f14, 0x3a001a02, 0x0c001622, 0x0c001613,   // sw.lt..._660 xxx.eu..._220 lt.pl..._870 lt.pl..._650
  0x66000102, 0x22003a12, 0x18100214, 0x29000109,   // en.af..._220 eu.tr..._640 da.sv.hu_666 en.ms..._440
  0x0f186608, 0x0c000f14, 0x1e1d3f02, 0x21292709,   // af.hu.es_443 es.pl..._660 sw.hr.sr_222 id.ms.tl_444
  // [0a70]
  0x06000c23, 0x0c002102, 0x15000323, 0x22008c07,   // pl.de..._880 tl.pl..._220 nl.lv..._880 ht.tr..._420
  0x66001002, 0x03001009, 0x16004509, 0x0c006614,   // sv.af..._220 sv.nl..._440 sk.lt..._440 af.pl..._660
  0x30000e13, 0x2b003f12, 0x04002908, 0x8c001613,   // ru.be..._650 sw.cy..._640 ms.fi..._430 lt.ht..._650
  0x30000e08, 0x0c002e22, 0x1d000809, 0x04154560,   // ru.be..._430 sq.pl..._870 it.hr..._440 sk.lv.fi_664
  // [0a80]
  0x0c000622, 0x0c002108, 0x45001402, 0x10000814,   // de.pl..._870 tl.pl..._430 is.sk..._220 it.sv..._660
  0x051029a4, 0x1c000e09, 0x05001702, 0x18001f12,   // ms.sv.fr_433 ru.bg..._440 ro.fr..._220 ga.hu..._640
  0x05000108, 0x00004b01, 0x0000012d, 0x03004302,   // en.fr..._430 az......_200 en......_A00 vi.nl..._220
  0x27004023, 0x0000052d, 0x08001402, 0x29162702,   // sl.id..._880 fr......_A00 is.it..._220 id.lt.ms_222
  // [0a90]
  0x00004e2d, 0x38004323, 0x14000d02, 0x29271912,   // fa......_A00 vi.ca..._880 pt.is..._220 et.id.ms_654
  0x1e1c2560, 0x0d051f07, 0x14001f23, 0x1f430d08,   // mk.bg.sr_664 ga.fr.pt_432 ga.is..._880 pt.vi.ga_443
  0x16150109, 0x12003822, 0x29273fa4, 0x03000612,   // en.lv.lt_444 ca.cs..._870 sw.id.ms_433 de.nl..._640
  0x45081702, 0x1d000202, 0x3f002e13, 0x40001213,   // ro.it.sk_222 da.hr..._220 sq.sw..._650 cs.sl..._650
  // [0aa0]
  0x05002902, 0x220612a4, 0x1e251c12, 0x08002702,   // ms.fr..._220 cs.de.tr_433 bg.mk.sr_654 id.it..._220
  0x10000109, 0x1d002914, 0x06101809, 0x0d080f14,   // en.sv..._440 ms.hr..._660 hu.sv.de_444 es.it.pt_666
  0x1e1d3a02, 0x0c004014, 0x40001223, 0x1e1d4508,   // eu.hr.sr_222 sl.pl..._660 cs.sl..._880 sk.hr.sr_443
  0x1e233060, 0x1f002113, 0x8c1a3f60, 0x45000314,   // be.uk.sr_664 tl.ga..._650 sw.xxx.ht_664 nl.sk..._660
  // [0ab0]
  0x1e231c12, 0x0d002e14, 0x0d002909, 0x2e003a14,   // bg.uk.sr_654 sq.pt..._660 ms.pt..._440 eu.sq..._660
  0x12003802, 0x42001914, 0x25001c08, 0x25001e11,   // ca.cs..._220 et.mt..._660 bg.mk..._430 sr.mk..._630
  0x121d1e08, 0x40003f08, 0x66000109, 0x2b006609,   // sr.hr.cs_443 sw.sl..._430 en.af..._440 af.cy..._440
  0x10001412, 0x04001e14, 0x06002b14, 0x19006609,   // is.sv..._640 sr.fi..._660 cy.de..._660 af.et..._440
  // [0ac0]
  0x3f000414, 0x45000414, 0x04001902, 0x3a001822,   // fi.sw..._660 fi.sk..._660 et.fi..._220 hu.eu..._870
  0x0d000123, 0x2e001613, 0x0f002123, 0x38002e14,   // en.pt..._880 lt.sq..._650 tl.es..._880 sq.ca..._660
  0x4b001702, 0x1a002114, 0x10004214, 0x3a1d0107,   // ro.az..._220 tl.xxx..._660 mt.sv..._660 en.hr.eu_432
  0x19004214, 0x0d003f09, 0x01006602, 0x15001a23,   // mt.et..._660 sw.pt..._440 af.en..._220 xxx.lv..._880
  // [0ad0]
  0x0c004509, 0x14001914, 0x2b1a1f08, 0x160c3a08,   // sk.pl..._440 et.is..._660 ga.xxx.cy_443 eu.pl.lt_443
  0x14003f02, 0x1f000522, 0x03000509, 0x29001413,   // sw.is..._220 fr.ga..._870 fr.nl..._440 is.ms..._650
  0x1e151d02, 0x1e251caf, 0x29001523, 0x0d001709,   // hr.lv.sr_222 bg.mk.sr_655 lv.ms..._880 ro.pt..._440
  0x22002b14, 0x3a001f14, 0x1e1d1502, 0x38001f14,   // cy.tr..._660 ga.eu..._660 lv.hr.sr_222 ga.ca..._660
  // [0ae0]
  0x0e001c13, 0x0c001014, 0x1f000523, 0x40002702,   // bg.ru..._650 sv.pl..._660 fr.ga..._880 id.sl..._220
  0x18000414, 0x21004b02, 0x0d004314, 0x03000c13,   // fi.hu..._660 az.tl..._220 vi.pt..._660 pl.nl..._650
  0x14000502, 0x15002e12, 0x1f000512, 0x1e401d60,   // fr.is..._220 sq.lv..._640 fr.ga..._640 hr.sl.sr_664
  0x0c001612, 0x0e001e13, 0x1d003f13, 0x1c0e2312,   // lt.pl..._640 sr.ru..._650 sw.hr..._650 uk.ru.bg_654
  // [0af0]
  0x0b003814, 0x10006602, 0x2b004209, 0x15004002,   // ca.no..._660 af.sv..._220 mt.cy..._440 sl.lv..._220
  0x1f001509, 0x17000f22, 0x45001f12, 0x0f000114,   // lv.ga..._440 es.ro..._870 ga.sk..._640 en.es..._660
  0x15450c12, 0x18002e13, 0x29271f02, 0x08004209,   // pl.sk.lv_654 sq.hu..._650 ga.id.ms_222 mt.it..._440
  0x02001012, 0x2e000202, 0x1e1d1512, 0x06002b11,   // sv.da..._640 da.sq..._220 lv.hr.sr_654 cy.de..._630
  // [0b00]
  0x0b0c0213, 0x0f0d1faf, 0x030c1209, 0x37003314,   // da.pl.no_665 ga.pt.es_655 cs.pl.nl_444 ur.ar..._660
  0x66002b09, 0x02061009, 0x0f3f1708, 0x04161508,   // cy.af..._440 sv.de.da_444 ro.sw.es_443 lv.lt.fi_443
  0x19162708, 0x100b0207, 0x2e2729a4, 0x18001013,   // id.lt.et_443 da.no.sv_432 ms.id.sq_433 sv.hu..._650
  0x1f000d13, 0x0d0f1f60, 0x1f003f23, 0x1f000d12,   // pt.ga..._650 ga.es.pt_664 sw.ga..._880 pt.ga..._640
  // [0b10]
  0x06036660, 0x251c1e14, 0x21022ba4, 0x301e2512,   // af.nl.de_664 sr.bg.mk_666 cy.da.tl_433 mk.sr.be_654
  0x42001f13, 0x27142902, 0x0b021009, 0x1f008c09,   // ga.mt..._650 ms.is.id_222 sv.da.no_444 ht.ga..._440
  0x401d1ea4, 0x1a000608, 0x21001902, 0x19001a09,   // sr.hr.sl_433 de.xxx..._430 et.tl..._220 xxx.et..._440
  0x1c3025af, 0x2b4b29af, 0x4b002909, 0x3f004b02,   // mk.be.bg_655 ms.az.cy_655 ms.az..._440 az.sw..._220
  // [0b20]
  0x66031908, 0x23300e14, 0x45001414, 0x10000c14,   // et.nl.af_443 ru.be.uk_666 is.sk..._660 pl.sv..._660
  0x17006614, 0x20000109, 0x19000d14, 0x1d0c1902,   // af.ro..._660 en.gl..._440 pt.et..._660 et.pl.hr_222
  0x66003f02, 0x151d1e09, 0x050b0109, 0x42002213,   // sw.af..._220 sr.hr.lv_444 en.no.fr_444 tr.mt..._650
  0x450c1a02, 0x1d184208, 0x15004009, 0x15000f21,   // xxx.pl.sk_222 mt.hu.hr_443 sl.lv..._440 es.lv..._860
  // [0b30]
  0x45001e14, 0x2e041908, 0x0f003809, 0x0d000f09,   // sr.sk..._660 et.fi.sq_443 ca.es..._440 es.pt..._440
  0x03003a08, 0x66002b23, 0x27006602, 0x3f000402,   // eu.nl..._430 cy.af..._880 af.id..._220 fi.sw..._220
  0x02000309, 0x23001c11, 0x06001a08, 0x1d3f1e08,   // nl.da..._440 bg.uk..._630 xxx.de..._430 sr.sw.hr_443
  0x38000f21, 0x01008c02, 0x19000422, 0x38000113,   // es.ca..._860 ht.en..._220 fi.et..._870 en.ca..._650
  // [0b40]
  0x10001a02, 0x12404502, 0x3a001821, 0x03003f09,   // xxx.sv..._220 sk.sl.cs_222 hu.eu..._860 sw.nl..._440
  0x2e3f2708, 0x27146602, 0x1d001208, 0x21451012,   // id.sw.sq_443 af.is.id_222 cs.hr..._430 sv.sk.tl_654
  0x19003f14, 0x23001c12, 0x1d004502, 0x12164509,   // sw.et..._660 bg.uk..._640 sk.hr..._220 sk.lt.cs_444
  0x04000f02, 0x1d001614, 0x0f080d55, 0x1e001a08,   // es.fi..._220 lt.hr..._660 pt.it.es_442 xxx.sr..._430
  // [0b50]
  0x05001709, 0x1f000f08, 0x0e233012, 0x16002909,   // ro.fr..._440 es.ga..._430 be.uk.ru_654 ms.lt..._440
  0x1e1d4509, 0x4b002902, 0x29044202, 0x18002109,   // sk.hr.sr_444 ms.az..._220 mt.fi.ms_222 tl.hu..._440
  0x22294b60, 0x4e003721, 0x18002102, 0x06001022,   // az.ms.tr_664 ar.fa..._860 tl.hu..._220 sv.de..._870
  0x66008c14, 0x23251c11, 0x18004209, 0x300e2309,   // ht.af..._660 bg.mk.uk_653 mt.hu..._440 uk.ru.be_444
  // [0b60]
  0x8c000414, 0x0b001822, 0x1f002214, 0x20080107,   // fi.ht..._660 hu.no..._870 tr.ga..._660 en.it.gl_432
  0x040b8c08, 0x02000107, 0x42001623, 0x1d008c22,   // ht.no.fi_443 en.da..._420 lt.mt..._880 ht.hr..._870
  0x2b000b21, 0x2b001a09, 0x12001008, 0x2b001613,   // no.cy..._860 xxx.cy..._440 sv.cs..._430 lt.cy..._650
  0x33003714, 0x3a000f07, 0x10006623, 0x10000408,   // ar.ur..._660 es.eu..._420 af.sv..._880 fi.sv..._430
  // [0b70]
  0x06002b22, 0x660b1409, 0x06660314, 0x05002b13,   // cy.de..._870 is.no.af_444 nl.af.de_666 cy.fr..._650
  0x45191602, 0x06101960, 0x0d000f13, 0x45000602,   // lt.et.sk_222 et.sv.de_664 es.pt..._650 de.sk..._220
  0x21002b02, 0x22003a09, 0x1e0e3002, 0x0e233008,   // cy.tl..._220 eu.tr..._440 be.ru.sr_222 be.uk.ru_443
  0x06003a08, 0x12001509, 0x1a002708, 0x16000f14,   // eu.de..._430 lv.cs..._440 id.xxx..._430 es.lt..._660
  // [0b80]
  0x3a002714, 0x23001e09, 0x05170c08, 0x19004509,   // id.eu..._660 sr.uk..._440 pl.ro.fr_443 sk.et..._440
  0x040c1912, 0x04100607, 0x1c1e2509, 0x230e3014,   // et.pl.fi_654 de.sv.fi_432 mk.sr.bg_444 be.ru.uk_666
  0x451f1208, 0x0b0419ad, 0x42000614, 0x05004202,   // cs.ga.sk_443 et.fi.no_643 de.mt..._660 mt.fr..._220
  0x028c0b13, 0x66000123, 0x40004522, 0x19100b08,   // no.ht.da_665 en.af..._880 sk.sl..._870 no.sv.et_443
  // [0b90]
  0x04001814, 0x30230e11, 0x1f451a09, 0x08006609,   // hu.fi..._660 ru.uk.be_653 xxx.sk.ga_444 af.it..._440
  0x1d001709, 0x3f011608, 0x19002e13, 0x2e002909,   // ro.hr..._440 lt.en.sw_443 sq.et..._650 ms.sq..._440
  0x3f292707, 0x12011aa4, 0x21002709, 0x43002b09,   // id.ms.sw_432 xxx.en.cs_433 id.tl..._440 cy.vi..._440
  0x3f000608, 0x1e0e2314, 0x0b050107, 0x45004022,   // de.sw..._430 uk.ru.sr_666 en.fr.no_432 sl.sk..._870
  // [0ba0]
  0x04004202, 0x14003a21, 0x04001f14, 0x15003f02,   // mt.fi..._220 eu.is..._860 ga.fi..._660 sw.lv..._220
  0x06000413, 0x16001502, 0x05000214, 0x21001f02,   // fi.de..._650 lv.lt..._220 da.fr..._660 ga.tl..._220
  0x40001a02, 0x120666a4, 0x29000514, 0x20002b23,   // xxx.sl..._220 af.de.cs_433 fr.ms..._660 cy.gl..._880
  0x19000412, 0x08001d14, 0x29180107, 0x4b001209,   // fi.et..._640 hr.it..._660 en.hu.ms_432 cs.az..._440
  // [0bb0]
  0x17001809, 0x2e3a0d08, 0x3f003a02, 0x1d0d1e02,   // hu.ro..._440 pt.eu.sq_443 eu.sw..._220 sr.pt.hr_222
  0x38004209, 0x1d401708, 0x4e003309, 0x1a063a09,   // mt.ca..._440 ro.sl.hr_443 ur.fa..._440 eu.de.xxx_444
  0x1c003009, 0x05002708, 0x1c250e12, 0x1d003a14,   // be.bg..._440 id.fr..._430 ru.mk.bg_654 eu.hr..._660
  0x03000209, 0x23001e23, 0x29002b22, 0x42003f13,   // da.nl..._440 sr.uk..._880 cy.ms..._870 sw.mt..._650
  // [0bc0]
  0x0d001702, 0x2b001602, 0x2b001708, 0x272916a4,   // ro.pt..._220 lt.cy..._220 ro.cy..._430 lt.ms.id_433
  0x00002b2d, 0x2e224b60, 0x06002b23, 0x03000202,   // cy......_A00 az.tr.sq_664 cy.de..._880 da.nl..._220
  0x29001714, 0x21002b23, 0x45000302, 0x03660208,   // ro.ms..._660 cy.tl..._880 nl.sk..._220 da.af.nl_443
  0x2b002e12, 0x29002b13, 0x29001602, 0x161921a4,   // sq.cy..._640 cy.ms..._650 lt.ms..._220 tl.et.lt_433
  // [0bd0]
  0x29002b23, 0x01298c12, 0x1c1e0e07, 0x01001502,   // cy.ms..._880 ht.ms.en_654 ru.sr.bg_432 lv.en..._220
  0x1f000808, 0x19003f02, 0x29004202, 0x0c001614,   // it.ga..._430 sw.et..._220 mt.ms..._220 lt.pl..._660
  0x02002b09, 0x1e401d12, 0x10020baf, 0x38000502,   // cy.da..._440 hr.sl.sr_654 no.da.sv_655 fr.ca..._220
  0x14000b08, 0x2b014209, 0x0c002702, 0x06004213,   // no.is..._430 mt.en.cy_444 id.pl..._220 mt.de..._650
  // [0be0]
  0x0d000522, 0x06001602, 0x29271802, 0x00003f2d,   // fr.pt..._870 lt.de..._220 hu.id.ms_222 sw......_A00
  0x19002109, 0x060403a4, 0x271729a4, 0x021410a4,   // tl.et..._440 nl.fi.de_433 ms.ro.id_433 sv.is.da_433
  0x0d200107, 0x38002909, 0x19000614, 0x29273a02,   // en.gl.pt_432 ms.ca..._440 de.et..._660 eu.id.ms_222
  0x27011a02, 0x06006608, 0x4b002b08, 0x162b6612,   // xxx.en.id_222 af.de..._430 cy.az..._430 af.cy.lt_654
  // [0bf0]
  0x0b272907, 0x1e1d1509, 0x8c000509, 0x19001002,   // ms.id.no_432 lv.hr.sr_444 fr.ht..._440 sv.et..._220
  0x10000414, 0x06001f02, 0x0600100c, 0x0d002202,   // fi.sv..._660 ga.de..._220 sv.de..._530 tr.pt..._220
  0x1e1d4009, 0x22004212, 0x1d4045a4, 0x42001f07,   // sl.hr.sr_444 mt.tr..._640 sk.sl.hr_433 ga.mt..._420
  0x450f2b02, 0x04001f13, 0x10001912, 0x0e231e08,   // cy.es.sk_222 ga.fi..._650 et.sv..._640 sr.uk.ru_443

  // [0c00]
  0x1a000613, 0x0c002e14, 0x0c001e14, 0x01000523,   // de.xxx..._650 sq.pl..._660 sr.pl..._660 fr.en..._880
  0x22003f02, 0x0c451212, 0x40004509, 0x1a002214,   // sw.tr..._220 cs.sk.pl_654 sk.sl..._440 tr.xxx..._660
  0x27004202, 0x1d170c02, 0x1e1d4055, 0x10001823,   // mt.id..._220 pl.ro.hr_222 sl.hr.sr_442 hu.sv..._880
  0x66030612, 0x01004202, 0x3a001702, 0x0c001214,   // de.nl.af_654 mt.en..._220 ro.eu..._220 cs.pl..._660
  // [0c10]
  0x06008c02, 0x12050107, 0x45001723, 0x1f000823,   // ht.de..._220 en.fr.cs_432 ro.sk..._880 it.ga..._880
  0x8c214bad, 0x380f42a4, 0x20000814, 0x06220312,   // az.tl.ht_643 mt.es.ca_433 it.gl..._660 nl.tr.de_654
  0x23003011, 0x251e0e14, 0x15000c21, 0x0f001902,   // be.uk..._630 ru.sr.mk_666 pl.lv..._860 et.es..._220
  0x20001923, 0x121e1d12, 0x401e1d09, 0x38002002,   // et.gl..._880 hr.sr.cs_654 hr.sr.sl_444 gl.ca..._220
  // [0c20]
  0x1e000c14, 0x1e001902, 0x1d660b02, 0x66002108,   // pl.sr..._660 et.sr..._220 no.af.hr_222 tl.af..._430
  0x1c1e25a4, 0x193f1508, 0x45124302, 0x30001e13,   // mk.sr.bg_433 lv.sw.et_443 vi.cs.sk_222 sr.be..._650
  0x0c008c02, 0x1e1d42a4, 0x160c1508, 0x22001a14,   // ht.pl..._220 mt.hr.sr_433 lv.pl.lt_443 xxx.tr..._660
  0x22002702, 0x21008c09, 0x20000f02, 0x3a003809,   // id.tr..._220 ht.tl..._440 es.gl..._220 ca.eu..._440
  // [0c30]
  0x40004502, 0x14000b13, 0x14004213, 0x1d002e02,   // sk.sl..._220 no.is..._650 mt.is..._650 sq.hr..._220
  0x0f002011, 0x3a002709, 0x0c190407, 0x06004b02,   // gl.es..._630 id.eu..._440 fi.et.pl_432 az.de..._220
  0x1f001412, 0x1a001708, 0x19001423, 0x43002102,   // is.ga..._640 ro.xxx..._430 is.et..._880 tl.vi..._220
  0x1f000502, 0x16152909, 0x124542a4, 0x06001a09,   // fr.ga..._220 ms.lv.lt_444 mt.sk.cs_433 xxx.de..._440
  // [0c40]
  0x04011a09, 0x4b1a3a08, 0x08003809, 0x04001009,   // xxx.en.fi_444 eu.xxx.az_443 ca.it..._440 sv.fi..._440
  0x2b141809, 0x25000e21, 0x03000b02, 0x1d1e1602,   // hu.is.cy_444 ru.mk..._860 no.nl..._220 lt.sr.hr_222
  0x29000209, 0x18001014, 0x1a001909, 0x1a001509,   // da.ms..._440 sv.hu..._660 et.xxx..._440 lv.xxx..._440
  0x03000609, 0x10000412, 0x1c003014, 0x22001708,   // de.nl..._440 fi.sv..._640 be.bg..._660 ro.tr..._430
  // [0c50]
  0x30002311, 0x43001709, 0x27101812, 0x06000214,   // uk.be..._630 ro.vi..._440 hu.sv.id_654 da.de..._660
  0x3a002b14, 0x45002e14, 0x45003809, 0x03001812,   // cy.eu..._660 sq.sk..._660 ca.sk..._440 hu.nl..._640
  0x18000c21, 0x0c001813, 0x45001408, 0x66030d12,   // pl.hu..._860 hu.pl..._650 is.sk..._430 pt.nl.af_654
  0x04008c13, 0x12002702, 0x050d8ca4, 0x2e0d0107,   // ht.fi..._650 id.cs..._220 ht.pt.fr_433 en.pt.sq_432
  // [0c60]
  0x8c000522, 0x01000d09, 0x1a004b08, 0x05008c22,   // fr.ht..._870 pt.en..._440 az.xxx..._430 ht.fr..._870
  0x00000b2d, 0x1c230e09, 0x1e004502, 0x05000408,   // no......_A00 ru.uk.bg_444 sk.sr..._220 fi.fr..._430
  0x12000523, 0x8c000523, 0x01001202, 0x10006608,   // fr.cs..._880 fr.ht..._880 cs.en..._220 af.sv..._430
  0x421e1d12, 0x18001907, 0x16004514, 0x1c302508,   // hr.sr.mt_654 et.hu..._420 sk.lt..._660 mk.be.bg_443
  // [0c70]
  0x45002908, 0x08000423, 0x020b1060, 0x02100b08,   // ms.sk..._430 fi.it..._880 sv.no.da_664 no.sv.da_443
  0x0e1c2313, 0x06001902, 0x1d001209, 0x0b0c1909,   // uk.bg.ru_665 et.de..._220 cs.hr..._440 et.pl.no_444
  0x01001909, 0x0d003a02, 0x06000b02, 0x0b100260,   // et.en..._440 eu.pt..._220 no.de..._220 da.sv.no_664
  0x66002e12, 0x01004002, 0x05000413, 0x1f000413,   // sq.af..._640 sl.en..._220 fi.fr..._650 fi.ga..._650
  // [0c80]
  0x03063802, 0x1e1d0502, 0x04003f07, 0x27000509,   // ca.de.nl_222 fr.hr.sr_222 sw.fi..._420 fr.id..._440
  0x151e1daf, 0x0b000623, 0x14150608, 0x22001413,   // hr.sr.lv_655 de.no..._880 de.lv.is_443 is.tr..._650
  0x100b0214, 0x300e23a4, 0x45004009, 0x45041902,   // da.no.sv_666 uk.ru.be_433 sl.sk..._440 et.fi.sk_222
  0x120c45af, 0x42001413, 0x45003f08, 0x0f008c02,   // sk.pl.cs_655 is.mt..._650 sw.sk..._430 ht.es..._220
  // [0c90]
  0x42002b09, 0x16421413, 0x1a000612, 0x8c004313,   // cy.mt..._440 is.mt.lt_665 de.xxx..._640 vi.ht..._650
  0x06000412, 0x02000302, 0x250e1c09, 0x1f003f02,   // fi.de..._640 nl.da..._220 bg.ru.mk_444 sw.ga..._220
  0x40002214, 0x17001a02, 0x0d001f22, 0x1d001f14,   // tr.sl..._660 xxx.ro..._220 ga.pt..._870 ga.hr..._660
  0x14002b07, 0x3f000b02, 0x184003af, 0x5c000718,   // cy.is..._420 no.sw..._220 nl.sl.hu_655 iw.yi..._740
  // [0ca0]
  0x2b001512, 0x1d224509, 0x2e004213, 0x14181009,   // lv.cy..._640 sk.tr.hr_444 mt.sq..._650 sv.hu.is_444
  0x01002b09, 0x03002e13, 0x300e1eaf, 0x38000d23,   // cy.en..._440 sq.nl..._650 sr.ru.be_655 pt.ca..._880
  0x38050f07, 0x43002909, 0x42001002, 0x0e3023af,   // es.fr.ca_432 ms.vi..._440 sv.mt..._220 uk.be.ru_655
  0x66060308, 0x0e1e2512, 0x8c004b14, 0x66000223,   // nl.de.af_443 mk.sr.ru_654 az.ht..._660 da.af..._880
  // [0cb0]
  0x40000314, 0x1d100202, 0x02100b09, 0x0e001e08,   // nl.sl..._660 da.sv.hr_222 no.sv.da_444 sr.ru..._430
  0x12002b02, 0x43002e14, 0x3f001709, 0x00002301,   // cy.cs..._220 sq.vi..._660 ro.sw..._440 uk......_200
  0x42002e09, 0x661a03a4, 0x06000409, 0x06010208,   // sq.mt..._440 nl.xxx.af_433 fi.de..._440 da.en.de_443
  0x1c002312, 0x06022907, 0x27218c14, 0x020b1814,   // uk.bg..._640 ms.da.de_432 ht.tl.id_666 hu.no.da_666
  // [0cc0]
  0x0b000302, 0x03001802, 0x0d0f0802, 0x10001608,   // nl.no..._220 hu.nl..._220 it.es.pt_222 lt.sv..._430
  0x1e001713, 0x102b0208, 0x01002b22, 0x04001713,   // ro.sr..._650 da.cy.sv_443 cy.en..._870 ro.fi..._650
  0x42000808, 0x04001714, 0x22001813, 0x14100608,   // it.mt..._430 ro.fi..._660 hu.tr..._650 de.sv.is_443
  0x10020ba4, 0x66002e08, 0x40004523, 0x3f001708,   // no.da.sv_433 sq.af..._430 sk.sl..._880 ro.sw..._430
  // [0cd0]
  0x3f180107, 0x1a003f14, 0x45061208, 0x0d004509,   // en.hu.sw_432 sw.xxx..._660 cs.de.sk_443 sk.pt..._440
  0x0f001002, 0x12164502, 0x12454012, 0x22003f13,   // sv.es..._220 sk.lt.cs_222 sl.sk.cs_654 sw.tr..._650
  0x3a002213, 0x33004e20, 0x1e0d1d02, 0x43001e14,   // tr.eu..._650 fa.ur..._850 hr.pt.sr_222 sr.vi..._660
  0x0d0f08a4, 0x0d0f0808, 0x19001d14, 0x0d0f0809,   // it.es.pt_433 it.es.pt_443 hr.et..._660 it.es.pt_444
  // [0ce0]
  0x1d1e1702, 0x1c300ea4, 0x120c4514, 0x2e001002,   // ro.sr.hr_222 ru.be.bg_433 sk.pl.cs_666 sv.sq..._220
  0x401e1d60, 0x29001712, 0x0f011712, 0x14001f20,   // hr.sr.sl_664 ro.ms..._640 ro.en.es_654 ga.is..._850
  0x06141013, 0x12000412, 0x06001709, 0x1c1e25af,   // sv.is.de_665 fi.cs..._640 ro.de..._440 mk.sr.bg_655
  0x08002902, 0x38002b02, 0x1e000e13, 0x380b1412,   // ms.it..._220 cy.ca..._220 ru.sr..._650 is.no.ca_654
  // [0cf0]
  0x196603a4, 0x15140b12, 0x30002321, 0x181a2108,   // nl.af.et_433 no.is.lv_654 uk.be..._860 tl.xxx.hu_443
  0x19000d07, 0x02001008, 0x1a080109, 0x19001a14,   // pt.et..._420 sv.da..._430 en.it.xxx_444 xxx.et..._660
  0x190d0b07, 0x03660b12, 0x04000607, 0x401d3f09,   // no.pt.et_432 no.af.nl_654 de.fi..._420 sw.hr.sl_444
  0x04001922, 0x19000b09, 0x03001a02, 0x1e000802,   // et.fi..._870 no.et..._440 xxx.nl..._220 it.sr..._220
  // [0d00]
  0x1d002e14, 0x1e1d2707, 0x163f4512, 0x1c0e2514,   // sq.hr..._660 id.hr.sr_432 sk.sw.lt_654 mk.ru.bg_666
  0x19100107, 0x06001521, 0x4b001809, 0x1d041908,   // en.sv.et_432 lv.de..._860 hu.az..._440 et.fi.hr_443
  0x66001413, 0x1f004312, 0x45004002, 0x4e3733af,   // is.af..._650 vi.ga..._640 sl.sk..._220 ur.ar.fa_655
  0x101d4208, 0x0c000602, 0x04002913, 0x1d1e2702,   // mt.hr.sv_443 de.pl..._220 ms.fi..._650 id.sr.hr_222
  // [0d10]
  0x1d450308, 0x1c0e2512, 0x1f001a08, 0x3f001f08,   // nl.sk.hr_443 mk.ru.bg_654 xxx.ga..._430 ga.sw..._430
  0x2e1842af, 0x23001c09, 0x8c003f12, 0x04003a08,   // mt.hu.sq_655 bg.uk..._440 sw.ht..._640 eu.fi..._430
  0x66000608, 0x03151208, 0x42006602, 0x1e001d20,   // de.af..._430 cs.lv.nl_443 af.mt..._220 hr.sr..._850
  0x66030b55, 0x16180c12, 0x2b0119a4, 0x45290d02,   // no.nl.af_442 pl.hu.lt_654 et.en.cy_433 pt.ms.sk_222
  // [0d20]
  0x10190460, 0x1e031d02, 0x18000202, 0x06001912,   // fi.et.sv_664 hr.nl.sr_222 da.hu..._220 et.de..._640
  0x06001908, 0x04002702, 0x0d380f14, 0x1a4b2207,   // et.de..._430 id.fi..._220 es.ca.pt_666 tr.az.xxx_432
  0x00001f01, 0x1f000102, 0x04008c02, 0x0b100208,   // ga......_200 en.ga..._220 ht.fi..._220 da.sv.no_443
  0x66000f23, 0x19004009, 0x12001702, 0x1f000108,   // es.af..._880 sl.et..._440 ro.cs..._220 en.ga..._430
  // [0d30]
  0x2b000408, 0x0c006602, 0x02001013, 0x1a001002,   // fi.cy..._430 af.pl..._220 sv.da..._650 sv.xxx..._220
  0x10183f07, 0x43000514, 0x10003f14, 0x10002114,   // sw.hu.sv_432 fr.vi..._660 sw.sv..._660 tl.sv..._660
  0x1a002121, 0x21004309, 0x334e3713, 0x1a002714,   // tl.xxx..._860 vi.tl..._440 ar.fa.ur_665 id.xxx..._660
  0x04190b07, 0x19000d02, 0x0b001414, 0x0d001a08,   // no.et.fi_432 pt.et..._220 is.no..._660 xxx.pt..._430
  // [0d40]
  0x10000523, 0x1a016608, 0x0d003823, 0x1d043f02,   // fr.sv..._880 af.en.xxx_443 ca.pt..._880 sw.fi.hr_222
  0x3a000202, 0x16081a11, 0x08001a02, 0x22001013,   // da.eu..._220 xxx.it.lt_653 xxx.it..._220 sv.tr..._650
  0x0f003a09, 0x19003a14, 0x04192112, 0x0b002723,   // eu.es..._440 eu.et..._660 tl.et.fi_654 id.no..._880
  0x18006612, 0x1a000309, 0x180d0f08, 0x45143a02,   // af.hu..._640 nl.xxx..._440 es.pt.hu_443 eu.is.sk_222
  // [0d50]
  0x401d1607, 0x1c0e2508, 0x0d002714, 0x3f003a08,   // lt.hr.sl_432 mk.ru.bg_443 id.pt..._660 eu.sw..._430
  0x1c250e14, 0x2e403a11, 0x27212907, 0x080d3a08,   // ru.mk.bg_666 eu.sl.sq_653 ms.tl.id_432 eu.pt.it_443
  0x21003a14, 0x1a002902, 0x1d1e4212, 0x22008c22,   // eu.tl..._660 ms.xxx..._220 mt.sr.hr_654 ht.tr..._870
  0x1f291708, 0x1d004214, 0x1c251e07, 0x22218c60,   // ro.ms.ga_443 mt.hr..._660 sr.mk.bg_432 ht.tl.tr_664
  // [0d60]
  0x08002023, 0x1d002e09, 0x0f003808, 0x14000d14,   // gl.it..._880 sq.hr..._440 ca.es..._430 pt.is..._660
  0x1f3814a4, 0x3f000602, 0x140f3802, 0x1f0f3809,   // is.ca.ga_433 de.sw..._220 ca.es.is_222 ca.es.ga_444
  0x25002314, 0x0d002e02, 0x1f001813, 0x1e1d4202,   // uk.mk..._660 sq.pt..._220 hu.ga..._650 mt.hr.sr_222
  0x12178c08, 0x0f381407, 0x12450502, 0x03000402,   // ht.ro.cs_443 is.ca.es_432 fr.sk.cs_222 fi.nl..._220
  // [0d70]
  0x172e1012, 0x140f3809, 0x06003823, 0x0e251c55,   // sv.sq.ro_654 ca.es.is_444 ca.de..._880 bg.mk.ru_442
  0x1e1d8c09, 0x33003711, 0x14181fad, 0x1f12456f,   // ht.hr.sr_444 ar.ur..._630 ga.hu.is_643 sk.cs.ga_886
  0x06004502, 0x45003814, 0x18451213, 0x0f000d08,   // sk.de..._220 ca.sk..._660 cs.sk.hu_665 pt.es..._430
  0x380805a4, 0x42001d02, 0x29002721, 0x18124513,   // fr.it.ca_433 hr.mt..._220 id.ms..._860 sk.cs.hu_665
  // [0d80]
  0x27290d09, 0x12184513, 0x4b004209, 0x18124511,   // pt.ms.id_444 sk.hu.cs_665 mt.az..._440 sk.cs.hu_653
  0x45160402, 0x22000609, 0x18124560, 0x0d000814,   // fi.lt.sk_222 de.tr..._440 sk.cs.hu_664 it.pt..._660
  0x18001913, 0x3a003823, 0x17003823, 0x38400509,   // et.hu..._650 ca.eu..._880 ca.ro..._880 fr.sl.ca_444
  0x02002914, 0x45001818, 0x450d0f02, 0x16000409,   // ms.da..._660 hu.sk..._740 es.pt.sk_222 fi.lt..._440
  // [0d90]
  0x15001614, 0x031805a4, 0x27293f02, 0x380d0f55,   // lt.lv..._660 fr.hu.nl_433 sw.ms.id_222 es.pt.ca_442
  0x0f001609, 0x0d001802, 0x04001602, 0x2b004514,   // lt.es..._440 hu.pt..._220 lt.fi..._220 sk.cy..._660
  0x0d0f1609, 0x230e1c13, 0x45000614, 0x12001e02,   // lt.es.pt_444 bg.ru.uk_665 de.sk..._660 sr.cs..._220
  0x19002113, 0x103f1909, 0x3f1516af, 0x17001802,   // tl.et..._650 et.sw.sv_444 lt.lv.sw_655 hu.ro..._220
  // [0da0]
  0x16000d23, 0x19001d02, 0x1f006614, 0x16003a13,   // pt.lt..._880 hr.et..._220 af.ga..._660 eu.lt..._650
  0x4b003f02, 0x10060508, 0x0b000602, 0x0d1910a4,   // sw.az..._220 fr.de.sv_443 de.no..._220 sv.et.pt_433
  0x40030c11, 0x8c001009, 0x08001902, 0x3a000609,   // pl.nl.sl_653 sv.ht..._440 et.it..._220 de.eu..._440
  0x10001913, 0x1e002214, 0x05001414, 0x18001414,   // et.sv..._650 tr.sr..._660 is.fr..._660 is.hu..._660
  // [0db0]
  0x0c036607, 0x06031faf, 0x251e3013, 0x0d660313,   // af.nl.pl_432 ga.nl.de_655 be.sr.mk_665 nl.af.pt_665
  0x2e292713, 0x06000322, 0x08050108, 0x1e004009,   // id.ms.sq_665 nl.de..._870 en.fr.it_443 sl.sr..._440
  0x02002707, 0x45121d02, 0x02001414, 0x2b001802,   // id.da..._420 hr.cs.sk_222 is.da..._660 hu.cy..._220
  0x2b660312, 0x1e004013, 0x29210402, 0x0c001009,   // nl.af.cy_654 sl.sr..._650 fi.tl.ms_222 sv.pl..._440
  // [0dc0]
  0x0d001613, 0x12452e02, 0x05453a08, 0x451d16ac,   // lt.pt..._650 sq.sk.cs_222 eu.sk.fr_443 lt.hr.sk_632
  0x18058c08, 0x02001514, 0x45001614, 0x04002114,   // ht.fr.hu_443 lv.da..._660 lt.sk..._660 tl.fi..._660
  0x041605a4, 0x08000402, 0x45171d02, 0x0f000102,   // fr.lt.fi_433 fi.it..._220 hr.ro.sk_222 en.es..._220
  0x66000614, 0x03000414, 0x05006608, 0x18660208,   // de.af..._660 fi.nl..._660 af.fr..._430 da.af.hu_443
  // [0dd0]
  0x40000309, 0x03000f02, 0x29002208, 0x081f0208,   // nl.sl..._440 es.nl..._220 tr.ms..._430 da.ga.it_443
  0x14003f07, 0x17003813, 0x18003a13, 0x04000302,   // sw.is..._420 ca.ro..._650 eu.hu..._650 nl.fi..._220
  0x66040313, 0x05000409, 0x03002709, 0x38000d08,   // nl.fi.af_665 fi.fr..._440 id.nl..._440 pt.ca..._430
  0x19001f14, 0x4b000d02, 0x66000402, 0x18001f21,   // ga.et..._660 pt.az..._220 fi.af..._220 ga.hu..._860
  // [0de0]
  0x1d1e4014, 0x06001702, 0x42003a09, 0x3a001712,   // sl.sr.hr_666 ro.de..._220 eu.mt..._440 ro.eu..._640
  0x04224b07, 0x40001e09, 0x2b001702, 0x66002b02,   // az.tr.fi_432 sr.sl..._440 ro.cy..._220 cy.af..._220
  0x0b002e14, 0x290d4507, 0x12454302, 0x19004502,   // sq.no..._660 sk.pt.ms_432 vi.sk.cs_222 sk.et..._220
  0x16001514, 0x43003a14, 0x27038ca4, 0x0d001409,   // lv.lt..._660 eu.vi..._660 ht.nl.id_433 is.pt..._440
  // [0df0]
  0x00000c2d, 0x12456602, 0x27223f02, 0x380f0d60,   // pl......_A00 af.sk.cs_222 sw.tr.id_222 pt.es.ca_664
  0x27292b02, 0x380f0d09, 0x27000d02, 0x221d1e13,   // cy.ms.id_222 pt.es.ca_444 pt.id..._220 sr.hr.tr_665
  0x380d0f13, 0x0f000d23, 0x050f0d08, 0x21000f09,   // es.pt.ca_665 pt.es..._880 pt.es.fr_443 es.tl..._440
  0x3f001a09, 0x04421960, 0x04661909, 0x27180302,   // xxx.sw..._440 et.mt.fi_664 et.af.fi_444 nl.hu.id_222
  // [0e00]
  0x401d1e08, 0x02003a14, 0x08050107, 0x18000d08,   // sr.hr.sl_443 eu.da..._660 en.fr.it_432 pt.hu..._430
  0x0d004502, 0x0e302512, 0x3f002e09, 0x16001509,   // sk.pt..._220 mk.be.ru_654 sq.sw..._440 lv.lt..._440
  0x0f004302, 0x23000e22, 0x01002e02, 0x3f003809,   // vi.es..._220 ru.uk..._870 sq.en..._220 ca.sw..._440
  0x3a001813, 0x1d004008, 0x0d002209, 0x1d1e40af,   // hu.eu..._650 sl.hr..._430 tr.pt..._440 sl.sr.hr_655
  // [0e10]
  0x29003f21, 0x15000809, 0x060127a4, 0x21451612,   // sw.ms..._860 it.lv..._440 id.en.de_433 lt.sk.tl_654
  0x45002b13, 0x0c003f13, 0x8c000513, 0x0c001823,   // cy.sk..._650 sw.pl..._650 fr.ht..._650 hu.pl..._880
  0x04191609, 0x21003f21, 0x21003f13, 0x0e1c2312,   // lt.et.fi_444 sw.tl..._860 sw.tl..._650 uk.bg.ru_654
  0x1e1d0802, 0x08000f14, 0x1a004214, 0x2b291612,   // it.hr.sr_222 es.it..._660 mt.xxx..._660 lt.ms.cy_654
  // [0e20]
  0x16002109, 0x38002113, 0x0c001f02, 0x42000402,   // tl.lt..._440 tl.ca..._650 ga.pl..._220 fi.mt..._220
  0x18000309, 0x12001d02, 0x12001e14, 0x45003808,   // nl.hu..._440 hr.cs..._220 sr.cs..._660 ca.sk..._430
  0x8c000507, 0x182b2e12, 0x21061812, 0x19001012,   // fr.ht..._420 sq.cy.hu_654 hu.de.tl_654 sv.et..._640
  0x04002213, 0x04000109, 0x0b3a0107, 0x2e002702,   // tr.fi..._650 en.fi..._440 en.eu.no_432 id.sq..._220
  // [0e30]
  0x0d002109, 0x3a003f08, 0x0f000809, 0x04003a14,   // tl.pt..._440 sw.eu..._430 it.es..._440 eu.fi..._660
  0x14001209, 0x14451812, 0x15001611, 0x03008c14,   // cs.is..._440 hu.sk.is_654 lt.lv..._630 ht.nl..._660
  0x04000b02, 0x12058c02, 0x04003a12, 0x1e401d09,   // no.fi..._220 ht.fr.cs_222 eu.fi..._640 hr.sl.sr_444
  0x124540af, 0x40001d08, 0x0d000107, 0x16001512,   // sl.sk.cs_655 hr.sl..._430 en.pt..._420 lv.lt..._640
  // [0e40]
  0x01000b14, 0x8c054055, 0x00000601, 0x06004013,   // no.en..._660 sl.fr.ht_442 de......_200 sl.de..._650
  0x2b001621, 0x121e1d60, 0x05003a02, 0x06041914,   // lt.cy..._860 hr.sr.cs_664 eu.fr..._220 et.fi.de_666
  0x14002714, 0x3a001814, 0x1f450107, 0x05003f14,   // id.is..._660 hu.eu..._660 en.sk.ga_432 sw.fr..._660
  0x101918af, 0x19000613, 0x19008c02, 0x4b000d12,   // hu.et.sv_655 de.et..._650 ht.et..._220 pt.az..._640
  // [0e50]
  0x1d002108, 0x22004214, 0x1d2e4260, 0x06000423,   // tl.hr..._430 mt.tr..._660 mt.sq.hr_664 fi.de..._880
  0x1d004007, 0x423a08af, 0x250e3011, 0x3a001709,   // sl.hr..._420 it.eu.mt_655 be.ru.mk_653 ro.eu..._440
  0x18000b07, 0x05002202, 0x66040309, 0x19660312,   // no.hu..._420 tr.fr..._220 nl.fi.af_444 nl.af.et_654
  0x1e452e02, 0x8c000809, 0x22000509, 0x17000114,   // sq.sk.sr_222 it.ht..._440 fr.tr..._440 en.ro..._660
  // [0e60]
  0x3a000123, 0x27001802, 0x27292107, 0x050601a4,   // en.eu..._880 hu.id..._220 tl.ms.id_432 en.de.fr_433
  0x3f3a1708, 0x0f003a08, 0x03001709, 0x0b000414,   // ro.eu.sw_443 eu.es..._430 ro.nl..._440 fi.no..._660
  0x0c000814, 0x18000109, 0x8c002114, 0x05184513,   // it.pl..._660 en.hu..._440 tl.ht..._660 sk.hu.fr_665
  0x450d0b07, 0x05008c02, 0x17080107, 0x0c004511,   // no.pt.sk_432 ht.fr..._220 en.it.ro_432 sk.pl..._630
  // [0e70]
  0x38171a08, 0x4b002913, 0x0d160fa4, 0x18001723,   // xxx.ro.ca_443 ms.az..._650 es.lt.pt_433 ro.hu..._880
  0x0c003f14, 0x1c001e13, 0x0f001823, 0x1e008c02,   // sw.pl..._660 sr.bg..._650 hu.es..._880 ht.sr..._220
  0x66030212, 0x3f0215af, 0x451d42a4, 0x40003f09,   // da.nl.af_654 lv.da.sw_655 mt.hr.sk_433 sw.sl..._440
  0x14000f13, 0x2e001723, 0x66030509, 0x21000f02,   // es.is..._650 ro.sq..._880 fr.nl.af_444 es.tl..._220
  // [0e80]
  0x12404509, 0x1e000109, 0x0e001e12, 0x451d1209,   // sk.sl.cs_444 en.sr..._440 sr.ru..._640 cs.hr.sk_444
  0x050d0109, 0x23001c13, 0x148c0b09, 0x15002b22,   // en.pt.fr_444 bg.uk..._650 no.ht.is_444 cy.lv..._870
  0x1e1d0402, 0x1d0806a4, 0x1c0e1e09, 0x45273f02,   // fi.hr.sr_222 de.it.hr_433 sr.ru.bg_444 sw.id.sk_222
  0x22001e09, 0x08000523, 0x1a000314, 0x02001814,   // sr.tr..._440 fr.it..._880 nl.xxx..._660 hu.da..._660
  // [0e90]
  0x18002e09, 0x05081a14, 0x3f001a12, 0x06001f14,   // sq.hu..._440 xxx.it.fr_666 xxx.sw..._640 ga.de..._660
  0x03001a14, 0x03002114, 0x66003814, 0x01003a14,   // xxx.nl..._660 tl.nl..._660 ca.af..._660 eu.en..._660
  0x38001702, 0x18004b14, 0x4b004309, 0x1a004509,   // ro.ca..._220 az.hu..._660 vi.az..._440 sk.xxx..._440
  0x03001a09, 0x14000509, 0x01008c09, 0x66000609,   // xxx.nl..._440 fr.is..._440 ht.en..._440 de.af..._440
  // [0ea0]
  0x14060b55, 0x3a000f12, 0x0e1c1e60, 0x1d151e08,   // no.de.is_442 es.eu..._640 sr.bg.ru_664 sr.lv.hr_443
  0x06002902, 0x05001f12, 0x1a003f02, 0x220c4b09,   // ms.de..._220 ga.fr..._640 sw.xxx..._220 az.pl.tr_444
  0x3a1f0f60, 0x2e004209, 0x06001914, 0x0c452ea4,   // es.ga.eu_664 mt.sq..._440 et.de..._660 sq.sk.pl_433
  0x04003f02, 0x193f0412, 0x1d004513, 0x1c1e2555,   // sw.fi..._220 fi.sw.et_654 sk.hr..._650 mk.sr.bg_442
  // [0eb0]
  0x21003f09, 0x30000e21, 0x0f0d1f14, 0x0f001f08,   // sw.tl..._440 ru.be..._860 ga.pt.es_666 ga.es..._430
  0x05002014, 0x08004014, 0x18000b02, 0x19401d08,   // gl.fr..._660 sl.it..._660 no.hu..._220 hr.sl.et_443
  0x2e001912, 0x1e000808, 0x1f000809, 0x060b02a4,   // et.sq..._640 it.sr..._430 it.ga..._440 da.no.de_433
  0x16001523, 0x15006602, 0x451d1e09, 0x01451a09,   // lv.lt..._880 af.lv..._220 sr.hr.sk_444 xxx.sk.en_444
  // [0ec0]
  0x45000808, 0x27003802, 0x40001909, 0x1d2e1e07,   // it.sk..._430 ca.id..._220 et.sl..._440 sr.sq.hr_432
  0x451e1d08, 0x16061507, 0x04001802, 0x1d1e2e11,   // hr.sr.sk_443 lv.de.lt_432 hu.fi..._220 sq.sr.hr_653
  0x3a003814, 0x18002923, 0x011a18a4, 0x04001614,   // ca.eu..._660 ms.hu..._880 hu.xxx.en_433 lt.fi..._660
  0x401e1d08, 0x301c0e12, 0x2b001712, 0x16004002,   // hr.sr.sl_443 ru.bg.be_654 ro.cy..._640 sl.lt..._220
  // [0ed0]
  0x06001608, 0x04002914, 0x04050107, 0x2b181fa4,   // lt.de..._430 ms.fi..._660 en.fr.fi_432 ga.hu.cy_433
  0x14061508, 0x2e001e02, 0x38003a02, 0x3f008c13,   // lv.de.is_443 sr.sq..._220 eu.ca..._220 ht.sw..._650
  0x1e401d13, 0x401d1e02, 0x0c001621, 0x14001902,   // hr.sl.sr_665 sr.hr.sl_222 lt.pl..._860 et.is..._220
  0x01001e09, 0x29000114, 0x00002e01, 0x02004023,   // sr.en..._440 en.ms..._660 sq......_200 sl.da..._880
  // [0ee0]
  0x23003021, 0x29008c09, 0x30001c11, 0x19036613,   // be.uk..._860 ht.ms..._440 bg.be..._630 af.nl.et_665
  0x22000f02, 0x18000502, 0x02002b02, 0x1d041402,   // es.tr..._220 fr.hu..._220 cy.da..._220 is.fi.hr_222
  0x22003f12, 0x06051409, 0x1e1d0202, 0x2b000c12,   // sw.tr..._640 is.fr.de_444 da.hr.sr_222 pl.cy..._640
  0x230e3013, 0x38001721, 0x0b3a42af, 0x45150c02,   // be.ru.uk_665 ro.ca..._860 mt.eu.no_655 pl.lv.sk_222
  // [0ef0]
  0x38003a22, 0x18000814, 0x18000c13, 0x0d0f1008,   // eu.ca..._870 it.hu..._660 pl.hu..._650 sv.es.pt_443
  0x010d17a4, 0x45123802, 0x18000c22, 0x16000402,   // ro.pt.en_433 ca.cs.sk_222 pl.hu..._870 fi.lt..._220
  0x14002e13, 0x27001a08, 0x1f080109, 0x060d6609,   // sq.is..._650 xxx.id..._430 en.it.ga_444 af.pt.de_444
  0x2e000414, 0x06002e09, 0x38000f09, 0x66002902,   // fi.sq..._660 sq.de..._440 es.ca..._440 ms.af..._220
  // [0f00]
  0x1a004b09, 0x122b4508, 0x45004309, 0x0f000209,   // az.xxx..._440 sk.cy.cs_443 vi.sk..._440 da.es..._440
  0x45001714, 0x0d000309, 0x0f003a14, 0x0d000502,   // ro.sk..._660 nl.pt..._440 eu.es..._660 fr.pt..._220
  0x0d000f07, 0x0e001e22, 0x14000307, 0x03662708,   // es.pt..._420 sr.ru..._870 nl.is..._420 id.af.nl_443
  0x04190309, 0x3a001602, 0x3f001813, 0x22001202,   // nl.et.fi_444 lt.eu..._220 hu.sw..._650 cs.tr..._220
  // [0f10]
  0x01000609, 0x14001802, 0x03000109, 0x1e230e02,   // de.en..._440 hu.is..._220 en.nl..._440 ru.uk.sr_222
  0x18124509, 0x160f2013, 0x16002023, 0x0d080109,   // sk.cs.hu_444 gl.es.lt_665 gl.lt..._880 en.it.pt_444
  0x0f001402, 0x200d0f08, 0x18223a13, 0x4b2e8ca4,   // is.es..._220 es.pt.gl_443 eu.tr.hu_665 ht.sq.az_433
  0x15041908, 0x43004202, 0x14451213, 0x211002a4,   // et.fi.lv_443 mt.vi..._220 cs.sk.is_665 da.sv.tl_433
  // [0f20]
  0x21000b02, 0x3a001523, 0x06004009, 0x17001f13,   // no.tl..._220 lv.eu..._880 sl.de..._440 ga.ro..._650
  0x16383a08, 0x0b001614, 0x14000f14, 0x3a001522,   // eu.ca.lt_443 lt.no..._660 es.is..._660 lv.eu..._870
  0x14200f12, 0x0d430f08, 0x20000f14, 0x030466a4,   // es.gl.is_654 es.vi.pt_443 es.gl..._660 af.fi.nl_433
  0x0d002902, 0x8c002714, 0x2e004208, 0x3a002102,   // ms.pt..._220 id.ht..._660 mt.sq..._430 tl.eu..._220
  // [0f30]
  0x06003a09, 0x22004223, 0x42003a02, 0x06000823,   // eu.de..._440 mt.tr..._880 eu.mt..._220 it.de..._880
  0x30001e20, 0x661e1da4, 0x05001a09, 0x18002913,   // sr.be..._850 hr.sr.af_433 xxx.fr..._440 ms.hu..._650
  0x04001622, 0x19001823, 0x1e401d14, 0x14000f09,   // lt.fi..._870 hu.et..._880 hr.sl.sr_666 es.is..._440
  0x0000042d, 0x45030107, 0x2e003f09, 0x10002e09,   // fi......_A00 en.nl.sk_432 sw.sq..._440 sq.sv..._440
  // [0f40]
  0x25000e23, 0x06041608, 0x27001602, 0x38172b07,   // ru.mk..._880 lt.fi.de_443 lt.id..._220 cy.ro.ca_432
  0x03000123, 0x04003a09, 0x03004002, 0x230e1e60,   // en.nl..._880 eu.fi..._440 sl.nl..._220 sr.ru.uk_664
  0x15000602, 0x18001212, 0x10003802, 0x14000213,   // de.lv..._220 cs.hu..._640 ca.sv..._220 da.is..._650
  0x18002708, 0x182729a4, 0x230e3009, 0x3a000602,   // id.hu..._430 ms.id.hu_433 be.ru.uk_444 de.eu..._220
  // [0f50]
  0x0b000c09, 0x10003809, 0x291a3f02, 0x3a001214,   // pl.no..._440 ca.sv..._440 sw.xxx.ms_222 cs.eu..._660
  0x273a0107, 0x27182902, 0x45061502, 0x05003809,   // en.eu.id_432 ms.hu.id_222 lv.de.sk_222 ca.fr..._440
  0x22454b13, 0x8c003f23, 0x228c3a07, 0x1a008c13,   // az.sk.tr_665 sw.ht..._880 eu.ht.tr_432 ht.xxx..._650
  0x22008c12, 0x18000302, 0x06002909, 0x8c053f08,   // ht.tr..._640 nl.hu..._220 ms.de..._440 sw.fr.ht_443
  // [0f60]
  0x1a008c14, 0x272904a4, 0x300e2308, 0x01101a02,   // ht.xxx..._660 fi.ms.id_433 uk.ru.be_443 xxx.sv.en_222
  0x8c006607, 0x3f008c09, 0x66218ca4, 0x2e008c22,   // af.ht..._420 ht.sw..._440 ht.tl.af_433 ht.sq..._870
  0x0000422d, 0x19000502, 0x17000f02, 0x12450402,   // mt......_A00 fr.et..._220 es.ro..._220 fi.sk.cs_222
  0x12004512, 0x12001a09, 0x17000d08, 0x230e1c14,   // sk.cs..._640 xxx.cs..._440 pt.ro..._430 bg.ru.uk_666
  // [0f70]
  0x3a003f13, 0x0e231c13, 0x8c002e08, 0x12450602,   // sw.eu..._650 bg.uk.ru_665 sq.ht..._430 de.sk.cs_222
  0x2b272909, 0x05002b09, 0x2b020b60, 0x15002e02,   // ms.id.cy_444 cy.fr..._440 no.da.cy_664 sq.lv..._220
  0x0c001912, 0x033f6607, 0x031466a4, 0x03002e14,   // et.pl..._640 af.sw.nl_432 af.is.nl_433 sq.nl..._660
  0x29002e14, 0x06002e12, 0x40190412, 0x04000107,   // sq.ms..._660 sq.de..._640 fi.et.sl_654 en.fi..._420
  // [0f80]
  0x04002709, 0x15001902, 0x04002e09, 0x15002107,   // id.fi..._440 et.lv..._220 sq.fi..._440 tl.lv..._420
  0x15000b02, 0x2b1a06a4, 0x10002e02, 0x3f002e02,   // no.lv..._220 de.xxx.cy_433 sq.sv..._220 sq.sw..._220
  0x0c001809, 0x22002b13, 0x27000b07, 0x33374e55,   // hu.pl..._440 cy.tr..._650 no.id..._420 fa.ar.ur_442
  0x4b2e2212, 0x8c1e1d08, 0x05001209, 0x37004e20,   // tr.sq.az_654 hr.sr.ht_443 cs.fr..._440 fa.ar..._850
  // [0f90]
  0x3a000509, 0x05002109, 0x151e1d13, 0x251e1c08,   // fr.eu..._440 tl.fr..._440 hr.sr.lv_665 bg.sr.mk_443
  0x251e0e07, 0x21004b23, 0x141d2109, 0x251c1e13,   // ru.sr.mk_432 az.tl..._880 tl.hr.is_444 sr.bg.mk_665
  0x0e251ea4, 0x22008c02, 0x4b002714, 0x1f001909,   // sr.mk.ru_433 ht.tr..._220 id.az..._660 et.ga..._440
  0x3f430412, 0x43000421, 0x1e1d8c02, 0x43002108,   // fi.vi.sw_654 fi.vi..._860 ht.hr.sr_222 tl.vi..._430
  // [0fa0]
  0x230e2508, 0x08002123, 0x14002709, 0x16004314,   // mk.ru.uk_443 tl.it..._880 id.is..._440 vi.lt..._660
  0x3f000f02, 0x3a000613, 0x0e251e12, 0x06140b55,   // es.sw..._220 de.eu..._650 sr.mk.ru_654 no.is.de_442
  0x04008c14, 0x3f000813, 0x29000202, 0x43000402,   // ht.fi..._660 it.sw..._650 da.ms..._220 fi.vi..._220
  0x162b1f13, 0x19001409, 0x14004b14, 0x0f083a02,   // ga.cy.lt_665 is.et..._440 az.is..._660 eu.it.es_222
  // [0fb0]
  0x3f000c12, 0x08003f23, 0x22001602, 0x00000d2d,   // pl.sw..._640 sw.it..._880 lt.tr..._220 pt......_A00
  0x21000809, 0x18000612, 0x0c006609, 0x01190b09,   // it.tl..._440 de.hu..._640 af.pl..._440 no.et.en_444
  0x1f002b13, 0x2b002708, 0x01001008, 0x30231e13,   // cy.ga..._650 id.cy..._430 sv.en..._430 sr.uk.be_665
  0x0e1c23a4, 0x04002b23, 0x4b002907, 0x380f2e12,   // uk.bg.ru_433 cy.fi..._880 ms.az..._420 sq.es.ca_654
  // [0fc0]
  0x30002514, 0x29006609, 0x174505a4, 0x19003809,   // mk.be..._660 af.ms..._440 fr.sk.ro_433 ca.et..._440
  0x15012b02, 0x03000422, 0x04002e22, 0x19001413,   // cy.en.lv_222 fi.nl..._870 sq.fi..._870 is.et..._650
  0x14000409, 0x1f000414, 0x3a041808, 0x03003a22,   // fi.is..._440 fi.ga..._660 hu.fi.eu_443 eu.nl..._870
  0x1f002b09, 0x1e001d07, 0x19160412, 0x10000302,   // cy.ga..._440 hr.sr..._420 fi.lt.et_654 nl.sv..._220
  // [0fd0]
  0x1e1d4007, 0x00001401, 0x061e1d08, 0x2e004309,   // sl.hr.sr_432 is......_200 hr.sr.de_443 vi.sq..._440
  0x06002907, 0x21000302, 0x06004514, 0x231e0eaf,   // ms.de..._420 nl.tl..._220 sk.de..._660 ru.sr.uk_655
  0x1c002508, 0x21000808, 0x1d401202, 0x05003814,   // mk.bg..._430 it.tl..._430 cs.sl.hr_222 ca.fr..._660
  0x0b001413, 0x2b001614, 0x06001421, 0x02001e02,   // is.no..._650 lt.cy..._660 is.de..._860 sr.da..._220
  // [0fe0]
  0x4b000809, 0x40000d12, 0x06036613, 0x04036614,   // it.az..._440 pt.sl..._640 af.nl.de_665 af.nl.fi_666
  0x66000508, 0x17001f22, 0x45020612, 0x27292109,   // fr.af..._430 ga.ro..._870 de.da.sk_654 tl.ms.id_444
  0x03000114, 0x1f001402, 0x272b3f09, 0x251e3008,   // en.nl..._660 is.ga..._220 sw.cy.id_444 be.sr.mk_443
  0x16003a14, 0x16000c13, 0x40000813, 0x21292708,   // eu.lt..._660 pl.lt..._650 it.sl..._650 id.ms.tl_443
  // [0ff0]
  0x16001814, 0x1a001e02, 0x66151612, 0x01000b02,   // hu.lt..._660 sr.xxx..._220 lt.lv.af_654 no.en..._220
  0x19006613, 0x21002712, 0x05002013, 0x10380b09,   // af.et..._650 id.tl..._640 gl.fr..._650 no.ca.sv_444
  0x18000402, 0x1e001614, 0x1e001c22, 0x0d000302,   // fi.hu..._220 lt.sr..._660 bg.sr..._870 nl.pt..._220
  0x05001602, 0x27002b02, 0x05001722, 0x17001f14,   // lt.fr..._220 cy.id..._220 ro.fr..._870 ga.ro..._660

  // [1000]
  0x1e004012, 0x30000e12, 0x2e001814, 0x05000809,   // sl.sr..._640 ru.be..._640 hu.sq..._660 it.fr..._440
  0x17004008, 0x10080b08, 0x1f170109, 0x2e001508,   // sl.ro..._430 no.it.sv_443 en.ro.ga_444 lv.sq..._430
  0x05172260, 0x40001913, 0x14200109, 0x03021f08,   // tr.ro.fr_664 et.sl..._650 en.gl.is_444 ga.da.nl_443
  0x421d4008, 0x050d38a4, 0x15001e08, 0x14004023,   // sl.hr.mt_443 ca.pt.fr_433 sr.lv..._430 sl.is..._880
  // [1010]
  0x40001922, 0x0f000414, 0x1f000113, 0x19004008,   // et.sl..._870 fi.es..._660 en.ga..._650 sl.et..._430
  0x2b000b09, 0x04000814, 0x22000302, 0x05000814,   // no.cy..._440 it.fi..._660 nl.tr..._220 it.fr..._660
  0x03662113, 0x33374ead, 0x05000602, 0x14000209,   // tl.af.nl_665 fa.ar.ur_643 de.fr..._220 da.is..._440
  0x0000122d, 0x22000d09, 0x66001014, 0x2b020b07,   // cs......_A00 pt.tr..._440 sv.af..._660 no.da.cy_432
  // [1020]
  0x1c251e12, 0x23301e09, 0x3f3a1908, 0x1e1c0e02,   // sr.mk.bg_654 sr.be.uk_444 et.eu.sw_443 ru.bg.sr_222
  0x380f2013, 0x12060502, 0x23300e09, 0x05008c12,   // gl.es.ca_665 fr.de.cs_222 ru.be.uk_444 ht.fr..._640
  0x1e1d08a4, 0x191e1da4, 0x0e001e23, 0x19000c13,   // it.hr.sr_433 hr.sr.et_433 sr.ru..._880 pl.et..._650
  0x16004013, 0x1e1d19af, 0x0d001f12, 0x40001623,   // sl.lt..._650 et.hr.sr_655 ga.pt..._640 lt.sl..._880
  // [1030]
  0x012214a4, 0x15000c14, 0x1e401d08, 0x1d000214,   // is.tr.en_433 pl.lv..._660 hr.sl.sr_443 da.hr..._660
  0x1e1d4013, 0x04272909, 0x30000e22, 0x40152709,   // sl.hr.sr_665 ms.id.fi_444 ru.be..._870 id.lv.sl_444
  0x22001823, 0x14002213, 0x2e224509, 0x1a002b02,   // hu.tr..._880 tr.is..._650 sk.tr.sq_444 cy.xxx..._220
  0x42002b21, 0x1c250e60, 0x0000232d, 0x01002109,   // cy.mt..._860 ru.mk.bg_664 uk......_A00 tl.en..._440
  // [1040]
  0x0c2b3fa4, 0x04191412, 0x29001a09, 0x02002709,   // sw.cy.pl_433 is.et.fi_654 xxx.ms..._440 id.da..._440
  0x0d000114, 0x19002202, 0x05004b02, 0x04002214,   // en.pt..._660 tr.et..._220 az.fr..._220 tr.fi..._660
  0x16011008, 0x16000d02, 0x04004b02, 0x14001909,   // sv.en.lt_443 pt.lt..._220 az.fi..._220 et.is..._440
  0x1e001c07, 0x10040608, 0x27001909, 0x03002e21,   // bg.sr..._420 de.fi.sv_443 et.id..._440 sq.nl..._860
  // [1050]
  0x12000d08, 0x1a000814, 0x0d003809, 0x1d171e02,   // pt.cs..._430 it.xxx..._660 ca.pt..._440 sr.ro.hr_222
  0x10000809, 0x0d0f0509, 0x381708af, 0x452e1808,   // it.sv..._440 fr.es.pt_444 it.ro.ca_655 hu.sq.sk_443
  0x06006613, 0x1f000509, 0x3f2729af, 0x1d002e23,   // af.de..._650 fr.ga..._440 ms.id.sw_655 sq.hr..._880
  0x300e2312, 0x278c0502, 0x3f000c14, 0x14002702,   // uk.ru.be_654 fr.ht.id_222 pl.sw..._660 id.is..._220
  // [1060]
  0x080c0508, 0x42001802, 0x0f000309, 0x05001f02,   // fr.pl.it_443 hu.mt..._220 nl.es..._440 ga.fr..._220
  0x1e022ea4, 0x4b213f13, 0x38004b12, 0x3a001802,   // sq.da.sr_433 sw.tl.az_665 az.ca..._640 hu.eu..._220
  0x0f004514, 0x0c1e1d14, 0x01061a08, 0x1e0c1d13,   // sk.es..._660 hr.sr.pl_666 xxx.de.en_443 hr.pl.sr_665
  0x1e0c1d14, 0x0e3023a4, 0x1e1d0caf, 0x0f001702,   // hr.pl.sr_666 uk.be.ru_433 pl.hr.sr_655 ro.es..._220
  // [1070]
  0x1e1d0c12, 0x02008c09, 0x18000c12, 0x06002714,   // pl.hr.sr_654 ht.da..._440 pl.hu..._640 id.de..._660
  0x1e250e02, 0x293f0607, 0x300e1e09, 0x3f001209,   // ru.mk.sr_222 de.sw.ms_432 sr.ru.be_444 cs.sw..._440
  0x3f190407, 0x0e002508, 0x15292760, 0x45001a09,   // fi.et.sw_432 mk.ru..._430 id.ms.lv_664 xxx.sk..._440
  0x66002914, 0x0f063aad, 0x3f002109, 0x23001c23,   // ms.af..._660 eu.de.es_643 tl.sw..._440 bg.uk..._880
  // [1080]
  0x1d003f02, 0x04004009, 0x04001623, 0x18002e02,   // sw.hr..._220 sl.fi..._440 lt.fi..._880 sq.hu..._220
  0x21002909, 0x3f001514, 0x10002e14, 0x1e004209,   // ms.tl..._440 lv.sw..._660 sq.sv..._660 mt.sr..._440
  0x401d1e12, 0x2e008c02, 0x19036609, 0x05001d02,   // sr.hr.sl_654 ht.sq..._220 af.nl.et_444 hr.fr..._220
  0x38000823, 0x18000c14, 0x3f004008, 0x45002e08,   // it.ca..._880 pl.hu..._660 sl.sw..._430 sq.sk..._430
  // [1090]
  0x27290ca4, 0x00000c01, 0x40002902, 0x12451502,   // pl.ms.id_433 pl......_200 ms.sl..._220 lv.sk.cs_222
  0x66031907, 0x4e333714, 0x03002b12, 0x29008c14,   // et.nl.af_432 ar.ur.fa_666 cy.nl..._640 ht.ms..._660
  0x20000123, 0x191d1708, 0x19006602, 0x19000114,   // en.gl..._880 ro.hr.et_443 af.et..._220 en.et..._660
  0x15001909, 0x06004302, 0x251e1ca4, 0x1c0e2308,   // et.lv..._440 vi.de..._220 bg.sr.mk_433 uk.ru.bg_443
  // [10a0]
  0x0000430a, 0x08001a08, 0x06001e02, 0x06101a09,   // vi......_500 xxx.it..._430 sr.de..._220 xxx.sv.de_444
  0x06002114, 0x2b004214, 0x8c1a3f13, 0x29062702,   // tl.de..._660 mt.cy..._660 sw.xxx.ht_665 id.de.ms_222
  0x0d0f3855, 0x251c0e60, 0x3f8c1a12, 0x08001909,   // ca.es.pt_442 ru.bg.mk_664 xxx.ht.sw_654 et.it..._440
  0x45021a60, 0x1a8c3f08, 0x0c000309, 0x0d0f3809,   // xxx.da.sk_664 sw.ht.xxx_443 nl.pl..._440 ca.es.pt_444
  // [10b0]
  0x12002b14, 0x121d1e02, 0x0c1a3f08, 0x1f004323,   // cy.cs..._660 sr.hr.cs_222 sw.xxx.pl_443 vi.ga..._880
  0x3f000c02, 0x451d1e13, 0x21272960, 0x151e1d14,   // pl.sw..._220 sr.hr.sk_665 ms.id.tl_664 hr.sr.lv_666
  0x151d1eaf, 0x1e1d4011, 0x3f000c09, 0x0b031009,   // sr.hr.lv_655 sl.hr.sr_653 pl.sw..._440 sv.nl.no_444
  0x151e1d09, 0x43191a08, 0x01002208, 0x0f124508,   // hr.sr.lv_444 xxx.et.vi_443 tr.en..._430 sk.cs.es_443
  // [10c0]
  0x12003f02, 0x401d1e09, 0x29001509, 0x29002e02,   // sw.cs..._220 sr.hr.sl_444 lv.ms..._440 sq.ms..._220
  0x38001523, 0x01002902, 0x291e1d02, 0x1f000f23,   // lv.ca..._880 ms.en..._220 hr.sr.ms_222 es.ga..._880
  0x451a4309, 0x1f000f02, 0x290f1402, 0x050f0d02,   // vi.xxx.sk_444 es.ga..._220 is.es.ms_222 pt.es.fr_222
  0x42001207, 0x16041955, 0x38000521, 0x38008c14,   // cs.mt..._420 et.fi.lt_442 fr.ca..._860 ht.ca..._660
  // [10d0]
  0x400d0508, 0x8c002014, 0x8c003a09, 0x12450d02,   // fr.pt.sl_443 gl.ht..._660 eu.ht..._440 pt.sk.cs_222
  0x12004002, 0x66388c08, 0x23002509, 0x08170109,   // sl.cs..._220 ht.ca.af_443 mk.uk..._440 en.ro.it_444
  0x1c251e14, 0x45001502, 0x374e33ac, 0x428c3f07,   // sr.mk.bg_666 lv.sk..._220 ur.fa.ar_632 sw.ht.mt_432
  0x230e1c07, 0x27004314, 0x1a163a07, 0x300e1c13,   // bg.ru.uk_432 vi.id..._660 eu.lt.xxx_432 bg.ru.be_665
  // [10e0]
  0x21001a09, 0x1c0e2360, 0x0e1c2314, 0x2b008c08,   // xxx.tl..._440 uk.ru.bg_664 uk.bg.ru_666 ht.cy..._430
  0x1f000202, 0x42003f11, 0x1d000c22, 0x380d1812,   // da.ga..._220 sw.mt..._630 pl.hr..._870 hu.pt.ca_654
  0x21002908, 0x0c000b09, 0x45002202, 0x17001513,   // ms.tl..._430 no.pl..._440 tr.sk..._220 lv.ro..._650
  0x401e1d12, 0x29002713, 0x03003813, 0x0d0f1408,   // hr.sr.sl_654 id.ms..._650 ca.nl..._650 is.es.pt_443
  // [10f0]
  0x03001202, 0x45380602, 0x1c250eaf, 0x1c0e2309,   // cs.nl..._220 de.ca.sk_222 ru.mk.bg_655 uk.ru.bg_444
  0x14000f12, 0x1d401e08, 0x15140b09, 0x401e1daf,   // es.is..._640 sr.sl.hr_443 no.is.lv_444 hr.sr.sl_655
  0x27000b02, 0x2b000f13, 0x45001814, 0x19001714,   // no.id..._220 es.cy..._650 hu.sk..._660 ro.et..._660
  0x37003321, 0x16002b14, 0x1f000309, 0x17000514,   // ur.ar..._860 cy.lt..._660 nl.ga..._440 fr.ro..._660
  // [1100]
  0x29192707, 0x160f0d11, 0x3f002214, 0x06003a14,   // id.et.ms_432 pt.es.lt_653 tr.sw..._660 eu.de..._660
  0x16001522, 0x2e002709, 0x1a423faf, 0x27163f08,   // lv.lt..._870 id.sq..._440 sw.mt.xxx_655 sw.lt.id_443
  0x15002714, 0x16002214, 0x05000402, 0x21292707,   // id.lv..._660 tr.lt..._660 fi.fr..._220 id.ms.tl_432
  0x21008c23, 0x3f002922, 0x29223a02, 0x22001a12,   // ht.tl..._880 ms.sw..._870 eu.tr.ms_222 xxx.tr..._640
  // [1110]
  0x3f001723, 0x3f001714, 0x1e0e2513, 0x22003a02,   // ro.sw..._880 ro.sw..._660 mk.ru.sr_665 eu.tr..._220
  0x22042907, 0x8c3f1a08, 0x27152907, 0x8c1a22af,   // ms.fi.tr_432 xxx.sw.ht_443 ms.lv.id_432 tr.xxx.ht_655
  0x012e8ca4, 0x06000513, 0x3a000313, 0x08001f02,   // ht.sq.en_433 fr.de..._650 nl.eu..._650 ga.it..._220
  0x15001f14, 0x06000313, 0x16050408, 0x30002320,   // ga.lv..._660 nl.de..._650 fi.fr.lt_443 uk.be..._850
  // [1120]
  0x15000502, 0x04001513, 0x12001f07, 0x1c251e13,   // fr.lv..._220 lv.fi..._650 ga.cs..._420 sr.mk.bg_665
  0x450c1214, 0x4e003308, 0x3f003a09, 0x121d1e09,   // cs.pl.sk_666 ur.fa..._430 eu.sw..._440 sr.hr.cs_444
  0x0f050d08, 0x8c000b09, 0x19000813, 0x66000114,   // pt.fr.es_443 no.ht..._440 it.et..._650 en.af..._660
  0x1e272902, 0x17002702, 0x45124009, 0x3f000309,   // ms.id.sr_222 id.ro..._220 sl.cs.sk_444 nl.sw..._440
  // [1130]
  0x273a2908, 0x4b001709, 0x3a171608, 0x1d170b07,   // ms.eu.id_443 ro.az..._440 lt.ro.eu_443 no.ro.hr_432
  0x0c001a02, 0x42003f02, 0x8c000402, 0x8c001d02,   // xxx.pl..._220 sw.mt..._220 fi.ht..._220 hr.ht..._220
  0x0d001712, 0x1f004302, 0x12001708, 0x02000402,   // ro.pt..._640 vi.ga..._220 ro.cs..._430 fi.da..._220
  0x38001a13, 0x02001702, 0x05003f02, 0x0f004502,   // xxx.ca..._650 ro.da..._220 sw.fr..._220 sk.es..._220
  // [1140]
  0x1e1d1702, 0x2b003a09, 0x0d1f0fa4, 0x27001714,   // ro.hr.sr_222 eu.cy..._440 es.ga.pt_433 ro.id..._660
  0x1d004507, 0x29142702, 0x1e001422, 0x22001423,   // sk.hr..._420 id.is.ms_222 is.sr..._870 is.tr..._880
  0x2b660309, 0x0d001422, 0x1e1c2555, 0x06000c13,   // nl.af.cy_444 is.pt..._870 mk.bg.sr_442 pl.de..._650
  0x0c003a13, 0x03003f22, 0x22000109, 0x38001402,   // eu.pl..._650 sw.nl..._870 en.tr..._440 is.ca..._220
  // [1150]
  0x0d3a0f09, 0x21000413, 0x05001809, 0x01000614,   // es.eu.pt_444 fi.tl..._650 hu.fr..._440 de.en..._660
  0x27668c07, 0x0d004307, 0x0c002b02, 0x421f0caf,   // ht.af.id_432 vi.pt..._420 cy.pl..._220 pl.ga.mt_655
  0x3f001902, 0x1a001502, 0x27003f11, 0x0c001814,   // et.sw..._220 lv.xxx..._220 sw.id..._630 hu.pl..._660
  0x15004013, 0x22000414, 0x12008c02, 0x1d001902,   // sl.lv..._650 fi.tr..._660 ht.cs..._220 et.hr..._220
  // [1160]
  0x20000d23, 0x3f036655, 0x17190412, 0x45002102,   // pt.gl..._880 af.nl.sw_442 fi.et.ro_654 tl.sk..._220
  0x3f002708, 0x02003a08, 0x2e002902, 0x0c001212,   // id.sw..._430 eu.da..._430 ms.sq..._220 cs.pl..._640
  0x42004013, 0x45161212, 0x1f083fa4, 0x1e1d2e09,   // sl.mt..._650 cs.lt.sk_654 sw.it.ga_433 sq.hr.sr_444
  0x4b000802, 0x20004323, 0x1e1d0609, 0x1d4005a4,   // it.az..._220 vi.gl..._880 de.hr.sr_444 fr.sl.hr_433
  // [1170]
  0x2b001812, 0x2e002122, 0x05001708, 0x66058c08,   // hu.cy..._640 tl.sq..._870 ro.fr..._430 ht.fr.af_443
  0x3f1f4208, 0x2e003a09, 0x05002e09, 0x14000609,   // mt.ga.sw_443 eu.sq..._440 sq.fr..._440 de.is..._440
  0x12006602, 0x3a002e13, 0x08003a14, 0x3f003a14,   // af.cs..._220 sq.eu..._650 eu.it..._660 eu.sw..._660
  0x0000292d, 0x17212b12, 0x08000509, 0x3a002e09,   // ms......_A00 cy.tl.ro_654 fr.it..._440 sq.eu..._440
  // [1180]
  0x2e003a23, 0x1a3a2e08, 0x14003814, 0x18004509,   // eu.sq..._880 sq.eu.xxx_443 ca.is..._660 sk.hu..._440
  0x0d000513, 0x45001422, 0x3f001812, 0x1e451d14,   // fr.pt..._650 is.sk..._870 hu.sw..._640 hr.sk.sr_666
  0x184208a4, 0x1f001602, 0x27000209, 0x173a2909,   // it.mt.hu_433 lt.ga..._220 da.id..._440 ms.eu.ro_444
  0x1f001a22, 0x29001514, 0x19003a09, 0x19002e22,   // xxx.ga..._870 lv.ms..._660 eu.et..._440 sq.et..._870
  // [1190]
  0x42001e14, 0x45000c23, 0x230e1c12, 0x43191a12,   // sr.mt..._660 pl.sk..._880 bg.ru.uk_654 xxx.et.vi_654
  0x66002b14, 0x380d0f14, 0x3f002b02, 0x45121fa4,   // cy.af..._660 es.pt.ca_666 cy.sw..._220 ga.cs.sk_433
  0x04002202, 0x2e002b02, 0x3a001209, 0x0d000614,   // tr.fi..._220 cy.sq..._220 cs.eu..._440 de.pt..._660
  0x10001709, 0x02002113, 0x2b001814, 0x1f050b08,   // ro.sv..._440 tl.da..._650 hu.cy..._660 no.fr.ga_443
  // [11a0]
  0x1a053802, 0x22000502, 0x12001a14, 0x08170107,   // ca.fr.xxx_222 fr.tr..._220 xxx.cs..._660 en.ro.it_432
  0x0f384507, 0x15004007, 0x231e0e12, 0x2e002714,   // sk.ca.es_432 sl.lv..._420 ru.sr.uk_654 id.sq..._660
  0x3a001a09, 0x2e000b07, 0x05008c23, 0x0f000c14,   // xxx.eu..._440 no.sq..._420 ht.fr..._880 pl.es..._660
  0x0c004202, 0x3f002122, 0x451d1202, 0x1e001d08,   // mt.pl..._220 tl.sw..._870 cs.hr.sk_222 hr.sr..._430
  // [11b0]
  0x40124514, 0x0c000514, 0x19004202, 0x3f002113,   // sk.cs.sl_666 fr.pl..._660 mt.et..._220 tl.sw..._650
  0x0c003f07, 0x29104b02, 0x100b0213, 0x1e1d1802,   // sw.pl..._420 az.sv.ms_222 da.no.sv_665 hu.hr.sr_222
  0x02100b12, 0x12004009, 0x8c004b02, 0x0f008c07,   // no.sv.da_654 sl.cs..._440 az.ht..._220 ht.es..._420
  0x1f0122a4, 0x08002214, 0x05001914, 0x16170813,   // tr.en.ga_433 tr.it..._660 et.fr..._660 it.ro.lt_665
  // [11c0]
  0x1a030655, 0x15001e14, 0x2b003f09, 0x14000f02,   // de.nl.xxx_442 sr.lv..._660 sw.cy..._440 es.is..._220
  0x14000f08, 0x05080109, 0x08000514, 0x38001a08,   // es.is..._430 en.it.fr_444 fr.it..._660 xxx.ca..._430
  0x45000d02, 0x17002e09, 0x42004b12, 0x15001e02,   // pt.sk..._220 sq.ro..._440 az.mt..._640 sr.lv..._220
  0x1e401daf, 0x451d1e07, 0x66002709, 0x401d1e11,   // hr.sl.sr_655 sr.hr.sk_432 id.af..._440 sr.hr.sl_653
  // [11d0]
  0x22292760, 0x01000b09, 0x29004014, 0x291d4002,   // id.ms.tr_664 no.en..._440 sl.ms..._660 sl.hr.ms_222
  0x02002e02, 0x19041a09, 0x1f003809, 0x170d0813,   // sq.da..._220 xxx.fi.et_444 ca.ga..._440 it.pt.ro_665
  0x3f181aa4, 0x06153a08, 0x06000d08, 0x1e402707,   // xxx.hu.sw_433 eu.lv.de_443 pt.de..._430 id.sl.sr_432
  0x38000602, 0x15660b09, 0x16006602, 0x14000c12,   // de.ca..._220 no.af.lv_444 af.lt..._220 pl.is..._640
  // [11e0]
  0x21000309, 0x1d001708, 0x1d401608, 0x29000313,   // nl.tl..._440 ro.hr..._430 lt.sl.hr_443 nl.ms..._650
  0x1d451e02, 0x04006613, 0x40001d23, 0x14001822,   // sr.sk.hr_222 af.fi..._650 hr.sl..._880 hu.is..._870
  0x04001514, 0x014b4302, 0x18001412, 0x04001709,   // lv.fi..._660 vi.az.en_222 is.hu..._640 ro.fi..._440
  0x08001f21, 0x193f0460, 0x42002121, 0x19001514,   // ga.it..._860 fi.sw.et_664 tl.mt..._860 lv.et..._660
  // [11f0]
  0x06004208, 0x02004207, 0x17001902, 0x22003f08,   // mt.de..._430 mt.da..._420 et.ro..._220 sw.tr..._430
  0x3f191508, 0x16011f07, 0x15001913, 0x063f6609,   // lv.et.sw_443 ga.en.lt_432 et.lv..._650 af.sw.de_444
  0x22001f23, 0x66200107, 0x21000202, 0x10000308,   // ga.tr..._880 en.gl.af_432 da.tl..._220 nl.sv..._430
  0x451d0c02, 0x2e000213, 0x3a000302, 0x043f1508,   // pl.hr.sk_222 da.sq..._650 nl.eu..._220 lv.sw.fi_443
  // [1200]
  0x2e660109, 0x04193fa4, 0x66002e02, 0x16002b23,   // en.af.sq_444 sw.et.fi_433 sq.af..._220 cy.lt..._880
  0x18002e14, 0x01002209, 0x3a001014, 0x0c001f22,   // sq.hu..._660 tr.en..._440 sv.eu..._660 ga.pl..._870
  0x14080b09, 0x66002214, 0x0c001f23, 0x1f004214,   // no.it.is_444 tr.af..._660 ga.pl..._880 mt.ga..._660
  0x1f000c14, 0x0000382d, 0x3f001f02, 0x12004521,   // pl.ga..._660 ca......_A00 ga.sw..._220 sk.cs..._860
  // [1210]
  0x45010c02, 0x27182913, 0x3f272913, 0x1e0d0f02,   // pl.en.sk_222 ms.hu.id_665 ms.id.sw_665 es.pt.sr_222
  0x45012102, 0x27000114, 0x1f000c23, 0x1d421ea4,   // tl.en.sk_222 en.id..._660 pl.ga..._880 sr.mt.hr_433
  0x2b001f02, 0x3a043fad, 0x1d004314, 0x18000b09,   // ga.cy..._220 sw.fi.eu_643 vi.hr..._660 no.hu..._440
  0x18001d23, 0x45100202, 0x01001702, 0x3a001409,   // hr.hu..._880 da.sv.sk_222 ro.en..._220 is.eu..._440
  // [1220]
  0x1d000209, 0x151d4008, 0x1d000c13, 0x01210c11,   // da.hr..._440 sl.hr.lv_443 pl.hr..._650 pl.tl.en_653
  0x0c061a08, 0x06660309, 0x15001723, 0x30002522,   // xxx.de.pl_443 nl.af.de_444 ro.lv..._880 mk.be..._870
  0x05001609, 0x27164208, 0x8c000602, 0x42001f02,   // lt.fr..._440 mt.lt.id_443 de.ht..._220 ga.mt..._220
  0x222729af, 0x18001613, 0x1e0e2309, 0x00000b01,   // ms.id.tr_655 lt.hu..._650 uk.ru.sr_444 no......_200
  // [1230]
  0x23251e55, 0x2e001a12, 0x03172107, 0x18001a09,   // sr.mk.uk_442 xxx.sq..._640 tl.ro.nl_432 xxx.hu..._440
  0x37003311, 0x224b29a4, 0x3f2b8c08, 0x1d011e02,   // ur.ar..._630 ms.az.tr_433 ht.cy.sw_443 sr.en.hr_222
  0x00004501, 0x21002212, 0x450f0107, 0x020366a4,   // sk......_200 tr.tl..._640 en.es.sk_432 af.nl.da_433
  0x02006609, 0x1a006614, 0x16003808, 0x05451a09,   // af.da..._440 af.xxx..._660 ca.lt..._430 xxx.sk.fr_444
  // [1240]
  0x200d3809, 0x01000409, 0x3f003a13, 0x66031a08,   // ca.pt.gl_444 fi.en..._440 eu.sw..._650 xxx.nl.af_443
  0x2b000214, 0x02036608, 0x16001d09, 0x03008c12,   // da.cy..._660 af.nl.da_443 hr.lt..._440 ht.nl..._640
  0x8c000308, 0x8c036609, 0x10001a21, 0x29663a02,   // nl.ht..._430 af.nl.ht_444 xxx.sv..._860 eu.af.ms_222
  0x14000109, 0x05001f08, 0x02001423, 0x18000123,   // en.is..._440 ga.fr..._430 is.da..._880 en.hu..._880
  // [1250]
  0x05000314, 0x38050f12, 0x19002213, 0x04193f09,   // nl.fr..._660 es.fr.ca_654 tr.et..._650 sw.et.fi_444
  0x04001702, 0x23300e60, 0x2e000402, 0x19002b02,   // ro.fi..._220 ru.be.uk_664 fi.sq..._220 cy.et..._220
  0x38433a12, 0x05008c08, 0x03061a08, 0x06001514,   // eu.vi.ca_654 ht.fr..._430 xxx.de.nl_443 lv.de..._660
  0x15000614, 0x1f000622, 0x16000614, 0x14062b08,   // de.lv..._660 de.ga..._870 de.lt..._660 cy.de.is_443
  // [1260]
  0x03002023, 0x380d0f08, 0x050d4309, 0x19001502,   // gl.nl..._880 es.pt.ca_443 vi.pt.fr_444 lv.et..._220
  0x1e002e09, 0x03000608, 0x15036608, 0x66001802,   // sq.sr..._440 de.nl..._430 af.nl.lv_443 hu.af..._220
  0x19100608, 0x052b3fa4, 0x43451f08, 0x151e2ea4,   // de.sv.et_443 sw.cy.fr_433 ga.sk.vi_443 sq.sr.lv_433
  0x22100214, 0x1d121502, 0x1f008c12, 0x10198c07,   // da.sv.tr_666 lv.cs.hr_222 ht.ga..._640 ht.et.sv_432
  // [1270]
  0x1a001f09, 0x05002b23, 0x42068ca4, 0x0000662d,   // ga.xxx..._440 cy.fr..._880 ht.de.mt_433 af......_A00
  0x1f000614, 0x15004202, 0x27422913, 0x0e231caf,   // de.ga..._660 mt.lv..._220 ms.mt.id_665 bg.uk.ru_655
  0x0f000808, 0x401d1e13, 0x220c2707, 0x16001914,   // it.es..._430 sr.hr.sl_665 id.pl.tr_432 et.lt..._660
  0x06001023, 0x06002914, 0x04050108, 0x14001514,   // sv.de..._880 ms.de..._660 en.fr.fi_443 lv.is..._660
  // [1280]
  0x23300e12, 0x1e251c08, 0x1d001202, 0x1e000814,   // ru.be.uk_654 bg.mk.sr_443 cs.hr..._220 it.sr..._660
  0x15041607, 0x0b000c02, 0x041e1da4, 0x43001914,   // lt.fi.lv_432 pl.no..._220 hr.sr.fi_433 et.vi..._660
  0x1d001602, 0x33374ea4, 0x01166608, 0x42002e12,   // lt.hr..._220 fa.ar.ur_433 af.lt.en_443 sq.mt..._640
  0x0d000523, 0x45014202, 0x40003802, 0x0b004302,   // fr.pt..._880 mt.en.sk_222 ca.sl..._220 vi.no..._220
  // [1290]
  0x17000d09, 0x12000302, 0x2e002b23, 0x45003a09,   // pt.ro..._440 nl.cs..._220 cy.sq..._880 eu.sk..._440
  0x01002002, 0x200f0107, 0x08006602, 0x06001813,   // gl.en..._220 en.es.gl_432 af.it..._220 hu.de..._650
  0x4e333711, 0x66020b07, 0x19000202, 0x66002213,   // ar.ur.fa_653 no.da.af_432 da.et..._220 tr.af..._650
  0x1c1e2355, 0x1d001509, 0x08001002, 0x17001014,   // uk.sr.bg_442 lv.hr..._440 sv.it..._220 sv.ro..._660
  // [12a0]
  0x38000114, 0x0d004514, 0x43004b09, 0x0f000513,   // en.ca..._660 sk.pt..._660 az.vi..._440 fr.es..._650
  0x66221913, 0x27296609, 0x8c053855, 0x0c002b21,   // et.tr.af_665 af.ms.id_444 ca.fr.ht_442 cy.pl..._860
  0x16001d14, 0x43000f02, 0x0d002702, 0x1e300e02,   // hr.lt..._660 es.vi..._220 id.pt..._220 ru.be.sr_222
  0x1d401e02, 0x3a272913, 0x660d0308, 0x18004b11,   // sr.sl.hr_222 ms.id.eu_665 nl.pt.af_443 az.hu..._630
  // [12b0]
  0x1a003809, 0x05124514, 0x0d0f3808, 0x1f008c14,   // ca.xxx..._440 sk.cs.fr_666 ca.es.pt_443 ht.ga..._660
  0x66032bad, 0x01002108, 0x4b001909, 0x08001423,   // cy.nl.af_643 tl.en..._430 et.az..._440 is.it..._880
  0x06001922, 0x15000f09, 0x8c004314, 0x43002902,   // et.de..._870 es.lv..._440 vi.ht..._660 ms.vi..._220
  0x0b004202, 0x15003f14, 0x2e001a09, 0x1e302509,   // mt.no..._220 sw.lv..._660 xxx.sq..._440 mk.be.sr_444
  // [12c0]
  0x37334e07, 0x01170808, 0x18003814, 0x18001408,   // fa.ur.ar_432 it.ro.en_443 ca.hu..._660 is.hu..._430
  0x10020b55, 0x18000f08, 0x4b001509, 0x3f004b14,   // no.da.sv_442 es.hu..._430 lv.az..._440 az.sw..._660
  0x29226602, 0x66004502, 0x19001613, 0x291d1e02,   // af.tr.ms_222 sk.af..._220 lt.et..._650 sr.hr.ms_222
  0x1d294002, 0x03660660, 0x04001621, 0x1a006608,   // sl.ms.hr_222 de.af.nl_664 lt.fi..._860 af.xxx..._430
  // [12d0]
  0x1d271e02, 0x00001515, 0x40272907, 0x18004213,   // sr.id.hr_222 lv......_700 ms.id.sl_432 mt.hu..._650
  0x16040814, 0x1d001513, 0x401d1e60, 0x4b004212,   // it.fi.lt_666 lv.hr..._650 sr.hr.sl_664 mt.az..._640
  0x1e1d1002, 0x22002909, 0x1d002902, 0x1d001502,   // sv.hr.sr_222 ms.tr..._440 ms.hr..._220 lv.hr..._220
  0x2b000613, 0x45000d09, 0x04001414, 0x4b2e42a4,   // de.cy..._650 pt.sk..._440 is.fi..._660 mt.sq.az_433
  // [12e0]
  0x1d002909, 0x1f000f07, 0x14002e09, 0x03660608,   // ms.hr..._440 es.ga..._420 sq.is..._440 de.af.nl_443
  0x043f19af, 0x12453aa4, 0x14002e22, 0x2e001423,   // et.sw.fi_655 eu.sk.cs_433 sq.is..._870 is.sq..._880
  0x19002102, 0x17002909, 0x27001902, 0x3f002707,   // tl.et..._220 ms.ro..._440 et.id..._220 id.sw..._420
  0x43006602, 0x2b036608, 0x1d161507, 0x15661911,   // af.vi..._220 af.nl.cy_443 lv.lt.hr_432 et.af.lv_653
  // [12f0]
  0x0d008c09, 0x29080f02, 0x270f38a4, 0x2b003f13,   // ht.pt..._440 es.it.ms_222 ca.es.id_433 sw.cy..._650
  0x45002108, 0x12044502, 0x45004307, 0x27001609,   // tl.sk..._430 sk.fi.cs_222 vi.sk..._420 lt.id..._440
  0x1e1d1614, 0x04100608, 0x45051502, 0x14190408,   // lt.hr.sr_666 de.sv.fi_443 lv.fr.sk_222 fi.et.is_443
  0x22001714, 0x0b002213, 0x1a003802, 0x42140608,   // ro.tr..._660 tr.no..._650 ca.xxx..._220 de.is.mt_443
  // [1300]
  0x42002709, 0x66000814, 0x21004212, 0x42002914,   // id.mt..._440 it.af..._660 mt.tl..._640 ms.mt..._660
  0x1d004302, 0x0000172d, 0x0b000512, 0x43000302,   // vi.hr..._220 ro......_A00 fr.no..._640 nl.vi..._220
  0x2e001514, 0x4b004321, 0x1a006609, 0x21008c14,   // lv.sq..._660 vi.az..._860 af.xxx..._440 ht.tl..._660
  0x1f0f0b07, 0x2b004314, 0x14006602, 0x08000123,   // no.es.ga_432 vi.cy..._660 af.is..._220 en.it..._880
  // [1310]
  0x40451213, 0x4b000107, 0x21002923, 0x164b2208,   // cs.sk.sl_665 en.az..._420 ms.tl..._880 tr.az.lt_443
  0x292721a4, 0x08036608, 0x29002112, 0x29212708,   // tl.id.ms_433 af.nl.it_443 tl.ms..._640 id.tl.ms_443
  0x8c4b22af, 0x4b000f02, 0x1d1e1508, 0x19001422,   // tr.az.ht_655 es.az..._220 lv.sr.hr_443 is.et..._870
  0x16002202, 0x1a001f12, 0x21000313, 0x1f008c13,   // tr.lt..._220 ga.xxx..._640 nl.tl..._650 ht.ga..._650
  // [1320]
  0x250e2360, 0x1f000513, 0x1e1d1602, 0x22003809,   // uk.ru.mk_664 fr.ga..._650 lt.hr.sr_222 ca.tr..._440
  0x1f001422, 0x0d001602, 0x06144208, 0x3a000d14,   // is.ga..._870 lt.pt..._220 mt.is.de_443 pt.eu..._660
  0x66004308, 0x04000d14, 0x0e2330af, 0x401e4507,   // vi.af..._430 pt.fi..._660 be.uk.ru_655 sk.sr.sl_432
  0x1a002213, 0x1d291f02, 0x1e003014, 0x2b002e13,   // tr.xxx..._650 ga.ms.hr_222 be.sr..._660 sq.cy..._650
  // [1330]
  0x27192902, 0x4b001009, 0x451d4002, 0x8c002023,   // ms.et.id_222 sv.az..._440 sl.hr.sk_222 gl.ht..._880
  0x1d000b14, 0x3f000d09, 0x43001e09, 0x06043a07,   // no.hr..._660 pt.sw..._440 sr.vi..._440 eu.fi.de_432
  0x22008c13, 0x05008c09, 0x0b000814, 0x451e0502,   // ht.tr..._650 ht.fr..._440 it.no..._660 fr.sr.sk_222
  0x2b000814, 0x17004009, 0x22660312, 0x1d454008,   // it.cy..._660 sl.ro..._440 nl.af.tr_654 sl.sk.hr_443
  // [1340]
  0x08001014, 0x0b001902, 0x033a6608, 0x380f0d08,   // sv.it..._660 et.no..._220 af.eu.nl_443 pt.es.ca_443
  0x23001e12, 0x27403a02, 0x1d002109, 0x4b004208,   // sr.uk..._640 eu.sl.id_222 tl.hr..._440 mt.az..._430
  0x45120daf, 0x3a006612, 0x45121812, 0x23251e14,   // pt.cs.sk_655 af.eu..._640 hu.cs.sk_654 sr.mk.uk_666
  0x1c002322, 0x14001813, 0x8c002709, 0x0d0f2909,   // uk.bg..._870 hu.is..._650 id.ht..._440 ms.es.pt_444
  // [1350]
  0x1a001402, 0x0f001613, 0x01004b02, 0x221e1d13,   // is.xxx..._220 lt.es..._650 az.en..._220 hr.sr.tr_665
  0x42004514, 0x0000222d, 0x66140b09, 0x2b0f3808,   // sk.mt..._660 tr......_A00 no.is.af_444 ca.es.cy_443
  0x16000612, 0x66000622, 0x43008c09, 0x01001908,   // de.lt..._640 de.af..._870 ht.vi..._440 et.en..._430
  0x1f001408, 0x1f001021, 0x42212907, 0x40272908,   // is.ga..._430 sv.ga..._860 ms.tl.mt_432 ms.id.sl_443
  // [1360]
  0x27001613, 0x04001412, 0x25000e07, 0x15000f08,   // lt.id..._650 is.fi..._640 ru.mk..._420 es.lv..._430
  0x251e1c12, 0x12001412, 0x38660308, 0x02000b21,   // bg.sr.mk_654 is.cs..._640 nl.af.ca_443 no.da..._860
  0x22001f22, 0x20380d60, 0x1e002709, 0x06001513,   // ga.tr..._870 pt.ca.gl_664 id.sr..._440 lv.de..._650
  0x12001a12, 0x1e024202, 0x40001509, 0x14660b09,   // xxx.cs..._640 mt.da.sr_222 lv.sl..._440 no.af.is_444
  // [1370]
  0x1c003008, 0x4b006614, 0x03002702, 0x011a4308,   // be.bg..._430 af.az..._660 id.nl..._220 vi.xxx.en_443
  0x0d003808, 0x121d1a02, 0x251c1e12, 0x1f12456d,   // ca.pt..._430 xxx.hr.cs_222 sr.bg.mk_654 sk.cs.ga_874
  0x17003f08, 0x02036660, 0x43000808, 0x14020b14,   // sw.ro..._430 af.nl.da_664 it.vi..._430 no.da.is_666
  0x251c1e08, 0x05004b13, 0x12000c14, 0x0c184060,   // sr.bg.mk_443 az.fr..._650 pl.cs..._660 sl.hu.pl_664
  // [1380]
  0x453a2b07, 0x45000113, 0x10000402, 0x380f0d14,   // cy.eu.sk_432 en.sk..._650 fi.sv..._220 pt.es.ca_666
  0x8c020b07, 0x29004b13, 0x45013a02, 0x17000509,   // no.da.ht_432 az.ms..._650 eu.en.sk_222 fr.ro..._440
  0x38002014, 0x0f000409, 0x06001814, 0x451e2102,   // gl.ca..._660 fi.es..._440 hu.de..._660 tl.sr.sk_222
  0x1e0e2508, 0x10002213, 0x100240a4, 0x10001514,   // mk.ru.sr_443 tr.sv..._650 sl.da.sv_433 lv.sv..._660
  // [1390]
  0x06000223, 0x0f008c09, 0x43001412, 0x22181008,   // da.de..._880 ht.es..._440 is.vi..._640 sv.hu.tr_443
  0x22001808, 0x08001614, 0x38000d09, 0x1e008c14,   // hu.tr..._430 lt.it..._660 pt.ca..._440 ht.sr..._660
  0x18450d12, 0x12144502, 0x27023808, 0x19001609,   // pt.sk.hu_654 sk.is.cs_222 ca.da.id_443 lt.et..._440
  0x17000823, 0x12451814, 0x8c000c1d, 0x12451808,   // it.ro..._880 hu.sk.cs_666 pl.ht..._820 hu.sk.cs_443
  // [13a0]
  0x1e252314, 0x0000452d, 0x1f011a08, 0x4b001d02,   // uk.mk.sr_666 sk......_A00 xxx.en.ga_443 hr.az..._220
  0x4b162207, 0x124518af, 0x0c451214, 0x0c002109,   // tr.lt.az_432 hu.sk.cs_655 cs.sk.pl_666 tl.pl..._440
  0x18380f08, 0x05001202, 0x12184514, 0x1f0f1809,   // es.ca.hu_443 cs.fr..._220 sk.hu.cs_666 hu.es.ga_444
  0x38000f07, 0x0f183814, 0x12451802, 0x12000409,   // es.ca..._420 ca.hu.es_666 hu.sk.cs_222 fi.cs..._440
  // [13b0]
  0x18003811, 0x16002114, 0x1f002b22, 0x12000413,   // ca.hu..._630 tl.lt..._660 cy.ga..._870 fi.cs..._650
  0x192716a4, 0x45000f11, 0x1d1708a4, 0x66004014,   // lt.id.et_433 es.sk..._630 it.ro.hr_433 sl.af..._660
  0x10001207, 0x221d45a4, 0x03001702, 0x3f0c2109,   // cs.sv..._420 sk.hr.tr_433 ro.nl..._220 tl.pl.sw_444
  0x18026608, 0x17001609, 0x270f2102, 0x21000802,   // af.da.hu_443 lt.ro..._440 tl.es.id_222 it.tl..._220
  // [13c0]
  0x8c211660, 0x02182b07, 0x120c4509, 0x181f0f09,   // lt.tl.ht_664 cy.hu.da_432 sk.pl.cs_444 es.ga.hu_444
  0x16004012, 0x182b0d55, 0x08003807, 0x45001221,   // sl.lt..._640 pt.cy.hu_442 ca.it..._420 cs.sk..._860
  0x401e1209, 0x3f002121, 0x08003813, 0x21003f08,   // cs.sr.sl_444 tl.sw..._860 ca.it..._650 sw.tl..._430
  0x1d404202, 0x01292708, 0x1d3f1e02, 0x1d154002,   // mt.sl.hr_222 id.ms.en_443 sr.sw.hr_222 sl.lv.hr_222
  // [13d0]
  0x0f083860, 0x3a036608, 0x02003a02, 0x17004314,   // ca.it.es_664 af.nl.eu_443 eu.da..._220 vi.ro..._660
  0x140d0f13, 0x1e1d2702, 0x2b002202, 0x08000413,   // es.pt.is_665 id.hr.sr_222 tr.cy..._220 fi.it..._650
  0x1f001902, 0x334e3711, 0x2e0d3855, 0x19000c02,   // et.ga..._220 ar.fa.ur_653 ca.pt.sq_442 pl.et..._220
  0x40000213, 0x27001409, 0x14000621, 0x3f001814,   // da.sl..._650 is.id..._440 de.is..._860 hu.sw..._660
  // [13e0]
  0x661a0209, 0x3f004209, 0x03660107, 0x2e380d07,   // da.xxx.af_444 mt.sw..._440 en.af.nl_432 pt.ca.sq_432
  0x14003a02, 0x0d063814, 0x21001523, 0x251e1c14,   // eu.is..._220 ca.de.pt_666 lv.tl..._880 bg.sr.mk_666
  0x0b022ea4, 0x1c231e13, 0x10000309, 0x10002707,   // sq.da.no_433 sr.uk.bg_665 nl.sv..._440 id.sv..._420
  0x43000123, 0x05088ca4, 0x3a001009, 0x29182702,   // en.vi..._880 ht.it.fr_433 sv.eu..._440 id.hu.ms_222
  // [13f0]
  0x42000823, 0x1d000c08, 0x38000813, 0x18001f22,   // it.mt..._880 pl.hr..._430 it.ca..._650 ga.hu..._870
  0x18001209, 0x14001812, 0x05000d08, 0x45002b14,   // cs.hu..._440 hu.is..._640 pt.fr..._430 cy.sk..._660
  0x2b004523, 0x1d000c12, 0x1a2b4555, 0x1d1e0c12,   // sk.cy..._880 pl.hr..._640 sk.cy.xxx_442 pl.sr.hr_654
  0x0d2b4507, 0x27000802, 0x29036612, 0x42380808,   // sk.cy.pt_432 it.id..._220 af.nl.ms_654 it.ca.mt_443

  // [1400]
  0x0c3a03af, 0x38004509, 0x22001414, 0x18001714,   // nl.eu.pl_655 sk.ca..._440 is.tr..._660 ro.hu..._660
  0x66001623, 0x38003f13, 0x38001209, 0x8c000f09,   // lt.af..._880 sw.ca..._650 cs.ca..._440 es.ht..._440
  0x0d000202, 0x660b03a4, 0x0c380d09, 0x01001f08,   // da.pt..._220 nl.no.af_433 pt.ca.pl_444 ga.en..._430
  0x06400109, 0x0d1e1aa4, 0x0d0f18a4, 0x12001812,   // en.sl.de_444 xxx.sr.pt_433 hu.es.pt_433 hu.cs..._640
  // [1410]
  0x06171209, 0x1f051612, 0x291e1a07, 0x03001014,   // cs.ro.de_444 lt.fr.ga_654 xxx.sr.ms_432 sv.nl..._660
  0x45000402, 0x45120b09, 0x18001208, 0x45193a02,   // fi.sk..._220 no.cs.sk_444 cs.hu..._430 eu.et.sk_222
  0x230e1eaf, 0x2b002923, 0x10001402, 0x45001009,   // sr.ru.uk_655 ms.cy..._880 is.sv..._220 sv.sk..._440
  0x1a002409, 0x08001a23, 0x21182ba4, 0x2b002123,   // hi.xxx..._440 xxx.it..._880 cy.hu.tl_433 tl.cy..._880
  // [1420]
  0x4b223f08, 0x2b451207, 0x15001802, 0x17003f13,   // sw.tr.az_443 cs.sk.cy_432 hu.lv..._220 sw.ro..._650
  0x17003a08, 0x3f000814, 0x173f1a08, 0x14190411,   // eu.ro..._430 it.sw..._660 xxx.sw.ro_443 fi.et.is_653
  0x18008c14, 0x17000d07, 0x14006612, 0x19002b23,   // ht.hu..._660 pt.ro..._420 af.is..._640 cy.et..._880
  0x1c001e09, 0x212b2909, 0x08003a09, 0x0e1c30a4,   // sr.bg..._440 ms.cy.tl_444 eu.it..._440 be.bg.ru_433
  // [1430]
  0x1f001814, 0x1d001802, 0x20000d21, 0x21000f14,   // hu.ga..._660 hu.hr..._220 pt.gl..._860 es.tl..._660
  0x451e1d13, 0x451e1d60, 0x18211012, 0x01002714,   // hr.sr.sk_665 hr.sr.sk_664 sv.tl.hu_654 id.en..._660
  0x181e1d14, 0x21002014, 0x45001823, 0x29042755,   // hr.sr.hu_666 gl.tl..._660 hu.sk..._880 id.fi.ms_442
  0x18191014, 0x19001614, 0x0b001023, 0x08000208,   // sv.et.hu_666 lt.et..._660 sv.no..._880 da.it..._430
  // [1440]
  0x03000602, 0x38001414, 0x10000113, 0x40001208,   // de.nl..._220 is.ca..._660 en.sv..._650 cs.sl..._430
  0x27002921, 0x45001f09, 0x14001f02, 0x1e001c23,   // ms.id..._860 ga.sk..._440 ga.is..._220 bg.sr..._880
  0x3f001923, 0x04002109, 0x03066608, 0x2b001013,   // et.sw..._880 tl.fi..._440 af.de.nl_443 sv.cy..._650
  0x17001e02, 0x42008c02, 0x03196602, 0x45001e09,   // sr.ro..._220 ht.mt..._220 af.et.nl_222 sr.sk..._440
  // [1450]
  0x3f4b1a09, 0x21272913, 0x010610a4, 0x38002914,   // xxx.az.sw_444 ms.id.tl_665 sv.de.en_433 ms.ca..._660
  0x27002202, 0x04000812, 0x29423a02, 0x45401e02,   // tr.id..._220 it.fi..._640 eu.mt.ms_222 sr.sl.sk_222
  0x3a020b12, 0x01000c02, 0x292e2702, 0x27003f12,   // no.da.eu_654 pl.en..._220 id.sq.ms_222 sw.id..._640
  0x22001014, 0x2e003802, 0x45001e02, 0x1e3f0402,   // sv.tr..._660 ca.sq..._220 sr.sk..._220 fi.sw.sr_222
  // [1460]
  0x2e003809, 0x1d2e3808, 0x22001913, 0x27212909,   // ca.sq..._440 ca.sq.hr_443 et.tr..._650 ms.tl.id_444
  0x10002202, 0x12001813, 0x27000808, 0x38000812,   // tr.sv..._220 hu.cs..._650 it.id..._430 it.ca..._640
  0x0f000107, 0x04000609, 0x1c0e30af, 0x8c000512,   // en.es..._420 de.fi..._440 be.ru.bg_655 fr.ht..._640
  0x06002102, 0x272221a4, 0x4b1d1e13, 0x22001912,   // tl.de..._220 tl.tr.id_433 sr.hr.az_665 et.tr..._640
  // [1470]
  0x1d404502, 0x8c000d07, 0x45001613, 0x3f000202,   // sk.sl.hr_222 pt.ht..._420 lt.sk..._650 da.sw..._220
  0x0c3a2e08, 0x8c003f13, 0x3f004b13, 0x10051a07,   // sq.eu.pl_443 sw.ht..._650 az.sw..._650 xxx.fr.sv_432
  0x15001209, 0x18150455, 0x023f18a4, 0x18211008,   // cs.lv..._440 fi.lv.hu_442 hu.sw.da_433 sv.tl.hu_443
  0x660306a4, 0x3f1a8c12, 0x0f001814, 0x8c000508,   // de.nl.af_433 ht.xxx.sw_654 hu.es..._660 fr.ht..._430
  // [1480]
  0x3a4b3808, 0x15001823, 0x061a0108, 0x18003f23,   // ca.az.eu_443 hu.lv..._880 en.xxx.de_443 sw.hu..._880
  0x0b001814, 0x191a1509, 0x29001f12, 0x19001509,   // hu.no..._660 lv.xxx.et_444 ga.ms..._640 lv.et..._440
  0x27293808, 0x04001a09, 0x2b000f02, 0x10183a07,   // ca.ms.id_443 xxx.fi..._440 es.cy..._220 eu.hu.sv_432
  0x02002014, 0x100b0107, 0x21001714, 0x8c001602,   // gl.da..._660 en.no.sv_432 ro.tl..._660 lt.ht..._220
  // [1490]
  0x0c2b8c09, 0x06041955, 0x0d002707, 0x10004509,   // ht.cy.pl_444 et.fi.de_442 id.pt..._420 sk.sv..._440
  0x12011a02, 0x45426602, 0x0c002b13, 0x3f212907,   // xxx.en.cs_222 af.mt.sk_222 cy.pl..._650 ms.tl.sw_432
  0x27291d02, 0x293f2102, 0x3a002114, 0x123a4502,   // hr.ms.id_222 tl.sw.ms_222 tl.eu..._660 sk.eu.cs_222
  0x45180f02, 0x0c001d23, 0x02002109, 0x22001702,   // es.hu.sk_222 hr.pl..._880 tl.da..._440 ro.tr..._220
  // [14a0]
  0x12001514, 0x151e1d55, 0x45120ca4, 0x06160f02,   // lv.cs..._660 hr.sr.lv_442 pl.cs.sk_433 es.lt.de_222
  0x4b8c2e12, 0x1a003f13, 0x45000c09, 0x06000408,   // sq.ht.az_654 sw.xxx..._650 pl.sk..._440 fi.de..._430
  0x1d452e02, 0x3a001823, 0x450d1207, 0x14004313,   // sq.sk.hr_222 hu.eu..._880 cs.pt.sk_432 vi.is..._650
  0x05001902, 0x27001a02, 0x0c004522, 0x1f190109,   // et.fr..._220 xxx.id..._220 sk.pl..._870 en.et.ga_444
  // [14b0]
  0x182b1a12, 0x01003a08, 0x4b008c02, 0x0b000502,   // xxx.cy.hu_654 eu.en..._430 ht.az..._220 fr.no..._220
  0x06001423, 0x03192baf, 0x1e1d0102, 0x43001208,   // is.de..._880 cy.et.nl_655 en.hr.sr_222 cs.vi..._430
  0x05450c08, 0x29001923, 0x1e004509, 0x0d008c23,   // pl.sk.fr_443 et.ms..._880 sk.sr..._440 ht.pt..._880
  0x2e100807, 0x1e302560, 0x22188ca4, 0x182e8c09,   // it.sv.sq_432 mk.be.sr_664 ht.hu.tr_433 ht.sq.hu_444
  // [14c0]
  0x1a006613, 0x03000213, 0x1f420307, 0x29000609,   // af.xxx..._650 da.nl..._650 nl.mt.ga_432 de.ms..._440
  0x06100411, 0x10040614, 0x12002902, 0x1a001709,   // fi.sv.de_653 de.fi.sv_666 ms.cs..._220 ro.xxx..._440
  0x453a0302, 0x22000614, 0x2b4b0109, 0x17160109,   // nl.eu.sk_222 de.tr..._660 en.az.cy_444 en.lt.ro_444
  0x16001f02, 0x15161a09, 0x2e002202, 0x45151660,   // ga.lt..._220 xxx.lt.lv_444 tr.sq..._220 lt.lv.sk_664
  // [14d0]
  0x18222907, 0x1c0e3009, 0x3f006614, 0x0b006609,   // ms.tr.hu_432 be.ru.bg_444 af.sw..._660 af.no..._440
  0x0c004023, 0x401d1e14, 0x03060107, 0x22002907,   // sl.pl..._880 sr.hr.sl_666 en.de.nl_432 ms.tr..._420
  0x04001023, 0x0c001709, 0x1d0c4002, 0x14450d11,   // sv.fi..._880 ro.pl..._440 sl.pl.hr_222 pt.sk.is_653
  0x200d0107, 0x231e0e14, 0x0c001e23, 0x1e1c0ea4,   // en.pt.gl_432 ru.sr.uk_666 sr.pl..._880 ru.bg.sr_433
  // [14e0]
  0x02000308, 0x45171402, 0x141f0614, 0x66001911,   // nl.da..._430 is.ro.sk_222 de.ga.is_666 et.af..._630
  0x06190455, 0x43011a09, 0x14008c13, 0x02002b08,   // fi.et.de_442 xxx.en.vi_444 ht.is..._650 cy.da..._430
  0x17004223, 0x0b142ba4, 0x29001909, 0x21002b13,   // mt.ro..._880 cy.is.no_433 et.ms..._440 cy.tl..._650
  0x25231ca4, 0x1a660308, 0x43451a09, 0x10060baf,   // bg.uk.mk_433 nl.af.xxx_443 xxx.sk.vi_444 no.de.sv_655
  // [14f0]
  0x29192702, 0x21000d02, 0x2b001823, 0x10060408,   // id.et.ms_222 pt.tl..._220 hu.cy..._880 fi.de.sv_443
  0x04000102, 0x082b0214, 0x45038c02, 0x21001914,   // en.fi..._220 da.cy.it_666 ht.nl.sk_222 et.tl..._660
  0x1d1e16a4, 0x00000101, 0x06140b07, 0x43020b60,   // lt.sr.hr_433 en......_200 no.is.de_432 no.da.vi_664
  0x036621a4, 0x1d000b11, 0x22004213, 0x02000d09,   // tl.af.nl_433 no.hr..._630 mt.tr..._650 pt.da..._440
  // [1500]
  0x03002212, 0x12004013, 0x1d000b09, 0x2b004309,   // tr.nl..._640 sl.cs..._650 no.hr..._440 vi.cy..._440
  0x40001202, 0x0d380f09, 0x2b000209, 0x0c001702,   // cs.sl..._220 es.ca.pt_444 da.cy..._440 ro.pl..._220
  0x1e230e55, 0x1a003f11, 0x22001522, 0x06033f09,   // ru.uk.sr_442 sw.xxx..._630 lv.tr..._870 sw.nl.de_444
  0x29001009, 0x1e1d0c09, 0x19001008, 0x2e210109,   // sv.ms..._440 pl.hr.sr_444 sv.et..._430 en.tl.sq_444
  // [1510]
  0x27000107, 0x21002e02, 0x3f452e08, 0x2e001214,   // en.id..._420 sq.tl..._220 sq.sk.sw_443 cs.sq..._660
  0x1e0c0b07, 0x06004214, 0x450c2708, 0x8c0b1412,   // no.pl.sr_432 mt.de..._660 id.pl.sk_443 is.no.ht_654
  0x66050355, 0x8c003f08, 0x17004514, 0x2e001223,   // nl.fr.af_442 sw.ht..._430 sk.ro..._660 cs.sq..._880
  0x0e1e2508, 0x12003a02, 0x8c002e23, 0x172e0109,   // mk.sr.ru_443 eu.cs..._220 sq.ht..._880 en.sq.ro_444
  // [1520]
  0x1e1d1513, 0x21000f08, 0x224b16a4, 0x231c0e13,   // lv.hr.sr_665 es.tl..._430 lt.az.tr_433 ru.bg.uk_665
  0x42008c14, 0x1e1d21af, 0x0f002014, 0x293a4b07,   // ht.mt..._660 tl.hr.sr_655 gl.es..._660 az.eu.ms_432
  0x02003a13, 0x0d004202, 0x1d454012, 0x22002e02,   // eu.da..._650 mt.pt..._220 sl.sk.hr_654 sq.tr..._220
  0x06001011, 0x20002223, 0x27163f02, 0x02001a02,   // sv.de..._630 tr.gl..._880 sw.lt.id_222 xxx.da..._220
  // [1530]
  0x0c001413, 0x1d401e09, 0x212729a4, 0x21003a12,   // is.pl..._650 sr.sl.hr_444 ms.id.tl_433 eu.tl..._640
  0x25002313, 0x21292713, 0x231c2560, 0x08000102,   // uk.mk..._650 id.ms.tl_665 mk.bg.uk_664 en.it..._220
  0x08143a02, 0x18451208, 0x08002202, 0x1c251e55,   // eu.is.it_222 cs.sk.hu_443 tr.it..._220 sr.mk.bg_442
  0x05003813, 0x38000d13, 0x03000d08, 0x18001512,   // ca.fr..._650 pt.ca..._650 pt.nl..._430 lv.hu..._640
  // [1540]
  0x1d191402, 0x17000309, 0x0f0d14a4, 0x10001502,   // is.et.hr_222 nl.ro..._440 is.pt.es_433 lv.sv..._220
  0x4b002102, 0x042118a4, 0x43002913, 0x1d0c1e02,   // tl.az..._220 hu.tl.fi_433 ms.vi..._650 sr.pl.hr_222
  0x0e251c12, 0x3f1f4209, 0x021d1e09, 0x180f3808,   // bg.mk.ru_654 mt.ga.sw_444 sr.hr.da_444 ca.es.hu_443
  0x15002914, 0x1d004523, 0x101a06a4, 0x10003f02,   // ms.lv..._660 sk.hr..._880 de.xxx.sv_433 sw.sv..._220
  // [1550]
  0x27182908, 0x45000c22, 0x0c452b13, 0x40001914,   // ms.hu.id_443 pl.sk..._870 cy.sk.pl_665 et.sl..._660
  0x2e421708, 0x1d001809, 0x12004014, 0x450c2ba4,   // ro.mt.sq_443 hu.hr..._440 sl.cs..._660 cy.pl.sk_433
  0x180366a4, 0x40000b12, 0x18003812, 0x40000609,   // af.nl.hu_433 no.sl..._640 ca.hu..._640 de.sl..._440
  0x43004509, 0x4b292209, 0x10000611, 0x06041013,   // sk.vi..._440 tr.ms.az_444 de.sv..._630 sv.fi.de_665
  // [1560]
  0x02008c02, 0x23300e08, 0x0c001002, 0x21042908,   // ht.da..._220 ru.be.uk_443 sv.pl..._220 ms.fi.tl_443
  0x45030608, 0x02000b12, 0x18008c02, 0x2b001714,   // de.nl.sk_443 no.da..._640 ht.hu..._220 ro.cy..._660
  0x2b001023, 0x66002909, 0x3a000b14, 0x42004513,   // sv.cy..._880 ms.af..._440 no.eu..._660 sk.mt..._650
  0x38058c08, 0x08000f23, 0x01001f23, 0x8c004309,   // ht.fr.ca_443 es.it..._880 ga.en..._880 vi.ht..._440
  // [1570]
  0x04001a14, 0x0b141f08, 0x1d124508, 0x14001f13,   // xxx.fi..._660 ga.is.no_443 sk.cs.hr_443 ga.is..._650
  0x1f030614, 0x01003f02, 0x2b000413, 0x29272102,   // de.nl.ga_666 sw.en..._220 fi.cy..._650 tl.id.ms_222
  0x8c002213, 0x16000c21, 0x15191809, 0x230e2507,   // tr.ht..._650 pl.lt..._860 hu.et.lv_444 mk.ru.uk_432
  0x1a000413, 0x1f001a13, 0x16000f09, 0x14004507,   // fi.xxx..._650 xxx.ga..._650 es.lt..._440 sk.is..._420
  // [1580]
  0x18001214, 0x1d451207, 0x18000614, 0x2e001914,   // cs.hu..._660 cs.sk.hr_432 de.hu..._660 et.sq..._660
  0x27292002, 0x0e1e2314, 0x16150f07, 0x1d0b2202,   // gl.ms.id_222 uk.sr.ru_666 es.lv.lt_432 tr.no.hr_222
  0x1a000f02, 0x15000d14, 0x38004202, 0x140f3808,   // es.xxx..._220 pt.lv..._660 mt.ca..._220 ca.es.is_443
  0x1e230eaf, 0x01001a12, 0x30251e14, 0x14000214,   // ru.uk.sr_655 xxx.en..._640 sr.mk.be_666 da.is..._660
  // [1590]
  0x14296608, 0x18002909, 0x1e1c2507, 0x21660208,   // af.ms.is_443 ms.hu..._440 mk.bg.sr_432 da.af.tl_443
  0x06000c14, 0x8c000f02, 0x0d002002, 0x1d383aa4,   // pl.de..._660 es.ht..._220 gl.pt..._220 eu.ca.hr_433
  0x04100660, 0x1d001013, 0x030615af, 0x14000312,   // de.sv.fi_664 sv.hr..._650 lv.de.nl_655 nl.is..._640
  0x01000d08, 0x01003f23, 0x0f200d60, 0x38000808,   // pt.en..._430 sw.en..._880 pt.gl.es_664 it.ca..._430
  // [15a0]
  0x0f0d4514, 0x0f001f13, 0x1d000102, 0x05000d09,   // sk.pt.es_666 ga.es..._650 en.hr..._220 pt.fr..._440
  0x8c000107, 0x0d001623, 0x06000323, 0x140b1012,   // en.ht..._420 lt.pt..._880 nl.de..._880 sv.no.is_654
  0x010d0508, 0x3a000214, 0x19000308, 0x38000f12,   // fr.pt.en_443 da.eu..._660 nl.et..._430 es.ca..._640
  0x0d001608, 0x45001e08, 0x08003823, 0x03000b08,   // lt.pt..._430 sr.sk..._430 ca.it..._880 no.nl..._430
  // [15b0]
  0x044b2221, 0x12450c12, 0x40000302, 0x10000b13,   // tr.az.fi_876 pl.sk.cs_654 nl.sl..._220 no.sv..._650
  0x1e1d0602, 0x04191614, 0x020b1413, 0x18002113,   // de.hr.sr_222 lt.et.fi_666 is.no.da_665 tl.hu..._650
  0x66100609, 0x103a29af, 0x2b036612, 0x1c253012,   // de.sv.af_444 ms.eu.sv_655 af.nl.cy_654 be.mk.bg_654
  0x1d121e02, 0x06660360, 0x29062709, 0x19043aa4,   // sr.cs.hr_222 nl.af.de_664 id.de.ms_444 eu.fi.et_433
  // [15c0]
  0x193a0408, 0x140b0109, 0x3f068c02, 0x8c062102,   // fi.eu.et_443 en.no.is_444 ht.de.sw_222 tl.de.ht_222
  0x1c002512, 0x10000b12, 0x8c001f22, 0x1d000c09,   // mk.bg..._640 no.sv..._640 ga.ht..._870 pl.hr..._440
  0x66000b14, 0x03000f14, 0x271629a4, 0x4b221709,   // no.af..._660 es.nl..._660 ms.lt.id_433 ro.tr.az_444
  0x27141802, 0x3a000b09, 0x45024202, 0x301e0e09,   // hu.is.id_222 no.eu..._440 mt.da.sk_222 ru.sr.be_444
  // [15d0]
  0x03066613, 0x210c4208, 0x27003a23, 0x42002e08,   // af.de.nl_665 mt.pl.tl_443 eu.id..._880 sq.mt..._430
  0x06000813, 0x0f181f13, 0x19002e02, 0x1e1d12a4,   // it.de..._650 ga.hu.es_665 sq.et..._220 cs.hr.sr_433
  0x45008c14, 0x061d0fa4, 0x1a3f8c09, 0x45003a08,   // ht.sk..._660 es.hr.de_433 ht.sw.xxx_444 eu.sk..._430
  0x3f002209, 0x4e373307, 0x08008c13, 0x29002202,   // tr.sw..._440 ur.ar.fa_432 ht.it..._650 tr.ms..._220
  // [15e0]
  0x43001a14, 0x08008c09, 0x380f0d12, 0x45000f09,   // xxx.vi..._660 ht.it..._440 pt.es.ca_654 es.sk..._440
  0x18100109, 0x45000f14, 0x14000d13, 0x1d002e08,   // en.sv.hu_444 es.sk..._660 pt.is..._650 sq.hr..._430
  0x031a8c08, 0x45180f55, 0x18003a09, 0x4b004021,   // ht.xxx.nl_443 es.hu.sk_442 eu.hu..._440 sl.az..._860
  0x174b2260, 0x17003a09, 0x38002714, 0x03002e02,   // tr.az.ro_664 eu.ro..._440 id.ca..._660 sq.nl..._220
  // [15f0]
  0x22003a23, 0x0f002021, 0x0d058c08, 0x183f1a09,   // eu.tr..._880 gl.es..._860 ht.fr.pt_443 xxx.sw.hu_444
  0x0c003f02, 0x02001022, 0x45061202, 0x1d1e0d02,   // sw.pl..._220 sv.da..._870 cs.de.sk_222 pt.sr.hr_222
  0x15003a02, 0x453a1802, 0x173f1aa4, 0x8c002914,   // eu.lv..._220 hu.eu.sk_222 xxx.sw.ro_433 ms.ht..._660
  0x1d401902, 0x213f16af, 0x08224b60, 0x02000313,   // et.sl.hr_222 lt.sw.tl_655 az.tr.it_664 nl.da..._650
  // [1600]
  0x1e000b09, 0x1a000609, 0x1c302308, 0x0b000402,   // no.sr..._440 de.xxx..._440 uk.be.bg_443 fi.no..._220
  0x38170514, 0x660c4509, 0x1e003012, 0x06004202,   // fr.ro.ca_666 sk.pl.af_444 be.sr..._640 mt.de..._220
  0x0d1f4511, 0x1d001914, 0x38001712, 0x1f000802,   // sk.ga.pt_653 et.hr..._660 ro.ca..._640 it.ga..._220
  0x03062709, 0x43006609, 0x04002b12, 0x27192102,   // id.de.nl_444 af.vi..._440 cy.fi..._640 tl.et.id_222
  // [1610]
  0x04001f09, 0x04272912, 0x0d004302, 0x66001709,   // ga.fi..._440 ms.id.fi_654 vi.pt..._220 ro.af..._440
  0x06188c08, 0x17081809, 0x21001d23, 0x66003802,   // ht.hu.de_443 hu.it.ro_444 hr.tl..._880 ca.af..._220
  0x1c002521, 0x3a000412, 0x40002923, 0x1e001722,   // mk.bg..._860 fi.eu..._640 ms.sl..._880 ro.sr..._870
  0x17000214, 0x01001f12, 0x011f1a09, 0x3f001f14,   // da.ro..._660 ga.en..._640 xxx.ga.en_444 ga.sw..._660
  // [1620]
  0x1e1d12af, 0x02001a08, 0x3a000413, 0x06001708,   // cs.hr.sr_655 xxx.da..._430 fi.eu..._650 ro.de..._430
  0x01003a02, 0x2b001f14, 0x03000622, 0x45010802,   // eu.en..._220 ga.cy..._660 de.nl..._870 it.en.sk_222
  0x15002b13, 0x173f1a09, 0x4b3f2207, 0x450d8c08,   // cy.lv..._650 xxx.sw.ro_444 tr.sw.az_432 ht.pt.sk_443
  0x2b001821, 0x3a000309, 0x10020107, 0x38001821,   // hu.cy..._860 nl.eu..._440 en.da.sv_432 hu.ca..._860
  // [1630]
  0x433a8c08, 0x00008c42, 0x17000f14, 0x1f152b08,   // ht.eu.vi_443 ht......_C00 es.ro..._660 cy.lv.ga_443
  0x3a004509, 0x8c003a14, 0x3f272912, 0x22000309,   // sk.eu..._440 eu.ht..._660 ms.id.sw_654 nl.tr..._440
  0x2e004b13, 0x1e002902, 0x16001702, 0x27222908,   // az.sq..._650 ms.sr..._220 ro.lt..._220 ms.tr.id_443
  0x22002102, 0x12454b02, 0x140b2baf, 0x143f2e07,   // tl.tr..._220 az.sk.cs_222 cy.no.is_655 sq.sw.is_432
  // [1640]
  0x27003a14, 0x231c2507, 0x06001402, 0x14008c02,   // eu.id..._660 mk.bg.uk_432 is.de..._220 ht.is..._220
  0x141f8c13, 0x18003a12, 0x3a001402, 0x0b108c09,   // ht.ga.is_665 eu.hu..._640 is.eu..._220 ht.sv.no_444
  0x14008c14, 0x1e000e08, 0x16001f13, 0x1f000602,   // ht.is..._660 ru.sr..._430 ga.lt..._650 de.ga..._220
  0x0d0f4009, 0x2e000b09, 0x19000509, 0x1a004502,   // sl.es.pt_444 no.sq..._440 fr.et..._440 sk.xxx..._220
  // [1650]
  0x03026608, 0x45001a02, 0x03001414, 0x06191009,   // af.da.nl_443 xxx.sk..._220 is.nl..._660 sv.et.de_444
  0x14001d14, 0x10000509, 0x45006614, 0x12450660,   // hr.is..._660 fr.sv..._440 af.sk..._660 de.sk.cs_664
  0x3f001809, 0x42002909, 0x2b001923, 0x30230e60,   // hu.sw..._440 ms.mt..._440 et.cy..._880 ru.uk.be_664
  0x2b420107, 0x42200107, 0x22001802, 0x19180d08,   // en.mt.cy_432 en.gl.mt_432 hu.tr..._220 pt.hu.et_443
  // [1660]
  0x290d0107, 0x03004202, 0x23001c14, 0x1c0e2509,   // en.pt.ms_432 mt.nl..._220 bg.uk..._660 mk.ru.bg_444
  0x04001421, 0x18000d14, 0x0e251c60, 0x453f0307,   // is.fi..._860 pt.hu..._660 bg.mk.ru_664 nl.sw.sk_432
  0x14102b12, 0x0c001602, 0x2b004012, 0x10002b20,   // cy.sv.is_654 lt.pl..._220 sl.cy..._640 cy.sv..._850
  0x25233009, 0x2e000114, 0x0f2e08a4, 0x2e004014,   // be.uk.mk_444 en.sq..._660 it.sq.es_433 sl.sq..._660
  // [1670]
  0x29001802, 0x0c1d1e07, 0x45400fa4, 0x102b04a4,   // hu.ms..._220 sr.hr.pl_432 es.sl.sk_433 fi.cy.sv_433
  0x1e001f22, 0x4b001f13, 0x29271402, 0x012b2908,   // ga.sr..._870 ga.az..._650 is.id.ms_222 ms.cy.en_443
  0x2b000414, 0x10003f09, 0x1d454002, 0x04003802,   // fi.cy..._660 sw.sv..._440 sl.sk.hr_222 ca.fi..._220
  0x19000107, 0x0f001802, 0x1d054002, 0x3a001d14,   // en.et..._420 hu.es..._220 sl.fr.hr_222 hr.eu..._660
  // [1680]
  0x04141007, 0x40272912, 0x1d102e02, 0x05001909,   // sv.is.fi_432 ms.id.sl_654 sq.sv.hr_222 et.fr..._440
  0x04000502, 0x1d000123, 0x38001802, 0x02001923,   // fr.fi..._220 en.hr..._880 hu.ca..._220 et.da..._880
  0x18000114, 0x2e000502, 0x2e000d02, 0x0c000123,   // en.hu..._660 fr.sq..._220 pt.sq..._220 en.pl..._880
  0x422b01a4, 0x1d1e3f02, 0x19003a23, 0x45191a02,   // en.cy.mt_433 sw.sr.hr_222 eu.et..._880 xxx.et.sk_222
  // [1690]
  0x45000d08, 0x293a1902, 0x3a004223, 0x0b001914,   // pt.sk..._430 et.eu.ms_222 mt.eu..._880 et.no..._660
  0x291d1902, 0x3a2e0107, 0x03000b14, 0x0f000514,   // et.hr.ms_222 en.sq.eu_432 no.nl..._660 fr.es..._660
  0x3a420107, 0x030b0208, 0x0d380107, 0x19001a13,   // en.mt.eu_432 da.no.nl_443 en.ca.pt_432 xxx.et..._650
  0x06002214, 0x080566a4, 0x1a001521, 0x8c000c14,   // tr.de..._660 af.fr.it_433 lv.xxx..._860 pl.ht..._660
  // [16a0]
  0x04146607, 0x423a38a4, 0x06030207, 0x38000802,   // af.is.fi_432 ca.eu.mt_433 da.nl.de_432 it.ca..._220
  0x45001623, 0x1e253009, 0x15000414, 0x14006609,   // lt.sk..._880 be.mk.sr_444 fi.lv..._660 af.is..._440
  0x29662709, 0x1c230e12, 0x0b001502, 0x0d004002,   // id.af.ms_444 ru.uk.bg_654 lv.no..._220 sl.pt..._220
  0x0d8c0107, 0x0f200d13, 0x15001414, 0x10000413,   // en.ht.pt_432 pt.gl.es_665 is.lv..._660 fi.sv..._650
  // [16b0]
  0x2b1a2108, 0x0d001a09, 0x0f380d09, 0x08002e14,   // tl.xxx.cy_443 xxx.pt..._440 pt.ca.es_444 sq.it..._660
  0x22002e09, 0x0f000d07, 0x1e003013, 0x45200f02,   // sq.tr..._440 pt.es..._420 be.sr..._650 es.gl.sk_222
  0x1f000f09, 0x0f001414, 0x08004523, 0x37003323,   // es.ga..._440 is.es..._660 sk.it..._880 ur.ar..._880
  0x191004a4, 0x45000c21, 0x0d0f0109, 0x43002e09,   // fi.sv.et_433 pl.sk..._860 en.es.pt_444 sq.vi..._440
  // [16c0]
  0x18450f09, 0x30230eaf, 0x18001908, 0x29003f02,   // es.sk.hu_444 ru.uk.be_655 et.hu..._430 sw.ms..._220
  0x25000e13, 0x1d003a09, 0x04000514, 0x17000414,   // ru.mk..._650 eu.hr..._440 fr.fi..._660 fi.ro..._660
  0x01060808, 0x08438c60, 0x0f003823, 0x43008c22,   // it.de.en_443 ht.vi.it_664 ca.es..._880 ht.vi..._870
  0x05002102, 0x088c4312, 0x121d1eaf, 0x2e162709,   // tl.fr..._220 vi.ht.it_654 sr.hr.cs_655 id.lt.sq_444
  // [16d0]
  0x1d004509, 0x401d1208, 0x43088c14, 0x8c000812,   // sk.hr..._440 cs.hr.sl_443 ht.it.vi_666 it.ht..._640
  0x43000202, 0x08002909, 0x40003f22, 0x14002b21,   // da.vi..._220 ms.it..._440 sw.sl..._870 cy.is..._860
  0x45003f14, 0x140d0f55, 0x273f2908, 0x04036612,   // sw.sk..._660 es.pt.is_442 ms.sw.id_443 af.nl.fi_654
  0x010f1a09, 0x40003f14, 0x450d0fa4, 0x08004202,   // xxx.es.en_444 sw.sl..._660 es.pt.sk_433 mt.it..._220
  // [16e0]
  0x230e1e09, 0x3f008c12, 0x05451207, 0x23251c09,   // sr.ru.uk_444 ht.sw..._640 cs.sk.fr_432 bg.mk.uk_444
  0x123f4502, 0x66000414, 0x0c020b09, 0x02002102,   // sk.sw.cs_222 fi.af..._660 no.da.pl_444 tl.da..._220
  0x0e002308, 0x45060208, 0x12001714, 0x18001902,   // uk.ru..._430 da.de.sk_443 ro.cs..._660 et.hu..._220
  0x18000209, 0x03006620, 0x19006612, 0x43003a07,   // da.hu..._440 af.nl..._850 af.et..._640 eu.vi..._420
  // [16f0]
  0x293f3a02, 0x4b001012, 0x451e3f02, 0x182e0b08,   // eu.sw.ms_222 sv.az..._640 sw.sr.sk_222 no.sq.hu_443
  0x1d2e2907, 0x2e002b09, 0x17001202, 0x03001823,   // ms.sq.hr_432 cy.sq..._440 cs.ro..._220 hu.nl..._880
  0x45000b02, 0x0f003813, 0x14003f09, 0x42002e11,   // no.sk..._220 ca.es..._650 sw.is..._440 sq.mt..._630
  0x228c3f12, 0x21001613, 0x27000414, 0x0f000508,   // sw.ht.tr_654 lt.tl..._650 fi.id..._660 fr.es..._430
  // [1700]
  0x2b001214, 0x1e004014, 0x03002902, 0x2b000402,   // cs.cy..._660 sl.sr..._660 ms.nl..._220 fi.cy..._220
  0x03000d14, 0x05004009, 0x01001f09, 0x292218a4,   // pt.nl..._660 sl.fr..._440 ga.en..._440 hu.tr.ms_433
  0x14004522, 0x8c000c08, 0x251c0e12, 0x27292102,   // sk.is..._870 pl.ht..._430 ru.bg.mk_654 tl.ms.id_222
  0x271e1d08, 0x14003a22, 0x02003f09, 0x4b043f07,   // hr.sr.id_443 eu.is..._870 sw.da..._440 sw.fi.az_432
  // [1710]
  0x15004023, 0x16151707, 0x120c4502, 0x4b152213,   // sl.lv..._880 ro.lv.lt_432 sk.pl.cs_222 tr.lv.az_665
  0x01061202, 0x18003809, 0x05000f13, 0x17002e14,   // cs.de.en_222 ca.hu..._440 es.fr..._650 sq.ro..._660
  0x00000f2d, 0x0d380f60, 0x10000423, 0x04451213,   // es......_A00 es.ca.pt_664 fi.sv..._880 cs.sk.fi_665
  0x45021202, 0x01291aaf, 0x1f004502, 0x66001812,   // cs.da.sk_222 xxx.ms.en_655 sk.ga..._220 hu.af..._640
  // [1720]
  0x22100612, 0x1a002102, 0x0f0d0514, 0x19002122,   // de.sv.tr_654 tl.xxx..._220 fr.pt.es_666 tl.et..._870
  0x12051f02, 0x8c003f07, 0x2b002223, 0x2e004009,   // ga.fr.cs_222 sw.ht..._420 tr.cy..._880 sl.sq..._440
  0x66001008, 0x05000d14, 0x1e2b1702, 0x0f001713,   // sv.af..._430 pt.fr..._660 ro.cy.sr_222 ro.es..._650
  0x06660307, 0x06036612, 0x020c2108, 0x1e000602,   // nl.af.de_432 af.nl.de_654 tl.pl.da_443 de.sr..._220
  // [1730]
  0x1a100b55, 0x3f008c22, 0x38008c02, 0x8c000802,   // no.sv.xxx_442 ht.sw..._870 ht.ca..._220 it.ht..._220
  0x230e3012, 0x011a4009, 0x0e251c13, 0x30230e55,   // be.ru.uk_654 sl.xxx.en_444 bg.mk.ru_665 ru.uk.be_442
  0x033a3fa4, 0x374e3308, 0x25002309, 0x27011402,   // sw.eu.nl_433 ur.fa.ar_443 uk.mk..._440 is.en.id_222
  0x14030608, 0x1d164502, 0x03061460, 0x1a000313,   // de.nl.is_443 sk.lt.hr_222 is.de.nl_664 nl.xxx..._650
  // [1740]
  0x1f002114, 0x10062b60, 0x02004202, 0x01008c23,   // tl.ga..._660 cy.de.sv_664 mt.da..._220 ht.en..._880
  0x04000614, 0x15164509, 0x08004309, 0x04004514,   // de.fi..._660 sk.lt.lv_444 vi.it..._440 sk.fi..._660
  0x18000d09, 0x17292708, 0x0f080d14, 0x08001713,   // pt.hu..._440 id.ms.ro_443 pt.it.es_666 ro.it..._650
  0x3f080107, 0x16006609, 0x1c233008, 0x293f2108,   // en.it.sw_432 af.lt..._440 be.uk.bg_443 tl.sw.ms_443
  // [1750]
  0x16002709, 0x2e1d1e09, 0x0c002e12, 0x43006621,   // id.lt..._440 sr.hr.sq_444 sq.pl..._640 af.vi..._860
  0x450f1a02, 0x1d000414, 0x18162b12, 0x16060455,   // xxx.es.sk_222 fi.hr..._660 cy.lt.hu_654 fi.de.lt_442
  0x0d664360, 0x04001502, 0x380f1f12, 0x45001709,   // vi.af.pt_664 lv.fi..._220 ga.es.ca_654 ro.sk..._440
  0x16000412, 0x43000d12, 0x04002b02, 0x29001709,   // fi.lt..._640 pt.vi..._640 cy.fi..._220 ro.ms..._440
  // [1760]
  0x3a001f08, 0x29042709, 0x17002b02, 0x3f190109,   // ga.eu..._430 id.fi.ms_444 cy.ro..._220 en.et.sw_444
  0x1c0e1e07, 0x29020ba4, 0x27000314, 0x171e1daf,   // sr.ru.bg_432 no.da.ms_433 nl.id..._660 hr.sr.ro_655
  0x45000309, 0x0e302311, 0x8c0d0512, 0x1e1d1560,   // nl.sk..._440 uk.be.ru_653 fr.pt.ht_654 lv.hr.sr_664
  0x160d0b09, 0x14000102, 0x8c001509, 0x14001502,   // no.pt.lt_444 en.is..._220 lv.ht..._440 lv.is..._220
  // [1770]
  0x16000f02, 0x200f0b09, 0x02000413, 0x160d0fa4,   // es.lt..._220 no.es.gl_444 fi.da..._650 es.pt.lt_433
  0x02211708, 0x01001814, 0x14000513, 0x03061560,   // ro.tl.da_443 hu.en..._660 fr.is..._650 lv.de.nl_664
  0x10061414, 0x45000f12, 0x8c000202, 0x42212e12,   // is.de.sv_666 es.sk..._640 da.ht..._220 sq.tl.mt_654
  0x3a004b14, 0x14000302, 0x10190612, 0x0f011a08,   // az.eu..._660 nl.is..._220 de.et.sv_654 xxx.en.es_443
  // [1780]
  0x451a0202, 0x19006623, 0x3f1f1808, 0x1f3f18a4,   // da.xxx.sk_222 af.et..._880 hu.ga.sw_443 hu.sw.ga_433
  0x2b006602, 0x40001923, 0x3a001a14, 0x19660313,   // af.cy..._220 et.sl..._880 xxx.eu..._660 nl.af.et_665
  0x03660808, 0x18452907, 0x04000314, 0x06001613,   // it.af.nl_443 ms.sk.hu_432 nl.fi..._660 lt.de..._650
  0x18003f13, 0x0e1c23af, 0x4b004214, 0x66002112,   // sw.hu..._650 uk.bg.ru_655 mt.az..._660 tl.af..._640
  // [1790]
  0x19141012, 0x293f1902, 0x18001702, 0x22001909,   // sv.is.et_654 et.sw.ms_222 ro.hu..._220 et.tr..._440
  0x3a002109, 0x1a000423, 0x42000602, 0x04000808,   // tl.eu..._440 fi.xxx..._880 de.mt..._220 it.fi..._430
  0x27000813, 0x293f2709, 0x04000209, 0x1e161d02,   // it.id..._650 id.sw.ms_444 da.fi..._440 hr.lt.sr_222
  0x45161702, 0x04660b07, 0x1e454002, 0x12450c08,   // ro.lt.sk_222 no.af.fi_432 sl.sk.sr_222 pl.sk.cs_443
  // [17a0]
  0x43180412, 0x2e662707, 0x29151612, 0x18294208,   // fi.hu.vi_654 id.af.sq_432 lt.lv.ms_654 mt.ms.hu_443
  0x0e1c2509, 0x18000212, 0x03002223, 0x19081708,   // mk.bg.ru_444 da.hu..._640 tr.nl..._880 ro.it.et_443
  0x38001814, 0x66004202, 0x19002923, 0x8c004302,   // hu.ca..._660 mt.af..._220 ms.et..._880 vi.ht..._220
  0x66001809, 0x43001809, 0x12001009, 0x2b271a08,   // hu.af..._440 hu.vi..._440 sv.cs..._440 xxx.id.cy_443
  // [17b0]
  0x21001802, 0x1e1c0e12, 0x08001708, 0x27001708,   // hu.tl..._220 ru.bg.sr_654 ro.it..._430 ro.id..._430
  0x19002b09, 0x1d194509, 0x1d1e1208, 0x4b004221,   // cy.et..._440 sk.et.hr_444 cs.sr.hr_443 mt.az..._860
  0x3f001908, 0x23002512, 0x160f0d13, 0x16000f12,   // et.sw..._430 mk.uk..._640 pt.es.lt_665 es.lt..._640
  0x1c000e11, 0x224b3aaf, 0x0e251caf, 0x45151260,   // ru.bg..._630 eu.az.tr_655 bg.mk.ru_655 cs.lv.sk_664
  // [17c0]
  0x01052b60, 0x21001609, 0x1e40455e, 0x230e3060,   // cy.fr.en_664 lt.tl..._440 sk.sl.sr_652 be.ru.uk_664
  0x04061009, 0x19100408, 0x19000314, 0x141006a4,   // sv.de.fi_444 fi.sv.et_443 nl.et..._660 de.sv.is_433
  0x0f450b07, 0x18001602, 0x29002123, 0x14002002,   // no.sk.es_432 lt.hu..._220 tl.ms..._880 gl.is..._220
  0x06660312, 0x4b000514, 0x04002113, 0x45008c02,   // nl.af.de_654 fr.az..._660 tl.fi..._650 ht.sk..._220
  // [17d0]
  0x1e1d1255, 0x22000612, 0x0d381a08, 0x45003823,   // cs.hr.sr_442 de.tr..._640 xxx.ca.pt_443 ca.sk..._880
  0x22002014, 0x45050102, 0x2e002207, 0x15001413,   // gl.tr..._660 en.fr.sk_222 tr.sq..._420 is.lv..._650
  0x12004008, 0x06224b13, 0x1e0e2308, 0x02100b60,   // sl.cs..._430 az.tr.de_665 uk.ru.sr_443 no.sv.da_664
  0x15001621, 0x42002222, 0x27292160, 0x3f000d08,   // lt.lv..._860 tr.mt..._870 tl.ms.id_664 pt.sw..._430
  // [17e0]
  0x0d001609, 0x04031907, 0x1e163f02, 0x04036609,   // lt.pt..._440 et.nl.fi_432 sw.lt.sr_222 af.nl.fi_444
  0x0b001713, 0x01002113, 0x1e000308, 0x1f003f12,   // ro.no..._650 tl.en..._650 nl.sr..._430 sw.ga..._640
  0x222729a4, 0x1c002309, 0x38001922, 0x1e1d16af,   // ms.id.tr_433 uk.bg..._440 et.ca..._870 lt.hr.sr_655
  0x16010208, 0x06191012, 0x19004b02, 0x1e1d1709,   // da.en.lt_443 sv.et.de_654 az.et..._220 ro.hr.sr_444
  // [17f0]
  0x29001508, 0x02004009, 0x10001809, 0x08001e14,   // lv.ms..._430 sl.da..._440 hu.sv..._440 sr.it..._660
  0x42000809, 0x0f0d1f12, 0x29001902, 0x04000602,   // it.mt..._440 ga.pt.es_654 et.ms..._220 de.fi..._220
  0x18000808, 0x19000421, 0x0e233060, 0x451d1702,   // it.hu..._430 fi.et..._860 be.uk.ru_664 ro.hr.sk_222
  0x10190411, 0x0000402d, 0x14001a08, 0x03001207,   // fi.et.sv_653 sl......_A00 xxx.is..._430 cs.nl..._420

  // [1800]
  0x38001723, 0x1f001409, 0x19002e09, 0x0f3f2109,   // ro.ca..._880 is.ga..._440 sq.et..._440 tl.sw.es_444
  0x3a000b02, 0x4b221714, 0x0d003a09, 0x183a1207,   // no.eu..._220 ro.tr.az_666 eu.pt..._440 cs.eu.hu_432
  0x101738af, 0x12000423, 0x16000813, 0x21000113,   // ca.ro.sv_655 fi.cs..._880 it.lt..._650 en.tl..._650
  0x29003a12, 0x0b003a22, 0x4b041aad, 0x06004211,   // eu.ms..._640 eu.no..._870 xxx.fi.az_643 mt.de..._630
  // [1810]
  0x02006608, 0x01002202, 0x0d004b14, 0x1d121509,   // af.da..._430 tr.en..._220 az.pt..._660 lv.cs.hr_444
  0x06000523, 0x05002909, 0x21001923, 0x14002b12,   // fr.de..._880 ms.fr..._440 et.tl..._880 cy.is..._640
  0x66001e09, 0x0f001808, 0x16002123, 0x21002907,   // sr.af..._440 hu.es..._430 tl.lt..._880 ms.tl..._420
  0x10001f09, 0x06001a14, 0x1d003f23, 0x0e302307,   // ga.sv..._440 xxx.de..._660 sw.hr..._880 uk.be.ru_432
  // [1820]
  0x27004309, 0x17000b23, 0x1e0e3013, 0x1f180f08,   // vi.id..._440 no.ro..._880 be.ru.sr_665 es.hu.ga_443
  0x0d004209, 0x38001714, 0x374e33ad, 0x1d008c09,   // mt.pt..._440 ro.ca..._660 ur.fa.ar_643 ht.hr..._440
  0x43000807, 0x4b000608, 0x66001613, 0x15003a14,   // it.vi..._420 de.az..._430 lt.af..._650 eu.lv..._660
  0x42000414, 0x1e1d19a4, 0x0c001821, 0x1d004207,   // fi.mt..._660 et.hr.sr_433 hu.pl..._860 mt.hr..._420
  // [1830]
  0x151d4209, 0x14000d08, 0x1d000413, 0x2e001809,   // mt.hr.lv_444 pt.is..._430 fi.hr..._650 hu.sq..._440
  0x1e400c02, 0x4b660107, 0x19423808, 0x121a4502,   // pl.sl.sr_222 en.af.az_432 ca.mt.et_443 sk.xxx.cs_222
  0x45121002, 0x03272908, 0x273f2902, 0x1e401da4,   // sv.cs.sk_222 ms.id.nl_443 ms.sw.id_222 hr.sl.sr_433
  0x3f002b13, 0x0f001614, 0x20450109, 0x021543a4,   // cy.sw..._650 lt.es..._660 en.sk.gl_444 vi.lv.da_433
  // [1840]
  0x14002114, 0x1f002209, 0x190d29a4, 0x0e231e09,   // tl.is..._660 tr.ga..._440 ms.pt.et_433 sr.uk.ru_444
  0x3f004502, 0x0b002e21, 0x100c45af, 0x374e3311,   // sk.sw..._220 sq.no..._860 sk.pl.sv_655 ur.fa.ar_653
  0x1e002702, 0x4b220fa4, 0x1d4b1e09, 0x14004209,   // id.sr..._220 es.tr.az_433 sr.az.hr_444 mt.is..._440
  0x14224b13, 0x45003a02, 0x08000314, 0x1e002708,   // az.tr.is_665 eu.sk..._220 nl.it..._660 id.sr..._430
  // [1850]
  0x45000d21, 0x1d1e18af, 0x06004014, 0x16000613,   // pt.sk..._860 hu.sr.hr_655 sl.de..._660 de.lt..._650
  0x21000108, 0x1d000602, 0x18002702, 0x2b001408,   // en.tl..._430 de.hr..._220 id.hu..._220 is.cy..._430
  0x3a000c14, 0x38432b08, 0x03223a08, 0x0d008c02,   // pl.eu..._660 cy.vi.ca_443 eu.tr.nl_443 ht.pt..._220
  0x2e001609, 0x06000809, 0x2b1618af, 0x10002913,   // lt.sq..._440 it.de..._440 hu.lt.cy_655 ms.sv..._650
  // [1860]
  0x0f8c0107, 0x0b100214, 0x08000d09, 0x17420808,   // en.ht.es_432 da.sv.no_666 pt.it..._440 it.mt.ro_443
  0x10004202, 0x1f050b07, 0x45001f14, 0x1e001c09,   // mt.sv..._220 no.fr.ga_432 ga.sk..._660 bg.sr..._440
  0x22000308, 0x1d000302, 0x05000609, 0x172e42a4,   // nl.tr..._430 nl.hr..._220 de.fr..._440 mt.sq.ro_433
  0x2b003a14, 0x2b424008, 0x29218c02, 0x301e2308,   // eu.cy..._660 sl.mt.cy_443 ht.tl.ms_222 uk.sr.be_443
  // [1870]
  0x660b1009, 0x27003a02, 0x100615a4, 0x45431409,   // sv.no.af_444 eu.id..._220 lv.de.sv_433 is.vi.sk_444
  0x101914a4, 0x16000809, 0x29002113, 0x18004312,   // is.et.sv_433 it.lt..._440 tl.ms..._650 vi.hu..._640
  0x1e1d1609, 0x02220109, 0x1d083a02, 0x0f1a8c55,   // lt.hr.sr_444 en.tr.da_444 eu.it.hr_222 ht.xxx.es_442
  0x22003f23, 0x0f000408, 0x292127af, 0x06004b23,   // sw.tr..._880 fi.es..._430 id.tl.ms_655 az.de..._880
  // [1880]
  0x4e3733ad, 0x07005c08, 0x05000c09, 0x230e30ad,   // ur.ar.fa_643 yi.iw..._430 pl.fr..._440 be.ru.uk_643
  0x200d0fa4, 0x21003808, 0x45273a02, 0x03001f09,   // es.pt.gl_433 ca.tl..._430 eu.id.sk_222 ga.nl..._440
  0x0d036655, 0x38008c13, 0x27002102, 0x12000309,   // af.nl.pt_442 ht.ca..._650 tl.id..._220 nl.cs..._440
  0x1d450c02, 0x10450b09, 0x1f0f3808, 0x4b000814,   // pl.sk.hr_222 no.sk.sv_444 ca.es.ga_443 it.az..._660
  // [1890]
  0x161d1e09, 0x0d000207, 0x18002114, 0x18004308,   // sr.hr.lt_444 da.pt..._420 tl.hu..._660 vi.hu..._430
  0x14004312, 0x18002e07, 0x8c006602, 0x45002e22,   // vi.is..._640 sq.hu..._420 af.ht..._220 sq.sk..._870
  0x05000808, 0x0d002102, 0x45001508, 0x03001509,   // it.fr..._430 tl.pt..._220 lv.sk..._430 lv.nl..._440
  0x23000e08, 0x01001713, 0x17000322, 0x1e232502,   // ru.uk..._430 ro.en..._650 nl.ro..._870 mk.uk.sr_222
  // [18a0]
  0x1a451712, 0x21006623, 0x1d451202, 0x10002b08,   // ro.sk.xxx_654 af.tl..._880 cs.sk.hr_222 cy.sv..._430
  0x21002e09, 0x17054509, 0x03001714, 0x1d1e0109,   // sq.tl..._440 sk.fr.ro_444 ro.nl..._660 en.sr.hr_444
  0x21002707, 0x1a004202, 0x053f1a08, 0x3f210109,   // id.tl..._420 mt.xxx..._220 xxx.sw.fr_443 en.tl.sw_444
  0x2e004b08, 0x45040302, 0x4b228c07, 0x12004214,   // az.sq..._430 nl.fi.sk_222 ht.tr.az_432 mt.cs..._660
  // [18b0]
  0x0c001012, 0x02006614, 0x0c000208, 0x38000c23,   // sv.pl..._640 af.da..._660 da.pl..._430 pl.ca..._880
  0x0e001e11, 0x17001a08, 0x19381712, 0x2b006612,   // sr.ru..._630 xxx.ro..._430 ro.ca.et_654 af.cy..._640
  0x1e1d0308, 0x1e003813, 0x03002109, 0x14002109,   // nl.hr.sr_443 ca.sr..._650 tl.nl..._440 tl.is..._440
  0x15002e09, 0x19003802, 0x17001009, 0x1e253002,   // sq.lv..._440 ca.et..._220 sv.ro..._440 be.mk.sr_222
  // [18c0]
  0x12451f12, 0x3f000f09, 0x22181012, 0x01000f09,   // ga.sk.cs_654 es.sw..._440 sv.hu.tr_654 es.en..._440
  0x8c1f1209, 0x1d001512, 0x450c3f02, 0x1a660507,   // cs.ga.ht_444 lv.hr..._640 sw.pl.sk_222 fr.af.xxx_432
  0x02000f09, 0x293f1f09, 0x061822bc, 0x23300ea4,   // es.da..._440 ga.sw.ms_444 tr.hu.de_865 ru.be.uk_433
  0x12002e09, 0x04000208, 0x06004309, 0x18002214,   // sq.cs..._440 da.fi..._430 vi.de..._440 tr.hu..._660
  // [18d0]
  0x06100312, 0x38001f02, 0x3a001621, 0x03661608,   // nl.sv.de_654 ga.ca..._220 lt.eu..._860 lt.af.nl_443
  0x151640a4, 0x45000c02, 0x45210f09, 0x06041413,   // sl.lt.lv_433 pl.sk..._220 es.tl.sk_444 is.fi.de_665
  0x14380faf, 0x45008c09, 0x0d382060, 0x12451609,   // es.ca.is_655 ht.sk..._440 gl.ca.pt_664 lt.sk.cs_444
  0x3f000502, 0x0b1814a4, 0x18000613, 0x01086608,   // fr.sw..._220 is.hu.no_433 de.hu..._650 af.it.en_443
  // [18e0]
  0x2b161812, 0x40001209, 0x1d124008, 0x1f001a02,   // hu.lt.cy_654 cs.sl..._440 sl.cs.hr_443 xxx.ga..._220
  0x1a001f08, 0x0000100a, 0x1d1e2e02, 0x1d161a08,   // ga.xxx..._430 sv......_500 sq.sr.hr_222 xxx.lt.hr_443
  0x1d451e09, 0x14004b12, 0x0e251c09, 0x04060309,   // sr.sk.hr_444 az.is..._640 bg.mk.ru_444 nl.de.fi_444
  0x21000414, 0x1d001611, 0x10001814, 0x04001608,   // fi.tl..._660 lt.hr..._630 hu.sv..._660 lt.fi..._430
  // [18f0]
  0x01000513, 0x08661708, 0x2b003814, 0x2e001409,   // fr.en..._650 ro.af.it_443 ca.cy..._660 is.sq..._440
  0x420d0809, 0x0c006607, 0x1e0b1d02, 0x14001008,   // it.pt.mt_444 af.pl..._420 hr.no.sr_222 sv.is..._430
  0x06000c09, 0x0000020a, 0x01000408, 0x04004209,   // pl.de..._440 da......_500 fi.en..._430 mt.fi..._440
  0x21002708, 0x45003807, 0x29000309, 0x01003808,   // id.tl..._430 ca.sk..._420 nl.ms..._440 ca.en..._430
  // [1900]
  0x12174202, 0x451d4202, 0x0f002902, 0x15000302,   // mt.ro.cs_222 mt.hr.sk_222 ms.es..._220 nl.lv..._220
  0x01002908, 0x03004309, 0x00002042, 0x03002214,   // ms.en..._430 vi.nl..._440 gl......_C00 tr.nl..._660
  0x14001022, 0x04193a60, 0x451d1207, 0x04000f14,   // sv.is..._870 eu.et.fi_664 cs.hr.sk_432 es.fi..._660
  0x04001509, 0x1a001807, 0x66000213, 0x43000107,   // lv.fi..._440 hu.xxx..._420 da.af..._650 en.vi..._420
  // [1910]
  0x06191014, 0x17000502, 0x3f6603a4, 0x06001032,   // sv.et.de_666 fr.ro..._220 nl.af.sw_433 sv.de..._A60
  0x4b2218bc, 0x2b006614, 0x16432b08, 0x66161412,   // hu.tr.az_865 af.cy..._660 cy.vi.lt_443 is.lt.af_654
  0x38054209, 0x45041a02, 0x3f001e02, 0x04000513,   // mt.fr.ca_444 xxx.fi.sk_222 sr.sw..._220 fr.fi..._650
  0x15000109, 0x02140b08, 0x40026608, 0x4b000614,   // en.lv..._440 no.is.da_443 af.da.sl_443 de.az..._660
  // [1920]
  0x45161214, 0x08002122, 0x15001d14, 0x38000514,   // cs.lt.sk_666 tl.it..._870 hr.lv..._660 fr.ca..._660
  0x271929a4, 0x4b003a13, 0x4b003f14, 0x1c302312,   // ms.et.id_433 eu.az..._650 sw.az..._660 uk.be.bg_654
  0x01296655, 0x27001814, 0x01008c12, 0x06000114,   // af.ms.en_442 hu.id..._660 ht.en..._640 en.de..._660
  0x18000308, 0x020b10a4, 0x0f3a3f02, 0x1a004014,   // nl.hu..._430 sv.no.da_433 sw.eu.es_222 sl.xxx..._660
  // [1930]
  0x66001007, 0x1a0f3f13, 0x02000323, 0x1d002002,   // sv.af..._420 sw.es.xxx_665 nl.da..._880 gl.hr..._220
  0x02040b08, 0x3a1a0fa4, 0x66030107, 0x0f170107,   // no.fi.da_443 es.xxx.eu_433 en.nl.af_432 en.ro.es_432
  0x0c000202, 0x1c232509, 0x450c2b13, 0x66000514,   // da.pl..._220 mk.uk.bg_444 cy.pl.sk_665 fr.af..._660
  0x43001414, 0x0c006621, 0x15000c09, 0x056629a4,   // is.vi..._660 af.pl..._860 pl.lv..._440 ms.af.fr_433
  // [1940]
  0x0c223f55, 0x33003721, 0x66004514, 0x3f0c4508,   // sw.tr.pl_442 ar.ur..._860 sk.af..._660 sk.pl.sw_443
  0x08004502, 0x1f000608, 0x66001f13, 0x1e252312,   // sk.it..._220 de.ga..._430 ga.af..._650 uk.mk.sr_654
  0x1e302502, 0x14001208, 0x3f001502, 0x14003f23,   // mk.be.sr_222 cs.is..._430 lv.sw..._220 sw.is..._880
  0x1a003f23, 0x1d001002, 0x1a000d09, 0x06004b09,   // sw.xxx..._880 sv.hr..._220 pt.xxx..._440 az.de..._440
  // [1950]
  0x2b100b09, 0x10420208, 0x06193a13, 0x45183a02,   // no.sv.cy_444 da.mt.sv_443 eu.et.de_665 eu.hu.sk_222
  0x17380107, 0x03660609, 0x140b0214, 0x18001914,   // en.ca.ro_432 de.af.nl_444 da.no.is_666 et.hu..._660
  0x451e4002, 0x2b000114, 0x27661902, 0x0c003f23,   // sl.sr.sk_222 en.cy..._660 et.af.id_222 sw.pl..._880
  0x19002112, 0x036619af, 0x30002508, 0x15001908,   // tl.et..._640 et.af.nl_655 mk.be..._430 et.lv..._430
  // [1960]
  0x02001512, 0x29192102, 0x45000b09, 0x1c003023,   // lv.da..._640 tl.et.ms_222 no.sk..._440 be.bg..._880
  0x3a002923, 0x17000f09, 0x06002014, 0x220c0d08,   // ms.eu..._880 es.ro..._440 gl.de..._660 pt.pl.tr_443
  0x3a001909, 0x0e302312, 0x27050d02, 0x05001e02,   // et.eu..._440 uk.be.ru_654 pt.fr.id_222 sr.fr..._220
  0x29008c08, 0x18000623, 0x0c000322, 0x66001923,   // ht.ms..._430 de.hu..._880 nl.pl..._870 et.af..._880
  // [1970]
  0x0d1a8c07, 0x18144513, 0x4b002e13, 0x0d000414,   // ht.xxx.pt_432 sk.is.hu_665 sq.az..._650 fi.pt..._660
  0x422718a4, 0x29660312, 0x19380507, 0x1d456608,   // hu.id.mt_433 nl.af.ms_654 fr.ca.et_432 af.sk.hr_443
  0x04004002, 0x40000414, 0x080d8ca4, 0x0b002e02,   // sl.fi..._220 fi.sl..._660 ht.pt.it_433 sq.no..._220
  0x0c451213, 0x29000802, 0x251e2308, 0x2e000509,   // cs.sk.pl_665 it.ms..._220 uk.sr.mk_443 fr.sq..._440
  // [1980]
  0x08100b09, 0x0d060208, 0x40000814, 0x0d003a14,   // no.sv.it_444 da.de.pt_443 it.sl..._660 eu.pt..._660
  0x251c1ea4, 0x1d451ea4, 0x43062109, 0x27008c14,   // sr.bg.mk_433 sr.sk.hr_433 tl.de.vi_444 ht.id..._660
  0x43000d21, 0x1d0d0802, 0x12454013, 0x0c001d12,   // pt.vi..._860 it.pt.hr_222 sl.sk.cs_665 hr.pl..._640
  0x40001512, 0x38431a08, 0x02100ba4, 0x25231ea4,   // lv.sl..._640 xxx.vi.ca_443 no.sv.da_433 sr.uk.mk_433
  // [1990]
  0x211d1e13, 0x14004523, 0x10001602, 0x12008c21,   // sr.hr.tl_665 sk.is..._880 lt.sv..._220 ht.cs..._860
  0x0d000514, 0x1a000509, 0x0b002b02, 0x454010a4,   // fr.pt..._660 fr.xxx..._440 cy.no..._220 sv.sl.sk_433
  0x17036614, 0x03008c21, 0x40001d09, 0x1e062ea4,   // af.nl.ro_666 ht.nl..._860 hr.sl..._440 sq.de.sr_433
  0x12451faf, 0x18161508, 0x02000509, 0x18001e09,   // ga.sk.cs_655 lv.lt.hu_443 fr.da..._440 sr.hu..._440
  // [19a0]
  0x02000507, 0x66001409, 0x0e1c2508, 0x02000513,   // fr.da..._420 is.af..._440 mk.bg.ru_443 fr.da..._650
  0x66020308, 0x0e1c2308, 0x0f0d45a4, 0x27000402,   // nl.da.af_443 uk.bg.ru_443 sk.pt.es_433 fi.id..._220
  0x3f182907, 0x02001609, 0x22000102, 0x27004b13,   // ms.hu.sw_432 lt.da..._440 en.tr..._220 az.id..._650
  0x10043809, 0x12451f02, 0x04002902, 0x02002708,   // ca.fi.sv_444 ga.sk.cs_222 ms.fi..._220 id.da..._430
  // [19b0]
  0x03001613, 0x05001022, 0x1e301c14, 0x19004b13,   // lt.nl..._650 sv.fr..._870 bg.be.sr_666 az.et..._650
  0x051f0107, 0x15003814, 0x033a66a4, 0x43003f09,   // en.ga.fr_432 ca.lv..._660 af.eu.nl_433 sw.vi..._440
  0x42290809, 0x2e182b12, 0x8c000123, 0x38000f22,   // it.ms.mt_444 cy.hu.sq_654 en.ht..._880 es.ca..._870
  0x02221209, 0x3f001414, 0x16003a02, 0x0d0f3807,   // cs.tr.da_444 is.sw..._660 eu.lt..._220 ca.es.pt_432
  // [19c0]
  0x15003a22, 0x0c000d09, 0x22001514, 0x27002023,   // eu.lv..._870 pt.pl..._440 lv.tr..._660 gl.id..._880
  0x14003a12, 0x19008c09, 0x22002b23, 0x06431fa4,   // eu.is..._640 ht.et..._440 cy.tr..._880 ga.vi.de_433
  0x43000208, 0x25000e12, 0x12008c08, 0x43001402,   // da.vi..._430 ru.mk..._640 ht.cs..._430 is.vi..._220
  0x1c230e07, 0x05001814, 0x4b000502, 0x16001002,   // ru.uk.bg_432 hu.fr..._660 fr.az..._220 sv.lt..._220
  // [19d0]
  0x45150c12, 0x1d292708, 0x3a002702, 0x29214212,   // pl.lv.sk_654 id.ms.hr_443 id.eu..._220 mt.tl.ms_654
  0x1c0e25a4, 0x0f004509, 0x15003808, 0x08041912,   // mk.ru.bg_433 sk.es..._440 ca.lv..._430 et.fi.it_654
  0x292b2702, 0x2b420c12, 0x1d000f14, 0x0b000409,   // id.cy.ms_222 pl.mt.cy_654 es.hr..._660 fi.no..._440
  0x06000307, 0x1f002b02, 0x14082ba4, 0x2e008c13,   // nl.de..._420 cy.ga..._220 cy.it.is_433 ht.sq..._650
  // [19e0]
  0x400d0f13, 0x2e003a13, 0x451e1d07, 0x02003809,   // es.pt.sl_665 eu.sq..._650 hr.sr.sk_432 ca.da..._440
  0x1e1d2e02, 0x8c0d19ad, 0x04020b09, 0x22030613,   // sq.hr.sr_222 et.pt.ht_643 no.da.fi_444 de.nl.tr_665
  0x0f3a3812, 0x231e2513, 0x0e251c07, 0x01000814,   // ca.eu.es_654 mk.sr.uk_665 bg.mk.ru_432 it.en..._660
  0x30002523, 0x66002714, 0x0f004209, 0x22031a13,   // mk.be..._880 id.af..._660 mt.es..._440 xxx.nl.tr_665
  // [19f0]
  0x1e1d1612, 0x0e1e2360, 0x19004b14, 0x42000512,   // lt.hr.sr_654 uk.sr.ru_664 az.et..._660 fr.mt..._640
  0x45408c02, 0x06003a21, 0x02222707, 0x06383a12,   // ht.sl.sk_222 eu.de..._860 id.tr.da_432 eu.ca.de_654
  0x030d3a08, 0x27221402, 0x20000b09, 0x12451412,   // eu.pt.nl_443 is.tr.id_222 no.gl..._440 is.sk.cs_654
  0x3f380107, 0x120f4509, 0x19043f08, 0x01002b13,   // en.ca.sw_432 sk.es.cs_444 sw.fi.et_443 cy.en..._650
  // [1a00]
  0x08003a13, 0x0f124509, 0x1c0e23af, 0x2e002914,   // eu.it..._650 sk.cs.es_444 uk.ru.bg_655 ms.sq..._660
  0x17002923, 0x422b2109, 0x2b004221, 0x3f004202,   // ms.ro..._880 tl.cy.mt_444 mt.cy..._860 mt.sw..._220
  0x1d120107, 0x0d0f1855, 0x1d451502, 0x1f002702,   // en.cs.hr_432 hu.es.pt_442 lv.sk.hr_222 id.ga..._220
  0x19003f23, 0x231e2560, 0x1d190409, 0x03000508,   // sw.et..._880 mk.sr.uk_664 fi.et.hr_444 fr.nl..._430
  // [1a10]
  0x0b002108, 0x22194b14, 0x0f8c2ea4, 0x14001f08,   // tl.no..._430 az.et.tr_666 sq.ht.es_433 ga.is..._430
  0x1d000508, 0x17002e07, 0x0f002102, 0x10190409,   // fr.hr..._430 sq.ro..._420 tl.es..._220 fi.et.sv_444
  0x14020b09, 0x3a001502, 0x300e2514, 0x45290402,   // no.da.is_444 lv.eu..._220 mk.ru.be_666 fi.ms.sk_222
  0x0f001f09, 0x29001809, 0x140f1808, 0x182206a4,   // ga.es..._440 hu.ms..._440 hu.es.is_443 de.tr.hu_433
  // [1a20]
  0x3f000214, 0x450f1209, 0x15164208, 0x0f000c12,   // da.sw..._660 cs.es.sk_444 mt.lt.lv_443 pl.es..._640
  0x12180f12, 0x42060c12, 0x0f006614, 0x0d3f1909,   // es.hu.cs_654 pl.de.mt_654 af.es..._660 et.sw.pt_444
  0x3a000608, 0x3a1d1e02, 0x45120fa4, 0x42060b09,   // de.eu..._430 sr.hr.eu_222 es.cs.sk_433 no.de.mt_444
  0x0f451260, 0x45004013, 0x05003a23, 0x16001521,   // cs.sk.es_664 sl.sk..._650 eu.fr..._880 lv.lt..._860
  // [1a30]
  0x38004502, 0x19224b14, 0x14004314, 0x42006613,   // sk.ca..._220 az.tr.et_666 vi.is..._660 af.mt..._650
  0x0f0d3812, 0x38001602, 0x04003821, 0x27004208,   // ca.pt.es_654 lt.ca..._220 ca.fi..._860 mt.id..._430
  0x04003812, 0x06000407, 0x15000b09, 0x05003f23,   // ca.fi..._640 fi.de..._420 no.lv..._440 sw.fr..._880
  0x14181f11, 0x17000b14, 0x141f1814, 0x14181f09,   // ga.hu.is_653 no.ro..._660 hu.ga.is_666 ga.hu.is_444
  // [1a40]
  0x38008c09, 0x38058c60, 0x4e3733a4, 0x18001f14,   // ht.ca..._440 ht.fr.ca_664 ur.ar.fa_433 ga.hu..._660
  0x120c1d02, 0x38450fa4, 0x3a2927a4, 0x1d151e02,   // hr.pl.cs_222 es.sk.ca_433 id.ms.eu_433 sr.lv.hr_222
  0x2e000809, 0x04001011, 0x22001908, 0x1e1f1d02,   // it.sq..._440 sv.fi..._630 et.tr..._430 hr.ga.sr_222
  0x140b0212, 0x0e251eaf, 0x05386609, 0x0b193809,   // da.no.is_654 sr.mk.ru_655 af.ca.fr_444 ca.et.no_444
  // [1a50]
  0x38001709, 0x0c014208, 0x2e183f12, 0x0c001822,   // ro.ca..._440 mt.en.pl_443 sw.hu.sq_654 hu.pl..._870
  0x190217a4, 0x4b220612, 0x12452902, 0x4b2e2208,   // ro.da.et_433 de.tr.az_654 ms.sk.cs_222 tr.sq.az_443
  0x1e003f09, 0x300e1c12, 0x45000512, 0x1e001a02,   // sw.sr..._440 bg.ru.be_654 fr.sk..._640 xxx.sr..._220
  0x182e2908, 0x2e004509, 0x2b001713, 0x10144212,   // ms.sq.hu_443 sk.sq..._440 ro.cy..._650 mt.is.sv_654
  // [1a60]
  0x21003f22, 0x45004208, 0x21002b14, 0x0d006608,   // sw.tl..._870 mt.sk..._430 cy.tl..._660 af.pt..._430
  0x08004223, 0x16008c08, 0x1c252308, 0x1a000408,   // mt.it..._880 ht.lt..._430 uk.mk.bg_443 fi.xxx..._430
  0x05451255, 0x120f4508, 0x12451413, 0x27664202,   // cs.sk.fr_442 sk.es.cs_443 is.sk.cs_665 mt.af.id_222
  0x1d1e1002, 0x1e1d1809, 0x03002e12, 0x22004b08,   // sv.sr.hr_222 hu.hr.sr_444 sq.nl..._640 az.tr..._430
  // [1a70]
  0x18002e22, 0x1e3f1d02, 0x1d001613, 0x3a001f09,   // sq.hu..._870 hr.sw.sr_222 lt.hr..._650 ga.eu..._440
  0x181f0f14, 0x38001708, 0x1a000b09, 0x01210502,   // es.ga.hu_666 ro.ca..._430 no.xxx..._440 fr.tl.en_222
  0x451a3802, 0x0c004214, 0x2e173808, 0x42003802,   // ca.xxx.sk_222 mt.pl..._660 ca.ro.sq_443 ca.mt..._220
  0x8c001e09, 0x45004008, 0x1e1d2102, 0x66060109,   // sr.ht..._440 sl.sk..._430 tl.hr.sr_222 en.de.af_444
  // [1a80]
  0x40008c13, 0x21428c14, 0x15000114, 0x3f660360,   // ht.sl..._650 ht.mt.tl_666 en.lv..._660 nl.af.sw_664
  0x1e001d11, 0x10001509, 0x01003809, 0x19040109,   // hr.sr..._630 lv.sv..._440 ca.en..._440 en.fi.et_444
  0x0d051808, 0x18660507, 0x15001702, 0x29042102,   // hu.fr.pt_443 fr.af.hu_432 ro.lv..._220 tl.fi.ms_222
  0x2e001612, 0x42001a02, 0x1d401507, 0x03004209,   // lt.sq..._640 xxx.mt..._220 lv.sl.hr_432 mt.nl..._440
  // [1a90]
  0x01001402, 0x06003f02, 0x2e001802, 0x05000822,   // is.en..._220 sw.de..._220 hu.sq..._220 it.fr..._870
  0x08001a22, 0x0b100213, 0x0b100209, 0x3a002b02,   // xxx.it..._870 da.sv.no_665 da.sv.no_444 cy.eu..._220
  0x2b000309, 0x08001514, 0x2b000802, 0x1a004009,   // nl.cy..._440 lv.it..._660 it.cy..._220 sl.xxx..._440
  0x12181a09, 0x22001614, 0x02180460, 0x3a001908,   // xxx.hu.cs_444 lt.tr..._660 fi.hu.da_664 et.eu..._430
  // [1aa0]
  0x21002214, 0x21002913, 0x3f000422, 0x1d000f02,   // tr.tl..._660 ms.tl..._650 fi.sw..._870 es.hr..._220
  0x222e2908, 0x10004302, 0x272917af, 0x0d004213,   // ms.sq.tr_443 vi.sv..._220 ro.ms.id_655 mt.pt..._650
  0x2e1d1e08, 0x120c0107, 0x42000d09, 0x12454060,   // sr.hr.sq_443 en.pl.cs_432 pt.mt..._440 sl.sk.cs_664
  0x00000715, 0x43002907, 0x19002907, 0x66030109,   // iw......_700 ms.vi..._420 ms.et..._420 en.nl.af_444
  // [1ab0]
  0x1e001714, 0x1d041902, 0x12454007, 0x0d380f02,   // ro.sr..._660 et.fi.hr_222 sl.sk.cs_432 es.ca.pt_222
  0x02140b09, 0x38001713, 0x3f001f13, 0x230e1e12,   // no.is.da_444 ro.ca..._650 ga.sw..._650 sr.ru.uk_654
  0x02100b13, 0x03001f13, 0x4b001714, 0x101d2e07,   // no.sv.da_665 ga.nl..._650 ro.az..._660 sq.hr.sv_432
  0x14002e12, 0x00003001, 0x122b6609, 0x4b002220,   // sq.is..._640 be......_200 af.cy.cs_444 tr.az..._850
  // [1ac0]
  0x1c230e60, 0x12454209, 0x45001f11, 0x0d000c14,   // ru.uk.bg_664 mt.sk.cs_444 ga.sk..._630 pl.pt..._660
  0x0c000409, 0x3f002e14, 0x3f004214, 0x45081402,   // fi.pl..._440 sq.sw..._660 mt.sw..._660 is.it.sk_222
  0x38180f12, 0x3f002e20, 0x1c001e12, 0x08002707,   // es.hu.ca_654 sq.sw..._850 sr.bg..._640 id.it..._420
  0x08001f14, 0x66002b21, 0x22003f22, 0x0f001813,   // ga.it..._660 cy.af..._860 sw.tr..._870 hu.es..._650
  // [1ad0]
  0x01002b08, 0x04001a02, 0x0f000814, 0x10000502,   // cy.en..._430 xxx.fi..._220 it.es..._660 fr.sv..._220
  0x0f001409, 0x12021002, 0x4b001002, 0x4b000f14,   // is.es..._440 sv.da.cs_222 sv.az..._220 es.az..._660
  0x08001202, 0x27000309, 0x04292109, 0x0f008c14,   // cs.it..._220 nl.id..._440 tl.ms.fi_444 ht.es..._660
  0x401e1da4, 0x10001a08, 0x14124560, 0x1c0e1eaf,   // hr.sr.sl_433 xxx.sv..._430 sk.cs.is_664 sr.ru.bg_655
  // [1ae0]
  0x05003822, 0x25000e22, 0x18000f02, 0x45001509,   // ca.fr..._870 ru.mk..._870 es.hu..._220 lv.sk..._440
  0x3f000314, 0x66004309, 0x1a3a2108, 0x213f1f08,   // nl.sw..._660 vi.af..._440 tl.eu.xxx_443 ga.sw.tl_443
  0x0b001a13, 0x27001f09, 0x25003013, 0x032b06a4,   // xxx.no..._650 ga.id..._440 be.mk..._650 de.cy.nl_433
  0x020b1014, 0x29001f14, 0x14100109, 0x0b006602,   // sv.no.da_666 ga.ms..._660 en.sv.is_444 af.no..._220
  // [1af0]
  0x3f001002, 0x40001d22, 0x04001207, 0x183a0607,   // sv.sw..._220 hr.sl..._870 cs.fi..._420 de.eu.hu_432
  0x25231c07, 0x12451602, 0x16001412, 0x080f0d14,   // bg.uk.mk_432 lt.sk.cs_222 is.lt..._640 pt.es.it_666
  0x06003f14, 0x08001912, 0x020b1009, 0x16004513,   // sw.de..._660 et.it..._640 sv.no.da_444 sk.lt..._650
  0x3a140b09, 0x45401d60, 0x06000b23, 0x15006609,   // no.is.eu_444 hr.sl.sk_664 no.de..._880 af.lv..._440
  // [1b00]
  0x29172702, 0x22003a14, 0x1f003a09, 0x1d1e0402,   // id.ro.ms_222 eu.tr..._660 eu.ga..._440 fi.sr.hr_222
  0x0f001502, 0x45001513, 0x17001214, 0x194b2255,   // lv.es..._220 lv.sk..._650 cs.ro..._660 tr.az.et_442
  0x1d0f2702, 0x0d190109, 0x05001713, 0x25231c09,   // id.es.hr_222 en.et.pt_444 ro.fr..._650 bg.uk.mk_444
  0x298c2702, 0x15001009, 0x0b002b13, 0x0f0d3809,   // id.ht.ms_222 sv.lv..._440 cy.no..._650 ca.pt.es_444
  // [1b10]
  0x022729a4, 0x380f1207, 0x14004009, 0x3a060308,   // ms.id.da_433 cs.es.ca_432 sl.is..._440 nl.de.eu_443
  0x37334e55, 0x25001c07, 0x21220412, 0x43000b09,   // fa.ur.ar_442 bg.mk..._420 fi.tr.tl_654 no.vi..._440
  0x16000b09, 0x3f001208, 0x8c001f13, 0x04001612,   // no.lt..._440 cs.sw..._430 ga.ht..._650 lt.fi..._640
  0x2e003f14, 0x3f002913, 0x02186612, 0x3f002908,   // sw.sq..._660 ms.sw..._650 af.hu.da_654 ms.sw..._430
  // [1b20]
  0x292e3f02, 0x03002b13, 0x270b2902, 0x181f0c08,   // sw.sq.ms_222 cy.nl..._650 ms.no.id_222 pl.ga.hu_443
  0x17192107, 0x3f001802, 0x02002b22, 0x01001609,   // tl.et.ro_432 hu.sw..._220 cy.da..._870 lt.en..._440
  0x27294202, 0x10002b23, 0x43000114, 0x06216612,   // mt.ms.id_222 cy.sv..._880 en.vi..._660 af.tl.de_654
  0x3a001e02, 0x231e2508, 0x2b000b14, 0x0f0d3aa4,   // sr.eu..._220 mk.sr.uk_443 no.cy..._660 eu.pt.es_433
  // [1b30]
  0x05006614, 0x0b002902, 0x3a001721, 0x1d193f02,   // af.fr..._660 ms.no..._220 ro.eu..._860 sw.et.hr_222
  0x06004002, 0x1e3023af, 0x8c002209, 0x1e000c09,   // sl.de..._220 uk.be.sr_655 tr.ht..._440 pl.sr..._440
  0x061410a4, 0x1f292709, 0x02043a55, 0x45401209,   // sv.is.de_433 id.ms.ga_444 eu.fi.da_442 cs.sl.sk_444
  0x0f006602, 0x060f2012, 0x08002709, 0x212e1009,   // af.es..._220 gl.es.de_654 id.it..._440 sv.sq.tl_444
  // [1b40]
  0x29000c02, 0x1d2e6602, 0x1f000c09, 0x8c003802,   // pl.ms..._220 af.sq.hr_222 pl.ga..._440 ca.ht..._220
  0x25233012, 0x08001d23, 0x17000f08, 0x66004009,   // be.uk.mk_654 hr.it..._880 es.ro..._430 sl.af..._440
  0x8c1d1207, 0x1e002322, 0x3f183aaf, 0x38002209,   // cs.hr.ht_432 uk.sr..._870 eu.hu.sw_655 tr.ca..._440
  0x1e1d29a4, 0x1f004b09, 0x12454014, 0x66022212,   // ms.hr.sr_433 az.ga..._440 sl.sk.cs_666 tr.da.af_654
  // [1b50]
  0x3f001609, 0x3a000422, 0x0f190408, 0x1f001d08,   // lt.sw..._440 fi.eu..._870 fi.et.es_443 hr.ga..._430
  0x210f2708, 0x060c0109, 0x45401a02, 0x0d1727a4,   // id.es.tl_443 en.pl.de_444 xxx.sl.sk_222 id.ro.pt_433
  0x121d4509, 0x05004308, 0x01001509, 0x1e001709,   // sk.hr.cs_444 vi.fr..._430 lv.en..._440 ro.sr..._440
  0x29003a23, 0x298c2708, 0x273f8c02, 0x3f004002,   // eu.ms..._880 id.ht.ms_443 ht.sw.id_222 sl.sw..._220
  // [1b60]
  0x3a004009, 0x27003a09, 0x45180d12, 0x1d404512,   // sl.eu..._440 eu.id..._440 pt.hu.sk_654 sk.sl.hr_654
  0x450366a4, 0x05193808, 0x3a000208, 0x1c232513,   // af.nl.sk_433 ca.et.fr_443 da.eu..._430 mk.uk.bg_665
  0x064b8c09, 0x20000621, 0x16002907, 0x101904af,   // ht.az.de_444 de.gl..._860 ms.lt..._420 fi.et.sv_655
  0x16002b21, 0x18004523, 0x3a000b23, 0x42003f08,   // cy.lt..._860 sk.hu..._880 no.eu..._880 sw.mt..._430
  // [1b70]
  0x0e002521, 0x19141008, 0x2b001612, 0x2b001622,   // mk.ru..._860 sv.is.et_443 lt.cy..._640 lt.cy..._870
  0x45061f02, 0x1a002208, 0x3f001402, 0x1a001d14,   // ga.de.sk_222 tr.xxx..._430 is.sw..._220 hr.xxx..._660
  0x2b001623, 0x16002b22, 0x190410a4, 0x0b000613,   // lt.cy..._880 cy.lt..._870 sv.fi.et_433 de.no..._650
  0x1d181207, 0x020c4208, 0x02660308, 0x0e231c55,   // cs.hu.hr_432 mt.pl.da_443 nl.af.da_443 bg.uk.ru_442
  // [1b80]
  0x14066612, 0x3f2729a4, 0x01001f14, 0x40002909,   // af.de.is_654 ms.id.sw_433 ga.en..._660 ms.sl..._440
  0x121d40a4, 0x21003a13, 0x19003a08, 0x27003f08,   // sl.hr.cs_433 eu.tl..._650 eu.et..._430 sw.id..._430
  0x1f002b21, 0x250e2308, 0x18000609, 0x152e17a4,   // cy.ga..._860 uk.ru.mk_443 de.hu..._440 ro.sq.lv_433
  0x40021a09, 0x293f1709, 0x45001609, 0x17003f22,   // xxx.da.sl_444 ro.sw.ms_444 lt.sk..._440 sw.ro..._870
  // [1b90]
  0x3a001708, 0x2b001202, 0x16421708, 0x451f1808,   // ro.eu..._430 cs.cy..._220 ro.mt.lt_443 hu.ga.sk_443
  0x3f224b08, 0x45061a02, 0x27381702, 0x10190412,   // az.tr.sw_443 xxx.de.sk_222 ro.ca.id_222 fi.et.sv_654
  0x120c4512, 0x173a0607, 0x08004b02, 0x15380b09,   // sk.pl.cs_654 de.eu.ro_432 az.it..._220 no.ca.lv_444
  0x290f2707, 0x02101a08, 0x22000d13, 0x18451207,   // id.es.ms_432 xxx.sv.da_443 pt.tr..._650 cs.sk.hu_432
  // [1ba0]
  0x18063a09, 0x0f000202, 0x1a001f02, 0x231c0ead,   // eu.de.hu_444 da.es..._220 ga.xxx..._220 ru.bg.uk_643
  0x43161702, 0x16002723, 0x1e0e25a4, 0x1f151655,   // ro.lt.vi_222 id.lt..._880 mk.ru.sr_433 lt.lv.ga_442
  0x25002308, 0x1e004512, 0x18003f09, 0x43273f08,   // uk.mk..._430 sk.sr..._640 sw.hu..._440 sw.id.vi_443
  0x22004209, 0x061f8c13, 0x0d002214, 0x22001209,   // mt.tr..._440 ht.ga.de_665 tr.pt..._660 cs.tr..._440
  // [1bb0]
  0x063f1a09, 0x66002923, 0x27003823, 0x3f0c0107,   // xxx.sw.de_444 ms.af..._880 ca.id..._880 en.pl.sw_432
  0x033a8c02, 0x230e2555, 0x15000814, 0x66001a02,   // ht.eu.nl_222 mk.ru.uk_442 it.lv..._660 xxx.af..._220
  0x1a001f14, 0x08001802, 0x29050107, 0x14001602,   // ga.xxx..._660 hu.it..._220 en.fr.ms_432 lt.is..._220
  0x01001414, 0x3f000c22, 0x29042702, 0x1d003f14,   // is.en..._660 pl.sw..._870 id.fi.ms_222 sw.hr..._660
  // [1bc0]
  0x0000182d, 0x40000b14, 0x25231c12, 0x290d4002,   // hu......_A00 no.sl..._660 bg.uk.mk_654 sl.pt.ms_222
  0x40003a23, 0x21003f23, 0x3f002123, 0x15211608,   // eu.sl..._880 sw.tl..._880 tl.sw..._880 lt.tl.lv_443
  0x15100b14, 0x1d3a2102, 0x270f2907, 0x8c002b09,   // no.sv.lv_666 tl.eu.hr_222 ms.es.id_432 cy.ht..._440
  0x1d003a23, 0x101504a4, 0x1d021002, 0x0b0210af,   // eu.hr..._880 fi.lv.sv_433 sv.da.hr_222 sv.da.no_655
  // [1bd0]
  0x1d182e02, 0x452e1212, 0x3f002923, 0x21001602,   // sq.hu.hr_222 cs.sq.sk_654 ms.sw..._880 lt.tl..._220
  0x1d0c0208, 0x19001813, 0x29001612, 0x3f001509,   // da.pl.hr_443 hu.et..._650 lt.ms..._640 lv.sw..._440
  0x1a001209, 0x2e450107, 0x14000b20, 0x0f3f0808,   // cs.xxx..._440 en.sk.sq_432 no.is..._850 it.sw.es_443
  0x12181f12, 0x19292707, 0x27001013, 0x0e1c1e55,   // ga.hu.cs_654 id.ms.et_432 sv.id..._650 sr.bg.ru_442
  // [1be0]
  0x22003f09, 0x29271902, 0x3f001408, 0x15001914,   // sw.tr..._440 et.id.ms_222 is.sw..._430 et.lv..._660
  0x22000423, 0x0d001614, 0x2e1d4208, 0x1d1e1aa4,   // fi.tr..._880 lt.pt..._660 mt.hr.sq_443 xxx.sr.hr_433
  0x2e388c12, 0x17000d23, 0x10020b07, 0x2e000209,   // ht.ca.sq_654 pt.ro..._880 no.da.sv_432 da.sq..._440
  0x66004214, 0x14002202, 0x29001913, 0x42002714,   // mt.af..._660 tr.is..._220 et.ms..._650 id.mt..._660
  // [1bf0]
  0x10190408, 0x17001e09, 0x21001a13, 0x0f004208,   // fi.et.sv_443 sr.ro..._440 xxx.tl..._650 mt.es..._430
  0x4b006609, 0x1d002209, 0x12194513, 0x45064209,   // af.az..._440 tr.hr..._440 sk.et.cs_665 mt.de.sk_444
  0x010f2009, 0x10146612, 0x0b181f08, 0x14020baf,   // gl.es.en_444 af.is.sv_654 ga.hu.no_443 no.da.is_655
  0x0f083808, 0x2b000602, 0x080f3808, 0x4b000813,   // ca.it.es_443 de.cy..._220 ca.es.it_443 it.az..._650

  // [1c00]
  0x19002b22, 0x19000f23, 0x15004213, 0x19001223,   // cy.et..._870 es.et..._880 mt.lv..._650 cs.et..._880
  0x29001922, 0x1f101907, 0x381f2b12, 0x19004b09,   // et.ms..._870 et.sv.ga_432 cy.ga.ca_654 az.et..._440
  0x1c232508, 0x0f002107, 0x30000e07, 0x19001209,   // mk.uk.bg_443 tl.es..._420 ru.be..._420 cs.et..._440
  0x19001214, 0x33374e07, 0x29061613, 0x43222108,   // cs.et..._660 fa.ar.ur_432 lt.de.ms_665 tl.tr.vi_443
  // [1c10]
  0x12450c09, 0x0c451207, 0x04001223, 0x27000109,   // pl.sk.cs_444 cs.sk.pl_432 cs.fi..._880 en.id..._440
  0x160c2108, 0x1d160208, 0x21222709, 0x17002214,   // tl.pl.lt_443 da.lt.hr_443 id.tr.tl_444 tr.ro..._660
  0x401d2709, 0x1c003022, 0x10008c02, 0x1d101802,   // id.hr.sl_444 be.bg..._870 ht.sv..._220 hu.sv.hr_222
  0x660c1709, 0x06101aa4, 0x42002913, 0x45001822,   // ro.pl.af_444 xxx.sv.de_433 ms.mt..._650 hu.sk..._870
  // [1c20]
  0x06141009, 0x1c231e60, 0x02036602, 0x10140b08,   // sv.is.de_444 sr.uk.bg_664 af.nl.da_222 no.is.sv_443
  0x15000411, 0x4b000d08, 0x66002b12, 0x45003f09,   // fi.lv..._630 pt.az..._430 cy.af..._640 sw.sk..._440
  0x08002e02, 0x0b003809, 0x8c002e12, 0x1d002702,   // sq.it..._220 ca.no..._440 sq.ht..._640 id.hr..._220
  0x10060b07, 0x224b06af, 0x66000c09, 0x05001508,   // no.de.sv_432 de.az.tr_655 pl.af..._440 lv.fr..._430
  // [1c30]
  0x1d000d02, 0x230e1ca4, 0x0d0838a4, 0x0b060109,   // pt.hr..._220 bg.ru.uk_433 ca.it.pt_433 en.de.no_444
  0x19000608, 0x1e000309, 0x02140b55, 0x17000d02,   // de.et..._430 nl.sr..._440 no.is.da_442 pt.ro..._220
  0x05000c23, 0x22002109, 0x401d1e55, 0x10060407,   // pl.fr..._880 tl.tr..._440 sr.hr.sl_442 fi.de.sv_432
  0x04191009, 0x12002e12, 0x0d001809, 0x14001713,   // sv.et.fi_444 sq.cs..._640 hu.pt..._440 ro.is..._650
  // [1c40]
  0x14451f12, 0x21036660, 0x1e252308, 0x1d001808,   // ga.sk.is_654 af.nl.tl_664 uk.mk.sr_443 hu.hr..._430
  0x40006609, 0x22000b23, 0x38001a09, 0x0d002022,   // af.sl..._440 no.tr..._880 xxx.ca..._440 gl.pt..._870
  0x8c004023, 0x22004514, 0x1e000e12, 0x0b001513,   // sl.ht..._880 sk.tr..._660 ru.sr..._640 lv.no..._650
  0x12171902, 0x452e1008, 0x0b000c12, 0x10190407,   // et.ro.cs_222 sv.sq.sk_443 pl.no..._640 fi.et.sv_432
  // [1c50]
  0x22002913, 0x662b1455, 0x22272908, 0x43002e02,   // ms.tr..._650 is.cy.af_442 ms.id.tr_443 sq.vi..._220
  0x42224b08, 0x16043f12, 0x29271702, 0x27292202,   // az.tr.mt_443 sw.fi.lt_654 ro.id.ms_222 tr.ms.id_222
  0x17004208, 0x18004513, 0x272922a4, 0x04002907,   // mt.ro..._430 sk.hu..._650 tr.ms.id_433 ms.fi..._420
  0x8c001213, 0x1d454202, 0x08003f14, 0x1f3f4208,   // cs.ht..._650 mt.sk.hr_222 sw.it..._660 mt.sw.ga_443
  // [1c60]
  0x1e450c08, 0x1e1d4514, 0x06002112, 0x0c000513,   // pl.sk.sr_443 sk.hr.sr_666 tl.de..._640 fr.pl..._650
  0x3f001d02, 0x38002b13, 0x43001a13, 0x1d108c02,   // hr.sw..._220 cy.ca..._650 xxx.vi..._650 ht.sv.hr_222
  0x17002114, 0x3a004222, 0x8c001723, 0x42003822,   // tl.ro..._660 mt.eu..._870 ro.ht..._880 ca.mt..._870
  0x451f1902, 0x1d3a1ea4, 0x1d401702, 0x031a6614,   // et.ga.sk_222 sr.eu.hr_433 ro.sl.hr_222 af.xxx.nl_666
  // [1c70]
  0x2e002708, 0x03004514, 0x02004514, 0x031a66a4,   // id.sq..._430 sk.nl..._660 sk.da..._660 af.xxx.nl_433
  0x14272108, 0x1f002e13, 0x451f4202, 0x2e001823,   // tl.id.is_443 sq.ga..._650 mt.ga.sk_222 hu.sq..._880
  0x12002b08, 0x1d000402, 0x2b3f2708, 0x23251c13,   // cy.cs..._430 fi.hr..._220 id.sw.cy_443 bg.mk.uk_665
  0x45141a12, 0x0f382baf, 0x01001f02, 0x3a000114,   // xxx.is.sk_654 cy.ca.es_655 ga.en..._220 en.eu..._660
  // [1c80]
  0x12061a02, 0x1e1d6602, 0x4b001914, 0x05006602,   // xxx.de.cs_222 af.hr.sr_222 et.az..._660 af.fr..._220
  0x1c0e3008, 0x0d001214, 0x22000413, 0x17000402,   // be.ru.bg_443 cs.pt..._660 fi.tr..._650 fi.ro..._220
  0x8c003809, 0x04000813, 0x22002707, 0x0b022b13,   // ca.ht..._440 it.fi..._650 id.tr..._420 cy.da.no_665
  0x10000212, 0x12450d09, 0x120603a4, 0x4b8c3f08,   // da.sv..._640 pt.sk.cs_444 nl.de.cs_433 sw.ht.az_443
  // [1c90]
  0x4b220355, 0x45002b08, 0x1f001721, 0x04030612,   // nl.tr.az_442 cy.sk..._430 ro.ga..._860 de.nl.fi_654
  0x2e000602, 0x10002b02, 0x27002e09, 0x02191812,   // de.sq..._220 cy.sv..._220 sq.id..._440 hu.et.da_654
  0x18003813, 0x228c2108, 0x0f000302, 0x25231c08,   // ca.hu..._650 tl.ht.tr_443 nl.es..._220 bg.uk.mk_443
  0x03001423, 0x03001909, 0x0f000d12, 0x45060255,   // is.nl..._880 et.nl..._440 pt.es..._640 da.de.sk_442
  // [1ca0]
  0x05382ead, 0x45002b23, 0x3a051f07, 0x19100612,   // sq.ca.fr_643 cy.sk..._880 ga.fr.eu_432 de.sv.et_654
  0x173a0107, 0x05000d13, 0x1f423809, 0x3a000514,   // en.eu.ro_432 pt.fr..._650 ca.mt.ga_444 fr.eu..._660
  0x2b296607, 0x22002b02, 0x4b004502, 0x29000421,   // af.ms.cy_432 cy.tr..._220 sk.az..._220 fi.ms..._860
  0x27001a13, 0x03046607, 0x08001e02, 0x0f003f07,   // xxx.id..._650 af.fi.nl_432 sr.it..._220 sw.es..._420
  // [1cb0]
  0x3a001f13, 0x8c001e14, 0x1a0f4060, 0x380d0f02,   // ga.eu..._650 sr.ht..._660 sl.es.xxx_664 es.pt.ca_222
  0x14081512, 0x15181612, 0x02043a60, 0x3a0603a4,   // lv.it.is_654 lt.hu.lv_654 eu.fi.da_664 nl.de.eu_433
  0x02003a21, 0x43001712, 0x0b003a21, 0x05004314,   // eu.da..._860 ro.vi..._640 eu.no..._860 vi.fr..._660
  0x2b001809, 0x02000102, 0x02061608, 0x3a006602,   // hu.cy..._440 en.da..._220 lt.de.da_443 af.eu..._220
  // [1cc0]
  0x66003a14, 0x3f001922, 0x45401d02, 0x05003a14,   // eu.af..._660 et.sw..._870 hr.sl.sk_222 eu.fr..._660
  0x27001614, 0x0c002713, 0x66030614, 0x0c003a14,   // lt.id..._660 id.pl..._650 de.nl.af_666 eu.pl..._660
  0x45036602, 0x8c000621, 0x200d0f14, 0x1e2e4013,   // af.nl.sk_222 de.ht..._860 es.pt.gl_666 sl.sq.sr_665
  0x27002123, 0x42450209, 0x29003f23, 0x272921a4,   // tl.id..._880 da.sk.mt_444 sw.ms..._880 tl.ms.id_433
  // [1cd0]
  0x03000122, 0x3f0f0508, 0x01001f13, 0x29006602,   // en.nl..._870 fr.es.sw_443 ga.en..._650 af.ms..._220
  0x3a000621, 0x29192708, 0x10000d13, 0x22002122,   // de.eu..._860 id.et.ms_443 pt.sv..._650 tl.tr..._870
  0x1d450402, 0x270d0f08, 0x16023f09, 0x29000414,   // fi.sk.hr_222 es.pt.id_443 sw.da.lt_444 fi.ms..._660
  0x01008c08, 0x8c001d22, 0x10003814, 0x8c002b14,   // ht.en..._430 hr.ht..._870 ca.sv..._660 cy.ht..._660
  // [1ce0]
  0x02004b14, 0x1d001a09, 0x01003814, 0x10008c14,   // az.da..._660 xxx.hr..._440 ca.en..._660 ht.sv..._660
  0x1f018c08, 0x0d002013, 0x011f0507, 0x061a03af,   // ht.en.ga_443 gl.pt..._650 fr.ga.en_432 nl.xxx.de_655
  0x02036614, 0x3f030607, 0x02030b07, 0x04020b07,   // af.nl.da_666 de.nl.sw_432 no.nl.da_432 no.da.fi_432
  0x0f004023, 0x04001423, 0x032b0609, 0x06181008,   // sl.es..._880 is.fi..._880 de.cy.nl_444 sv.hu.de_443
  // [1cf0]
  0x0d000f21, 0x1f001722, 0x21202909, 0x141e2b08,   // es.pt..._860 ro.ga..._870 ms.gl.tl_444 cy.sr.is_443
  0x30001c12, 0x10002e07, 0x01001e02, 0x15002709,   // bg.be..._640 sq.sv..._420 sr.en..._220 id.lv..._440
  0x1c0e1ead, 0x25301c12, 0x2e008c14, 0x1d4540a4,   // sr.ru.bg_643 bg.be.mk_654 ht.sq..._660 sl.sk.hr_433
  0x1d001508, 0x40004213, 0x161d1509, 0x8c001708,   // lv.hr..._430 mt.sl..._650 lv.hr.lt_444 ro.ht..._430
  // [1d00]
  0x063f0208, 0x18000d11, 0x0d193f55, 0x1a000b02,   // da.sw.de_443 pt.hu..._630 sw.et.pt_442 no.xxx..._220
  0x194b1012, 0x66030b08, 0x1a002e12, 0x19041008,   // sv.az.et_654 no.nl.af_443 sq.xxx..._640 sv.fi.et_443
  0x03008c09, 0x178c0508, 0x021a0b08, 0x170305a4,   // ht.nl..._440 fr.ht.ro_443 no.xxx.da_443 fr.nl.ro_433
  0x10001613, 0x14004b13, 0x04000621, 0x140c1a09,   // lt.sv..._650 az.is..._650 de.fi..._860 xxx.pl.is_444
  // [1d10]
  0x450b1402, 0x14100614, 0x1d000f09, 0x1d661002,   // is.no.sk_222 de.sv.is_666 es.hr..._440 sv.af.hr_222
  0x01003823, 0x12404507, 0x16004302, 0x00001e42,   // ca.en..._880 sk.sl.cs_432 vi.lt..._220 sr......_C00
  0x03060b07, 0x42080109, 0x271f0202, 0x0b020109,   // no.de.nl_432 en.it.mt_444 da.ga.id_222 en.da.no_444
  0x2e080108, 0x14000809, 0x1d161508, 0x05001214,   // en.it.sq_443 it.is..._440 lv.lt.hr_443 cs.fr..._660
  // [1d20]
  0x04000c23, 0x43001f02, 0x17004507, 0x42000107,   // pl.fi..._880 ga.vi..._220 sk.ro..._420 en.mt..._420
  0x17002e23, 0x08001712, 0x450c0faf, 0x66034509,   // sq.ro..._880 ro.it..._640 es.pl.sk_655 sk.nl.af_444
  0x17080109, 0x15000823, 0x43002914, 0x012b1a08,   // en.it.ro_444 it.lv..._880 ms.vi..._660 xxx.cy.en_443
  0x04001523, 0x050f0608, 0x19002123, 0x02004014,   // lv.fi..._880 de.es.fr_443 tl.et..._880 sl.da..._660
  // [1d30]
  0x06100209, 0x01000f08, 0x01002114, 0x10004502,   // da.sv.de_444 es.en..._430 tl.en..._660 sk.sv..._220
  0x2b004213, 0x2e003a08, 0x19161509, 0x1d1e1612,   // mt.cy..._650 eu.sq..._430 lv.lt.et_444 lt.sr.hr_654
  0x12451e09, 0x04014507, 0x06003a22, 0x1e150813,   // sr.sk.cs_444 sk.en.fi_432 eu.de..._870 it.lv.sr_665
  0x8c173aa4, 0x3f1917a4, 0x291e2707, 0x1e081207,   // eu.ro.ht_433 ro.et.sw_433 id.sr.ms_432 cs.it.sr_432
  // [1d40]
  0x38170507, 0x060b1408, 0x0f002709, 0x0b001008,   // fr.ro.ca_432 is.no.de_443 id.es..._440 sv.no..._430
  0x0b021413, 0x0b004022, 0x380f0509, 0x0b003a14,   // is.da.no_665 sl.no..._870 fr.es.ca_444 eu.no..._660
  0x450c12a4, 0x08432b14, 0x3a000322, 0x29272109,   // cs.pl.sk_433 cy.vi.it_666 nl.eu..._870 tl.id.ms_444
  0x043817a4, 0x3f4b8c02, 0x66042707, 0x061022a4,   // ro.ca.fi_433 ht.az.sw_222 id.fi.af_432 tr.sv.de_433
  // [1d50]
  0x29002122, 0x04002723, 0x17001521, 0x1f003a22,   // tl.ms..._870 id.fi..._880 lv.ro..._860 eu.ga..._870
  0x18001422, 0x17001f23, 0x03000f09, 0x29004302,   // is.hu..._870 ga.ro..._880 es.nl..._440 vi.ms..._220
  0x0f002b02, 0x0f001f14, 0x14181012, 0x27002e14,   // cy.es..._220 ga.es..._660 sv.hu.is_654 sq.id..._660
  0x66060b07, 0x2e001f02, 0x0d002112, 0x16002b12,   // no.de.af_432 ga.sq..._220 tl.pt..._640 cy.lt..._640
  // [1d60]
  0x06160412, 0x19000514, 0x15211907, 0x03060108,   // fi.lt.de_654 fr.et..._660 et.tl.lv_432 en.de.nl_443
  0x02190b09, 0x42210112, 0x0d380f08, 0x06001614,   // no.et.da_444 en.tl.mt_654 es.ca.pt_443 lt.de..._660
  0x1c1e0e13, 0x42008c12, 0x40001414, 0x01380408,   // ru.sr.bg_665 ht.mt..._640 is.sl..._660 fi.ca.en_443
  0x12001f13, 0x271f2b55, 0x16000c23, 0x0f400107,   // ga.cs..._650 cy.ga.id_442 pl.lt..._880 en.sl.es_432
  // [1d70]
  0x380d0109, 0x06002107, 0x084217a4, 0x19001e09,   // en.pt.ca_444 tl.de..._420 ro.mt.it_433 sr.et..._440
  0x122b4312, 0x3f292714, 0x1a432e07, 0x21001009,   // vi.cy.cs_654 id.ms.sw_666 sq.vi.xxx_432 sv.tl..._440
  0x3f000323, 0x08001914, 0x1d000109, 0x45082102,   // nl.sw..._880 et.it..._660 en.hr..._440 tl.it.sk_222
  0x12001a02, 0x22292709, 0x66032112, 0x04660309,   // xxx.cs..._220 id.ms.tr_444 tl.nl.af_654 nl.af.fi_444
  // [1d80]
  0x42000811, 0x8c003813, 0x10031207, 0x4b002207,   // it.mt..._630 ca.ht..._650 cs.nl.sv_432 tr.az..._420
  0x300e1c08, 0x45000c08, 0x22000513, 0x3f062708,   // bg.ru.be_443 pl.sk..._430 fr.tr..._650 id.de.sw_443
  0x29224b12, 0x22144b08, 0x4b001414, 0x22002108,   // az.tr.ms_654 az.is.tr_443 is.az..._660 tl.tr..._430
  0x0e301e13, 0x1e080b02, 0x21004514, 0x160b0107,   // sr.be.ru_665 no.it.sr_222 sk.tl..._660 en.no.lt_432
  // [1d90]
  0x2b003812, 0x0b002b14, 0x42036607, 0x16000609,   // ca.cy..._640 cy.no..._660 af.nl.mt_432 de.lt..._440
  0x42003823, 0x14000814, 0x15161413, 0x2e451a08,   // ca.mt..._880 it.is..._660 is.lt.lv_665 xxx.sk.sq_443
  0x224b1609, 0x1d004309, 0x2e002712, 0x451e1d09,   // lt.az.tr_444 vi.hr..._440 id.sq..._640 hr.sr.sk_444
  0x40000409, 0x3a2b3fa4, 0x01001614, 0x21000102,   // fi.sl..._440 sw.cy.eu_433 lt.en..._660 en.tl..._220
  // [1da0]
  0x06002e02, 0x21003813, 0x1d000409, 0x15001f09,   // sq.de..._220 ca.tl..._650 fi.hr..._440 ga.lv..._440
  0x40004209, 0x14000211, 0x15000123, 0x05160109,   // mt.sl..._440 da.is..._630 en.lv..._880 en.lt.fr_444
  0x050f0107, 0x18001f08, 0x40001409, 0x02001413,   // en.es.fr_432 ga.hu..._430 is.sl..._440 is.da..._650
  0x23001e22, 0x2e003814, 0x08004023, 0x04003823,   // sr.uk..._870 ca.sq..._660 sl.it..._880 ca.fi..._880
  // [1db0]
  0x012e2ba4, 0x1a002113, 0x45001802, 0x1d002208,   // cy.sq.en_433 tl.xxx..._650 hu.sk..._220 tr.hr..._430
  0x18006609, 0x1e001209, 0x03041908, 0x66001912,   // af.hu..._440 cs.sr..._440 et.fi.nl_443 et.af..._640
  0x18004522, 0x21001808, 0x21001822, 0x18002709,   // sk.hu..._870 hu.tl..._430 hu.tl..._870 id.hu..._440
  0x29036608, 0x1e004007, 0x401d1eaf, 0x8c002909,   // af.nl.ms_443 sl.sr..._420 sr.hr.sl_655 ms.ht..._440
  // [1dc0]
  0x21001a14, 0x18001620, 0x120c2702, 0x0b000321,   // xxx.tl..._660 lt.hu..._850 id.pl.cs_222 nl.no..._860
  0x02030b09, 0x08181612, 0x03000b07, 0x29000b02,   // no.nl.da_444 lt.hu.it_654 no.nl..._420 no.ms..._220
  0x10060108, 0x032b6614, 0x0b001f13, 0x2e001a14,   // en.de.sv_443 af.cy.nl_666 ga.no..._650 xxx.sq..._660
  0x66003f21, 0x0b000309, 0x19003f08, 0x22000323,   // sw.af..._860 nl.no..._440 sw.et..._430 nl.tr..._880
  // [1dd0]
  0x66000b23, 0x041205a4, 0x0d0f05a4, 0x22000c14,   // no.af..._880 fr.cs.fi_433 fr.es.pt_433 pl.tr..._660
  0x02001714, 0x0e253013, 0x184b2260, 0x2e271a12,   // ro.da..._660 be.mk.ru_665 tr.az.hu_664 xxx.id.sq_654
  0x04380502, 0x1d124202, 0x1a002202, 0x27100602,   // fr.ca.fi_222 mt.cs.hr_222 tr.xxx..._220 de.sv.id_222
  0x0b060107, 0x22000c02, 0x12000c23, 0x160c8c08,   // en.de.no_432 pl.tr..._220 pl.cs..._880 ht.pl.lt_443
  // [1de0]
  0x17000202, 0x20001209, 0x05000309, 0x15000f13,   // da.ro..._220 cs.gl..._440 nl.fr..._440 es.lv..._650
  0x43001902, 0x10002108, 0x01002121, 0x16002102,   // et.vi..._220 tl.sv..._430 tl.en..._860 tl.lt..._220
  0x38002923, 0x2e003f13, 0x1e1d0b02, 0x25003014,   // ms.ca..._880 sw.sq..._650 no.hr.sr_222 be.mk..._660
  0x1f003f14, 0x4b228c13, 0x16001009, 0x1a192107,   // sw.ga..._660 ht.tr.az_665 sv.lt..._440 tl.et.xxx_432
  // [1df0]
  0x1d161e55, 0x06102707, 0x02034212, 0x292e1502,   // sr.lt.hr_442 id.sv.de_432 mt.nl.da_654 lv.sq.ms_222
  0x1d2e4008, 0x1c0e25ad, 0x271a3f09, 0x17060312,   // sl.sq.hr_443 mk.ru.bg_643 sw.xxx.id_444 nl.de.ro_654
  0x3f1a2b08, 0x062b3f07, 0x29002b08, 0x42001014,   // cy.xxx.sw_443 sw.cy.de_432 cy.ms..._430 sv.mt..._660
  0x38171213, 0x1e161d12, 0x08001a14, 0x0c000302,   // cs.ro.ca_665 hr.lt.sr_654 xxx.it..._660 nl.pl..._220
  // [1e00]
  0x4b002211, 0x228c3fad, 0x40000c02, 0x1e1c0e08,   // tr.az..._630 sw.ht.tr_643 pl.sl..._220 ru.bg.sr_443
  0x45121e02, 0x10221f08, 0x2e000214, 0x8c1d4009,   // sr.cs.sk_222 ga.tr.sv_443 da.sq..._660 sl.hr.ht_444
  0x2e004308, 0x02182e55, 0x38006608, 0x1c252360,   // vi.sq..._430 sq.hu.da_442 af.ca..._430 uk.mk.bg_664
  0x03663812, 0x2e400212, 0x66001712, 0x2e178c09,   // ca.af.nl_654 da.sl.sq_654 ro.af..._640 ht.ro.sq_444
  // [1e10]
  0x14063808, 0x45002b09, 0x17000522, 0x2b003808,   // ca.de.is_443 cy.sk..._440 fr.ro..._870 ca.cy..._430
  0x0b000211, 0x1d122902, 0x42004309, 0x19003a02,   // da.no..._630 ms.cs.hr_222 vi.mt..._440 eu.et..._220
  0x27002e13, 0x10004208, 0x02000f14, 0x2e000b23,   // sq.id..._650 mt.sv..._430 es.da..._660 no.sq..._880
  0x40000602, 0x160f4509, 0x0d002b23, 0x2e003f12,   // de.sl..._220 sk.es.lt_444 cy.pt..._880 sw.sq..._640
  // [1e20]
  0x0b002e12, 0x2b036613, 0x180f2112, 0x0d382008,   // sq.no..._640 af.nl.cy_665 tl.es.hu_654 gl.ca.pt_443
  0x0f0d0109, 0x1e233009, 0x16051e07, 0x151e1d12,   // en.pt.es_444 be.uk.sr_444 sr.fr.lt_432 hr.sr.lv_654
  0x06002b08, 0x0c004008, 0x29170408, 0x2e381760,   // cy.de..._430 sl.pl..._430 fi.ro.ms_443 ro.ca.sq_664
  0x0e233011, 0x2b002709, 0x03000208, 0x1d450355,   // be.uk.ru_653 id.cy..._440 da.nl..._430 nl.sk.hr_442
  // [1e30]
  0x22182909, 0x080c1707, 0x171f08a4, 0x180c3a55,   // ms.hu.tr_444 ro.pl.it_432 it.ga.ro_433 eu.pl.hu_442
  0x40451209, 0x1a030208, 0x27008c09, 0x42003a14,   // cs.sk.sl_444 da.nl.xxx_443 ht.id..._440 eu.mt..._660
  0x0b001a12, 0x05001823, 0x3a002909, 0x38002023,   // xxx.no..._640 hu.fr..._880 ms.eu..._440 gl.ca..._880
  0x05001a02, 0x18002b13, 0x08421855, 0x45181602,   // xxx.fr..._220 cy.hu..._650 hu.mt.it_442 lt.hu.sk_222
  // [1e40]
  0x150416a4, 0x27062907, 0x14101908, 0x1d041602,   // lt.fi.lv_433 ms.de.id_432 et.sv.is_443 lt.fi.hr_222
  0x40001809, 0x300e1ca4, 0x16003a21, 0x17000107,   // hu.sl..._440 bg.ru.be_433 eu.lt..._860 en.ro..._420
  0x102b0b55, 0x06002202, 0x3a001614, 0x1d160c02,   // no.cy.sv_442 tr.de..._220 lt.eu..._660 pl.lt.hr_222
  0x0c000107, 0x250e1c60, 0x14050b09, 0x2b003822,   // en.pl..._420 bg.ru.mk_664 no.fr.is_444 ca.cy..._870
  // [1e50]
  0x45120509, 0x2e660108, 0x250e1e08, 0x20000107,   // fr.cs.sk_444 en.af.sq_443 sr.ru.mk_443 en.gl..._420
  0x2e002209, 0x1a000102, 0x08103a08, 0x2e003a22,   // tr.sq..._440 en.xxx..._220 eu.sv.it_443 eu.sq..._870
  0x22000b07, 0x3a001a08, 0x08000502, 0x06001f22,   // no.tr..._420 xxx.eu..._430 fr.it..._220 ga.de..._870
  0x2e003808, 0x1a8c3f12, 0x401d2e12, 0x14001e09,   // ca.sq..._430 sw.ht.xxx_654 sq.hr.sl_654 sr.is..._440
  // [1e60]
  0x43008c08, 0x1a001523, 0x08051a08, 0x05140109,   // ht.vi..._430 lv.xxx..._880 xxx.fr.it_443 en.is.fr_444
  0x06000102, 0x06001d14, 0x662b0309, 0x2b000102,   // en.de..._220 hr.de..._660 nl.cy.af_444 en.cy..._220
  0x03000223, 0x030266a4, 0x1e1c25a4, 0x3a001513,   // da.nl..._880 af.da.nl_433 mk.bg.sr_433 lv.eu..._650
  0x06191008, 0x0d053807, 0x29001014, 0x45086609,   // sv.et.de_443 ca.fr.pt_432 sv.ms..._660 af.it.sk_444
  // [1e70]
  0x210d3f07, 0x0d003807, 0x0c001f09, 0x224b0da4,   // sw.pt.tl_432 ca.pt..._420 ga.pl..._440 pt.az.tr_433
  0x18061412, 0x1e001f08, 0x17450812, 0x0c003809,   // is.de.hu_654 ga.sr..._430 it.sk.ro_654 ca.pl..._440
  0x0d3f0107, 0x06668c08, 0x2b001509, 0x38291709,   // en.sw.pt_432 ht.af.de_443 lv.cy..._440 ro.ms.ca_444
  0x06030109, 0x06000514, 0x06030b07, 0x03001a23,   // en.nl.de_444 fr.de..._660 no.nl.de_432 xxx.nl..._880
  // [1e80]
  0x42030614, 0x17001414, 0x2e0b1008, 0x05008c13,   // de.nl.mt_666 is.ro..._660 sv.no.sq_443 ht.fr..._650
  0x2b000513, 0x1f001913, 0x15002909, 0x38001502,   // fr.cy..._650 et.ga..._650 ms.lv..._440 lv.ca..._220
  0x12451613, 0x16008c02, 0x1e002507, 0x10001407,   // lt.sk.cs_665 ht.lt..._220 mk.sr..._420 is.sv..._420
  0x2e011708, 0x40002e02, 0x14021008, 0x0d001502,   // ro.en.sq_443 sq.sl..._220 sv.da.is_443 lv.pt..._220
  // [1e90]
  0x12404514, 0x1d000114, 0x0b004b23, 0x14000b12,   // sk.sl.cs_666 en.hr..._660 az.no..._880 no.is..._640
  0x8c006614, 0x03662e12, 0x43000207, 0x66002e21,   // af.ht..._660 sq.af.nl_654 da.vi..._420 sq.af..._860
  0x1d011f02, 0x42173a08, 0x3a380808, 0x21148c08,   // ga.en.hr_222 eu.ro.mt_443 it.ca.eu_443 ht.is.tl_443
  0x66002107, 0x43000102, 0x0b00021a, 0x054b2208,   // tl.af..._420 en.vi..._220 da.no..._760 tr.az.fr_443
  // [1ea0]
  0x04000323, 0x043a6614, 0x0c000209, 0x3a030455,   // nl.fi..._880 af.eu.fi_666 da.pl..._440 fi.nl.eu_442
  0x29063a12, 0x2e003f22, 0x1a000409, 0x04000309,   // eu.de.ms_654 sw.sq..._870 fi.xxx..._440 nl.fi..._440
  0x38003a08, 0x4b001413, 0x29430302, 0x43200555,   // eu.ca..._430 is.az..._650 nl.vi.ms_222 fr.gl.vi_442
  0x43000513, 0x02002214, 0x43011708, 0x3a002113,   // fr.vi..._650 tr.da..._660 ro.en.vi_443 tl.eu..._650
  // [1eb0]
  0x01006608, 0x19000823, 0x0b022260, 0x250e2309,   // af.en..._430 it.et..._880 tr.da.no_664 uk.ru.mk_444
  0x43052b07, 0x0b002202, 0x43000502, 0x4b001402,   // cy.fr.vi_432 tr.no..._220 fr.vi..._220 is.az..._220
  0x121d1e07, 0x27293faf, 0x38100b07, 0x0d050f02,   // sr.hr.cs_432 sw.ms.id_655 no.sv.ca_432 es.fr.pt_222
  0x3f1a2155, 0x231c3013, 0x158c1908, 0x0f002109,   // tl.xxx.sw_442 be.bg.uk_665 et.ht.lv_443 tl.es..._440
  // [1ec0]
  0x22000514, 0x29270502, 0x66001602, 0x04151812,   // fr.tr..._660 fr.id.ms_222 lt.af..._220 hu.lv.fi_654
  0x8c000f08, 0x15000509, 0x21004202, 0x14100ba4,   // es.ht..._430 fr.lv..._440 mt.tl..._220 no.sv.is_433
  0x29271da4, 0x1e292702, 0x3a001509, 0x151816a4,   // hr.id.ms_433 id.ms.sr_222 lv.eu..._440 lt.hu.lv_433
  0x1e0e2560, 0x27002108, 0x29004b02, 0x42002b13,   // mk.ru.sr_664 tl.id..._430 az.ms..._220 cy.mt..._650
  // [1ed0]
  0x224b0b09, 0x2e006608, 0x1e2530af, 0x15008c14,   // no.az.tr_444 af.sq..._430 be.mk.sr_655 ht.lv..._660
  0x1a4b2212, 0x22004009, 0x16004209, 0x662b0412,   // tr.az.xxx_654 sl.tr..._440 mt.lt..._440 fi.cy.af_654
  0x19004313, 0x168c0107, 0x03196608, 0x14003809,   // vi.et..._650 en.ht.lt_432 af.et.nl_443 ca.is..._440
  0x2b0b0208, 0x33003723, 0x1d0d3f02, 0x0b8c14a4,   // da.no.cy_443 ar.ur..._880 sw.pt.hr_222 is.ht.no_433
  // [1ee0]
  0x29161a07, 0x01001209, 0x173a0b07, 0x0d453a02,   // xxx.lt.ms_432 cs.en..._440 no.eu.ro_432 eu.sk.pt_222
  0x3a004502, 0x450d1802, 0x172e0b09, 0x66224509,   // sk.eu..._220 hu.pt.sk_222 no.sq.ro_444 sk.tr.af_444
  0x27142914, 0x1a001413, 0x22292714, 0x182b16a4,   // ms.is.id_666 is.xxx..._650 id.ms.tr_666 lt.cy.hu_433
  0x19004522, 0x19000123, 0x036615a4, 0x42000123,   // sk.et..._870 en.et..._880 lv.af.nl_433 en.mt..._880
  // [1ef0]
  0x18100b09, 0x10030b55, 0x02000123, 0x061a0109,   // no.sv.hu_444 no.nl.sv_442 en.da..._880 en.xxx.de_444
  0x01001514, 0x08000202, 0x1e2e2902, 0x03002b14,   // lv.en..._660 da.it..._220 ms.sq.sr_222 cy.nl..._660
  0x38003f14, 0x1c001e23, 0x1e253012, 0x1e2530a4,   // sw.ca..._660 sr.bg..._880 be.mk.sr_654 be.mk.sr_433
  0x38001722, 0x2b004313, 0x1d451702, 0x1e004008,   // ro.ca..._870 vi.cy..._650 ro.sk.hr_222 sl.sr..._430
  // [1f00]
  0x16000c12, 0x45181fa4, 0x21000f21, 0x2b001412,   // pl.lt..._640 ga.hu.sk_433 es.tl..._860 is.cy..._640
  0x29214ba4, 0x17451207, 0x45400c02, 0x45040c12,   // az.tl.ms_433 cs.sk.ro_432 pl.sl.sk_222 pl.fi.sk_654
  0x191e1d08, 0x291027a4, 0x3f000802, 0x3a161412,   // hr.sr.et_443 id.sv.ms_433 it.sw..._220 is.lt.eu_654
  0x43000822, 0x8c100408, 0x4b3a2208, 0x3f002709,   // it.vi..._870 fi.sv.ht_443 tr.eu.az_443 id.sw..._440
  // [1f10]
  0x4b003a09, 0x22000214, 0x270d2902, 0x45032202,   // eu.az..._440 da.tr..._660 ms.pt.id_222 tr.nl.sk_222
  0x278c0b02, 0x0c1e1d08, 0x450f1207, 0x0e003020,   // no.ht.id_222 hr.sr.pl_443 cs.es.sk_432 be.ru..._850
  0x0d124560, 0x19084060, 0x05002221, 0x45004302,   // sk.cs.pt_664 sl.it.et_664 tr.fr..._860 vi.sk..._220
  0x2b001402, 0x02004002, 0x180f0d08, 0x18000507,   // is.cy..._220 sl.da..._220 pt.es.hu_443 fr.hu..._420
  // [1f20]
  0x29030102, 0x8c000314, 0x01291a08, 0x45000c07,   // en.nl.ms_222 nl.ht..._660 xxx.ms.en_443 pl.sk..._420
  0x301c2560, 0x1c0e25af, 0x45020b12, 0x0c004213,   // mk.bg.be_664 mk.ru.bg_655 no.da.sk_654 mt.pl..._650
  0x00001703, 0x213f1fa4, 0x388c0512, 0x060c0313,   // ro......_300 ga.sw.tl_433 fr.ht.ca_654 nl.pl.de_665
  0x45001821, 0x181f1408, 0x3a001514, 0x1e060b07,   // hu.sk..._860 is.ga.hu_443 lv.eu..._660 no.de.sr_432
  // [1f30]
  0x05020b09, 0x29191502, 0x12000514, 0x06181012,   // no.da.fr_444 lv.et.ms_222 fr.cs..._660 sv.hu.de_654
  0x22003a08, 0x1f0b0208, 0x21004314, 0x17001502,   // eu.tr..._430 da.no.ga_443 vi.tl..._660 lv.ro..._220
  0x38000809, 0x1d2e1ea4, 0x0c1d40a4, 0x06001723,   // it.ca..._440 sr.sq.hr_433 sl.hr.pl_433 ro.de..._880
  0x0d3805a4, 0x12450560, 0x08002b09, 0x0c003f08,   // fr.ca.pt_433 fr.sk.cs_664 cy.it..._440 sw.pl..._430
  // [1f40]
  0x1f002908, 0x1d2b6608, 0x16006608, 0x0d002708,   // ms.ga..._430 af.cy.hr_443 af.lt..._430 id.pt..._430
  0x1e143802, 0x151a4008, 0x01121a09, 0x14000414,   // ca.is.sr_222 sl.xxx.lv_443 xxx.cs.en_444 fi.is..._660
  0x42003813, 0x18004014, 0x22001712, 0x03006621,   // ca.mt..._650 sl.hu..._660 ro.tr..._640 af.nl..._860
  0x12450b02, 0x8c4b2212, 0x05002b08, 0x334e37ad,   // no.sk.cs_222 tr.az.ht_654 cy.fr..._430 ar.fa.ur_643
  // [1f50]
  0x08004323, 0x0f001602, 0x02123802, 0x43001522,   // vi.it..._880 lt.es..._220 ca.cs.da_222 lv.vi..._870
  0x21004302, 0x20000823, 0x43003a08, 0x3a004309,   // vi.tl..._220 it.gl..._880 eu.vi..._430 vi.eu..._440
  0x10031907, 0x10000107, 0x08002b14, 0x17000d14,   // et.nl.sv_432 en.sv..._420 cy.it..._660 pt.ro..._660
  0x29003809, 0x05104507, 0x0d200f09, 0x43006614,   // ca.ms..._440 sk.sv.fr_432 es.gl.pt_444 af.vi..._660
  // [1f60]
  0x0c660312, 0x0c000102, 0x1d451f09, 0x0d000222,   // nl.af.pl_654 en.pl..._220 ga.sk.hr_444 da.pt..._870
  0x01660ca4, 0x66001a14, 0x42002702, 0x1d272102,   // pl.af.en_433 xxx.af..._660 id.mt..._220 tl.id.hr_222
  0x66030214, 0x0c008c12, 0x0b004508, 0x3f003a07,   // da.nl.af_666 ht.pl..._640 sk.no..._430 eu.sw..._420
  0x1d1e4008, 0x22002708, 0x02002e08, 0x45056602,   // sl.sr.hr_443 id.tr..._430 sq.da..._430 af.fr.sk_222
  // [1f70]
  0x1e000e09, 0x101d1e09, 0x0b002102, 0x1d081ea4,   // ru.sr..._440 sr.hr.sv_444 tl.no..._220 sr.it.hr_433
  0x2b001f09, 0x2b001a08, 0x04290b09, 0x27002213,   // ga.cy..._440 xxx.cy..._430 no.ms.fi_444 tr.id..._650
  0x251c1eaf, 0x141f1812, 0x3f001513, 0x01423a12,   // sr.bg.mk_655 hu.ga.is_654 lv.sw..._650 eu.mt.en_654
  0x45002e13, 0x14000208, 0x0b003f09, 0x1d181e02,   // sq.sk..._650 da.is..._430 sw.no..._440 sr.hu.hr_222
  // [1f80]
  0x00001f0a, 0x381a0107, 0x0b001022, 0x0d000c09,   // ga......_500 en.xxx.ca_432 sv.no..._870 pl.pt..._440
  0x45024008, 0x0d0602a4, 0x45004b02, 0x174b2255,   // sl.da.sk_443 da.de.pt_433 az.sk..._220 tr.az.ro_442
  0x40000614, 0x18222709, 0x0c001223, 0x42001209,   // de.sl..._660 id.tr.hu_444 cs.pl..._880 cs.mt..._440
  0x22006614, 0x100814a4, 0x1e000b02, 0x02001f14,   // af.tr..._660 is.it.sv_433 no.sr..._220 ga.da..._660
  // [1f90]
  0x18002723, 0x0c002723, 0x18001207, 0x1d1e03a4,   // id.hu..._880 id.pl..._880 cs.hu..._420 nl.sr.hr_433
  0x22182709, 0x08006614, 0x05001f11, 0x29001623,   // id.hu.tr_444 af.it..._660 ga.fr..._630 lt.ms..._880
  0x8c006609, 0x22040202, 0x0f004323, 0x8c212909,   // af.ht..._440 da.fi.tr_222 vi.es..._880 ms.tl.ht_444
  0x21000123, 0x10000213, 0x438c0108, 0x1a2b18ad,   // en.tl..._880 da.sv..._650 en.ht.vi_443 hu.cy.xxx_643
  // [1fa0]
  0x4b224312, 0x0e301e09, 0x40002023, 0x0e1c2514,   // vi.tr.az_654 sr.be.ru_444 gl.sl..._880 mk.bg.ru_666
  0x0b000509, 0x14001d13, 0x450c0109, 0x01221a09,   // fr.no..._440 hr.is..._650 en.pl.sk_444 xxx.tr.en_444
  0x2b004502, 0x16001711, 0x05060108, 0x12000d02,   // sk.cy..._220 ro.lt..._630 en.de.fr_443 pt.cs..._220
  0x03003f14, 0x1a000c12, 0x12452102, 0x10001408,   // sw.nl..._660 pl.xxx..._640 tl.sk.cs_222 is.sv..._430
  // [1fb0]
  0x2b000208, 0x03151a08, 0x03450607, 0x034b0809,   // da.cy..._430 xxx.lv.nl_443 de.sk.nl_432 it.az.nl_444
  0x10001422, 0x14000107, 0x40000508, 0x0c140109,   // is.sv..._870 en.is..._420 fr.sl..._430 en.is.pl_444
  0x0f002702, 0x45001523, 0x43003f07, 0x12021908,   // id.es..._220 lv.sk..._880 sw.vi..._420 et.da.cs_443
  0x10001409, 0x15000413, 0x02000122, 0x020b1008,   // is.sv..._440 fi.lv..._650 en.da..._870 sv.no.da_443
  // [1fc0]
  0x453f0c07, 0x0d380f55, 0x03004509, 0x224b3a12,   // pl.sw.sk_432 es.ca.pt_442 sk.nl..._440 eu.az.tr_654
  0x08002109, 0x20381207, 0x1d191602, 0x21000409,   // tl.it..._440 cs.ca.gl_432 lt.et.hr_222 fi.tl..._440
  0x230e30a4, 0x27060d08, 0x221f4209, 0x38001514,   // be.ru.uk_433 pt.de.id_443 mt.ga.tr_444 lv.ca..._660
  0x17143a12, 0x3a000502, 0x43004502, 0x06004523,   // eu.is.ro_654 fr.eu..._220 sk.vi..._220 sk.de..._880
  // [1fd0]
  0x163a0109, 0x08000c02, 0x29000513, 0x291a0b60,   // en.eu.lt_444 pl.it..._220 fr.ms..._650 no.xxx.ms_664
  0x3f001a23, 0x10060107, 0x0f214560, 0x451f2702,   // xxx.sw..._880 en.de.sv_432 sk.tl.es_664 id.ga.sk_222
  0x01002709, 0x1c1e2512, 0x450c2e02, 0x38002109,   // id.en..._440 mk.sr.bg_654 sq.pl.sk_222 tl.ca..._440
  0x38000623, 0x1e1c2307, 0x0d002b02, 0x0c001f13,   // de.ca..._880 uk.bg.sr_432 cy.pt..._220 ga.pl..._650
  // [1fe0]
  0x3a004b02, 0x1d003809, 0x29000f02, 0x14004b02,   // az.eu..._220 ca.hr..._440 es.ms..._220 az.is..._220
  0x0f4b2213, 0x4b2922a4, 0x1c0e1e08, 0x0f002214,   // tr.az.es_665 tr.ms.az_433 sr.ru.bg_443 tr.es..._660
  0x10002109, 0x2e001209, 0x23300eaf, 0x27291908,   // tl.sv..._440 cs.sq..._440 ru.be.uk_655 et.ms.id_443
  0x29004209, 0x1e1d03a4, 0x16004022, 0x45121602,   // mt.ms..._440 nl.hr.sr_433 sl.lt..._870 lt.cs.sk_222
  // [1ff0]
  0x45012702, 0x27003f14, 0x1e381d02, 0x02101a09,   // id.en.sk_222 sw.id..._660 hr.ca.sr_222 xxx.sv.da_444
  0x05000f23, 0x1d1e0602, 0x08004509, 0x45000608,   // es.fr..._880 de.sr.hr_222 sk.it..._440 de.sk..._430
  0x12431802, 0x0c002714, 0x0d000512, 0x22380109,   // hu.vi.cs_222 id.pl..._660 fr.pt..._640 en.ca.tr_444
  0x0d001523, 0x43001f23, 0x2b006613, 0x8c001702,   // lv.pt..._880 ga.vi..._880 af.cy..._650 ro.ht..._220

  // [2000]
  0x1e000123, 0x04004014, 0x45180507, 0x0c451aa4,   // en.sr..._880 sl.fi..._660 fr.hu.sk_432 xxx.sk.pl_433
  0x45002002, 0x17001602, 0x1e141902, 0x04001213,   // gl.sk..._220 lt.ro..._220 et.is.sr_222 cs.fi..._650
  0x66001402, 0x45121702, 0x03001502, 0x0f451808,   // is.af..._220 ro.cs.sk_222 lv.nl..._220 hu.sk.es_443
  0x1d161e02, 0x1e000214, 0x0f003812, 0x29004b14,   // sr.lt.hr_222 da.sr..._660 ca.es..._640 az.ms..._660
  // [2010]
  0x1e401812, 0x0c1e1d09, 0x1e181d02, 0x0d008c12,   // hu.sl.sr_654 hr.sr.pl_444 hr.hu.sr_222 ht.pt..._640
  0x14004002, 0x0e002513, 0x0c1d1e55, 0x16002714,   // sl.is..._220 mk.ru..._650 sr.hr.pl_442 id.lt..._660
  0x16000b23, 0x1d1e16ad, 0x40001014, 0x16042209,   // no.lt..._880 lt.sr.hr_643 sv.sl..._660 tr.fi.lt_444
  0x66290309, 0x14210f12, 0x0f380107, 0x0d000f22,   // nl.ms.af_444 es.tl.is_654 en.ca.es_432 es.pt..._870
  // [2020]
  0x45664202, 0x21001821, 0x10018c07, 0x0f000614,   // mt.af.sk_222 hu.tl..._860 ht.en.sv_432 de.es..._660
  0x17004213, 0x0d004212, 0x03386608, 0x03004208,   // mt.ro..._650 mt.pt..._640 af.ca.nl_443 mt.nl..._430
  0x451d1e12, 0x1d1e1609, 0x40004512, 0x1d183a02,   // sr.hr.sk_654 lt.sr.hr_444 sk.sl..._640 eu.hu.hr_222
  0x1d002b02, 0x3a003813, 0x1d004b09, 0x0b002b23,   // cy.hr..._220 ca.eu..._650 az.hr..._440 cy.no..._880
  // [2030]
  0x14006608, 0x16048c07, 0x3a000402, 0x19002e23,   // af.is..._430 ht.fi.lt_432 fi.eu..._220 sq.et..._880
  0x0c001708, 0x15000423, 0x0d382012, 0x3a8c0c09,   // ro.pl..._430 fi.lv..._880 gl.ca.pt_654 pl.ht.eu_444
  0x29212709, 0x8c1d1e09, 0x66223a07, 0x45218c02,   // id.tl.ms_444 sr.hr.ht_444 eu.tr.af_432 ht.tl.sk_222
  0x1f003a14, 0x08000f09, 0x25231e13, 0x45188c02,   // eu.ga..._660 es.it..._440 sr.uk.mk_665 ht.hu.sk_222
  // [2040]
  0x081742a4, 0x0c124560, 0x18000b08, 0x30251e09,   // mt.ro.it_433 sk.cs.pl_664 no.hu..._430 sr.mk.be_444
  0x40003809, 0x8c002202, 0x1a008c09, 0x8c002212,   // ca.sl..._440 tr.ht..._220 ht.xxx..._440 tr.ht..._640
  0x45001a12, 0x0c2b02af, 0x0c218c08, 0x1a002207,   // xxx.sk..._640 da.cy.pl_655 ht.tl.pl_443 tr.xxx..._420
  0x0f0d38a4, 0x224b8c12, 0x4b228c12, 0x0d004309,   // ca.pt.es_433 ht.az.tr_654 ht.tr.az_654 vi.pt..._440
  // [2050]
  0x14001809, 0x224b0b08, 0x10190209, 0x16000214,   // hu.is..._440 no.az.tr_443 da.et.sv_444 da.lt..._660
  0x0b1602a4, 0x121a0302, 0x251c1e07, 0x66020b55,   // da.lt.no_433 nl.xxx.cs_222 sr.bg.mk_432 no.da.af_442
  0x10061408, 0x16008c09, 0x16000208, 0x05004509,   // is.de.sv_443 ht.lt..._440 da.lt..._430 sk.fr..._440
  0x06101414, 0x0818381d, 0x29010b07, 0x45272902,   // is.sv.de_666 ca.hu.it_852 no.en.ms_432 ms.id.sk_222
  // [2060]
  0x01124508, 0x8c004514, 0x3f000209, 0x30230e09,   // sk.cs.en_443 sk.ht..._660 da.sw..._440 ru.uk.be_444
  0x0f004b14, 0x1e1d0c14, 0x16004009, 0x38004214,   // az.es..._660 pl.hr.sr_666 sl.lt..._440 mt.ca..._660
  0x3f000123, 0x050d0807, 0x08000f08, 0x1e3023a4,   // en.sw..._880 it.pt.fr_432 es.it..._430 uk.be.sr_433
  0x27042902, 0x0f000b09, 0x29054302, 0x0e232509,   // ms.fi.id_222 no.es..._440 vi.fr.ms_222 mk.uk.ru_444
  // [2070]
  0x17451209, 0x3a401511, 0x00002e42, 0x0e302508,   // cs.sk.ro_444 lv.sl.eu_653 sq......_C00 mk.be.ru_443
  0x1f272912, 0x29001614, 0x8c170555, 0x12000402,   // ms.id.ga_654 lt.ms..._660 fr.ro.ht_442 fi.cs..._220
  0x04002922, 0x27451202, 0x401245a4, 0x29422707,   // ms.fi..._870 cs.sk.id_222 sk.cs.sl_433 id.mt.ms_432
  0x42001412, 0x4b000513, 0x451940af, 0x15163a12,   // is.mt..._640 fr.az..._650 sl.et.sk_655 eu.lt.lv_654
  // [2080]
  0x1e088c02, 0x21008c02, 0x29000108, 0x0f380560,   // ht.it.sr_222 ht.tl..._220 en.ms..._430 fr.ca.es_664
  0x18002202, 0x06004314, 0x45401208, 0x20053813,   // tr.hu..._220 vi.de..._660 cs.sl.sk_443 ca.fr.gl_665
  0x1f004309, 0x27001e14, 0x1d002b08, 0x42000c12,   // vi.ga..._440 sr.id..._660 cy.hr..._430 pl.mt..._640
  0x0c212b08, 0x45221202, 0x1d432b02, 0x10140baf,   // cy.tl.pl_443 cs.tr.sk_222 cy.vi.hr_222 no.is.sv_655
  // [2090]
  0x03660614, 0x40001609, 0x29003a02, 0x29271d02,   // de.af.nl_666 lt.sl..._440 eu.ms..._220 hr.id.ms_222
  0x1e1d3f09, 0x10002209, 0x3f001009, 0x1d2e1e02,   // sw.hr.sr_444 tr.sv..._440 sv.sw..._440 sr.sq.hr_222
  0x27294002, 0x0d001723, 0x060c0413, 0x06003a07,   // sl.ms.id_222 ro.pt..._880 fi.pl.de_665 eu.de..._420
  0x3f160612, 0x08000b23, 0x14451208, 0x12013802,   // de.lt.sw_654 no.it..._880 cs.sk.is_443 ca.en.cs_222
  // [20a0]
  0x18001d14, 0x29004213, 0x0000272d, 0x2e001d02,   // hr.hu..._660 mt.ms..._650 id......_A00 hr.sq..._220
  0x23001c22, 0x20000f13, 0x3a220ca4, 0x2e002214,   // bg.uk..._870 es.gl..._650 pl.tr.eu_433 tr.sq..._660
  0x2e002223, 0x06001923, 0x0b000123, 0x02041912,   // tr.sq..._880 et.de..._880 en.no..._880 et.fi.da_654
  0x10000422, 0x19006608, 0x43001d02, 0x23002521,   // fi.sv..._870 af.et..._430 hr.vi..._220 mk.uk..._860
  // [20b0]
  0x08000409, 0x38420da4, 0x43004b08, 0x2b1a0108,   // fi.it..._440 pt.mt.ca_433 az.vi..._430 en.xxx.cy_443
  0x06100b08, 0x0e231e14, 0x02001d14, 0x1d081f02,   // no.sv.de_443 sr.uk.ru_666 hr.da..._660 ga.it.hr_222
  0x158c1614, 0x1e1d1902, 0x3f4b2213, 0x21001402,   // lt.ht.lv_666 et.hr.sr_222 tr.az.sw_665 is.tl..._220
  0x27002114, 0x03000409, 0x29212702, 0x660603a4,   // tl.id..._660 fi.nl..._440 id.tl.ms_222 nl.de.af_433
  // [20c0]
  0x27212908, 0x19000f14, 0x3a000d02, 0x0d051707,   // ms.tl.id_443 es.et..._660 pt.eu..._220 ro.fr.pt_432
  0x45001f08, 0x15001708, 0x17423a08, 0x15001008,   // ga.sk..._430 ro.lv..._430 eu.mt.ro_443 sv.lv..._430
  0x12003a12, 0x05004b09, 0x08000f12, 0x4b001f14,   // eu.cs..._640 az.fr..._440 es.it..._640 ga.az..._660
  0x0f0d0814, 0x272919af, 0x01002023, 0x1d1a1e02,   // it.pt.es_666 et.ms.id_655 gl.en..._880 sr.xxx.hr_222
  // [20d0]
  0x25230e60, 0x15003f21, 0x0e1c2512, 0x0c2b1a07,   // ru.uk.mk_664 sw.lv..._860 mk.bg.ru_654 xxx.cy.pl_432
  0x19001f02, 0x2b002213, 0x10000409, 0x04063a08,   // ga.et..._220 tr.cy..._650 fi.sv..._440 eu.de.fi_443
  0x16004507, 0x04000b14, 0x03296612, 0x14000d09,   // sk.lt..._420 no.fi..._660 af.ms.nl_654 pt.is..._440
  0x15004507, 0x15044508, 0x06000c02, 0x04451209,   // sk.lv..._420 sk.fi.lv_443 pl.de..._220 cs.sk.fi_444
  // [20e0]
  0x4b2122a4, 0x1e1d2709, 0x432e1008, 0x45001902,   // tr.tl.az_433 id.hr.sr_444 sv.sq.vi_443 et.sk..._220
  0x0d0f0107, 0x060208a4, 0x231c0e09, 0x30002513,   // en.es.pt_432 it.da.de_433 ru.bg.uk_444 mk.be..._650
  0x0f200109, 0x14002909, 0x16150b09, 0x3a002e02,   // en.gl.es_444 ms.is..._440 no.lv.lt_444 sq.eu..._220
  0x0d001814, 0x22144b14, 0x17404509, 0x2e001422,   // hu.pt..._660 az.is.tr_666 sk.sl.ro_444 is.sq..._870
  // [20f0]
  0x14001709, 0x031d0202, 0x1c000e21, 0x15002923,   // ro.is..._440 da.hr.nl_222 ru.bg..._860 ms.lv..._880
  0x181f4513, 0x02000802, 0x4b142213, 0x1d142e02,   // sk.ga.hu_665 it.da..._220 tr.is.az_665 sq.is.hr_222
  0x018c2ea4, 0x0d0f2014, 0x12000809, 0x45150202,   // sq.ht.en_433 gl.es.pt_666 it.cs..._440 da.lv.sk_222
  0x29000814, 0x032b66a4, 0x66032b12, 0x1f291955,   // it.ms..._660 af.cy.nl_433 cy.nl.af_654 et.ms.ga_442
  // [2100]
  0x08004514, 0x45002b21, 0x0f000b07, 0x662b0355,   // sk.it..._660 cy.sk..._860 no.es..._420 nl.cy.af_442
  0x08001623, 0x16001a23, 0x38082908, 0x45120512,   // lt.it..._880 xxx.lt..._880 ms.it.ca_443 fr.cs.sk_654
  0x66002b13, 0x10450b08, 0x38036612, 0x66033aaf,   // cy.af..._650 no.sk.sv_443 af.nl.ca_654 eu.nl.af_655
  0x03003a13, 0x3a001521, 0x03008c08, 0x420501a4,   // eu.nl..._650 lv.eu..._860 ht.nl..._430 en.fr.mt_433
  // [2110]
  0x43008c13, 0x3a292708, 0x02050408, 0x1a0b1712,   // ht.vi..._650 id.ms.eu_443 fi.fr.da_443 ro.no.xxx_654
  0x041a0608, 0x43008c12, 0x2e272913, 0x43271a07,   // de.xxx.fi_443 ht.vi..._640 ms.id.sq_665 xxx.id.vi_432
  0x14001608, 0x18002108, 0x08004b09, 0x1a000414,   // lt.is..._430 tl.hu..._430 az.it..._440 fi.xxx..._660
  0x45221602, 0x121d4008, 0x06001a02, 0x1d001909,   // lt.tr.sk_222 sl.hr.cs_443 xxx.de..._220 et.hr..._440
  // [2120]
  0x1a061009, 0x02001709, 0x04003a07, 0x10001a09,   // sv.de.xxx_444 ro.da..._440 eu.fi..._420 xxx.sv..._440
  0x3a041755, 0x3f2104a4, 0x043a21a4, 0x21223a09,   // ro.fi.eu_442 fi.tl.sw_433 tl.eu.fi_433 eu.tr.tl_444
  0x3f003a22, 0x1f002108, 0x3a004b22, 0x04173aa4,   // eu.sw..._870 tl.ga..._430 az.eu..._870 eu.ro.fi_433
  0x3f041908, 0x2e001f14, 0x021f1708, 0x2e000b14,   // et.fi.sw_443 ga.sq..._660 ro.ga.da_443 no.sq..._660
  // [2130]
  0x02180b07, 0x19001e02, 0x0b001a22, 0x27036602,   // no.hu.da_432 sr.et..._220 xxx.no..._870 af.nl.id_222
  0x3f001909, 0x012b1f07, 0x29003814, 0x42001921,   // et.sw..._440 ga.cy.en_432 ca.ms..._660 et.mt..._860
  0x181445af, 0x43001f09, 0x1e251c11, 0x66000812,   // sk.is.hu_655 ga.vi..._440 bg.mk.sr_653 it.af..._640
  0x2e0f3aa4, 0x2e003a07, 0x1d041e08, 0x0e231c09,   // eu.es.sq_433 eu.sq..._420 sr.fi.hr_443 bg.uk.ru_444
  // [2140]
  0x45164002, 0x100b02af, 0x4b004514, 0x102e1a09,   // sl.lt.sk_222 da.no.sv_655 sk.az..._660 xxx.sq.sv_444
  0x1e0f3802, 0x1e1d0c02, 0x45002014, 0x018c2b09,   // ca.es.sr_222 pl.hr.sr_222 gl.sk..._660 cy.ht.en_444
  0x0f1e1da4, 0x380f2009, 0x04024302, 0x27422e02,   // hr.sr.es_433 gl.es.ca_444 vi.da.fi_222 sq.mt.id_222
  0x01001602, 0x15450c08, 0x8c000309, 0x21002e23,   // lt.en..._220 pl.sk.lv_443 nl.ht..._440 sq.tl..._880
  // [2150]
  0x1d2e42a4, 0x2e166612, 0x1f001707, 0x3a001922,   // mt.sq.hr_433 af.lt.sq_654 ro.ga..._420 et.eu..._870
  0x2e001602, 0x2e4b2213, 0x14000608, 0x03003809,   // lt.sq..._220 tr.az.sq_665 de.is..._430 ca.nl..._440
  0x3a1a0207, 0x2b004312, 0x12046602, 0x3a001623,   // da.xxx.eu_432 vi.cy..._640 af.fi.cs_222 lt.eu..._880
  0x2b004323, 0x38180109, 0x04002002, 0x16001a02,   // vi.cy..._880 en.hu.ca_444 gl.fi..._220 xxx.lt..._220
  // [2160]
  0x1a001414, 0x14100b07, 0x2e001623, 0x10001522,   // is.xxx..._660 no.sv.is_432 lt.sq..._880 lv.sv..._870
  0x1d1002a4, 0x14020b08, 0x12450511, 0x081d4008,   // da.sv.hr_433 no.da.is_443 fr.sk.cs_653 sl.hr.it_443
  0x66050308, 0x45121512, 0x0e003011, 0x1e8c4307,   // nl.fr.af_443 lv.cs.sk_654 be.ru..._630 vi.ht.sr_432
  0x8c036613, 0x0b002714, 0x43000621, 0x03668c13,   // af.nl.ht_665 id.no..._660 de.vi..._860 ht.af.nl_665
  // [2170]
  0x1a003a08, 0x19001a02, 0x8c000114, 0x45122ba4,   // eu.xxx..._430 xxx.et..._220 en.ht..._660 cy.cs.sk_433
  0x40003f02, 0x21001814, 0x1f003f08, 0x0f0c1f12,   // sw.sl..._220 hu.tl..._660 sw.ga..._430 ga.pl.es_654
  0x0d1d1e08, 0x01002914, 0x18002908, 0x38170d09,   // sr.hr.pt_443 ms.en..._660 ms.hu..._430 pt.ro.ca_444
  0x66031512, 0x45060107, 0x0d0f2009, 0x3f004513,   // lv.nl.af_654 en.de.sk_432 gl.es.pt_444 sk.sw..._650
  // [2180]
  0x1c250ea4, 0x213f4b12, 0x032b0412, 0x20004502,   // ru.mk.bg_433 az.sw.tl_654 fi.cy.nl_654 sk.gl..._220
  0x17150fa4, 0x4b008c12, 0x2b004307, 0x02101a07,   // es.lv.ro_433 ht.az..._640 vi.cy..._420 xxx.sv.da_432
  0x12003f13, 0x2b008c11, 0x0000120a, 0x29004b23,   // sw.cs..._650 ht.cy..._630 cs......_500 az.ms..._880
  0x02000514, 0x3f001614, 0x0f004202, 0x05001923,   // fr.da..._660 lt.sw..._660 mt.es..._220 et.fr..._880
  // [2190]
  0x1f3818af, 0x18000809, 0x0c181e07, 0x194b0107,   // hu.ca.ga_655 it.hu..._440 sr.hu.pl_432 en.az.et_432
  0x251e0e12, 0x664b2909, 0x19083a11, 0x06190407,   // ru.sr.mk_654 ms.az.af_444 eu.it.et_653 fi.et.de_432
  0x45001612, 0x40080f09, 0x08000d14, 0x18004208,   // lt.sk..._640 es.it.sl_444 pt.it..._660 mt.hu..._430
  0x10001e14, 0x0e251cad, 0x16000209, 0x10004209,   // sr.sv..._660 bg.mk.ru_643 da.lt..._440 mt.sv..._440
  // [21a0]
  0x210c16a4, 0x40272913, 0x17224b13, 0x15002b23,   // lt.pl.tl_433 ms.id.sl_665 az.tr.ro_665 cy.lv..._880
  0x1a003f09, 0x42402907, 0x251e0eaf, 0x10000c07,   // sw.xxx..._440 ms.sl.mt_432 ru.sr.mk_655 pl.sv..._420
  0x451a3f02, 0x021003a4, 0x1e300e14, 0x04008c08,   // sw.xxx.sk_222 nl.sv.da_433 ru.be.sr_666 ht.fi..._430
  0x27291412, 0x0f002e14, 0x2e002b14, 0x22041912,   // is.ms.id_654 sq.es..._660 cy.sq..._660 et.fi.tr_654
  // [21b0]
  0x3a004514, 0x12450f02, 0x0d1f2b12, 0x1f004202,   // sk.eu..._660 es.sk.cs_222 cy.ga.pt_654 mt.ga..._220
  0x01002e14, 0x231e0e08, 0x14002e07, 0x08008c21,   // sq.en..._660 ru.sr.uk_443 sq.is..._420 ht.it..._860
  0x15000d02, 0x38124560, 0x05001002, 0x12044509,   // pt.lv..._220 sk.cs.ca_664 sv.fr..._220 sk.fi.cs_444
  0x2b001502, 0x4b001712, 0x3a000414, 0x0c001513,   // lv.cy..._220 ro.az..._640 fi.eu..._660 lv.pl..._650
  // [21c0]
  0x0d061607, 0x1a000307, 0x1e191d02, 0x19061012,   // lt.de.pt_432 nl.xxx..._420 hr.et.sr_222 sv.de.et_654
  0x3f272908, 0x03003f02, 0x03000222, 0x03000621,   // ms.id.sw_443 sw.nl..._220 da.nl..._870 de.nl..._860
  0x1a454209, 0x06020b13, 0x0c001509, 0x036602af,   // mt.sk.xxx_444 no.da.de_665 lv.pl..._440 da.af.nl_655
  0x2e002114, 0x173a0f08, 0x42004002, 0x05002914,   // tl.sq..._660 es.eu.ro_443 sl.mt..._220 ms.fr..._660
  // [21d0]
  0x1e2e1d60, 0x033a0608, 0x3f1d1e13, 0x3a431a07,   // hr.sq.sr_664 de.eu.nl_443 sr.hr.sw_665 xxx.vi.eu_432
  0x16003a23, 0x45000823, 0x292b0b07, 0x3f190413,   // eu.lt..._880 it.sk..._880 no.cy.ms_432 fi.et.sw_665
  0x2b020b08, 0x18141f60, 0x16381707, 0x10001908,   // no.da.cy_443 ga.is.hu_664 ro.ca.lt_432 et.sv..._430
  0x21100108, 0x661f0b07, 0x19000809, 0x3a002122,   // en.sv.tl_443 no.ga.af_432 it.et..._440 tl.eu..._870
  // [21e0]
  0x1d2927a4, 0x40004507, 0x45150f07, 0x05001a14,   // id.ms.hr_433 sk.sl..._420 es.lv.sk_432 xxx.fr..._660
  0x0f002914, 0x05228c08, 0x27002912, 0x0d001f14,   // ms.es..._660 ht.tr.fr_443 ms.id..._640 ga.pt..._660
  0x121d4002, 0x0f002114, 0x0c101f08, 0x180f0d07,   // sl.hr.cs_222 tl.es..._660 ga.sv.pl_443 pt.es.hu_432
  0x22000b14, 0x194b2208, 0x4b221a02, 0x66030b07,   // no.tr..._660 tr.az.et_443 xxx.tr.az_222 no.nl.af_432
  // [21f0]
  0x40200d09, 0x0d101a09, 0x21001023, 0x1f000123,   // pt.gl.sl_444 xxx.sv.pt_444 sv.tl..._880 en.ga..._880
  0x0f1e1d08, 0x0d001913, 0x38000102, 0x060410ad,   // hr.sr.es_443 et.pt..._650 en.ca..._220 sv.fi.de_643
  0x181e1d08, 0x181d1e08, 0x02001a12, 0x27292112,   // hr.sr.hu_443 sr.hr.hu_443 xxx.da..._640 tl.ms.id_654
  0x1e001514, 0x011a6608, 0x40181e08, 0x1d1e1802,   // lv.sr..._660 af.xxx.en_443 sr.hu.sl_443 hu.sr.hr_222
  // [2200]
  0x38002b09, 0x10060208, 0x8c000302, 0x03010608,   // cy.ca..._440 da.de.sv_443 nl.ht..._220 de.en.nl_443
  0x17002b08, 0x383a2b08, 0x0e253012, 0x1f380813,   // cy.ro..._430 cy.eu.ca_443 be.mk.ru_654 it.ca.ga_665
  0x198c0409, 0x03196613, 0x08000d23, 0x031d6608,   // fi.ht.et_444 af.et.nl_665 pt.it..._880 af.hr.nl_443
  0x024521a4, 0x05004502, 0x2b053807, 0x1d451209,   // tl.sk.da_433 sk.fr..._220 ca.fr.cy_432 cs.sk.hr_444
  // [2210]
  0x1c233060, 0x06001a23, 0x15190b13, 0x181d1e12,   // be.uk.bg_664 xxx.de..._880 no.et.lv_665 sr.hr.hu_654
  0x03176613, 0x178c0c12, 0x16193f55, 0x1e1d1012,   // af.ro.nl_665 pl.ht.ro_654 sw.et.lt_442 sv.hr.sr_654
  0x8c001822, 0x1d450802, 0x45003813, 0x1d401e13,   // hu.ht..._870 it.sk.hr_222 ca.sk..._650 sr.sl.hr_665
  0x4e373355, 0x45004012, 0x010802a4, 0x1d3f1e07,   // ur.ar.fa_442 sl.sk..._640 da.it.en_433 sr.sw.hr_432
  // [2220]
  0x8c001709, 0x3a003808, 0x22001902, 0x0b004223,   // ro.ht..._440 ca.eu..._430 et.tr..._220 mt.no..._880
  0x45002708, 0x27001014, 0x29271602, 0x29000522,   // id.sk..._430 sv.id..._660 lt.id.ms_222 fr.ms..._870
  0x02001a14, 0x10020b12, 0x16002209, 0x01000308,   // xxx.da..._660 no.da.sv_654 tr.lt..._440 nl.en..._430
  0x0d380f13, 0x100604af, 0x00000e2d, 0x38004b02,   // es.ca.pt_665 fi.de.sv_655 ru......_A00 az.ca..._220
  // [2230]
  0x38000309, 0x45100107, 0x1e230e13, 0x04196602,   // nl.ca..._440 en.sv.sk_432 ru.uk.sr_665 af.et.fi_222
  0x17001509, 0x454b0b02, 0x081e1d60, 0x3f451a07,   // lv.ro..._440 no.az.sk_222 hr.sr.it_664 xxx.sk.sw_432
  0x1a001609, 0x0e301e08, 0x16002708, 0x38001909,   // lt.xxx..._440 sr.be.ru_443 id.lt..._430 et.ca..._440
  0x1a1f0108, 0x1a001f20, 0x0f000d1d, 0x45144302,   // en.ga.xxx_443 ga.xxx..._850 pt.es..._820 vi.is.sk_222
  // [2240]
  0x43004209, 0x27290414, 0x2b000514, 0x02050107,   // mt.vi..._440 fi.ms.id_666 fr.cy..._660 en.fr.da_432
  0x271d4008, 0x45000423, 0x302325a4, 0x1c0e2555,   // sl.hr.id_443 fi.sk..._880 mk.uk.be_433 mk.ru.bg_442
  0x1a003a09, 0x12011a08, 0x03001914, 0x8c002102,   // eu.xxx..._440 xxx.en.cs_443 et.nl..._660 tl.ht..._220
  0x15001912, 0x40000d14, 0x27291002, 0x2e382b14,   // et.lv..._640 pt.sl..._660 sv.ms.id_222 cy.ca.sq_666
  // [2250]
  0x2e1a3809, 0x08001214, 0x16003814, 0x06272913,   // ca.xxx.sq_444 cs.it..._660 ca.lt..._660 ms.id.de_665
  0x450c1808, 0x1d2b0608, 0x40000109, 0x1e0e2514,   // hu.pl.sk_443 de.cy.hr_443 en.sl..._440 mk.ru.sr_666
  0x18000c09, 0x0b1014a4, 0x18001909, 0x01002708,   // pl.hu..._440 is.sv.no_433 et.hu..._440 id.en..._430
  0x10001914, 0x1a0c4255, 0x05000308, 0x19000802,   // et.sv..._660 mt.pl.xxx_442 nl.fr..._430 it.et..._220
  // [2260]
  0x30001e12, 0x1d0f3a02, 0x0f001207, 0x45010f02,   // sr.be..._640 eu.es.hr_222 cs.es..._420 es.en.sk_222
  0x1f001709, 0x17000508, 0x45121802, 0x1f004002,   // ro.ga..._440 fr.ro..._430 hu.cs.sk_222 sl.ga..._220
  0x190d0412, 0x03020b08, 0x22061908, 0x40001608,   // fi.pt.et_654 no.da.nl_443 et.de.tr_443 lt.sl..._430
  0x1e1c0e09, 0x0c4540a4, 0x05000f22, 0x1e001414,   // ru.bg.sr_444 sl.sk.pl_433 es.fr..._870 is.sr..._660
  // [2270]
  0x451d1ea4, 0x16003809, 0x251e3060, 0x38001614,   // sr.hr.sk_433 ca.lt..._440 be.sr.mk_664 lt.ca..._660
  0x14002113, 0x2b000314, 0x1d1e4209, 0x4b001e09,   // tl.is..._650 nl.cy..._660 mt.sr.hr_444 sr.az..._440
  0x083a4209, 0x2e001a02, 0x43001002, 0x023f2908,   // mt.eu.it_444 xxx.sq..._220 sv.vi..._220 ms.sw.da_443
  0x173a0109, 0x272b29af, 0x432e1f60, 0x16004520,   // en.eu.ro_444 ms.cy.id_655 ga.sq.vi_664 sk.lt..._850
  // [2280]
  0x0b006614, 0x0b000314, 0x15002114, 0x3a000f23,   // af.no..._660 nl.no..._660 tl.lv..._660 es.eu..._880
  0x173805a4, 0x1f001809, 0x27160b07, 0x14224b08,   // fr.ca.ro_433 hu.ga..._440 no.lt.id_432 az.tr.is_443
  0x0b003802, 0x16000302, 0x662e0308, 0x27001a12,   // ca.no..._220 nl.lt..._220 nl.sq.af_443 xxx.id..._640
  0x0f002b09, 0x0f380da4, 0x4b221712, 0x0c8c2b08,   // cy.es..._440 pt.ca.es_433 ro.tr.az_654 cy.ht.pl_443
  // [2290]
  0x4b1822af, 0x29001502, 0x1d0821a4, 0x42080107,   // tr.hu.az_655 lv.ms..._220 tl.it.hr_433 en.it.mt_432
  0x0e251e07, 0x06660313, 0x42000502, 0x38000609,   // sr.mk.ru_432 nl.af.de_665 fr.mt..._220 de.ca..._440
  0x02222b60, 0x66002907, 0x29001f08, 0x27051a02,   // cy.tr.da_664 ms.af..._420 ga.ms..._430 xxx.fr.id_222
  0x2b004208, 0x0b140213, 0x08000108, 0x08004002,   // mt.cy..._430 da.is.no_665 en.it..._430 sl.it..._220
  // [22a0]
  0x20000523, 0x3a002023, 0x2b0d3808, 0x04272908,   // fr.gl..._880 gl.eu..._880 ca.pt.cy_443 ms.id.fi_443
  0x45151202, 0x1d001014, 0x16001923, 0x0e1c2309,   // cs.lv.sk_222 sv.hr..._660 et.lt..._880 uk.bg.ru_444
  0x160b0213, 0x66003813, 0x2b004202, 0x1e001409,   // da.no.lt_665 ca.af..._650 mt.cy..._220 is.sr..._440
  0x10036609, 0x0b001421, 0x22001009, 0x2b001409,   // af.nl.sv_444 is.no..._860 sv.tr..._440 is.cy..._440
  // [22b0]
  0x10006614, 0x03001a08, 0x1e1d3f13, 0x060f0b09,   // af.sv..._660 xxx.nl..._430 sw.hr.sr_665 no.es.de_444
  0x19383aaf, 0x272e2913, 0x08160107, 0x0c000613,   // eu.ca.et_655 ms.sq.id_665 en.lt.it_432 de.pl..._650
  0x1a002b12, 0x1e230e07, 0x3f000c21, 0x0e301e12,   // cy.xxx..._640 ru.uk.sr_432 pl.sw..._860 sr.be.ru_654
  0x03660caf, 0x14020ba4, 0x18451255, 0x662b0208,   // pl.af.nl_655 no.da.is_433 cs.sk.hu_442 da.cy.af_443
  // [22c0]
  0x251e3012, 0x18000412, 0x05000202, 0x4b221760,   // be.sr.mk_654 fi.hu..._640 da.fr..._220 ro.tr.az_664
  0x16006613, 0x0d001914, 0x45000507, 0x29000302,   // af.lt..._650 et.pt..._660 fr.sk..._420 nl.ms..._220
  0x1f180f12, 0x660305a4, 0x3f3a17af, 0x1a002e02,   // es.hu.ga_654 fr.nl.af_433 ro.eu.sw_655 sq.xxx..._220
  0x4b2217ad, 0x3a001713, 0x14001f14, 0x66001913,   // ro.tr.az_643 ro.eu..._650 ga.is..._660 et.af..._650
  // [22d0]
  0x01000414, 0x3a004202, 0x211a14a4, 0x05000b07,   // fi.en..._660 mt.eu..._220 is.xxx.tl_433 no.fr..._420
  0x15060507, 0x3a001723, 0x19020b09, 0x05000209,   // fr.de.lv_432 ro.eu..._880 no.da.et_444 da.fr..._440
  0x38006602, 0x1e224b02, 0x14213aaf, 0x2e050107,   // af.ca..._220 az.tr.sr_222 eu.tl.is_655 en.fr.sq_432
  0x1a002108, 0x2b000113, 0x66058c60, 0x0c002914,   // tl.xxx..._430 en.cy..._650 ht.fr.af_664 ms.pl..._660
  // [22e0]
  0x2e001202, 0x42000309, 0x17004309, 0x060c03af,   // cs.sq..._220 nl.mt..._440 vi.ro..._440 nl.pl.de_655
  0x1d000d14, 0x1a003f21, 0x06421207, 0x02062e08,   // pt.hr..._660 sw.xxx..._860 cs.mt.de_432 sq.de.da_443
  0x45121faf, 0x40292712, 0x29193802, 0x18002e08,   // ga.cs.sk_655 id.ms.sl_654 ca.et.ms_222 sq.hu..._430
  0x18001513, 0x1d000622, 0x2b001f12, 0x1e002312,   // lv.hu..._650 de.hr..._870 ga.cy..._640 uk.sr..._640
  // [22f0]
  0x1f002b08, 0x40001413, 0x170d21a4, 0x251c0e07,   // cy.ga..._430 is.sl..._650 tl.pt.ro_433 ru.bg.mk_432
  0x1a000308, 0x3f1410af, 0x21003a09, 0x1e400b07,   // nl.xxx..._430 sv.is.sw_655 eu.tl..._440 no.sl.sr_432
  0x020610a4, 0x1f4512a4, 0x3a002121, 0x03452b07,   // sv.de.da_433 cs.sk.ga_433 tl.eu..._860 cy.sk.nl_432
  0x66003f13, 0x21000c14, 0x0d210109, 0x45050612,   // sw.af..._650 pl.tl..._660 en.tl.pt_444 de.fr.sk_654
  // [2300]
  0x66001422, 0x21001614, 0x3f001f23, 0x1d4508a4,   // is.af..._870 lt.tl..._660 ga.sw..._880 it.sk.hr_433
  0x212901a4, 0x66001523, 0x29000d14, 0x66013808,   // en.ms.tl_433 lv.af..._880 pt.ms..._660 ca.en.af_443
  0x0e002321, 0x10003a09, 0x3f061aa4, 0x29001f02,   // uk.ru..._860 eu.sv..._440 xxx.de.sw_433 ga.ms..._220
  0x18001708, 0x15000107, 0x15006623, 0x00004215,   // ro.hu..._430 en.lv..._420 af.lv..._880 mt......_700
  // [2310]
  0x062b1860, 0x1d000208, 0x02002b07, 0x15001409,   // hu.cy.de_664 da.hr..._430 cy.da..._420 is.lv..._440
  0x10020b60, 0x03001402, 0x22000412, 0x380f1a07,   // no.da.sv_664 is.nl..._220 fi.tr..._640 xxx.es.ca_432
  0x05000f14, 0x068c2b08, 0x2e1a0808, 0x1d003802,   // es.fr..._660 cy.ht.de_443 it.xxx.sq_443 ca.hr..._220
  0x1f272960, 0x08001f09, 0x3f000f14, 0x30251c08,   // ms.id.ga_664 ga.it..._440 es.sw..._660 bg.mk.be_443
  // [2320]
  0x0c0d4208, 0x3a002021, 0x1f0d0b08, 0x0d002b08,   // mt.pt.pl_443 gl.eu..._860 no.pt.ga_443 cy.pt..._430
  0x22661207, 0x2e004502, 0x40002708, 0x173f3a12,   // cs.af.tr_432 sk.sq..._220 id.sl..._430 eu.sw.ro_654
  0x06032709, 0x30230e14, 0x2e001413, 0x02000623,   // id.nl.de_444 ru.uk.be_666 is.sq..._650 de.da..._880
  0x14061a08, 0x38001623, 0x033a0609, 0x45102b07,   // xxx.de.is_443 lt.ca..._880 de.eu.nl_444 cy.sv.sk_432
  // [2330]
  0x2b001609, 0x23250e12, 0x66001e02, 0x66002b22,   // lt.cy..._440 ru.mk.uk_654 sr.af..._220 cy.af..._870
  0x16000423, 0x380d1412, 0x45018c02, 0x25001e08,   // fi.lt..._880 is.pt.ca_654 ht.en.sk_222 sr.mk..._430
  0x223f2908, 0x08001809, 0x22151613, 0x16084508,   // ms.sw.tr_443 hu.it..._440 lt.lv.tr_665 sk.it.lt_443
  0x3a172113, 0x05004208, 0x2e002b12, 0x40000b02,   // tl.ro.eu_665 mt.fr..._430 cy.sq..._640 no.sl..._220
  // [2340]
  0x0d003f14, 0x210f0d60, 0x04000308, 0x40000d09,   // sw.pt..._660 pt.es.tl_664 nl.fi..._430 pt.sl..._440
  0x42000821, 0x0f002113, 0x0d002014, 0x12062b08,   // it.mt..._860 tl.es..._650 gl.pt..._660 cy.de.cs_443
  0x0d210fa4, 0x3f000413, 0x66041913, 0x21000412,   // es.tl.pt_433 fi.sw..._650 et.fi.af_665 fi.tl..._640
  0x1c250e13, 0x18160108, 0x04001821, 0x3a8c0107,   // ru.mk.bg_665 en.lt.hu_443 hu.fi..._860 en.ht.eu_432
  // [2350]
  0x02142707, 0x02451a08, 0x3a000f14, 0x1e001502,   // id.is.da_432 xxx.sk.da_443 es.eu..._660 lv.sr..._220
  0x272e2909, 0x21003a23, 0x22001f09, 0x29101602,   // ms.sq.id_444 eu.tl..._880 ga.tr..._440 lt.sv.ms_222
  0x4b001e08, 0x0f003821, 0x20000114, 0x010c6609,   // sr.az..._430 ca.es..._860 en.gl..._660 af.pl.en_444
  0x0b001812, 0x8c061fa4, 0x06001f08, 0x27296612,   // hu.no..._640 ga.de.ht_433 ga.de..._430 af.ms.id_654
  // [2360]
  0x451d4014, 0x38023a12, 0x10216612, 0x1f001413,   // sl.hr.sk_666 eu.da.ca_654 af.tl.sv_654 is.ga..._650
  0x45121f12, 0x29431602, 0x21272907, 0x3a003f14,   // ga.cs.sk_654 lt.vi.ms_222 ms.id.tl_432 sw.eu..._660
  0x19002e07, 0x184b2255, 0x21001502, 0x040c16af,   // sq.et..._420 tr.az.hu_442 lv.tl..._220 lt.pl.fi_655
  0x16002914, 0x27432b02, 0x16061509, 0x3f004309,   // ms.lt..._660 cy.vi.id_222 lv.de.lt_444 vi.sw..._440
  // [2370]
  0x19000209, 0x1e1d8caf, 0x17000609, 0x0d000507,   // da.et..._440 ht.hr.sr_655 de.ro..._440 fr.pt..._420
  0x43068c02, 0x27290b09, 0x1e060302, 0x45003a12,   // ht.de.vi_222 no.ms.id_444 nl.de.sr_222 eu.sk..._640
  0x0f003f02, 0x29003f22, 0x1c230ea4, 0x18000521,   // sw.es..._220 sw.ms..._870 ru.uk.bg_433 fr.hu..._860
  0x38008c08, 0x17000809, 0x40292709, 0x011a4b55,   // ht.ca..._430 it.ro..._440 id.ms.sl_444 az.xxx.en_442
  // [2380]
  0x1f180c11, 0x0c292708, 0x42223809, 0x4b002b23,   // pl.hu.ga_653 id.ms.pl_443 ca.tr.mt_444 cy.az..._880
  0x272921af, 0x08020b60, 0x0c001714, 0x0c001713,   // tl.ms.id_655 no.da.it_664 ro.pl..._660 ro.pl..._650
  0x1e003a02, 0x2e000d23, 0x2e006620, 0x2b430808,   // eu.sr..._220 pt.sq..._880 af.sq..._850 it.vi.cy_443
  0x3a004014, 0x01003f14, 0x15003a09, 0x0e1c1e14,   // sl.eu..._660 sw.en..._660 eu.lv..._440 sr.bg.ru_666
  // [2390]
  0x1d211e02, 0x301e23a4, 0x3f001213, 0x3f080508,   // sr.tl.hr_222 uk.sr.be_433 cs.sw..._650 fr.it.sw_443
  0x1e8c3f02, 0x15002902, 0x14001f09, 0x271d2902,   // sw.ht.sr_222 ms.lv..._220 ga.is..._440 ms.hr.id_222
  0x18000314, 0x1e1d3a14, 0x1e1d8ca4, 0x083f0612,   // nl.hu..._660 eu.hr.sr_666 ht.hr.sr_433 de.sw.it_654
  0x660306af, 0x0d004013, 0x2e200d12, 0x0d000813,   // de.nl.af_655 sl.pt..._650 pt.gl.sq_654 it.pt..._650
  // [23a0]
  0x66001d14, 0x22001609, 0x1d401eaf, 0x1a001f07,   // hr.af..._660 lt.tr..._440 sr.sl.hr_655 ga.xxx..._420
  0x100b0260, 0x20002909, 0x012e0208, 0x16000323,   // da.no.sv_664 ms.gl..._440 da.sq.en_443 nl.lt..._880
  0x38050109, 0x290d2702, 0x1f451212, 0x2e008c23,   // en.fr.ca_444 id.pt.ms_222 cs.sk.ga_654 ht.sq..._880
  0x16272909, 0x214b2212, 0x012b1208, 0x382e10a4,   // ms.id.lt_444 tr.az.tl_654 cs.cy.en_443 sv.sq.ca_433
  // [23b0]
  0x1a020b08, 0x12001e09, 0x3a061512, 0x14061908,   // no.da.xxx_443 sr.cs..._440 lv.de.eu_654 et.de.is_443
  0x17004214, 0x04000202, 0x38008c21, 0x1f000623,   // mt.ro..._660 da.fi..._220 ht.ca..._860 de.ga..._880
  0x06010308, 0x06000123, 0x2b064307, 0x2b001a02,   // nl.en.de_443 en.de..._880 vi.de.cy_432 xxx.cy..._220
  0x0d001722, 0x1a000208, 0x020b0412, 0x1d1e4013,   // ro.pt..._870 da.xxx..._430 fi.no.da_654 sl.sr.hr_665
  // [23c0]
  0x3a220808, 0x66004013, 0x14000421, 0x10000314,   // it.tr.eu_443 sl.af..._650 fi.is..._860 nl.sv..._660
  0x27000202, 0x10001802, 0x1e002e14, 0x06002222,   // da.id..._220 hu.sv..._220 sq.sr..._660 tr.de..._870
  0x2e000314, 0x1d1e0309, 0x38003a13, 0x19000612,   // nl.sq..._660 nl.sr.hr_444 eu.ca..._650 de.et..._640
  0x19004223, 0x2e3f0108, 0x3f2e0107, 0x4b000302,   // mt.et..._880 en.sw.sq_443 en.sq.sw_432 nl.az..._220
  // [23d0]
  0x06004b14, 0x2e000313, 0x0c000f08, 0x3f002e22,   // az.de..._660 nl.sq..._650 es.pl..._430 sq.sw..._870
  0x05000121, 0x08123fa4, 0x19004209, 0x05660308,   // en.fr..._860 sw.cs.it_433 mt.et..._440 nl.af.fr_443
  0x1d421e14, 0x0c451209, 0x1a010209, 0x04190b13,   // sr.mt.hr_666 cs.sk.pl_444 da.en.xxx_444 no.et.fi_665
  0x66000c14, 0x1a000c11, 0x0600101a, 0x19061060,   // pl.af..._660 pl.xxx..._630 sv.de..._760 sv.de.et_664
  // [23e0]
  0x061904af, 0x3f002e21, 0x181245a4, 0x06162707,   // fi.et.de_655 sq.sw..._860 sk.cs.hu_433 id.lt.de_432
  0x17030508, 0x4b220d12, 0x0f3842a4, 0x3f190b09,   // fr.nl.ro_443 pt.tr.az_654 mt.ca.es_433 no.et.sw_444
  0x4b221912, 0x2e000107, 0x200d0f60, 0x3f002e08,   // et.tr.az_654 en.sq..._420 es.pt.gl_664 sq.sw..._430
  0x1a8c3a12, 0x21001709, 0x1c0e23a4, 0x0e002311,   // eu.ht.xxx_654 ro.tl..._440 uk.ru.bg_433 uk.ru..._630
  // [23f0]
  0x40191608, 0x660302a4, 0x1e006609, 0x12451f08,   // lt.et.sl_443 da.nl.af_433 af.sr..._440 ga.sk.cs_443
  0x06030b09, 0x03451a07, 0x22001a08, 0x21004009,   // no.nl.de_444 xxx.sk.nl_432 xxx.tr..._430 sl.tl..._440
  0x1e0e1c09, 0x0400190d, 0x06190412, 0x08000214,   // bg.ru.sr_444 et.fi..._540 fi.et.de_654 da.it..._660
  0x19000214, 0x0b002702, 0x041a2109, 0x02003802,   // da.et..._660 id.no..._220 tl.xxx.fi_444 ca.da..._220

  // [2400]
  0x031a01a4, 0x02001608, 0x1d402e02, 0x10008c12,   // en.xxx.nl_433 lt.da..._430 sq.sl.hr_222 ht.sv..._640
  0x053a1702, 0x05002907, 0x290f3a02, 0x12450f07,   // ro.eu.fr_222 ms.fr..._420 eu.es.ms_222 es.sk.cs_432
  0x224b2907, 0x14040812, 0x0f431a09, 0x15191008,   // ms.az.tr_432 it.fi.is_654 xxx.vi.es_444 sv.et.lv_443
  0x08040b07, 0x2e000d22, 0x1f171a09, 0x16050107,   // no.fi.it_432 pt.sq..._870 xxx.ro.ga_444 en.fr.lt_432
  // [2410]
  0x170d08af, 0x06033a09, 0x38000202, 0x1f001207,   // it.pt.ro_655 eu.nl.de_444 da.ca..._220 cs.ga..._420
  0x0b081809, 0x250e2313, 0x1e232514, 0x16001f21,   // hu.it.no_444 uk.ru.mk_665 mk.uk.sr_666 ga.lt..._860
  0x02038c13, 0x03001023, 0x3a290308, 0x45120c12,   // ht.nl.da_665 sv.nl..._880 nl.ms.eu_443 pl.cs.sk_654
  0x041f1908, 0x1e001708, 0x1d664008, 0x0c000b02,   // et.ga.fi_443 ro.sr..._430 sl.af.hr_443 no.pl..._220
  // [2420]
  0x0b000413, 0x402e1e09, 0x1f3f4209, 0x1f002109,   // fi.no..._650 sr.sq.sl_444 mt.sw.ga_444 tl.ga..._440
  0x38140ba4, 0x27294502, 0x1d190412, 0x19000411,   // no.is.ca_433 sk.ms.id_222 fi.et.hr_654 fi.et..._630
  0x0c3f2b12, 0x1e291d02, 0x16003f23, 0x16001413,   // cy.sw.pl_654 hr.ms.sr_222 sw.lt..._880 is.lt..._650
  0x14272e08, 0x14400b08, 0x45022e08, 0x04143f09,   // sq.id.is_443 no.sl.is_443 sq.da.sk_443 sw.is.fi_444
  // [2430]
  0x05001514, 0x16003a08, 0x42002202, 0x05081707,   // lv.fr..._660 eu.lt..._430 tr.mt..._220 ro.it.fr_432
  0x18002914, 0x45060102, 0x230e1ea4, 0x29002222,   // ms.hu..._660 en.de.sk_222 sr.ru.uk_433 tr.ms..._870
  0x180302a4, 0x03002113, 0x1c0e1ea4, 0x0e1e2509,   // da.nl.hu_433 tl.nl..._650 sr.ru.bg_433 mk.sr.ru_444
  0x01000208, 0x43012108, 0x66190314, 0x25003022,   // da.en..._430 tl.en.vi_443 nl.et.af_666 be.mk..._870
  // [2440]
  0x29041902, 0x05124508, 0x10000d02, 0x17001207,   // et.fi.ms_222 sk.cs.fr_443 pt.sv..._220 cs.ro..._420
  0x3800201d, 0x0c0f4555, 0x45221612, 0x8c003808,   // gl.ca..._820 sk.es.pl_442 lt.tr.sk_654 ca.ht..._430
  0x15050109, 0x292b2707, 0x16002702, 0x1d0b42a4,   // en.fr.lv_444 id.cy.ms_432 id.lt..._220 mt.no.hr_433
  0x14004221, 0x19001f22, 0x0e231e11, 0x02006613,   // mt.is..._860 ga.et..._870 sr.uk.ru_653 af.da..._650
  // [2450]
  0x08401d09, 0x010d0f08, 0x0b001f08, 0x2e000512,   // hr.sl.it_444 es.pt.en_443 ga.no..._430 fr.sq..._640
  0x12451f09, 0x3a190413, 0x451812a4, 0x12000307,   // ga.sk.cs_444 fi.et.eu_665 cs.hu.sk_433 nl.cs..._420
  0x212b3a07, 0x23002511, 0x011d1a09, 0x45181212,   // eu.cy.tl_432 mk.uk..._630 xxx.hr.en_444 cs.hu.sk_654
  0x06001509, 0x23001c08, 0x0c000f12, 0x16151913,   // lv.de..._440 bg.uk..._430 es.pl..._640 et.lv.lt_665
  // [2460]
  0x18004009, 0x3a002209, 0x40001823, 0x42083a08,   // sl.hu..._440 tr.eu..._440 hu.sl..._880 eu.it.mt_443
  0x04100655, 0x1d1a1502, 0x1e301c02, 0x1a006602,   // de.sv.fi_442 lv.xxx.hr_222 bg.be.sr_222 af.xxx..._220
  0x4b000402, 0x29060402, 0x12294b09, 0x0e301eaf,   // fi.az..._220 fi.de.ms_222 az.ms.cs_444 sr.be.ru_655
  0x450f3802, 0x1d006614, 0x01081708, 0x8c051412,   // ca.es.sk_222 af.hr..._660 ro.it.en_443 is.fr.ht_654
  // [2470]
  0x15450109, 0x19004b08, 0x30251ea4, 0x0e1c3013,   // en.sk.lv_444 az.et..._430 sr.mk.be_433 be.bg.ru_665
  0x120d4502, 0x05003807, 0x251e1caf, 0x0d003a13,   // sk.pt.cs_222 ca.fr..._420 bg.sr.mk_655 eu.pt..._650
  0x66062909, 0x451e1da4, 0x16192909, 0x27456602,   // ms.de.af_444 hr.sr.sk_433 ms.et.lt_444 af.sk.id_222
  0x0f422e07, 0x2e003807, 0x04181012, 0x29080109,   // sq.mt.es_432 ca.sq..._420 sv.hu.fi_654 en.it.ms_444
  // [2480]
  0x1d1e4202, 0x18144514, 0x17382707, 0x1e0c1da4,   // mt.sr.hr_222 sk.is.hu_666 id.ca.ro_432 hr.pl.sr_433
  0x1d1e4560, 0x1c230ead, 0x010b0208, 0x43000c12,   // sk.sr.hr_664 ru.uk.bg_643 da.no.en_443 pl.vi..._640
  0x1e1c2302, 0x0d0f3812, 0x0f003822, 0x29008c02,   // uk.bg.sr_222 ca.es.pt_654 ca.es..._870 ht.ms..._220
  0x3f000113, 0x1d401e55, 0x278c4209, 0x3f218ca4,   // en.sw..._650 sr.sl.hr_442 mt.ht.id_444 ht.tl.sw_433
  // [2490]
  0x06031512, 0x1d181e13, 0x27008c08, 0x181d1ea4,   // lv.nl.de_654 sr.hu.hr_665 ht.id..._430 sr.hr.hu_433
  0x033f21a4, 0x010f1f60, 0x0f000507, 0x164b2708,   // tl.sw.nl_433 ga.es.en_664 fr.es..._420 id.az.lt_443
  0x3f1a42a4, 0x18401e02, 0x1d191e08, 0x04082b12,   // mt.xxx.sw_433 sr.sl.hu_222 sr.et.hr_443 cy.it.fi_654
  0x1d181ea4, 0x121d1ea4, 0x273f2108, 0x03000512,   // sr.hu.hr_433 sr.hr.cs_433 tl.sw.id_443 fr.nl..._640
  // [24a0]
  0x0e1e23a4, 0x27401402, 0x0c183855, 0x40080f08,   // uk.sr.ru_433 is.sl.id_222 ca.hu.pl_442 es.it.sl_443
  0x0d451f07, 0x27001402, 0x453f4ba4, 0x3f004b09,   // ga.sk.pt_432 is.id..._220 az.sw.sk_433 az.sw..._440
  0x27001a09, 0x21272914, 0x04660313, 0x0e251e08,   // xxx.id..._440 ms.id.tl_666 nl.af.fi_665 sr.mk.ru_443
  0x22001509, 0x1d272909, 0x12450d12, 0x43002908,   // lv.tr..._440 ms.id.hr_444 pt.sk.cs_654 ms.vi..._430
  // [24b0]
  0x8c001202, 0x66450302, 0x19150408, 0x0c008c22,   // cs.ht..._220 nl.sk.af_222 fi.lv.et_443 ht.pl..._870
  0x1d3a2e02, 0x0c001913, 0x66000307, 0x16001714,   // sq.eu.hr_222 et.pl..._650 nl.af..._420 ro.lt..._660
  0x1a020407, 0x0d002709, 0x0d003a08, 0x170d0107,   // fi.da.xxx_432 id.pt..._440 eu.pt..._430 en.pt.ro_432
  0x031a1008, 0x3a003807, 0x29001a14, 0x8c001209,   // sv.xxx.nl_443 ca.eu..._420 xxx.ms..._660 cs.ht..._440
  // [24c0]
  0x1a100209, 0x8c223f55, 0x1d001714, 0x3a001923,   // da.sv.xxx_444 sw.tr.ht_442 ro.hr..._660 et.eu..._880
  0x18002123, 0x0f382009, 0x0f000602, 0x19000b14,   // tl.hu..._880 gl.ca.es_444 de.es..._220 no.et..._660
  0x1d051602, 0x300e1e55, 0x3a000113, 0x17040514,   // lt.fr.hr_222 sr.ru.be_442 en.eu..._650 fr.fi.ro_666
  0x01002b12, 0x01191a08, 0x15003f09, 0x38006609,   // cy.en..._640 xxx.et.en_443 sw.lv..._440 af.ca..._440
  // [24d0]
  0x27014208, 0x10140b14, 0x29270f09, 0x1c0e2355,   // mt.en.id_443 no.is.sv_666 es.id.ms_444 uk.ru.bg_442
  0x45053a08, 0x0d0f0508, 0x29002e13, 0x45013802,   // eu.fr.sk_443 fr.es.pt_443 sq.ms..._650 ca.en.sk_222
  0x18451f07, 0x0f001202, 0x12180802, 0x0b000102,   // ga.sk.hu_432 cs.es..._220 it.hu.cs_222 en.no..._220
  0x00003a42, 0x1c251e60, 0x21001008, 0x033f6608,   // eu......_C00 sr.mk.bg_664 sv.tl..._430 af.sw.nl_443
  // [24e0]
  0x4b182208, 0x27000108, 0x0f002e09, 0x01000b23,   // tr.hu.az_443 en.id..._430 sq.es..._440 no.en..._880
  0x0d0f1708, 0x2e004b14, 0x15000c02, 0x16002902,   // ro.es.pt_443 az.sq..._660 pl.lv..._220 ms.lt..._220
  0x43002714, 0x08051708, 0x2e003a11, 0x15036613,   // id.vi..._660 ro.fr.it_443 eu.sq..._630 af.nl.lv_665
  0x22272913, 0x29000614, 0x08422ead, 0x2e004223,   // ms.id.tr_665 de.ms..._660 sq.mt.it_643 mt.sq..._880
  // [24f0]
  0x0b004514, 0x27000113, 0x16001209, 0x16191513,   // sk.no..._660 en.id..._650 cs.lt..._440 lv.et.lt_665
  0x0f001214, 0x20004314, 0x27290107, 0x45121f14,   // cs.es..._660 vi.gl..._660 en.ms.id_432 ga.cs.sk_666
  0x0c002909, 0x2e004b02, 0x27291512, 0x2e3f0109,   // ms.pl..._440 az.sq..._220 lv.ms.id_654 en.sw.sq_444
  0x45003f13, 0x100b0209, 0x04050155, 0x29274209,   // sw.sk..._650 da.no.sv_444 en.fr.fi_442 mt.id.ms_444
  // [2500]
  0x1a020107, 0x2b8c6609, 0x06026655, 0x04001e02,   // en.da.xxx_432 af.ht.cy_444 af.da.de_442 sr.fi..._220
  0x1e1240a4, 0x66003809, 0x1a001912, 0x0f001222,   // sl.cs.sr_433 ca.af..._440 et.xxx..._640 cs.es..._870
  0x43272909, 0x17004014, 0x12454008, 0x04001402,   // ms.id.vi_444 sl.ro..._660 sl.sk.cs_443 is.fi..._220
  0x250e23a4, 0x1a3a21a4, 0x290b1a02, 0x3a000b07,   // uk.ru.mk_433 tl.eu.xxx_433 xxx.no.ms_222 no.eu..._420
  // [2510]
  0x20002914, 0x3f000b23, 0x18003a08, 0x1a000b14,   // ms.gl..._660 no.sw..._880 eu.hu..._430 no.xxx..._660
  0x27082908, 0x2e3f2907, 0x2e004313, 0x03660408,   // ms.it.id_443 ms.sw.sq_432 vi.sq..._650 fi.af.nl_443
  0x38004313, 0x0f380d60, 0x27004008, 0x15001e09,   // vi.ca..._650 pt.ca.es_664 sl.id..._430 sr.lv..._440
  0x1d1e1608, 0x08000d22, 0x1d1e4012, 0x03143a08,   // lt.sr.hr_443 pt.it..._870 sl.sr.hr_654 eu.is.nl_443
  // [2520]
  0x183a1408, 0x02140b13, 0x04000d02, 0x06000c08,   // is.eu.hu_443 no.is.da_665 pt.fi..._220 pl.de..._430
  0x8c001907, 0x01000808, 0x060c0208, 0x0d1f3810,   // et.ht..._420 it.en..._430 da.pl.de_443 ca.ga.pt_642
  0x01002707, 0x05000823, 0x45036660, 0x1d213f09,   // id.en..._420 it.fr..._880 af.nl.sk_664 sw.tl.hr_444
  0x060c2709, 0x45151702, 0x3f292713, 0x2b004b14,   // id.pl.de_444 ro.lv.sk_222 id.ms.sw_665 az.cy..._660
  // [2530]
  0x1d004208, 0x17041913, 0x2e003f11, 0x19660302,   // mt.hr..._430 et.fi.ro_665 sw.sq..._630 nl.af.et_222
  0x19041712, 0x19001d09, 0x16001213, 0x661516a4,   // ro.fi.et_654 hr.et..._440 cs.lt..._650 lt.lv.af_433
  0x8c060c08, 0x10000c02, 0x0c160408, 0x1a000514,   // pl.de.ht_443 pl.sv..._220 fi.lt.pl_443 fr.xxx..._660
  0x141a6612, 0x380f0d13, 0x1d180b08, 0x40001902,   // af.xxx.is_654 pt.es.ca_665 no.hu.hr_443 et.sl..._220
  // [2540]
  0x300e2355, 0x21002922, 0x273f29af, 0x29212707,   // uk.ru.be_442 ms.tl..._870 ms.sw.id_655 id.tl.ms_432
  0x27212914, 0x0f0d1807, 0x1c0e3013, 0x251e2313,   // ms.tl.id_666 hu.pt.es_432 be.ru.bg_665 uk.sr.mk_665
  0x12450202, 0x20001423, 0x14000607, 0x450d1a02,   // da.sk.cs_222 is.gl..._880 de.is..._420 xxx.pt.sk_222
  0x05020b60, 0x02000608, 0x29002b09, 0x21003f12,   // no.da.fr_664 de.da..._430 cy.ms..._440 sw.tl..._640
  // [2550]
  0x120d4513, 0x08063a08, 0x1a002702, 0x42004312,   // sk.pt.cs_665 eu.de.it_443 id.xxx..._220 vi.mt..._640
  0x0d124508, 0x42000209, 0x66030408, 0x38041612,   // sk.cs.pt_443 da.mt..._440 fi.nl.af_443 lt.fi.ca_654
  0x45003a13, 0x29001002, 0x45001a14, 0x03041909,   // eu.sk..._650 sv.ms..._220 xxx.sk..._660 et.fi.nl_444
  0x16040655, 0x29000413, 0x271d4002, 0x174b2212,   // de.fi.lt_442 fi.ms..._650 sl.hr.id_222 tr.az.ro_654
  // [2560]
  0x05003812, 0x12450612, 0x16450107, 0x22002e11,   // ca.fr..._640 de.sk.cs_654 en.sk.lt_432 sq.tr..._630
  0x3f000d13, 0x04100613, 0x3a000314, 0x1e451d13,   // pt.sw..._650 de.sv.fi_665 nl.eu..._660 hr.sk.sr_665
  0x45000612, 0x1c252309, 0x02001f23, 0x0b021008,   // de.sk..._640 uk.mk.bg_444 ga.da..._880 sv.da.no_443
  0x14180d07, 0x03196609, 0x03661909, 0x250e1eaf,   // pt.hu.is_432 af.et.nl_444 et.af.nl_444 sr.ru.mk_655
  // [2570]
  0x03001d09, 0x044b2212, 0x190666a4, 0x27000c09,   // hr.nl..._440 tr.az.fi_654 af.de.et_433 pl.id..._440
  0x3f661a12, 0x8c3805a4, 0x3f1a66af, 0x21004313,   // xxx.af.sw_654 fr.ca.ht_433 af.xxx.sw_655 vi.tl..._650
  0x06002e13, 0x08004222, 0x12001602, 0x18000522,   // sq.de..._650 mt.it..._870 lt.cs..._220 fr.hu..._870
  0x063a2b13, 0x19036660, 0x45051214, 0x4b00221f,   // cy.eu.de_665 af.nl.et_664 cs.fr.sk_666 tr.az..._840
  // [2580]
  0x050f38a4, 0x43001f12, 0x0f001f02, 0x12000d14,   // ca.es.fr_433 ga.vi..._640 ga.es..._220 pt.cs..._660
  0x38001023, 0x1d001e04, 0x66030607, 0x05002b14,   // sv.ca..._880 sr.hr..._320 de.nl.af_432 cy.fr..._660
  0x451e1d11, 0x2e451812, 0x03660612, 0x454012a4,   // hr.sr.sk_653 hu.sk.sq_654 de.af.nl_654 cs.sl.sk_433
  0x25003021, 0x21001813, 0x1e253013, 0x40008c02,   // be.mk..._860 hu.tl..._650 be.mk.sr_665 ht.sl..._220
  // [2590]
  0x8c004223, 0x1f0d0fa4, 0x05001e09, 0x10002909,   // mt.ht..._880 es.pt.ga_433 sr.fr..._440 ms.sv..._440
  0x033f0613, 0x01002e08, 0x4b000823, 0x21000614,   // de.sw.nl_665 sq.en..._430 it.az..._880 de.tl..._660
  0x45001521, 0x2e001722, 0x43002114, 0x19183fa4,   // lv.sk..._860 ro.sq..._870 tl.vi..._660 sw.hu.et_433
  0x10384208, 0x27002e23, 0x0d292708, 0x14042907,   // mt.ca.sv_443 sq.id..._880 id.ms.pt_443 ms.fi.is_432
  // [25a0]
  0x1a002107, 0x0d1f431f, 0x0c100208, 0x012b1708,   // tl.xxx..._420 vi.ga.pt_864 da.sv.pl_443 ro.cy.en_443
  0x29221902, 0x18141f55, 0x3f190408, 0x10030608,   // et.tr.ms_222 ga.is.hu_442 fi.et.sw_443 de.nl.sv_443
  0x04001722, 0x0d001f08, 0x0e1e3013, 0x10000b0d,   // ro.fi..._870 ga.pt..._430 be.sr.ru_665 no.sv..._540
  0x45061207, 0x2b060109, 0x04000312, 0x12214514,   // cs.de.sk_432 en.de.cy_444 nl.fi..._640 sk.tl.cs_666
  // [25b0]
  0x42000114, 0x1d2e1002, 0x1200181f, 0x45001912,   // en.mt..._660 sv.sq.hr_222 hu.cs..._840 et.sk..._640
  0x0c001914, 0x1d162e02, 0x1d1e2e12, 0x19003a12,   // et.pl..._660 sq.lt.hr_222 sq.sr.hr_654 eu.et..._640
  0x8c003812, 0x2e000409, 0x40002109, 0x18162108,   // ca.ht..._640 fi.sq..._440 tl.sl..._440 tl.lt.hu_443
  0x45001811, 0x05380d12, 0x1a000112, 0x058c3808,   // hu.sk..._630 pt.ca.fr_654 en.xxx..._640 ca.ht.fr_443
  // [25c0]
  0x450f0d02, 0x451d1055, 0x45124002, 0x2e004202,   // pt.es.sk_222 sv.hr.sk_442 sl.cs.sk_222 mt.sq..._220
  0x2e002123, 0x1d292102, 0x2e002113, 0x12000c12,   // tl.sq..._880 tl.ms.hr_222 tl.sq..._650 pl.cs..._640
  0x1e300e11, 0x152e3fa4, 0x1a080107, 0x1700121d,   // ru.be.sr_653 sw.sq.lv_433 en.it.xxx_432 cs.ro..._820
  0x1a3f2109, 0x45198c09, 0x14272908, 0x8c001f02,   // tl.sw.xxx_444 ht.et.sk_444 ms.id.is_443 ga.ht..._220
  // [25d0]
  0x43003f02, 0x1a8c3f11, 0x3a182207, 0x1d191e09,   // sw.vi..._220 sw.ht.xxx_653 tr.hu.eu_432 sr.et.hr_444
  0x0b020107, 0x19003a22, 0x0d451213, 0x06141007,   // en.da.no_432 eu.et..._870 cs.sk.pt_665 sv.is.de_432
  0x29012102, 0x290d4302, 0x43002b14, 0x0c0b4208,   // tl.en.ms_222 vi.pt.ms_222 cy.vi..._660 mt.no.pl_443
  0x19061209, 0x02004314, 0x66003a02, 0x04140b08,   // cs.de.et_444 vi.da..._660 eu.af..._220 no.is.fi_443
  // [25e0]
  0x662e0255, 0x14002102, 0x4b450507, 0x45101402,   // da.sq.af_442 tl.is..._220 fr.sk.az_432 is.sv.sk_222
  0x203a2709, 0x20003a22, 0x450d2002, 0x270c6602,   // id.eu.gl_444 eu.gl..._870 gl.pt.sk_222 af.pl.id_222
  0x15001714, 0x38001509, 0x1f3f2108, 0x293f2708,   // ro.lv..._660 lv.ca..._440 tl.sw.ga_443 id.sw.ms_443
  0x1e1d16a4, 0x1a223a07, 0x45401212, 0x1e1d4555,   // lt.hr.sr_433 eu.tr.xxx_432 cs.sl.sk_654 sk.hr.sr_442
  // [25f0]
  0x42001909, 0x271e2902, 0x38000214, 0x1e451d12,   // et.mt..._440 ms.sr.id_222 da.ca..._660 hr.sk.sr_654
  0x06002707, 0x22000523, 0x2e000d09, 0x03050107,   // id.de..._420 fr.tr..._880 pt.sq..._440 en.fr.nl_432
  0x1a001508, 0x3f030107, 0x15004514, 0x0b004509,   // lv.xxx..._430 en.nl.sw_432 sk.lv..._660 sk.no..._440
  0x4b662208, 0x22006623, 0x4b226614, 0x08272908,   // tr.af.az_443 af.tr..._880 af.tr.az_666 ms.id.it_443
  // [2600]
  0x0f204512, 0x21002b09, 0x8c2e2707, 0x193f04a4,   // sk.gl.es_654 cy.tl..._440 id.sq.ht_432 fi.sw.et_433
  0x1e1d0b07, 0x3f000b22, 0x4b226613, 0x19001a12,   // no.hr.sr_432 no.sw..._870 af.tr.az_665 xxx.et..._640
  0x42000c21, 0x0d000b02, 0x45041502, 0x0b001523,   // pl.mt..._860 no.pt..._220 lv.fi.sk_222 lv.no..._880
  0x22002e13, 0x40001709, 0x1e171d02, 0x0f220155,   // sq.tr..._650 ro.sl..._440 hr.ro.sr_222 en.tr.es_442
  // [2610]
  0x15004014, 0x27001e02, 0x0c004212, 0x06050b07,   // sl.lv..._660 sr.id..._220 mt.pl..._640 no.fr.de_432
  0x42000b23, 0x120f0d08, 0x0f001f07, 0x10001907,   // no.mt..._880 pt.es.cs_443 ga.es..._420 et.sv..._420
  0x03663f12, 0x03001809, 0x401d2108, 0x1a000c09,   // sw.af.nl_654 hu.nl..._440 tl.hr.sl_443 pl.xxx..._440
  0x402e0308, 0x300e1e08, 0x04221808, 0x08001413,   // nl.sq.sl_443 sr.ru.be_443 hu.tr.fi_443 is.it..._650
  // [2620]
  0x8c2e40af, 0x142e0109, 0x22002112, 0x1d400312,   // sl.sq.ht_655 en.sq.is_444 tl.tr..._640 nl.sl.hr_654
  0x08000209, 0x45008c22, 0x17002e13, 0x01000508,   // da.it..._440 ht.sk..._870 sq.ro..._650 fr.en..._430
  0x15402e60, 0x1d400302, 0x191a21a4, 0x29222702,   // sq.sl.lv_664 nl.sl.hr_222 tl.xxx.et_433 id.tr.ms_222
  0x3f004023, 0x43000802, 0x3f001e09, 0x4b211a55,   // sl.sw..._880 it.vi..._220 sr.sw..._440 xxx.tl.az_442
  // [2630]
  0x66003f12, 0x3a020b07, 0x0f041613, 0x27294302,   // sw.af..._640 no.da.eu_432 lt.fi.es_665 vi.ms.id_222
  0x3f660c12, 0x1a000209, 0x218c3faf, 0x06002908,   // pl.af.sw_654 da.xxx..._440 sw.ht.tl_655 ms.de..._430
  0x374e33a4, 0x1e001812, 0x251c2312, 0x66030609,   // ur.fa.ar_433 hu.sr..._640 uk.bg.mk_654 de.nl.af_444
  0x0d000508, 0x0f181faf, 0x29194b02, 0x4b192907,   // fr.pt..._430 ga.hu.es_655 az.et.ms_222 ms.et.az_432
  // [2640]
  0x03021209, 0x45042902, 0x8c3f2255, 0x294b8c08,   // cs.da.nl_444 ms.fi.sk_222 tr.sw.ht_442 ht.az.ms_443
  0x8c004b22, 0x1d003a02, 0x1e151612, 0x451f1702,   // az.ht..._870 eu.hr..._220 lt.lv.sr_654 ro.ga.sk_222
  0x29194b12, 0x1d161502, 0x22012108, 0x8c273f12,   // az.et.ms_654 lv.lt.hr_222 tl.en.tr_443 sw.id.ht_654
  0x14454208, 0x22194b08, 0x1e404507, 0x660c3f08,   // mt.sk.is_443 az.et.tr_443 sk.sl.sr_432 sw.pl.af_443
  // [2650]
  0x121f1412, 0x3a181a09, 0x0d224b07, 0x45120b60,   // is.ga.cs_654 xxx.hu.eu_444 az.tr.pt_432 no.cs.sk_664
  0x04000823, 0x38004212, 0x05000f08, 0x19001521,   // it.fi..._880 mt.ca..._640 es.fr..._430 lv.et..._860
  0x03001921, 0x8c3a2208, 0x0f003a22, 0x02223aa4,   // et.nl..._860 tr.eu.ht_443 eu.es..._870 eu.tr.da_433
  0x16451514, 0x8c002223, 0x2e294008, 0x8c001802,   // lv.sk.lt_666 tr.ht..._880 sl.ms.sq_443 hu.ht..._220
  // [2660]
  0x124519a4, 0x14060b09, 0x29001702, 0x14008c12,   // et.sk.cs_433 no.de.is_444 ro.ms..._220 ht.is..._640
  0x29661402, 0x29000502, 0x660d0360, 0x19066608,   // is.af.ms_222 fr.ms..._220 nl.pt.af_664 af.de.et_443
  0x8c100b07, 0x1f190612, 0x1d0c40a4, 0x29001d14,   // no.sv.ht_432 de.et.ga_654 sl.pl.hr_433 hr.ms..._660
  0x27004002, 0x122b04ac, 0x0b0314a4, 0x061410af,   // sl.id..._220 fi.cy.cs_632 is.nl.no_433 sv.is.de_655
  // [2670]
  0x0c190809, 0x05001402, 0x230e1e14, 0x22001f02,   // it.et.pl_444 is.fr..._220 sr.ru.uk_666 ga.tr..._220
  0x38140b09, 0x0b002014, 0x141e1d08, 0x1d3f0402,   // no.is.ca_444 gl.no..._660 hr.sr.is_443 fi.sw.hr_222
  0x0d001813, 0x1e001602, 0x0f004513, 0x171a42a4,   // hu.pt..._650 lt.sr..._220 sk.es..._650 mt.xxx.ro_433
  0x1a001902, 0x042b1412, 0x0f1245a4, 0x0f0c6602,   // et.xxx..._220 is.cy.fi_654 sk.cs.es_433 af.pl.es_222
  // [2680]
  0x3a030609, 0x05040612, 0x0f0d0808, 0x10000621,   // de.nl.eu_444 de.fi.fr_654 it.pt.es_443 de.sv..._860
  0x0f0d2108, 0x0d000f1f, 0x19036612, 0x29001812,   // tl.pt.es_443 es.pt..._840 af.nl.et_654 hu.ms..._640
  0x18001213, 0x401006ad, 0x18000c23, 0x42451207,   // cs.hu..._650 de.sv.sl_643 pl.hu..._880 cs.sk.mt_432
  0x2b000d09, 0x45150802, 0x0c000413, 0x18002212,   // pt.cy..._440 it.lv.sk_222 fi.pl..._650 tr.hu..._640
  // [2690]
  0x1d002b14, 0x21228c13, 0x278c0f02, 0x8c002121,   // cy.hr..._660 ht.tr.tl_665 es.ht.id_222 tl.ht..._860
  0x45008c12, 0x16170109, 0x04002b14, 0x38000d12,   // ht.sk..._640 en.ro.lt_444 cy.fi..._660 pt.ca..._640
  0x1d001409, 0x190406a4, 0x12003f12, 0x1f001d02,   // is.hr..._440 de.fi.et_433 sw.cs..._640 hr.ga..._220
  0x38000d21, 0x271d1502, 0x0c004223, 0x02001914,   // pt.ca..._860 lv.hr.id_222 mt.pl..._880 et.da..._660
  // [26a0]
  0x2e420408, 0x42002e14, 0x231c2509, 0x10002212,   // fi.mt.sq_443 sq.mt..._660 mk.bg.uk_444 tr.sv..._640
  0x198c3fad, 0x17000c09, 0x14124513, 0x0d001909,   // sw.ht.et_643 pl.ro..._440 sk.cs.is_665 et.pt..._440
  0x191a0107, 0x27294012, 0x19001a07, 0x2b170107,   // en.xxx.et_432 sl.ms.id_654 xxx.et..._420 en.ro.cy_432
  0x45222902, 0x29270802, 0x38430d12, 0x050f2909,   // ms.tr.sk_222 it.id.ms_222 pt.vi.ca_654 ms.es.fr_444
  // [26b0]
  0x21001a08, 0x060d1409, 0x1800140d, 0x38000302,   // xxx.tl..._430 is.pt.de_444 is.hu..._540 nl.ca..._220
  0x45002713, 0x12174502, 0x1f000b14, 0x20004509,   // id.sk..._650 sk.ro.cs_222 no.ga..._660 sk.gl..._440
  0x45000d13, 0x0d0c08a4, 0x03081208, 0x1e001702,   // pt.sk..._650 it.pl.pt_433 cs.it.nl_443 ro.sr..._220
  0x1a00240d, 0x14002914, 0x0f001509, 0x450b1602,   // hi.xxx..._540 ms.is..._660 lv.es..._440 lt.no.sk_222
  // [26c0]
  0x14451f60, 0x1c1e0e60, 0x27104002, 0x21006614,   // ga.sk.is_664 ru.sr.bg_664 sl.sv.id_222 af.tl..._660
  0x17003a14, 0x03660108, 0x38008c07, 0x0d001908,   // eu.ro..._660 en.af.nl_443 ht.ca..._420 et.pt..._430
  0x2b124513, 0x19041660, 0x45002213, 0x1a004b11,   // sk.cs.cy_665 lt.fi.et_664 tr.sk..._650 az.xxx..._630
  0x66001614, 0x66270608, 0x01181a08, 0x14000623,   // lt.af..._660 de.id.af_443 xxx.hu.en_443 de.is..._880
  // [26d0]
  0x0e252309, 0x19001f09, 0x121e1dad, 0x17001402,   // uk.mk.ru_444 ga.et..._440 hr.sr.cs_643 is.ro..._220
  0x0f380d07, 0x18001f23, 0x22000107, 0x02001007,   // pt.ca.es_432 ga.hu..._880 en.tr..._420 sv.da..._420
  0x02000814, 0x063a08a4, 0x1d4029af, 0x0c102b13,   // it.da..._660 it.eu.de_433 ms.sl.hr_655 cy.sv.pl_665
  0x23301c12, 0x08003a22, 0x18141760, 0x21000814,   // bg.be.uk_654 eu.it..._870 ro.is.hu_664 it.tl..._660
  // [26e0]
  0x19000213, 0x08000d21, 0x1f000b08, 0x04190308,   // da.et..._650 pt.it..._860 no.ga..._430 nl.et.fi_443
  0x22001e02, 0x15031a09, 0x05080108, 0x270f2b08,   // sr.tr..._220 xxx.nl.lv_444 en.it.fr_443 cy.es.id_443
  0x45000214, 0x010602a4, 0x3f036608, 0x43000609,   // da.sk..._660 da.de.en_433 af.nl.sw_443 de.vi..._440
  0x45010302, 0x423a0408, 0x17002202, 0x380f3a13,   // nl.en.sk_222 fi.eu.mt_443 tr.ro..._220 eu.es.ca_665
  // [26f0]
  0x0e231e12, 0x29008c13, 0x16001d02, 0x21048ca4,   // sr.uk.ru_654 ht.ms..._650 hr.lt..._220 ht.fi.tl_433
  0x66002707, 0x0e001e21, 0x1200451a, 0x05001812,   // id.af..._420 sr.ru..._860 sk.cs..._760 hu.fr..._640
  0x4b001707, 0x0c002114, 0x27004502, 0x04002b13,   // ro.az..._420 tl.pl..._660 sk.id..._220 cy.fi..._650
  0x06272907, 0x03180b09, 0x18020b08, 0x0f151a08,   // ms.id.de_432 no.hu.nl_444 no.da.hu_443 xxx.lv.es_443
  // [2700]
  0x272b2907, 0x1e000509, 0x17000314, 0x1c301e13,   // ms.cy.id_432 fr.sr..._440 nl.ro..._660 sr.be.bg_665
  0x1f004512, 0x0c030660, 0x03001923, 0x178c06af,   // sk.ga..._640 de.nl.pl_664 et.nl..._880 de.ht.ro_655
  0x29000823, 0x18001f20, 0x8c000813, 0x04000c14,   // it.ms..._880 ga.hu..._850 it.ht..._650 pl.fi..._660
  0x40000522, 0x4b003a08, 0x45403807, 0x278c2908,   // fr.sl..._870 eu.az..._430 ca.sl.sk_432 ms.ht.id_443
  // [2710]
  0x12050da4, 0x1a060107, 0x4e3337ad, 0x08001412,   // pt.fr.cs_433 en.de.xxx_432 ar.ur.fa_643 is.it..._640
  0x1f000c12, 0x0f451202, 0x17084212, 0x12451809,   // pl.ga..._640 cs.sk.es_222 mt.it.ro_654 hu.sk.cs_444
  0x042e2907, 0x124045af, 0x12450d14, 0x02001812,   // ms.sq.fi_432 sk.sl.cs_655 pt.sk.cs_666 hu.da..._640
  0x3a000107, 0x12450ca4, 0x18021aa4, 0x12456613,   // en.eu..._420 pl.sk.cs_433 xxx.da.hu_433 af.sk.cs_665
  // [2720]
  0x10030207, 0x38002102, 0x8c000b02, 0x14041908,   // da.nl.sv_432 tl.ca..._220 no.ht..._220 et.fi.is_443
  0x12451012, 0x0c000608, 0x1e452202, 0x12064502,   // sv.sk.cs_654 de.pl..._430 tr.sk.sr_222 sk.de.cs_222
  0x02002213, 0x45660302, 0x8c3f1508, 0x04002b09,   // tr.da..._650 nl.af.sk_222 lv.sw.ht_443 cy.fi..._440
  0x04004302, 0x211e1d12, 0x04002123, 0x3f001608,   // vi.fi..._220 hr.sr.tl_654 tl.fi..._880 lt.sw..._430
  // [2730]
  0x45120c02, 0x0f200107, 0x02063a08, 0x05292709,   // pl.cs.sk_222 en.gl.es_432 eu.de.da_443 id.ms.fr_444
  0x1f060108, 0x00000142, 0x14002923, 0x0c003814,   // en.de.ga_443 en......_C00 ms.is..._880 ca.pl..._660
  0x1d228c02, 0x1f008c08, 0x27453802, 0x12001a08,   // ht.tr.hr_222 ht.ga..._430 ca.sk.id_222 xxx.cs..._430
  0x27142960, 0x03661412, 0x0f380d13, 0x3f211aa4,   // ms.is.id_664 is.af.nl_654 pt.ca.es_665 xxx.tl.sw_433
  // [2740]
  0x22003a22, 0x2e001402, 0x1e300e08, 0x0d004512,   // eu.tr..._870 is.sq..._220 ru.be.sr_443 sk.pt..._640
  0x1d1e12af, 0x0f2b8c13, 0x251e2312, 0x3f190411,   // cs.sr.hr_655 ht.cy.es_665 uk.sr.mk_654 fi.et.sw_653
  0x1f001e14, 0x12290b07, 0x10002709, 0x0b036609,   // sr.ga..._660 no.ms.cs_432 id.sv..._440 af.nl.no_444
  0x011f8c09, 0x8c001623, 0x10002914, 0x20051709,   // ht.ga.en_444 lt.ht..._880 ms.sv..._660 ro.fr.gl_444
  // [2750]
  0x01040512, 0x0e231c08, 0x38000108, 0x12001f14,   // fr.fi.en_654 bg.uk.ru_443 en.ca..._430 ga.cs..._660
  0x17002212, 0x1e1d2902, 0x22000b02, 0x1d1e18a4,   // tr.ro..._640 ms.hr.sr_222 no.tr..._220 hu.sr.hr_433
  0x2b3f0c12, 0x1d401e60, 0x10000f02, 0x1a000108,   // pl.sw.cy_654 sr.sl.hr_664 es.sv..._220 en.xxx..._430
  0x19001608, 0x2b000c13, 0x03066614, 0x19001607,   // lt.et..._430 pl.cy..._650 af.de.nl_666 lt.et..._420
  // [2760]
  0x43061255, 0x0c162b12, 0x400c4509, 0x30250ea4,   // cs.de.vi_442 cy.lt.pl_654 sk.pl.sl_444 ru.mk.be_433
  0x06000213, 0x8c084208, 0x15002209, 0x04211909,   // da.de..._650 mt.it.ht_443 tr.lv..._440 et.tl.fi_444
  0x190366af, 0x21001909, 0x45004314, 0x22211a13,   // af.nl.et_655 et.tl..._440 vi.sk..._660 xxx.tl.tr_665
  0x183f1508, 0x0d121fba, 0x00001f42, 0x1a004323,   // lv.sw.hu_443 ga.cs.pt_843 ga......_C00 vi.xxx..._880
  // [2770]
  0x43001014, 0x00002b42, 0x12451002, 0x18451209,   // sv.vi..._660 cy......_C00 sv.sk.cs_222 cs.sk.hu_444
  0x45150b07, 0x04050b09, 0x29216602, 0x42000f14,   // no.lv.sk_432 no.fr.fi_444 af.tl.ms_222 es.mt..._660
  0x1a002112, 0x18001411, 0x3a001002, 0x12002109,   // tl.xxx..._640 is.hu..._630 sv.eu..._220 tl.cs..._440
  0x8c001002, 0x42001922, 0x1d222707, 0x4b221a13,   // sv.ht..._220 et.mt..._870 id.tr.hr_432 xxx.tr.az_665
  // [2780]
  0x43000608, 0x12660c08, 0x1d454009, 0x12422b60,   // de.vi..._430 pl.af.cs_443 sl.sk.hr_444 cy.mt.cs_664
  0x10001523, 0x66000813, 0x19001722, 0x02011a08,   // lv.sv..._880 it.af..._650 ro.et..._870 xxx.en.da_443
  0x1a180660, 0x10271fa4, 0x27100b09, 0x01061aa4,   // de.hu.xxx_664 ga.id.sv_433 no.sv.id_444 xxx.de.en_433
  0x2b002e14, 0x8c001823, 0x06001808, 0x01001409,   // sq.cy..._660 hu.ht..._880 hu.de..._430 is.en..._440
  // [2790]
  0x29423802, 0x18001713, 0x228c2907, 0x20001723,   // ca.mt.ms_222 ro.hu..._650 ms.ht.tr_432 ro.gl..._880
  0x1e1d4060, 0x1d001922, 0x128c4507, 0x27022902,   // sl.hr.sr_664 et.hr..._870 sk.ht.cs_432 ms.da.id_222
  0x23002508, 0x16000509, 0x12450209, 0x0f0518a4,   // mk.uk..._430 fr.lt..._440 da.sk.cs_444 hu.fr.es_433
  0x02001913, 0x23003009, 0x183a0508, 0x29004009,   // et.da..._650 be.uk..._440 fr.eu.hu_443 sl.ms..._440
  // [27a0]
  0x17053a08, 0x02100b07, 0x1e044002, 0x08000421,   // eu.fr.ro_443 no.sv.da_432 sl.fi.sr_222 fi.it..._860
  0x3f000107, 0x18001a14, 0x29170202, 0x1f000122,   // en.sw..._420 xxx.hu..._660 da.ro.ms_222 en.ga..._870
  0x032e42a4, 0x1f001702, 0x66180308, 0x17003f09,   // mt.sq.nl_433 ro.ga..._220 nl.hu.af_443 sw.ro..._440
  0x192702a4, 0x40001402, 0x14003808, 0x184512ad,   // da.id.et_433 is.sl..._220 ca.is..._430 cs.sk.hu_643
  // [27b0]
  0x27151055, 0x190b04a4, 0x19002121, 0x4b001a22,   // sv.lv.id_442 fi.no.et_433 tl.et..._860 xxx.az..._870
  0x38180107, 0x0f002202, 0x401d0307, 0x060b0208,   // en.hu.ca_432 tr.es..._220 nl.hr.sl_432 da.no.de_443
  0x0c450612, 0x05000813, 0x00003f42, 0x00001042,   // de.sk.pl_654 it.fr..._650 sw......_C00 sv......_C00
  0x21003a22, 0x29272112, 0x00004242, 0x660340af,   // eu.tl..._870 tl.id.ms_654 mt......_C00 sl.nl.af_655
  // [27c0]
  0x2e660309, 0x43001a07, 0x01001a13, 0x15000f12,   // nl.af.sq_444 xxx.vi..._420 xxx.en..._650 es.lv..._640
  0x29273f09, 0x27000308, 0x0e232508, 0x8c004014,   // sw.id.ms_444 nl.id..._430 mk.uk.ru_443 sl.ht..._660
  0x18151655, 0x3f002223, 0x1f081709, 0x01101a08,   // lt.lv.hu_442 tr.sw..._880 ro.it.ga_444 xxx.sv.en_443
  0x22290109, 0x17420107, 0x43003f14, 0x450d4302,   // en.ms.tr_444 en.mt.ro_432 sw.vi..._660 vi.pt.sk_222
  // [27d0]
  0x0d004321, 0x190604a4, 0x29000402, 0x161d0412,   // vi.pt..._860 fi.de.et_433 fi.ms..._220 fi.hr.lt_654
  0x17000d11, 0x0d0f3813, 0x3a008c13, 0x061e1d09,   // pt.ro..._630 ca.es.pt_665 ht.eu..._650 hr.sr.de_444
  0x1e181da4, 0x151d1e60, 0x0b002709, 0x450d3a02,   // hr.hu.sr_433 sr.hr.lv_664 id.no..._440 eu.pt.sk_222
  0x45001514, 0x04000114, 0x0d0f0512, 0x3f122e08,   // lv.sk..._660 en.fi..._660 fr.es.pt_654 sq.cs.sw_443
  // [27e0]
  0x15002e08, 0x40001a09, 0x12451813, 0x1f002002,   // sq.lv..._430 xxx.sl..._440 hu.sk.cs_665 gl.ga..._220
  0x45001f02, 0x1f0f1814, 0x2e1f20a4, 0x40082e12,   // ga.sk..._220 hu.es.ga_666 gl.ga.sq_433 sq.it.sl_654
  0x42001213, 0x12001a07, 0x2e100b07, 0x02060109,   // cs.mt..._650 xxx.cs..._420 no.sv.sq_432 en.de.da_444
  0x43001f13, 0x1e003f08, 0x0b021407, 0x66000c02,   // ga.vi..._650 sw.sr..._430 is.da.no_432 pl.af..._220
  // [27f0]
  0x041d1e09, 0x02002702, 0x19000b08, 0x231c2508,   // sr.hr.fi_444 id.da..._220 no.et..._430 mk.bg.uk_443
  0x0b002b09, 0x66008c02, 0x04661208, 0x20050107,   // cy.no..._440 ht.af..._220 cs.af.fi_443 en.fr.gl_432
  0x05001207, 0x0e003008, 0x0f001807, 0x0c4540af,   // cs.fr..._420 be.ru..._430 hu.es..._420 sl.sk.pl_655
  0x17220460, 0x38000b02, 0x06004022, 0x300e1e13,   // fi.tr.ro_664 no.ca..._220 sl.de..._870 sr.ru.be_665

  // [2800]
  0x08003822, 0x2b002914, 0x4b272907, 0x22000c13,   // ca.it..._870 ms.cy..._660 ms.id.az_432 pl.tr..._650
  0x27001a07, 0x19010b09, 0x1d001713, 0x17000208,   // xxx.id..._420 no.en.et_444 ro.hr..._650 da.ro..._430
  0x0b026614, 0x01171f12, 0x12292702, 0x43001821,   // af.da.no_666 ga.ro.en_654 id.ms.cs_222 hu.vi..._860
  0x43001813, 0x66001723, 0x66000222, 0x101402a4,   // hu.vi..._650 ro.af..._880 da.af..._870 da.is.sv_433
  // [2810]
  0x17002b22, 0x05004312, 0x14000221, 0x17001913,   // cy.ro..._870 vi.fr..._640 da.is..._860 et.ro..._650
  0x060366af, 0x45002114, 0x21043f09, 0x080f0107,   // af.nl.de_655 tl.sk..._660 sw.fi.tl_444 en.es.it_432
  0x27002113, 0x212927af, 0x1d400c02, 0x1a000d02,   // tl.id..._650 id.ms.tl_655 pl.sl.hr_222 pt.xxx..._220
  0x21001a23, 0x45122902, 0x0c003808, 0x3f1f8c07,   // xxx.tl..._880 ms.cs.sk_222 ca.pl..._430 ht.ga.sw_432
  // [2820]
  0x0c000802, 0x0e002523, 0x45383a02, 0x25301e14,   // it.pl..._220 mk.ru..._880 eu.ca.sk_222 sr.be.mk_666
  0x8c002923, 0x23000e11, 0x8c663f07, 0x15002913,   // ms.ht..._880 ru.uk..._630 sw.af.ht_432 ms.lv..._650
  0x2e003a02, 0x08000602, 0x1a386608, 0x8c0c3f12,   // eu.sq..._220 de.it..._220 af.ca.xxx_443 sw.pl.ht_654
  0x10140208, 0x22003802, 0x052119a4, 0x03100208,   // da.is.sv_443 ca.tr..._220 et.tl.fr_433 da.sv.nl_443
  // [2830]
  0x42082908, 0x02100660, 0x1e1d0255, 0x1f271a13,   // ms.it.mt_443 de.sv.da_664 da.hr.sr_442 xxx.id.ga_665
  0x19421409, 0x40001908, 0x19004514, 0x2e036612,   // is.mt.et_444 et.sl..._430 sk.et..._660 af.nl.sq_654
  0x4b000d14, 0x06003f09, 0x45002223, 0x1d001621,   // pt.az..._660 sw.de..._440 tr.sk..._880 lt.hr..._860
  0x12160c02, 0x27000b09, 0x66001702, 0x0c404555,   // pl.lt.cs_222 no.id..._440 ro.af..._220 sk.sl.pl_442
  // [2840]
  0x290f1002, 0x2e292760, 0x1e8c1d02, 0x29431a02,   // sv.es.ms_222 id.ms.sq_664 hr.ht.sr_222 xxx.vi.ms_222
  0x43003814, 0x45011a02, 0x29402ba4, 0x2e040107,   // ca.vi..._660 xxx.en.sk_222 cy.sl.ms_433 en.fi.sq_432
  0x14002713, 0x29100202, 0x14184560, 0x12180d09,   // id.is..._650 da.sv.ms_222 sk.hu.is_664 pt.hu.cs_444
  0x17000602, 0x27000602, 0x37003307, 0x2b000c23,   // de.ro..._220 de.id..._220 ur.ar..._420 pl.cy..._880
  // [2850]
  0x200f0b07, 0x2e061912, 0x45002e12, 0x02182e12,   // no.es.gl_432 et.de.sq_654 sq.sk..._640 sq.hu.da_654
  0x40001522, 0x06026612, 0x12034302, 0x06000512,   // lv.sl..._870 af.da.de_654 vi.nl.cs_222 fr.de..._640
  0x181066a4, 0x10051a08, 0x45000d14, 0x230e3011,   // af.sv.hu_433 xxx.fr.sv_443 pt.sk..._660 be.ru.uk_653
  0x660619a4, 0x19272907, 0x45030202, 0x19004b22,   // et.de.af_433 ms.id.et_432 da.nl.sk_222 az.et..._870
  // [2860]
  0x19004b23, 0x66051408, 0x02004008, 0x0d0f0855,   // az.et..._880 is.fr.af_443 sl.da..._430 it.es.pt_442
  0x0c0f0d55, 0x10004b02, 0x08001d02, 0x4b172208,   // pt.es.pl_442 az.sv..._220 hr.it..._220 tr.ro.az_443
  0x14020b60, 0x17004310, 0x154b2208, 0x1e3a1d02,   // no.da.is_664 vi.ro..._620 tr.az.lv_443 hr.eu.sr_222
  0x380f0d02, 0x45380f07, 0x1e041d08, 0x1e402702,   // pt.es.ca_222 es.ca.sk_432 hr.fi.sr_443 id.sl.sr_222
  // [2870]
  0x1f000d09, 0x14660309, 0x45123a08, 0x3a004507,   // pt.ga..._440 nl.af.is_444 eu.cs.sk_443 sk.eu..._420
  0x45120c55, 0x212927a4, 0x422927a4, 0x21001420,   // pl.cs.sk_442 id.ms.tl_433 id.ms.mt_433 is.tl..._850
  0x29001414, 0x1d213f02, 0x381614a4, 0x380d0faf,   // is.ms..._660 sw.tl.hr_222 is.lt.ca_433 es.pt.ca_655
  0x17001d14, 0x2b000f22, 0x20002709, 0x05000102,   // hr.ro..._660 es.cy..._870 id.gl..._440 en.fr..._220
  // [2880]
  0x2e000108, 0x140b0255, 0x25000e09, 0x064543a4,   // en.sq..._430 da.no.is_442 ru.mk..._440 vi.sk.de_433
  0x02052e12, 0x2e000113, 0x45000308, 0x40002709,   // sq.fr.da_654 en.sq..._650 nl.sk..._430 id.sl..._440
  0x0b000d14, 0x1f3a2909, 0x40000f02, 0x22002923,   // pt.no..._660 ms.eu.ga_444 es.sl..._220 ms.tr..._880
  0x052e38a4, 0x4b001912, 0x20380b07, 0x0d050107,   // ca.sq.fr_433 et.az..._640 no.ca.gl_432 en.fr.pt_432
  // [2890]
  0x2e424b60, 0x271a4202, 0x0f008c08, 0x12452002,   // az.mt.sq_664 mt.xxx.id_222 ht.es..._430 gl.sk.cs_222
  0x12144514, 0x0d0f0813, 0x0f080d09, 0x00001a42,   // sk.is.cs_666 it.es.pt_665 pt.it.es_444 xxx......_C00
  0x0e231e60, 0x382b05a4, 0x14000f07, 0x38052909,   // sr.uk.ru_664 fr.cy.ca_433 es.is..._420 ms.fr.ca_444
  0x19380509, 0x0d001713, 0x05002714, 0x66033a08,   // fr.ca.et_444 ro.pt..._650 id.fr..._660 eu.nl.af_443
  // [28a0]
  0x02001a23, 0x2b003a08, 0x04002e08, 0x663a2bad,   // xxx.da..._880 eu.cy..._430 sq.fi..._430 cy.eu.af_643
  0x0d002223, 0x66030508, 0x17002023, 0x0d000808,   // tr.pt..._880 fr.nl.af_443 gl.ro..._880 it.pt..._430
  0x4b1822ad, 0x15006614, 0x15190412, 0x17061808,   // tr.hu.az_643 af.lv..._660 fi.et.lv_654 hu.de.ro_443
  0x060812a4, 0x3f032108, 0x14001509, 0x10061807,   // cs.it.de_433 tl.nl.sw_443 lv.is..._440 hu.de.sv_432
  // [28b0]
  0x3f004220, 0x3f002112, 0x43003823, 0x1a000402,   // mt.sw..._850 tl.sw..._640 ca.vi..._880 fi.xxx..._220
  0x18002907, 0x103a0b08, 0x1a423fa4, 0x37334ea4,   // ms.hu..._420 no.eu.sv_443 sw.mt.xxx_433 fa.ur.ar_433
  0x273f21ad, 0x21000c08, 0x1c000e07, 0x450d3a60,   // tl.sw.id_643 pl.tl..._430 ru.bg..._420 eu.pt.sk_664
  0x45001608, 0x250e2355, 0x10660255, 0x450421a4,   // lt.sk..._430 uk.ru.mk_442 da.af.sv_442 tl.fi.sk_433
  // [28c0]
  0x2e170b07, 0x21001622, 0x17000523, 0x8c002b23,   // no.ro.sq_432 lt.tl..._870 fr.ro..._880 cy.ht..._880
  0x29228c08, 0x013a0b08, 0x12220108, 0x0f080d60,   // ht.tr.ms_443 no.eu.en_443 en.tr.cs_443 pt.it.es_664
  0x14001702, 0x10000808, 0x15000308, 0x140f18af,   // ro.is..._220 it.sv..._430 nl.lv..._430 hu.es.is_655
  0x080d3f07, 0x27000f02, 0x18380d08, 0x12006614,   // sw.pt.it_432 es.id..._220 pt.ca.hu_443 af.cs..._660
  // [28d0]
  0x23002522, 0x0e1e2560, 0x230e2509, 0x3a003f23,   // mk.uk..._870 mk.sr.ru_664 mk.ru.uk_444 sw.eu..._880
  0x17003f02, 0x0c1a3f09, 0x15001712, 0x8c183f08,   // sw.ro..._220 sw.xxx.pl_444 ro.lv..._640 sw.hu.ht_443
  0x05000b14, 0x05038c08, 0x2e001608, 0x0d0f14a4,   // no.fr..._660 ht.nl.fr_443 lt.sq..._430 is.es.pt_433
  0x3a000802, 0x4b0d22a4, 0x0f003a07, 0x16002e13,   // it.eu..._220 tr.pt.az_433 eu.es..._420 sq.lt..._650
  // [28e0]
  0x4b000b02, 0x0c003a12, 0x06001502, 0x42002209,   // no.az..._220 eu.pl..._640 lv.de..._220 tr.mt..._440
  0x124518a4, 0x450c4002, 0x3f3a0807, 0x3a000812,   // hu.sk.cs_433 sl.pl.sk_222 it.eu.sw_432 it.eu..._640
  0x66060302, 0x8c3a08a4, 0x3a000823, 0x05000c02,   // nl.de.af_222 it.eu.ht_433 it.eu..._880 pl.fr..._220
  0x181d1e07, 0x05031a08, 0x8c100b12, 0x1d401802,   // sr.hr.hu_432 xxx.nl.fr_443 no.sv.ht_654 hu.sl.hr_222
  // [28f0]
  0x3a000d09, 0x20004014, 0x1a3f1808, 0x45290808,   // pt.eu..._440 sl.gl..._660 hu.sw.xxx_443 it.ms.sk_443
  0x3f003802, 0x0c000623, 0x1e212707, 0x16001908,   // ca.sw..._220 de.pl..._880 id.tl.sr_432 et.lt..._430
  0x17003a23, 0x3f4b2907, 0x45001014, 0x1e002e02,   // eu.ro..._880 ms.az.sw_432 sv.sk..._660 sq.sr..._220
  0x22004b07, 0x424b2709, 0x451a0502, 0x22218c13,   // az.tr..._420 id.az.mt_444 fr.xxx.sk_222 ht.tl.tr_665
  // [2900]
  0x21008c22, 0x04003809, 0x38000507, 0x1a004514,   // ht.tl..._870 ca.fi..._440 fr.ca..._420 sk.xxx..._660
  0x4b3a2212, 0x3a008c08, 0x14000223, 0x662e1455,   // tr.eu.az_654 ht.eu..._430 da.is..._880 is.sq.af_442
  0x451a2902, 0x05004302, 0x8c002113, 0x0d011aa4,   // ms.xxx.sk_222 vi.fr..._220 tl.ht..._650 xxx.en.pt_433
  0x45388c12, 0x8c150514, 0x1e451208, 0x15000412,   // ht.ca.sk_654 fr.lv.ht_666 cs.sk.sr_443 fi.lv..._640
  // [2910]
  0x19000c14, 0x1d006609, 0x1d1021a4, 0x121d4507,   // pl.et..._660 af.hr..._440 tl.sv.hr_433 sk.hr.cs_432
  0x43001e02, 0x0c001923, 0x17008c23, 0x02003f02,   // sr.vi..._220 et.pl..._880 ht.ro..._880 sw.da..._220
  0x3a1d8ca4, 0x27001912, 0x8c003a21, 0x05001a12,   // ht.hr.eu_433 et.id..._640 eu.ht..._860 xxx.fr..._640
  0x1d0c4009, 0x162217af, 0x27221f08, 0x27222909,   // sl.pl.hr_444 ro.tr.lt_655 ga.tr.id_443 ms.tr.id_444
  // [2920]
  0x06003a12, 0x4b2221a4, 0x27142102, 0x17004209,   // eu.de..._640 tl.tr.az_433 tl.is.id_222 mt.ro..._440
  0x1e003f02, 0x301e2560, 0x14020b13, 0x1f002e02,   // sw.sr..._220 mk.sr.be_664 no.da.is_665 sq.ga..._220
  0x152e3808, 0x66002b07, 0x1d021a08, 0x04001f22,   // ca.sq.lv_443 cy.af..._420 xxx.da.hr_443 ga.fi..._870
  0x1f000b12, 0x03186609, 0x17190107, 0x45278c02,   // no.ga..._640 af.hu.nl_444 en.et.ro_432 ht.id.sk_222
  // [2930]
  0x15001423, 0x66060307, 0x1e1d1514, 0x66181909,   // is.lv..._880 nl.de.af_432 lv.hr.sr_666 et.hu.af_444
  0x06003f23, 0x10182e13, 0x06002923, 0x22001822,   // sw.de..._880 sq.hu.sv_665 ms.de..._880 hu.tr..._870
  0x020b1414, 0x19001812, 0x27291a02, 0x1e1d2e60,   // is.no.da_666 hu.et..._640 xxx.ms.id_222 sq.hr.sr_664
  0x061a2709, 0x21000602, 0x27062902, 0x29011a07,   // id.xxx.de_444 de.tl..._220 ms.de.id_222 xxx.en.ms_432
  // [2940]
  0x29212714, 0x3a212709, 0x18144360, 0x3f272909,   // id.tl.ms_666 id.tl.eu_444 vi.is.hu_664 ms.id.sw_444
  0x19061009, 0x066603a4, 0x02000612, 0x45014302,   // sv.de.et_444 nl.af.de_433 de.da..._640 vi.en.sk_222
  0x12450ba4, 0x40451207, 0x45660b07, 0x29270107,   // no.sk.cs_433 cs.sk.sl_432 no.af.sk_432 en.id.ms_432
  0x18192208, 0x01104202, 0x450f1f08, 0x194b22af,   // tr.et.hu_443 mt.sv.en_222 ga.es.sk_443 tr.az.et_655
  // [2950]
  0x0c081e08, 0x4b292709, 0x3f0c4255, 0x1d001823,   // sr.it.pl_443 id.ms.az_444 mt.pl.sw_442 hu.hr..._880
  0x45402102, 0x17101207, 0x184b2214, 0x0d002914,   // tl.sl.sk_222 cs.sv.ro_432 tr.az.hu_666 ms.pt..._660
  0x4b000b09, 0x293a2714, 0x03660b09, 0x21163a07,   // no.az..._440 id.eu.ms_666 no.af.nl_444 eu.lt.tl_432
  0x15380513, 0x2b660360, 0x05388c12, 0x058c3812,   // fr.ca.lv_665 nl.af.cy_664 ht.ca.fr_654 ca.ht.fr_654
  // [2960]
  0x19002723, 0x45121612, 0x1d000314, 0x25001c11,   // id.et..._880 lt.cs.sk_654 nl.hr..._660 bg.mk..._630
  0x38008c12, 0x8c003814, 0x3f000c08, 0x06001413,   // ht.ca..._640 ca.ht..._660 pl.sw..._430 is.de..._650
  0x8c3805af, 0x0e252311, 0x1d1240a4, 0x15121ea4,   // fr.ca.ht_655 uk.mk.ru_653 sl.cs.hr_433 sr.cs.lv_433
  0x1e451207, 0x1f001808, 0x3f421a09, 0x19004208,   // cs.sk.sr_432 hu.ga..._430 xxx.mt.sw_444 mt.et..._430
  // [2970]
  0x184b2212, 0x06000521, 0x06272909, 0x1d3f1f55,   // tr.az.hu_654 fr.de..._860 ms.id.de_444 ga.sw.hr_442
  0x8c002723, 0x05180107, 0x27170608, 0x1d124507,   // id.ht..._880 en.hu.fr_432 de.ro.id_443 sk.cs.hr_432
  0x1f3f0d55, 0x08000d08, 0x02061060, 0x17002908,   // pt.sw.ga_442 pt.it..._430 sv.de.da_664 ms.ro..._430
  0x1a002209, 0x01001802, 0x1a000d14, 0x40124512,   // tr.xxx..._440 hu.en..._220 pt.xxx..._660 sk.cs.sl_654
  // [2980]
  0x8c222108, 0x03436602, 0x1d1e3fa4, 0x020b1013,   // tl.tr.ht_443 af.vi.nl_222 sw.sr.hr_433 sv.no.da_665
  0x19003f13, 0x3f000412, 0x45180d02, 0x22001707,   // sw.et..._650 fi.sw..._640 pt.hu.sk_222 ro.tr..._420
  0x03001908, 0x02000b10, 0x1a293f13, 0x3f124508,   // et.nl..._430 no.da..._620 sw.ms.xxx_665 sk.cs.sw_443
  0x10004514, 0x12003f09, 0x0f041713, 0x66001a09,   // sk.sv..._660 sw.cs..._440 ro.fi.es_665 xxx.af..._440
  // [2990]
  0x66034207, 0x200d0faf, 0x1a228c08, 0x018c2107,   // mt.nl.af_432 es.pt.gl_655 ht.tr.xxx_443 tl.ht.en_432
  0x183a1a08, 0x12104502, 0x0d002b09, 0x451d1708,   // xxx.eu.hu_443 sk.sv.cs_222 cy.pt..._440 ro.hr.sk_443
  0x03064209, 0x3f000622, 0x04006612, 0x1e2e1d12,   // mt.de.nl_444 de.sw..._870 af.fi..._640 hr.sq.sr_654
  0x1d081402, 0x14101a09, 0x1d004022, 0x451218ba,   // is.it.hr_222 xxx.sv.is_444 sl.hr..._870 hu.cs.sk_843
  // [29a0]
  0x66000607, 0x250e1c07, 0x42001d14, 0x08184212,   // de.af..._420 bg.ru.mk_432 hr.mt..._660 mt.hu.it_654
  0x45228c02, 0x0e231c11, 0x380f0daf, 0x03002208,   // ht.tr.sk_222 bg.uk.ru_653 pt.es.ca_655 tr.nl..._430
  0x271f1a02, 0x03668ca4, 0x06006607, 0x45121860,   // xxx.ga.id_222 ht.af.nl_433 af.de..._420 hu.cs.sk_664
  0x231e2514, 0x01660355, 0x06041009, 0x45002123,   // mk.sr.uk_666 nl.af.en_442 sv.fi.de_444 tl.sk..._880
  // [29b0]
  0x14020660, 0x10140b13, 0x8c002122, 0x38000c13,   // de.da.is_664 no.is.sv_665 tl.ht..._870 pl.ca..._650
  0x12000608, 0x17002e02, 0x1d2e1e08, 0x0f000609,   // de.cs..._430 sq.ro..._220 sr.sq.hr_443 de.es..._440
  0x2b001a14, 0x2b002e22, 0x27290d02, 0x100b02a4,   // xxx.cy..._660 sq.cy..._870 pt.ms.id_222 da.no.sv_433
  0x0d004507, 0x08420614, 0x04006623, 0x2b006623,   // sk.pt..._420 de.mt.it_666 af.fi..._880 af.cy..._880
  // [29c0]
  0x45222e09, 0x43124508, 0x19041055, 0x041d2e09,   // sq.tr.sk_444 sk.cs.vi_443 sv.fi.et_442 sq.hr.fi_444
  0x1d001207, 0x18124512, 0x4b0538a4, 0x0c452907,   // cs.hr..._420 sk.cs.hu_654 ca.fr.az_433 ms.sk.pl_432
  0x21002209, 0x17001f12, 0x21002202, 0x020b06af,   // tr.tl..._440 ga.ro..._640 tr.tl..._220 de.no.da_655
  0x21000502, 0x01066608, 0x05001807, 0x38211555,   // fr.tl..._220 af.de.en_443 hu.fr..._420 lv.tl.ca_442
  // [29d0]
  0x14001a02, 0x22002e08, 0x1e1c0e13, 0x0f0c2ba4,   // xxx.is..._220 sq.tr..._430 ru.bg.sr_665 cy.pl.es_433
  0x21004308, 0x1d0c4212, 0x14193f14, 0x3a401560,   // vi.tl..._430 mt.pl.hr_654 sw.et.is_666 lv.sl.eu_664
  0x40003a02, 0x14000c23, 0x1f004009, 0x450c1055,   // eu.sl..._220 pl.is..._880 sl.ga..._440 sv.pl.sk_442
  0x15000314, 0x45030602, 0x1f004509, 0x18001a02,   // nl.lv..._660 de.nl.sk_222 sk.ga..._440 xxx.hu..._220
  // [29e0]
  0x0f008c23, 0x0d080f08, 0x45000409, 0x2e020b07,   // ht.es..._880 es.it.pt_443 fi.sk..._440 no.da.sq_432
  0x40451208, 0x27291407, 0x0b002e13, 0x03660109,   // cs.sk.sl_443 is.ms.id_432 sq.no..._650 en.af.nl_444
  0x04190109, 0x08004212, 0x292721af, 0x3a428c13,   // en.et.fi_444 mt.it..._640 tl.id.ms_655 ht.mt.eu_665
  0x2b1f14a4, 0x026621af, 0x66002121, 0x1e231c02,   // is.ga.cy_433 tl.af.da_655 tl.af..._860 bg.uk.sr_222
  // [29f0]
  0x66002702, 0x16004502, 0x08203809, 0x03001713,   // id.af..._220 sk.lt..._220 ca.gl.it_444 ro.nl..._650
  0x1d121e07, 0x19170212, 0x16001813, 0x3a004212,   // sr.cs.hr_432 da.ro.et_654 hu.lt..._650 mt.eu..._640
  0x1c1e0e08, 0x10001902, 0x1e031d12, 0x40001008,   // ru.sr.bg_443 et.sv..._220 hr.nl.sr_654 sv.sl..._430
  0x3f001409, 0x224b1209, 0x04000c13, 0x14190baf,   // is.sw..._440 cs.az.tr_444 pl.fi..._650 no.et.is_655
  // [2a00]
  0x14002e14, 0x45041908, 0x0d3a2b12, 0x1a000809,   // sq.is..._660 et.fi.sk_443 cy.eu.pt_654 it.xxx..._440
  0x42008c09, 0x1f000b02, 0x27066602, 0x3a041908,   // ht.mt..._440 no.ga..._220 af.de.id_222 et.fi.eu_443
  0x19001f23, 0x8c3f1712, 0x3f004013, 0x19043a14,   // ga.et..._880 ro.sw.ht_654 sl.sw..._650 eu.fi.et_666
  0x12004202, 0x12058c55, 0x0d001d02, 0x06003f13,   // mt.cs..._220 ht.fr.cs_442 hr.pt..._220 sw.de..._650
  // [2a10]
  0x0d002108, 0x120b0555, 0x1d000b02, 0x4b001623,   // tl.pt..._430 fr.no.cs_442 no.hr..._220 lt.az..._880
  0x1c001e08, 0x0d001d23, 0x12224209, 0x15000514,   // sr.bg..._430 hr.pt..._880 mt.tr.cs_444 fr.lv..._660
  0x1a003a13, 0x03170512, 0x15003809, 0x16001409,   // eu.xxx..._650 fr.ro.nl_654 ca.lv..._440 is.lt..._440
  0x06021008, 0x19046608, 0x0b000609, 0x12028c08,   // sv.da.de_443 af.fi.et_443 de.no..._440 ht.da.cs_443
  // [2a20]
  0x43000508, 0x251c2308, 0x18001409, 0x17001a09,   // fr.vi..._430 uk.bg.mk_443 is.hu..._440 xxx.ro..._440
  0x4b000109, 0x433f2b07, 0x292742a4, 0x66030b09,   // en.az..._440 cy.sw.vi_432 mt.id.ms_433 no.nl.af_444
  0x29273aa4, 0x27222102, 0x45001507, 0x8c002e02,   // eu.id.ms_433 tl.tr.id_222 lv.sk..._420 sq.ht..._220
  0x27451555, 0x17041907, 0x02104209, 0x45151902,   // lv.sk.id_442 et.fi.ro_432 mt.sv.da_444 et.lv.sk_222
  // [2a30]
  0x27290409, 0x220d0109, 0x3f1a0409, 0x3f001512,   // fi.ms.id_444 en.pt.tr_444 fi.xxx.sw_444 lv.sw..._640
  0x1e1d3a12, 0x293f1f02, 0x16001909, 0x38004b08,   // eu.hr.sr_654 ga.sw.ms_222 et.lt..._440 az.ca..._430
  0x10064b08, 0x1d453a02, 0x04053fa4, 0x40003a14,   // az.de.sv_443 eu.sk.hr_222 sw.fr.fi_433 eu.sl..._660
  0x12453f02, 0x193a2108, 0x2b000d07, 0x0b023fa4,   // sw.sk.cs_222 tl.eu.et_443 pt.cy..._420 sw.da.no_433
  // [2a40]
  0x12064507, 0x12000508, 0x4b002b12, 0x3a450302,   // sk.de.cs_432 fr.cs..._430 cy.az..._640 nl.sk.eu_222
  0x22001a23, 0x191f0408, 0x16000202, 0x2e001007,   // xxx.tr..._880 fi.ga.et_443 da.lt..._220 sv.sq..._420
  0x40000402, 0x2b0b0260, 0x1e002e12, 0x1d194002,   // fi.sl..._220 da.no.cy_664 sq.sr..._640 sl.et.hr_222
  0x2b020b09, 0x18004314, 0x020b2e08, 0x42001908,   // no.da.cy_444 vi.hu..._660 sq.no.da_443 et.mt..._430
  // [2a50]
  0x298c0108, 0x14003a13, 0x08193aa4, 0x12000202,   // en.ht.ms_443 eu.is..._650 eu.et.it_433 da.cs..._220
  0x02000314, 0x291704a4, 0x214318a4, 0x21036608,   // nl.da..._660 fi.ro.ms_433 hu.vi.tl_433 af.nl.tl_443
  0x21003f07, 0x1f062b09, 0x052b1a08, 0x03003f07,   // sw.tl..._420 cy.de.ga_444 xxx.cy.fr_443 sw.nl..._420
  0x0f1f3808, 0x18080109, 0x1f002e08, 0x19181a09,   // ca.ga.es_443 en.it.hu_444 sq.ga..._430 xxx.hu.et_444
  // [2a60]
  0x08380d60, 0x10021912, 0x0c1e1d12, 0x453f0107,   // pt.ca.it_664 et.da.sv_654 hr.sr.pl_654 en.sw.sk_432
  0x45194202, 0x0d380fa4, 0x05380109, 0x0d661707,   // mt.et.sk_222 es.ca.pt_433 en.ca.fr_444 ro.af.pt_432
  0x08000b08, 0x10011a08, 0x4b3f0109, 0x190b0107,   // no.it..._430 xxx.en.sv_443 en.sw.az_444 en.no.et_432
  0x40001502, 0x0d018c02, 0x18140b08, 0x1e1d1413,   // lv.sl..._220 ht.en.pt_222 no.is.hu_443 is.hr.sr_665
  // [2a70]
  0x10124511, 0x0d0f4209, 0x03001012, 0x0f004508,   // sk.cs.sv_653 mt.es.pt_444 sv.nl..._640 sk.es..._430
  0x0f080109, 0x1d008c08, 0x66002b08, 0x04192709,   // en.it.es_444 ht.hr..._430 cy.af..._430 id.et.fi_444
  0x08003f09, 0x300e2311, 0x0f004008, 0x1e1d0ca4,   // sw.it..._440 uk.ru.be_653 sl.es..._430 pl.hr.sr_433
  0x29000613, 0x01006614, 0x1d1e3faf, 0x01000d14,   // de.ms..._650 af.en..._660 sw.sr.hr_655 pt.en..._660
  // [2a80]
  0x22218c08, 0x153a1208, 0x18450f08, 0x05458ca4,   // ht.tl.tr_443 cs.eu.lv_443 es.sk.hu_443 ht.sk.fr_433
  0x4b000314, 0x02431408, 0x38004002, 0x17008c09,   // nl.az..._660 is.vi.da_443 sl.ca..._220 ht.ro..._440
  0x15272914, 0x450c1207, 0x0e1c3008, 0x101a8c08,   // ms.id.lv_666 cs.pl.sk_432 be.bg.ru_443 ht.xxx.sv_443
  0x45001923, 0x190b0109, 0x8c000113, 0x08000b02,   // et.sk..._880 en.no.et_444 en.ht..._650 no.it..._220
  // [2a90]
  0x374e3355, 0x29274202, 0x19003823, 0x380d0508,   // ur.fa.ar_442 mt.id.ms_222 ca.et..._880 fr.pt.ca_443
  0x19001623, 0x3f000609, 0x3a272908, 0x400c1209,   // lt.et..._880 de.sw..._440 ms.id.eu_443 cs.pl.sl_444
  0x1a001408, 0x0b141909, 0x0f0d0107, 0x1f002709,   // is.xxx..._430 et.is.no_444 en.pt.es_432 id.ga..._440
  0x06008c08, 0x2b000614, 0x0d000609, 0x0f003a13,   // ht.de..._430 de.cy..._660 de.pt..._440 eu.es..._650
  // [2aa0]
  0x05100109, 0x29064b02, 0x12042e02, 0x0e001c21,   // en.sv.fr_444 az.de.ms_222 sq.fi.cs_222 bg.ru..._860
  0x451e1daf, 0x3f0d0b07, 0x0000050a, 0x8c001902,   // hr.sr.sk_655 no.pt.sw_432 fr......_500 et.ht..._220
  0x293a2708, 0x0d3a38a4, 0x0f002209, 0x43121a09,   // id.eu.ms_443 ca.eu.pt_433 tr.es..._440 xxx.cs.vi_444
  0x041a14a4, 0x020b3fa4, 0x0f000c02, 0x43001413,   // is.xxx.fi_433 sw.no.da_433 pl.es..._220 is.vi..._650
  // [2ab0]
  0x01004207, 0x21004014, 0x0c002708, 0x290d0402,   // mt.en..._420 sl.tl..._660 id.pl..._430 fi.pt.ms_222
  0x12191002, 0x30001e22, 0x0e1e2313, 0x064b22af,   // sv.et.cs_222 sr.be..._870 uk.sr.ru_665 tr.az.de_655
  0x04004208, 0x45180513, 0x8c451209, 0x2b001413,   // mt.fi..._430 fr.hu.sk_665 cs.sk.ht_444 is.cy..._650
  0x3a292760, 0x17001d09, 0x0b002209, 0x271a2b02,   // id.ms.eu_664 hr.ro..._440 tr.no..._440 cy.xxx.id_222
  // [2ac0]
  0x101d3aa4, 0x29100402, 0x38451208, 0x22003814,   // eu.hr.sv_433 fi.sv.ms_222 cs.sk.ca_443 ca.tr..._660
  0x272e0302, 0x21420b07, 0x1e001a07, 0x0d001a14,   // nl.sq.id_222 no.mt.tl_432 xxx.sr..._420 xxx.pt..._660
  0x43060109, 0x1a000602, 0x05000613, 0x450d1902,   // en.de.vi_444 de.xxx..._220 de.fr..._650 et.pt.sk_222
  0x0d000511, 0x0c004013, 0x43000b14, 0x15420812,   // fr.pt..._630 sl.pl..._650 no.vi..._660 it.mt.lv_654
  // [2ad0]
  0x23300ead, 0x0c0b0411, 0x3a1d1e08, 0x4b003a23,   // ru.be.uk_643 fi.no.pl_653 sr.hr.eu_443 eu.az..._880
  0x100b026f, 0x25301e08, 0x15001d02, 0x1d400107,   // da.no.sv_886 sr.be.mk_443 hr.lv..._220 en.sl.hr_432
  0x27142907, 0x10020b11, 0x140f0d60, 0x2b430107,   // ms.is.id_432 no.da.sv_653 pt.es.is_664 en.vi.cy_432
  0x0d001a23, 0x3f001821, 0x8c212709, 0x026603af,   // xxx.pt..._880 hu.sw..._860 id.tl.ht_444 nl.af.da_655
  // [2ae0]
  0x1d661e02, 0x38058c12, 0x0d004522, 0x20001823,   // sr.af.hr_222 ht.fr.ca_654 sk.pt..._870 hu.gl..._880
  0x08000614, 0x20001a23, 0x02001522, 0x14040109,   // de.it..._660 xxx.gl..._880 lv.da..._870 en.fi.is_444
  0x05003821, 0x05014208, 0x4e003723, 0x05002223,   // ca.fr..._860 mt.en.fr_443 ar.fa..._880 tr.fr..._880
  0x06006612, 0x43000c09, 0x1d1e2709, 0x15004b14,   // af.de..._640 pl.vi..._440 id.sr.hr_444 az.lv..._660
  // [2af0]
  0x451a2202, 0x0c064255, 0x224b17a4, 0x04161509,   // tr.xxx.sk_222 mt.de.pl_442 ro.az.tr_433 lv.lt.fi_444
  0x05003f21, 0x18001612, 0x21000613, 0x2e002212,   // sw.fr..._860 lt.hu..._640 de.tl..._650 tr.sq..._640
  0x06002e14, 0x421808a4, 0x2e100b60, 0x04151608,   // sq.de..._660 it.hu.mt_433 no.sv.sq_664 lt.lv.fi_443
  0x29002108, 0x05004309, 0x1e211d02, 0x451238af,   // tl.ms..._430 vi.fr..._440 hr.tl.sr_222 ca.cs.sk_655
  // [2b00]
  0x29223f07, 0x454b0f02, 0x18420811, 0x18084208,   // sw.tr.ms_432 es.az.sk_222 it.mt.hu_653 mt.it.hu_443
  0x224b2709, 0x8c000f14, 0x1d041e02, 0x45408c08,   // id.az.tr_444 es.ht..._660 sr.fi.hr_222 ht.sl.sk_443
  0x3f001713, 0x18001202, 0x170d43a4, 0x02030508,   // ro.sw..._650 cs.hu..._220 vi.pt.ro_433 fr.nl.da_443
  0x12004209, 0x18191411, 0x14001609, 0x16000808,   // mt.cs..._440 is.et.hu_653 lt.is..._440 it.lt..._430
  // [2b10]
  0x66002708, 0x21006608, 0x0b008c23, 0x14020b07,   // id.af..._430 af.tl..._430 ht.no..._880 no.da.is_432
  0x10040b09, 0x2b008c14, 0x29002223, 0x1f002023,   // no.fi.sv_444 ht.cy..._660 tr.ms..._880 gl.ga..._880
  0x29001822, 0x048c4507, 0x29000d23, 0x1a8c0513,   // hu.ms..._870 sk.ht.fi_432 pt.ms..._880 fr.ht.xxx_665
  0x21000b09, 0x43001514, 0x10010208, 0x27290802,   // no.tl..._440 lv.vi..._660 da.en.sv_443 it.ms.id_222
  // [2b20]
  0x231c0ea4, 0x29004b12, 0x231c2512, 0x27293f09,   // ru.bg.uk_433 az.ms..._640 mk.bg.uk_654 sw.ms.id_444
  0x1d1e0b09, 0x18000514, 0x30001c23, 0x45003821,   // no.sr.hr_444 fr.hu..._660 bg.be..._880 ca.sk..._860
  0x121d2702, 0x29001513, 0x66000d13, 0x66000d14,   // id.hr.cs_222 lv.ms..._650 pt.af..._650 pt.af..._660
  0x2b2e3860, 0x02036609, 0x45121a09, 0x380d2e07,   // ca.sq.cy_664 af.nl.da_444 xxx.cs.sk_444 sq.pt.ca_432
  // [2b30]
  0x14004502, 0x4b003814, 0x43001009, 0x01101a09,   // sk.is..._220 ca.az..._660 sv.vi..._440 xxx.sv.en_444
  0x1f000d08, 0x01001914, 0x12011a09, 0x140b0107,   // pt.ga..._430 et.en..._660 xxx.en.cs_444 en.no.is_432
  0x18450c12, 0x19151611, 0x06142b13, 0x1a100208,   // pl.sk.hu_654 lt.lv.et_653 cy.is.de_665 da.sv.xxx_443
  0x2e000c14, 0x18000d12, 0x0f0d4508, 0x0f2b3808,   // pl.sq..._660 pt.hu..._640 sk.pt.es_443 ca.cy.es_443
  // [2b40]
  0x8c000323, 0x1d382e02, 0x1e000f02, 0x8c004002,   // nl.ht..._880 sq.ca.hr_222 es.sr..._220 sl.ht..._220
  0x4b0d3808, 0x010c3fa4, 0x0f0d2012, 0x0e2325a4,   // ca.pt.az_443 sw.pl.en_433 gl.pt.es_654 mk.uk.ru_433
  0x15006608, 0x061a1008, 0x1e1d6609, 0x0f0d2b12,   // af.lv..._430 sv.xxx.de_443 af.hr.sr_444 cy.pt.es_654
  0x1d1e40ac, 0x20001714, 0x45432702, 0x03001d02,   // sl.sr.hr_632 ro.gl..._660 id.vi.sk_222 hr.nl..._220
  // [2b50]
  0x02660360, 0x12451902, 0x19004013, 0x12458c12,   // nl.af.da_664 et.sk.cs_222 sl.et..._650 ht.sk.cs_654
  0x451a1002, 0x45008c13, 0x29004323, 0x451517a4,   // sv.xxx.sk_222 ht.sk..._650 vi.ms..._880 ro.lv.sk_433
  0x3a660309, 0x45191202, 0x1e051d02, 0x27001f14,   // nl.af.eu_444 cs.et.sk_222 hr.fr.sr_222 ga.id..._660
  0x1e1d04a4, 0x0f002913, 0x0c002902, 0x0b001209,   // fi.hr.sr_433 ms.es..._650 ms.pl..._220 cs.no..._440
  // [2b60]
  0x45000502, 0x21001623, 0x0e252307, 0x0f001a09,   // fr.sk..._220 lt.tl..._880 uk.mk.ru_432 xxx.es..._440
  0x1d451002, 0x0f140d02, 0x4b0d0b07, 0x17004b02,   // sv.sk.hr_222 pt.is.es_222 no.pt.az_432 az.ro..._220
  0x43001708, 0x04421a09, 0x66031913, 0x21001908,   // ro.vi..._430 xxx.mt.fi_444 et.nl.af_665 et.tl..._430
  0x19660360, 0x04000509, 0x43001a08, 0x3a004209,   // nl.af.et_664 fr.fi..._440 xxx.vi..._430 mt.eu..._440
  // [2b70]
  0x40006602, 0x3f080109, 0x12458c02, 0x2b0f0107,   // af.sl..._220 en.it.sw_444 ht.sk.cs_222 en.es.cy_432
  0x06000321, 0x22000814, 0x05010b09, 0x230e1c60,   // nl.de..._860 it.tr..._660 no.en.fr_444 bg.ru.uk_664
  0x29142707, 0x2e434b07, 0x224b1408, 0x2e142908,   // id.is.ms_432 az.vi.sq_432 is.az.tr_443 ms.is.sq_443
  0x17082909, 0x20380d13, 0x380d2009, 0x1a002e14,   // ms.it.ro_444 pt.ca.gl_665 gl.pt.ca_444 sq.xxx..._660
  // [2b80]
  0x0d001014, 0x183a2260, 0x0d451421, 0x142e2707,   // sv.pt..._660 tr.eu.hu_664 is.sk.pt_876 id.sq.is_432
  0x14002e02, 0x190208a4, 0x3a0b1812, 0x66292707,   // sq.is..._220 it.da.et_433 hu.no.eu_654 id.ms.af_432
  0x041a3f55, 0x14100b60, 0x0f0d3855, 0x45000d23,   // sw.xxx.fi_442 no.sv.is_664 ca.pt.es_442 pt.sk..._880
  0x180d4513, 0x180d4512, 0x1e3f1da4, 0x0b001813,   // sk.pt.hu_665 sk.pt.hu_654 hr.sw.sr_433 hu.no..._650
  // [2b90]
  0x18004521, 0x66058ca4, 0x12184511, 0x271429a4,   // sk.hu..._860 ht.fr.af_433 sk.hu.cs_653 ms.is.id_433
  0x450c1212, 0x1a212e09, 0x05001412, 0x1d222902,   // cs.pl.sk_654 sq.tl.xxx_444 is.fr..._640 ms.tr.hr_222
  0x0c008c08, 0x2e001813, 0x4b003802, 0x45002907,   // ht.pl..._430 hu.sq..._650 ca.az..._220 ms.sk..._420
  0x1e2b0802, 0x06021407, 0x046603a4, 0x03660b07,   // it.cy.sr_222 is.da.de_432 nl.af.fi_433 no.af.nl_432
  // [2ba0]
  0x04151611, 0x06100b09, 0x4b1d8c07, 0x1a0c18a4,   // lt.lv.fi_653 no.sv.de_444 ht.hr.az_432 hu.pl.xxx_433
  0x031e1d13, 0x06002212, 0x45006609, 0x4b0b10a4,   // hr.sr.nl_665 tr.de..._640 af.sk..._440 sv.no.az_433
  0x2e001013, 0x100d1a08, 0x211f3fa4, 0x21001f14,   // sv.sq..._650 xxx.pt.sv_443 sw.ga.tl_433 ga.tl..._660
  0x3a001622, 0x3f170107, 0x22293a12, 0x66012ba4,   // lt.eu..._870 en.ro.sw_432 eu.ms.tr_654 cy.en.af_433
  // [2bb0]
  0x29020b07, 0x19223a07, 0x21001922, 0x16000421,   // no.da.ms_432 eu.tr.et_432 et.tl..._870 fi.lt..._860
  0x3a190f55, 0x0f052208, 0x45084208, 0x06450d08,   // es.et.eu_442 tr.fr.es_443 mt.it.sk_443 pt.sk.de_443
  0x21292711, 0x02004507, 0x031a0f09, 0x200d0b08,   // id.ms.tl_653 sk.da..._420 es.xxx.nl_444 no.pt.gl_443
  0x08421209, 0x06008c14, 0x21224ba4, 0x8c000102,   // cs.mt.it_444 ht.de..._660 az.tr.tl_433 en.ht..._220
  // [2bc0]
  0x0b061009, 0x2b124560, 0x22193a08, 0x66030512,   // sv.de.no_444 sk.cs.cy_664 eu.et.tr_443 fr.nl.af_654
  0x180f4508, 0x0c2e1508, 0x19224b11, 0x45122709,   // sk.es.hu_443 lv.sq.pl_443 az.tr.et_653 id.cs.sk_444
  0x12421708, 0x0d000f12, 0x03000522, 0x380f0408,   // ro.mt.cs_443 es.pt..._640 fr.nl..._870 fi.es.ca_443
  0x8c036612, 0x0c002107, 0x660b2908, 0x04000b13,   // af.nl.ht_654 tl.pl..._420 ms.no.af_443 no.fi..._650
  // [2bd0]
  0x17002102, 0x17000c13, 0x0c454008, 0x19213a13,   // tl.ro..._220 pl.ro..._650 sl.sk.pl_443 eu.tl.et_665
  0x12451a02, 0x120f4502, 0x16001414, 0x42001621,   // xxx.sk.cs_222 sk.es.cs_222 is.lt..._660 lt.mt..._860
  0x0c004022, 0x1e188c07, 0x230e1c55, 0x250e1c12,   // sl.pl..._870 ht.hu.sr_432 bg.ru.uk_442 bg.ru.mk_654
  0x40003a08, 0x2b002108, 0x45292702, 0x180f0d13,   // eu.sl..._430 tl.cy..._430 id.ms.sk_222 pt.es.hu_665
  // [2be0]
  0x0b1f0612, 0x121f4502, 0x1d221702, 0x660c0212,   // de.ga.no_654 sk.ga.cs_222 ro.tr.hr_222 da.pl.af_654
  0x3f292712, 0x1d0b1e09, 0x3f8c0108, 0x14006613,   // id.ms.sw_654 sr.no.hr_444 en.ht.sw_443 af.is..._650
  0x45000b14, 0x45006623, 0x0c012b09, 0x18000608,   // no.sk..._660 af.sk..._880 cy.en.pl_444 de.hu..._430
  0x42010b09, 0x19000122, 0x05170107, 0x29210b08,   // no.en.mt_444 en.et..._870 en.ro.fr_432 no.tl.ms_443
  // [2bf0]
  0x21000609, 0x08001409, 0x38060113, 0x0e1e1caf,   // de.tl..._440 is.it..._440 en.de.ca_665 bg.sr.ru_655
  0x19004b20, 0x401d29a4, 0x01003822, 0x66272b12,   // az.et..._850 ms.hr.sl_433 ca.en..._870 cy.id.af_654
  0x04006607, 0x01003813, 0x38000b09, 0x1e1d0414,   // af.fi..._420 ca.en..._650 no.ca..._440 fi.hr.sr_666
  0x38002212, 0x061002a4, 0x12001002, 0x0f0d1808,   // tr.ca..._640 da.sv.de_433 sv.cs..._220 hu.pt.es_443

  // [2c00]
  0x231e0e13, 0x18004512, 0x120f0d60, 0x1f001214,   // ru.sr.uk_665 sk.hu..._640 pt.es.cs_664 cs.ga..._660
  0x22001002, 0x060210a4, 0x3f001413, 0x0d001a12,   // sv.tr..._220 sv.da.de_433 is.sw..._650 xxx.pt..._640
  0x451f1214, 0x03003a09, 0x06004008, 0x8c001a08,   // cs.ga.sk_666 eu.nl..._440 sl.de..._430 xxx.ht..._430
  0x230e2512, 0x0c1a6613, 0x1d000523, 0x45271a02,   // mk.ru.uk_654 af.xxx.pl_665 fr.hr..._880 xxx.id.sk_222
  // [2c10]
  0x45123f02, 0x42002721, 0x27102902, 0x29001814,   // sw.cs.sk_222 id.mt..._860 ms.sv.id_222 hu.ms..._660
  0x062b2707, 0x12668ca4, 0x40002221, 0x453a2908,   // id.cy.de_432 ht.af.cs_433 tr.sl..._860 ms.eu.sk_443
  0x29001013, 0x22060109, 0x03000214, 0x1d001608,   // sv.ms..._650 en.de.tr_444 da.nl..._660 lt.hr..._430
  0x19060b09, 0x19000b22, 0x3a1516a4, 0x02004502,   // no.de.et_444 no.et..._870 lt.lv.eu_433 sk.da..._220
  // [2c20]
  0x0f124514, 0x29000509, 0x8c0b2208, 0x45012902,   // sk.cs.es_666 fr.ms..._440 tr.no.ht_443 ms.en.sk_222
  0x1d000b23, 0x18001f02, 0x3f006608, 0x2b001822,   // no.hr..._880 ga.hu..._220 af.sw..._430 hu.cy..._870
  0x06031814, 0x19100413, 0x1f451214, 0x06031808,   // hu.nl.de_666 fi.sv.et_665 cs.sk.ga_666 hu.nl.de_443
  0x17001909, 0x1d001212, 0x0e233007, 0x1e001413,   // et.ro..._440 cs.hr..._640 be.uk.ru_432 is.sr..._650
  // [2c30]
  0x1d012b02, 0x04001007, 0x1a8c3f09, 0x1e1d0109,   // cy.en.hr_222 sv.fi..._420 sw.ht.xxx_444 en.hr.sr_444
  0x22182108, 0x03011002, 0x8c004502, 0x29000c14,   // tl.hu.tr_443 sv.en.nl_222 sk.ht..._220 pl.ms..._660
  0x22004302, 0x45380f02, 0x3f002907, 0x16004309,   // vi.tr..._220 es.ca.sk_222 ms.sw..._420 vi.lt..._440
  0x17001a14, 0x122e4502, 0x0d001812, 0x294b4213,   // xxx.ro..._660 sk.sq.cs_222 hu.pt..._640 mt.az.ms_665
  // [2c40]
  0x19002714, 0x21000107, 0x45660107, 0x38004302,   // id.et..._660 en.tl..._420 en.af.sk_432 vi.ca..._220
  0x120f2109, 0x45104302, 0x04000123, 0x22001412,   // tl.es.cs_444 vi.sv.sk_222 en.fi..._880 is.tr..._640
  0x1d1e3802, 0x38170107, 0x66000209, 0x660327a4,   // ca.sr.hr_222 en.ro.ca_432 da.af..._440 id.nl.af_433
  0x40001713, 0x40001708, 0x43000408, 0x3f004302,   // ro.sl..._650 ro.sl..._430 fi.vi..._430 vi.sw..._220
  // [2c50]
  0x22001409, 0x030b0109, 0x12451414, 0x40291209,   // is.tr..._440 en.no.nl_444 is.sk.cs_666 cs.ms.sl_444
  0x0d053814, 0x10001513, 0x10053855, 0x66004302,   // ca.fr.pt_666 lv.sv..._650 ca.fr.sv_442 vi.af..._220
  0x08011a08, 0x17001523, 0x051f3f13, 0x21202709,   // xxx.en.it_443 lv.ro..._880 sw.ga.fr_665 id.gl.tl_444
  0x2e000612, 0x8c3f2108, 0x1e404508, 0x17002902,   // de.sq..._640 tl.sw.ht_443 sk.sl.sr_443 ms.ro..._220
  // [2c60]
  0x29002b02, 0x06431a09, 0x06001714, 0x02002e14,   // cy.ms..._220 xxx.vi.de_444 ro.de..._660 sq.da..._660
  0x1d001402, 0x8c001622, 0x19000b12, 0x45050108,   // is.hr..._220 lt.ht..._870 no.et..._640 en.fr.sk_443
  0x21003802, 0x0c004b02, 0x14002708, 0x06002108,   // ca.tl..._220 az.pl..._220 id.is..._430 tl.de..._430
  0x16214013, 0x02002b23, 0x42001809, 0x38000d07,   // sl.tl.lt_665 cy.da..._880 hu.mt..._440 pt.ca..._420
  // [2c70]
  0x43002e22, 0x42001823, 0x45102e02, 0x2b4b2208,   // sq.vi..._870 hu.mt..._880 sq.sv.sk_222 tr.az.cy_443
  0x3f170508, 0x23302514, 0x1d212902, 0x03001814,   // fr.ro.sw_443 mk.be.uk_666 ms.tl.hr_222 hu.nl..._660
  0x66190412, 0x1d0c2102, 0x01433fa4, 0x43000523,   // fi.et.af_654 tl.pl.hr_222 sw.vi.en_433 fr.vi..._880
  0x0f002713, 0x19004221, 0x274b2202, 0x221245a4,   // id.es..._650 mt.et..._860 tr.az.id_222 sk.cs.tr_433
  // [2c80]
  0x4b000613, 0x010c4508, 0x42083808, 0x4b221814,   // de.az..._650 sk.pl.en_443 ca.it.mt_443 hu.tr.az_666
  0x4b000c02, 0x1f000209, 0x05001908, 0x4b2218ad,   // pl.az..._220 da.ga..._440 et.fr..._430 hu.tr.az_643
  0x18224b13, 0x4b001812, 0x2e3f1812, 0x06002b21,   // az.tr.hu_665 hu.az..._640 hu.sw.sq_654 cy.de..._860
  0x1c300e13, 0x19272908, 0x03660607, 0x21100208,   // ru.be.bg_665 ms.id.et_443 de.af.nl_432 da.sv.tl_443
  // [2c90]
  0x21002222, 0x66060360, 0x01001a23, 0x1d1e1513,   // tr.tl..._870 nl.de.af_664 xxx.en..._880 lv.sr.hr_665
  0x8c001809, 0x0b021408, 0x22002113, 0x0f0d3814,   // hu.ht..._440 is.da.no_443 tl.tr..._650 ca.pt.es_666
  0x45000108, 0x1e1d03af, 0x02001613, 0x0f001914,   // en.sk..._430 nl.hr.sr_655 lt.da..._650 et.es..._660
  0x27001a23, 0x294b2707, 0x04080b09, 0x12453a02,   // xxx.id..._880 id.az.ms_432 no.it.fi_444 eu.sk.cs_222
  // [2ca0]
  0x02004212, 0x291e0107, 0x0f003f23, 0x16004b23,   // mt.da..._640 en.sr.ms_432 sw.es..._880 az.lt..._880
  0x2b000c09, 0x42004b21, 0x2b002e02, 0x01062ba4,   // pl.cy..._440 az.mt..._860 sq.cy..._220 cy.de.en_433
  0x01272b08, 0x43000507, 0x180210a4, 0x3a008c09,   // cy.id.en_443 fr.vi..._420 sv.da.hu_433 ht.eu..._440
  0x058c0608, 0x43050108, 0x2b001902, 0x020b10af,   // de.ht.fr_443 en.fr.vi_443 et.cy..._220 sv.no.da_655
  // [2cb0]
  0x2b000b07, 0x1f010508, 0x8c002e14, 0x222e8c12,   // no.cy..._420 fr.en.ga_443 sq.ht..._660 ht.sq.tr_654
  0x1e233002, 0x45011207, 0x141d1e09, 0x12000114,   // be.uk.sr_222 cs.en.sk_432 sr.hr.is_444 en.cs..._660
  0x12000108, 0x66000122, 0x0b000222, 0x3a000423,   // en.cs..._430 en.af..._870 da.no..._870 fi.eu..._880
  0x43000414, 0x450c1208, 0x043f3a12, 0x01000b07,   // fi.vi..._660 cs.pl.sk_443 eu.sw.fi_654 no.en..._420
  // [2cc0]
  0x1d171002, 0x0d003a22, 0x434512af, 0x21002213,   // sv.ro.hr_222 eu.pt..._870 cs.sk.vi_655 tr.tl..._650
  0x03660255, 0x3a043f08, 0x3f043a12, 0x05173813,   // da.af.nl_442 sw.fi.eu_443 eu.fi.sw_654 ca.ro.fr_665
  0x08002e07, 0x18002b23, 0x380f0109, 0x383a0109,   // sq.it..._420 cy.hu..._880 en.es.ca_444 en.eu.ca_444
  0x0f004309, 0x43003a13, 0x05451212, 0x05080107,   // vi.es..._440 eu.vi..._650 cs.sk.fr_654 en.it.fr_432
  // [2cd0]
  0x10004312, 0x0c001d08, 0x181a0b12, 0x1e151d09,   // vi.sv..._640 hr.pl..._430 no.xxx.hu_654 hr.lv.sr_444
  0x2b1d0209, 0x231c3009, 0x2b000609, 0x01000613,   // da.hr.cy_444 be.bg.uk_444 de.cy..._440 de.en..._650
  0x0d0f1714, 0x04173a09, 0x02001408, 0x051a0302,   // ro.es.pt_666 eu.ro.fi_444 is.da..._430 nl.xxx.fr_222
  0x15002b02, 0x27150107, 0x0c001414, 0x19000b23,   // cy.lv..._220 en.lv.id_432 is.pl..._660 no.et..._880
  // [2ce0]
  0x0b001e14, 0x38001409, 0x213f0109, 0x16036608,   // sr.no..._660 is.ca..._440 en.sw.tl_444 af.nl.lt_443
  0x10003f12, 0x293a2102, 0x404b1808, 0x02000d14,   // sw.sv..._640 tl.eu.ms_222 hu.az.sl_443 pt.da..._660
  0x45000514, 0x290c2709, 0x66031808, 0x032b0107,   // fr.sk..._660 id.pl.ms_444 hu.nl.af_443 en.cy.nl_432
  0x401d2208, 0x16272907, 0x45101502, 0x19161008,   // tr.hr.sl_443 ms.id.lt_432 lv.sv.sk_222 sv.lt.et_443
  // [2cf0]
  0x05663f55, 0x300e2360, 0x18451f60, 0x1f184508,   // sw.af.fr_442 uk.ru.be_664 ga.sk.hu_664 sk.hu.ga_443
  0x45181413, 0x16002107, 0x8c454055, 0x15008c09,   // is.hu.sk_665 tl.lt..._420 sl.sk.ht_442 ht.lv..._440
  0x12408ca4, 0x12004520, 0x42004b14, 0x1f451812,   // ht.sl.cs_433 sk.cs..._850 az.mt..._660 hu.sk.ga_654
  0x14004222, 0x1e003a12, 0x14000c02, 0x123f0402,   // mt.is..._870 eu.sr..._640 pl.is..._220 fi.sw.cs_222
  // [2d00]
  0x42001013, 0x12000613, 0x0c001723, 0x40020b09,   // sv.mt..._650 de.cs..._650 ro.pl..._880 no.da.sl_444
  0x17004523, 0x14020b12, 0x10020613, 0x12451712,   // sk.ro..._880 no.da.is_654 de.da.sv_665 ro.sk.cs_654
  0x21066609, 0x21000d14, 0x12081702, 0x020f0b07,   // af.de.tl_444 pt.tl..._660 ro.it.cs_222 no.es.da_432
  0x0e302355, 0x04146613, 0x18000b23, 0x18000b14,   // uk.be.ru_442 af.is.fi_665 no.hu..._880 no.hu..._660
  // [2d10]
  0x10140107, 0x45001708, 0x43000122, 0x1d1e4007,   // en.is.sv_432 ro.sk..._430 en.vi..._870 sl.sr.hr_432
  0x1e1d15a4, 0x29211e02, 0x04191060, 0x1f0c1a08,   // lv.hr.sr_433 sr.tl.ms_222 sv.et.fi_664 xxx.pl.ga_443
  0x451e1d12, 0x45292709, 0x0c002709, 0x1e003f14,   // hr.sr.sk_654 id.ms.sk_444 id.pl..._440 sw.sr..._660
  0x05042ba4, 0x1e302508, 0x0b000513, 0x120c4560,   // cy.fi.fr_433 mk.be.sr_443 fr.no..._650 sk.pl.cs_664
  // [2d20]
  0x453f0802, 0x08003a08, 0x04000c02, 0x42660f09,   // it.sw.sk_222 eu.it..._430 pl.fi..._220 es.af.mt_444
  0x0f000c23, 0x3f458ca4, 0x27294509, 0x3a064209,   // pl.es..._880 ht.sk.sw_433 sk.ms.id_444 mt.de.eu_444
  0x450f0602, 0x273f1aa4, 0x25000e08, 0x191521af,   // de.es.sk_222 xxx.sw.id_433 ru.mk..._430 tl.lv.et_655
  0x06661408, 0x42002109, 0x1f000514, 0x2b001709,   // is.af.de_443 tl.mt..._440 fr.ga..._660 ro.cy..._440
  // [2d30]
  0x14001508, 0x2b002908, 0x15003a12, 0x4b004014,   // lv.is..._430 ms.cy..._430 eu.lv..._640 sl.az..._660
  0x3f001913, 0x06191aa4, 0x0f0d1409, 0x121e4502,   // et.sw..._650 xxx.et.de_433 is.pt.es_444 sk.sr.cs_222
  0x29033802, 0x05001707, 0x17044308, 0x458c4b02,   // ca.nl.ms_222 ro.fr..._420 vi.fi.ro_443 az.ht.sk_222
  0x06101407, 0x29002e22, 0x454b8c02, 0x8c002e22,   // is.sv.de_432 sq.ms..._870 ht.az.sk_222 sq.ht..._870
  // [2d40]
  0x103a0109, 0x4b000409, 0x08008c22, 0x1f000423,   // en.eu.sv_444 fi.az..._440 ht.it..._870 fi.ga..._880
  0x66008c22, 0x043a1fa4, 0x06001823, 0x14100b09,   // ht.af..._870 ga.eu.fi_433 hu.de..._880 no.sv.is_444
  0x1f002902, 0x1d004213, 0x03660460, 0x03021008,   // ms.ga..._220 mt.hr..._650 fi.af.nl_664 sv.da.nl_443
  0x16052b55, 0x1f004208, 0x124516af, 0x020c0b07,   // cy.fr.lt_442 mt.ga..._430 lt.sk.cs_655 no.pl.da_432
  // [2d50]
  0x1d1e15a4, 0x43001202, 0x3a000522, 0x3a001609,   // lv.sr.hr_433 cs.vi..._220 fr.eu..._870 lt.eu..._440
  0x21000209, 0x04192108, 0x12211a02, 0x2b001e09,   // da.tl..._440 tl.et.fi_443 xxx.tl.cs_222 sr.cy..._440
  0x42400da4, 0x29214202, 0x38220660, 0x3a000d08,   // pt.sl.mt_433 mt.tl.ms_222 de.tr.ca_664 pt.eu..._430
  0x2e124509, 0x06050109, 0x190c4014, 0x420c1507,   // sk.cs.sq_444 en.fr.de_444 sl.pl.et_666 lv.pl.mt_432
  // [2d60]
  0x0c001f14, 0x04001202, 0x12002914, 0x04173808,   // ga.pl..._660 cs.fi..._220 ms.cs..._660 ca.ro.fi_443
  0x0c003a23, 0x03002914, 0x27290655, 0x0d003821,   // eu.pl..._880 ms.nl..._660 de.ms.id_442 ca.pt..._860
  0x0e232512, 0x03002907, 0x22121508, 0x8c210ca4,   // mk.uk.ru_654 ms.nl..._420 lv.cs.tr_443 pl.tl.ht_433
  0x42141609, 0x4b004009, 0x15001f02, 0x1c251eaf,   // lt.is.mt_444 sl.az..._440 ga.lv..._220 sr.mk.bg_655
  // [2d70]
  0x27000d09, 0x43422908, 0x16000413, 0x08002002,   // pt.id..._440 ms.mt.vi_443 fi.lt..._650 gl.it..._220
  0x0f120d08, 0x18000602, 0x29272113, 0x00008c03,   // pt.cs.es_443 de.hu..._220 tl.id.ms_665 ht......_300
  0x431a2108, 0x031418af, 0x3a451207, 0x06100107,   // tl.xxx.vi_443 hu.is.nl_655 cs.sk.eu_432 en.sv.de_432
  0x45423a12, 0x12000d12, 0x12450daf, 0x050f0d14,   // eu.mt.sk_654 pt.cs..._640 pt.sk.cs_655 pt.es.fr_666
  // [2d80]
  0x27211502, 0x27291802, 0x22001f14, 0x273a1902,   // lv.tl.id_222 hu.ms.id_222 ga.tr..._660 et.eu.id_222
  0x291e1d08, 0x050f0d60, 0x1f001d09, 0x0f3a8c08,   // hr.sr.ms_443 pt.es.fr_664 hr.ga..._440 ht.eu.es_443
  0x3f0b02a4, 0x2b0638a4, 0x14000114, 0x4b3f2214,   // da.no.sw_433 ca.de.cy_433 en.is..._660 tr.sw.az_666
  0x050f1807, 0x2b1a2707, 0x14002e20, 0x29018c02,   // hu.es.fr_432 id.xxx.cy_432 sq.is..._850 ht.en.ms_222
  // [2d90]
  0x42000c23, 0x01040302, 0x38060313, 0x42004023,   // pl.mt..._880 nl.fi.en_222 nl.de.ca_665 sl.mt..._880
  0x02031a09, 0x140d3808, 0x1f001513, 0x29172e08,   // xxx.nl.da_444 ca.pt.is_443 lv.ga..._650 sq.ro.ms_443
  0x29274002, 0x25302360, 0x250e1e09, 0x27222913,   // sl.id.ms_222 uk.be.mk_664 sr.ru.mk_444 ms.tr.id_665
  0x45003f23, 0x450d2102, 0x0f080d08, 0x12401d02,   // sw.sk..._880 tl.pt.sk_222 pt.it.es_443 hr.sl.cs_222
  // [2da0]
  0x14002209, 0x29001723, 0x06004012, 0x2b001209,   // tr.is..._440 ro.ms..._880 sl.de..._640 cs.cy..._440
  0x05004209, 0x010f2160, 0x15002113, 0x018c4208,   // mt.fr..._440 tl.es.en_664 tl.lv..._650 mt.ht.en_443
  0x100f8ca4, 0x3f000c13, 0x0c124509, 0x1e1d17a4,   // ht.es.sv_433 pl.sw..._650 sk.cs.pl_444 ro.hr.sr_433
  0x06192e12, 0x38002b14, 0x0c000422, 0x43003808,   // sq.et.de_654 cy.ca..._660 fi.pl..._870 ca.vi..._430
  // [2db0]
  0x22061807, 0x3f224b11, 0x02001809, 0x2e401460,   // hu.de.tr_432 az.tr.sw_653 hu.da..._440 is.sl.sq_664
  0x2e2b2109, 0x17001907, 0x40004202, 0x42000c14,   // tl.cy.sq_444 et.ro..._420 mt.sl..._220 pl.mt..._660
  0x063a2209, 0x38001914, 0x19003822, 0x02001909,   // tr.eu.de_444 et.ca..._660 ca.et..._870 et.da..._440
  0x0f1a1e08, 0x4b1922a4, 0x45140d02, 0x10003f08,   // sr.xxx.es_443 tr.et.az_433 pt.is.sk_222 sw.sv..._430
  // [2dc0]
  0x222b4b14, 0x1c252314, 0x05182b11, 0x1e1d0309,   // az.cy.tr_666 uk.mk.bg_666 cy.hu.fr_653 nl.hr.sr_444
  0x8c001f08, 0x66034208, 0x05001f22, 0x458c0107,   // ga.ht..._430 mt.nl.af_443 ga.fr..._870 en.ht.sk_432
  0x12000f02, 0x14000622, 0x10012b02, 0x27022908,   // es.cs..._220 de.is..._870 cy.en.sv_222 ms.da.id_443
  0x0c200109, 0x16004212, 0x17160407, 0x66002e22,   // en.gl.pl_444 mt.lt..._640 fi.lt.ro_432 sq.af..._870
  // [2dd0]
  0x2e000614, 0x21660314, 0x3a200f12, 0x12171002,   // de.sq..._660 nl.af.tl_666 es.gl.eu_654 sv.ro.cs_222
  0x2b181608, 0x21008c08, 0x0c124512, 0x21000213,   // lt.hu.cy_443 ht.tl..._430 sk.cs.pl_654 da.tl..._650
  0x25300e13, 0x040127a4, 0x06020b09, 0x1d000309,   // ru.be.mk_665 id.en.fi_433 no.da.de_444 nl.hr..._440
  0x17001d02, 0x40002b09, 0x3f1a8caf, 0x1e031d60,   // hr.ro..._220 cy.sl..._440 ht.xxx.sw_655 hr.nl.sr_664
  // [2de0]
  0x21021008, 0x183a0c09, 0x03000207, 0x29004509,   // sv.da.tl_443 pl.eu.hu_444 da.nl..._420 sk.ms..._440
  0x18160408, 0x43000809, 0x2b001914, 0x14002123,   // fi.lt.hu_443 it.vi..._440 et.cy..._660 tl.is..._880
  0x16003a12, 0x300e1c14, 0x22452e08, 0x30000e11,   // eu.lt..._640 bg.ru.be_666 sq.sk.tr_443 ru.be..._630
  0x19004023, 0x2b4b2212, 0x1d450202, 0x1f002b12,   // sl.et..._880 tr.az.cy_654 da.sk.hr_222 cy.ga..._640
  // [2df0]
  0x3a170109, 0x22183a12, 0x22001622, 0x22272909,   // en.ro.eu_444 eu.hu.tr_654 lt.tr..._870 ms.id.tr_444
  0x8c002922, 0x40000313, 0x38000314, 0x0b002214,   // ms.ht..._870 nl.sl..._650 nl.ca..._660 tr.no..._660
  0x03008c13, 0x401a0508, 0x0e251e13, 0x17000d12,   // ht.nl..._650 fr.xxx.sl_443 sr.mk.ru_665 pt.ro..._640
  0x10008c23, 0x17452708, 0x2e001712, 0x1d004508,   // ht.sv..._880 id.sk.ro_443 ro.sq..._640 sk.hr..._430
  // [2e00]
  0x25002312, 0x2e1d1e07, 0x2e224b12, 0x4b044208,   // uk.mk..._640 sr.hr.sq_432 az.tr.sq_654 mt.fi.az_443
  0x10004223, 0x4b000522, 0x420f4508, 0x19161508,   // mt.sv..._880 fr.az..._870 sk.es.mt_443 lv.lt.et_443
  0x03040b09, 0x3f001202, 0x05000621, 0x66060312,   // no.fi.nl_444 cs.sw..._220 de.fr..._860 nl.de.af_654
  0x15190455, 0x12001414, 0x27290302, 0x29190407,   // fi.et.lv_442 is.cs..._660 nl.ms.id_222 fi.et.ms_432
  // [2e10]
  0x40000209, 0x124540a4, 0x401d2ea4, 0x22002908,   // da.sl..._440 sl.sk.cs_433 sq.hr.sl_433 ms.tr..._430
  0x0b002b12, 0x27000609, 0x2e002108, 0x45191012,   // cy.no..._640 de.id..._440 tl.sq..._430 sv.et.sk_654
  0x1f002923, 0x38002013, 0x162e66a4, 0x15211612,   // ms.ga..._880 gl.ca..._650 af.sq.lt_433 lt.tl.lv_654
  0x102e6608, 0x06001e09, 0x170d05a4, 0x0b141009,   // af.sq.sv_443 sr.de..._440 fr.pt.ro_433 sv.is.no_444
  // [2e20]
  0x66420c13, 0x12000f12, 0x0b004222, 0x21000402,   // pl.mt.af_665 es.cs..._640 mt.no..._870 fi.tl..._220
  0x21004b13, 0x02001822, 0x042b12af, 0x1d451602,   // az.tl..._650 hu.da..._870 cs.cy.fi_655 lt.sk.hr_222
  0x10021e09, 0x8c050109, 0x12000414, 0x3a002014,   // sr.da.sv_444 en.fr.ht_444 fi.cs..._660 gl.eu..._660
  0x0c002e08, 0x0e1e25a4, 0x3a043f13, 0x66190308,   // sq.pl..._430 mk.sr.ru_433 sw.fi.eu_665 nl.et.af_443
  // [2e30]
  0x210f01a4, 0x66031955, 0x271d0b07, 0x1a660312,   // en.es.tl_433 et.nl.af_442 no.hr.id_432 nl.af.xxx_654
  0x19000323, 0x42000b02, 0x66002908, 0x3f181612,   // nl.et..._880 no.mt..._220 ms.af..._430 lt.hu.sw_654
  0x27063a02, 0x2e3f1f12, 0x16152709, 0x43161808,   // eu.de.id_222 ga.sw.sq_654 id.lv.lt_444 hu.lt.vi_443
  0x05002923, 0x14001723, 0x200d06af, 0x0c001502,   // ms.fr..._880 ro.is..._880 de.pt.gl_655 lv.pl..._220
  // [2e40]
  0x8c004214, 0x10020309, 0x42001523, 0x08001522,   // mt.ht..._660 nl.da.sv_444 lv.mt..._880 lv.it..._870
  0x1e0e23af, 0x2b221412, 0x21000f07, 0x3f100b07,   // uk.ru.sr_655 is.tr.cy_654 es.tl..._420 no.sv.sw_432
  0x450c2b60, 0x38050f08, 0x450f0d60, 0x16001008,   // cy.pl.sk_664 es.fr.ca_443 pt.es.sk_664 sv.lt..._430
  0x1f450da4, 0x0c000d02, 0x231e0ea4, 0x0d000c08,   // pt.sk.ga_433 pt.pl..._220 ru.sr.uk_433 pl.pt..._430
  // [2e50]
  0x14100b14, 0x3a008c14, 0x25230e13, 0x1a001814,   // no.sv.is_666 ht.eu..._660 ru.uk.mk_665 hu.xxx..._660
  0x231c0e60, 0x10004009, 0x0e301ca4, 0x38004208,   // ru.bg.uk_664 sl.sv..._440 bg.be.ru_433 mt.ca..._430
  0x25000e11, 0x2b001422, 0x22002023, 0x190638a4,   // ru.mk..._630 is.cy..._870 gl.tr..._880 ca.de.et_433
  0x4b222e08, 0x3a000c23, 0x2b451212, 0x040221a4,   // sq.tr.az_443 pl.eu..._880 cs.sk.cy_654 tl.da.fi_433
  // [2e60]
  0x1d3a4b02, 0x0c181708, 0x14220408, 0x29273faf,   // az.eu.hr_222 ro.hu.pl_443 fi.tr.is_443 sw.id.ms_655
  0x141922a4, 0x21001412, 0x190c2b12, 0x08151908,   // tr.et.is_433 is.tl..._640 cy.pl.et_654 et.lv.it_443
  0x45128c02, 0x38000513, 0x38001612, 0x17191508,   // ht.cs.sk_222 fr.ca..._650 lt.ca..._640 lv.et.ro_443
  0x27291902, 0x18001012, 0x1e421d02, 0x010266a4,   // et.ms.id_222 sv.hu..._640 hr.mt.sr_222 af.da.en_433
  // [2e70]
  0x1d191702, 0x17004b09, 0x0d000423, 0x27172902,   // ro.et.hr_222 az.ro..._440 fi.pt..._880 ms.ro.id_222
  0x10000514, 0x08000422, 0x08174209, 0x4b060109,   // fr.sv..._660 fi.it..._870 mt.ro.it_444 en.de.az_444
  0x140d0f09, 0x2e140107, 0x45290107, 0x1d662b02,   // es.pt.is_444 en.is.sq_432 en.ms.sk_432 cy.af.hr_222
  0x18000807, 0x45151214, 0x45004308, 0x42084013,   // it.hu..._420 cs.lv.sk_666 vi.sk..._430 sl.it.mt_665
  // [2e80]
  0x05001208, 0x1e002309, 0x024b2755, 0x05124509,   // cs.fr..._430 uk.sr..._440 id.az.da_442 sk.cs.fr_444
  0x29434502, 0x0d290208, 0x1f001609, 0x1d2b1a02,   // sk.vi.ms_222 da.ms.pt_443 lt.ga..._440 xxx.cy.hr_222
  0x1a050f07, 0x18000b22, 0x17002209, 0x1d0c4055,   // es.fr.xxx_432 no.hu..._870 tr.ro..._440 sl.pl.hr_442
  0x0f0d4b08, 0x01002913, 0x1d1e0c09, 0x16002e08,   // az.pt.es_443 ms.en..._650 pl.sr.hr_444 sq.lt..._430
  // [2e90]
  0x121d4508, 0x14102709, 0x16002e14, 0x17002914,   // sk.hr.cs_443 id.sv.is_444 sq.lt..._660 ms.ro..._660
  0x66000613, 0x1f053f08, 0x292e2707, 0x0e251e14,   // de.af..._650 sw.fr.ga_443 id.sq.ms_432 sr.mk.ru_666
  0x06040109, 0x22002b21, 0x3a0110a4, 0x15001921,   // en.fi.de_444 cy.tr..._860 sv.en.eu_433 et.lv..._860
  0x3a042108, 0x12400107, 0x66211f12, 0x1d064202,   // tl.fi.eu_443 en.sl.cs_432 ga.tl.af_654 mt.de.hr_222
  // [2ea0]
  0x42052b13, 0x1d450408, 0x05036655, 0x1d3a0c07,   // cy.fr.mt_665 fi.sk.hr_443 af.nl.fr_442 pl.eu.hr_432
  0x66038c08, 0x04001e07, 0x03660212, 0x29151660,   // ht.nl.af_443 sr.fi..._420 da.af.nl_654 lt.lv.ms_664
  0x01000314, 0x1f001009, 0x3f0f16a4, 0x16001708,   // nl.en..._660 sv.ga..._440 lt.es.sw_433 ro.lt..._430
  0x21041908, 0x1e302513, 0x29271812, 0x42002223,   // et.fi.tl_443 mk.be.sr_665 hu.id.ms_654 tr.mt..._880
  // [2eb0]
  0x0b004213, 0x1c2325a4, 0x16001014, 0x10002b21,   // mt.no..._650 mk.uk.bg_433 sv.lt..._660 cy.sv..._860
  0x430f1f08, 0x12001f21, 0x293a0c02, 0x270d2909,   // ga.es.vi_443 ga.cs..._860 pl.eu.ms_222 ms.pt.id_444
  0x2b224b13, 0x141f4360, 0x12004012, 0x121e1d08,   // az.tr.cy_665 vi.ga.is_664 sl.cs..._640 hr.sr.cs_443
  0x0c228c09, 0x3a002202, 0x22274b09, 0x4b000d13,   // ht.tr.pl_444 tr.eu..._220 az.id.tr_444 pt.az..._650
  // [2ec0]
  0x270c2909, 0x0f381f09, 0x42213f13, 0x23301c09,   // ms.pl.id_444 ga.ca.es_444 sw.tl.mt_665 bg.be.uk_444
  0x12004322, 0x3a0f0d08, 0x22004b20, 0x1d0f1002,   // vi.cs..._870 pt.es.eu_443 az.tr..._850 sv.es.hr_222
  0x161e1d60, 0x3f4b2260, 0x29151602, 0x3f001602,   // hr.sr.lt_664 tr.az.sw_664 lt.lv.ms_222 lt.sw..._220
  0x453f6602, 0x4b221755, 0x29160b09, 0x16000309,   // af.sw.sk_222 ro.tr.az_442 no.lt.ms_444 nl.lt..._440
  // [2ed0]
  0x17002213, 0x45150c14, 0x42001713, 0x2b051faf,   // tr.ro..._650 pl.lv.sk_666 ro.mt..._650 ga.fr.cy_655
  0x10140b11, 0x8c003a08, 0x45228c55, 0x0c8c2b12,   // no.is.sv_653 eu.ht..._430 ht.tr.sk_442 cy.ht.pl_654
  0x12001f02, 0x05124511, 0x050f6609, 0x06008c13,   // ga.cs..._220 sk.cs.fr_653 af.es.fr_444 ht.de..._650
  0x19001513, 0x301e0e08, 0x1e222107, 0x45181411,   // lv.et..._650 ru.sr.be_443 tl.tr.sr_432 is.hu.sk_653
  // [2ee0]
  0x1d181e08, 0x222e0b09, 0x0f141fa4, 0x1e161508,   // sr.hu.hr_443 no.sq.tr_444 ga.is.es_433 lv.lt.sr_443
  0x22161560, 0x18381f12, 0x29273a08, 0x10000222,   // lv.lt.tr_664 ga.ca.hu_654 eu.id.ms_443 da.sv..._870
  0x40001212, 0x1d144202, 0x301c2513, 0x0b002e09,   // cs.sl..._640 mt.is.hr_222 mk.bg.be_665 sq.no..._440
  0x1d2e0f08, 0x27003f13, 0x17003a21, 0x0c000308,   // es.sq.hr_443 sw.id..._650 eu.ro..._860 nl.pl..._430
  // [2ef0]
  0x030b06a4, 0x03060408, 0x08003f02, 0x0c000808,   // de.no.nl_433 fi.de.nl_443 sw.it..._220 it.pl..._430
  0x43008c14, 0x12001814, 0x29000d09, 0x3f1e1da4,   // ht.vi..._660 hu.cs..._660 pt.ms..._440 hr.sr.sw_433
  0x30251ca4, 0x01000213, 0x0e231c60, 0x3a001f12,   // bg.mk.be_433 da.en..._650 bg.uk.ru_664 ga.eu..._640
  0x121a4009, 0x15003a08, 0x3f058c08, 0x043f1612,   // sl.xxx.cs_444 eu.lv..._430 ht.fr.sw_443 lt.sw.fi_654
  // [2f00]
  0x8c002123, 0x38050fa4, 0x01002123, 0x228c0107,   // tl.ht..._880 es.fr.ca_433 tl.en..._880 en.ht.tr_432
  0x03451a08, 0x3a000f22, 0x27002b14, 0x3f1d1e60,   // xxx.sk.nl_443 es.eu..._870 cy.id..._660 sr.hr.sw_664
  0x42001814, 0x251e30a4, 0x1a3f4208, 0x42000f13,   // hu.mt..._660 be.sr.mk_433 mt.sw.xxx_443 es.mt..._650
  0x8c001814, 0x0e1c2360, 0x15001d23, 0x14380f08,   // hu.ht..._660 uk.bg.ru_664 hr.lv..._880 es.ca.is_443
  // [2f10]
  0x020619a4, 0x0b6610a4, 0x0d450f09, 0x06100413,   // et.de.da_433 sv.af.no_433 es.sk.pt_444 fi.sv.de_665
  0x06002113, 0x0e1c2555, 0x02000114, 0x4b002e14,   // tl.de..._650 mk.bg.ru_442 en.da..._660 sq.az..._660
  0x05001808, 0x27000102, 0x66002b11, 0x4b002113,   // hu.fr..._430 en.id..._220 cy.af..._630 tl.az..._650
  0x15004b09, 0x38060512, 0x0c000823, 0x4b008c09,   // az.lv..._440 fr.de.ca_654 it.pl..._880 ht.az..._440
  // [2f20]
  0x38004023, 0x278c4b02, 0x27052013, 0x1e001408,   // sl.ca..._880 az.ht.id_222 gl.fr.id_665 is.sr..._430
  0x18001008, 0x38002b23, 0x382b1713, 0x45021208,   // sv.hu..._430 cy.ca..._880 ro.cy.ca_665 cs.da.sk_443
  0x45000208, 0x12024509, 0x10000d08, 0x061a10a4,   // da.sk..._430 sk.da.cs_444 pt.sv..._430 sv.xxx.de_433
  0x080b02a4, 0x2e000613, 0x2b011f08, 0x22180209,   // da.no.it_433 de.sq..._650 ga.en.cy_443 da.hu.tr_444
  // [2f30]
  0x19002014, 0x2e1f01af, 0x4b221707, 0x01004b09,   // gl.et..._660 en.ga.sq_655 ro.tr.az_432 az.en..._440
  0x22151008, 0x2b060b09, 0x22420b07, 0x08000b14,   // sv.lv.tr_443 no.de.cy_444 no.mt.tr_432 no.it..._660
  0x1e451d09, 0x10000813, 0x3f451209, 0x17224b08,   // hr.sk.sr_444 it.sv..._650 cs.sk.sw_444 az.tr.ro_443
  0x15004513, 0x01001d09, 0x1e250e12, 0x2b004322,   // sk.lv..._650 hr.en..._440 ru.mk.sr_654 vi.cy..._870
  // [2f40]
  0x660214a4, 0x43002b12, 0x3a433808, 0x08004009,   // is.da.af_433 cy.vi..._640 ca.vi.eu_443 sl.it..._440
  0x0c002214, 0x08384507, 0x160210a4, 0x04000d08,   // tr.pl..._660 sk.ca.it_432 sv.da.lt_433 pt.fi..._430
  0x01053860, 0x03290407, 0x1e000302, 0x16214009,   // ca.fr.en_664 fi.ms.nl_432 nl.sr..._220 sl.tl.lt_444
  0x0b660312, 0x2b000b08, 0x3a060109, 0x1d000614,   // nl.af.no_654 no.cy..._430 en.de.eu_444 de.hr..._660
  // [2f50]
  0x19001808, 0x031d1e08, 0x382729a4, 0x00002e0a,   // hu.et..._430 sr.hr.nl_443 ms.id.ca_433 sq......_500
  0x45182102, 0x40002209, 0x1e003020, 0x66002209,   // tl.hu.sk_222 tr.sl..._440 be.sr..._850 tr.af..._440
  0x2b000d22, 0x08002b13, 0x1a000b21, 0x1e000107,   // pt.cy..._870 cy.it..._650 no.xxx..._860 en.sr..._420
  0x19026608, 0x06000312, 0x3f660355, 0x29003f12,   // af.da.et_443 nl.de..._640 nl.af.sw_442 sw.ms..._640
  // [2f60]
  0x42000408, 0x04420808, 0x191d1ea4, 0x43003809,   // fi.mt..._430 it.mt.fi_443 sr.hr.et_433 ca.vi..._440
  0x0c060309, 0x38434b12, 0x03060109, 0x121a1408,   // nl.de.pl_444 az.vi.ca_654 en.de.nl_444 is.xxx.cs_443
  0x19002212, 0x4b003a02, 0x02002714, 0x4b003809,   // tr.et..._640 eu.az..._220 id.da..._660 ca.az..._440
  0x0b003f02, 0x450f1e02, 0x180f0b08, 0x18023fa4,   // sw.no..._220 sr.es.sk_222 no.es.hu_443 sw.da.hu_433
  // [2f70]
  0x4b001a08, 0x034b22a4, 0x15002e14, 0x10000323,   // xxx.az..._430 tr.az.nl_433 sq.lv..._660 nl.sv..._880
  0x29000102, 0x40002102, 0x18001509, 0x228c4b12,   // en.ms..._220 tl.sl..._220 lv.hu..._440 az.ht.tr_654
  0x453f1502, 0x163f3aa4, 0x4b00221b, 0x061014a4,   // lv.sw.sk_222 eu.sw.lt_433 tr.az..._770 is.sv.de_433
  0x3f003814, 0x02000523, 0x04190508, 0x152b1209,   // ca.sw..._660 fr.da..._880 fr.et.fi_443 cs.cy.lv_444
  // [2f80]
  0x02050b07, 0x29100208, 0x230e25a4, 0x662b02a4,   // no.fr.da_432 da.sv.ms_443 mk.ru.uk_433 da.cy.af_433
  0x03001409, 0x0f0416a4, 0x17224b07, 0x278c2202,   // is.nl..._440 lt.fi.es_433 az.tr.ro_432 tr.ht.id_222
  0x120f1a02, 0x16002213, 0x21000c09, 0x1d101912,   // xxx.es.cs_222 tr.lt..._650 pl.tl..._440 et.sv.hr_654
  0x2b000308, 0x18454208, 0x06036611, 0x172b1faf,   // nl.cy..._430 mt.sk.hu_443 af.nl.de_653 ga.cy.ro_655
  // [2f90]
  0x251c0e55, 0x170f4507, 0x383a2b12, 0x02141009,   // ru.bg.mk_442 sk.es.ro_432 cy.eu.ca_654 sv.is.da_444
  0x29000113, 0x15041609, 0x2e008c08, 0x15001713,   // en.ms..._650 lt.fi.lv_444 ht.sq..._430 ro.lv..._650
  0x23251ca4, 0x27004523, 0x06140b09, 0x06006622,   // bg.mk.uk_433 sk.id..._880 no.is.de_444 af.de..._870
  0x66032ea4, 0x0d451214, 0x171e1d14, 0x0f002923,   // sq.nl.af_433 cs.sk.pt_666 hr.sr.ro_666 ms.es..._880
  // [2fa0]
  0x06021009, 0x03104309, 0x0b190212, 0x43000409,   // sv.da.de_444 vi.sv.nl_444 da.et.no_654 fi.vi..._440
  0x38220da4, 0x14000b21, 0x66000208, 0x43004208,   // pt.tr.ca_433 no.is..._860 da.af..._430 mt.vi..._430
  0x4b024209, 0x1e1d3a07, 0x0c001812, 0x423a0814,   // mt.da.az_444 eu.hr.sr_432 hu.pl..._640 it.eu.mt_666
  0x0b004214, 0x02001209, 0x1d120202, 0x1d2e4307,   // mt.no..._660 cs.da..._440 da.cs.hr_222 vi.sq.hr_432
  // [2fb0]
  0x42012ba4, 0x42001a14, 0x3a061812, 0x1d032e08,   // cy.en.mt_433 xxx.mt..._660 hu.de.eu_654 sq.nl.hr_443
  0x04060109, 0x04420ba4, 0x42080108, 0x22180807,   // en.de.fi_444 no.mt.fi_433 en.it.mt_443 it.hu.tr_432
  0x43001814, 0x0b044208, 0x270d2907, 0x024516a4,   // hu.vi..._660 mt.fi.no_443 ms.pt.id_432 lt.sk.da_433
  0x17053855, 0x29182707, 0x1c302314, 0x18000f22,   // ca.fr.ro_442 id.hu.ms_432 uk.be.bg_666 es.hu..._870
  // [2fc0]
  0x18001f11, 0x0f001821, 0x12451860, 0x200f1812,   // ga.hu..._630 hu.es..._860 hu.sk.cs_664 hu.es.gl_654
  0x05380107, 0x42000b14, 0x18054b08, 0x100603a4,   // en.ca.fr_432 no.mt..._660 az.fr.hu_443 nl.de.sv_433
  0x04453f12, 0x3f004223, 0x3f3a2709, 0x22058c12,   // sw.sk.fi_654 mt.sw..._880 id.eu.sw_444 ht.fr.tr_654
  0x0f001e09, 0x12002202, 0x05001822, 0x128c0560,   // sr.es..._440 tr.cs..._220 hu.fr..._870 fr.ht.cs_664
  // [2fd0]
  0x20000802, 0x2b000c08, 0x20000122, 0x20001802,   // it.gl..._220 pl.cy..._430 en.gl..._870 hu.gl..._220
  0x29012707, 0x0b0f0d11, 0x120d66ad, 0x29452702,   // id.en.ms_432 pt.es.no_653 af.pt.cs_643 id.sk.ms_222
  0x18000523, 0x18000f07, 0x06100412, 0x01008c14,   // fr.hu..._880 es.hu..._420 fi.sv.de_654 ht.en..._660
  0x19001512, 0x21003a08, 0x21222909, 0x10041908,   // lv.et..._640 eu.tl..._430 ms.tr.tl_444 et.fi.sv_443
  // [2fe0]
  0x032e66a4, 0x17004002, 0x66000f14, 0x25302307,   // af.sq.nl_433 sl.ro..._220 es.af..._660 uk.be.mk_432
  0x42000102, 0x030c0608, 0x1e001c08, 0x0b161009,   // en.mt..._220 de.pl.nl_443 bg.sr..._430 sv.lt.no_444
  0x02001623, 0x43004009, 0x3f001623, 0x06011a13,   // lt.da..._880 sl.vi..._440 lt.sw..._880 xxx.en.de_665
  0x15001a09, 0x251c0ead, 0x2e124508, 0x05451812,   // xxx.lv..._440 ru.bg.mk_643 sk.cs.sq_443 hu.sk.fr_654
  // [2ff0]
  0x19001f12, 0x190502a4, 0x0d0f1809, 0x141904af,   // ga.et..._640 da.fr.et_433 hu.es.pt_444 fi.et.is_655
  0x0d182012, 0x1d451611, 0x05001413, 0x25301c14,   // gl.hu.pt_654 lt.sk.hr_653 is.fr..._650 bg.be.mk_666
  0x22181a09, 0x18223a08, 0x04006608, 0x0d184509,   // xxx.hu.tr_444 eu.tr.hu_443 af.fi..._430 sk.hu.pt_444
  0x01100202, 0x0f0d1812, 0x17002123, 0x8c213f12,   // da.sv.en_222 hu.pt.es_654 tl.ro..._880 sw.tl.ht_654

  // [3000]
  0x0f001514, 0x0d0117a4, 0x1d001e21, 0x66182107,   // lv.es..._660 ro.en.pt_433 sr.hr..._860 tl.hu.af_432
  0x21022702, 0x124505a4, 0x1e380412, 0x0f001810,   // id.da.tl_222 fr.sk.cs_433 fi.ca.sr_654 hu.es..._620
  0x1f451209, 0x45154002, 0x02003808, 0x1e106602,   // cs.sk.ga_444 sl.lv.sk_222 ca.da..._430 af.sv.sr_222
  0x08000112, 0x15196613, 0x1e002511, 0x0f004014,   // en.it..._640 af.et.lv_665 mk.sr..._630 sl.es..._660
  // [3010]
  0x19002e12, 0x100f2e60, 0x16400d12, 0x17000308,   // sq.et..._640 sq.es.sv_664 pt.sl.lt_654 nl.ro..._430
  0x151002a4, 0x29000409, 0x180d1455, 0x1f001812,   // da.sv.lv_433 fi.ms..._440 is.pt.hu_442 hu.ga..._640
  0x0d0f1808, 0x2e004013, 0x0c000402, 0x42081055,   // hu.es.pt_443 sl.sq..._650 fi.pl..._220 sv.it.mt_442
  0x10210b09, 0x1d296602, 0x01000809, 0x192b01a4,   // no.tl.sv_444 af.ms.hr_222 it.en..._440 en.cy.et_433
  // [3020]
  0x4b0b2b08, 0x05180d55, 0x29272e09, 0x450b1208,   // cy.no.az_443 pt.hu.fr_442 sq.id.ms_444 cs.no.sk_443
  0x01171002, 0x152e4008, 0x29000f14, 0x0d002e13,   // sv.ro.en_222 sl.sq.lv_443 es.ms..._660 sq.pt..._650
  0x10000d09, 0x0d1738a4, 0x14001913, 0x0c8c2b60,   // pt.sv..._440 ca.ro.pt_433 et.is..._650 cy.ht.pl_664
  0x04160613, 0x18001a12, 0x19001809, 0x0d223809,   // de.lt.fi_665 xxx.hu..._640 hu.et..._440 ca.tr.pt_444
  // [3030]
  0x15000f14, 0x2e060312, 0x1e161d13, 0x1c252312,   // es.lv..._660 nl.de.sq_654 hr.lt.sr_665 uk.mk.bg_654
  0x453f0109, 0x1e1d0d02, 0x15011a09, 0x12064508,   // en.sw.sk_444 pt.hr.sr_222 xxx.en.lv_444 sk.de.cs_443
  0x08060109, 0x42292709, 0x17083a08, 0x023f1060,   // en.de.it_444 id.ms.mt_444 eu.it.ro_443 sv.sw.da_664
  0x16173a08, 0x17000813, 0x230e2511, 0x42003f23,   // eu.ro.lt_443 it.ro..._650 mk.ru.uk_653 sw.mt..._880
  // [3040]
  0x150c4513, 0x0b100207, 0x27291f60, 0x45141f02,   // sk.pl.lv_665 da.sv.no_432 ga.ms.id_664 ga.is.sk_222
  0x10002907, 0x271a2102, 0x14004b09, 0x8c002907,   // ms.sv..._420 tl.xxx.id_222 az.is..._440 ms.ht..._420
  0x66140b07, 0x1e0e1cad, 0x21004002, 0x19000c09,   // no.is.af_432 bg.ru.sr_643 sl.tl..._220 pl.et..._440
  0x1f000d23, 0x0c001607, 0x1a002e09, 0x03000521,   // pt.ga..._880 lt.pl..._420 sq.xxx..._440 fr.nl..._860
  // [3050]
  0x02102b07, 0x14041008, 0x224b1707, 0x1e001909,   // cy.sv.da_432 sv.fi.is_443 ro.az.tr_432 et.sr..._440
  0x370e1e14, 0x8c000b14, 0x3f003a12, 0x38001613,   // sr.ru.ar_666 no.ht..._660 eu.sw..._640 lt.ca..._650
  0x04141912, 0x0d002b14, 0x17383a11, 0x14000309,   // et.is.fi_654 cy.pt..._660 eu.ca.ro_653 nl.is..._440
  0x3f001522, 0x19003f22, 0x03190460, 0x3f1a4209,   // lv.sw..._870 sw.et..._870 fi.et.nl_664 mt.xxx.sw_444
  // [3060]
  0x191804a4, 0x224b0612, 0x3f1a2eaf, 0x0c8c4260,   // fi.hu.et_433 de.az.tr_654 sq.xxx.sw_655 mt.ht.pl_664
  0x22001513, 0x04000f07, 0x0d002e09, 0x4b220609,   // lv.tr..._650 es.fi..._420 sq.pt..._440 de.tr.az_444
  0x220d0fa4, 0x23001c07, 0x02100bad, 0x0d0f4509,   // es.pt.tr_433 bg.uk..._420 no.sv.da_643 sk.es.pt_444
  0x061019ad, 0x45151212, 0x01041412, 0x06150307,   // et.sv.de_643 cs.lv.sk_654 is.fi.en_654 nl.lv.de_432
  // [3070]
  0x1f001712, 0x1d162709, 0x02011aa4, 0x020d0f08,   // ro.ga..._640 id.lt.hr_444 xxx.en.da_433 es.pt.da_443
  0x018c1a07, 0x2b000b13, 0x402e2107, 0x19161512,   // xxx.ht.en_432 no.cy..._650 tl.sq.sl_432 lv.lt.et_654
  0x041519af, 0x1d1e6602, 0x2b004302, 0x040610af,   // et.lv.fi_655 af.sr.hr_222 vi.cy..._220 sv.de.fi_655
  0x184b2213, 0x02040b07, 0x45001a23, 0x19041013,   // tr.az.hu_665 no.fi.da_432 xxx.sk..._880 sv.fi.et_665
  // [3080]
  0x04036608, 0x1a084208, 0x05000612, 0x3a030fa4,   // af.nl.fi_443 mt.it.xxx_443 de.fr..._640 es.nl.eu_433
  0x8c3f2213, 0x031002a4, 0x14061008, 0x29212202,   // tr.sw.ht_665 da.sv.nl_433 sv.de.is_443 tr.tl.ms_222
  0x22213f12, 0x0c061809, 0x04100611, 0x0f2b0d08,   // sw.tl.tr_654 hu.de.pl_444 de.sv.fi_653 pt.cy.es_443
  0x21000223, 0x1e250e07, 0x38402b09, 0x400c4555,   // da.tl..._880 ru.mk.sr_432 cy.sl.ca_444 sk.pl.sl_442
  // [3090]
  0x27452902, 0x251e1c11, 0x452e0407, 0x1d1a1e08,   // ms.sk.id_222 bg.sr.mk_653 fi.sq.sk_432 sr.xxx.hr_443
  0x1a171508, 0x8c001909, 0x0b001823, 0x8c000d02,   // lv.ro.xxx_443 et.ht..._440 hu.no..._880 pt.ht..._220
  0x19003a13, 0x0b061008, 0x10191860, 0x0b002109,   // eu.et..._650 sv.de.no_443 hu.et.sv_664 tl.no..._440
  0x8c0b1860, 0x3a002914, 0x02420809, 0x1e1d3802,   // hu.no.ht_664 ms.eu..._660 it.mt.da_444 ca.hr.sr_222
  // [30a0]
  0x1a001802, 0x27006608, 0x181d1e13, 0x15008c02,   // hu.xxx..._220 af.id..._430 sr.hr.hu_665 ht.lv..._220
  0x45000408, 0x04196608, 0x10066608, 0x21000214,   // fi.sk..._430 af.et.fi_443 af.de.sv_443 da.tl..._660
  0x04001f21, 0x15002109, 0x081a3f09, 0x16003f22,   // ga.fi..._860 tl.lv..._440 sw.xxx.it_444 sw.lt..._870
  0x15000609, 0x3f292708, 0x3f184208, 0x3a0d3860,   // de.lv..._440 id.ms.sw_443 mt.hu.sw_443 ca.pt.eu_664
  // [30b0]
  0x3a061a08, 0x402e1209, 0x04003f08, 0x1f001a14,   // xxx.de.eu_443 cs.sq.sl_444 sw.fi..._430 xxx.ga..._660
  0x0d050802, 0x20001f14, 0x17162e08, 0x45221902,   // it.fr.pt_222 ga.gl..._660 sq.lt.ro_443 et.tr.sk_222
  0x43012b08, 0x27192909, 0x3f004212, 0x193f0307,   // cy.en.vi_443 ms.et.id_444 mt.sw..._640 nl.sw.et_432
  0x21272909, 0x04212709, 0x063f1a14, 0x3a0c0fa4,   // ms.id.tl_444 id.tl.fi_444 xxx.sw.de_666 es.pl.eu_433
  // [30c0]
  0x0f003f14, 0x1d163f02, 0x1a003f22, 0x0f003f13,   // sw.es..._660 sw.lt.hr_222 sw.xxx..._870 sw.es..._650
  0x0d051812, 0x174b0308, 0x1d003f07, 0x02002202,   // hu.fr.pt_654 nl.az.ro_443 sw.hr..._420 tr.da..._220
  0x010302a4, 0x660203af, 0x66000207, 0x0d001e09,   // da.nl.en_433 nl.da.af_655 da.af..._420 sr.pt..._440
  0x2e000312, 0x2e0c18a4, 0x0000380a, 0x18000c08,   // nl.sq..._640 hu.pl.sq_433 ca......_500 pl.hu..._430
  // [30d0]
  0x19154255, 0x1a003812, 0x08660314, 0x40034507,   // mt.lv.et_442 ca.xxx..._640 nl.af.it_666 sk.nl.sl_432
  0x3a000408, 0x08004208, 0x050d0f60, 0x05000d22,   // fi.eu..._430 mt.it..._430 es.pt.fr_664 pt.fr..._870
  0x0d0f0555, 0x20040d09, 0x27194208, 0x1e1d1611,   // fr.es.pt_442 pt.fi.gl_444 mt.et.id_443 lt.hr.sr_653
  0x40002b02, 0x0f004b09, 0x0c002b23, 0x230e2560,   // cy.sl..._220 az.es..._440 cy.pl..._880 mk.ru.uk_664
  // [30e0]
  0x4b4208a4, 0x18000d23, 0x15451612, 0x0b200109,   // it.mt.az_433 pt.hu..._880 lt.sk.lv_654 en.gl.no_444
  0x050f8c02, 0x0e231ca4, 0x0f3805af, 0x10180b09,   // ht.es.fr_222 bg.uk.ru_433 fr.ca.es_655 no.hu.sv_444
  0x0b420807, 0x3f080d14, 0x2e002907, 0x04160b09,   // it.mt.no_432 pt.it.sw_666 ms.sq..._420 no.lt.fi_444
  0x431d1e02, 0x3f000d23, 0x14011f02, 0x4b221413,   // sr.hr.vi_222 pt.sw..._880 ga.en.is_222 is.tr.az_665
  // [30f0]
  0x0f0d3807, 0x20001822, 0x3f8c1a09, 0x42008c22,   // ca.pt.es_432 hu.gl..._870 xxx.ht.sw_444 ht.mt..._870
  0x05000c14, 0x291e1d07, 0x0c180655, 0x0f4b226b,   // pl.fr..._660 hr.sr.ms_432 de.hu.pl_442 tr.az.es_872
  0x450b1002, 0x16221409, 0x14180612, 0x06161507,   // sv.no.sk_222 is.tr.lt_444 de.hu.is_654 lv.lt.de_432
  0x272e2902, 0x42172e09, 0x19002b13, 0x191615a4,   // ms.sq.id_222 sq.ro.mt_444 cy.et..._650 lv.lt.et_433
  // [3100]
  0x05002e08, 0x451a0107, 0x300e1e07, 0x66420107,   // sq.fr..._430 en.xxx.sk_432 sr.ru.be_432 en.mt.af_432
  0x453f0602, 0x1d061e02, 0x380f0512, 0x062266a4,   // de.sw.sk_222 sr.de.hr_222 fr.es.ca_654 af.tr.de_433
  0x03002222, 0x0f380d12, 0x662b03a4, 0x0c003f22,   // tr.nl..._870 pt.ca.es_654 nl.cy.af_433 sw.pl..._870
  0x3f0c1aa4, 0x8c3f2114, 0x231e0e09, 0x06211460,   // xxx.pl.sw_433 tl.sw.ht_666 ru.sr.uk_444 is.tl.de_664
  // [3110]
  0x382e0f08, 0x0b102b12, 0x0b001021, 0x662927af,   // es.sq.ca_443 cy.sv.no_654 sv.no..._860 id.ms.af_655
  0x21040109, 0x27192908, 0x17001413, 0x17002122,   // en.fi.tl_444 ms.et.id_443 is.ro..._650 tl.ro..._870
  0x8c002b08, 0x01080508, 0x12003f08, 0x38220daf,   // cy.ht..._430 fr.it.en_443 sw.cs..._430 pt.tr.ca_655
  0x02082e08, 0x053a2e13, 0x2e000823, 0x1a453fa4,   // sq.it.da_443 sq.eu.fr_665 it.sq..._880 sw.sk.xxx_433
  // [3120]
  0x0b002909, 0x1e1d1402, 0x18001709, 0x14000408,   // ms.no..._440 is.hr.sr_222 ro.hu..._440 fi.is..._430
  0x0c180613, 0x03660213, 0x16001e14, 0x08422707,   // de.hu.pl_665 da.af.nl_665 sr.lt..._660 id.mt.it_432
  0x45402e02, 0x12018c02, 0x16183aa4, 0x14001622,   // sq.sl.sk_222 ht.en.cs_222 eu.hu.lt_433 lt.is..._870
  0x380f0d11, 0x1d001423, 0x1e001207, 0x0e1e2309,   // pt.es.ca_653 is.hr..._880 cs.sr..._420 uk.sr.ru_444
  // [3130]
  0x0c001e09, 0x170d1608, 0x05001608, 0x0f0d12a4,   // sr.pl..._440 lt.pt.ro_443 lt.fr..._430 cs.pt.es_433
  0x16004b09, 0x0f003a20, 0x06011a07, 0x433a4209,   // az.lt..._440 eu.es..._850 xxx.en.de_432 mt.eu.vi_444
  0x8c003a13, 0x0e301ea4, 0x14100b08, 0x16001709,   // eu.ht..._650 sr.be.ru_433 no.sv.is_443 ro.lt..._440
  0x0f0d0502, 0x451218af, 0x1f001923, 0x1c250e08,   // fr.pt.es_222 hu.cs.sk_655 et.ga..._880 ru.mk.bg_443
  // [3140]
  0x190d0b09, 0x40002714, 0x10002214, 0x033a6609,   // no.pt.et_444 id.sl..._660 tr.sv..._660 af.eu.nl_444
  0x18003a22, 0x03002b08, 0x40001422, 0x05004002,   // eu.hu..._870 cy.nl..._430 is.sl..._870 sl.fr..._220
  0x2b001909, 0x16043f07, 0x21190408, 0x2e001f13,   // et.cy..._440 sw.fi.lt_432 fi.et.tl_443 ga.sq..._650
  0x021f1807, 0x1f060f08, 0x45150c13, 0x18210109,   // hu.ga.da_432 es.de.ga_443 pl.lv.sk_665 en.tl.hu_444
  // [3150]
  0x141d0b09, 0x27291660, 0x29451e02, 0x29004514,   // no.hr.is_444 lt.ms.id_664 sr.sk.ms_222 sk.ms..._660
  0x45181213, 0x43001614, 0x27001914, 0x05001811,   // cs.hu.sk_665 lt.vi..._660 et.id..._660 hu.fr..._630
  0x081e1d09, 0x3a0f38a4, 0x05080408, 0x3f1e1d13,   // hr.sr.it_444 ca.es.eu_433 fi.it.fr_443 hr.sr.sw_665
  0x25301e12, 0x42452909, 0x3f004509, 0x212b1f12,   // sr.be.mk_654 ms.sk.mt_444 sk.sw..._440 ga.cy.tl_654
  // [3160]
  0x01124560, 0x02008c14, 0x8c003811, 0x19182b08,   // sk.cs.en_664 ht.da..._660 ca.ht..._630 cy.hu.et_443
  0x4b144507, 0x3814181d, 0x18453812, 0x16001821,   // sk.is.az_432 hu.is.ca_852 ca.sk.hu_654 hu.lt..._860
  0x100266a4, 0x05003f09, 0x030666af, 0x3a292709,   // af.da.sv_433 sw.fr..._440 af.de.nl_655 id.ms.eu_444
  0x43000f09, 0x02003a09, 0x3f2e3aaf, 0x2e3f0412,   // es.vi..._440 eu.da..._440 eu.sq.sw_655 fi.sw.sq_654
  // [3170]
  0x292b8c02, 0x3a0d0f12, 0x01042b08, 0x22001907,   // ht.cy.ms_222 es.pt.eu_654 cy.fi.en_443 et.tr..._420
  0x45012b02, 0x2e006614, 0x0c000f07, 0x213f0108,   // cy.en.sk_222 af.sq..._660 es.pl..._420 en.sw.tl_443
  0x02004523, 0x27103f08, 0x25003023, 0x2e004522,   // sk.da..._880 sw.sv.id_443 be.mk..._880 sk.sq..._870
  0x04004214, 0x27212913, 0x03060c55, 0x1d1e0110,   // mt.fi..._660 ms.tl.id_665 pl.de.nl_442 en.sr.hr_642
  // [3180]
  0x166604a4, 0x04000623, 0x450442a4, 0x292e3a02,   // fi.af.lt_433 de.fi..._880 mt.fi.sk_433 eu.sq.ms_222
  0x45004214, 0x18422ea4, 0x20001023, 0x20003a23,   // mt.sk..._660 sq.mt.hu_433 sv.gl..._880 eu.gl..._880
  0x03063aa4, 0x1a001023, 0x1d031e02, 0x18380508,   // eu.de.nl_433 sv.xxx..._880 sr.nl.hr_222 fr.ca.hu_443
  0x14003a23, 0x14221012, 0x38001f10, 0x0d050109,   // eu.is..._880 sv.tr.is_654 ga.ca..._620 en.fr.pt_444
  // [3190]
  0x1e1d45a4, 0x451d4008, 0x45063a08, 0x273f2907,   // sk.hr.sr_433 sl.hr.sk_443 eu.de.sk_443 ms.sw.id_432
  0x294b2702, 0x43000602, 0x45010202, 0x21002714,   // id.az.ms_222 de.vi..._220 da.en.sk_222 id.tl..._660
  0x231e0e55, 0x29020b02, 0x050d0107, 0x29042708,   // ru.sr.uk_442 no.da.ms_222 en.pt.fr_432 id.fi.ms_443
  0x29082709, 0x27210b08, 0x16004223, 0x21290b09,   // id.it.ms_444 no.tl.id_443 mt.lt..._880 no.ms.tl_444
  // [31a0]
  0x2e4b4212, 0x454b2202, 0x04191709, 0x01000c14,   // mt.az.sq_654 tr.az.sk_222 ro.et.fi_444 pl.en..._660
  0x1d00400e, 0x08008c14, 0x45120802, 0x29001214,   // sl.hr..._550 ht.it..._660 it.cs.sk_222 cs.ms..._660
  0x10000f09, 0x221d3aa4, 0x27173802, 0x45120d08,   // es.sv..._440 eu.hr.tr_433 ca.ro.id_222 pt.cs.sk_443
  0x8c040b09, 0x4b004213, 0x18000213, 0x42000c08,   // no.fi.ht_444 mt.az..._650 da.hu..._650 pl.mt..._430
  // [31b0]
  0x20001614, 0x17001022, 0x04001f23, 0x15164508,   // lt.gl..._660 sv.ro..._870 ga.fi..._880 sk.lt.lv_443
  0x27030c12, 0x1d2e1e09, 0x041f0109, 0x291a2702,   // pl.nl.id_654 sr.sq.hr_444 en.ga.fi_444 id.xxx.ms_222
  0x0b1202a4, 0x27218c02, 0x27214302, 0x661a1009,   // da.cs.no_433 ht.tl.id_222 vi.tl.id_222 sv.xxx.af_444
  0x45021007, 0x05001f21, 0x1d0442a4, 0x05001f07,   // sv.da.sk_432 ga.fr..._860 mt.fi.hr_433 ga.fr..._420
  // [31c0]
  0x8c060109, 0x3f000614, 0x20000602, 0x060c1a09,   // en.de.ht_444 de.sw..._660 de.gl..._220 xxx.pl.de_444
  0x063f0308, 0x1e1d1212, 0x2e8c3812, 0x1c250e09,   // nl.sw.de_443 cs.hr.sr_654 ca.ht.sq_654 ru.mk.bg_444
  0x3f001a13, 0x00002501, 0x251e0e08, 0x2e00051f,   // xxx.sw..._650 mk......_200 ru.sr.mk_443 fr.sq..._840
  0x19003812, 0x23301e12, 0x45041702, 0x2e3a0408,   // ca.et..._640 sr.be.uk_654 ro.fi.sk_222 fi.eu.sq_443
  // [31d0]
  0x04001e09, 0x14004022, 0x29002e21, 0x15004221,   // sr.fi..._440 sl.is..._870 sq.ms..._860 mt.lv..._860
  0x00001f15, 0x02000414, 0x124b4502, 0x45001413,   // ga......_700 fi.da..._660 sk.az.cs_222 is.sk..._650
  0x1a004213, 0x45001909, 0x18060412, 0x45016607,   // mt.xxx..._650 et.sk..._440 fi.de.hu_654 af.en.sk_432
  0x45123812, 0x221e1d14, 0x21423fad, 0x18293aa4,   // ca.cs.sk_654 hr.sr.tr_666 sw.mt.tl_643 eu.ms.hu_433
  // [31e0]
  0x66141060, 0x8c002e07, 0x2b003f22, 0x108c0109,   // sv.is.af_664 sq.ht..._420 sw.cy..._870 en.ht.sv_444
  0x0f0d1809, 0x04001907, 0x02140ba4, 0x420c4555,   // hu.pt.es_444 et.fi..._420 no.is.da_433 sk.pl.mt_442
  0x0f008c22, 0x43014208, 0x04060cad, 0x0f213a09,   // ht.es..._870 mt.en.vi_443 pl.de.fi_643 eu.tl.es_444
  0x05001014, 0x66000c12, 0x451e1d14, 0x19060455,   // sv.fr..._660 pl.af..._640 hr.sr.sk_666 fi.de.et_442
  // [31f0]
  0x2b001f13, 0x0b000514, 0x18006614, 0x19004014,   // ga.cy..._650 fr.no..._660 af.hu..._660 sl.et..._660
  0x42002e23, 0x10000607, 0x422e4007, 0x1f004b14,   // sq.mt..._880 de.sv..._420 sl.sq.mt_432 az.ga..._660
  0x2e004008, 0x29062707, 0x0f002012, 0x10404260,   // sl.sq..._430 id.de.ms_432 gl.es..._640 mt.sl.sv_664
  0x27298c14, 0x04450608, 0x0c002113, 0x04171914,   // ht.ms.id_666 de.sk.fi_443 tl.pl..._650 et.ro.fi_666
  // [3200]
  0x45434002, 0x1d1e1f02, 0x0f000c09, 0x1e024002,   // sl.vi.sk_222 ga.sr.hr_222 pl.es..._440 sl.da.sr_222
  0x0c124511, 0x1a014508, 0x4b004302, 0x1a002b09,   // sk.cs.pl_653 sk.en.xxx_443 vi.az..._220 cy.xxx..._440
  0x2b1018a4, 0x21192707, 0x1d161512, 0x0f001014,   // hu.sv.cy_433 id.et.tl_432 lv.lt.hr_654 sv.es..._660
  0x40000312, 0x19292ba4, 0x43001409, 0x04001a08,   // nl.sl..._640 cy.ms.et_433 is.vi..._440 xxx.fi..._430
  // [3210]
  0x14272960, 0x42000607, 0x45001f22, 0x040322a4,   // ms.id.is_664 de.mt..._420 ga.sk..._870 tr.nl.fi_433
  0x190d0f08, 0x1d031e09, 0x040d0fa4, 0x063a1a02,   // es.pt.et_443 sr.nl.hr_444 es.pt.fi_433 xxx.eu.de_222
  0x15002213, 0x21001702, 0x27404202, 0x42291808,   // tr.lv..._650 ro.tl..._220 mt.sl.id_222 hu.ms.mt_443
  0x40001523, 0x12451f11, 0x401942a4, 0x66000802,   // lv.sl..._880 ga.sk.cs_653 mt.et.sl_433 it.af..._220
  // [3220]
  0x03106609, 0x0c001522, 0x29001611, 0x45002209,   // af.sv.nl_444 lv.pl..._870 lt.ms..._630 tr.sk..._440
  0x660302af, 0x10060355, 0x0f274b12, 0x3f001621,   // da.nl.af_655 nl.de.sv_442 az.id.es_654 lt.sw..._860
  0x1d270402, 0x19002707, 0x3f8c1707, 0x45421502,   // fi.id.hr_222 id.et..._420 ro.ht.sw_432 lv.mt.sk_222
  0x05001a08, 0x0b008c02, 0x08002907, 0x04008c23,   // xxx.fr..._430 ht.no..._220 ms.it..._420 ht.fi..._880
  // [3230]
  0x100206a4, 0x40001707, 0x2e001923, 0x1d2e0b08,   // de.da.sv_433 ro.sl..._420 et.sq..._880 no.sq.hr_443
  0x0b041909, 0x38001014, 0x05041f12, 0x15001002,   // et.fi.no_444 sv.ca..._660 ga.fi.fr_654 sv.lv..._220
  0x45000f07, 0x3a0f0107, 0x3f000408, 0x15003a07,   // es.sk..._420 en.es.eu_432 fi.sw..._430 eu.lv..._420
  0x19381a09, 0x8c000322, 0x4b662209, 0x20380107,   // xxx.ca.et_444 nl.ht..._870 tr.af.az_444 en.ca.gl_432
  // [3240]
  0x43001714, 0x1e004223, 0x2b008c09, 0x29270d02,   // ro.vi..._660 mt.sr..._880 ht.cy..._440 pt.id.ms_222
  0x0d001f21, 0x43001702, 0x17000612, 0x380f05a4,   // ga.pt..._860 ro.vi..._220 de.ro..._640 fr.es.ca_433
  0x14003823, 0x1d8c0308, 0x020666a4, 0x21014208,   // ca.is..._880 nl.ht.hr_443 af.de.da_433 mt.en.tl_443
  0x04020b60, 0x12002108, 0x0c002b07, 0x2b383a60,   // no.da.fi_664 tl.cs..._430 cy.pl..._420 eu.ca.cy_664
  // [3250]
  0x12001409, 0x1c300e12, 0x0c001f12, 0x021921a4,   // is.cs..._440 ru.be.bg_654 ga.pl..._640 tl.et.da_433
  0x21001e02, 0x291d1802, 0x15041960, 0x38000b08,   // sr.tl..._220 hu.hr.ms_222 et.fi.lv_664 no.ca..._430
  0x38451255, 0x01296609, 0x0b006613, 0x12000f07,   // cs.sk.ca_442 af.ms.en_444 af.no..._650 es.cs..._420
  0x1d401502, 0x1a002023, 0x19001f08, 0x1e1d2e08,   // lv.sl.hr_222 gl.xxx..._880 ga.et..._430 sq.hr.sr_443
  // [3260]
  0x27006612, 0x14002221, 0x2e003813, 0x3a2e4509,   // af.id..._640 tr.is..._860 ca.sq..._650 sk.sq.eu_444
  0x8c053808, 0x22002e12, 0x15381760, 0x12004b02,   // ca.fr.ht_443 sq.tr..._640 ro.ca.lv_664 az.cs..._220
  0x17272909, 0x05000d11, 0x3f002713, 0x224b1a09,   // ms.id.ro_444 pt.fr..._630 id.sw..._650 xxx.az.tr_444
  0x17660312, 0x0e1c3012, 0x291018a4, 0x03000c14,   // nl.af.ro_654 be.bg.ru_654 hu.sv.ms_433 pl.nl..._660
  // [3270]
  0x14450f55, 0x66004b02, 0x19000808, 0x040b0208,   // es.sk.is_442 az.af..._220 it.et..._430 da.no.fi_443
  0x1d050107, 0x02004214, 0x1f004314, 0x27000b14,   // en.fr.hr_432 mt.da..._660 vi.ga..._660 no.id..._660
  0x15001814, 0x3f001508, 0x06056608, 0x18000408,   // hu.lv..._660 lv.sw..._430 af.fr.de_443 fi.hu..._430
  0x2b000621, 0x1e018ca4, 0x42003f09, 0x03002b09,   // de.cy..._860 ht.en.sr_433 sw.mt..._440 cy.nl..._440
  // [3280]
  0x2b008c13, 0x23300e11, 0x1e233008, 0x12001413,   // ht.cy..._650 ru.be.uk_653 be.uk.sr_443 is.cs..._650
  0x66001f09, 0x17006609, 0x0d003812, 0x1d000408,   // ga.af..._440 af.ro..._440 ca.pt..._640 fi.hr..._430
  0x161e1d08, 0x02222102, 0x04001413, 0x301c0e13,   // hr.sr.lt_443 tl.tr.da_222 is.fi..._650 ru.bg.be_665
  0x4b000508, 0x0d180fa4, 0x151a1712, 0x18001d09,   // fr.az..._430 es.hu.pt_433 ro.xxx.lv_654 hr.hu..._440
  // [3290]
  0x0d172e55, 0x02210b07, 0x2e170da4, 0x05171fa4,   // sq.ro.pt_442 no.tl.da_432 pt.ro.sq_433 ga.ro.fr_433
  0x451205a4, 0x0d1f0f07, 0x45000513, 0x011f1755,   // fr.cs.sk_433 es.ga.pt_432 fr.sk..._650 ro.ga.en_442
  0x4b003f22, 0x27004308, 0x1f006608, 0x29000821,   // sw.az..._870 vi.id..._430 af.ga..._430 it.ms..._860
  0x29152709, 0x01178c02, 0x03011a09, 0x430f0107,   // id.lv.ms_444 ht.ro.en_222 xxx.en.nl_444 en.es.vi_432
  // [32a0]
  0x20008c02, 0x8c2e3f12, 0x1d1e2902, 0x1a183f08,   // ht.gl..._220 sw.sq.ht_654 ms.sr.hr_222 sw.hu.xxx_443
  0x22041a08, 0x18002b08, 0x301c0e09, 0x1d101f02,   // xxx.fi.tr_443 cy.hu..._430 ru.bg.be_444 ga.sv.hr_222
  0x40002e07, 0x29170802, 0x1f001713, 0x10140109,   // sq.sl..._420 it.ro.ms_222 ro.ga..._650 en.is.sv_444
  0x0c008c13, 0x45001220, 0x12144560, 0x190c16a4,   // ht.pl..._650 cs.sk..._850 sk.is.cs_664 lt.pl.et_433
  // [32b0]
  0x1d1a2102, 0x14451808, 0x451d2702, 0x16006614,   // tl.xxx.hr_222 hu.sk.is_443 id.hr.sk_222 af.lt..._660
  0x27004b02, 0x1c0e2507, 0x45001f13, 0x1f008c22,   // az.id..._220 mk.ru.bg_432 ga.sk..._650 ht.ga..._870
  0x1f0c2707, 0x0d123860, 0x3f2b4208, 0x293a1802,   // id.pl.ga_432 ca.cs.pt_664 mt.cy.sw_443 hu.eu.ms_222
  0x0e231e55, 0x1e2b1d02, 0x200f0d14, 0x3f222908,   // sr.uk.ru_442 hr.cy.sr_222 pt.es.gl_666 ms.tr.sw_443
  // [32c0]
  0x221810a4, 0x45000508, 0x22141012, 0x380d1709,   // sv.hu.tr_433 fr.sk..._430 sv.is.tr_654 ro.pt.ca_444
  0x200d0f13, 0x05001622, 0x66011fa4, 0x19450107,   // es.pt.gl_665 lt.fr..._870 ga.en.af_433 en.sk.et_432
  0x3f006612, 0x2e001821, 0x27293fa4, 0x061a3f12,   // af.sw..._640 hu.sq..._860 sw.ms.id_433 sw.xxx.de_654
  0x294b2260, 0x15002214, 0x0f0c0109, 0x663f1aa4,   // tr.az.ms_664 tr.lv..._660 en.pl.es_444 xxx.sw.af_433
  // [32d0]
  0x43001f14, 0x1a450107, 0x290214a4, 0x0b1f2ba4,   // ga.vi..._660 en.sk.xxx_432 is.da.ms_433 cy.ga.no_433
  0x12004208, 0x10001a12, 0x27190402, 0x16001f14,   // mt.cs..._430 xxx.sv..._640 fi.et.id_222 ga.lt..._660
  0x19180813, 0x17272913, 0x0b008c09, 0x1c1e0ea4,   // it.hu.et_665 ms.id.ro_665 ht.no..._440 ru.sr.bg_433
  0x16270308, 0x042e1908, 0x40000d02, 0x08001e09,   // nl.id.lt_443 et.sq.fi_443 pt.sl..._220 sr.it..._440
  // [32e0]
  0x12001d14, 0x18001514, 0x0f0d05a4, 0x18050da4,   // hr.cs..._660 lv.hu..._660 fr.pt.es_433 pt.fr.hu_433
  0x18001d02, 0x291803a4, 0x2b001213, 0x8c2b3fad,   // hr.hu..._220 nl.hu.ms_433 cs.cy..._650 sw.cy.ht_643
  0x21006609, 0x4b218c09, 0x19000113, 0x42002107,   // af.tl..._440 ht.tl.az_444 en.et..._650 tl.mt..._420
  0x38036614, 0x1e402709, 0x18004322, 0x3a1a0460,   // af.nl.ca_666 id.sl.sr_444 vi.hu..._870 fi.xxx.eu_664
  // [32f0]
  0x14184308, 0x0b021412, 0x14124312, 0x0f0d2014,   // vi.hu.is_443 is.da.no_654 vi.cs.is_654 gl.pt.es_666
  0x22004023, 0x18004307, 0x8c000423, 0x27000513,   // sl.tr..._880 vi.hu..._420 fi.ht..._880 fr.id..._650
  0x156617a4, 0x02004208, 0x02001a13, 0x17406611,   // ro.af.lv_433 mt.da..._430 xxx.da..._650 af.sl.ro_653
  0x42002e02, 0x3f000308, 0x058c1207, 0x128c0507,   // sq.mt..._220 nl.sw..._430 cs.ht.fr_432 fr.ht.cs_432
  // [3300]
  0x05221a08, 0x06101908, 0x45181208, 0x0c174509,   // xxx.tr.fr_443 et.sv.de_443 cs.hu.sk_443 sk.ro.pl_444
  0x04221508, 0x1f0c42a4, 0x04152260, 0x1e000d09,   // lv.tr.fi_443 mt.pl.ga_433 tr.lv.fi_664 pt.sr..._440
  0x402e1207, 0x021d1008, 0x020614a4, 0x16142b13,   // cs.sq.sl_432 sv.hr.da_443 is.de.da_433 cy.is.lt_665
  0x0c002209, 0x16080109, 0x03004313, 0x20000c23,   // tr.pl..._440 en.it.lt_444 vi.nl..._650 pl.gl..._880
  // [3310]
  0x1d002707, 0x3f002023, 0x380f1912, 0x45104202,   // id.hr..._420 gl.sw..._880 et.es.ca_654 mt.sv.sk_222
  0x3f4518ad, 0x45381fa4, 0x1e000414, 0x4b042e12,   // hu.sk.sw_643 ga.ca.sk_433 fi.sr..._660 sq.fi.az_654
  0x040f2707, 0x0c000d12, 0x2e001502, 0x1f450d1f,   // id.es.fi_432 pt.pl..._640 lv.sq..._220 pt.sk.ga_864
  0x01003f08, 0x19014208, 0x17224b09, 0x10061809,   // sw.en..._430 mt.en.et_443 az.tr.ro_444 hu.de.sv_444
  // [3320]
  0x38001a02, 0x1d004011, 0x3a001f02, 0x153f1a09,   // xxx.ca..._220 sl.hr..._630 ga.eu..._220 xxx.sw.lv_444
  0x19001708, 0x1d1e1512, 0x05003811, 0x04002e23,   // ro.et..._430 lv.sr.hr_654 ca.fr..._630 sq.fi..._880
  0x1f3f42a4, 0x22081708, 0x20001702, 0x161d1e07,   // mt.sw.ga_433 ro.it.tr_443 ro.gl..._220 sr.hr.lt_432
  0x2b660255, 0x18053814, 0x1a000212, 0x10004b11,   // da.af.cy_442 ca.fr.hu_666 da.xxx..._640 az.sv..._630
  // [3330]
  0x19660314, 0x120f1408, 0x01001912, 0x251c2360,   // nl.af.et_666 is.es.cs_443 et.en..._640 uk.bg.mk_664
  0x22000123, 0x21002223, 0x42034507, 0x14002b22,   // en.tr..._880 tr.tl..._880 sk.nl.mt_432 cy.is..._870
  0x1d191e02, 0x2b000123, 0x04002923, 0x14000113,   // sr.et.hr_222 en.cy..._880 ms.fi..._880 en.is..._650
  0x66060313, 0x230e1c11, 0x2e001909, 0x271d4202,   // nl.de.af_665 bg.ru.uk_653 et.sq..._440 mt.hr.id_222
  // [3340]
  0x27002e02, 0x1e003802, 0x450f0d08, 0x200f4509,   // sq.id..._220 ca.sr..._220 pt.es.sk_443 sk.es.gl_444
  0x10003a13, 0x02103a07, 0x8c000807, 0x0d452709,   // eu.sv..._650 eu.sv.da_432 it.ht..._420 id.sk.pt_444
  0x200f38af, 0x454b3f02, 0x400f1209, 0x0f0d1013,   // ca.es.gl_655 sw.az.sk_222 cs.es.sl_444 sv.pt.es_665
  0x0d0f0807, 0x16124514, 0x451d1e55, 0x3f000823,   // it.es.pt_432 sk.cs.lt_666 sr.hr.sk_442 it.sw..._880
  // [3350]
  0x21004213, 0x194b4509, 0x8c224b08, 0x210c2909,   // mt.tl..._650 sk.az.et_444 az.tr.ht_443 ms.pl.tl_444
  0x0e1c1e12, 0x19001007, 0x04000214, 0x38451213,   // sr.bg.ru_654 sv.et..._420 da.fi..._660 cs.sk.ca_665
  0x15041913, 0x8c004307, 0x2e272912, 0x38420860,   // et.fi.lv_665 vi.ht..._420 ms.id.sq_654 it.mt.ca_664
  0x06100302, 0x2e180309, 0x29012b02, 0x05008c07,   // nl.sv.de_222 nl.hu.sq_444 cy.en.ms_222 ht.fr..._420
  // [3360]
  0x140f0d08, 0x3a161709, 0x01211a07, 0x181f4512,   // pt.es.is_443 ro.lt.eu_444 xxx.tl.en_432 sk.ga.hu_654
  0x43012e08, 0x12384508, 0x19272913, 0x29200107,   // sq.en.vi_443 sk.ca.cs_443 ms.id.et_665 en.gl.ms_432
  0x1f4b2209, 0x278c1e02, 0x3a3f2909, 0x2e051809,   // tr.az.ga_444 sr.ht.id_222 ms.sw.eu_444 hu.fr.sq_444
  0x05122e07, 0x22003813, 0x0b001514, 0x43002707,   // sq.cs.fr_432 ca.tr..._650 lv.no..._660 id.vi..._420
  // [3370]
  0x0e1c25a4, 0x0b002713, 0x18054509, 0x27290402,   // mk.bg.ru_433 id.no..._650 sk.fr.hu_444 fi.ms.id_222
  0x27060109, 0x05121812, 0x3a060213, 0x18141f13,   // en.de.id_444 hu.cs.fr_654 da.de.eu_665 ga.is.hu_665
  0x1e002102, 0x3f221a07, 0x42000409, 0x10001e09,   // tl.sr..._220 xxx.tr.sw_432 fi.mt..._440 sr.sv..._440
  0x181f38af, 0x27084202, 0x00002001, 0x27000814,   // ca.ga.hu_655 mt.it.id_222 gl......_200 it.id..._660
  // [3380]
  0x0b003a09, 0x01438c02, 0x3a1066a4, 0x18120613,   // eu.no..._440 ht.vi.en_222 af.sv.eu_433 de.cs.hu_665
  0x4b003a07, 0x8c101409, 0x3a060107, 0x38000613,   // eu.az..._420 is.sv.ht_444 en.de.eu_432 de.ca..._650
  0x4b002023, 0x12030b07, 0x04213aa4, 0x0d380f07,   // gl.az..._880 no.nl.cs_432 eu.tl.fi_433 es.ca.pt_432
  0x45008c08, 0x12194009, 0x38124509, 0x080b1955,   // ht.sk..._430 sl.et.cs_444 sk.cs.ca_444 et.no.it_442
  // [3390]
  0x21001514, 0x05000821, 0x0d380f12, 0x19021f12,   // lv.tl..._660 it.fr..._860 es.ca.pt_654 ga.da.et_654
  0x06190413, 0x22184baf, 0x03000408, 0x1e0e2312,   // fi.et.de_665 az.hu.tr_655 fi.nl..._430 uk.ru.sr_654
  0x03001623, 0x66031914, 0x27054309, 0x06224b60,   // lt.nl..._880 et.nl.af_666 vi.fr.id_444 az.tr.de_664
  0x0f001209, 0x12000509, 0x043f2e08, 0x29164002,   // cs.es..._440 fr.cs..._440 sq.sw.fi_443 sl.lt.ms_222
  // [33a0]
  0x14001714, 0x02002b21, 0x663a0107, 0x2b011008,   // ro.is..._660 cy.da..._860 en.eu.af_432 sv.en.cy_443
  0x020b01a4, 0x2b004014, 0x200d0109, 0x43221a08,   // en.no.da_433 sl.cy..._660 en.pt.gl_444 xxx.tr.vi_443
  0x2b8c6607, 0x17000623, 0x164029a4, 0x3a291812,   // af.ht.cy_432 de.ro..._880 ms.sl.lt_433 hu.ms.eu_654
  0x19180107, 0x66000311, 0x1e1d43af, 0x0d003810,   // en.hu.et_432 nl.af..._630 vi.hr.sr_655 ca.pt..._620
  // [33b0]
  0x03000d09, 0x10386609, 0x27003809, 0x1a660360,   // pt.nl..._440 af.ca.sv_444 ca.id..._440 nl.af.xxx_664
  0x45291002, 0x0d3820ab, 0x0f1f0da4, 0x19142255,   // sv.ms.sk_222 gl.ca.pt_621 pt.ga.es_433 tr.is.et_442
  0x15220109, 0x66003f08, 0x3f2b0d08, 0x8c162709,   // en.tr.lv_444 sw.af..._430 pt.cy.sw_443 id.lt.ht_444
  0x4b003a12, 0x42082009, 0x04003f14, 0x1e001914,   // eu.az..._640 gl.it.mt_444 sw.fi..._660 et.sr..._660
  // [33c0]
  0x0f190107, 0x45171a02, 0x1c233014, 0x45002913,   // en.et.es_432 xxx.ro.sk_222 be.uk.bg_666 ms.sk..._650
  0x1d184002, 0x40002e23, 0x40002e09, 0x291d3f02,   // sl.hu.hr_222 sq.sl..._880 sq.sl..._440 sw.hr.ms_222
  0x17001002, 0x19040612, 0x0c160207, 0x17050302,   // sv.ro..._220 de.fi.et_654 da.lt.pl_432 nl.fr.ro_222
  0x14182e07, 0x10001609, 0x42000422, 0x19180414,   // sq.hu.is_432 lt.sv..._440 fi.mt..._870 fi.hu.et_666
  // [33d0]
  0x04420813, 0x2e001913, 0x4b224008, 0x19044212,   // it.mt.fi_665 et.sq..._650 sl.tr.az_443 mt.fi.et_654
  0x01380f08, 0x03100207, 0x1e1d0814, 0x22190109,   // es.ca.en_443 da.sv.nl_432 it.hr.sr_666 en.et.tr_444
  0x3a0366af, 0x1d1e0814, 0x1d1e43a4, 0x0d001213,   // af.nl.eu_655 it.sr.hr_666 vi.sr.hr_433 cs.pt..._650
  0x1d151ea4, 0x15000613, 0x8c194baf, 0x05001813,   // sr.lv.hr_433 de.lv..._650 az.et.ht_655 hu.fr..._650
  // [33e0]
  0x38190c55, 0x1d000c23, 0x8c051460, 0x40000123,   // pl.et.ca_442 pl.hr..._880 is.fr.ht_664 en.sl..._880
  0x18002714, 0x1e1d45af, 0x18060da4, 0x060b10a4,   // id.hu..._660 sk.hr.sr_655 pt.de.hu_433 sv.no.de_433
  0x45060802, 0x08002112, 0x17003a12, 0x22000f14,   // it.de.sk_222 tl.it..._640 eu.ro..._640 es.tr..._660
  0x18000d07, 0x43660360, 0x0d063a13, 0x30002308,   // pt.hu..._420 nl.af.vi_664 eu.de.pt_665 uk.be..._430
  // [33f0]
  0x101827a4, 0x011842af, 0x0e1c3009, 0x1d0f1702,   // id.hu.sv_433 mt.hu.en_655 be.bg.ru_444 ro.es.hr_222
  0x43210808, 0x04002e21, 0x4b221955, 0x011766a4,   // it.tl.vi_443 sq.fi..._860 et.tr.az_442 af.ro.en_433
  0x66151207, 0x16001723, 0x1e003a14, 0x1d084202,   // cs.lv.af_432 ro.lt..._880 eu.sr..._660 mt.it.hr_222
  0x043a1714, 0x05001523, 0x40161509, 0x29000c13,   // ro.eu.fi_666 lv.fr..._880 lv.lt.sl_444 pl.ms..._650

  // [3400]
  0x21228c60, 0x0f0d1fb2, 0x14004521, 0x43003813,   // ht.tr.tl_664 ga.pt.es_732 sk.is..._860 ca.vi..._650
  0x103a42a4, 0x40001009, 0x21000308, 0x08002213,   // mt.eu.sv_433 sv.sl..._440 nl.tl..._430 tr.it..._650
  0x033805a4, 0x06020b07, 0x18451f12, 0x16172112,   // fr.ca.nl_433 no.da.de_432 ga.sk.hu_654 tl.ro.lt_654
  0x66001202, 0x2b001008, 0x0f1f3814, 0x120b1a02,   // cs.af..._220 sv.cy..._430 ca.ga.es_666 xxx.no.cs_222
  // [3410]
  0x45401002, 0x22214ba4, 0x451666af, 0x66212707,   // sv.sl.sk_222 az.tl.tr_433 af.lt.sk_655 id.tl.af_432
  0x3f041913, 0x19043f60, 0x42002b12, 0x40450c08,   // et.fi.sw_665 sw.fi.et_664 cy.mt..._640 pl.sk.sl_443
  0x27004014, 0x3f002b12, 0x10123fa4, 0x00005c15,   // sl.id..._660 cy.sw..._640 sw.cs.sv_433 yi......_700
  0x02102b08, 0x273f2914, 0x1c0e3060, 0x400f1608,   // cy.sv.da_443 ms.sw.id_666 be.ru.bg_664 lt.es.sl_443
  // [3420]
  0x2b006611, 0x273a2960, 0x8c002e1d, 0x66031012,   // af.cy..._630 ms.eu.id_664 sq.ht..._820 sv.nl.af_654
  0x0d210faf, 0x08001622, 0x04004223, 0x291f2102,   // es.tl.pt_655 lt.it..._870 mt.fi..._880 tl.ga.ms_222
  0x210c3f08, 0x0c036608, 0x0e232560, 0x02001011,   // sw.pl.tl_443 af.nl.pl_443 mk.uk.ru_664 sv.da..._630
  0x40004b02, 0x25002320, 0x21064507, 0x8c220b09,   // az.sl..._220 uk.mk..._850 sk.de.tl_432 no.tr.ht_444
  // [3430]
  0x1e302360, 0x06030107, 0x21001508, 0x661903a4,   // uk.be.sr_664 en.nl.de_432 lv.tl..._430 nl.et.af_433
  0x192e2113, 0x454b1502, 0x14060255, 0x04661908,   // tl.sq.et_665 lv.az.sk_222 da.de.is_442 et.af.fi_443
  0x01000b08, 0x3f002222, 0x19041714, 0x224b27a4,   // no.en..._430 tr.sw..._870 ro.fi.et_666 id.az.tr_433
  0x1c0e1e13, 0x06000d14, 0x22000209, 0x3a002902,   // sr.ru.bg_665 pt.de..._660 da.tr..._440 ms.eu..._220
  // [3440]
  0x3f4b22a4, 0x30251c12, 0x0d080107, 0x4b001514,   // tr.az.sw_433 bg.mk.be_654 en.it.pt_432 lv.az..._660
  0x08004b14, 0x17000812, 0x45122202, 0x12036602,   // az.it..._660 it.ro..._640 tr.cs.sk_222 af.nl.cs_222
  0x061a42a4, 0x3a000807, 0x02001411, 0x10458c08,   // mt.xxx.de_433 it.eu..._420 is.da..._630 ht.sk.sv_443
  0x14001912, 0x12004302, 0x0f011702, 0x3f004507,   // et.is..._640 vi.cs..._220 ro.en.es_222 sk.sw..._420
  // [3450]
  0x15000312, 0x14000d12, 0x45011802, 0x3a002123,   // nl.lv..._640 pt.is..._640 hu.en.sk_222 tl.eu..._880
  0x2e4b4255, 0x1e302307, 0x2e000808, 0x08174508,   // mt.az.sq_442 uk.be.sr_432 it.sq..._430 sk.ro.it_443
  0x8c212708, 0x15431a02, 0x42003a13, 0x27213f07,   // id.tl.ht_443 xxx.vi.lv_222 eu.mt..._650 sw.tl.id_432
  0x1d081e02, 0x1d2e4002, 0x301c2512, 0x38180513,   // sr.it.hr_222 sl.sq.hr_222 mk.bg.be_654 fr.hu.ca_665
  // [3460]
  0x45150b09, 0x0c064214, 0x19000f09, 0x03451512,   // no.lv.sk_444 mt.de.pl_666 es.et..._440 lv.sk.nl_654
  0x02001502, 0x45001707, 0x05002702, 0x01004b08,   // lv.da..._220 ro.sk..._420 id.fr..._220 az.en..._430
  0x06420812, 0x16001a13, 0x27294008, 0x3a1a3fa4,   // it.mt.de_654 xxx.lt..._650 sl.ms.id_443 sw.xxx.eu_433
  0x02061014, 0x1e002202, 0x042e17a4, 0x17021f08,   // sv.de.da_666 tr.sr..._220 ro.sq.fi_433 ga.da.ro_443
  // [3470]
  0x1e001609, 0x1f003a23, 0x1f3a0109, 0x17001f09,   // lt.sr..._440 eu.ga..._880 en.eu.ga_444 ga.ro..._440
  0x8c010302, 0x251e0e60, 0x19044009, 0x1e451d08,   // nl.en.ht_222 ru.sr.mk_664 sl.fi.et_444 hr.sk.sr_443
  0x08162b07, 0x45192102, 0x0f162b07, 0x163f0408,   // cy.lt.it_432 tl.et.sk_222 cy.lt.es_432 fi.sw.lt_443
  0x4b2e3fa4, 0x10004507, 0x0e301caf, 0x02191608,   // sw.sq.az_433 sk.sv..._420 bg.be.ru_655 lt.et.da_443
  // [3480]
  0x400c42a4, 0x66020b09, 0x03140212, 0x04293f09,   // mt.pl.sl_433 no.da.af_444 da.is.nl_654 sw.ms.fi_444
  0x27224b55, 0x1e036608, 0x15001907, 0x38003f02,   // az.tr.id_442 af.nl.sr_443 et.lv..._420 sw.ca..._220
  0x2e1f3f07, 0x3f000102, 0x171d40a4, 0x40002113,   // sw.ga.sq_432 en.sw..._220 sl.hr.ro_433 tl.sl..._650
  0x1d420802, 0x45402702, 0x2b000322, 0x12012702,   // it.mt.hr_222 id.sl.sk_222 nl.cy..._870 id.en.cs_222
  // [3490]
  0x1a002b22, 0x0f003f08, 0x0c081760, 0x100b1814,   // cy.xxx..._870 sw.es..._430 ro.it.pl_664 hu.no.sv_666
  0x180b1060, 0x2e002109, 0x18102eaf, 0x66001612,   // sv.no.hu_664 tl.sq..._440 sq.sv.hu_655 lt.af..._640
  0x180b1012, 0x18102e08, 0x23003020, 0x22272907,   // sv.no.hu_654 sq.sv.hu_443 be.uk..._850 ms.id.tr_432
  0x0c001402, 0x22000409, 0x02213f08, 0x2b451208,   // is.pl..._220 fi.tr..._440 sw.tl.da_443 cs.sk.cy_443
  // [34a0]
  0x12001802, 0x06000d13, 0x3a002e23, 0x170f0107,   // hu.cs..._220 pt.de..._650 sq.eu..._880 en.es.ro_432
  0x0c004b14, 0x0f380d02, 0x0f4b2209, 0x3f272960,   // az.pl..._660 pt.ca.es_222 tr.az.es_444 ms.id.sw_664
  0x02661414, 0x1c002511, 0x30251e12, 0x29270602,   // is.af.da_666 mk.bg..._630 sr.mk.be_654 de.id.ms_222
  0x4b220611, 0x12404510, 0x18001608, 0x27182907,   // de.tr.az_653 sk.sl.cs_642 lt.hu..._430 ms.hu.id_432
  // [34b0]
  0x228c2112, 0x21228c14, 0x29000621, 0x251c0e09,   // tl.ht.tr_654 ht.tr.tl_666 de.ms..._860 ru.bg.mk_444
  0x21001912, 0x22020109, 0x05100b08, 0x02060b09,   // et.tl..._640 en.da.tr_444 no.sv.fr_443 no.de.da_444
  0x2b001022, 0x294b2212, 0x058c4b60, 0x450c0107,   // sv.cy..._870 tr.az.ms_654 az.ht.fr_664 en.pl.sk_432
  0x0d004023, 0x451d2102, 0x03100209, 0x2b0c1208,   // sl.pt..._880 tl.hr.sk_222 da.sv.nl_444 cs.pl.cy_443
  // [34c0]
  0x15030107, 0x012b8ca4, 0x66032108, 0x2b000c21,   // en.nl.lv_432 ht.cy.en_433 tl.nl.af_443 pl.cy..._860
  0x3f228c55, 0x05660313, 0x0c3f0107, 0x8c036655,   // ht.tr.sw_442 nl.af.fr_665 en.sw.pl_432 af.nl.ht_442
  0x45061402, 0x402e03a4, 0x40002213, 0x08000508,   // is.de.sk_222 nl.sq.sl_433 tr.sl..._650 fr.it..._430
  0x431f2b08, 0x0d0f1712, 0x1a213f08, 0x17080113,   // cy.ga.vi_443 ro.es.pt_654 sw.tl.xxx_443 en.it.ro_665
  // [34d0]
  0x0c451255, 0x08000522, 0x2b050809, 0x3a3f2155,   // cs.sk.pl_442 fr.it..._870 it.fr.cy_444 tl.sw.eu_442
  0x0b001f14, 0x0b171f08, 0x1d003f09, 0x1e001002,   // ga.no..._660 ga.ro.no_443 sw.hr..._440 sv.sr..._220
  0x14042108, 0x1a3a1912, 0x3a0f38af, 0x0e1e2555,   // tl.fi.is_443 et.eu.xxx_654 ca.es.eu_655 mk.sr.ru_442
  0x08002e13, 0x4b221812, 0x06221812, 0x1d0b2e02,   // sq.it..._650 hu.tr.az_654 hu.tr.de_654 sq.no.hr_222
  // [34e0]
  0x4b2218af, 0x1e230ea4, 0x29001d13, 0x8c4b2909,   // hu.tr.az_655 ru.uk.sr_433 hr.ms..._650 ms.az.ht_444
  0x22001812, 0x15002908, 0x1e0e1c11, 0x0b001809,   // hu.tr..._640 ms.lv..._430 bg.ru.sr_653 hu.no..._440
  0x12044507, 0x29004008, 0x17004023, 0x3a002b08,   // sk.fi.cs_432 sl.ms..._430 sl.ro..._880 cy.eu..._430
  0x30001c22, 0x121d4007, 0x40002914, 0x45064213,   // bg.be..._870 sl.hr.cs_432 ms.sl..._660 mt.de.sk_665
  // [34f0]
  0x02001202, 0x10180b08, 0x3f182b12, 0x38004308,   // cs.da..._220 no.hu.sv_443 cy.hu.sw_654 vi.ca..._430
  0x66010307, 0x0c451202, 0x273a2ba4, 0x02000622,   // nl.en.af_432 cs.sk.pl_222 cy.eu.id_433 de.da..._870
  0x0c451e09, 0x401e1d10, 0x660b1008, 0x27293aa4,   // sr.sk.pl_444 hr.sr.sl_642 sv.no.af_443 eu.ms.id_433
  0x221516a4, 0x2e292708, 0x011a1009, 0x1e233012,   // lt.lv.tr_433 id.ms.sq_443 sv.xxx.en_444 be.uk.sr_654
  // [3500]
  0x4b000609, 0x8c451207, 0x273a0408, 0x3a120d09,   // de.az..._440 cs.sk.ht_432 fi.eu.id_443 pt.cs.eu_444
  0x21272908, 0x04190609, 0x161d4014, 0x27001913,   // ms.id.tl_443 de.et.fi_444 sl.hr.lt_666 et.id..._650
  0x45004313, 0x1f1a4209, 0x121d4504, 0x1d0c2e55,   // vi.sk..._650 mt.xxx.ga_444 sk.hr.cs_332 sq.pl.hr_442
  0x0f451412, 0x1e001623, 0x21162909, 0x23251e09,   // is.sk.es_654 lt.sr..._880 ms.lt.tl_444 sr.mk.uk_444
  // [3510]
  0x450c1213, 0x15191609, 0x29008c22, 0x14014502,   // cs.pl.sk_665 lt.et.lv_444 ht.ms..._870 sk.en.is_222
  0x12451402, 0x27032907, 0x1a004523, 0x29008c23,   // is.sk.cs_222 ms.nl.id_432 sk.xxx..._880 ht.ms..._880
  0x1d1a0109, 0x1f003f22, 0x144b0107, 0x171f0b09,   // en.xxx.hr_444 sw.ga..._870 en.az.is_432 no.ga.ro_444
  0x06140ba4, 0x1e000307, 0x66030608, 0x0b006623,   // no.is.de_433 nl.sr..._420 de.nl.af_443 af.no..._880
  // [3520]
  0x1e300e13, 0x06002708, 0x3f171aa4, 0x02004302,   // ru.be.sr_665 id.de..._430 xxx.ro.sw_433 vi.da..._220
  0x0f1a1855, 0x66001708, 0x10000c13, 0x4b002e07,   // hu.xxx.es_442 ro.af..._430 pl.sv..._650 sq.az..._420
  0x161915a4, 0x22020b08, 0x2e1d6608, 0x0e1e3012,   // lv.et.lt_433 no.da.tr_443 af.hr.sq_443 be.sr.ru_654
  0x1a001608, 0x222e0b07, 0x420c0b07, 0x043f21a4,   // lt.xxx..._430 no.sq.tr_432 no.pl.mt_432 tl.sw.fi_433
  // [3530]
  0x0b002e08, 0x8c004b12, 0x16001013, 0x213a3f13,   // sq.no..._430 az.ht..._640 sv.lt..._650 sw.eu.tl_665
  0x1e401d11, 0x22272911, 0x16124512, 0x04001607,   // hr.sl.sr_653 ms.id.tr_653 sk.cs.lt_654 lt.fi..._420
  0x1e000e22, 0x06000212, 0x0b221812, 0x27000d07,   // ru.sr..._870 da.de..._640 hu.tr.no_654 pt.id..._420
  0x4b001614, 0x19163fa4, 0x1f292714, 0x12008c23,   // lt.az..._660 sw.lt.et_433 id.ms.ga_666 ht.cs..._880
  // [3540]
  0x16004b02, 0x45022e02, 0x02030b08, 0x27000d13,   // az.lt..._220 sq.da.sk_222 no.nl.da_443 pt.id..._650
  0x20000423, 0x16011a09, 0x1a002707, 0x03662b13,   // fi.gl..._880 xxx.en.lt_444 id.xxx..._420 cy.af.nl_665
  0x18660360, 0x27292114, 0x212b14a4, 0x38290f14,   // nl.af.hu_664 tl.ms.id_666 is.cy.tl_433 es.ms.ca_666
  0x0d210f09, 0x29000d02, 0x14001613, 0x16210107,   // es.tl.pt_444 pt.ms..._220 lt.is..._650 en.tl.lt_432
  // [3550]
  0x0c000d22, 0x3f004314, 0x221838a4, 0x38002709,   // pt.pl..._870 vi.sw..._660 ca.hu.tr_433 id.ca..._440
  0x18001923, 0x04198c08, 0x8c212212, 0x1d003808,   // et.hu..._880 ht.et.fi_443 tr.tl.ht_654 ca.hr..._430
  0x10002b07, 0x66061508, 0x42042108, 0x080f3f13,   // cy.sv..._420 lv.de.af_443 tl.fi.mt_443 sw.es.it_665
  0x4b272909, 0x4b000208, 0x17002713, 0x3a040509,   // ms.id.az_444 da.az..._430 id.ro..._650 fr.fi.eu_444
  // [3560]
  0x3a0d2b09, 0x0c001721, 0x3a000508, 0x04052007,   // cy.pt.eu_444 ro.pl..._860 fr.eu..._430 gl.fr.fi_432
  0x43040d12, 0x19102208, 0x0c001222, 0x3f002107,   // pt.fi.vi_654 tr.sv.et_443 cs.pl..._870 tl.sw..._420
  0x251c1e55, 0x0d1a4508, 0x18000512, 0x16001922,   // sr.bg.mk_442 sk.xxx.pt_443 fr.hu..._640 et.lt..._870
  0x1f0f2b09, 0x20003f23, 0x0f050d09, 0x1a3a3f12,   // cy.es.ga_444 sw.gl..._880 pt.fr.es_444 sw.eu.xxx_654
  // [3570]
  0x1d224202, 0x1e251c55, 0x05122ea4, 0x081d1e09,   // mt.tr.hr_222 bg.mk.sr_442 sq.cs.fr_433 sr.hr.it_444
  0x0c3f1a09, 0x190640a4, 0x10003808, 0x151d1e02,   // xxx.sw.pl_444 sl.de.et_433 ca.sv..._430 sr.hr.lv_222
  0x1a000c07, 0x1a001014, 0x0d0f2013, 0x16454012,   // pl.xxx..._420 sv.xxx..._660 gl.es.pt_665 sl.sk.lt_654
  0x42000d13, 0x1d001f02, 0x0d001009, 0x03062e09,   // pt.mt..._650 ga.hr..._220 sv.pt..._440 sq.de.nl_444
  // [3580]
  0x031f6607, 0x450c1012, 0x30232514, 0x66001514,   // af.ga.nl_432 sv.pl.sk_654 mk.uk.be_666 lv.af..._660
  0x12171a08, 0x191f4255, 0x45031202, 0x421e1d60,   // xxx.ro.cs_443 mt.ga.et_442 cs.nl.sk_222 hr.sr.mt_664
  0x421e1d09, 0x1e1d4214, 0x250e1ca4, 0x383a2112,   // hr.sr.mt_444 mt.hr.sr_666 bg.ru.mk_433 tl.eu.ca_654
  0x22060308, 0x0f0d0513, 0x150c0312, 0x4b000202,   // nl.de.tr_443 fr.pt.es_665 nl.pl.lv_654 da.az..._220
  // [3590]
  0x05124513, 0x21001002, 0x08008c07, 0x01000507,   // sk.cs.fr_665 sv.tl..._220 ht.it..._420 fr.en..._420
  0x380f1414, 0x231c1e12, 0x190b0213, 0x0f031f09,   // is.es.ca_666 sr.bg.uk_654 da.no.et_665 ga.nl.es_444
  0x23301c55, 0x0c030608, 0x12184508, 0x121845a4,   // bg.be.uk_442 de.nl.pl_443 sk.hu.cs_443 sk.hu.cs_433
  0x213a2709, 0x3f000509, 0x27001502, 0x25231e08,   // id.eu.tl_444 fr.sw..._440 lv.id..._220 sr.uk.mk_443
  // [35a0]
  0x42401513, 0x27021a02, 0x011d6602, 0x1d1e1709,   // lv.sl.mt_665 xxx.da.id_222 af.hr.en_222 ro.sr.hr_444
  0x021f42a4, 0x021910a4, 0x452b1f08, 0x1e006602,   // mt.ga.da_433 sv.et.da_433 ga.cy.sk_443 af.sr..._220
  0x21000c12, 0x18061008, 0x14061007, 0x2b0c8c60,   // pl.tl..._640 sv.de.hu_443 sv.de.is_432 ht.pl.cy_664
  0x30001c07, 0x1e1c25ad, 0x020b14a4, 0x40001702,   // bg.be..._420 mk.bg.sr_643 is.no.da_433 ro.sl..._220
  // [35b0]
  0x40152ba4, 0x224b1912, 0x05171a08, 0x1d001523,   // cy.lv.sl_433 et.az.tr_654 xxx.ro.fr_443 lv.hr..._880
  0x04002108, 0x2b003a22, 0x1c231e09, 0x04004213,   // tl.fi..._430 eu.cy..._870 sr.uk.bg_444 mt.fi..._650
  0x2b001522, 0x04422755, 0x0e231ead, 0x2b041f08,   // lv.cy..._870 id.mt.fi_442 sr.uk.ru_643 ga.fi.cy_443
  0x0c004314, 0x300e23af, 0x020b1012, 0x27004213,   // vi.pl..._660 uk.ru.be_655 sv.no.da_654 mt.id..._650
  // [35c0]
  0x42000413, 0x03002e09, 0x42213f12, 0x1d012e07,   // fi.mt..._650 sq.nl..._440 sw.tl.mt_654 sq.en.hr_432
  0x15000507, 0x38050309, 0x661f0412, 0x06041fa4,   // fr.lv..._420 nl.fr.ca_444 fi.ga.af_654 ga.fi.de_433
  0x22000d14, 0x42001409, 0x230e1cad, 0x03000c12,   // pt.tr..._660 is.mt..._440 bg.ru.uk_643 pl.nl..._640
  0x15001014, 0x08210107, 0x0c141fad, 0x45050d08,   // sv.lv..._660 en.tl.it_432 ga.is.pl_643 pt.fr.sk_443
  // [35d0]
  0x04191508, 0x04000322, 0x16382ba4, 0x1d292709,   // lv.et.fi_443 nl.fi..._870 cy.ca.lt_433 id.ms.hr_444
  0x19042707, 0x17006608, 0x18004b13, 0x0e232507,   // id.fi.et_432 af.ro..._430 az.hu..._650 mk.uk.ru_432
  0x2b0f1f09, 0x2e180508, 0x05012e13, 0x451e1212,   // ga.es.cy_444 fr.hu.sq_443 sq.en.fr_665 cs.sr.sk_654
  0x1e1d12ba, 0x14000b22, 0x14061012, 0x10141f08,   // cs.hr.sr_843 no.is..._870 sv.de.is_654 ga.is.sv_443
  // [35e0]
  0x19143a08, 0x21004b14, 0x08001922, 0x27062908,   // eu.is.et_443 az.tl..._660 et.it..._870 ms.de.id_443
  0x43000612, 0x29270614, 0x06292714, 0x10002e12,   // de.vi..._640 de.id.ms_666 id.ms.de_666 sq.sv..._640
  0x153a2709, 0x4b006608, 0x292706a4, 0x292706af,   // id.eu.lv_444 af.az..._430 de.id.ms_433 de.id.ms_655
  0x06292713, 0x03164208, 0x22210408, 0x451d1208,   // id.ms.de_665 mt.lt.nl_443 fi.tl.tr_443 cs.hr.sk_443
  // [35f0]
  0x431f4509, 0x1d1e40ab, 0x14030660, 0x45120102,   // sk.ga.vi_444 sl.sr.hr_621 de.nl.is_664 en.cs.sk_222
  0x161d1508, 0x12004007, 0x1c1e2507, 0x12001612,   // lv.hr.lt_443 sl.cs..._420 mk.sr.bg_432 lt.cs..._640
  0x0f001723, 0x191e1d13, 0x8c000823, 0x30230e08,   // ro.es..._880 hr.sr.et_665 it.ht..._880 ru.uk.be_443
  0x38193a09, 0x181f05af, 0x42082909, 0x3a163f13,   // eu.et.ca_444 fr.ga.hu_655 ms.it.mt_444 sw.lt.eu_665
  // [3600]
  0x043f19a4, 0x12001f08, 0x200d0f09, 0x082143a4,   // et.sw.fi_433 ga.cs..._430 es.pt.gl_444 vi.tl.it_433
  0x18272960, 0x3f101a09, 0x0d081a09, 0x0b0414a4,   // ms.id.hu_664 xxx.sv.sw_444 xxx.it.pt_444 is.fi.no_433
  0x0b000809, 0x06183fa4, 0x12001d23, 0x15121e08,   // it.no..._440 sw.hu.de_433 hr.cs..._880 sr.cs.lv_443
  0x420408a4, 0x08002914, 0x191016af, 0x06020508,   // it.fi.mt_433 ms.it..._660 lt.sv.et_655 fr.da.de_443
  // [3610]
  0x1a004207, 0x0d422109, 0x15004522, 0x050f0809,   // mt.xxx..._420 tl.mt.pt_444 sk.lv..._870 it.es.fr_444
  0x0f051708, 0x3f0d29af, 0x1a041f12, 0x1e8c1702,   // ro.fr.es_443 ms.pt.sw_655 ga.fi.xxx_654 ro.ht.sr_222
  0x218c1209, 0x40144508, 0x42001e08, 0x29221d02,   // cs.ht.tl_444 sk.is.sl_443 sr.mt..._430 hr.tr.ms_222
  0x45401802, 0x0c001523, 0x43003f08, 0x05001509,   // hu.sl.sk_222 lv.pl..._880 sw.vi..._430 lv.fr..._440
  // [3620]
  0x14040308, 0x1a001f11, 0x4b8c2214, 0x220d3a08,   // nl.fi.is_443 ga.xxx..._630 tr.ht.az_666 eu.pt.tr_443
  0x1d0c0109, 0x190b2707, 0x42162907, 0x0e231e07,   // en.pl.hr_444 id.no.et_432 ms.lt.mt_432 sr.uk.ru_432
  0x1e4015a4, 0x38121755, 0x10030202, 0x29003f08,   // lv.sl.sr_433 ro.cs.ca_442 da.nl.sv_222 sw.ms..._430
  0x23251e13, 0x052e3802, 0x01221a60, 0x200f0d13,   // sr.mk.uk_665 ca.sq.fr_222 xxx.tr.en_664 pt.es.gl_665
  // [3630]
  0x171f3808, 0x191604a4, 0x27003814, 0x3a210109,   // ca.ga.ro_443 fi.lt.et_433 ca.id..._660 en.tl.eu_444
  0x451a4209, 0x38190107, 0x160804a4, 0x29211f02,   // mt.xxx.sk_444 en.et.ca_432 fi.it.lt_433 ga.tl.ms_222
  0x05001913, 0x660c4209, 0x8c432713, 0x1e081d08,   // et.fr..._650 mt.pl.af_444 id.vi.ht_665 hr.it.sr_443
  0x23251e60, 0x03060da4, 0x04050109, 0x19021008,   // sr.mk.uk_664 pt.de.nl_433 en.fr.fi_444 sv.da.et_443
  // [3640]
  0x42002707, 0x03026612, 0x2b006608, 0x301c0e08,   // id.mt..._420 af.da.nl_654 af.cy..._430 ru.bg.be_443
  0x1f2e08af, 0x4b001a14, 0x213f0fa4, 0x27001509,   // it.sq.ga_655 xxx.az..._660 es.sw.tl_433 lv.id..._440
  0x10061412, 0x18004013, 0x1d001607, 0x02102b12,   // is.de.sv_654 sl.hu..._650 lt.hr..._420 cy.sv.da_654
  0x0c000813, 0x401d2e55, 0x0f000523, 0x100614af,   // it.pl..._650 sq.hr.sl_442 fr.es..._880 is.de.sv_655
  // [3650]
  0x0b006622, 0x18001421, 0x04061509, 0x14001523,   // af.no..._870 is.hu..._860 lv.de.fi_444 lv.is..._880
  0x1d161e09, 0x03663a60, 0x38001d14, 0x06001f09,   // sr.lt.hr_444 eu.af.nl_664 hr.ca..._660 ga.de..._440
  0x06011aa4, 0x12001609, 0x3f1a20af, 0x140d0f07,   // xxx.en.de_433 lt.cs..._440 gl.xxx.sw_655 es.pt.is_432
  0x02060b07, 0x172e1a09, 0x17003f23, 0x20003f02,   // no.de.da_432 xxx.sq.ro_444 sw.ro..._880 sw.gl..._220
  // [3660]
  0x8c223f08, 0x0c1d1e60, 0x123f0502, 0x01002107,   // sw.tr.ht_443 sr.hr.pl_664 fr.sw.cs_222 tl.en..._420
  0x1f124560, 0x3f1a21a4, 0x1c001e21, 0x294b2202,   // sk.cs.ga_664 tl.xxx.sw_433 sr.bg..._860 tr.az.ms_222
  0x14001823, 0x04001021, 0x1e1d4208, 0x06004509,   // hu.is..._880 sv.fi..._860 mt.hr.sr_443 sk.de..._440
  0x22044208, 0x1e1d1655, 0x05040807, 0x140d0f12,   // mt.fi.tr_443 lt.hr.sr_442 it.fi.fr_432 es.pt.is_654
  // [3670]
  0x0c001512, 0x14001512, 0x18001023, 0x1d1e17a4,   // lv.pl..._640 lv.is..._640 sv.hu..._880 ro.sr.hr_433
  0x401614a4, 0x100b2212, 0x43000d02, 0x45001809,   // is.lt.sl_433 tr.no.sv_654 pt.vi..._220 hu.sk..._440
  0x16222ea4, 0x05194208, 0x231c25af, 0x1e001821,   // sq.tr.lt_433 mt.et.fr_443 mk.bg.uk_655 hu.sr..._860
  0x173f1960, 0x15451212, 0x14182114, 0x04140b09,   // et.sw.ro_664 cs.sk.lv_654 tl.hu.is_666 no.is.fi_444
  // [3680]
  0x1f001523, 0x2b003a23, 0x1e1d1608, 0x06001f13,   // lv.ga..._880 eu.cy..._880 lt.hr.sr_443 ga.de..._650
  0x1a2b0107, 0x162122ad, 0x19212e12, 0x2b000622,   // en.cy.xxx_432 tr.tl.lt_643 sq.tl.et_654 de.cy..._870
  0x15000b07, 0x01183a08, 0x22041255, 0x27001009,   // no.lv..._420 eu.hu.en_443 cs.fi.tr_442 sv.id..._440
  0x0e2530a4, 0x661d02a4, 0x42000d08, 0x12141708,   // be.mk.ru_433 da.hr.af_433 pt.mt..._430 ro.is.cs_443
  // [3690]
  0x15061202, 0x451240ab, 0x45401207, 0x1e002b13,   // cs.de.lv_222 sl.cs.sk_621 cs.sl.sk_432 cy.sr..._650
  0x1e302355, 0x10140b07, 0x10140b09, 0x08421007,   // uk.be.sr_442 no.is.sv_432 no.is.sv_444 sv.mt.it_432
  0x06010508, 0x2b003f08, 0x66271a12, 0x25230e14,   // fr.en.de_443 sw.cy..._430 xxx.id.af_654 ru.uk.mk_666
  0x66000c13, 0x1e001510, 0x3a1f0107, 0x17001622,   // pl.af..._650 lv.sr..._620 en.ga.eu_432 lt.ro..._870
  // [36a0]
  0x66003f22, 0x3a031f07, 0x2e0127a4, 0x0c006613,   // sw.af..._870 ga.nl.eu_432 id.en.sq_433 af.pl..._650
  0x04001813, 0x3f000514, 0x66003f14, 0x03086608,   // hu.fi..._650 fr.sw..._660 sw.af..._660 af.it.nl_443
  0x10008c08, 0x0f001608, 0x04002708, 0x661f0208,   // ht.sv..._430 lt.es..._430 id.fi..._430 da.ga.af_443
  0x17000613, 0x08002e09, 0x42001613, 0x14021014,   // de.ro..._650 sq.it..._440 lt.mt..._650 sv.da.is_666
  // [36b0]
  0x2e381708, 0x19008c14, 0x291d0b07, 0x298c2707,   // ro.ca.sq_443 ht.et..._660 no.hr.ms_432 id.ht.ms_432
  0x20002e02, 0x12002909, 0x12224502, 0x66272908,   // sq.gl..._220 ms.cs..._440 sk.tr.cs_222 ms.id.af_443
  0x1d000b21, 0x25003012, 0x45031a02, 0x0b191a08,   // no.hr..._860 be.mk..._640 xxx.nl.sk_222 xxx.et.no_443
  0x151d4208, 0x050d8c08, 0x02043a08, 0x1d2b1009,   // mt.hr.lv_443 ht.pt.fr_443 eu.fi.da_443 sv.cy.hr_444
  // [36c0]
  0x05140107, 0x1a001f21, 0x29190402, 0x22000314,   // en.is.fr_432 ga.xxx..._860 fi.et.ms_222 nl.tr..._660
  0x1a004212, 0x3a001a13, 0x04290107, 0x06041912,   // mt.xxx..._640 xxx.eu..._650 en.ms.fi_432 et.fi.de_654
  0x3f190460, 0x8c001f14, 0x29210f08, 0x224b3f13,   // fi.et.sw_664 ga.ht..._660 es.tl.ms_443 sw.az.tr_665
  0x12454009, 0x16021509, 0x10002b14, 0x388c0560,   // sl.sk.cs_444 lv.da.lt_444 cy.sv..._660 fr.ht.ca_664
  // [36d0]
  0x40002922, 0x161f2e07, 0x14102b60, 0x1f014208,   // ms.sl..._870 sq.ga.lt_432 cy.sv.is_664 mt.en.ga_443
  0x10223f08, 0x1a004507, 0x4b003f08, 0x45184002,   // sw.tr.sv_443 sk.xxx..._420 sw.az..._430 sl.hu.sk_222
  0x45006608, 0x2e000b08, 0x3f100207, 0x1a180308,   // af.sk..._430 no.sq..._430 da.sv.sw_432 nl.hu.xxx_443
  0x3f3a2909, 0x29181a02, 0x12662907, 0x16220608,   // ms.eu.sw_444 xxx.hu.ms_222 ms.af.cs_432 de.tr.lt_443
  // [36e0]
  0x40000214, 0x08000513, 0x1d401e14, 0x8c1a3f12,   // da.sl..._660 fr.it..._650 sr.sl.hr_666 sw.xxx.ht_654
  0x27171902, 0x15001a02, 0x211d1e11, 0x1d1a1508,   // et.ro.id_222 xxx.lv..._220 sr.hr.tl_653 lv.xxx.hr_443
  0x142b1008, 0x3f000f23, 0x3f001d13, 0x3f1a4212,   // sv.cy.is_443 es.sw..._880 hr.sw..._650 mt.xxx.sw_654
  0x0f006609, 0x2e000b22, 0x3a004214, 0x01000c12,   // af.es..._440 no.sq..._870 mt.eu..._660 pl.en..._640
  // [36f0]
  0x66001f14, 0x052e0109, 0x1d001723, 0x29171a02,   // ga.af..._660 en.sq.fr_444 ro.hr..._880 xxx.ro.ms_222
  0x0f0d1408, 0x05001d23, 0x1d008c23, 0x1e292707,   // is.pt.es_443 hr.fr..._880 ht.hr..._880 id.ms.sr_432
  0x19002002, 0x1f001614, 0x10000b21, 0x0f404508,   // gl.et..._220 lt.ga..._660 no.sv..._860 sk.sl.es_443
  0x05120d02, 0x3f161209, 0x043f3a08, 0x2e0f3807,   // pt.cs.fr_222 cs.lt.sw_444 eu.sw.fi_443 ca.es.sq_432
  // [3700]
  0x0d002114, 0x3a0f8ca4, 0x16003f09, 0x0f124513,   // tl.pt..._660 ht.es.eu_433 sw.lt..._440 sk.cs.es_665
  0x10040209, 0x22180460, 0x452e0502, 0x02290b08,   // da.fi.sv_444 fi.hu.tr_664 fr.sq.sk_222 no.ms.da_443
  0x0f401209, 0x452b2902, 0x42224baf, 0x293f0402,   // cs.sl.es_444 ms.cy.sk_222 az.tr.mt_655 fi.sw.ms_222
  0x16150107, 0x0f001811, 0x0f004312, 0x3a038c08,   // en.lv.lt_432 hu.es..._630 vi.es..._640 ht.nl.eu_443
  // [3710]
  0x18140b60, 0x1e002b09, 0x02011a09, 0x38292709,   // no.is.hu_664 cy.sr..._440 xxx.en.da_444 id.ms.ca_444
  0x66000b12, 0x224b2ea4, 0x4b003a14, 0x45181f09,   // no.af..._640 sq.az.tr_433 eu.az..._660 ga.hu.sk_444
  0x1a1d1e02, 0x04001214, 0x251c2313, 0x1e003022,   // sr.hr.xxx_222 cs.fi..._660 uk.bg.mk_665 be.sr..._870
  0x153f2107, 0x23251e08, 0x18170109, 0x38423a08,   // tl.sw.lv_432 sr.mk.uk_443 en.ro.hu_444 eu.mt.ca_443
  // [3720]
  0x0d004214, 0x05060107, 0x19000622, 0x3f041960,   // mt.pt..._660 en.de.fr_432 de.et..._870 et.fi.sw_664
  0x224b0b07, 0x2b000313, 0x45020402, 0x0b001802,   // no.az.tr_432 nl.cy..._650 fi.da.sk_222 hu.no..._220
  0x17000323, 0x05036608, 0x12184560, 0x4b048ca4,   // nl.ro..._880 af.nl.fr_443 sk.hu.cs_664 ht.fi.az_433
  0x45141208, 0x1f002e11, 0x08000f13, 0x120d0f08,   // cs.is.sk_443 sq.ga..._630 es.it..._650 es.pt.cs_443
  // [3730]
  0x181f1460, 0x14001f0d, 0x29220202, 0x18008c09,   // is.ga.hu_664 ga.is..._540 da.tr.ms_222 ht.hu..._440
  0x03000814, 0x15451207, 0x170f22a4, 0x060d1002,   // it.nl..._660 cs.sk.lv_432 tr.es.ro_433 sv.pt.de_222
  0x1c250e11, 0x293f0502, 0x2e3f1fa4, 0x06100309,   // ru.mk.bg_653 fr.sw.ms_222 ga.sw.sq_433 nl.sv.de_444
  0x42081812, 0x1e382208, 0x0d001202, 0x0c0d0f55,   // hu.it.mt_654 tr.ca.sr_443 cs.pt..._220 es.pt.pl_442
  // [3740]
  0x301c0eaf, 0x4b004002, 0x03081e02, 0x1d2e1402,   // ru.bg.be_655 sl.az..._220 sr.it.nl_222 is.sq.hr_222
  0x04213f07, 0x0f190407, 0x02061008, 0x14008c23,   // sw.tl.fi_432 fi.et.es_432 sv.de.da_443 ht.is..._880
  0x03660b08, 0x40001d12, 0x220610af, 0x2b0f38af,   // no.af.nl_443 hr.sl..._640 sv.de.tr_655 ca.es.cy_655
  0x080d1a07, 0x0f3a0107, 0x0b002923, 0x1f180512,   // xxx.pt.it_432 en.eu.es_432 ms.no..._880 fr.hu.ga_654
  // [3750]
  0x08002108, 0x271d2908, 0x17000209, 0x0b100c12,   // tl.it..._430 ms.hr.id_443 da.ro..._440 pl.sv.no_654
  0x0f180560, 0x031d1e02, 0x29001609, 0x1d0c1e14,   // fr.hu.es_664 sr.hr.nl_222 lt.ms..._440 sr.pl.hr_666
  0x42000214, 0x1e064002, 0x4b008c13, 0x66001414,   // da.mt..._660 sl.de.sr_222 ht.az..._650 is.af..._660
  0x0b151660, 0x66010408, 0x42001a12, 0x2e3a8c55,   // lt.lv.no_664 fi.en.af_443 xxx.mt..._640 ht.eu.sq_442
  // [3760]
  0x02008c13, 0x16002e23, 0x2e1e1daf, 0x10030208,   // ht.da..._650 sq.lt..._880 hr.sr.sq_655 da.nl.sv_443
  0x1e1d3f07, 0x27036609, 0x27011aa4, 0x12381602,   // sw.hr.sr_432 af.nl.id_444 xxx.en.id_433 lt.ca.cs_222
  0x212b2208, 0x1d0c4507, 0x04660360, 0x66190360,   // tr.cy.tl_443 sk.pl.hr_432 nl.af.fi_664 nl.et.af_664
  0x14001f21, 0x12451e12, 0x14272909, 0x4b002702,   // ga.is..._860 sr.sk.cs_654 ms.id.is_444 id.az..._220
  // [3770]
  0x012205a4, 0x0f054b09, 0x2b1d1fa4, 0x43043a07,   // fr.tr.en_433 az.fr.es_444 ga.hr.cy_433 eu.fi.vi_432
  0x27004209, 0x27020b02, 0x140f45a4, 0x190121a4,   // mt.id..._440 no.da.id_222 sk.es.is_433 tl.en.et_433
  0x01662b08, 0x01003a12, 0x12451fa0, 0x0f170508,   // cy.af.en_443 eu.en..._640 ga.sk.cs_322 fr.ro.es_443
  0x031615af, 0x12000802, 0x0c008c14, 0x16000107,   // lv.lt.nl_655 it.cs..._220 ht.pl..._660 en.lt..._420
  // [3780]
  0x214b2213, 0x0f381f08, 0x010d1755, 0x27422ead,   // tr.az.tl_665 ga.ca.es_443 ro.pt.en_442 sq.mt.id_643
  0x1a150109, 0x01003f13, 0x38002b22, 0x19212709,   // en.lv.xxx_444 sw.en..._650 cy.ca..._870 id.tl.et_444
  0x030615a4, 0x2b001e02, 0x3a004b12, 0x08002209,   // lv.de.nl_433 sr.cy..._220 az.eu..._640 tr.it..._440
  0x4b2916af, 0x45020b02, 0x1f451860, 0x40000102,   // lt.ms.az_655 no.da.sk_222 hu.sk.ga_664 en.sl..._220
  // [3790]
  0x12001902, 0x0c013fa4, 0x148c04a4, 0x2e024009,   // et.cs..._220 sw.en.pl_433 fi.ht.is_433 sl.da.sq_444
  0x40000114, 0x14001a14, 0x03000b11, 0x06023a02,   // en.sl..._660 xxx.is..._660 no.nl..._630 eu.da.de_222
  0x2b000f09, 0x454212af, 0x3a004023, 0x66190313,   // es.cy..._440 cs.mt.sk_655 sl.eu..._880 nl.et.af_665
  0x29001023, 0x1a450209, 0x04151613, 0x012138a4,   // sv.ms..._880 da.sk.xxx_444 lt.lv.fi_665 ca.tl.en_433
  // [37a0]
  0x0b004b13, 0x1e0d1402, 0x451d3f02, 0x1e0c4502,   // az.no..._650 is.pt.sr_222 sw.hr.sk_222 sk.pl.sr_222
  0x3f001722, 0x17001d23, 0x40021013, 0x08292707,   // ro.sw..._870 hr.ro..._880 sv.da.sl_665 id.ms.it_432
  0x17221a09, 0x14000423, 0x12191702, 0x16004b22,   // xxx.tr.ro_444 fi.is..._880 ro.et.cs_222 az.lt..._870
  0x17001922, 0x05002114, 0x12004023, 0x27042102,   // et.ro..._870 tl.fr..._660 sl.cs..._880 tl.fi.id_222
  // [37b0]
  0x18000214, 0x21042708, 0x451d3a02, 0x38004514,   // da.hu..._660 id.fi.tl_443 eu.hr.sk_222 sk.ca..._660
  0x02101a02, 0x450f2002, 0x22190412, 0x041519a4,   // xxx.sv.da_222 gl.es.sk_222 fi.et.tr_654 et.lv.fi_433
  0x19210412, 0x0d004323, 0x27100302, 0x12000d09,   // fi.tl.et_654 vi.pt..._880 nl.sv.id_222 pt.cs..._440
  0x1c250e07, 0x03000b13, 0x12040107, 0x664b22a4,   // ru.mk.bg_432 no.nl..._650 en.fi.cs_432 tr.az.af_433
  // [37c0]
  0x273f0408, 0x22043f08, 0x19060109, 0x45661e02,   // fi.sw.id_443 sw.fi.tr_443 en.de.et_444 sr.af.sk_222
  0x421a2112, 0x1d001a08, 0x1a660107, 0x66032ba4,   // tl.xxx.mt_654 xxx.hr..._430 en.af.xxx_432 cy.nl.af_433
  0x1e000614, 0x15166612, 0x4b008c11, 0x10420b07,   // de.sr..._660 af.lt.lv_654 ht.az..._630 no.mt.sv_432
  0x17080108, 0x02000121, 0x18020b09, 0x2e1916a4,   // en.it.ro_443 en.da..._860 no.da.hu_444 lt.et.sq_433
  // [37d0]
  0x058c02af, 0x15000c12, 0x0f3a0ca4, 0x0c664509,   // da.ht.fr_655 pl.lv..._640 pl.eu.es_433 sk.af.pl_444
  0x450f2707, 0x16000123, 0x45011202, 0x02060408,   // id.es.sk_432 en.lt..._880 cs.en.sk_222 fi.de.da_443
  0x273f29a4, 0x3f100b13, 0x103f0b09, 0x17002b14,   // ms.sw.id_433 no.sv.sw_665 no.sw.sv_444 cy.ro..._660
  0x1d421e02, 0x033f1a08, 0x058c2208, 0x661a0107,   // sr.mt.hr_222 xxx.sw.nl_443 tr.ht.fr_443 en.xxx.af_432
  // [37e0]
  0x1e1d1208, 0x40660307, 0x4b001f02, 0x2b290b09,   // cs.hr.sr_443 nl.af.sl_432 ga.az..._220 no.ms.cy_444
  0x1e001613, 0x200d2907, 0x02003f12, 0x033a6655,   // lt.sr..._650 ms.pt.gl_432 sw.da..._640 af.eu.nl_442
  0x21001f13, 0x380d1413, 0x27001809, 0x4b221860,   // ga.tl..._650 is.pt.ca_665 hu.id..._440 hu.tr.az_664
  0x05420107, 0x2b003f23, 0x66061a13, 0x3f004009,   // en.mt.fr_432 sw.cy..._880 xxx.de.af_665 sl.sw..._440
  // [37f0]
  0x04001920, 0x064219a4, 0x04212ba4, 0x191806af,   // et.fi..._850 et.mt.de_433 cy.tl.fi_433 de.hu.et_655
  0x140c2b08, 0x0b001a09, 0x3f2b1faf, 0x22003a21,   // cy.pl.is_443 xxx.no..._440 ga.cy.sw_655 eu.tr..._860
  0x011f2955, 0x421f3fa4, 0x3a001512, 0x14043a07,   // ms.ga.en_442 sw.ga.mt_433 lv.eu..._640 eu.fi.is_432
  0x080f0555, 0x01008c07, 0x17041209, 0x0f0d0512,   // fr.es.it_442 ht.en..._420 cs.fi.ro_444 fr.pt.es_654

  // [3800]
  0x42001f14, 0x170d3813, 0x04000f08, 0x08001f13,   // ga.mt..._660 ca.pt.ro_665 es.fi..._430 ga.it..._650
  0x45401202, 0x27004b07, 0x45061002, 0x40124508,   // cs.sl.sk_222 az.id..._420 sv.de.sk_222 sk.cs.sl_443
  0x45196602, 0x03004314, 0x22291a08, 0x451d0802,   // af.et.sk_222 vi.nl..._660 xxx.ms.tr_443 it.hr.sk_222
  0x45001d09, 0x1e3a2908, 0x10660660, 0x08181407,   // hr.sk..._440 ms.eu.sr_443 de.af.sv_664 is.hu.it_432
  // [3810]
  0x04292713, 0x142729a4, 0x4b002e23, 0x27150412,   // id.ms.fi_665 ms.id.is_433 sq.az..._880 fi.lv.id_654
  0x0e1c1e09, 0x3a3f1207, 0x45043a02, 0x27102202,   // sr.bg.ru_444 cs.sw.eu_432 eu.fi.sk_222 tr.sv.id_222
  0x29001409, 0x450c1209, 0x013f0609, 0x10041faf,   // is.ms..._440 cs.pl.sk_444 de.sw.en_444 ga.fi.sv_655
  0x18000c02, 0x1d210407, 0x1d3f0f02, 0x01451fa4,   // pl.hu..._220 fi.tl.hr_432 es.sw.hr_222 ga.sk.en_433
  // [3820]
  0x14000507, 0x40004208, 0x14451260, 0x0c002e02,   // fr.is..._420 mt.sl..._430 cs.sk.is_664 sq.pl..._220
  0x451e8c02, 0x66001a12, 0x06224b08, 0x031e2e07,   // ht.sr.sk_222 xxx.af..._640 az.tr.de_443 sq.sr.nl_432
  0x29660602, 0x12101aa4, 0x8c220c12, 0x1e050602,   // de.af.ms_222 xxx.sv.cs_433 pl.tr.ht_654 de.fr.sr_222
  0x1e060202, 0x023f1a08, 0x02002114, 0x2e4b2212,   // da.de.sr_222 xxx.sw.da_443 tl.da..._660 tr.az.sq_654
  // [3830]
  0x2b002114, 0x38001f13, 0x08001923, 0x06141008,   // tl.cy..._660 ga.ca..._650 et.it..._880 sv.is.de_443
  0x03004502, 0x8c3f0c55, 0x42290412, 0x142e4212,   // sk.nl..._220 pl.sw.ht_442 fi.ms.mt_654 mt.sq.is_654
  0x1a431202, 0x3f0c8ca4, 0x1f3f2907, 0x1d0c6602,   // cs.vi.xxx_222 ht.pl.sw_433 ms.sw.ga_432 af.pl.hr_222
  0x102e0c13, 0x0c404509, 0x2e002913, 0x66061808,   // pl.sq.sv_665 sk.sl.pl_444 ms.sq..._650 hu.de.af_443
  // [3840]
  0x2e002013, 0x10004523, 0x1e401207, 0x224b1713,   // gl.sq..._650 sk.sv..._880 cs.sl.sr_432 ro.az.tr_665
  0x45224b08, 0x224b10a4, 0x21272911, 0x16002b08,   // az.tr.sk_443 sv.az.tr_433 ms.id.tl_653 cy.lt..._430
  0x66061012, 0x19000207, 0x08001d09, 0x2b068c09,   // sv.de.af_654 da.et..._420 hr.it..._440 ht.de.cy_444
  0x1e1d2ea4, 0x0c1e1d60, 0x0c000423, 0x06001508,   // sq.hr.sr_433 hr.sr.pl_664 fi.pl..._880 lv.de..._430
  // [3850]
  0x12101708, 0x29002213, 0x3f400c13, 0x45400b02,   // ro.sv.cs_443 tr.ms..._650 pl.sl.sw_665 no.sl.sk_222
  0x29213f02, 0x12450302, 0x222127a4, 0x03001008,   // sw.tl.ms_222 nl.sk.cs_222 id.tl.tr_433 sv.nl..._430
  0x3a001613, 0x66004008, 0x14004008, 0x19041002,   // lt.eu..._650 sl.af..._430 sl.is..._430 sv.fi.et_222
  0x21004323, 0x16152213, 0x16001f12, 0x03663813,   // vi.tl..._880 tr.lv.lt_665 ga.lt..._640 ca.af.nl_665
  // [3860]
  0x08002b23, 0x1d0f0107, 0x290f1e02, 0x0d002b22,   // cy.it..._880 en.es.hr_432 sr.es.ms_222 cy.pt..._870
  0x10060260, 0x02001602, 0x1d144209, 0x2b162709,   // da.de.sv_664 lt.da..._220 mt.is.hr_444 id.lt.cy_444
  0x4b2b14a4, 0x27382909, 0x0f2b0411, 0x16008c14,   // is.cy.az_433 ms.ca.id_444 fi.cy.es_653 ht.lt..._660
  0x1f000323, 0x04193808, 0x0b021055, 0x38180f08,   // nl.ga..._880 ca.et.fi_443 sv.da.no_442 es.hu.ca_443
  // [3870]
  0x1e2b1d09, 0x2e4202a4, 0x42380b09, 0x02030b55,   // hr.cy.sr_444 da.mt.sq_433 no.ca.mt_444 no.nl.da_442
  0x022e0109, 0x1e4e3712, 0x38000423, 0x2e001f23,   // en.sq.da_444 ar.fa.sr_654 fi.ca..._880 ga.sq..._880
  0x1a120607, 0x0e001c11, 0x38190109, 0x250e3007,   // de.cs.xxx_432 bg.ru..._630 en.et.ca_444 be.ru.mk_432
  0x45001722, 0x0e301c55, 0x2e004022, 0x3f1d1e09,   // ro.sk..._870 bg.be.ru_442 sl.sq..._870 sr.hr.sw_444
  // [3880]
  0x0000072d, 0x40000509, 0x3a002e08, 0x10002902,   // iw......_A00 fr.sl..._440 sq.eu..._430 ms.sv..._220
  0x0b000d09, 0x4b000414, 0x4b002b14, 0x1d3f2108,   // pt.no..._440 fi.az..._660 cy.az..._660 tl.sw.hr_443
  0x4b2b2209, 0x1d1e4b02, 0x08041960, 0x02001723,   // tr.cy.az_444 az.sr.hr_222 et.fi.it_664 ro.da..._880
  0x451f1212, 0x451812af, 0x14224b55, 0x06000b07,   // cs.ga.sk_654 cs.hu.sk_655 az.tr.is_442 no.de..._420
  // [3890]
  0x3f000d02, 0x40000c13, 0x2e1410a4, 0x0c100b07,   // pt.sw..._220 pl.sl..._650 sv.is.sq_433 no.sv.pl_432
  0x03196614, 0x08036655, 0x451f1402, 0x14382ba4,   // af.et.nl_666 af.nl.it_442 is.ga.sk_222 cy.ca.is_433
  0x10182260, 0x2e000d08, 0x1a000214, 0x03042208,   // tr.hu.sv_664 pt.sq..._430 da.xxx..._660 tr.fi.nl_443
  0x050f3812, 0x10050b09, 0x19043a12, 0x0c0166a4,   // ca.es.fr_654 no.fr.sv_444 eu.fi.et_654 af.en.pl_433
  // [38a0]
  0x0c2b2112, 0x0e3025af, 0x08163aaf, 0x66001209,   // tl.cy.pl_654 mk.be.ru_655 eu.lt.it_655 cs.af..._440
  0x22453a08, 0x21001d02, 0x05001408, 0x45174202,   // eu.sk.tr_443 hr.tl..._220 is.fr..._430 mt.ro.sk_222
  0x66190109, 0x03662109, 0x180c4008, 0x05002b22,   // en.et.af_444 tl.af.nl_444 sl.pl.hu_443 cy.fr..._870
  0x3a000813, 0x08044312, 0x10002223, 0x04202b60,   // it.eu..._650 vi.fi.it_654 tr.sv..._880 cy.gl.fi_664
  // [38b0]
  0x1e250e13, 0x100f4ba4, 0x121d4009, 0x4b102213,   // ru.mk.sr_665 az.es.sv_433 sl.hr.cs_444 tr.sv.az_665
  0x4b001008, 0x188c3f13, 0x0d151255, 0x66420807,   // sv.az..._430 sw.ht.hu_665 cs.lv.pt_442 it.mt.af_432
  0x12001822, 0x1e0c0102, 0x102e2707, 0x19002913,   // hu.cs..._870 en.pl.sr_222 id.sq.sv_432 ms.et..._650
  0x15002202, 0x272e1412, 0x124515a4, 0x21002b08,   // tr.lv..._220 is.sq.id_654 lv.sk.cs_433 cy.tl..._430
  // [38c0]
  0x16004213, 0x0c004309, 0x1d1e8ca4, 0x0f002108,   // mt.lt..._650 vi.pl..._440 ht.sr.hr_433 tl.es..._430
  0x05000d07, 0x3a008c23, 0x0b001012, 0x033a8c55,   // pt.fr..._420 ht.eu..._880 sv.no..._640 ht.eu.nl_442
  0x40000d23, 0x0d381207, 0x17000622, 0x18001011,   // pt.sl..._880 cs.ca.pt_432 de.ro..._870 sv.hu..._630
  0x29000523, 0x01431aa4, 0x05080155, 0x27018c08,   // fr.ms..._880 xxx.vi.en_433 en.it.fr_442 ht.en.id_443
  // [38d0]
  0x0d001207, 0x04102b08, 0x1c0e1e60, 0x1e000209,   // cs.pt..._420 cy.sv.fi_443 sr.ru.bg_664 da.sr..._440
  0x0b100212, 0x0b008c14, 0x42003f12, 0x213f2909,   // da.sv.no_654 ht.no..._660 sw.mt..._640 ms.sw.tl_444
  0x19000611, 0x19100414, 0x0b003f22, 0x27002e08,   // de.et..._630 fi.sv.et_666 sw.no..._870 sq.id..._430
  0x1d041002, 0x3f3a1a08, 0x193a1808, 0x66022b12,   // sv.fi.hr_222 xxx.eu.sw_443 hu.eu.et_443 cy.da.af_654
  // [38e0]
  0x42003a12, 0x66001a08, 0x08220b09, 0x140522a4,   // eu.mt..._640 xxx.af..._430 no.tr.it_444 tr.fr.is_433
  0x2e000122, 0x40292708, 0x293a1f02, 0x04021008,   // en.sq..._870 id.ms.sl_443 ga.eu.ms_222 sv.da.fi_443
  0x15002b12, 0x29270b02, 0x0b000f02, 0x40001002,   // cy.lv..._640 no.id.ms_222 es.no..._220 sv.sl..._220
  0x2b003823, 0x2e154307, 0x06140b13, 0x38001423,   // ca.cy..._880 vi.lv.sq_432 no.is.de_665 is.ca..._880
  // [38f0]
  0x22293f13, 0x04221960, 0x18100208, 0x10400308,   // sw.ms.tr_665 et.tr.fi_664 da.sv.hu_443 nl.sl.sv_443
  0x180104a4, 0x40008c07, 0x45408c12, 0x012b0c09,   // fi.en.hu_433 ht.sl..._420 ht.sl.sk_654 pl.cy.en_444
  0x140b10a4, 0x12000208, 0x3a200f13, 0x1d000207,   // sv.no.is_433 da.cs..._430 es.gl.eu_665 da.hr..._420
  0x8c003f02, 0x250e3060, 0x8c293f07, 0x45036608,   // sw.ht..._220 be.ru.mk_664 sw.ms.ht_432 af.nl.sk_443
  // [3900]
  0x038c6612, 0x27041913, 0x12278c02, 0x45401260,   // af.ht.nl_654 et.fi.id_665 ht.id.cs_222 cs.sl.sk_664
  0x451f1207, 0x8c006613, 0x8c001402, 0x401d12a4,   // cs.ga.sk_432 af.ht..._650 is.ht..._220 cs.hr.sl_433
  0x183f1a08, 0x1a000f09, 0x1a4b2209, 0x0f380b07,   // xxx.sw.hu_443 es.xxx..._440 tr.az.xxx_444 no.ca.es_432
  0x38451260, 0x1f004523, 0x1d172702, 0x01151a08,   // cs.sk.ca_664 sk.ga..._880 id.ro.hr_222 xxx.lv.en_443
  // [3910]
  0x17003a22, 0x0b003a12, 0x2b000f08, 0x1a2b6614,   // eu.ro..._870 eu.no..._640 es.cy..._430 af.cy.xxx_666
  0x422e4b12, 0x020b0107, 0x18104213, 0x2e4218a4,   // az.sq.mt_654 en.no.da_432 mt.sv.hu_665 hu.mt.sq_433
  0x42001712, 0x22000607, 0x1a290107, 0x2b8c3aad,   // ro.mt..._640 de.tr..._420 en.ms.xxx_432 eu.ht.cy_643
  0x21001612, 0x16381f08, 0x036643a4, 0x041f0107,   // lt.tl..._640 ga.ca.lt_443 vi.af.nl_433 en.ga.fi_432
  // [3920]
  0x0c400109, 0x1d151207, 0x06003814, 0x22272960,   // en.sl.pl_444 cs.lv.hr_432 ca.de..._660 ms.id.tr_664
  0x2b002913, 0x2b004b02, 0x21041907, 0x30000e20,   // ms.cy..._650 az.cy..._220 et.fi.tl_432 ru.be..._850
  0x45022102, 0x08001509, 0x02142708, 0x0b2b0109,   // tl.da.sk_222 lv.it..._440 id.is.da_443 en.cy.no_444
  0x0f382008, 0x1e141d14, 0x0f053808, 0x04000307,   // gl.ca.es_443 hr.is.sr_666 ca.fr.es_443 nl.fi..._420
  // [3930]
  0x27042908, 0x18401a08, 0x19661f60, 0x451d0402,   // ms.fi.id_443 xxx.sl.hu_443 ga.af.et_664 fi.hr.sk_222
  0x03002002, 0x06041908, 0x4b0f38a4, 0x04003f22,   // gl.nl..._220 et.fi.de_443 ca.es.az_433 sw.fi..._870
  0x0b102ba4, 0x0f004009, 0x22001a13, 0x45000b21,   // cy.sv.no_433 sl.es..._440 xxx.tr..._650 no.sk..._860
  0x1d002112, 0x06001822, 0x1e1d4513, 0x1d451e14,   // tl.hr..._640 hu.de..._870 sk.hr.sr_665 sr.sk.hr_666
  // [3940]
  0x1d1e4514, 0x29142760, 0x45120b02, 0x0b001207,   // sk.sr.hr_666 id.is.ms_664 no.cs.sk_222 cs.no..._420
  0x1e003f23, 0x04001f12, 0x27001f02, 0x15004012,   // sw.sr..._880 ga.fi..._640 ga.id..._220 sl.lv..._640
  0x251c3013, 0x10142b12, 0x27003f07, 0x021d4008,   // be.bg.mk_665 cy.is.sv_654 sw.id..._420 sl.hr.da_443
  0x17164008, 0x3f451a09, 0x0f000d21, 0x17088c09,   // sl.lt.ro_443 xxx.sk.sw_444 pt.es..._860 ht.it.ro_444
  // [3950]
  0x400b0208, 0x17063814, 0x42140b13, 0x0c2b8c07,   // da.no.sl_443 ca.de.ro_666 no.is.mt_665 ht.cy.pl_432
  0x2e000212, 0x27004009, 0x0f050da4, 0x12002112,   // da.sq..._640 sl.id..._440 pt.fr.es_433 tl.cs..._640
  0x211f18a4, 0x06180b09, 0x27001823, 0x42000f02,   // hu.ga.tl_433 no.hu.de_444 hu.id..._880 es.mt..._220
  0x1a4b22a4, 0x4b1a1708, 0x1d1a3f02, 0x451a0da4,   // tr.az.xxx_433 ro.xxx.az_443 sw.xxx.hr_222 pt.xxx.sk_433
  // [3960]
  0x4b1a2208, 0x1d001813, 0x17002b23, 0x431a0507,   // tr.xxx.az_443 hu.hr..._650 cy.ro..._880 fr.xxx.vi_432
  0x173f3802, 0x3a172707, 0x43001723, 0x273a8c02,   // ca.sw.ro_222 id.ro.eu_432 ro.vi..._880 ht.eu.id_222
  0x05043a08, 0x02660314, 0x0f002121, 0x1f3f2e12,   // eu.fi.fr_443 nl.af.da_666 tl.es..._860 sq.sw.ga_654
  0x011a1509, 0x2b000b02, 0x10003813, 0x04002212,   // lv.xxx.en_444 no.cy..._220 ca.sv..._650 tr.fi..._640
  // [3970]
  0x04101a02, 0x181a1708, 0x06034208, 0x21004502,   // xxx.sv.fi_222 ro.xxx.hu_443 mt.nl.de_443 sk.tl..._220
  0x1a193fa4, 0x0e1c1e08, 0x1d160d02, 0x1a000c13,   // sw.et.xxx_433 sr.bg.ru_443 pt.lt.hr_222 pl.xxx..._650
  0x22000f13, 0x8c420c12, 0x06000f14, 0x16153f08,   // es.tr..._650 pl.mt.ht_654 es.de..._660 sw.lv.lt_443
  0x12031a08, 0x0f000423, 0x16660314, 0x120c45a4,   // xxx.nl.cs_443 fi.es..._880 nl.af.lt_666 sk.pl.cs_433
  // [3980]
  0x1e1d06a4, 0x45126609, 0x1e000809, 0x0c004222,   // de.hr.sr_433 af.cs.sk_444 it.sr..._440 mt.pl..._870
  0x1d1e0f02, 0x064b2260, 0x1d450208, 0x10000421,   // es.sr.hr_222 tr.az.de_664 da.sk.hr_443 fi.sv..._860
  0x03001602, 0x1c1e2560, 0x1d383a02, 0x03004507,   // lt.nl..._220 mk.sr.bg_664 eu.ca.hr_222 sk.nl..._420
  0x1d170309, 0x27021009, 0x19101813, 0x0b001714,   // nl.ro.hr_444 sv.da.id_444 hu.sv.et_665 ro.no..._660
  // [3990]
  0x1e151d12, 0x03001d13, 0x1d1e0302, 0x0b002212,   // hr.lv.sr_654 hr.nl..._650 nl.sr.hr_222 tr.no..._640
  0x03004214, 0x29014b02, 0x14010202, 0x14161a13,   // mt.nl..._660 az.en.ms_222 da.en.is_222 xxx.lt.is_665
  0x40381412, 0x14004212, 0x19001820, 0x45124202,   // is.ca.sl_654 mt.is..._640 hu.et..._850 mt.cs.sk_222
  0x1f141912, 0x16001912, 0x29001f09, 0x8c0c0107,   // et.is.ga_654 et.lt..._640 ga.ms..._440 en.pl.ht_432
  // [39a0]
  0x451d0c08, 0x12003a13, 0x12184502, 0x4b2214af,   // pl.hr.sk_443 eu.cs..._650 sk.hu.cs_222 is.tr.az_655
  0x1a0f0109, 0x4b142208, 0x144b2b13, 0x27020d02,   // en.es.xxx_444 tr.is.az_443 cy.az.is_665 pt.da.id_222
  0x053f20af, 0x4b004202, 0x1d221f02, 0x66002e14,   // gl.sw.fr_655 mt.az..._220 ga.tr.hr_222 sq.af..._660
  0x456602a4, 0x27023f02, 0x250e2312, 0x12451614,   // da.af.sk_433 sw.da.id_222 uk.ru.mk_654 lt.sk.cs_666
  // [39b0]
  0x8c003a23, 0x02001f09, 0x66002e23, 0x1a014509,   // eu.ht..._880 ga.da..._440 sq.af..._880 sk.en.xxx_444
  0x40002e22, 0x18002b09, 0x662b0c14, 0x8c292713,   // sq.sl..._870 cy.hu..._440 pl.cy.af_666 id.ms.ht_665
  0x160d4509, 0x66004002, 0x010c4209, 0x45160302,   // sk.pt.lt_444 sl.af..._220 mt.pl.en_444 nl.lt.sk_222
  0x29272b14, 0x660c0107, 0x06004b08, 0x15000b14,   // cy.id.ms_666 en.pl.af_432 az.de..._430 no.lv..._660
  // [39c0]
  0x22100b60, 0x19002b14, 0x29040202, 0x660d2102,   // no.sv.tr_664 cy.et..._660 da.fi.ms_222 tl.pt.af_222
  0x02191809, 0x3f1d1e08, 0x1e1d3fa4, 0x3f1e1d08,   // hu.et.da_444 sr.hr.sw_443 sw.hr.sr_433 hr.sr.sw_443
  0x1d081e09, 0x03216609, 0x170f0d12, 0x100d4009,   // sr.it.hr_444 af.tl.nl_444 pt.es.ro_654 sl.pt.sv_444
  0x061d4008, 0x29450107, 0x08002708, 0x17100308,   // sl.hr.de_443 en.sk.ms_432 id.it..._430 nl.sv.ro_443
  // [39d0]
  0x1d104502, 0x0b141014, 0x15003f12, 0x050116a4,   // sk.sv.hr_222 sv.is.no_666 sw.lv..._640 lt.en.fr_433
  0x042e2b09, 0x12000808, 0x664521a4, 0x04193f13,   // cy.sq.fi_444 it.cs..._430 tl.sk.af_433 sw.et.fi_665
  0x18002122, 0x22064b12, 0x271f0f02, 0x01002022,   // tl.hu..._870 az.de.tr_654 es.ga.id_222 gl.en..._870
  0x04190b09, 0x170d1f60, 0x21000608, 0x15001607,   // no.et.fi_444 ga.pt.ro_664 de.tl..._430 lt.lv..._420
  // [39e0]
  0x12451a13, 0x04061060, 0x0c001d02, 0x152e8ca4,   // xxx.sk.cs_665 sv.de.fi_664 hr.pl..._220 ht.sq.lv_433
  0x27210108, 0x2e0d0f13, 0x18000107, 0x40000502,   // en.tl.id_443 es.pt.sq_665 en.hu..._420 fr.sl..._220
  0x050408a4, 0x451602a4, 0x16200109, 0x14001a23,   // it.fi.fr_433 da.lt.sk_433 en.gl.lt_444 xxx.is..._880
  0x17080d12, 0x10004b08, 0x1f292760, 0x16001802,   // pt.it.ro_654 az.sv..._430 id.ms.ga_664 hu.lt..._220
  // [39f0]
  0x292e4b02, 0x01000407, 0x4b001421, 0x66001608,   // az.sq.ms_222 fi.en..._420 is.az..._860 lt.af..._430
  0x18450809, 0x08000c13, 0x45150f08, 0x8c056608,   // it.sk.hu_444 pl.it..._650 es.lv.sk_443 af.fr.ht_443
  0x45151207, 0x45000f13, 0x15001812, 0x21004214,   // cs.lv.sk_432 es.sk..._650 hu.lv..._640 mt.tl..._660
  0x422b2108, 0x42002122, 0x21004223, 0x66001a22,   // tl.cy.mt_443 tl.mt..._870 mt.tl..._880 xxx.af..._870
  // [3a00]
  0x433a3808, 0x0c214214, 0x1e006614, 0x1e1d0107,   // ca.eu.vi_443 mt.tl.pl_666 af.sr..._660 en.hr.sr_432
  0x05001409, 0x66001f02, 0x0b661013, 0x02452b08,   // is.fr..._440 ga.af..._220 sv.af.no_665 cy.sk.da_443
  0x17380114, 0x05188c08, 0x0f000512, 0x18450d07,   // en.ca.ro_666 ht.hu.fr_443 fr.es..._640 pt.sk.hu_432
  0x041f3f12, 0x18004008, 0x21001823, 0x042719a4,   // sw.ga.fi_654 sl.hu..._430 hu.tl..._880 et.id.fi_433
  // [3a10]
  0x45140d12, 0x17380d14, 0x8c001714, 0x38002e02,   // pt.is.sk_654 pt.ca.ro_666 ro.ht..._660 sq.ca..._220
  0x0d001414, 0x0f001722, 0x03000413, 0x4b0d2255,   // is.pt..._660 ro.es..._870 fi.nl..._650 tr.pt.az_442
  0x290d2e02, 0x38003a07, 0x10020109, 0x27003a08,   // sq.pt.ms_222 eu.ca..._420 en.da.sv_444 eu.id..._430
  0x0c061a07, 0x024512a4, 0x45430107, 0x45001713,   // xxx.de.pl_432 cs.sk.da_433 en.vi.sk_432 ro.sk..._650
  // [3a20]
  0x1d1e0b02, 0x450d0502, 0x3a001812, 0x14001011,   // no.sr.hr_222 fr.pt.sk_222 hu.eu..._640 sv.is..._630
  0x16190409, 0x21001423, 0x290c2b02, 0x451d1a07,   // fi.et.lt_444 is.tl..._880 cy.pl.ms_222 xxx.hr.sk_432
  0x08001422, 0x1a273f07, 0x041940a4, 0x451e2907,   // is.it..._870 sw.id.xxx_432 sl.et.fi_433 ms.sr.sk_432
  0x03023fa4, 0x4b221012, 0x1f002013, 0x12430802,   // sw.da.nl_433 sv.tr.az_654 gl.ga..._650 it.vi.cs_222
  // [3a30]
  0x21001f08, 0x0f140b07, 0x0f080107, 0x3a004513,   // ga.tl..._430 no.is.es_432 en.it.es_432 sk.eu..._650
  0x1e020b09, 0x2b004b13, 0x122b4514, 0x45060202,   // no.da.sr_444 az.cy..._650 sk.cy.cs_666 da.de.sk_222
  0x3a2e1a07, 0x12002709, 0x29081a55, 0x03001d23,   // xxx.sq.eu_432 id.cs..._440 xxx.it.ms_442 hr.nl..._880
  0x06050108, 0x17453fa4, 0x16033aa4, 0x45163f02,   // en.fr.de_443 sw.sk.ro_433 eu.nl.lt_433 sw.lt.sk_222
  // [3a40]
  0x3a150f09, 0x2e000d14, 0x1a000c23, 0x1f001212,   // es.lv.eu_444 pt.sq..._660 pl.xxx..._880 cs.ga..._640
  0x21000c13, 0x030f2b08, 0x15000421, 0x0c008c21,   // pl.tl..._650 cy.es.nl_443 fi.lv..._860 ht.pl..._860
  0x0e1e1c08, 0x0d006609, 0x0d081a12, 0x06292709,   // bg.sr.ru_443 af.pt..._440 xxx.it.pt_654 id.ms.de_444
  0x298c0402, 0x3a001a07, 0x0d004012, 0x032e0b09,   // fi.ht.ms_222 xxx.eu..._420 sl.pt..._640 no.sq.nl_444
  // [3a50]
  0x01421f08, 0x0e1e1c12, 0x0f0d2ba4, 0x16001812,   // ga.mt.en_443 bg.sr.ru_654 cy.pt.es_433 hu.lt..._640
  0x19000822, 0x0f2b0c08, 0x0d381708, 0x12451611,   // it.et..._870 pl.cy.es_443 ro.ca.pt_443 lt.sk.cs_653
  0x051706a4, 0x121e1d13, 0x03001912, 0x0c8c2108,   // de.ro.fr_433 hr.sr.cs_665 et.nl..._640 tl.ht.pl_443
  0x290d3802, 0x1c233007, 0x08004521, 0x0e251e09,   // ca.pt.ms_222 be.uk.bg_432 sk.it..._860 sr.mk.ru_444
  // [3a60]
  0x03016609, 0x0e1c1ea4, 0x45180c07, 0x45180cad,   // af.en.nl_444 sr.bg.ru_433 pl.hu.sk_432 pl.hu.sk_643
  0x8c001a13, 0x42041912, 0x29273a12, 0x66030ca4,   // xxx.ht..._650 et.fi.mt_654 eu.id.ms_654 pl.nl.af_433
  0x66032708, 0x451d1602, 0x191d1e13, 0x06004011,   // id.nl.af_443 lt.hr.sk_222 sr.hr.et_665 sl.de..._630
  0x0f001408, 0x272915a4, 0x10291908, 0x450d0f08,   // is.es..._430 lv.ms.id_433 et.ms.sv_443 es.pt.sk_443
  // [3a70]
  0x18221608, 0x12150308, 0x16221507, 0x0d002221,   // lt.tr.hu_443 nl.lv.cs_443 lv.tr.lt_432 tr.pt..._860
  0x3f001523, 0x180d0f07, 0x0f380d14, 0x19001814,   // lv.sw..._880 es.pt.hu_432 pt.ca.es_666 hu.et..._660
  0x42002e22, 0x06041007, 0x40002223, 0x150366af,   // sq.mt..._870 sv.fi.de_432 tr.sl..._880 af.nl.lv_655
  0x224b2960, 0x011705af, 0x0f0d1f09, 0x42000d22,   // ms.az.tr_664 fr.ro.en_655 ga.pt.es_444 pt.mt..._870
  // [3a80]
  0x14001a13, 0x4b228c08, 0x06193aa4, 0x12453faf,   // xxx.is..._650 ht.tr.az_443 eu.et.de_433 sw.sk.cs_655
  0x450f1408, 0x05004212, 0x4b3a1912, 0x19180455,   // is.es.sk_443 mt.fr..._640 et.eu.az_654 fi.hu.et_442
  0x17004312, 0x45032702, 0x191e1d09, 0x02003f08,   // vi.ro..._640 id.nl.sk_222 hr.sr.et_444 sw.da..._430
  0x040b1908, 0x17001607, 0x291e2702, 0x420b0107,   // et.no.fi_443 lt.ro..._420 id.sr.ms_222 en.no.mt_432
  // [3a90]
  0x06002921, 0x10020609, 0x06002023, 0x3a000f11,   // ms.de..._860 de.da.sv_444 gl.de..._880 es.eu..._630
  0x02101aa4, 0x273f0b07, 0x10001a13, 0x1d190402,   // xxx.sv.da_433 no.sw.id_432 xxx.sv..._650 fi.et.hr_222
  0x21293a12, 0x02292108, 0x2e000f02, 0x0d000412,   // eu.ms.tl_654 tl.ms.da_443 es.sq..._220 fi.pt..._640
  0x3f101608, 0x0d003822, 0x1d086602, 0x0b140212,   // lt.sv.sw_443 ca.pt..._870 af.it.hr_222 da.is.no_654
  // [3aa0]
  0x15060b07, 0x03002708, 0x1e0103a4, 0x18001e12,   // no.de.lv_432 id.nl..._430 nl.en.sr_433 sr.hu..._640
  0x10040612, 0x1d3f2908, 0x2e001f12, 0x29004b09,   // de.fi.sv_654 ms.sw.hr_443 ga.sq..._640 az.ms..._440
  0x27214b02, 0x22214b09, 0x1e041d02, 0x02102108,   // az.tl.id_222 az.tl.tr_444 hr.fi.sr_222 tl.sv.da_443
  0x29274508, 0x451f2109, 0x45170109, 0x16083a08,   // sk.id.ms_443 tl.ga.sk_444 en.ro.sk_444 eu.it.lt_443
  // [3ab0]
  0x05014209, 0x1c0e2560, 0x66002122, 0x163a1712,   // mt.en.fr_444 mk.ru.bg_664 tl.af..._870 ro.eu.lt_654
  0x10190208, 0x163f0807, 0x15454008, 0x19148c09,   // da.et.sv_443 it.sw.lt_432 sl.sk.lv_443 ht.is.et_444
  0x03002e10, 0x121a4508, 0x1d001612, 0x1e0c0107,   // sq.nl..._620 sk.xxx.cs_443 lt.hr..._640 en.pl.sr_432
  0x43000413, 0x384b2208, 0x011a4b08, 0x45002214,   // fi.vi..._650 tr.az.ca_443 az.xxx.en_443 tr.sk..._660
  // [3ac0]
  0x30251c60, 0x151f29a4, 0x43080455, 0x04004b13,   // bg.mk.be_664 ms.ga.lv_433 fi.it.vi_442 az.fi..._650
  0x0b0f06af, 0x42080d12, 0x18000423, 0x08063802,   // de.es.no_655 pt.it.mt_654 fi.hu..._880 ca.de.it_222
  0x05003a09, 0x066603af, 0x03020b12, 0x29451209,   // eu.fr..._440 nl.af.de_655 no.da.nl_654 cs.sk.ms_444
  0x0f0d1507, 0x18081608, 0x16003f13, 0x451d0b07,   // lv.pt.es_432 lt.it.hu_443 sw.lt..._650 no.hr.sk_432
  // [3ad0]
  0x1a004308, 0x1a216612, 0x1e151602, 0x080d0f08,   // vi.xxx..._430 af.tl.xxx_654 lt.lv.sr_222 es.pt.it_443
  0x29001a13, 0x00001d2d, 0x45171002, 0x40001a08,   // xxx.ms..._650 hr......_A00 sv.ro.sk_222 xxx.sl..._430
  0x03001614, 0x45181207, 0x45180402, 0x03182708,   // lt.nl..._660 cs.hu.sk_432 fi.hu.sk_222 id.hu.nl_443
  0x66001f23, 0x66190b09, 0x06036655, 0x29182755,   // ga.af..._880 no.et.af_444 af.nl.de_442 id.hu.ms_442
  // [3ae0]
  0x453f1802, 0x2e2729af, 0x04000522, 0x1f000d22,   // hu.sw.sk_222 ms.id.sq_655 fr.fi..._870 pt.ga..._870
  0x0b100612, 0x043f2109, 0x1e401dad, 0x05000422,   // de.sv.no_654 tl.sw.fi_444 hr.sl.sr_643 fi.fr..._870
  0x1f000422, 0x040d4208, 0x21002e08, 0x15662107,   // fi.ga..._870 mt.pt.fi_443 sq.tl..._430 tl.af.lv_432
  0x06181002, 0x4b3f8c07, 0x4e333708, 0x2b000409,   // sv.hu.de_222 ht.sw.az_432 ar.ur.fa_443 fi.cy..._440
  // [3af0]
  0x431d4555, 0x19220607, 0x22041908, 0x0d001708,   // sk.hr.vi_442 de.tr.et_432 et.fi.tr_443 ro.pt..._430
  0x1e000d02, 0x212229a4, 0x080f3814, 0x101a3fa4,   // pt.sr..._220 ms.tr.tl_433 ca.es.it_666 sw.xxx.sv_433
  0x063829af, 0x1f660107, 0x19000d23, 0x1f001213,   // ms.ca.de_655 en.af.ga_432 pt.et..._880 cs.ga..._650
  0x422b10a4, 0x15140612, 0x0f4b1f12, 0x0f00180d,   // sv.cy.mt_433 de.is.lv_654 ga.az.es_654 hu.es..._540
  // [3b00]
  0x190d0fa4, 0x02061002, 0x18100608, 0x4b0622a4,   // es.pt.et_433 sv.de.da_222 de.sv.hu_443 tr.de.az_433
  0x251e3009, 0x19140260, 0x2b040da4, 0x02100107,   // be.sr.mk_444 da.is.et_664 pt.fi.cy_433 en.sv.da_432
  0x14010b07, 0x66000b07, 0x04001a12, 0x4b660b09,   // no.en.is_432 no.af..._420 xxx.fi..._640 no.af.az_444
  0x401218a4, 0x27001002, 0x036606af, 0x10002723,   // hu.cs.sl_433 sv.id..._220 de.af.nl_655 id.sv..._880
  // [3b10]
  0x18122ea4, 0x40038c13, 0x66221aa4, 0x1d1e1402,   // sq.cs.hu_433 ht.nl.sl_665 xxx.tr.af_433 is.sr.hr_222
  0x8c003f21, 0x15002112, 0x0f380808, 0x224b2e12,   // sw.ht..._860 tl.lv..._640 it.ca.es_443 sq.az.tr_654
  0x38000d22, 0x3f8c4207, 0x1e002321, 0x16001421,   // pt.ca..._870 mt.ht.sw_432 uk.sr..._860 is.lt..._860
  0x2e002208, 0x15004509, 0x153f19af, 0x0d0f1f12,   // tr.sq..._430 sk.lv..._440 et.sw.lv_655 ga.es.pt_654
  // [3b20]
  0x4b000808, 0x29211502, 0x01662b12, 0x29270b09,   // it.az..._430 lv.tl.ms_222 cy.af.en_654 no.id.ms_444
  0x8c222113, 0x02008c08, 0x1d1f1e02, 0x17002208,   // tl.tr.ht_665 ht.da..._430 sr.ga.hr_222 tr.ro..._430
  0x27382102, 0x27290602, 0x050d0b07, 0x0d380512,   // tl.ca.id_222 de.ms.id_222 no.pt.fr_432 fr.ca.pt_654
  0x141f0414, 0x293f2e08, 0x43002e11, 0x14450ba4,   // fi.ga.is_666 sq.sw.ms_443 sq.vi..._630 no.sk.is_433
  // [3b30]
  0x1f006609, 0x45013f55, 0x0b001613, 0x66060355,   // af.ga..._440 sw.en.sk_442 lt.no..._650 nl.de.af_442
  0x1f140f13, 0x04002b07, 0x0d001411, 0x27008c12,   // es.is.ga_665 cy.fi..._420 is.pt..._630 ht.id..._640
  0x102b1608, 0x044b2207, 0x05001623, 0x16000514,   // lt.cy.sv_443 tr.az.fi_432 lt.fr..._880 fr.lt..._660
  0x12051812, 0x05001f23, 0x18141007, 0x022b6609,   // hu.fr.cs_654 ga.fr..._880 sv.is.hu_432 af.cy.da_444
  // [3b40]
  0x1f001623, 0x0b660308, 0x291f1402, 0x27298c02,   // lt.ga..._880 nl.af.no_443 is.ga.ms_222 ht.ms.id_222
  0x1e1d0b13, 0x1f000814, 0x45141212, 0x0b050f09,   // no.hr.sr_665 it.ga..._660 cs.is.sk_654 es.fr.no_444
  0x0b003823, 0x0b004209, 0x10004b23, 0x08170108,   // ca.no..._880 mt.no..._440 az.sv..._880 en.ro.it_443
  0x1f000314, 0x21001809, 0x0f0d1814, 0x1f002708,   // nl.ga..._660 hu.tl..._440 hu.pt.es_666 id.ga..._430
  // [3b50]
  0x270421a4, 0x38200d12, 0x18141f14, 0x04272907,   // tl.fi.id_433 pt.gl.ca_654 ga.is.hu_666 ms.id.fi_432
  0x27451002, 0x451812ad, 0x04183807, 0x0f001f23,   // sv.sk.id_222 cs.hu.sk_643 ca.hu.fi_432 ga.es..._880
  0x0c001511, 0x27046602, 0x8c001a22, 0x0c161512,   // lv.pl..._630 af.fi.id_222 xxx.ht..._870 lv.lt.pl_654
  0x4b271860, 0x0f003f09, 0x45121f09, 0x06001811,   // hu.id.az_664 sw.es..._440 ga.cs.sk_444 hu.de..._630
  // [3b60]
  0x0c150f07, 0x43002b07, 0x15000214, 0x14060b07,   // es.lv.pl_432 cy.vi..._420 da.lv..._660 no.de.is_432
  0x224b2160, 0x45150302, 0x12058c08, 0x0d0f0514,   // tl.az.tr_664 nl.lv.sk_222 ht.fr.cs_443 fr.es.pt_666
  0x16151907, 0x1d194212, 0x1f004b02, 0x1d0142a4,   // et.lv.lt_432 mt.et.hr_654 az.ga..._220 mt.en.hr_433
  0x1d382b02, 0x290f8c02, 0x2e004007, 0x18060302,   // cy.ca.hr_222 ht.es.ms_222 sl.sq..._420 nl.de.hu_222
  // [3b70]
  0x42001d13, 0x04456612, 0x053f8c08, 0x1d051e02,   // hr.mt..._650 af.sk.fi_654 ht.sw.fr_443 sr.fr.hr_222
  0x05384212, 0x3a0817a4, 0x10003a14, 0x0d0f2012,   // mt.ca.fr_654 ro.it.eu_433 eu.sv..._660 gl.es.pt_654
  0x16003a22, 0x064b4208, 0x08001707, 0x21000f23,   // eu.lt..._870 mt.az.de_443 ro.it..._420 es.tl..._880
  0x04002223, 0x12450faf, 0x173a05a4, 0x0d050f09,   // tr.fi..._880 es.sk.cs_655 fr.eu.ro_433 es.fr.pt_444
  // [3b80]
  0x12452702, 0x450f1702, 0x2e4b2211, 0x45124060,   // id.sk.cs_222 ro.es.sk_222 tr.az.sq_653 sl.cs.sk_664
  0x191d0455, 0x15221912, 0x02664008, 0x0f1f0d09,   // fi.hr.et_442 et.tr.lv_654 sl.af.da_443 pt.ga.es_444
  0x23251c60, 0x0d3f3a09, 0x10194260, 0x1e0e1c12,   // bg.mk.uk_664 eu.sw.pt_444 mt.et.sv_664 bg.ru.sr_654
  0x10004b09, 0x2b003f21, 0x29010502, 0x4b102108,   // az.sv..._440 sw.cy..._860 fr.en.ms_222 tl.sv.az_443
  // [3b90]
  0x0d1806af, 0x141e1d60, 0x43000b02, 0x451002a4,   // de.hu.pt_655 hr.sr.is_664 no.vi..._220 da.sv.sk_433
  0x30001e21, 0x2e001d14, 0x3a003821, 0x1e101d02,   // sr.be..._860 hr.sq..._660 ca.eu..._860 hr.sv.sr_222
  0x22000d12, 0x192e0413, 0x19100614, 0x301c23af,   // pt.tr..._640 fi.sq.et_665 de.sv.et_666 uk.bg.be_655
  0x40190460, 0x1a3f2708, 0x1a218c08, 0x16002707,   // fi.et.sl_664 id.sw.xxx_443 ht.tl.xxx_443 id.lt..._420
  // [3ba0]
  0x0c1a2709, 0x3f291912, 0x16211507, 0x0f191509,   // id.xxx.pl_444 et.ms.sw_654 lv.tl.lt_432 lv.et.es_444
  0x05290faf, 0x01004009, 0x0d0f0812, 0x38062108,   // es.ms.fr_655 sl.en..._440 it.es.pt_654 tl.de.ca_443
  0x183f1960, 0x38001823, 0x05000b23, 0x66423a12,   // et.sw.hu_664 hu.ca..._880 no.fr..._880 eu.mt.af_654
  0x3a1f0daf, 0x1e8c2e02, 0x43060107, 0x43000b07,   // pt.ga.eu_655 sq.ht.sr_222 en.de.vi_432 no.vi..._420
  // [3bb0]
  0x0d001a02, 0x14100baf, 0x1d153a07, 0x2b002113,   // xxx.pt..._220 no.sv.is_655 eu.lv.hr_432 tl.cy..._650
  0x0d276608, 0x29182102, 0x0d003a11, 0x04008c09,   // af.id.pt_443 tl.hu.ms_222 eu.pt..._630 ht.fi..._440
  0x40002913, 0x18273811, 0x1f170d55, 0x17001608,   // ms.sl..._650 ca.id.hu_653 pt.ro.ga_442 lt.ro..._430
  0x22102708, 0x14151909, 0x1d164008, 0x278c3a09,   // id.sv.tr_443 et.lv.is_444 sl.lt.hr_443 eu.ht.id_444
  // [3bc0]
  0x4b292212, 0x10292708, 0x08201207, 0x3a002212,   // tr.ms.az_654 id.ms.sv_443 cs.gl.it_432 tr.eu..._640
  0x16041708, 0x1f003823, 0x17001422, 0x1f060b09,   // ro.fi.lt_443 ca.ga..._880 is.ro..._870 no.de.ga_444
  0x14430f08, 0x16001423, 0x3a002722, 0x030142a4,   // es.vi.is_443 is.lt..._880 id.eu..._870 mt.en.nl_433
  0x04160faf, 0x402b06a4, 0x43000f12, 0x0c002707,   // es.lt.fi_655 de.cy.sl_433 es.vi..._640 id.pl..._420
  // [3bd0]
  0x38058c09, 0x42002908, 0x2e014502, 0x3f211a12,   // ht.fr.ca_444 ms.mt..._430 sk.en.sq_222 xxx.tl.sw_654
  0x103f3807, 0x17083a09, 0x01051408, 0x45163808,   // ca.sw.sv_432 eu.it.ro_444 is.fr.en_443 ca.lt.sk_443
  0x0d200f60, 0x05002e14, 0x010604a4, 0x0f220302,   // es.gl.pt_664 sq.fr..._660 fi.de.en_433 nl.tr.es_222
  0x08024208, 0x19000814, 0x17100b07, 0x17451202,   // mt.da.it_443 it.et..._660 no.sv.ro_432 cs.sk.ro_222
  // [3be0]
  0x1f0f0d08, 0x29041911, 0x66030209, 0x29270402,   // pt.es.ga_443 et.fi.ms_653 da.nl.af_444 fi.id.ms_222
  0x29001209, 0x25001c21, 0x3f292b12, 0x38002214,   // cs.ms..._440 bg.mk..._860 cy.ms.sw_654 tr.ca..._660
  0x27052909, 0x21001d14, 0x2e000513, 0x01171a12,   // ms.fr.id_444 hr.tl..._660 fr.sq..._650 xxx.ro.en_654
  0x15000607, 0x2e1d1e02, 0x1c1e0eaf, 0x12002b09,   // de.lv..._420 sr.hr.sq_222 ru.sr.bg_655 cy.cs..._440
  // [3bf0]
  0x300e1c09, 0x0c1245af, 0x172e3a08, 0x0d022708,   // bg.ru.be_444 sk.cs.pl_655 eu.sq.ro_443 id.da.pt_443
  0x293a0602, 0x03003802, 0x083f0faf, 0x3a292713,   // de.eu.ms_222 ca.nl..._220 es.sw.it_655 id.ms.eu_665
  0x45001512, 0x450c3a07, 0x08003f08, 0x0f011a09,   // lv.sk..._640 eu.pl.sk_432 sw.it..._430 xxx.en.es_444
  0x1d151e14, 0x2e273a08, 0x21270107, 0x190f1f08,   // sr.lv.hr_666 eu.id.sq_443 en.id.tl_432 ga.es.et_443

  // [3c00]
  0x0b000423, 0x8c000f13, 0x4b212213, 0x29222107,   // fi.no..._880 es.ht..._650 tr.tl.az_665 tl.tr.ms_432
  0x23251c07, 0x1c1e2511, 0x45051808, 0x0c1d2e09,   // bg.mk.uk_432 mk.sr.bg_653 hu.fr.sk_443 sq.hr.pl_444
  0x05001223, 0x08000f22, 0x2b003821, 0x17002b13,   // cs.fr..._880 es.it..._870 ca.cy..._860 cy.ro..._650
  0x0d001413, 0x45180fa4, 0x8c081708, 0x381f1209,   // is.pt..._650 es.hu.sk_433 ro.it.ht_443 cs.ga.ca_444
  // [3c10]
  0x1f141809, 0x38004207, 0x1e250e14, 0x8c272909,   // hu.is.ga_444 mt.ca..._420 ru.mk.sr_666 ms.id.ht_444
  0x15003f08, 0x20000402, 0x19151609, 0x29004208,   // sw.lv..._430 fi.gl..._220 lt.lv.et_444 mt.ms..._430
  0x15001202, 0x02211f08, 0x10001f02, 0x05000423,   // cs.lv..._220 ga.tl.da_443 ga.sv..._220 fi.fr..._880
  0x08001013, 0x1f004321, 0x10000d14, 0x1e1d2908,   // sv.it..._650 vi.ga..._860 pt.sv..._660 ms.hr.sr_443
  // [3c20]
  0x1e1d1a02, 0x8c004013, 0x42006614, 0x22000223,   // xxx.hr.sr_222 sl.ht..._650 af.mt..._660 da.tr..._880
  0x27001f13, 0x0b2b1f12, 0x0d384508, 0x0f002b12,   // ga.id..._650 ga.cy.no_654 sk.ca.pt_443 cy.es..._640
  0x180f1408, 0x15081a09, 0x17000b02, 0x380f0560,   // is.es.hu_443 xxx.it.lv_444 no.ro..._220 fr.es.ca_664
  0x0d004513, 0x088c3808, 0x17000f23, 0x0d453809,   // sk.pt..._650 ca.ht.it_443 es.ro..._880 ca.sk.pt_444
  // [3c30]
  0x0d0f18af, 0x42004b09, 0x101d1409, 0x380f1812,   // hu.es.pt_655 az.mt..._440 is.hr.sv_444 hu.es.ca_654
  0x1a0c3f07, 0x12452b08, 0x29000122, 0x2e002211,   // sw.pl.xxx_432 cy.sk.cs_443 en.ms..._870 tr.sq..._630
  0x05001614, 0x8c051707, 0x0d3f2e08, 0x160c1513,   // lt.fr..._660 ro.fr.ht_432 sq.sw.pt_443 lv.pl.lt_665
  0x450c1512, 0x0f200d14, 0x43000821, 0x010c2b09,   // lv.pl.sk_654 pt.gl.es_666 it.vi..._860 cy.pl.en_444
  // [3c40]
  0x66272ba4, 0x0b001912, 0x66181607, 0x12184512,   // cy.id.af_433 et.no..._640 lt.hu.af_432 sk.hu.cs_654
  0x01004508, 0x12451702, 0x45123809, 0x05040b07,   // sk.en..._430 ro.sk.cs_222 ca.cs.sk_444 no.fi.fr_432
  0x18226609, 0x19142b08, 0x213f8c08, 0x2b423a09,   // af.tr.hu_444 cy.is.et_443 ht.sw.tl_443 eu.mt.cy_444
  0x15100b07, 0x1a3f21a4, 0x29004223, 0x4b3f2707,   // no.sv.lv_432 tl.sw.xxx_433 mt.ms..._880 id.sw.az_432
  // [3c50]
  0x1e1d4209, 0x05088c08, 0x8c001514, 0x661808a4,   // mt.hr.sr_444 ht.it.fr_443 lv.ht..._660 it.hu.af_433
  0x14008c22, 0x0c164508, 0x0c000313, 0x8c001a14,   // ht.is..._870 sk.lt.pl_443 nl.pl..._650 xxx.ht..._660
  0x0b3f6608, 0x10006607, 0x3f0d0409, 0x27290413,   // af.sw.no_443 af.sv..._420 fi.pt.sw_444 fi.ms.id_665
  0x161e0109, 0x45101802, 0x17120208, 0x220b14af,   // en.sr.lt_444 hu.sv.sk_222 da.cs.ro_443 is.no.tr_655
  // [3c60]
  0x22001422, 0x45002e09, 0x42008c13, 0x161705a4,   // is.tr..._870 sq.sk..._440 ht.mt..._650 fr.ro.lt_433
  0x27001908, 0x050d04ab, 0x3f002b07, 0x163f27a4,   // et.id..._430 fi.pt.fr_621 cy.sw..._420 id.sw.lt_433
  0x19002b12, 0x19180607, 0x663f0308, 0x1e220c02,   // cy.et..._640 de.hu.et_432 nl.sw.af_443 pl.tr.sr_222
  0x42000c09, 0x0d001509, 0x3f218c08, 0x06003f08,   // pl.mt..._440 lv.pt..._440 ht.tl.sw_443 sw.de..._430
  // [3c70]
  0x1a001602, 0x27452b02, 0x1f100b12, 0x1f003808,   // lt.xxx..._220 cy.sk.id_222 no.sv.ga_654 ca.ga..._430
  0x45422902, 0x18004309, 0x45141811, 0x29212b02,   // ms.mt.sk_222 vi.hu..._440 hu.is.sk_653 cy.tl.ms_222
  0x140b1009, 0x14001623, 0x052e1aa4, 0x23001c21,   // sv.no.is_444 lt.is..._880 xxx.sq.fr_433 bg.uk..._860
  0x29660308, 0x14172212, 0x224b8c09, 0x19000b07,   // nl.af.ms_443 tr.ro.is_654 ht.az.tr_444 no.et..._420
  // [3c80]
  0x051a1fa4, 0x2b001d02, 0x2b381708, 0x21001509,   // ga.xxx.fr_433 hr.cy..._220 ro.ca.cy_443 lv.tl..._440
  0x3a0b2b12, 0x150c1814, 0x66060309, 0x22104309,   // cy.no.eu_654 hu.pl.lv_666 nl.de.af_444 vi.sv.tr_444
  0x0e1e1c60, 0x18000411, 0x18006623, 0x10022108,   // bg.sr.ru_664 fi.hu..._630 af.hu..._880 tl.da.sv_443
  0x2b0b0212, 0x38002b08, 0x3a1e1d08, 0x1e251c07,   // da.no.cy_654 cy.ca..._430 hr.sr.eu_443 bg.mk.sr_432
  // [3c90]
  0x2b8c05a4, 0x1f021708, 0x22000621, 0x053a0f08,   // fr.ht.cy_433 ro.da.ga_443 de.tr..._860 es.eu.fr_443
  0x29274302, 0x66170507, 0x160c3a12, 0x0f001f22,   // vi.id.ms_222 fr.ro.af_432 eu.pl.lt_654 ga.es..._870
  0x29000f13, 0x2e002014, 0x0c006623, 0x02000f02,   // es.ms..._650 gl.sq..._660 af.pl..._880 es.da..._220
  0x01000822, 0x124538af, 0x388c1702, 0x01000212,   // it.en..._870 ca.sk.cs_655 ro.ht.ca_222 da.en..._640
  // [3ca0]
  0x1d1a1e09, 0x38000807, 0x14400b09, 0x02006612,   // sr.xxx.hr_444 it.ca..._420 no.sl.is_444 af.da..._640
  0x27000502, 0x220d0f08, 0x121e1daf, 0x29162e08,   // fr.id..._220 es.pt.tr_443 hr.sr.cs_655 sq.lt.ms_443
  0x06101608, 0x0c036609, 0x221d1602, 0x23002520,   // lt.sv.de_443 af.nl.pl_444 lt.hr.tr_222 mk.uk..._850
  0x01060209, 0x4b008c08, 0x144b22a4, 0x1e300ea4,   // da.de.en_444 ht.az..._430 tr.az.is_433 ru.be.sr_433
  // [3cb0]
  0x100b1412, 0x02008c22, 0x40421207, 0x12060302,   // is.no.sv_654 ht.da..._870 cs.mt.sl_432 nl.de.cs_222
  0x1e0e1ca4, 0x4b3f2908, 0x272b3f12, 0x8c002107,   // bg.ru.sr_433 ms.sw.az_443 sw.cy.id_654 tl.ht..._420
  0x45000b23, 0x0f100202, 0x27001f12, 0x29382707,   // no.sk..._880 da.sv.es_222 ga.id..._640 id.ca.ms_432
  0x182927a4, 0x1d291702, 0x21002e14, 0x1c252307,   // id.ms.hu_433 ro.ms.hr_222 sq.tl..._660 uk.mk.bg_432
  // [3cc0]
  0x40124509, 0x29272202, 0x1f040107, 0x0c210107,   // sk.cs.sl_444 tr.id.ms_222 en.fi.ga_432 en.tl.pl_432
  0x14004014, 0x1d120302, 0x43002123, 0x2e1a0107,   // sl.is..._660 nl.cs.hr_222 tl.vi..._880 en.xxx.sq_432
  0x21432909, 0x01038c07, 0x43001922, 0x43292107,   // ms.vi.tl_444 ht.nl.en_432 et.vi..._870 tl.ms.vi_432
  0x45002b12, 0x19004309, 0x66000809, 0x2b002212,   // cy.sk..._640 vi.et..._440 it.af..._440 tr.cy..._640
  // [3cd0]
  0x42006621, 0x06183aaf, 0x21170107, 0x21001722,   // af.mt..._860 eu.hu.de_655 en.ro.tl_432 ro.tl..._870
  0x150f0d09, 0x100b0614, 0x0d000b14, 0x223810a4,   // pt.es.lv_444 de.no.sv_666 no.pt..._660 sv.ca.tr_433
  0x1c230e08, 0x45058c02, 0x161d1e08, 0x12002013,   // ru.uk.bg_443 ht.fr.sk_222 sr.hr.lt_443 gl.cs..._650
  0x0e233055, 0x27012902, 0x42292708, 0x011d2ba4,   // be.uk.ru_442 ms.en.id_222 id.ms.mt_443 cy.hr.en_433
  // [3ce0]
  0x05002213, 0x380f4b08, 0x251c3012, 0x2e420812,   // tr.fr..._650 az.es.ca_443 be.bg.mk_654 it.mt.sq_654
  0x14004509, 0x3f161712, 0x0c040baf, 0x16001712,   // sk.is..._440 ro.lt.sw_654 no.fi.pl_655 ro.lt..._640
  0x3a003822, 0x1d000b13, 0x27082e08, 0x380d2013,   // ca.eu..._870 no.hr..._650 sq.it.id_443 gl.pt.ca_665
  0x163f4509, 0x2e008c12, 0x043a3fa4, 0x124505af,   // sk.sw.lt_444 ht.sq..._640 sw.eu.fi_433 fr.sk.cs_655
  // [3cf0]
  0x1d006608, 0x03661f09, 0x0400051f, 0x12450512,   // af.hr..._430 ga.af.nl_444 fr.fi..._840 fr.sk.cs_654
  0x1a002212, 0x06021012, 0x66010309, 0x0f083807,   // tr.xxx..._640 sv.da.de_654 nl.en.af_444 ca.it.es_432
  0x40002707, 0x17388c09, 0x15003a23, 0x14001507,   // id.sl..._420 ht.ca.ro_444 eu.lv..._880 lv.is..._420
  0x04128ca4, 0x42000812, 0x22170109, 0x30251e07,   // ht.cs.fi_433 it.mt..._640 en.ro.tr_444 sr.mk.be_432
  // [3d00]
  0x0f1805a4, 0x42002108, 0x27012b12, 0x1f001521,   // fr.hu.es_433 tl.mt..._430 cy.en.id_654 lv.ga..._860
  0x21062709, 0x12012e02, 0x2b008c23, 0x14100b55,   // id.de.tl_444 sq.en.cs_222 ht.cy..._880 no.sv.is_442
  0x29432708, 0x3f001012, 0x03011a08, 0x3f450814,   // id.vi.ms_443 sv.sw..._640 xxx.en.nl_443 it.sk.sw_666
  0x45160c13, 0x43051a08, 0x3a1a3f08, 0x04084213,   // pl.lt.sk_665 xxx.fr.vi_443 sw.xxx.eu_443 mt.it.fi_665
  // [3d10]
  0x2b451f08, 0x40102707, 0x0b001214, 0x452b0202,   // ga.sk.cy_443 id.sv.sl_432 cs.no..._660 da.cy.sk_222
  0x45181211, 0x42001023, 0x27004013, 0x18273809,   // cs.hu.sk_653 sv.mt..._880 sl.id..._650 ca.id.hu_444
  0x21432709, 0x43002121, 0x43210109, 0x08001822,   // id.vi.tl_444 tl.vi..._860 en.tl.vi_444 hu.it..._870
  0x16003f07, 0x06084060, 0x2e000822, 0x66004314,   // sw.lt..._420 sl.it.de_664 it.sq..._870 vi.af..._660
  // [3d20]
  0x18002222, 0x08003f13, 0x452e0309, 0x01006613,   // tr.hu..._870 sw.it..._650 nl.sq.sk_444 af.en..._650
  0x04001d23, 0x08000f07, 0x2e0b0407, 0x8c200f08,   // hr.fi..._880 es.it..._420 fi.no.sq_432 es.gl.ht_443
  0x2e001812, 0x1e181d60, 0x182e1d08, 0x172e0514,   // hu.sq..._640 hr.hu.sr_664 hr.sq.hu_443 fr.sq.ro_666
  0x12054514, 0x38002114, 0x08423809, 0x120f0107,   // sk.fr.cs_666 tl.ca..._660 ca.mt.it_444 en.es.cs_432
  // [3d30]
  0x450c1e02, 0x0d220502, 0x29120107, 0x0d180faf,   // sr.pl.sk_222 fr.tr.pt_222 en.cs.ms_432 es.hu.pt_655
  0x12451509, 0x0f3a0812, 0x1a000523, 0x29001f13,   // lv.sk.cs_444 it.eu.es_654 fr.xxx..._880 ga.ms..._650
  0x22001722, 0x0f181409, 0x0f450d07, 0x0e3025a4,   // ro.tr..._870 is.hu.es_444 pt.sk.es_432 mk.be.ru_433
  0x18001920, 0x014505a4, 0x43000209, 0x011821a4,   // et.hu..._850 fr.sk.en_433 da.vi..._440 tl.hu.en_433
  // [3d40]
  0x20004514, 0x18450fa4, 0x4b008c21, 0x29001d23,   // sk.gl..._660 es.sk.hu_433 ht.az..._860 hr.ms..._880
  0x068c2108, 0x15000213, 0x42003814, 0x0f183a07,   // tl.ht.de_443 da.lv..._650 ca.mt..._660 eu.hu.es_432
  0x45004b07, 0x1d1e1902, 0x2b450b07, 0x2e000508,   // az.sk..._420 et.sr.hr_222 no.sk.cy_432 fr.sq..._430
  0x250e1ea4, 0x0f00431d, 0x4b004023, 0x06146608,   // sr.ru.mk_433 vi.es..._820 sl.az..._880 af.is.de_443
  // [3d50]
  0x4b008c14, 0x02002b12, 0x0b001608, 0x29043a02,   // ht.az..._660 cy.da..._640 lt.no..._430 eu.fi.ms_222
  0x4b000423, 0x04004b22, 0x18001022, 0x2b001f21,   // fi.az..._880 az.fi..._870 sv.hu..._870 ga.cy..._860
  0x10021913, 0x211e1d09, 0x17008c14, 0x0f0d0b09,   // et.da.sv_665 hr.sr.tl_444 ht.ro..._660 no.pt.es_444
  0x27001414, 0x0c4518ab, 0x27458c02, 0x40001508,   // is.id..._660 hu.sk.pl_621 ht.sk.id_222 lv.sl..._430
  // [3d60]
  0x1d161ea4, 0x43001e07, 0x250e2314, 0x3a002723,   // sr.lt.hr_433 sr.vi..._420 uk.ru.mk_666 id.eu..._880
  0x1e003011, 0x01052ba4, 0x1d001907, 0x66003a08,   // be.sr..._630 cy.fr.en_433 et.hr..._420 eu.af..._430
  0x66003a12, 0x3a036611, 0x27006613, 0x2b214212,   // eu.af..._640 af.nl.eu_653 af.id..._650 mt.tl.cy_654
  0x42180309, 0x3a006622, 0x0b1002a4, 0x0b008c13,   // nl.hu.mt_444 af.eu..._870 da.sv.no_433 ht.no..._650
  // [3d70]
  0x060314a4, 0x14124511, 0x1d122ea4, 0x211808a4,   // is.nl.de_433 sk.cs.is_653 sq.cs.hr_433 it.hu.tl_433
  0x0c151608, 0x1e002e08, 0x03451211, 0x06451a07,   // lt.lv.pl_443 sq.sr..._430 cs.sk.nl_653 xxx.sk.de_432
  0x01662107, 0x17194208, 0x08100b07, 0x2b0c6608,   // tl.af.en_432 mt.et.ro_443 no.sv.it_432 af.pl.cy_443
  0x061802a4, 0x04000508, 0x19042ba4, 0x1d004023,   // da.hu.de_433 fr.fi..._430 cy.fi.et_433 sl.hr..._880
  // [3d80]
  0x04011407, 0x03026609, 0x1d1e2212, 0x1e1d2208,   // is.en.fi_432 af.da.nl_444 tr.sr.hr_654 tr.hr.sr_443
  0x45141812, 0x1e1d22af, 0x27291a07, 0x291a0108,   // hu.is.sk_654 tr.hr.sr_655 xxx.ms.id_432 en.xxx.ms_443
  0x12194007, 0x2e001509, 0x1e1d1912, 0x0f003a11,   // sl.et.cs_432 lv.sq..._440 et.hr.sr_654 eu.es..._630
  0x1e170b07, 0x17001821, 0x45000412, 0x04021009,   // no.ro.sr_432 hu.ro..._860 fi.sk..._640 sv.da.fi_444
  // [3d90]
  0x10041407, 0x036619a4, 0x043a1913, 0x383a0f09,   // is.fi.sv_432 et.af.nl_433 et.eu.fi_665 es.eu.ca_444
  0x060b0209, 0x661f3fa4, 0x12380f02, 0x03188ca4,   // da.no.de_444 sw.ga.af_433 es.ca.cs_222 ht.hu.nl_433
  0x2b1f3812, 0x42000113, 0x19151708, 0x08003808,   // ca.ga.cy_654 en.mt..._650 ro.lv.et_443 ca.it..._430
  0x0f000402, 0x208c0109, 0x191404a4, 0x01064209,   // fi.es..._220 en.ht.gl_444 fi.is.et_433 mt.de.en_444
  // [3da0]
  0x1a194208, 0x8c000808, 0x29003a08, 0x66002014,   // mt.et.xxx_443 it.ht..._430 eu.ms..._430 gl.af..._660
  0x453a0312, 0x42002b02, 0x66003823, 0x10062eba,   // nl.eu.sk_654 cy.mt..._220 ca.af..._880 sq.de.sv_843
  0x27668c02, 0x45181209, 0x08001d08, 0x45140f02,   // ht.af.id_222 cs.hu.sk_444 hr.it..._430 es.is.sk_222
  0x17053802, 0x17053aa4, 0x02004223, 0x22001012,   // ca.fr.ro_222 eu.fr.ro_433 mt.da..._880 sv.tr..._640
  // [3db0]
  0x17013f08, 0x1c0e2311, 0x29081702, 0x29191002,   // sw.en.ro_443 uk.ru.bg_653 ro.it.ms_222 sv.et.ms_222
  0x06001021, 0x181f45af, 0x45181f12, 0x290f0d02,   // sv.de..._860 sk.ga.hu_655 ga.hu.sk_654 pt.es.ms_222
  0x10222b08, 0x0f141860, 0x0d380faf, 0x2b040107,   // cy.tr.sv_443 hu.is.es_664 es.ca.pt_655 en.fi.cy_432
  0x1d1e2907, 0x1a272908, 0x0c2b6608, 0x12452b02,   // ms.sr.hr_432 ms.id.xxx_443 af.cy.pl_443 cy.sk.cs_222
  // [3dc0]
  0x03004009, 0x05451209, 0x0f000412, 0x15161707,   // sl.nl..._440 cs.sk.fr_444 fi.es..._640 ro.lt.lv_432
  0x450810a4, 0x29662708, 0x171f2260, 0x030f0508,   // sv.it.sk_433 id.af.ms_443 tr.ga.ro_664 fr.es.nl_443
  0x01038ca4, 0x29454002, 0x02220b09, 0x084b2212,   // ht.nl.en_433 sl.sk.ms_222 no.tr.da_444 tr.az.it_654
  0x08001913, 0x33003722, 0x4b001802, 0x45381260,   // et.it..._650 ar.ur..._870 hu.az..._220 cs.ca.sk_664
  // [3dd0]
  0x0c000f13, 0x032b2909, 0x0b001412, 0x0c001808,   // es.pl..._650 ms.cy.nl_444 is.no..._640 hu.pl..._430
  0x4b001408, 0x100c02a4, 0x1f014008, 0x020c1008,   // is.az..._430 da.pl.sv_433 sl.en.ga_443 sv.pl.da_443
  0x450c1d02, 0x10181412, 0x14020655, 0x101242a4,   // hr.pl.sk_222 is.hu.sv_654 de.da.is_442 mt.cs.sv_433
  0x0c000f02, 0x22401209, 0x1d421602, 0x381f0f08,   // es.pl..._220 cs.sl.tr_444 lt.mt.hr_222 es.ga.ca_443
  // [3de0]
  0x3f1e1d09, 0x274329af, 0x1a2e3a08, 0x3f224b13,   // hr.sr.sw_444 ms.vi.id_655 eu.sq.xxx_443 az.tr.sw_665
  0x08128c02, 0x3f002221, 0x0b140209, 0x08380d13,   // ht.cs.it_222 tr.sw..._860 da.is.no_444 pt.ca.it_665
  0x8c000c02, 0x3f060113, 0x05002002, 0x0d000402,   // pl.ht..._220 en.de.sw_665 gl.fr..._220 fi.pt..._220
  0x153f21a4, 0x15193a07, 0x0f001712, 0x29173f02,   // tl.sw.lv_433 eu.et.lv_432 ro.es..._640 sw.ro.ms_222
  // [3df0]
  0x05001802, 0x45431214, 0x02431f12, 0x153f1608,   // hu.fr..._220 cs.vi.sk_666 ga.vi.da_654 lt.sw.lv_443
  0x29000b14, 0x02030109, 0x1f000f13, 0x40660b07,   // no.ms..._660 en.nl.da_444 es.ga..._650 no.af.sl_432
  0x29002e09, 0x03001209, 0x1d4b1602, 0x060c0b07,   // sq.ms..._440 cs.nl..._440 lt.az.hr_222 no.pl.de_432
  0x45661002, 0x06011a02, 0x161d1e02, 0x030666a4,   // sv.af.sk_222 xxx.en.de_222 sr.hr.lt_222 af.de.nl_433
  // [3e00]
  0x384b8c09, 0x1f003a12, 0x2e163a14, 0x15161460,   // ht.az.ca_444 eu.ga..._640 eu.lt.sq_666 is.lt.lv_664
  0x02002b14, 0x2e2b6612, 0x40002202, 0x04002b08,   // cy.da..._660 af.cy.sq_654 tr.sl..._220 cy.fi..._430
  0x08001621, 0x27291f13, 0x1e001214, 0x8c003a22,   // lt.it..._860 ga.ms.id_665 cs.sr..._660 eu.ht..._870
  0x10000512, 0x1e2330a4, 0x21001913, 0x27294208,   // fr.sv..._640 be.uk.sr_433 et.tl..._650 mt.ms.id_443
  // [3e10]
  0x3f000b07, 0x18004011, 0x1a1e1d60, 0x27182109,   // no.sw..._420 sl.hu..._630 hr.sr.xxx_664 tl.hu.id_444
  0x251c2311, 0x080f3807, 0x0f0d1011, 0x0f000813,   // uk.bg.mk_653 ca.es.it_432 sv.pt.es_653 it.es..._650
  0x18000823, 0x1a030412, 0x03066611, 0x3a380612,   // it.hu..._880 fi.nl.xxx_654 af.de.nl_653 de.ca.eu_654
  0x10003822, 0x21006613, 0x4b212209, 0x40000422,   // ca.sv..._870 af.tl..._650 tr.tl.az_444 fi.sl..._870
  // [3e20]
  0x0f150107, 0x19008c23, 0x38002e09, 0x198c0107,   // en.lv.es_432 ht.et..._880 sq.ca..._440 en.ht.et_432
  0x0b004b09, 0x04001d14, 0x0b003813, 0x1a002b23,   // az.no..._440 hr.fi..._660 ca.no..._650 cy.xxx..._880
  0x19000212, 0x431a4213, 0x290d0f02, 0x42080612,   // da.et..._640 mt.xxx.vi_665 es.pt.ms_222 de.it.mt_654
  0x231e3012, 0x15660208, 0x301c1e60, 0x29660202,   // be.sr.uk_654 da.af.lv_443 sr.bg.be_664 da.af.ms_222
  // [3e30]
  0x17380109, 0x66031209, 0x45141260, 0x0f002208,   // en.ca.ro_444 cs.nl.af_444 cs.is.sk_664 tr.es..._430
  0x43006623, 0x1d002b09, 0x151e1d60, 0x0f382013,   // af.vi..._880 cy.hr..._440 hr.sr.lv_664 gl.ca.es_665
  0x27290f08, 0x4b002123, 0x01053808, 0x19001622,   // es.ms.id_443 tl.az..._880 ca.fr.en_443 lt.et..._870
  0x3f2921a4, 0x29213a02, 0x42001812, 0x20160109,   // tl.ms.sw_433 eu.tl.ms_222 hu.mt..._640 en.lt.gl_444
  // [3e40]
  0x27011802, 0x43161aa4, 0x191a2707, 0x0c1f03a4,   // hu.en.id_222 xxx.lt.vi_433 id.xxx.et_432 nl.ga.pl_433
  0x29452b02, 0x19000313, 0x12001f12, 0x181f1002,   // cy.sk.ms_222 nl.et..._650 ga.cs..._640 sv.ga.hu_222
  0x01021055, 0x231c3012, 0x3a041a09, 0x1e302308,   // sv.da.en_442 be.bg.uk_654 xxx.fi.eu_444 uk.be.sr_443
  0x45170f08, 0x10140612, 0x00001442, 0x22180609,   // es.ro.sk_443 de.is.sv_654 is......_C00 de.hu.tr_444
  // [3e50]
  0x174b22af, 0x042b1912, 0x43003a23, 0x0f0d2013,   // tr.az.ro_655 et.cy.fi_654 eu.vi..._880 gl.pt.es_665
  0x4b001902, 0x1e100307, 0x38200109, 0x0d183a08,   // et.az..._220 nl.sv.sr_432 en.gl.ca_444 eu.hu.pt_443
  0x42082907, 0x1e002909, 0x21290108, 0x42000c02,   // ms.it.mt_432 ms.sr..._440 en.ms.tl_443 pl.mt..._220
  0x1d0c18a4, 0x1e302311, 0x66051808, 0x454b1a02,   // hu.pl.hr_433 uk.be.sr_653 hu.fr.af_443 xxx.az.sk_222
  // [3e60]
  0x0f452e07, 0x22004522, 0x04004023, 0x452e1209,   // sq.sk.es_432 sk.tr..._870 sl.fi..._880 cs.sq.sk_444
  0x42000c13, 0x451d2b02, 0x40008c23, 0x0c066609,   // pl.mt..._650 cy.hr.sk_222 ht.sl..._880 af.de.pl_444
  0x1e0e2307, 0x27222907, 0x0c6621a4, 0x011903a4,   // uk.ru.sr_432 ms.tr.id_432 tl.af.pl_433 nl.et.en_433
  0x3f004b23, 0x29190107, 0x061a3f02, 0x4b172214,   // az.sw..._880 en.et.ms_432 sw.xxx.de_222 tr.ro.az_666
  // [3e70]
  0x43001008, 0x12381a02, 0x38004321, 0x42002214,   // sv.vi..._430 xxx.ca.cs_222 vi.ca..._860 tr.mt..._660
  0x38021008, 0x03002209, 0x45000813, 0x23250ea4,   // sv.da.ca_443 tr.nl..._440 it.sk..._650 ru.mk.uk_433
  0x27011708, 0x3f001008, 0x01004308, 0x27222960,   // ro.en.id_443 sv.sw..._430 vi.en..._430 ms.tr.id_664
  0x30001c08, 0x8c272908, 0x8c004213, 0x290f0107,   // bg.be..._430 ms.id.ht_443 mt.ht..._650 en.es.ms_432
  // [3e80]
  0x17002014, 0x3a036612, 0x42004b07, 0x1c1e0e14,   // gl.ro..._660 af.nl.eu_654 az.mt..._420 ru.sr.bg_666
  0x3f224509, 0x451f1202, 0x180f3812, 0x0f451fa4,   // sk.tr.sw_444 cs.ga.sk_222 ca.es.hu_654 ga.sk.es_433
  0x08004313, 0x1d122102, 0x45382b02, 0x38438c12,   // vi.it..._650 tl.cs.hr_222 cy.ca.sk_222 ht.vi.ca_654
  0x041927a4, 0x1e301c08, 0x01452907, 0x1a000113,   // id.et.fi_433 bg.be.sr_443 ms.sk.en_432 en.xxx..._650
  // [3e90]
  0x23251c14, 0x22061007, 0x29408c02, 0x16190412,   // bg.mk.uk_666 sv.de.tr_432 ht.sl.ms_222 fi.et.lt_654
  0x29001613, 0x1f0c14ad, 0x3f000313, 0x17001512,   // lt.ms..._650 is.pl.ga_643 nl.sw..._650 lv.ro..._640
  0x40380f07, 0x16271513, 0x452b0107, 0x10161508,   // es.ca.sl_432 lv.id.lt_665 en.cy.sk_432 lv.lt.sv_443
  0x0d0f1612, 0x101516a4, 0x18000d22, 0x1d1e4055,   // lt.es.pt_654 lt.lv.sv_433 pt.hu..._870 sl.sr.hr_442
  // [3ea0]
  0x29001d02, 0x1e45125e, 0x06181007, 0x38000b14,   // hr.ms..._220 cs.sk.sr_652 sv.hu.de_432 no.ca..._660
  0x1e1d1213, 0x16001511, 0x041908a4, 0x0d180509,   // cs.hr.sr_665 lv.lt..._630 it.et.fi_433 fr.hu.pt_444
  0x16140b13, 0x1d048c02, 0x27291709, 0x2b003a13,   // no.is.lt_665 ht.fi.hr_222 ro.ms.id_444 eu.cy..._650
  0x2b004509, 0x4b000622, 0x8c001914, 0x04161f11,   // sk.cy..._440 de.az..._870 et.ht..._660 ga.lt.fi_653
  // [3eb0]
  0x1f006623, 0x1d044002, 0x20080f09, 0x21004008,   // af.ga..._880 sl.fi.hr_222 es.it.gl_444 sl.tl..._430
  0x19003821, 0x431d1aa4, 0x3f000613, 0x42000f08,   // ca.et..._860 xxx.hr.vi_433 de.sw..._650 es.mt..._430
  0x4b294212, 0x30250e13, 0x1d3f2e02, 0x291f2702,   // mt.ms.az_654 ru.mk.be_665 sq.sw.hr_222 id.ga.ms_222
  0x401d45a4, 0x380f08a4, 0x27170302, 0x08002222,   // sk.hr.sl_433 it.es.ca_433 nl.ro.id_222 tr.it..._870
  // [3ec0]
  0x040d0f08, 0x102b0b12, 0x19180609, 0x012b4202,   // es.pt.fi_443 no.cy.sv_654 de.hu.et_444 mt.cy.en_222
  0x45083aa4, 0x3f458c02, 0x453a4002, 0x66030b13,   // eu.it.sk_433 ht.sk.sw_222 sl.eu.sk_222 no.nl.af_665
  0x061f0ba4, 0x8c004202, 0x17000408, 0x0f001923,   // no.ga.de_433 mt.ht..._220 fi.ro..._430 et.es..._880
  0x04101913, 0x163f1f07, 0x66051913, 0x25230e07,   // et.sv.fi_665 ga.sw.lt_432 et.fr.af_665 ru.uk.mk_432
  // [3ed0]
  0x121d1e55, 0x1c302313, 0x0b000220, 0x14161508,   // sr.hr.cs_442 uk.be.bg_665 da.no..._850 lv.lt.is_443
  0x12402e02, 0x18000313, 0x250e23af, 0x19664507,   // sq.sl.cs_222 nl.hu..._650 uk.ru.mk_655 sk.af.et_432
  0x17001a13, 0x42224b13, 0x8c4b2113, 0x0d0f2709,   // xxx.ro..._650 az.tr.mt_665 tl.az.ht_665 id.es.pt_444
  0x42001402, 0x210d2060, 0x43000113, 0x03063a14,   // is.mt..._220 gl.pt.tl_664 en.vi..._650 eu.de.nl_666
  // [3ee0]
  0x8c000609, 0x2e001023, 0x3a004b13, 0x29103812,   // de.ht..._440 sv.sq..._880 az.eu..._650 ca.sv.ms_654
  0x291e1207, 0x05001f10, 0x0d220202, 0x041019af,   // cs.sr.ms_432 ga.fr..._620 da.tr.pt_222 et.sv.fi_655
  0x8c002112, 0x04292709, 0x12271a09, 0x1a000c08,   // tl.ht..._640 id.ms.fi_444 xxx.id.cs_444 pl.xxx..._430
  0x16011a08, 0x0f0d18af, 0x12450b08, 0x05003a13,   // xxx.en.lt_443 hu.pt.es_655 no.sk.cs_443 eu.fr..._650
  // [3ef0]
  0x0c0d45a4, 0x190204a4, 0x45001d22, 0x05000d21,   // sk.pt.pl_433 fi.da.et_433 hr.sk..._870 pt.fr..._860
  0x3f000b14, 0x1e081502, 0x0f0d0509, 0x1e003a09,   // no.sw..._660 lv.it.sr_222 fr.pt.es_444 eu.sr..._440
  0x421019a4, 0x03000c11, 0x3f451009, 0x4b006623,   // et.sv.mt_433 pl.nl..._630 sv.sk.sw_444 af.az..._880
  0x0c213f60, 0x20000b23, 0x180d0107, 0x231c1e08,   // sw.tl.pl_664 no.gl..._880 en.pt.hu_432 sr.bg.uk_443
  // [3f00]
  0x0c024302, 0x1d292760, 0x121d2e02, 0x3f062109,   // vi.da.pl_222 id.ms.hr_664 sq.hr.cs_222 tl.de.sw_444
  0x451614ad, 0x05001008, 0x14108ca4, 0x1f001e09,   // is.lt.sk_643 sv.fr..._430 ht.sv.is_433 sr.ga..._440
  0x1a214009, 0x1d0c1e55, 0x453f1a09, 0x21008c12,   // sl.tl.xxx_444 sr.pl.hr_442 xxx.sw.sk_444 ht.tl..._640
  0x3f036660, 0x05003a08, 0x18001a08, 0x06140109,   // af.nl.sw_664 eu.fr..._430 xxx.hu..._430 en.is.de_444
  // [3f10]
  0x2b010308, 0x18002209, 0x061910a4, 0x050d1821,   // nl.en.cy_443 tr.hu..._440 sv.et.de_433 hu.pt.fr_876
  0x042e16a4, 0x3a054555, 0x12456607, 0x013f1a07,   // lt.sq.fi_433 sk.fr.eu_442 af.sk.cs_432 xxx.sw.en_432
  0x2b182ea4, 0x02003a23, 0x12408c02, 0x29272baf,   // sq.hu.cy_433 eu.da..._880 ht.sl.cs_222 cy.id.ms_655
  0x0e1c3014, 0x011f8c08, 0x1d2e18a4, 0x29080102,   // be.bg.ru_666 ht.ga.en_443 hu.sq.hr_433 en.it.ms_222
  // [3f20]
  0x04008c07, 0x04660355, 0x1e1d4512, 0x0d081a08,   // ht.fi..._420 nl.af.fi_442 sk.hr.sr_654 xxx.it.pt_443
  0x292b2709, 0x300e2307, 0x18062255, 0x452e0b09,   // id.cy.ms_444 uk.ru.be_432 tr.de.hu_442 no.sq.sk_444
  0x2b0614af, 0x142b0660, 0x223f2909, 0x221806ac,   // is.de.cy_655 de.cy.is_664 ms.sw.tr_444 de.hu.tr_632
  0x0f1a2208, 0x06221814, 0x043f16ad, 0x2e001822,   // tr.xxx.es_443 hu.tr.de_666 lt.sw.fi_643 hu.sq..._870
  // [3f30]
  0x18272909, 0x170d0809, 0x18002220, 0x04168ca4,   // ms.id.hu_444 it.pt.ro_444 tr.hu..._850 ht.lt.fi_433
  0x020f1aa4, 0x19224bad, 0x190410a7, 0x03000212,   // xxx.es.da_433 az.tr.et_643 sv.fi.et_532 da.nl..._640
  0x12006608, 0x12001608, 0x03000113, 0x19100607,   // af.cs..._430 lt.cs..._430 en.nl..._650 de.sv.et_432
  0x10041960, 0x0e001e07, 0x02001f13, 0x4b2217af,   // et.fi.sv_664 sr.ru..._420 ga.da..._650 ro.tr.az_655
  // [3f40]
  0x453f1202, 0x03021707, 0x1d451e13, 0x38000822,   // cs.sw.sk_222 ro.da.nl_432 sr.sk.hr_665 it.ca..._870
  0x273f1a08, 0x18272908, 0x1e1d10a4, 0x291002a4,   // xxx.sw.id_443 ms.id.hu_443 sv.hr.sr_433 da.sv.ms_433
  0x1d3a1e02, 0x15004314, 0x04004309, 0x40004b12,   // sr.eu.hr_222 vi.lv..._660 vi.fi..._440 az.sl..._640
  0x0c272b08, 0x1d0c3f02, 0x1a154513, 0x272b0107,   // cy.id.pl_443 sw.pl.hr_222 sk.lv.xxx_665 en.cy.id_432
  // [3f50]
  0x0f3f05a4, 0x12451409, 0x05004513, 0x1d450b07,   // fr.sw.es_433 is.sk.cs_444 sk.fr..._650 no.sk.hr_432
  0x14181f14, 0x10000307, 0x450d1e02, 0x17001923,   // ga.hu.is_666 nl.sv..._420 sr.pt.sk_222 et.ro..._880
  0x8c380514, 0x10041912, 0x271d1e08, 0x45011f02,   // fr.ca.ht_666 et.fi.sv_654 sr.hr.id_443 ga.en.sk_222
  0x02101fa4, 0x1f000613, 0x45141214, 0x1d001514,   // ga.sv.da_433 de.ga..._650 cs.is.sk_666 lv.hr..._660
  // [3f60]
  0x1c302560, 0x0c003a08, 0x4b1f2260, 0x3f031f09,   // mk.be.bg_664 eu.pl..._430 tr.ga.az_664 ga.nl.sw_444
  0x15001809, 0x191a3fa4, 0x1d173f02, 0x04001822,   // hu.lv..._440 sw.xxx.et_433 sw.ro.hr_222 hu.fi..._870
  0x101e06a4, 0x02000423, 0x18008c08, 0x12004508,   // de.sr.sv_433 fi.da..._880 ht.hu..._430 sk.cs..._430
  0x2e1e1d12, 0x0f000511, 0x2e403f07, 0x29182709,   // hr.sr.sq_654 fr.es..._630 sw.sl.sq_432 id.hu.ms_444
  // [3f70]
  0x1d0f16a4, 0x38001913, 0x20030609, 0x08030608,   // lt.es.hr_433 et.ca..._650 de.nl.gl_444 de.nl.it_443
  0x08030612, 0x0b002707, 0x4b001609, 0x121a1602,   // de.nl.it_654 id.no..._420 lt.az..._440 lt.xxx.cs_222
  0x45031802, 0x45020507, 0x3f1f4212, 0x17004b14,   // hu.nl.sk_222 fr.da.sk_432 mt.ga.sw_654 az.ro..._660
  0x19002022, 0x453f1a02, 0x05001d09, 0x10400109,   // gl.et..._870 xxx.sw.sk_222 hr.fr..._440 en.sl.sv_444
  // [3f80]
  0x45181412, 0x66000b13, 0x0e1e2308, 0x1d1e1614,   // is.hu.sk_654 no.af..._650 uk.sr.ru_443 lt.sr.hr_666
  0x27001712, 0x42001722, 0x0c002014, 0x080c40a4,   // ro.id..._640 ro.mt..._870 gl.pl..._660 sl.pl.it_433
  0x14001522, 0x1e000e07, 0x05008c11, 0x1d3f1202,   // lv.is..._870 ru.sr..._420 ht.fr..._630 cs.sw.hr_222
  0x00004b15, 0x03002e08, 0x29403f08, 0x12000502,   // az......_700 sq.nl..._430 sw.sl.ms_443 fr.cs..._220
  // [3f90]
  0x140d0f08, 0x15664507, 0x0b450109, 0x3f001e14,   // es.pt.is_443 sk.af.lv_432 en.sk.no_444 sr.sw..._660
  0x18272914, 0x1d451612, 0x193f0455, 0x05002e13,   // ms.id.hu_666 lt.sk.hr_654 fi.sw.et_442 sq.fr..._650
  0x40003814, 0x0b001e09, 0x02124521, 0x40001813,   // ca.sl..._660 sr.no..._440 sk.cs.da_876 hu.sl..._650
  0x45001e23, 0x22140b09, 0x14451813, 0x1e451802,   // sr.sk..._880 no.is.tr_444 hu.sk.is_665 hu.sk.sr_222
  // [3fa0]
  0x2e061012, 0x38003f09, 0x2e141f55, 0x16451260,   // sv.de.sq_654 sw.ca..._440 ga.is.sq_442 cs.sk.lt_664
  0x3a001e09, 0x45290f02, 0x0f083802, 0x18003f08,   // sr.eu..._440 es.ms.sk_222 ca.it.es_222 sw.hu..._430
  0x17000c14, 0x42003808, 0x3f041509, 0x05061760,   // pl.ro..._660 ca.mt..._430 lv.fi.sw_444 ro.de.fr_664
  0x16000602, 0x2b000d23, 0x0f4520a4, 0x06176612,   // de.lt..._220 pt.cy..._880 gl.sk.es_433 af.ro.de_654
  // [3fb0]
  0x3f2166af, 0x1e300e09, 0x0d200109, 0x1e403a07,   // af.tl.sw_655 ru.be.sr_444 en.gl.pt_444 eu.sl.sr_432
  0x38002702, 0x0d450f07, 0x0c162908, 0x120c4002,   // id.ca..._220 es.sk.pt_432 ms.lt.pl_443 sl.pl.cs_222
  0x23301e08, 0x1c231e14, 0x4b212960, 0x17003808,   // sr.be.uk_443 sr.uk.bg_666 ms.tl.az_664 ca.ro..._430
  0x1d0c0107, 0x0d050b55, 0x14001923, 0x220f0109,   // en.pl.hr_432 no.fr.pt_442 et.is..._880 en.es.tr_444
  // [3fc0]
  0x14190b07, 0x0b191460, 0x19001022, 0x274b3a02,   // no.et.is_432 is.et.no_664 sv.et..._870 eu.az.id_222
  0x451f0107, 0x22001623, 0x08053808, 0x274b2208,   // en.ga.sk_432 lt.tr..._880 ca.fr.it_443 tr.az.id_443
  0x140b1909, 0x8c000607, 0x29004212, 0x02000808,   // et.no.is_444 de.ht..._420 mt.ms..._640 it.da..._430
  0x300e1c07, 0x3a2e4255, 0x0b001e02, 0x12001709,   // bg.ru.be_432 mt.sq.eu_442 sr.no..._220 ro.cs..._440
  // [3fd0]
  0x12180502, 0x3f154308, 0x272b2908, 0x38002907,   // fr.hu.cs_222 vi.lv.sw_443 ms.cy.id_443 ms.ca..._420
  0x43000f08, 0x43220f09, 0x66000509, 0x171f2b09,   // es.vi..._430 es.tr.vi_444 fr.af..._440 cy.ga.ro_444
  0x38401912, 0x15046602, 0x66273f07, 0x1a018ca4,   // et.sl.ca_654 af.fi.lv_222 sw.id.af_432 ht.en.xxx_433
  0x18041913, 0x18003a21, 0x45120d02, 0x45061802,   // et.fi.hu_665 eu.hu..._860 pt.cs.sk_222 hu.de.sk_222
  // [3fe0]
  0x1d3f3a02, 0x231c3008, 0x1d298c02, 0x1a004002,   // eu.sw.hr_222 be.bg.uk_443 ht.ms.hr_222 sl.xxx..._220
  0x1e1a1702, 0x160f1512, 0x3a000102, 0x21190109,   // ro.xxx.sr_222 lv.es.lt_654 en.eu..._220 en.et.tl_444
  0x1e252309, 0x1d221ea4, 0x17001813, 0x380d0560,   // uk.mk.sr_444 sr.tr.hr_433 hu.ro..._650 fr.pt.ca_664
  0x27292113, 0x3a001d23, 0x38004014, 0x22001d02,   // tl.ms.id_665 hr.eu..._880 sl.ca..._660 hr.tr..._220
  // [3ff0]
  0x8c403f07, 0x40004b23, 0x3f0c4202, 0x29103f02,   // sw.sl.ht_432 az.sl..._880 mt.pl.sw_222 sw.sv.ms_222
  0x211a19a4, 0x3a001d13, 0x1e0c1d08, 0x010c1008,   // et.xxx.tl_433 hr.eu..._650 hr.pl.sr_443 sv.pl.en_443
  0x06000122, 0x0b144213, 0x251e0ea4, 0x022e2109,   // en.de..._870 mt.is.no_665 ru.sr.mk_433 tl.sq.da_444
  0x45161802, 0x1f012108, 0x42293fa4, 0x190b1408,   // hu.lt.sk_222 tl.en.ga_443 sw.ms.mt_433 is.no.et_443

  // [4000]
  0x10142709, 0x43000d07, 0x12450c60, 0x17001423,   // id.is.sv_444 pt.vi..._420 pl.sk.cs_664 is.ro..._880
  0x0c2b1609, 0x0c004508, 0x0f3a3808, 0x1e2e1608,   // lt.cy.pl_444 sk.pl..._430 ca.eu.es_443 lt.sq.sr_443
  0x2e401608, 0x8c0d0109, 0x02050b08, 0x08050d08,   // lt.sl.sq_443 en.pt.ht_444 no.fr.da_443 pt.fr.it_443
  0x0b001702, 0x06140b08, 0x20380f14, 0x14451209,   // ro.no..._220 no.is.de_443 es.ca.gl_666 cs.sk.is_444
  // [4010]
  0x141f1208, 0x38001a14, 0x14000c14, 0x04183aa4,   // cs.ga.is_443 xxx.ca..._660 pl.is..._660 eu.hu.fi_433
  0x17224b12, 0x1d3f1908, 0x04064208, 0x14081209,   // az.tr.ro_654 et.sw.hr_443 mt.de.fi_443 cs.it.is_444
  0x3a220107, 0x1c2330ad, 0x2b001f08, 0x0c0f1a08,   // en.tr.eu_432 be.uk.bg_643 ga.cy..._430 xxx.es.pl_443
  0x04001809, 0x19050107, 0x01001508, 0x2b011a08,   // hu.fi..._440 en.fr.et_432 lv.en..._430 xxx.en.cy_443
  // [4020]
  0x01152b09, 0x0b002914, 0x02420808, 0x1d100107,   // cy.lv.en_444 ms.no..._660 it.mt.da_443 en.sv.hr_432
  0x4b001f23, 0x43001602, 0x420c1709, 0x29004002,   // ga.az..._880 lt.vi..._220 ro.pl.mt_444 sl.ms..._220
  0x10001a23, 0x660614a4, 0x160b0412, 0x1f184512,   // xxx.sv..._880 is.de.af_433 fi.no.lt_654 sk.hu.ga_654
  0x1e384202, 0x17430107, 0x2e080107, 0x29432709,   // mt.ca.sr_222 en.vi.ro_432 en.it.sq_432 id.vi.ms_444
  // [4030]
  0x12002e13, 0x0f1f05a4, 0x424b08a4, 0x122e3fa4,   // sq.cs..._650 fr.ga.es_433 it.az.mt_433 sw.sq.cs_433
  0x08002e22, 0x211d1a09, 0x046619a4, 0x154b3a08,   // sq.it..._870 xxx.hr.tl_444 et.af.fi_433 eu.az.lv_443
  0x0d2b0607, 0x450d1702, 0x14000308, 0x1f100613,   // de.cy.pt_432 ro.pt.sk_222 nl.is..._430 de.sv.ga_665
  0x05006613, 0x051842a4, 0x27292e14, 0x3f1a2107,   // af.fr..._650 mt.hu.fr_433 sq.ms.id_666 tl.xxx.sw_432
  // [4040]
  0x29454202, 0x423f2ea4, 0x3f001422, 0x27291502,   // mt.sk.ms_222 sq.sw.mt_433 is.sw..._870 lv.ms.id_222
  0x0b001223, 0x45004223, 0x150419af, 0x401e1d07,   // cs.no..._880 mt.sk..._880 et.fi.lv_655 hr.sr.sl_432
  0x40003813, 0x12400caf, 0x1e1d3f08, 0x3a0121a4,   // ca.sl..._650 pl.sl.cs_655 sw.hr.sr_443 tl.en.eu_433
  0x4b004207, 0x17033a11, 0x3f000808, 0x14161560,   // mt.az..._420 eu.nl.ro_653 it.sw..._430 lv.lt.is_664
  // [4050]
  0x8c171f07, 0x0c001213, 0x0f1f4207, 0x12154502,   // ga.ro.ht_432 cs.pl..._650 mt.ga.es_432 sk.lv.cs_222
  0x14001f11, 0x0f170d13, 0x42001808, 0x22000422,   // ga.is..._630 pt.ro.es_665 hu.mt..._430 fi.tr..._870
  0x221d1e08, 0x45163802, 0x170f38a4, 0x66001421,   // sr.hr.tr_443 ca.lt.sk_222 ca.es.ro_433 is.af..._860
  0x1d181702, 0x18141f12, 0x45121407, 0x02278ca4,   // ro.hu.hr_222 ga.is.hu_654 is.cs.sk_432 ht.id.da_433
  // [4060]
  0x3a033f13, 0x12451811, 0x14001f07, 0x1e0c1daf,   // sw.nl.eu_665 hu.sk.cs_653 ga.is..._420 hr.pl.sr_655
  0x3a272909, 0x01002222, 0x3f212909, 0x1d0d0b07,   // ms.id.eu_444 tr.en..._870 ms.tl.sw_444 no.pt.hr_432
  0x4b272914, 0x18003808, 0x3a030b07, 0x29220c02,   // ms.id.az_666 ca.hu..._430 no.nl.eu_432 pl.tr.ms_222
  0x1c0e2511, 0x041619a4, 0x151d1607, 0x25231e12,   // mk.ru.bg_653 et.lt.fi_433 lt.hr.lv_432 sr.uk.mk_654
  // [4070]
  0x140604a4, 0x060429a4, 0x121e1d09, 0x38000622,   // fi.de.is_433 ms.fi.de_433 hr.sr.cs_444 de.ca..._870
  0x03140b08, 0x211014a4, 0x3f2e1609, 0x160d2e14,   // no.is.nl_443 is.sv.tl_433 lt.sq.sw_444 sq.pt.lt_666
  0x08001f23, 0x16002e11, 0x15002e13, 0x160804af,   // ga.it..._880 sq.lt..._630 sq.lv..._650 fi.it.lt_655
  0x1d381a02, 0x17002022, 0x00000f03, 0x0d081508,   // xxx.ca.hr_222 gl.ro..._870 es......_300 lv.it.pt_443
  // [4080]
  0x17080508, 0x06151f60, 0x1a000823, 0x0d141fa4,   // fr.it.ro_443 ga.lv.de_664 it.xxx..._880 ga.is.pt_433
  0x0f451209, 0x162e4009, 0x0d180560, 0x0f3a8c13,   // cs.sk.es_444 sl.sq.lt_444 fr.hu.pt_664 ht.eu.es_665
  0x293f0f02, 0x38080f09, 0x38000614, 0x224b2909,   // es.sw.ms_222 es.it.ca_444 de.ca..._660 ms.az.tr_444
  0x021e1d12, 0x29040b07, 0x1d1e0802, 0x4b223a12,   // hr.sr.da_654 no.fi.ms_432 it.sr.hr_222 eu.tr.az_654
  // [4090]
  0x224b2707, 0x04004b23, 0x01171fa4, 0x1d000813,   // id.az.tr_432 az.fi..._880 ga.ro.en_433 it.hr..._650
  0x201f0155, 0x1e1d1511, 0x1d401509, 0x0f170d08,   // en.ga.gl_442 lv.hr.sr_653 lv.sl.hr_444 pt.ro.es_443
  0x15000508, 0x04422213, 0x290b2702, 0x03001d14,   // fr.lv..._430 tr.mt.fi_665 id.no.ms_222 hr.nl..._660
  0x0c162160, 0x292b0107, 0x3f184209, 0x291d2709,   // tl.lt.pl_664 en.cy.ms_432 mt.hu.sw_444 id.hr.ms_444
  // [40a0]
  0x0b100308, 0x27160802, 0x18000102, 0x06002e07,   // nl.sv.no_443 it.lt.id_222 en.hu..._220 sq.de..._420
  0x450c0f12, 0x43003a09, 0x061608a4, 0x218c2707,   // es.pl.sk_654 eu.vi..._440 it.lt.de_433 id.ht.tl_432
  0x22054308, 0x43161508, 0x278c2902, 0x143a0b09,   // vi.fr.tr_443 lv.lt.vi_443 ms.ht.id_222 no.eu.is_444
  0x1d0f2002, 0x3a003f12, 0x1d121ea4, 0x42100202,   // gl.es.hr_222 sw.eu..._640 sr.cs.hr_433 da.sv.mt_222
  // [40b0]
  0x3f001f21, 0x380f8c09, 0x02000c02, 0x451f0f02,   // ga.sw..._860 ht.es.ca_444 pl.da..._220 es.ga.sk_222
  0x14001021, 0x1d400109, 0x1d161e08, 0x1e1d2e14,   // sv.is..._860 en.sl.hr_444 sr.lt.hr_443 sq.hr.sr_666
  0x1d154502, 0x0d184512, 0x1f184521, 0x010b1a12,   // sk.lv.hr_222 sk.hu.pt_654 sk.hu.ga_876 xxx.no.en_654
  0x3f061a08, 0x3f291fa4, 0x38103a08, 0x293a1002,   // xxx.de.sw_443 ga.ms.sw_433 eu.sv.ca_443 sv.eu.ms_222
  // [40c0]
  0x8c0f0509, 0x03060b09, 0x122b3f12, 0x22064208,   // fr.es.ht_444 no.de.nl_444 sw.cy.cs_654 mt.de.tr_443
  0x45121a07, 0x124566a4, 0x401d4555, 0x1d401612,   // xxx.cs.sk_432 af.sk.cs_433 sk.hr.sl_442 lt.sl.hr_654
  0x16000502, 0x03122e11, 0x3f162108, 0x14002922,   // fr.lt..._220 sq.cs.nl_653 tl.lt.sw_443 ms.is..._870
  0x420b1460,                                       // is.no.mt_664
  };

COMPILE_ASSERT(16589 < (1 << 16), k_indirectbits_too_small);

extern const cld::CLDTableSummary kQuadTable_obj = {
  kQuadChrome,
  kQuadChromeInd,
  kQuadChromeSize,
  arraysize(kQuadChromeInd),
  kQuadChromeKeyMask,
  kQuadChromeBuildDate,
};

// End of generated tables
